#!/bin/sh
# ********************************************************************
# (C) Copyright IBM Corp.  2005-2006
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
#********************************************************************

DB=$1
USR=$2
PWRD=$3
TBSCHEM=$4

usage() {
    echo -n "usage: ReorgStats62 database username userpassword tableschema"
    exit 1
}

err_schema() {
    echo -n "Schema name $TBSCHEM is undefined Provide the right schema name"
    exit 1
}

error_connect() {
		echo -n "One of the parameters specified to connect to the database is incorrect"
		exit 1
}

if [ "$DB" == "" ]; then
    usage
fi
if [ "$USR" == "" ]; then
    usage
fi
if [ "$PWRD" == "" ]; then
    usage
fi
if [ "$TBSCHEM" == "" ]; then
    usage
fi

db2 connect to $DB user $USR using $PWRD
RETVAL=$?
if [ $RETVAL != 0 ]; then
    error_connect
fi


db2 set CURRENT SCHEMA $TBSCHEM
RETVAL=$?
if [ $RETVAL != 0 ]; then
    err_schema
fi


 db2 REORG TABLE $TBSCHEM.ACTIVITIES INDEX $TBSCHEM.ACTVT_TAID_CX USE TEMPSPACE32K   
RETVAL=$?
if [ $RETVAL != 0 ]; then
    err_schema
fi                 
 db2 REORG TABLE $TBSCHEM.ALERT_MESSAGES INDEX $TBSCHEM.ALMSG_ALID_LC_CU USE TEMPSPACE32K             
 db2 REORG TABLE $TBSCHEM.ASSET_CROSS_CHARGE INDEX $TBSCHEM.ASTCC_AIPI_CU USE TEMPSPACE32K            
 db2 REORG TABLE $TBSCHEM.ASSET_DEPRECIATION INDEX $TBSCHEM.ASDEP_EID_CU USE TEMPSPACE32K             
 db2 REORG TABLE $TBSCHEM.ASSET_MAINTENANCE INDEX $TBSCHEM.ASMTN_EID_CU USE TEMPSPACE32K              
 db2 REORG TABLE $TBSCHEM.ASSET_ORGANIZATIONS INDEX $TBSCHEM.ORG_ASSORG_CU USE TEMPSPACE32K           
 db2 REORG TABLE $TBSCHEM.ASSET_REFERENCES INDEX $TBSCHEM.ASSETREF_EID_CU USE TEMPSPACE32K            
 db2 REORG TABLE $TBSCHEM.ASSET_RESOURCES INDEX $TBSCHEM.RS_ASSRES_CU USE TEMPSPACE32K                
 db2 REORG TABLE $TBSCHEM.ASSET_RTF INDEX $TBSCHEM.ASSETRT_EID_CX USE TEMPSPACE32K                    
 db2 REORG TABLE $TBSCHEM.BUDGETS INDEX $TBSCHEM.BDGTS_EBCID_CU USE TEMPSPACE32K                      
 db2 REORG TABLE $TBSCHEM.CALENDAR_DAY_OF_YEAR INDEX $TBSCHEM.CLDYR_EID_DY_CU USE TEMPSPACE32K        
 db2 REORG TABLE $TBSCHEM.CALENDAR_EXCEPTIONS INDEX $TBSCHEM.CLDEX_CLR_CX USE TEMPSPACE32K            
 db2 REORG TABLE $TBSCHEM.CLIENT_REFERENCES INDEX $TBSCHEM.CLIENTREF_EID_CU USE TEMPSPACE32K          
 db2 REORG TABLE $TBSCHEM.CLIENT_RTF INDEX $TBSCHEM.CLIENTRT_EID_CX USE TEMPSPACE32K                  
 db2 REORG TABLE $TBSCHEM.COST_APPROVAL_STATUS INDEX $TBSCHEM.IDX_CAS0 USE TEMPSPACE32K               
 db2 REORG TABLE $TBSCHEM.CRIDEPENDENCIES INDEX $TBSCHEM.CRDPN_PPSPID_CX USE TEMPSPACE32K             
 db2 REORG TABLE $TBSCHEM.CRI_RTF INDEX $TBSCHEM.CRIRT_EID_CX USE TEMPSPACE32K                        
 db2 REORG TABLE $TBSCHEM.DEPENDENCIES INDEX $TBSCHEM.DPNXX_PPSPID_CX USE TEMPSPACE32K                
 db2 REORG TABLE $TBSCHEM.DOCUMENT_BLOBS INDEX $TBSCHEM.DCBLB_EID_CU USE TEMPSPACE32K                 
 db2 REORG TABLE $TBSCHEM.DOC_RTF INDEX $TBSCHEM.DOCRT_EID_CX USE TEMPSPACE32K                        
 db2 REORG TABLE $TBSCHEM.EFFORT_WEEK INDEX $TBSCHEM.IDX_EW0 USE TEMPSPACE32K                         
 db2 REORG TABLE $TBSCHEM.FAVORITE_ACTIVITIES INDEX $TBSCHEM.FVACT_RPJID_CX USE TEMPSPACE32K          
 db2 REORG TABLE $TBSCHEM.FISCAL_CALENDAR INDEX $TBSCHEM.FY_Y_M USE TEMPSPACE32K                      
 db2 REORG TABLE $TBSCHEM.FS_XML_MONITOR INDEX $TBSCHEM.FSXMN_RDT_CX USE TEMPSPACE32K                 
 db2 REORG TABLE $TBSCHEM.HISTORY_ASSETS INDEX $TBSCHEM.HSASX_EID_RDT_CX USE TEMPSPACE32K             
 db2 REORG TABLE $TBSCHEM.HISTORY_ASSET_DOCUMENTS INDEX $TBSCHEM.HASSD_EID_MJIRV_CU USE TEMPSPACE32K  
 db2 REORG TABLE $TBSCHEM.HISTORY_ASSET_RTF INDEX $TBSCHEM.HSASR_EID_CX USE TEMPSPACE32K              
 db2 REORG TABLE $TBSCHEM.HISTORY_CLIENTS INDEX $TBSCHEM.HSCLX_EID_RDT_CX USE TEMPSPACE32K            
 db2 REORG TABLE $TBSCHEM.HISTORY_CLIENT_DOCUMENTS INDEX $TBSCHEM.HCLID_EID_MJIRV_CU USE TEMPSPACE32K 
 db2 REORG TABLE $TBSCHEM.HISTORY_CLIENT_RTF INDEX $TBSCHEM.HSCLR_EID_CX USE TEMPSPACE32K             
 db2 REORG TABLE $TBSCHEM.HISTORY_CRI INDEX $TBSCHEM.HSCRI_EID_RDT_CX USE TEMPSPACE32K                
 db2 REORG TABLE $TBSCHEM.HISTORY_CRI_RTF INDEX $TBSCHEM.HSCRT_EID_CX USE TEMPSPACE32K                
 db2 REORG TABLE $TBSCHEM.HISTORY_DOCUMENTS INDEX $TBSCHEM.HSDOC_EID_MJIRV_CU USE TEMPSPACE32K        
 db2 REORG TABLE $TBSCHEM.HISTORY_DOC_RTF INDEX $TBSCHEM.HSDCR_EID_CX USE TEMPSPACE32K                
 db2 REORG TABLE $TBSCHEM.HISTORY_POOLS INDEX $TBSCHEM.HSPLX_EID_RDT_CX USE TEMPSPACE32K              
 db2 REORG TABLE $TBSCHEM.HISTORY_POOL_DOCUMENTS INDEX $TBSCHEM.HPOOLD_EID_RV_CU USE TEMPSPACE32K     
 db2 REORG TABLE $TBSCHEM.HISTORY_RESOURCE_DOCUMENTS INDEX $TBSCHEM.HRD_EID_MJIRV_CU USE TEMPSPACE32K 
 db2 REORG TABLE $TBSCHEM.HISTORY_VENDORS INDEX $TBSCHEM.HSVNX_EID_RDT_CX USE TEMPSPACE32K            
 db2 REORG TABLE $TBSCHEM.HISTORY_VENDOR_DOCUMENTS INDEX $TBSCHEM.HVEND_EID_MJIRV_CU USE TEMPSPACE32K 
 db2 REORG TABLE $TBSCHEM.HISTORY_WBS INDEX $TBSCHEM.HSWBS_EID_RDT_CX USE TEMPSPACE32K                
 db2 REORG TABLE $TBSCHEM.HISTORY_WBS_RTF INDEX $TBSCHEM.HSWBR_EID_CX USE TEMPSPACE32K                
 db2 REORG TABLE $TBSCHEM.LEVEL_TASK_DAY_OF_YEAR INDEX $TBSCHEM.LTKDYR_PJTAID_DYCU USE TEMPSPACE32K   
 db2 REORG TABLE $TBSCHEM.POOL_REFERENCES INDEX $TBSCHEM.PLREF_EID_CU USE TEMPSPACE32K                
 db2 REORG TABLE $TBSCHEM.PROFILES INDEX $TBSCHEM.PRFLS_PJPFID_NM_CU USE TEMPSPACE32K                 
 db2 REORG TABLE $TBSCHEM.PROJECT_ALERTS INDEX $TBSCHEM.PJALT_PJALID_CU USE TEMPSPACE32K              
 db2 REORG TABLE $TBSCHEM.PROJECT_ASSIGNMENTS INDEX $TBSCHEM.PJASG_RPJID_CX USE TEMPSPACE32K          
 db2 REORG TABLE $TBSCHEM.PROJECT_CHARGEBACK INDEX $TBSCHEM.CHAGB_EBCID_CU USE TEMPSPACE32K           
 db2 REORG TABLE $TBSCHEM.PROJECT_COSTBACK INDEX $TBSCHEM.COSTB_EBCID_CU USE TEMPSPACE32K             
 db2 REORG TABLE $TBSCHEM.PROJECT_DISCOUNT INDEX $TBSCHEM.PRDIC_EID_CU USE TEMPSPACE32K               
 db2 REORG TABLE $TBSCHEM.RATES INDEX $TBSCHEM.RTSXX_RTID_CU USE TEMPSPACE32K                         
 db2 REORG TABLE $TBSCHEM.RESOURCE_ASSIGNMENTS INDEX $TBSCHEM.RSAS_EID_RT_RID_CX USE TEMPSPACE32K     
 db2 REORG TABLE $TBSCHEM.RESOURCE_ASSIGN_SKILLS INDEX $TBSCHEM.RSASK_GKID_XU USE TEMPSPACE32K        
 db2 REORG TABLE $TBSCHEM.RESOURCE_EDUCATION INDEX $TBSCHEM.RSEDU_RID_CX USE TEMPSPACE32K             
 db2 REORG TABLE $TBSCHEM.RESOURCE_EMPLOYMENT_HISTORY INDEX $TBSCHEM.RSEMH_RID_CX USE TEMPSPACE32K    
 db2 REORG TABLE $TBSCHEM.RESOURCE_INDUSTRY_EXPERIENCE INDEX $TBSCHEM.RINEX_RID_CX USE TEMPSPACE32K   
 db2 REORG TABLE $TBSCHEM.RESOURCE_PROJECT_HISTORY INDEX $TBSCHEM.RSPJH_RID_CX USE TEMPSPACE32K       
 db2 REORG TABLE $TBSCHEM.RESOURCE_READINESS INDEX $TBSCHEM.RSRDN_RID_CX USE TEMPSPACE32K             
 db2 REORG TABLE $TBSCHEM.SUMMARY_TIMESHEETS INDEX $TBSCHEM.SMRTS_RPJID_CX USE TEMPSPACE32K           
 db2 REORG TABLE $TBSCHEM.TASK_ASSIGNMENTS INDEX $TBSCHEM.TKASG_PJTRID_BF_CX USE TEMPSPACE32K         
 db2 REORG TABLE $TBSCHEM.TASK_DAY_OF_YEAR INDEX $TBSCHEM.TKDYR_PJTAID_DY_CU USE TEMPSPACE32K         
 db2 REORG TABLE $TBSCHEM.TIMESHEET_APPROVAL_STATUS INDEX $TBSCHEM.IDX_TAS0 USE TEMPSPACE32K          
 db2 REORG TABLE $TBSCHEM.TMT_ASSETS INDEX $TBSCHEM.TASSET_RK_CU USE TEMPSPACE32K                     
 db2 REORG TABLE $TBSCHEM.TMT_ASSET_ATTRIBUTES INDEX $TBSCHEM.TASSETA_RK_CU USE TEMPSPACE32K          
 db2 REORG TABLE $TBSCHEM.TMT_ASSET_DOCUMENTS INDEX $TBSCHEM.ASSDOC_PRK_RK_CX USE TEMPSPACE32K        
 db2 REORG TABLE $TBSCHEM.TMT_ASSIGNED_SCORECARDS INDEX $TBSCHEM.IDX_ASC0 USE TEMPSPACE32K            
 db2 REORG TABLE $TBSCHEM.TMT_CALENDARS INDEX $TBSCHEM.TCLND_RK_CU USE TEMPSPACE32K                   
 db2 REORG TABLE $TBSCHEM.TMT_CHARGECODES INDEX $TBSCHEM.TCHCD_RK_CU USE TEMPSPACE32K                 
 db2 REORG TABLE $TBSCHEM.TMT_CLIENTS INDEX $TBSCHEM.TCLIENT_RK_CU USE TEMPSPACE32K                   
 db2 REORG TABLE $TBSCHEM.TMT_CLIENT_ATTRIBUTES INDEX $TBSCHEM.TCLIENTA_RK_CU USE TEMPSPACE32K        
 db2 REORG TABLE $TBSCHEM.TMT_CLIENT_DOCUMENTS INDEX $TBSCHEM.CLIDOC_PRK_RK_CX USE TEMPSPACE32K       
 db2 REORG TABLE $TBSCHEM.TMT_COMPETENCIES INDEX $TBSCHEM.TCMPT_RK_CU USE TEMPSPACE32K                
 db2 REORG TABLE $TBSCHEM.TMT_CONTACTS INDEX $TBSCHEM.TCNTC_RK_CU USE TEMPSPACE32K                    
 db2 REORG TABLE $TBSCHEM.TMT_CONTRACTS INDEX $TBSCHEM.TCONTR_RK_CU USE TEMPSPACE32K                  
 db2 REORG TABLE $TBSCHEM.TMT_COSTS INDEX $TBSCHEM.TCSTS_RK_CU USE TEMPSPACE32K                       
 db2 REORG TABLE $TBSCHEM.TMT_CRI INDEX $TBSCHEM.TCRIX_PRK_RK_CX USE TEMPSPACE32K                     
 db2 REORG TABLE $TBSCHEM.TMT_CRI_ATTRIBUTES INDEX $TBSCHEM.TCRIA_RK_CU USE TEMPSPACE32K              
 db2 REORG TABLE $TBSCHEM.TMT_DATAFIELDS INDEX $TBSCHEM.TDTFL_TID_CX USE TEMPSPACE32K                 
 db2 REORG TABLE $TBSCHEM.TMT_DOCUMENTS INDEX $TBSCHEM.TDCMT_PRK_RK_CX USE TEMPSPACE32K               
 db2 REORG TABLE $TBSCHEM.TMT_DOCUMENT_ATTRIBUTES INDEX $TBSCHEM.TDOCA_RK_CU USE TEMPSPACE32K         
 db2 REORG TABLE $TBSCHEM.TMT_DOMAINS INDEX $TBSCHEM.TDOMN_RK_CU USE TEMPSPACE32K                     
 db2 REORG TABLE $TBSCHEM.TMT_FACTORS INDEX $TBSCHEM.TFCTR_RK_CU USE TEMPSPACE32K                     
 db2 REORG TABLE $TBSCHEM.TMT_GEOGRAPHIES INDEX $TBSCHEM.TGEOG_RK_CU USE TEMPSPACE32K                 
 db2 REORG TABLE $TBSCHEM.TMT_GLOBAL_SECURITY INDEX $TBSCHEM.TGLSC_RK_CU USE TEMPSPACE32K             
 db2 REORG TABLE $TBSCHEM.TMT_NAB INDEX $TBSCHEM.TNABX_RK_CU USE TEMPSPACE32K                         
 db2 REORG TABLE $TBSCHEM.TMT_ORGANIZATIONS INDEX $TBSCHEM.TORGN_RK_CU USE TEMPSPACE32K               
 db2 REORG TABLE $TBSCHEM.TMT_POOLS INDEX $TBSCHEM.TPOOL_RK_CU USE TEMPSPACE32K                       
 db2 REORG TABLE $TBSCHEM.TMT_POOL_ATTRIBUTES INDEX $TBSCHEM.TPOLA_RK_CU USE TEMPSPACE32K             
 db2 REORG TABLE $TBSCHEM.TMT_POOL_DOCUMENTS INDEX $TBSCHEM.POOLDOC_PRK_RK_CX USE TEMPSPACE32K        
 db2 REORG TABLE $TBSCHEM.TMT_PORTFOLIOS INDEX $TBSCHEM.TPRTF_RK_CU USE TEMPSPACE32K                  
 db2 REORG TABLE $TBSCHEM.TMT_PUBLISHED_SCORECARDS INDEX $TBSCHEM.IDX_PSC0 USE TEMPSPACE32K           
 db2 REORG TABLE $TBSCHEM.TMT_REPORT_SECURITY INDEX $TBSCHEM.TRPSC_RK_CU USE TEMPSPACE32K             
 db2 REORG TABLE $TBSCHEM.TMT_RESOURCE_DOCUMENTS INDEX $TBSCHEM.TRD_PRK_RK_CX USE TEMPSPACE32K        
 db2 REORG TABLE $TBSCHEM.TMT_SCENARIOS INDEX $TBSCHEM.TSCEN_RK_CU USE TEMPSPACE32K                   
 db2 REORG TABLE $TBSCHEM.TMT_SCORECARDS_DEF_AST INDEX $TBSCHEM.TSCRD_D_A_RK_CU USE TEMPSPACE32K      
 db2 REORG TABLE $TBSCHEM.TMT_SCORECARDS_DEF_CRI INDEX $TBSCHEM.TSCRD_D_C_RK_CU USE TEMPSPACE32K      
 db2 REORG TABLE $TBSCHEM.TMT_SCORECARDS_DEF_RES INDEX $TBSCHEM.TSCRD_D_R_RK_CU USE TEMPSPACE32K      
 db2 REORG TABLE $TBSCHEM.TMT_SCORECARDS_DEF_WBS INDEX $TBSCHEM.TSCRD_D_W_RK_CU USE TEMPSPACE32K      
 db2 REORG TABLE $TBSCHEM.TMT_TIMECODES INDEX $TBSCHEM.TTMCD_RK_CU USE TEMPSPACE32K                   
 db2 REORG TABLE $TBSCHEM.TMT_VENDORS INDEX $TBSCHEM.TVENDOR_RK_CU USE TEMPSPACE32K                   
 db2 REORG TABLE $TBSCHEM.TMT_VENDOR_ATTRIBUTES INDEX $TBSCHEM.TVENDORA_RK_CU USE TEMPSPACE32K        
 db2 REORG TABLE $TBSCHEM.TMT_VENDOR_DOCUMENTS INDEX $TBSCHEM.VENDOC_PRK_RK_CX USE TEMPSPACE32K       
 db2 REORG TABLE $TBSCHEM.TMT_WBS INDEX $TBSCHEM.TWBSX_RK_CU USE TEMPSPACE32K                         
 db2 REORG TABLE $TBSCHEM.TMT_WBS_ATTRIBUTES INDEX $TBSCHEM.TWBSA_RK_CU USE TEMPSPACE32K              
 db2 REORG TABLE $TBSCHEM.TMT_WORKFLOWS INDEX $TBSCHEM.TWKFL_RK_CU USE TEMPSPACE32K                   
 db2 REORG TABLE $TBSCHEM.TMT_WORKFLOW_CYCLES INDEX $TBSCHEM.TWFCL_RK_CU USE TEMPSPACE32K             
 db2 REORG TABLE $TBSCHEM.VENDOR_REFERENCES INDEX $TBSCHEM.VENDORREF_EID_CU USE TEMPSPACE32K          
 db2 REORG TABLE $TBSCHEM.WBS_RTF INDEX $TBSCHEM.WBSRT_EID_CX USE TEMPSPACE32K                        
 db2 REORG TABLE $TBSCHEM.WORKFLOW_REPLIES INDEX $TBSCHEM.WKFRP_EID_CX USE TEMPSPACE32K 
 db2 REORG TABLE $TBSCHEM.TMT_LAYOUTS INDEX $TBSCHEM.TMTLO_RK_CU USE TEMPSPACE32K
 db2 REORG TABLE $TBSCHEM.TMT_CUSTOM_DATASETS  INDEX $TBSCHEM.CDS_RANK USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_ACTIONS INDEX $TBSCHEM.TACT_RK_CU USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_ASSET_CUSTOM_FIELDS INDEX $TBSCHEM.TASSETCF_RK_CU  USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_CATEGORY_COLUMNS INDEX $TBSCHEM.TCATCOL_RK_CU USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_CLIENT_CUSTOM_FIELDS INDEX $TBSCHEM.TCLIENTCF_RK_CU USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_CUSTOM_FIELDS  INDEX $TBSCHEM.TCF_RK_CU  USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_CUSTOM_PORTLETS  INDEX $TBSCHEM.TCPORT_RK_CU USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_DOC_CUSTOM_FIELDS INDEX $TBSCHEM.TDOCCF_RK_CU USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_EXTERNAL_ACTIONS INDEX $TBSCHEM.TEXTA_RK_CU USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_INHERITANCE_MDS INDEX $TBSCHEM.TIMDS_RK_CU USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_MASTER_DATASETS INDEX $TBSCHEM.TMDS_RK_CU USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_MDS_CALC_FIELDS INDEX $TBSCHEM.TMDSCALF_RK_CU USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_RESOURCE_CUSTOM_FIELDS INDEX $TBSCHEM.TRESCF_RK_CU USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_WBS_CRI_CUSTOM_FIELDS  INDEX $TBSCHEM.TWBSCF_RK_CU USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.TMT_WORKFLOW_QUERY  INDEX $TBSCHEM.TWKFQ_RK_CU USE TEMPSPACE32K
db2 REORG TABLE $TBSCHEM.WORKFLOW_PREDEF_COLUMNS  INDEX $TBSCHEM.WKFPCOL_RK_CU USE TEMPSPACE32K



                    
 db2 REORG TABLE $TBSCHEM.ALERT_MSG_PREDEF_COLUMN          
 db2 REORG TABLE $TBSCHEM.ASSET_DEPENDENCIES          
 db2 REORG TABLE $TBSCHEM.CONTRACT_BREAKDOWN             
 db2 REORG TABLE $TBSCHEM.COST_APPROVAL                   
 db2 REORG TABLE $TBSCHEM.CURRENCY_EXCHANGES           
 db2 REORG TABLE $TBSCHEM.DETAIL_TIMESHEETS                                   
 db2 REORG TABLE $TBSCHEM.HISTORY_ASSIGNED_SCORECARDS  
 db2 REORG TABLE $TBSCHEM.HISTORY_CALENDARS                      
 db2 REORG TABLE $TBSCHEM.HISTORY_DOCUMENT_SCORECARDS 
 db2 REORG TABLE $TBSCHEM.HISTORY_PUBLISHED_SCORECARDS 
 db2 REORG TABLE $TBSCHEM.HISTORY_RESOURCES                
 db2 REORG TABLE $TBSCHEM.PDA_LOOKUP                        
 db2 REORG TABLE $TBSCHEM.PENDING_MONITOR              
 db2 REORG TABLE $TBSCHEM.PMO_DEFAULTS                         
 db2 REORG TABLE $TBSCHEM.PROJECT_BUDGET_BREAKDOWN           
 db2 REORG TABLE $TBSCHEM.PROJECT_CHARGEBACK_BREAKDOWN       
 db2 REORG TABLE $TBSCHEM.PROJECT_COST_CENTERS          
 db2 REORG TABLE $TBSCHEM.PROJECT_DETAILS             
 db2 REORG TABLE $TBSCHEM.PROJECT_RECONCILIATION         
 db2 REORG TABLE $TBSCHEM.PROJECT_STATE_DEF                
 db2 REORG TABLE $TBSCHEM.PROJECT_STATE_TRG                
 db2 REORG TABLE $TBSCHEM.RESOURCES                    
 db2 REORG TABLE $TBSCHEM.RESOURCE_ASSIGN_ROLES              
 db2 REORG TABLE $TBSCHEM.RESOURCE_COST_CENTERS         
 db2 REORG TABLE $TBSCHEM.RM_ASSIGNMENTS                 
 db2 REORG TABLE $TBSCHEM.STATE_TASK_NEXT_STATE_CNFG 
 db2 REORG TABLE $TBSCHEM.TIMEPHASED_DELTA                   
 db2 REORG TABLE $TBSCHEM.TIMEPHASED_PROJECT                  
 db2 REORG TABLE $TBSCHEM.TMT_SETTINGS                     
 db2 REORG TABLE $TBSCHEM.USER_SESSIONS  
 db2 REORG TABLE $TBSCHEM.STEP_ASSOCIATED_ITEMS 
 db2 REORG TABLE $TBSCHEM.PROCESS_DEFAULTS
 db2 REORG TABLE $TBSCHEM.STEP_CHECKLIST
 db2 REORG TABLE $TBSCHEM.STEP_PARTICIPANT
 db2 REORG TABLE $TBSCHEM.WKF_ROLES
 db2 REORG TABLE $TBSCHEM.OUTCOME_STEPS
 db2 REORG TABLE $TBSCHEM.OUTCOME_ADOPTS
 db2 REORG TABLE $TBSCHEM.TMT_OUTCOME_MONITORS
 db2 REORG TABLE $TBSCHEM.PROJECT_WKF_PROCESS
 db2 REORG TABLE $TBSCHEM.PROJECT_WKF_ROLES
 db2 REORG TABLE $TBSCHEM.WKF_ATTACHMENTS
 db2 REORG TABLE $TBSCHEM.WKF_CHECKLIST
 db2 REORG TABLE $TBSCHEM.WKF_OUTCOMES
db2 REORG TABLE $TBSCHEM.WKF_OUTCOME_ADOPTS
db2 REORG TABLE $TBSCHEM.WKF_MONITOR_ITEMS
db2 REORG TABLE $TBSCHEM.PJC_CHARTS_SECURITY


db2 REORG TABLE $TBSCHEM.ASSIGNED_ACTIONS
db2 REORG TABLE $TBSCHEM.ASSIGNED_EXTERNAL_ACTIONS
db2 REORG TABLE $TBSCHEM.ASSIGNED_PROCESS
db2 REORG TABLE $TBSCHEM.RES_ASSIGNED_ORG
db2 REORG TABLE $TBSCHEM.PRJ_ASSIGNED_ORG
db2 REORG TABLE $TBSCHEM.RES_ORG_FILTER
db2 REORG TABLE $TBSCHEM.SCHED_PROCESSES
db2 REORG TABLE $TBSCHEM.EXTERNAL_ACTION_MONITOR
db2 REORG TABLE $TBSCHEM.MDS_CATEGORY
db2 REORG TABLE $TBSCHEM.CDS_ASSIGNED_COLUMNS
db2 REORG TABLE $TBSCHEM.CDS_QUERY_PARAMS
db2 REORG TABLE $TBSCHEM.CRI_TYPES
db2 REORG TABLE $TBSCHEM.CUSTOM_FIELD_TYPE_MAPPING
db2 REORG TABLE $TBSCHEM.QUERY_CONDITION


 
 
 
 
db2 RUNSTATS ON TABLE $TBSCHEM.ACTIVITIES AND DETAILED INDEXES ALL SHRLEVEL CHANGE            
db2 RUNSTATS ON TABLE $TBSCHEM.ALERTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.ALERT_MESSAGES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.ALERT_MSG_PREDEF_COLUMN AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.ASSET_CROSS_CHARGE AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.ASSET_DEPENDENCIES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.ASSET_DEPRECIATION AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.ASSET_MAINTENANCE AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.ASSET_ORGANIZATIONS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.ASSET_REFERENCES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.ASSET_RESOURCES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.ASSET_RTF AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.BUDGETS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.CALENDAR_DAY_OF_YEAR AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.CALENDAR_EXCEPTIONS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.CHANGE_LOG AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.CLIENT_REFERENCES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.CLIENT_RTF AND DETAILED INDEXES ALL SHRLEVEL CHANGE
 db2 RUNSTATS ON TABLE $TBSCHEM.CONTRACT_BREAKDOWN AND DETAILED INDEXES ALL SHRLEVEL CHANGE           
db2 RUNSTATS ON TABLE $TBSCHEM.COST_APPROVAL AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.COST_APPROVAL_STATUS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.CRIDEPENDENCIES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.CRI_RTF AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.CURRENCY_EXCHANGES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.DEPENDENCIES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.DETAIL_TIMESHEETS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.DOCUMENT_BLOBS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.DOC_RTF AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.DUAL AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.EFFORT_WEEK AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.FAVORITE_ACTIVITIES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.FISCAL_CALENDAR AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.FS_XML_MONITOR AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_ASSETS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_ASSET_DOCUMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_ASSET_RTF AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_ASSIGNED_SCORECARDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_CALENDARS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_CLIENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_CLIENT_DOCUMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_CLIENT_RTF AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_CRI AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_CRI_RTF AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_DOCUMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_DOCUMENT_SCORECARDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_DOC_RTF AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_POOLS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_POOL_DOCUMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_PUBLISHED_SCORECARDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_RESOURCES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_RESOURCE_DOCUMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_VENDORS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_VENDOR_DOCUMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_WBS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.HISTORY_WBS_RTF AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.LEVEL_TASK_DAY_OF_YEAR AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PDA_LOOKUP AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PENDING_MONITOR AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PMO_DEFAULTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.POOL_REFERENCES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROC_LOG AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROFILES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_ALERTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_ASSIGNMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_BUDGET_BREAKDOWN AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_CHARGEBACK AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_CHARGEBACK_BREAKDOWN AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_COSTBACK AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_COST_CENTERS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_DETAILS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_DISCOUNT AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_RECONCILIATION AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_STATE_DEF AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_STATE_TRG AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RATES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RESOURCES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RESOURCE_ASSIGNMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RESOURCE_ASSIGN_ROLES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RESOURCE_ASSIGN_SKILLS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RESOURCE_COST_CENTERS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RESOURCE_EDUCATION AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RESOURCE_EMPLOYMENT_HISTORY AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RESOURCE_INDUSTRY_EXPERIENCE AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RESOURCE_PROJECT_HISTORY AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RESOURCE_READINESS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RM_ASSIGNMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.STATE_TASK_NEXT_STATE_CNFG AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.SUMMARY_TIMESHEETS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TASK_ASSIGNMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TASK_DAY_OF_YEAR AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TIMEPHASED_DELTA AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TIMEPHASED_PROJECT AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TIMESHEET_APPROVAL_STATUS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_ASSETS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_ASSET_ATTRIBUTES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_ASSET_DOCUMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_ASSIGNED_SCORECARDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CALENDARS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CHARGECODES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CLIENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CLIENT_ATTRIBUTES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CLIENT_DOCUMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_COMPETENCIES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CONTACTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
 db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CONTRACTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE                
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_COSTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CRI AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CRI_ATTRIBUTES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_DATAFIELDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_DOCUMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_DOCUMENT_ATTRIBUTES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_DOMAINS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_FACTORS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_GEOGRAPHIES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_GLOBAL_SECURITY AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_NAB AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_ORGANIZATIONS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_POOLS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_POOL_ATTRIBUTES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_POOL_DOCUMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_PORTFOLIOS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_PUBLISHED_SCORECARDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_REPORT_SECURITY AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_RESOURCE_DOCUMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_SCENARIOS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_SCORECARDS_DEF_AST AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_SCORECARDS_DEF_CRI AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_SCORECARDS_DEF_RES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_SCORECARDS_DEF_WBS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_SETTINGS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_TIMECODES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_VENDORS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_VENDOR_ATTRIBUTES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_VENDOR_DOCUMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_WBS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_WBS_ATTRIBUTES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_WORKFLOWS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_WORKFLOW_CYCLES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TRACE_PROCS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.USER_SESSIONS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.VENDOR_REFERENCES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.WBS_RTF AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.WORKFLOW_REPLIES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_LAYOUTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.STEP_ASSOCIATED_ITEMS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROCESS_DEFAULTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.STEP_CHECKLIST AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.STEP_PARTICIPANT AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.WKF_ROLES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.OUTCOME_STEPS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.OUTCOME_ADOPTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_OUTCOME_MONITORS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_WKF_PROCESS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PROJECT_WKF_ROLES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.WKF_ATTACHMENTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.WKF_CHECKLIST AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.WKF_OUTCOMES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.WKF_OUTCOME_ADOPTS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.WKF_MONITOR_ITEMS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PJC_CHARTS_SECURITY AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CUSTOM_FIELDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CUSTOM_PORTLETS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_WBS_CRI_CUSTOM_FIELDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_DOC_CUSTOM_FIELDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_RESOURCE_CUSTOM_FIELDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE 
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CLIENT_CUSTOM_FIELDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_ASSET_CUSTOM_FIELDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_ACTIONS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_EXTERNAL_ACTIONS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.ASSIGNED_ACTIONS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.ASSIGNED_EXTERNAL_ACTIONS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.ASSIGNED_PROCESS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RES_ASSIGNED_ORG AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.PRJ_ASSIGNED_ORG AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.RES_ORG_FILTER AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.SCHED_PROCESSES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.EXTERNAL_ACTION_MONITOR  AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.WORKFLOW_PREDEF_COLUMNS  AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_WORKFLOW_QUERY AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_MASTER_DATASETS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CATEGORY_COLUMNS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.MDS_CATEGORY AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.CDS_ASSIGNED_COLUMNS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_MDS_CALC_FIELDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.CDS_QUERY_PARAMS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_CUSTOM_DATASETS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.CRI_TYPES AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.TMT_INHERITANCE_MDS AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.CUSTOM_FIELD_TYPE_MAPPING AND DETAILED INDEXES ALL SHRLEVEL CHANGE
db2 RUNSTATS ON TABLE $TBSCHEM.QUERY_CONDITION AND DETAILED INDEXES ALL SHRLEVEL CHANGE










































 