#!/bin/bash
#/********************************************************************
# (C) Copyright IBM Corp.  2005-2006
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
#********************************************************************/

OWNER=
OWNERPASS=
DIR=logs
RESPONSE=
LOC=
CON=
FILENAME=RPMVERSION.sh
VALID_COUNT=


echo "******************************************************************"
echo "*           Welcome to RPM 6.2.2.3 Migration Script              *"
echo "*                                                                *"
echo "* This script migrates your connected user to 6.2.2.3.           *"
echo "*                                                                *"
echo "******************************************************************"


#check oracle_home

if [ "$ORACLE_HOME" != "" ]; then
	echo "**********************************************************************"
	echo " The script has verified that ORACLE_HOME is set to " $ORACLE_HOME
	echo "**********************************************************************"

	RESPONSE=
	while [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]
	do
		echo "Is this the right value?(y/n)"
		read RESPONSE
		if [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]; then
			echo "Invalid reply!"
		fi
	done

	if [ "$RESPONSE" != "y" -a "$RESPONSE" != "Y" ]; then
		ORACLE_HOME=
	fi
fi

while [ "$ORACLE_HOME" = "" ]
do
echo "Please enter ORACLE_HOME:"
read ORACLE_HOME
if [ "$ORACLE_HOME" = "" ]; then
	echo "no value for ORACLE_HOME"
fi
done

# check if sqlplus exists
if [ ! -x $ORACLE_HOME/bin/sqlplus ]; then
	echo
	echo "*********************************************************************"
	echo "* No migration was performed."                                         
	echo "* Reason: sqlplus not found in " $ORACLE_HOME/bin " directory."               
	echo "* Exiting 6.2.2.3 Migration Script."                                   
	echo "*********************************************************************"
	echo
	exit 0

fi

# ADD ORACLE_HOME/BIN TO PATH
export PATH=$PATH:$ORACLE_HOME/bin


LOC=
while [ "$LOC" != "y" -a  "$LOC" != "Y" -a "$LOC" != "n" -a "$LOC" != "N" ]
do
        echo "Is your RPM database installed on this machine?(y/n)"
        read LOC
        if [ "$LOC" != "y" -a  "$LOC" != "Y" -a "$LOC" != "n" -a "$LOC" != "N" ]; then
                echo "Invalid reply!"
        fi
done

if [ "$LOC" = "y" -o "$LOC" = "Y" ]; then

	if [ "$ORACLE_SID" != "" ]; then
		echo "**********************************************************************"
		echo " The script has verified that ORACLE_SID is set to " $ORACLE_SID
		echo "**********************************************************************"

		RESPONSE=
		while [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]
		do
			echo "Is this the right value?(y/n)"
			read RESPONSE
			if [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]; then
				echo "Invalid reply!"
			fi
		done

		if [ "$RESPONSE" != "y" -a "$RESPONSE" != "Y" ]; then
			ORACLE_SID=
		fi
	fi

	while [ "$ORACLE_SID" = "" ]
	do
	echo "Please enter ORACLE_SID:"
	read ORACLE_SID
	if [ "$ORACLE_SID" = "" ]; then
		echo "no value for ORACLE_SID"
	fi
	done

else
ORACLE_SID=
	while [ "$ORACLE_SID" = "" ]
	do
	echo "Please enter TNS string:"
	read ORACLE_SID
	if [ "$ORACLE_SID" = "" ]; then
		echo "no value for TNS string"
	fi
	done
fi


export ORACLE_SID


while [ "$OWNER" = "" ]
do
echo "Please enter IBMRPM schema owner:"
read OWNER
if [ "$OWNER" = "" ]; then
	echo "no value for owner"
fi
done

while [ "$OWNERPASS" = "" ]
do
echo "Please enter IBMRPM schema owner password:"
read OWNERPASS
if [ "$OWNERPASS" = "" ]; then
	echo "no value for owner password"
fi
done



	while [ "$CONUSER" = "" ]
	do
	echo "Please enter IBMRPM connected user name:"
	read CONUSER
	if [ "$CONUSER" = "" ]; then
		echo "no value for connected user name"
	fi
	done

	while [ "$CONPASS" = "" ]
	do
	echo "Please enter IBMRPM connected user password:"
	read CONPASS
	if [ "$CONPASS" = "" ]; then
		echo "no value for connected user password"
	fi
	done

	while [ "$SYSPASS" = "" ]
	do
	echo "Please enter sys password:"
	read SYSPASS
	if [ "$SYSPASS" = "" ]; then
		echo "no value for sys password"
	fi
	done
	
	if [ "$LOC" = "y" -o  "$LOC" = "Y" ]; then
		SYS_CON_STR=sys/$SYSPASS
		CON_CON_STR=$CONUSER/$CONPASS
	elif [ "$LOC" = "n" -o  "$LOC" = "N" ]; then
		SYS_CON_STR=sys/$SYSPASS@$ORACLE_SID
		CON_CON_STR=$CONUSER/$CONPASS@$ORACLE_SID

	fi


if [ "$LOC" = "y" -o  "$LOC" = "Y" ]; then
	CON=$OWNER/$OWNERPASS
elif [ "$LOC" = "n" -o "$LOC" = "N" ]; then
	CON=$OWNER/$OWNERPASS@$ORACLE_SID
fi

sqlplus -S /nolog @scripts/check/check_con.sql $CON

if [ "$?" != "0" ]; then
	echo "***********************************************************************"
	echo "* No migration was performed.                                         *"
	echo "* Reason: RPM schema owner was not able to connect to RPM database.   *"
	echo "* Exiting IBMRPM 6.2.2.3 Migration Script.                            *"
	echo "***********************************************************************"
	exit 0
fi

sqlplus -S /nolog @scripts/check/check_con_sys.sql $SYS_CON_STR

if [ "$?" != "0" ]; then
	echo "***********************************************************************"
	echo "* No migration was performed.                                         *"
	echo "* Reason: sys user was not able to connect to RPM database.           *"
	echo "* Exiting IBMRPM 6.2.2.3 Migration Script.                            *"
	echo "***********************************************************************"
	exit 0
fi

sqlplus -S /nolog @scripts/check/check_con.sql $CON_CON_STR

if [ "$?" != "0" ]; then
	echo "***********************************************************************"
	echo "* No migration was performed.                                         *"
	echo "* Reason: connected user was not able to connect to RPM database.     *"
	echo "* Exiting IBMRPM 6.2.2.3 Migration Script.                            *"
	echo "***********************************************************************"
	exit 0
fi



if [ ! -d $DIR ]; then 
mkdir $DIR
chmod 775 $DIR
fi

if [ -f $FILENAME ]; then
	rm $FILENAME
fi


echo "******************************************************************************"
echo "* Migration script has gathered all the necessary information for migrating  *"
echo "* your connected user.                                                       *"
echo "******************************************************************************"
RESPONSE=
while [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]
do
        echo "Are you sure you want to migrate your connected user now?(y/n)"
        read RESPONSE
        if [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]; then
                echo "Invalid reply!"
        fi
done

if [ "$RESPONSE" != "y" -a "$RESPONSE" != "Y" ]; then
	echo "**********************************************************************"
	echo "* No migration was performed.                                        *"
	echo "* Reason: Migration was cancelled by the user.                       *"
	echo "* Exiting 6.2.2.3 RPM Migration Script.                              *"
	echo "**********************************************************************"
	exit 0
fi



sqlplus -S $CON @scripts/check/recycle.sql >> $FILENAME
sqlplus /nolog @utils/createpmosecu.sql $SYS_CON_STR $CON $CONUSER
sqlplus /nolog @utils/createpmosyn.sql $OWNER $CON_CON_STR

if [ -f $FILENAME ]; then
	rm $FILENAME
fi

sqlplus -S $CON @scripts/check/recycle.sql >>$FILENAME
echo " "
echo "*******************************************************************************"
echo "* Migration logs are created in the logs folder.                              *"
echo "* End of migration to 6.2.2.3                                                 *"
echo "* Exiting 6.2.2.3 Migration Script                                            *"
echo "*******************************************************************************"

if [ -f $FILENAME ]; then
	rm $FILENAME
fi


