#!/bin/bash
#/********************************************************************
# (C) Copyright IBM Corp.  2005-2006
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
#********************************************************************/

OWNER=
OWNERPASS=
DIR=logs
RESPONSE=
LOC=
CON=
FILENAME=RPMVERSION.sh
VALID_COUNT=

echo " "
echo "********************************************************************"
echo "*                        RPM Migration 6.2.2.3                     *"
echo "*                                                                  *"
echo "* This migration runs on RPM version 6.2.1.2 and migrates your RPM *"
echo "* database to 6.2.2.3.                                             *"
echo "* Please make sure that you have a backup of your database         *"
echo "* before running the migration.                                    *"
echo "*                                                                  *"
echo "********************************************************************"
echo " "




RESPONSE=
while [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]
do
echo "Do you have a backup of your database?(y/n)"
read RESPONSE
if [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]; then
	echo "Invalid reply!"
fi
done



if [ "$RESPONSE" != "y" -a "$RESPONSE" != "Y" ]; then
	echo "************************************************************************"
	echo "* Migration was not applied.                                            "
	echo "* Reason: no backup.                                                    "
	echo "* Please try the migration after getting a backup of your database.     "
	echo "* Exiting RPM Migration 6.2.2.3.                                        "
	echo "************************************************************************"
	exit 0
fi



#check oracle_home

if [ "$ORACLE_HOME" != "" ]; then
	echo "**********************************************************************"
	echo " The script has verified that ORACLE_HOME is set to " $ORACLE_HOME
	echo "**********************************************************************"

	RESPONSE=
	while [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]
	do
		echo "Is this the right value?(y/n)"
		read RESPONSE
		if [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]; then
			echo "Invalid reply!"
		fi
	done

	if [ "$RESPONSE" != "y" -a "$RESPONSE" != "Y" ]; then
		ORACLE_HOME=
	fi
fi

while [ "$ORACLE_HOME" = "" ]
do
echo "Please enter ORACLE_HOME:"
read ORACLE_HOME
if [ "$ORACLE_HOME" = "" ]; then
	echo "no value for ORACLE_HOME"
fi
done

# check if sqlplus exists
if [ ! -x $ORACLE_HOME/bin/sqlplus ]; then
	echo
	echo "*********************************************************************"
	echo "* Migration was not applied."                                         
	echo "* Reason: sqlplus not found in " $ORACLE_HOME/bin " directory."               
	echo "* Exiting RPM Migration 6.2.2.3."                                   
	echo "*********************************************************************"
	echo
	exit 0

fi

# ADD ORACLE_HOME/BIN TO PATH
export PATH=$PATH:$ORACLE_HOME/bin



LOC=
while [ "$LOC" != "y" -a  "$LOC" != "Y" -a "$LOC" != "n" -a "$LOC" != "N" ]
do
        echo "Is your RPM database installed on this machine?(y/n)"
        read LOC
        if [ "$LOC" != "y" -a  "$LOC" != "Y" -a "$LOC" != "n" -a "$LOC" != "N" ]; then
                echo "Invalid reply!"
        fi
done

if [ "$LOC" = "y" -o "$LOC" = "Y" ]; then

	if [ "$ORACLE_SID" != "" ]; then
		echo "**********************************************************************"
		echo " The script has verified that ORACLE_SID is set to " $ORACLE_SID
		echo "**********************************************************************"

		RESPONSE=
		while [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]
		do
			echo "Is this the right value?(y/n)"
			read RESPONSE
			if [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]; then
				echo "Invalid reply!"
			fi
		done

		if [ "$RESPONSE" != "y" -a "$RESPONSE" != "Y" ]; then
			ORACLE_SID=
		fi
	fi

	while [ "$ORACLE_SID" = "" ]
	do
	echo "Please enter ORACLE_SID:"
	read ORACLE_SID
	if [ "$ORACLE_SID" = "" ]; then
		echo "no value for ORACLE_SID"
	fi
	done

else
ORACLE_SID=
	while [ "$ORACLE_SID" = "" ]
	do
	echo "Please enter TNS string:"
	read ORACLE_SID
	if [ "$ORACLE_SID" = "" ]; then
		echo "no value for TNS string"
	fi
	done
fi


export ORACLE_SID


while [ "$OWNER" = "" ]
do
echo "Please enter IBMRPM schema owner:"
read OWNER
if [ "$OWNER" = "" ]; then
	echo "no value for owner"
fi
done

while [ "$OWNERPASS" = "" ]
do
echo "Please enter IBMRPM schema owner password:"
read OWNERPASS
if [ "$OWNERPASS" = "" ]; then
	echo "no value for owner password"
fi
done


if [ "$LOC" = "y" -o  "$LOC" = "Y" ]; then
	CON=$OWNER/$OWNERPASS
elif [ "$LOC" = "n" -o "$LOC" = "N" ]; then
	CON=$OWNER/$OWNERPASS@$ORACLE_SID
fi

sqlplus -S /nolog @scripts/check/check_con.sql $CON

if [ "$?" != "0" ]; then
	echo "***********************************************************************"
	echo "* Migration was not applied.                                           "
	echo "* Reason: Unable to connect to RPM database.                           "
	echo "* Exiting RPM Migration 6.2.2.3.                                       "
	echo "***********************************************************************"
	exit 0
fi


if [ ! -d $DIR ]; then 
mkdir $DIR
chmod 775 $DIR
fi

if [ -f $FILENAME ]; then
	rm $FILENAME
fi


echo "******************************************************************************"
echo " Migration script has gathered all the necessary information to apply the     "
echo " migration on your database.After applying the migration, you cannot go back  "
echo " to your old version unless you use your database backup.                     "
echo "******************************************************************************"
RESPONSE=
while [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]
do
        echo "Are you sure you want to apply the migration to your database now?(y/n)"
        read RESPONSE
        if [ "$RESPONSE" != "y" -a  "$RESPONSE" != "Y" -a "$RESPONSE" != "n" -a "$RESPONSE" != "N" ]; then
                echo "Invalid reply!"
        fi
done

if [ "$RESPONSE" != "y" -a "$RESPONSE" != "Y" ]; then
	echo "**********************************************************************"
	echo "* Migration was not applied.                                          "
	echo "* Reason: Operation was cancelled by the user.                        "
	echo "* Exiting RPM Migration 6.2.2.3.                                      "
	echo "**********************************************************************"
	exit 0
fi






sqlplus -S $CON @scripts/check/recycle.sql >>$FILENAME
#if [ -f $FILENAME ]; then
#	rm $FILENAME
#fi


if [ -f $FILENAME ]; then
	rm $FILENAME
fi
#check number of valid objects


sqlplus -S $CON @scripts/step1.sql
sqlplus -S $CON @scripts/step2.sql

sqlplus -S $CON @scripts/check/recycle.sql >>$FILENAME
if [ -f $FILENAME ]; then
	rm $FILENAME
fi

# check version of database
sqlplus -S $CON @scripts/check/versionfunction.sql
sqlplus -S $CON @scripts/check/uversion.sql >>$FILENAME
chmod 777 $FILENAME
RPM_VERSION=
read RPM_VERSION <$FILENAME

if [ -f $FILENAME ]; then
	rm $FILENAME
fi

#check number of valid objects

sqlplus -S $CON @scripts/check/ucheck_valid.sql >>$FILENAME
chmod 777 $FILENAME
VALID_COUNT=
read VALID_COUNT <$FILENAME

if [ -f $FILENAME ]; then
	rm $FILENAME
fi

#check number of objects
sqlplus -S $CON @scripts/check/dropversion.sql
sqlplus -S $CON @scripts/check/check.sql >>$FILENAME
chmod 777 $FILENAME


echo "*******************************************************************************"
echo "*                          6.2.2.3 RPM Migration Report                       *"
echo "*******************************************************************************"
echo " "
echo " Current version of your RPM database is : $RPM_VERSION                       "
echo " "
echo " There are $VALID_COUNT invalid objects in your database."
echo " "
cat $FILENAME
echo " "
echo "*******************************************************************************"
echo " "
echo "************************************************************************"
echo " Migration logs are created in the logs folder." 
echo " End of migration 6.2.2.3."
echo " Exiting RPM Migration 6.2.2.3."
echo "************************************************************************"

if [ -f $FILENAME ]; then
	rm $FILENAME
fi


