/* ********************************************************************
# (C) Copyright IBM Corp.  2005-2006
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
#*********************************************************************/
/*
#Stored Procedure  :SP_SEARCH_2
#Short Description :Search and Assign a resource or profile to a element.
#Description       :Search or Search and Assign a resource or profile with effort to a WBS or CRI element.
				   :If search/assign a participant (without effort) all effort related parameters are not required.
				   :Search criteria is a sum of input parameters, witch tells how to filter out the result set.
				   :This function gets called from RPM client, Import and Level/Calculate.
RULE1: cannot assign more then once a resource to a element.
RULE2: cannot assign a resource to a project if the resource is already assigned to a task whitin the project.
RULE3: cannot assign to a task from project reserve more effort then remaining effort at the project.
RULE4: if bitflag = 9 then assignment without effort, otherwise assignment with effort.
RULE5: if bitflag between 1 and 8 the assignment is contoured: contour > 0 and work > 0
RULE6: if search by name then partially ignore the search criteria: org_id, geo_id, pool_id, work_loc, and_roles, and_skills, shw_roles, shw_skills
RULE7: if effort = 0 and bitflag < 9 then both start  finish dates are required
RULE8: if assign units <> 100%, then bitflag < 9 and effort > 0 and both start  finish dates are required
RULE9: cannot assign a resource if is not active, effective date is in the future or discontinue date is in the past
#Table Name        :
#Parameters        :
 $$bitflag  = 0 - ASP ---------------------------------------------------------------------------------------------
            = 1 - Daily         -- contour3
            = 2 - Weekly        -- contour3{, contur1}, {amount falg}
            = 3 - Monthly(C)    -- contour3{, contur2}
            = 4 - Monthly(B)    -- contour3{, contur2}
            = 5 - Monthly(A)    -- contour3{, contur2 | contour2  countour1}
            = 6 - Yearly(C)     -- contour2, contur4
            = 7 - Yearly(B)     -- contour2, contur4, contur1(only one day)
            = 8 - Yearly(A)     -- contour2, contur4, contur1(many days)
            = 9 - Participant
 $$contour (contour structure) ------------------------------------------------------------------------------------
  contur1:  DAY:    bits 0-6    0 = Su, 1 = Mo, 2 = Tu, 3 = We, 4 = Th, 5 = Fr, 6 = Sa,
  contur2:  WEEK:   bits 7-11   A) 7 = week1, 8 = week2, 8 = week3, 9 = week4
                                B) 1-First/2-Second/3-Third/4-Fourth/5-Last
                                C) The Day 1 to 31
  contour3:     EVRY:   bits 12-16  EVRY 1 to 31 day / week / month
  contour4:     MONTH:  bits 17-28  17 = Jan, 18 = Feb, ... 28 = Dec
  2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
  8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
                                                S F T W T M S
                                      w1 to w4  A(7 days from the 1st)
                                      5 4 3 2 1 B(Last, Fourth, Third, Second, First)
                                      31 .... 1 C(The Day 6)
                            31 ........ 1 (Day)
                            31 ........ 1 (week)
                            12 ........ 1 (month)
  D N O S A J J M A M F J (Month)
  Exemple:
  2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1 
  9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 
                                      5-4-3-2-1               B) 1-First/2-Second/3-Third/4-Fourth/5-Last
  X D N O S A J J M A M F J --EVERY-- -THE-DAY- S F T W T M S C) The Day 1 to 31
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 = 4096      1 (every day) 	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 = 8192      1 (every 2nd day) 
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 = 12288     1 (every 3rd day) 
  1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 = 536875014 2 (Monday, Tuesday, every week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 = 4102      2 (Monday, Tuesday, every week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 1 1 0 = 8198      2 (Monday, Monday, every 2nd week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 = 4864      3 (6th day of every month)
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 1 0 = 8322      4 (1st Monday of every 2nd month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 = 4224      5 (week1 of every month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 = 4480      5 (week1, week2 of every month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 1 0 0 0 0 0 0 0 = 8576      5 (week1, week2 of every 2nd month)
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0 1 1 0 = 8454      5 (Monday, Tuesday, week2 every 2nd month)	
  1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0 1 1 0 = 536879366 5 (Monday, Tuesday, week2 every 2nd month)	
  0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 = 301990656 6 (6th day of month 9, 12)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 1 0 = 301990146 7 (1st Monday of month 1, 2)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1 0 0 0 0 0 1 0 0 = 4356      7 (2nd Tuesday, every month)	
  0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 1 1 0 = 301990534 8 (Monday, Tuesday; week1, week3 of month 9, 12)	
  1 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 1 1 0 = 838861446 8 (Monday, Tuesday; week1, week3 of month 9, 12)	
 $$consider_planned_sched ------------------------------------------------------------------------------------------
  CONSIDER                                              inner current project   outer current project   all projects
  scheduled                                                         1                   2                   3
  scheduled  planned                                               4                   5                   6
  NONE(consider all available time)                                 7
  scheduled outer current project				                                        13                  14
  scheduled  planned outer current project				                                15                  16
  scheduled outer current project  planned all projects            20
  scheduled outer current project  planned inner current project   21
  scheduled all projects    planned outer current project          22
  planned inner current project                                     24
  search from project assignments		= 10  pool_id   = resource_id
  search create new profile				= 12  and_roles = the first role_id is used to create a new profile
  duplicate profile						= 12  pool_id   = profile_id
  assign pool  org as participant to a template folder, all template views
  assign pool	= SC_SRCH_POOL (31)  pool_id	= pool_id
  assign org	= SC_SRCH_ORG  (32)  org_id	= org_id
  Note: bits 30 - 31 (in addition to above values): Consider All Scop Element Exceptions = 1 consider, 0 don't consider
  $$eunit, applies to effort
		= 0 MINUTE (default), 
		= 1 h, 
		= 2 d, 
		= 3 w
  $$unit, applies to work
		= 0 h/d,
		= 3 h/w, 
		= 4 h/m, 
		= 1 d/w, 
		= 2 d/m, 
		= 5 w/m
		= 100 then work = percent units
#Returns           :Result Set of resource(s), Best Start date, Best Finish date and daly contour (5*480,2*0,3*400,...) 
				   :For search the number of rows depends on search criteria and is limited by max_rows parameter.
				   :For search/assign is always only one row, the resource whith has been assigned
#Errors            :The errors are returned only in search/assign
				   : TASK_ASSIGNMENT_ERROR (200062) - many reasons the assignment failed.
				   : CHILD_TASK_ASSIGNMENT_ALREADY_EXISTS (20083) - violation of RULE2
				   : CANNOT_ASSIGN_FROM_PROJECT_AFFECTED (20085) - violation of RULE3
				   : RESOURCE_NOT_ACTIVE (200019) - violation of RULE9
				   : F_DATE_EARLIER_THAN_S_DATE - finish date is earlier then start date
				   : 200220 - violation of RULE7
*/
Prompt == FUNCTION SP_SEARCH_2 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
2f7
2 :e:
1FUNCTION:
1SP_SEARCH_2:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1FNAME:
1COST001:
1ORG_ID001:
1GEO_ID001:
1POOL_ID001:
1WORK_LOCATION001:
1AND_ROLES:
1AND_SKILLS:
1SHW_ROLES:
1SHW_SKILLS:
1MAX_ROWS:
1P_UPDATE:
1WORK_TYPE:
1P_TYPE:
1LAST_ID:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_WBS_ID:
132:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RS_ID:
1H_UNIQUEID:
1H_REC_USER:
1H_FNAME:
1255:
1H_COST:
110:
1H_AND_ROLES:
18000:
1H_AND_SKILLS:
1H_SHW_ROLES:
1H_SHW_SKILLS:
1H_AND_ROLE:
1H_AND_SKILL:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_SOURCE_IDS:
1H_TARGET_IDS:
1H_RES_ID:
1H_LAST_ID:
1H_RANK:
1200:
1H_DAYOFYEAR:
1DATE:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_START_D:
1H_RES_TYPE:
11:
1H_ASSIGN_ID:
1H_ROLE_ID:
1H_SKILL_ID:
1H_FULL_NAME:
1H_REC_STATUS:
1H_BITFLAG:
10:
1H_EXISTS:
1H_TYPE:
1H_COUNT:
1H_UPDATE:
1H_WORK_TYPE:
1H_WORK_LOCATION:
1H_CRI:
1H_MAX_ROWS:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_DURATION:
1H_BIT_MINUTES:
1H_NUMBER:
1H_PRIORITY:
1H_DAYS:
1H_RES_COST:
1NUMBER:
10.00:
1H_RATE_ECHANGE:
1H_TOTAL:
1H_POOL_TYPE:
1H_CURRENCY_ID:
1H_JULIAN_DAY:
1H_J_EFECTIVE_DATE:
1H_J_DISCONTI_DATE:
1H_WEEK:
1H_ACTIVE:
1H_TASK_TYPE:
1H_SCHED_WORK:
1H_PARTICIPANT:
1STMT:
17999:
1STWHERE:
12999:
1H_TEMP_STMT:
1H_TABLE_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_PROFILE_ID:
1H_RESOURCE_ID:
1H_CRI_SECURITY_ID:
1H_CHAR:
1H_TEMP_VAR:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1I:
1II:
1I_ROW:
1I_RETURN:
1ISF:
1TOKEN:
1I_NOSKILL:
1NUMITEMS:
1BCREATEPROFILE:
1LEN:
1K:
1NLEN:
1NLEN001:
1NLEN002:
1C12:
1CURSOR:
1C42:
1PROJECT_ASSIGNMENT_ID:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1TASK_ID:
1RESOURCE_ID:
1SELECT PROJECT_ASSIGNMENT_ID:n         FROM TASK_ASSIGNMENTS:n         WHERE +
1PROJECT_ID = h_project_id:n         AND TASK_ID = h_project_id:n         AND +
1RESOURCE_ID = h_res_id:
1CU42:
1RS_ID:
1RES_ID:
1RTRIM:
1ROLE_ID:
1COALESCE:
1ROLE_NAME:
1SKILL_ID:
1SKILL_NAME:
1SHOW_ROLE:
1SHOW_SKILL:
1PMO_TMP_SEARCH:
1SELECT:n         RS_ID:n         , RES_ID:n         , RTRIM(ROLE_ID):n       +
1  , COALESCE(ROLE_NAME , ''):n         , RTRIM(SKILL_ID):n         , COALESCE+
1(SKILL_NAME , ''):n         , COALESCE(SHOW_ROLE , ''):n         , COALESCE(S+
1HOW_SKILL , ''):n         FROM PMO_TMP_SEARCH:n         ORDER BY RES_ID:
1C775C0:
1C775E1:
1C775E0:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_2(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1197:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_2(198) :: cplan.sql(343) :: :
1PMO_CNST:
1!=:
1SC_SRCH_PARTICIPANT:
1IS NULL:
18:
1240:
1      RETURN_INVALID:: SP_SEARCH_2(241) :: cplan.sql(386) :: :
1 :
1STATE:: :
1ELEMENT_ID_REQUIRED:
1243:
1                EXIT:: SP_SEARCH_2(244) :: cplan.sql(389) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_SRCH_FROM_PROJECT:
1=:
1SC_SRCH_PROFILE:
1252:
1      RETURN_INVALID:: SP_SEARCH_2(253) :: cplan.sql(398) :: :
1INVALID_PARAMS:
1                EXIT:: SP_SEARCH_2(256) :: cplan.sql(401) :: :
1ELSIF:
1260:
1      RETURN_INVALID:: SP_SEARCH_2(261) :: cplan.sql(406) :: :
1263:
1                EXIT:: SP_SEARCH_2(264) :: cplan.sql(409) :: :
15:
1271:
1      RETURN_INVALID:: SP_SEARCH_2(272) :: cplan.sql(417) :: :
1274:
1                EXIT:: SP_SEARCH_2(275) :: cplan.sql(420) :: :
1265:
1IS NOT NULL:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1300:
1           EXCEPTION:: SP_SEARCH_2(301) :: cplan.sql(446) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1<:
1307:
1      RETURN_INVALID:: SP_SEARCH_2(308) :: cplan.sql(453) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1310:
1                EXIT:: SP_SEARCH_2(311) :: cplan.sql(456) :: :
1SELECT SYSTIMESTAMP INTO h_start_date FROM DUAL:
1328:
1           EXCEPTION:: SP_SEARCH_2(329) :: cplan.sql(474) :: :
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1SC_SRCH_POOL:
12:
1SC_SRCH_ORG:
13:
1>:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1372:
1           EXCEPTION:: SP_SEARCH_2(373) :: cplan.sql(518) :: :
1REC_STATUS:
1TMT_WBS:
1ELEMENT_ID:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1390:
1           EXCEPTION:: SP_SEARCH_2(391) :: cplan.sql(536) :: :
1STRCMP:
1L:
1397:
1        RETURN_ERROR:: SP_SEARCH_2(398) :: cplan.sql(543) :: :
1LEV_LOCKED_BY_COPY:
1 ID:: :
1400:
1                EXIT:: SP_SEARCH_2(401) :: cplan.sql(546) :: :
1PMO_RETURN_ERROR_SP:
1GETTABLE:
1GETASSNTYPE:
1411:
1      RETURN_INVALID:: SP_SEARCH_2(412) :: cplan.sql(557) :: :
1414:
1                EXIT:: SP_SEARCH_2(415) :: cplan.sql(560) :: :
1SC_TABLE_WBS:
1427:
1      RETURN_INVALID:: SP_SEARCH_2(428) :: cplan.sql(573) :: :
1430:
1                EXIT:: SP_SEARCH_2(431) :: cplan.sql(576) :: :
1ASSIGNRESOURCE:
1RECORD_ALREADY_ASSIGNED:
1449:
1        RETURN_ERROR:: SP_SEARCH_2(450) :: cplan.sql(595) :: :
1452:
1                EXIT:: SP_SEARCH_2(453) :: cplan.sql(598) :: :
1459:
1        RETURN_ERROR:: SP_SEARCH_2(460) :: cplan.sql(605) :: :
1462:
1                EXIT:: SP_SEARCH_2(463) :: cplan.sql(608) :: :
1ISPROJECTTYPE:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1SELECT:n               PROJECT_ID:n               , COALESCE(MINUTE_PER_DAY, +
1480):n               , COALESCE(MINUTE_PER_WEEK, 2400):n               , PRIO+
1RITY:n               INTO:n               h_project_id:n               , h_pe+
1r_day:n               , h_per_week:n               , h_priority:n            +
1   FROM TMT_WBS:n               WHERE ELEMENT_ID = h_task_id:
1489:
1           EXCEPTION:: SP_SEARCH_2(490) :: cplan.sql(635) :: :
1B:
1TASK_TYPE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1A:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1SELECT:n               B.TASK_TYPE:n               , B.UNRESOLVED_START:n    +
1           , B.UNRESOLVED_FINISH:n               , B.PROJECT_ID:n            +
1   , COALESCE(A.MINUTE_PER_DAY, 480):n               , COALESCE(A.MINUTE_PER_+
1WEEK, 2400):n               , A.PRIORITY:n               , B.PLANNED_EFFORT ++
1 B.SCHED_EFFORT:n               INTO:n               h_task_type:n           +
1    , h_task_start_DT:n               , h_task_finish_DT:n               , h_+
1project_id:n               , h_per_day:n               , h_per_week:n        +
1       , h_priority:n               , h_sched_work:n               FROM TMT_W+
1BS A, TMT_WBS B:n               WHERE B.ELEMENT_ID = h_task_id:n             +
1  AND A.ELEMENT_ID = B.PROJECT_ID:
1524:
1           EXCEPTION:: SP_SEARCH_2(525) :: cplan.sql(670) :: :
1532:
1        RETURN_ERROR:: SP_SEARCH_2(533) :: cplan.sql(678) :: :
1RECORD_NOT_FOUND:
1535:
1                EXIT:: SP_SEARCH_2(536) :: cplan.sql(681) :: :
1SC_TABLE_CRI:
1TYPE_ID:
1WBS_ID:
1TMT_CRI:
1SELECT:n            PROJECT_ID:n            , TYPE_ID:n            , WBS_ID:n+
1            INTO:n            h_project_id:n            , h_type:n           +
1 , h_wbs_id:n            FROM TMT_CRI:n            WHERE ELEMENT_ID = h_task_+
1id:
1559:
1           EXCEPTION:: SP_SEARCH_2(560) :: cplan.sql(705) :: :
1566:
1        RETURN_ERROR:: SP_SEARCH_2(567) :: cplan.sql(712) :: :
1569:
1                EXIT:: SP_SEARCH_2(570) :: cplan.sql(715) :: :
1START_DT:
1TO_TIMESTAMP:
1SELECT:n            CASE:n            WHEN START_DT > h_start_DT:n           +
1 THEN START_DT:n            ELSE TO_TIMESTAMP(h_start_DT):n            END:n +
1           , COALESCE(MINUTE_PER_DAY, 480):n            , COALESCE(MINUTE_PER+
1_WEEK, 2400):n            , PRIORITY:n            INTO:n            h_start_D+
1T:n            , h_per_day:n            , h_per_week:n            , h_priorit+
1y:n            FROM TMT_WBS:n            WHERE PROJECT_ID = h_project_id:n   +
1         AND ELEMENT_ID = h_project_id:
1602:
1           EXCEPTION:: SP_SEARCH_2(603) :: cplan.sql(748) :: :
1609:
1        RETURN_ERROR:: SP_SEARCH_2(610) :: cplan.sql(755) :: :
1612:
1                EXIT:: SP_SEARCH_2(613) :: cplan.sql(758) :: :
1FC_MIRROR_TYPE:
1627:
1        RETURN_ERROR:: SP_SEARCH_2(628) :: cplan.sql(773) :: :
1630:
1                EXIT:: SP_SEARCH_2(631) :: cplan.sql(776) :: :
1NICK_NAME:
1JULIAN_DAY:
1ACTIVE:
1EFFECTIVE_DATE:
1DISCONTINUE_DATE:
1RESOURCES:
1SELECT:n            NICK_NAME:n            , PMO_ORASTD.JULIAN_DAY(h_start_DT+
1):n            , ACTIVE:n            , EFFECTIVE_DATE:n            , COALESCE+
1(PMO_ORASTD.JULIAN_DAY(EFFECTIVE_DATE) ,0):n            , COALESCE(PMO_ORASTD+
1.JULIAN_DAY(DISCONTINUE_DATE) ,0):n            INTO:n            h_full_name+
1:n            , h_julian_day:n            , h_active:n            , h_start_D+
1:n            , h_j_efective_date:n            , h_j_disconti_date:n         +
1   FROM RESOURCES:n            WHERE RESOURCE_ID = h_res_id:
1663:
1           EXCEPTION:: SP_SEARCH_2(664) :: cplan.sql(809) :: :
1SC_SQL_NO_DATA:
1670:
1        RETURN_ERROR:: SP_SEARCH_2(671) :: cplan.sql(816) :: :
1673:
1                EXIT:: SP_SEARCH_2(674) :: cplan.sql(819) :: :
1680:
1        RETURN_ERROR:: SP_SEARCH_2(681) :: cplan.sql(826) :: :
1RESOURCE_NOT_ACTIVE:
1683:
1                EXIT:: SP_SEARCH_2(684) :: cplan.sql(829) :: :
1DB2TIMESTAMP:
1TO_DATE:
1TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_D, 1, 10)), PMO_ORASTD.+
1TIME('00.00.00')) INTO h_start_DT:n                  FROM DUAL:
1701:
1           EXCEPTION:: SP_SEARCH_2(702) :: cplan.sql(847) :: :
1721:
1        RETURN_ERROR:: SP_SEARCH_2(722) :: cplan.sql(867) :: :
1CANNOT_ASSIGN_COMPETENCY:
1724:
1                EXIT:: SP_SEARCH_2(725) :: cplan.sql(870) :: :
1SELECT:n            PRIORITY:n            , COALESCE(MINUTE_PER_DAY, 480):n  +
1          , COALESCE(MINUTE_PER_WEEK, 2400):n            INTO:n            h_+
1priority:n            , h_per_day:n            , h_per_week:n            FROM+
1 TMT_WBS:n            WHERE ELEMENT_ID = h_project_id:
1751:
1           EXCEPTION:: SP_SEARCH_2(752) :: cplan.sql(897) :: :
1TMT_POOLS:
1SELECT:n               480:n               , 2400:n               INTO:n     +
1          h_per_day:n               , h_per_week:n               FROM TMT_POO+
1LS WHERE ELEMENT_ID = h_project_id:
1775:
1           EXCEPTION:: SP_SEARCH_2(776) :: cplan.sql(921) :: :
1782:
1        RETURN_ERROR:: SP_SEARCH_2(783) :: cplan.sql(928) :: :
1785:
1                EXIT:: SP_SEARCH_2(786) :: cplan.sql(931) :: :
1100:
11899-12-31 00::00::00:
1:
1FC_CALC_DURATION:
1822:
1      RETURN_INVALID:: SP_SEARCH_2(823) :: cplan.sql(968) :: :
1825:
1                EXIT:: SP_SEARCH_2(826) :: cplan.sql(971) :: :
1830:
1        RETURN_ERROR:: SP_SEARCH_2(831) :: cplan.sql(976) :: :
1833:
1                EXIT:: SP_SEARCH_2(834) :: cplan.sql(979) :: :
14:
1SYS_GUID:
1PROFILES:
1PROFILE_ID:
1SELECT REC_STATUS INTO h_rec_status:n            FROM PROFILES:n            W+
1HERE PROFILE_ID = h_res_id:
1890:
1           EXCEPTION:: SP_SEARCH_2(891) :: cplan.sql(1036) :: :
1RES_ASSIGNMENT_ID:
1RESOURCE_ASSIGNMENTS:
1RESOURCE_TYPE:
1PARTICIPANT:
1SC_TEAMMEMBER:
1SELECT:n                  RES_ASSIGNMENT_ID:n                  INTO:n        +
1          h_uniqueID:n                  FROM RESOURCE_ASSIGNMENTS:n          +
1        WHERE ELEMENT_ID = h_task_id:n                  AND RESOURCE_ID = h_r+
1es_id:n                  AND RESOURCE_TYPE = '1':n                  AND PARTI+
1CIPANT = pmo_cnst.SC_TEAMMEMBER:
1915:
1           EXCEPTION:: SP_SEARCH_2(916) :: cplan.sql(1061) :: :
1MAX:
1PROF_NUMBER:
1SELECT:n            COALESCE(MAX(PROF_NUMBER),0)+1:n            INTO:n       +
1     h_number:n            FROM PROFILES:n            WHERE PROJECT_ID=h_proj+
1ect_id:n            AND ROLE_ID=h_role_id:
1947:
1           EXCEPTION:: SP_SEARCH_2(948) :: cplan.sql(1093) :: :
1STRINGCONCAT:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1PARENT_ID:
1SELECT:n            PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORAST+
1D.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEM+
1ENT_NAME):n            , ', '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(+
1h_number))), ')'):n            INTO h_full_name:n            FROM TMT_COMPETE+
1NCIES TC, TMT_COMPETENCIES TCP:n            WHERE TC.ELEMENT_ID = h_role_id:n+
1            AND TCP.ELEMENT_ID = TC.PARENT_ID:
1968:
1           EXCEPTION:: SP_SEARCH_2(969) :: cplan.sql(1114) :: :
1975:
1        RETURN_ERROR:: SP_SEARCH_2(976) :: cplan.sql(1121) :: :
1978:
1                EXIT:: SP_SEARCH_2(979) :: cplan.sql(1124) :: :
1U:
1D:
1PROFILE_NAME:
1POOL_ID:
1GEO_ID:
1ORG_ID:
1INSERT INTO PROFILES:n            (:n            PROFILE_ID:n            , PR+
1OJECT_ID:n            , ROLE_ID:n            , PROF_NUMBER:n            , PRO+
1FILE_NAME:n            , REC_STATUS:n            , POOL_ID:n            , GEO+
1_ID:n            , ORG_ID:n            ):n            VALUES:n            (:n+
1            h_res_id:n            , h_project_id:n            , h_role_id:n  +
1          , h_number:n            , h_full_name:n            , h_char:n      +
1      , pool_id001:n            , geo_id001:n            , org_id001:n       +
1     ):
1FOUND:
11026:
1           EXCEPTION:: SP_SEARCH_2(1027) :: cplan.sql(1172) :: :
1UPDATE PROFILES SET REC_STATUS = 'U',:n            POOL_ID = pool_id001,:n   +
1         GEO_ID  = geo_id001,:n            ORG_ID  = org_id001:n            W+
1HERE PROFILE_ID = h_res_id:
11051:
1           EXCEPTION:: SP_SEARCH_2(1052) :: cplan.sql(1197) :: :
1RESOURCE_ASSIGN_SKILLS:
1DELETE FROM RESOURCE_ASSIGN_SKILLS:n         WHERE RES_ASSIGNMENT_ID IN (:n  +
1       SELECT PROFILE_ID:n         FROM PROFILES:n         WHERE PROJECT_ID =+
1 h_project_id:n         AND REC_STATUS='D':n         AND PROFILE_ID <> h_res_+
1id):
11079:
1           EXCEPTION:: SP_SEARCH_2(1080) :: cplan.sql(1225) :: :
1RESOURCE_ASSIGN_ROLES:
1DELETE FROM RESOURCE_ASSIGN_ROLES:n         WHERE RES_ASSIGNMENT_ID IN (:n   +
1      SELECT PROFILE_ID:n         FROM PROFILES:n         WHERE PROJECT_ID = +
1h_project_id:n         AND REC_STATUS='D':n         AND PROFILE_ID <> h_res_i+
1d):
11104:
1           EXCEPTION:: SP_SEARCH_2(1105) :: cplan.sql(1250) :: :
1DELETE FROM PROFILES:n         WHERE PROJECT_ID = h_project_id:n         AND +
1REC_STATUS='D':n         AND PROFILE_ID <> h_res_id:
11126:
1           EXCEPTION:: SP_SEARCH_2(1127) :: cplan.sql(1272) :: :
1FC_DECLARE_PMO_TMP_SEARCH:
1SC_MAX_ROWS:
1SELECT ':
1' AS RESOURCE_ID :
1FROM TMT_COMPETENCIES r :
1WHERE r.TYPE_ID=73 :
1      AND r.ELEMENT_ID = ':
1SELECT ra.RESOURCE_ID :
1FROM RESOURCE_ASSIGNMENTS ra :
1JOIN TASK_ASSIGNMENTS ta ON ra.ELEMENT_ID=':
1' :
1AND ra.RESOURCE_ID=':
1AND ra.RES_ASSIGNMENT_ID=ta.RES_ASSIGNMENT_ID :
1SELECT r.RESOURCE_ID :
1FROM RESOURCES r :
1WHERE r.CALENDAR_ID IS NOT NuLL :
1        AND r.RESOURCE_ID = ':
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN_0007:
1DELETE FROM PMO_TMP_CPLN_007a:
1PMO_TMP_CPLN_007A:
1RANK:
1PUBLIC_FLAG:
1P:
1JOIN:
1RA:
1ELEMENT_TYPE:
1INSERT INTO PMO_TMP_CPLN_007a:n               SELECT ELEMENT_ID, RANK:n      +
1         FROM TMT_POOLS:n               WHERE PUBLIC_FLAG = '1':n            +
1   UNION ALL:n               ---- All pools to which the resource is assigned+
1:n               SELECT P.ELEMENT_ID, P.RANK:n               FROM TMT_POOLS P+
1:n               JOIN RESOURCE_ASSIGNMENTS RA ON:n               P.ELEMENT_ID+
1 = RA.ELEMENT_ID:n               AND RA.ELEMENT_TYPE = 11:n               AND+
1 RA.RESOURCE_ID = h_rec_user:
11253:
1           EXCEPTION:: SP_SEARCH_2(1254) :: cplan.sql(1399) :: :
1PMO_TMP_CPLN_0007:
1M:
1LENGTH:
1INSERT INTO PMO_TMP_CPLN_0007:n               SELECT M.RANK:n               F+
1ROM PMO_TMP_CPLN_007a M:n               WHERE NOT EXISTS (:n               SE+
1LECT A.ELEMENT_ID:n               FROM PMO_TMP_CPLN_007a A:n               WH+
1ERE A.RANK < M.RANK:n               AND SUBSTR(M.RANK, 1, LENGTH(A.RANK)) = A+
1.RANK):
11281:
1           EXCEPTION:: SP_SEARCH_2(1282) :: cplan.sql(1427) :: :
132767:
165535:
1-:
165536:
1WHILE:
1LOOP:
1ASCII:
137:
195:
1EXIT:
11308:
1      RETURN_INVALID:: SP_SEARCH_2(1309) :: cplan.sql(1454) :: :
11311:
1                EXIT:: SP_SEARCH_2(1312) :: cplan.sql(1457) :: :
1REPLACE:
1SELECT REPLACE(h_fname,'''',''''''):n            INTO h_fname:n            FR+
1OM DUAL:
11328:
1           EXCEPTION:: SP_SEARCH_2(1329) :: cplan.sql(1474) :: :
1SELECT p.PROFILE_ID AS RESOURCE_ID FROM PROFILES p JOIN TMT_COMPETENCIES r ON+
1 p.ROLE_ID = r.ELEMENT_ID:
1 WHERE p.PROFILE_ID=':
1SELECT r.RESOURCE_ID FROM RESOURCES r JOIN RESOURCE_ASSIGNMENTS ra ON BITAND(+
1ra.PARTICIPANT,4096)>0 AND ra.ELEMENT_ID=':
1' AND ra.RESOURCE_ID=r.RESOURCE_ID:
1 WHERE 0=0 :
1SELECT DISTINCT r.RESOURCE_ID FROM RESOURCES r:
1 AND r.RESOURCE_ID > ':
1 AND r.CALENDAR_ID IS NOT NuLL :
1AND UPPER(r.FULL_NAME) like UPPER(':
1%'):
1SELECT r.RESOURCE_ID FROM RESOURCES r:
1SELECT DISTINCT r.RESOURCE_ID :
1FROM TMT_POOLS TP, PMO_TMP_CPLN_0007 MP, RESOURCES r:
1AND TP.ELEMENT_ID=R.RESOURCE_ID :
1  AND (MP.RANK >= SUBSTR(TP.RANK, 1, 8) :
1        AND MP.RANK <= TP.RANK :
1        AND length(MP.RANK) <= length(TP.RANK) :
1        AND substr(TP.RANK, 1, length(MP.RANK)) = MP.RANK) :
1  AND r.CALENDAR_ID IS NOT NuLL :
1  AND UPPER(r.FULL_NAME) LIKE UPPER(':
1SELECT RANK INTO h_rank:n               FROM TMT_POOLS:n               WHERE +
1ELEMENT_ID = pool_id001:
11413:
1           EXCEPTION:: SP_SEARCH_2(1414) :: cplan.sql(1559) :: :
1,TMT_POOLS p:
1 AND r.RESOURCE_ID = p.ELEMENT_ID :
1AND p.RANK LIKE ':
1%' :
11427:
1        RETURN_ERROR:: SP_SEARCH_2(1428) :: cplan.sql(1573) :: :
11430:
1                EXIT:: SP_SEARCH_2(1431) :: cplan.sql(1576) :: :
1TMT_ORGANIZATIONS:
1SELECT RANK INTO h_rank:n               FROM TMT_ORGANIZATIONS:n             +
1  WHERE ELEMENT_ID = org_id001:
11449:
1           EXCEPTION:: SP_SEARCH_2(1450) :: cplan.sql(1595) :: :
1,TMT_ORGANIZATIONS o:
1 AND r.RESOURCE_ID=o.ELEMENT_ID :
1AND o.RANK LIKE ':
11460:
1        RETURN_ERROR:: SP_SEARCH_2(1461) :: cplan.sql(1606) :: :
11463:
1                EXIT:: SP_SEARCH_2(1464) :: cplan.sql(1609) :: :
1TMT_GEOGRAPHIES:
1SELECT RANK INTO h_rank:n               FROM TMT_GEOGRAPHIES:n               +
1WHERE ELEMENT_ID = geo_id001:
11482:
1           EXCEPTION:: SP_SEARCH_2(1483) :: cplan.sql(1628) :: :
1,TMT_GEOGRAPHIES g:
1 AND r.RESOURCE_ID=g.ELEMENT_ID :
1AND g.RANK LIKE ':
11493:
1        RETURN_ERROR:: SP_SEARCH_2(1494) :: cplan.sql(1639) :: :
11496:
1                EXIT:: SP_SEARCH_2(1497) :: cplan.sql(1642) :: :
1 AND r.WORK_LOCATION=:
1PMO_STPU:
1STRNPCPY:
1SELECT RANK INTO h_rank:n               FROM TMT_COMPETENCIES:n              +
1 WHERE ELEMENT_ID = h_role_id:
11528:
1           EXCEPTION:: SP_SEARCH_2(1529) :: cplan.sql(1674) :: :
11535:
1        RETURN_ERROR:: SP_SEARCH_2(1536) :: cplan.sql(1681) :: :
11538:
1                EXIT:: SP_SEARCH_2(1539) :: cplan.sql(1684) :: :
1 AND EXISTS :
1(SELECT t1.ELEMENT_ID :
1  FROM TMT_COMPETENCIES t1:
1  WHERE t1.RANK LIKE ':
1%':
1AND r.ELEMENT_ID=t1.ELEMENT_ID) :
1AND r.RESOURCE_ID=t1.RESOURCE_ID) :
11583:
1           EXCEPTION:: SP_SEARCH_2(1584) :: cplan.sql(1729) :: :
11590:
1        RETURN_ERROR:: SP_SEARCH_2(1591) :: cplan.sql(1736) :: :
11593:
1                EXIT:: SP_SEARCH_2(1594) :: cplan.sql(1739) :: :
1     AND r.RESOURCE_ID=t1.RESOURCE_ID) :
1 ORDER BY RESOURCE_ID  :
1OPEN:
1CLOSE:
11657:
1           EXCEPTION:: SP_SEARCH_2(1658) :: cplan.sql(1803) :: :
1CONTINUE0000:
11677:
1           EXCEPTION:: SP_SEARCH_2(1678) :: cplan.sql(1823) :: :
1COUNT:
1TSK_ASSIGNMENT_ID:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_temp_var :n                  FROM TASK+
1_ASSIGNMENTS:n                  WHERE PROJECT_ID = h_project_id:n            +
1      AND RESOURCE_ID = h_res_id:n                  AND RESOURCE_TYPE = '0':
11708:
1           EXCEPTION:: SP_SEARCH_2(1709) :: cplan.sql(1854) :: :
11724:
1           EXCEPTION:: SP_SEARCH_2(1725) :: cplan.sql(1870) :: :
11730:
1        RETURN_ERROR:: SP_SEARCH_2(1731) :: cplan.sql(1876) :: :
1CHILD_TASK_ASSIGNMENT_ALREADY_:
11733:
1                EXIT:: SP_SEARCH_2(1734) :: cplan.sql(1879) :: :
1FC_SEARCH_2:
11759:
1           EXCEPTION:: SP_SEARCH_2(1760) :: cplan.sql(1905) :: :
1DB_OFFSET:
1TASK_ASSIGNMENT_ERROR:
11769:
1        RETURN_ERROR:: SP_SEARCH_2(1770) :: cplan.sql(1915) :: :
11772:
1                EXIT:: SP_SEARCH_2(1773) :: cplan.sql(1918) :: :
1UPDATE PROFILES SET REC_STATUS='U' WHERE PROFILE_ID = h_res_id AND REC_STATUS+
1='D':
11790:
1           EXCEPTION:: SP_SEARCH_2(1791) :: cplan.sql(1936) :: :
11834:
1           EXCEPTION:: SP_SEARCH_2(1835) :: cplan.sql(1980) :: :
1ASSIGN_STRING_TOLONG:
11843:
1        RETURN_ERROR:: SP_SEARCH_2(1844) :: cplan.sql(1989) :: :
11846:
1                EXIT:: SP_SEARCH_2(1847) :: cplan.sql(1992) :: :
1NOTNULL:
1UPDATE PMO_TMP_SEARCH SET:n                  ROLE_ID = h_source_ids:n        +
1          , ROLE_NAME = h_and_roles:n                  , SKILL_ID = h_target_+
1ids:n                  , SKILL_NAME = h_and_skills:n                  , SHOW_+
1ROLE = h_shw_roles:n                  , SHOW_SKILL = h_shw_skills:n          +
1        WHERE RS_ID = h_last_id:
11914:
1           EXCEPTION:: SP_SEARCH_2(1915) :: cplan.sql(2060) :: :
1UPDATE PMO_TMP_SEARCH SET:n               ROLE_ID = NuLL:n               , RO+
1LE_NAME = NuLL:n               , SKILL_ID = NuLL:n               , SKILL_NAME+
1 = NuLL:n               , SHOW_ROLE = NuLL:n               , SHOW_SKILL = NuL+
1L:n               WHERE RS_ID = h_last_id:
11957:
1           EXCEPTION:: SP_SEARCH_2(1958) :: cplan.sql(2103) :: :
1,:
12018:
1           EXCEPTION:: SP_SEARCH_2(2019) :: cplan.sql(2164) :: :
1UPDATE PMO_TMP_SEARCH SET:n            ROLE_ID = h_source_ids:n            , +
1ROLE_NAME = h_and_roles:n            , SKILL_ID = h_target_ids:n            ,+
1 SKILL_NAME = h_and_skills:n            , SHOW_ROLE = h_shw_roles:n          +
1  , SHOW_SKILL = h_shw_skills:n            WHERE RS_ID = h_last_id:
12046:
1           EXCEPTION:: SP_SEARCH_2(2047) :: cplan.sql(2192) :: :
1SUM:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1DAY_YEAR:
1SELECT COALESCE(SUM(AVAILABLE_MIN),0) INTO h_effort:n            FROM CALENDA+
1R_DAY_OF_YEAR:n            WHERE ELEMENT_ID=h_project_id:n            AND DAY+
1_YEAR BETWEEN TO_DATE(SubStr(h_start_DT, 1, 10)) AND TO_DATE(SubStr(h_finish_+
1DT, 1, 10)):
12068:
1           EXCEPTION:: SP_SEARCH_2(2069) :: cplan.sql(2214) :: :
1CURRENCY_ID:
1TODECIMAL:
1TD:
1TW:
1TMT_DATAFIELDS:
1SELECT CURRENCY_ID, PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4) INTO h_currenc+
1y_id, h_rate_echange:n      FROM TMT_WBS tw JOIN TMT_DATAFIELDS td on tw.CURR+
1ENCY_ID = td.ELEMENT_ID:n      WHERE tw.ELEMENT_ID = h_project_id:
12090:
1           EXCEPTION:: SP_SEARCH_2(2091) :: cplan.sql(2236) :: :
1DELETE FROM PMO_TMP_CPLN_0005:
1PMO_TMP_CPLN_0005:
1REGULAR_COST:
1REGULAR_SALE:
1SPECIAL_COST:
1SPECIAL_SALE:
1INSERT INTO PMO_TMP_CPLN_0005:n         SELECT RES_ID:n         , REGULAR_COS+
1T:n         , REGULAR_SALE:n         , SPECIAL_COST:n         , SPECIAL_SALE+
1:n         FROM PMO_TMP_SEARCH:n         WHERE RS_ID = h_rs_id:n         AND +
1(REGULAR_COST + REGULAR_SALE) > 0:
12128:
1           EXCEPTION:: SP_SEARCH_2(2129) :: cplan.sql(2274) :: :
1INSERT INTO PMO_TMP_CPLN_0005:n            SELECT RES_ID:n            , MAX(R+
1EGULAR_COST) AS REGULAR_COST:n            , MAX(REGULAR_SALE) AS REGULAR_SALE+
1:n            , MAX(SPECIAL_COST) AS SPECIAL_COST:n            , MAX(SPECIAL_+
1SALE) AS SPECIAL_SALE:n            FROM PMO_TMP_SEARCH:n            WHERE RS_+
1ID <> h_rs_id:n            GROUP BY RES_ID:
12157:
1           EXCEPTION:: SP_SEARCH_2(2158) :: cplan.sql(2303) :: :
1INSERT INTO PMO_TMP_CPLN_0005:n               SELECT RES_ID, 0.00, 0.00, 0.00+
1, 0.00:n               FROM PMO_TMP_SEARCH:n               WHERE RS_ID = h_rs+
1_id:n               GROUP BY RES_ID:
12181:
1           EXCEPTION:: SP_SEARCH_2(2182) :: cplan.sql(2327) :: :
1RS:
1WORK_LOCATION:
1O1:
1ORGANIZATION:
1G1:
1GEOGRAPHY:
1ROUND:
1PA:
1RES_SALE_RATE:
1TEMP:
1REGULAR_RATE:
1SPECIAL_RATE:
1START_DATE:
1FINISH_DATE:
1ASSIGNABLE:
1PLANNED:
1SCHED:
1PROPOSED:
1WORK_EFFORT:
1UNIT_EFFORT:
1AVAILABLE:
1VERIFIED:
1STATUS2_ID:
1FULL_NAME:
1PP:
1POOL_NAME:
1E_MAIL_ADDRESS:
1UNIQUE_ID:
1CONTOUR:
1ASSIGN_STRING:
1ASSIGNED_FLAG:
1FS_LABOR_CODE:
1RES_MODIFIED_DATE:
1EXTERNAL_ID:
1LEFT:
1OUTER:
1PROJECT_ASSIGNMENTS:
1R:
1RATES:
1RATE_ID:
1SELECT h_res_id AS ELEMENT_ID, 41 AS TYPE_ID, p.PROFILE_NAME AS ELEMENT_NAME,+
1 rs.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, h_work_location AS+
1 WORK_LOCATION,:n      o1.ELEMENT_NAME AS ORGANIZATION,g1.ELEMENT_NAME AS GEO+
1GRAPHY,:n      ROUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.REGULAR_COST WHEN rs+
1.RES_SALE_RATE=0 THEN temp.REGULAR_COST * h_rate_echange ELSE a.REGULAR_COST +
1* h_rate_echange END,2) AS REGULAR_COST,:n      ROUND(CASE WHEN pa.REGULAR_RA+
1TE>0 THEN pa.REGULAR_RATE WHEN rs.RES_SALE_RATE=0 THEN temp.REGULAR_SALE * h_+
1rate_echange ELSE a.REGULAR_SALE * h_rate_echange END,2) AS REGULAR_SALE,:n  +
1    ROUND(CASE WHEN pa.SPECIAL_COST>0 THEN pa.SPECIAL_COST WHEN rs.RES_SALE_R+
1ATE=0 THEN temp.SPECIAL_COST * h_rate_echange ELSE a.SPECIAL_COST * h_rate_ec+
1hange END,2) AS SPECIAL_COST,:n      ROUND(CASE WHEN pa.SPECIAL_RATE>0 THEN p+
1a.SPECIAL_RATE WHEN rs.RES_SALE_RATE=0 THEN temp.SPECIAL_SALE * h_rate_echang+
1e ELSE a.SPECIAL_SALE * h_rate_echange END,2) AS SPECIAL_SALE,:n      rs.STAR+
1T_DATE,rs.FINISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PROPOSE+
1D > 0 THEN rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT_EFFO+
1RT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n      '' AS VERIFIE+
1D, 0 AS STATUS2_ID, '' AS FULL_NAME, pp.ELEMENT_NAME AS POOL_NAME, '' AS E_MA+
1IL_ADDRESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIG+
1N_STRING, h_and_roles AS ROLE_ID, h_and_skills AS SKILL_ID, 0 AS ASSIGNED_FLA+
1G,:n      'PMOFFICE' AS FS_LABOR_CODE, TO_TIMESTAMP('1899-12-31 00::00::00') +
1AS RES_MODIFIED_DATE, '' AS EXTERNAL_ID:n      FROM PMO_TMP_CPLN_0005 temp JO+
1IN PMO_TMP_SEARCH rs ON rs.RES_ID = temp.RES_ID:n      LEFT OUTER JOIN PROJEC+
1T_ASSIGNMENTS pa ON pa.PROJECT_ID=h_project_id AND pa.RESOURCE_ID=rs.RES_ID:n+
1      JOIN PROFILES p ON p.PROFILE_ID = h_res_id:n      JOIN TMT_COMPETENCIES+
1 r ON p.ROLE_ID=r.ELEMENT_ID:n      LEFT OUTER JOIN RATES a ON r.RATE_ID=a.RA+
1TE_ID:n      LEFT OUTER JOIN TMT_ORGANIZATIONS o1 ON p.ORG_ID = o1.ELEMENT_ID+
1:n      LEFT OUTER JOIN TMT_GEOGRAPHIES g1 ON p.GEO_ID = g1.ELEMENT_ID:n     +
1 LEFT OUTER JOIN TMT_POOLS pp ON pp.ELEMENT_ID = p.POOL_ID:n      WHERE NOT (+
1rs.ROLE_NAME IS NuLL AND rs.SKILL_NAME IS NuLL AND rs.SHOW_ROLE IS NuLL AND r+
1s.SHOW_SKILL IS NuLL):
12207:
1                EXIT:: SP_SEARCH_2(2208) :: cplan.sql(2353) :: :
1O2:
1G2:
1DEFAULT_FLAG:
1RV:
1RM:
1PLANNED_WORK:
1SCHED_WORK:
1REC_DATETIME:
1MANAGER_ID:
1VERIFIED_1:
1SELECT rs.RES_ID AS ELEMENT_ID, 13 AS TYPE_ID, r.FULL_NAME AS ELEMENT_NAME, r+
1s.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, r.WORK_LOCATION,:n  +
1       o2.ELEMENT_NAME AS ORGANIZATION,g2.ELEMENT_NAME AS GEOGRAPHY,:n       +
1  ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THEN rs.REGULAR_COST * CASE WHEN (r.CUR+
1RENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE +
1(SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELE+
1MENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FR+
1OM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END WHEN rs.DEFAULT_FLAG=+
1'1' THEN rs.REGULAR_COST ELSE rs.REGULAR_COST * h_rate_echange END,2) AS REGU+
1LAR_COST,:n         ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THEN rs.REGULAR_SALE +
1* CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id+
1 = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DA+
1TAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELE+
1MENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END WHE+
1N rs.DEFAULT_FLAG='1' THEN rs.REGULAR_SALE ELSE rs.REGULAR_SALE * h_rate_echa+
1nge END,2) AS REGULAR_SALE,:n         ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THE+
1N rs.SPECIAL_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_+
1ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME+
1,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_OR+
1ASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CU+
1RRENCY_ID) END WHEN rs.DEFAULT_FLAG='1' THEN rs.SPECIAL_COST ELSE rs.SPECIAL_+
1COST * h_rate_echange END,2) AS SPECIAL_COST,:n         ROUND(CASE WHEN rs.DE+
1FAULT_FLAG='0' THEN rs.SPECIAL_SALE * CASE WHEN (r.CURRENCY_ID = h_currency_i+
1d) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODE+
1CIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id+
1) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE+
1 ELEMENT_ID = r.CURRENCY_ID) END WHEN rs.DEFAULT_FLAG='1' THEN rs.SPECIAL_SAL+
1E ELSE rs.SPECIAL_SALE * h_rate_echange END,2) AS SPECIAL_SALE,:n         rs.+
1START_DATE, rs.FINISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PR+
1OPOSED > 0 THEN rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT+
1_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n         rv.FU+
1LL_NAME AS VERIFIED, r.STATUS2_ID, pp.ELEMENT_NAME AS POOL_NAME, RM.FULL_NAME+
1, RM.E_MAIL_ADDRESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR+
1 AS ASSIGN_STRING, rs.ROLE_ID, rs.SKILL_ID, COALESCE(pa.PLANNED_WORK + pa.SCH+
1ED_WORK,0) AS ASSIGNED_FLAG,:n         r.FS_LABOR_CODE, r.REC_DATETIME AS RES+
1_MODIFIED_DATE, r.EXTERNAL_ID:n         FROM PMO_TMP_SEARCH rs JOIN TMT_POOLS+
1 p ON rs.RES_ID=p.ELEMENT_ID:n         JOIN TMT_POOLS pp ON pp.ELEMENT_ID=p.P+
1ARENT_ID:n         LEFT OUTER JOIN RESOURCES RM ON pp.MANAGER_ID=RM.RESOURCE_+
1ID:n         JOIN RESOURCES r ON rs.RES_ID=r.RESOURCE_ID LEFT OUTER JOIN RESO+
1URCES rv ON rv.RESOURCE_ID=r.VERIFIED_1:n         LEFT OUTER JOIN PROJECT_ASS+
1IGNMENTS pa ON pa.PROJECT_ID=h_project_id AND pa.RESOURCE_ID=rs.RES_ID:n     +
1    LEFT OUTER JOIN TMT_ORGANIZATIONS o1 ON r.RESOURCE_ID=o1.ELEMENT_ID:n    +
1     LEFT OUTER JOIN TMT_ORGANIZATIONS o2 ON o1.PARENT_ID=o2.ELEMENT_ID:n    +
1     LEFT OUTER JOIN TMT_GEOGRAPHIES g1 ON r.RESOURCE_ID=g1.ELEMENT_ID:n     +
1    LEFT OUTER JOIN TMT_GEOGRAPHIES g2 ON g1.PARENT_ID=g2.ELEMENT_ID:n       +
1  ORDER BY ELEMENT_ID:
12232:
1                EXIT:: SP_SEARCH_2(2233) :: cplan.sql(2378) :: :
1DELETE FROM PMO_TMP_CPLN_0006:
1PMO_TMP_CPLN_0006:
1INSERT INTO PMO_TMP_CPLN_0006:n            SELECT RES_ID, REGULAR_COST, REGUL+
1AR_SALE, SPECIAL_COST, SPECIAL_SALE, 1:n            FROM PMO_TMP_SEARCH WHERE+
1 DEFAULT_FLAG = '1':
12255:
1           EXCEPTION:: SP_SEARCH_2(2256) :: cplan.sql(2401) :: :
1INSERT INTO PMO_TMP_CPLN_0006:n            SELECT  RES_ID,                   +
1          MAX(REGULAR_COST) AS REGULAR_COST,:n            MAX(REGULAR_SALE) A+
1S REGULAR_SALE,  MAX(SPECIAL_COST) AS SPECIAL_COST,:n            MAX(SPECIAL_+
1SALE) AS SPECIAL_SALE , 0:n            FROM PMO_TMP_SEARCH:n            WHERE+
1 RES_ID NOT IN (SELECT RES_ID FROM PMO_TMP_SEARCH WHERE DEFAULT_FLAG = '1' AN+
1D RES_ID IS NOT NuLL):n            GROUP BY RES_ID:
12280:
1           EXCEPTION:: SP_SEARCH_2(2281) :: cplan.sql(2426) :: :
1DEF:
1PRF:
1RR:
1SELECT rs.RES_ID AS ELEMENT_ID, 13 AS TYPE_ID, r.FULL_NAME AS ELEMENT_NAME, r+
1s.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, r.WORK_LOCATION,:n  +
1       o2.ELEMENT_NAME AS ORGANIZATION,g2.ELEMENT_NAME AS GEOGRAPHY,:n       +
1  :n         ROUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.REGULAR_COST:n        +
1 WHEN a.REGULAR_COST>0 THEN a.REGULAR_COST * CASE WHEN (r.CURRENCY_ID = h_cur+
1rency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORAS+
1TD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_curr+
1ency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELD+
1S WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         WHEN def.REGULAR_COST>0 THE+
1N def.REGULAR_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY+
1_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAM+
1E,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_O+
1RASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.C+
1URRENCY_ID) END:n         else prf.REGULAR_COST * h_rate_echange:n         EN+
1D,2) AS REGULAR_COST,:n         :n         ROUND(CASE WHEN pa.REGULAR_COST> 0+
1 THEN pa.REGULAR_RATE:n         WHEN a.REGULAR_COST > 0 THEN a.REGULAR_SALE *+
1 CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id +
1= 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DAT+
1AFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEM+
1ENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n   +
1      WHEN def.REGULAR_COST>0 THEN def.REGULAR_SALE * CASE WHEN (r.CURRENCY_I+
1D = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT+
1 PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID+
1 = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_+
1DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         else prf.REGULAR_S+
1ALE * h_rate_echange:n         END,2) AS REGULAR_SALE,:n         :n         R+
1OUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.SPECIAL_COST:n         WHEN a.REGULA+
1R_COST>0 THEN a.SPECIAL_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (+
1r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(E+
1LEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SE+
1LECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMEN+
1T_ID = r.CURRENCY_ID) END:n         WHEN def.REGULAR_COST>0 THEN def.SPECIAL_+
1COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_curren+
1cy_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM T+
1MT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMA+
1L(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) EN+
1D:n         else prf.SPECIAL_COST * h_rate_echange:n         END,2) AS SPECIA+
1L_COST,:n         :n         ROUND(CASE WHEN pa.REGULAR_RATE>0 THEN pa.SPECIA+
1L_RATE:n         WHEN a.REGULAR_SALE>0 THEN a.SPECIAL_SALE * CASE WHEN (r.CUR+
1RENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE +
1(SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELE+
1MENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FR+
1OM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         WHEN def.RE+
1GULAR_COST>0 THEN def.SPECIAL_SALE * CASE WHEN (r.CURRENCY_ID = h_currency_id+
1) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODEC+
1IMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id)+
1 / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE +
1ELEMENT_ID = r.CURRENCY_ID) END:n         else prf.SPECIAL_SALE * h_rate_echa+
1nge:n         END,2) AS SPECIAL_SALE,:n         :n         rs.START_DATE,rs.F+
1INISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PROPOSED > 0 THEN +
1rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT_EFFORT,(rs.ASSI+
1GNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n         rv.FULL_NAME AS VERIF+
1IED, r.STATUS2_ID, pp.ELEMENT_NAME AS POOL_NAME, RM.FULL_NAME, RM.E_MAIL_ADDR+
1ESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRIN+
1G,:n         rs.ROLE_ID, rs.SKILL_ID, COALESCE(pa.PLANNED_WORK + pa.SCHED_WOR+
1K,0) AS ASSIGNED_FLAG,:n         r.FS_LABOR_CODE, r.REC_DATETIME AS RES_MODIF+
1IED_DATE, r.EXTERNAL_ID:n         FROM PMO_TMP_SEARCH rs:n         LEFT JOIN +
1PMO_TMP_CPLN_0006 def ON rs.RES_ID=def.RES_ID AND def.DEFAULT_FLAG = 1:n     +
1    LEFT JOIN PMO_TMP_CPLN_0006 prf ON rs.RES_ID=prf.RES_ID AND prf.DEFAULT_F+
1LAG = 0:n         JOIN TMT_POOLS p ON rs.RES_ID=p.ELEMENT_ID:n         JOIN T+
1MT_POOLS pp ON pp.ELEMENT_ID=p.PARENT_ID:n         LEFT OUTER JOIN RESOURCES +
1RM ON pp.MANAGER_ID=RM.RESOURCE_ID:n         JOIN RESOURCES r ON rs.RES_ID=r.+
1RESOURCE_ID LEFT OUTER JOIN RESOURCES rv ON rv.RESOURCE_ID=r.VERIFIED_1:n    +
1     LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID=h_project_id AND+
1 pa.RESOURCE_ID=rs.RES_ID:n         LEFT OUTER JOIN RESOURCES rr ON r.VERIFIE+
1D_1=rr.RESOURCE_ID:n         LEFT OUTER JOIN TMT_ORGANIZATIONS o1 ON r.RESOUR+
1CE_ID=o1.ELEMENT_ID LEFT OUTER JOIN TMT_ORGANIZATIONS o2 ON o1.PARENT_ID=o2.E+
1LEMENT_ID:n         LEFT OUTER JOIN TMT_GEOGRAPHIES g1 ON r.RESOURCE_ID=g1.EL+
1EMENT_ID LEFT OUTER JOIN TMT_GEOGRAPHIES g2 ON g1.PARENT_ID=g2.ELEMENT_ID:n  +
1       LEFT OUTER JOIN RATES a ON r.RATE_ID=a.RATE_ID:n         WHERE NOT (rs+
1.ROLE_NAME IS NuLL AND rs.SKILL_NAME IS NuLL AND rs.SHOW_ROLE IS NuLL AND rs.+
1SHOW_SKILL IS NuLL):n         ORDER BY ELEMENT_ID:
12331:
1                EXIT:: SP_SEARCH_2(2332) :: cplan.sql(2477) :: :
1RETURN_ERROR_EXCEPTION:
12341:
1           EXCEPTION:: SP_SEARCH_2(2342) :: cplan.sql(2487) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
12353:
1           EXCEPTION:: SP_SEARCH_2(2354) :: cplan.sql(2499) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
3722
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a0 f4
b4 bf c8 :8 a0 12a bd b7 11
a4 b1 a0 f4 b4 bf c8 :10 a0
12a bd b7 11 a4 b1 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d a0 51 d a0 51 d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a0 7e b4 2e :2 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a a 10
a0 7e b4 2e :2 5a a 10 a0
7e b4 2e :2 5a a 10 :2 a0 51
a5 b a0 7e a0 6b b4 2e
5a a 10 a0 7e b4 2e :2 5a
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 a0 b7 a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 :2 19 3c b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e a
10 :2 a0 51 a5 b 7e 51 b4
2e a 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c a0 7e b4
2e :2 5a a0 51 d b7 :2 a0 d
b7 :2 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e 5a a0 7e
b4 2e :2 5a a 10 a0 7e b4
2e :2 5a a 10 :8 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c a0 51 d b7
19 3c a0 7e b4 2e :2 5a a0
7e b4 2e :2 5a a 10 :3 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c :2 a0 d :3 a0 6b :3 a0
51 a5 b :2 a0 6b a5 b 5a
51 a5 b d :4 a0 51 a5 b
:2 a0 6b a5 b d :3 a0 6b :3 a0
51 a5 b :2 a0 6b a5 b 5a
51 a5 b d :4 a0 51 a5 b
:2 a0 6b a5 b d :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
6e d a0 b7 :2 a0 51 a5 b
a0 7e a0 6b b4 2e a0 6e
d b7 19 :2 a0 51 a5 b a0
7e a0 6b b4 2e a0 6e d
b7 a0 6e d b7 :2 19 3c b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e a0 51 d :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 6e a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 19 3c
:4 a0 51 a5 b a5 b d :2 a0
51 a5 b 7e 51 b4 2e :4 a0
51 a5 b a5 b d :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:3 a0 6b d b7 19 3c :2 a0 d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 d b7 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 :2 19 3c :8 a0 a5 b
d :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 51 a5 b 7e
51 b4 2e :3 a0 6b d b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 51 a5 b :2 a0 a5
57 b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
51 a5 b :2 a0 a5 57 b7 19
3c :2 a0 51 a5 b a0 7e a0
6b b4 2e :3 a0 51 a5 b a5
b 7e 51 b4 2e :d a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:27 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
a0 b7 :2 a0 51 a5 b a0 7e
a0 6b b4 2e :9 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :13 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c a0 7e
b4 2e 5a :3 a0 6b d :3 a0 a5
b d b7 19 3c b7 19 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 19
3c :2 a0 51 a5 b a0 7e a0
6b b4 2e :17 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 a0 b7 :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 :2 51 a5 b 7e 6e b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e a 10 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :9 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 :2 19 3c b7
19 3c b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
7e b4 2e 5a a 10 :2 a0 51
a5 b 7e 51 b4 2e a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :2 a0 51 a5 b a0 7e
a0 6b b4 2e :b a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 19 3c b7
19 3c b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e a 10 a0
51 d b7 19 3c :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
7e b4 2e 5a a0 6e d a0
6e d b7 :2 a0 d :2 a0 d b7
:2 19 3c a0 51 d b7 a0 7e
51 b4 2e a0 6e d :6 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :3 a0 a5
b d :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 b7 :2 19 3c
b7 :2 a0 d b7 :2 19 3c :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 a0 51
d a0 b7 :2 a0 51 a5 b 7e
51 b4 2e a0 51 d a0 b7
19 :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 a0 51 d
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e a0 51 d b7 :2 19
3c b7 19 3c b7 :2 19 3c :2 a0
51 a5 b a0 7e a0 6b b4
2e a0 51 d :2 a0 d :2 a0 d
:3 a0 :2 51 a5 b d a0 4d d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 b4 2e d a0 51 d b7
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e :b a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 a0 51 d b7 :2 19 3c b7
:2 19 3c a0 7e 51 b4 2e :9 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :1f a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e a0 6e
d b7 a0 6e d b7 :2 19 3c
:13 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 b7 :2 a0 :2 51 a5 b 7e 6e
b4 2e :a a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :6 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
:2 a0 b4 2e d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
a0 7e a0 6b b4 2e a 10
:2 a0 51 a5 b a0 7e a0 6b
b4 2e a 10 a0 7e b4 2e
5a :2 a0 d b7 19 3c b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e :3 a0 6b d b7 19 3c a0
7e b4 2e 5a a0 7e b4 2e
5a a 10 a0 7e b4 2e 5a
a 10 a0 7e b4 2e :2 5a a
10 a0 51 d b7 19 3c a0
6e d a0 6e d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e d b7 19 a0 6e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e d b7 :2 19 3c b7
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 51 a5 b a0 7e
a0 6b b4 2e a 10 :2 a0 51
a5 b a0 7e a0 6b b4 2e
a 10 :2 a0 6e 11e 11d :2 a0 6b
51 d a0 7e b4 2e 5a :2 a0
6e 11e 11d :2 a0 6b 51 d :17 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :15 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 a0 d b7 :2 19 3c b7 19 3c
a0 7e b4 2e 5a :4 a0 a5 b
51 a5 b 7e 51 b4 2e :4 a0
a5 b 51 a5 b 51 a5 b
7e 51 b4 2e a6 122 :4 a0 a5
b 51 a5 b 51 a5 b 122
124 d a0 51 d :3 a0 7e a0
b4 2e 82 :5 a0 7e 51 b4 2e
51 a5 b a5 b 51 a5 b
7e 51 b4 2e :5 a0 7e 51 b4
2e 51 a5 b a5 b 51 a5
b 7e 51 b4 2e a 10 a0
2b b7 19 3c :2 a0 7e 51 b4
2e d b7 a0 47 :2 a0 7e b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :4 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
:2 a0 51 a5 b a0 7e a0 6b
b4 2e a0 6e d a0 6e d
:2 a0 7e a0 b4 2e d :2 a0 7e
6e b4 2e d a0 b7 :2 a0 51
a5 b a0 7e a0 6b b4 2e
a0 6e d :2 a0 7e a0 b4 2e
d :2 a0 7e 6e b4 2e d a0
6e d b7 19 :2 a0 51 a5 b
a0 7e a0 6b b4 2e a0 6e
d a0 6e d a0 7e b4 2e
5a :2 a0 7e 6e b4 2e d :2 a0
7e a0 b4 2e d :2 a0 7e 6e
b4 2e d b7 19 3c :2 a0 7e
6e b4 2e d a0 7e b4 2e
5a :2 a0 7e 6e b4 2e d :2 a0
7e a0 b4 2e d :2 a0 7e 6e
b4 2e d b7 19 3c b7 a0
7e b4 2e 5a :2 a0 7e 6e b4
2e d a0 6e d b7 :2 a0 7e
6e b4 2e 7e 6e b4 2e d
a0 6e d a0 7e b4 2e 5a
:2 a0 7e 6e b4 2e d :2 a0 7e
a0 b4 2e d :2 a0 7e 6e b4
2e d b7 19 3c :2 a0 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e d b7
:2 19 3c a0 7e b4 2e 5a :2 a0
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e d b7 19 3c
b7 :2 19 3c b7 :2 19 3c :2 a0 51
a5 b a0 7e a0 6b b4 2e
a0 7e b4 2e 5a :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:4 a0 a5 b 51 a5 b d :2 a0
7e 6e b4 2e d :2 a0 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d b7
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 19 3c b7 19 3c a0 7e b4
2e 5a :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 7e 6e
b4 2e d :2 a0 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e d b7 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 19 3c
b7 19 3c a0 7e b4 2e 5a
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 7e 6e b4 2e
d :2 a0 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d b7 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 19 3c b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 51 a5 b 7e 51 b4
2e a 10 :2 a0 7e 6e b4 2e
7e :3 a0 51 a5 b a5 b b4
2e 7e 6e b4 2e d b7 19
3c b7 19 3c a0 7e b4 2e
5a :4 a0 a5 b 51 a5 b d
a0 51 d :3 a0 7e a0 b4 2e
82 :3 a0 6b :2 51 a0 7e 51 b4
2e a0 a5 b d :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :2 a0 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e d :2 a0 51 a5 b
a0 7e a0 6b b4 2e :2 a0 7e
6e b4 2e d b7 :2 a0 7e 6e
b4 2e d b7 :2 19 3c :2 a0 51
a5 b a0 7e a0 6b b4 2e
a0 2b b7 19 3c :2 a0 7e 51
b4 2e d b7 a0 47 b7 19
3c :2 a0 51 a5 b a0 7e a0
6b b4 2e :4 a0 a5 b 51 a5
b d a0 51 d :3 a0 7e a0
b4 2e 82 :3 a0 6b :2 51 a0 7e
51 b4 2e a0 a5 b d :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :2 a0 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e d :2 a0 7e 51 b4 2e d
b7 a0 47 b7 19 3c :2 a0 7e
a0 b4 2e d b7 :2 19 3c :2 a0
7e 6e b4 2e d :3 a0 11c 11d
:3 a0 e9 d3 :2 a0 f :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a a0 2b b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b a0 7e a0 6b b4
2e a 10 :2 a0 51 a5 b a0
7e a0 6b b4 2e a 10 :2 a0
51 a5 b a0 7e a0 6b b4
2e a0 7e b4 2e 5a 52 10
5a a 10 :2 a0 e9 dd b3 :2 a0
e9 d3 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 e9 c1 :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 3b b7 :2 a0
e9 c1 :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 19 3c
:2 a0 d :2 a0 d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 :2 51 a5 b
7e 6e b4 2e :2 a0 b4 2e d
a0 51 d b7 :3 a0 51 a5 b
a5 b 7e 51 b4 2e :9 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 19 3c
b7 :2 19 3c :20 a0 51 a5 b :4 51
a5 b d a0 7e 51 b4 2e
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 7e a0 6b b4
2e :3 a0 6b d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:3 a0 a5 57 a0 b7 :2 a0 :2 51 a5
b 7e 6e b4 2e 5a :2 a0 :2 51
a5 b 7e 6e b4 2e 5a a
10 :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c a0 2b b7 :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 d :2 a0 d b7 19 3c
:1e a0 :5 51 a5 b d a0 7e 51
b4 2e :2 a0 7e 51 b4 2e d
a0 b7 a0 7e 51 b4 2e a0
2b b7 :2 19 3c :2 a0 7e a0 51
a5 b b4 2e a0 2b b7 19
3c b7 :2 19 3c 93 4f b0 46
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 7e
a0 6b b4 2e 5a a0 7e 51
b4 2e 5a 52 10 a0 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e a 10 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:3 a0 a5 57 b7 19 3c a0 7e
51 b4 2e a0 6e d a0 6e
d a0 6e d :2 a0 e9 dd b3
a0 51 d :a a0 e9 d3 5 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a a0 2b
b7 19 3c a0 7e b4 2e 5a
:2 a0 6b :2 a0 a5 b 7e 51 b4
2e a 10 :3 a0 a5 b 51 a5
b 7e 51 b4 2e a 10 :2 a0
d b7 19 3c :2 a0 6b :2 a0 a5
b 7e 51 b4 2e a0 7e 51
b4 2e :f a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c a0 6e d
a0 6e d a0 6e d a0 6e
d a0 6e d a0 6e d :2 a0
d a0 51 d b7 19 3c a0
7e 51 b4 2e a0 7e b4 2e
5a a 10 :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c a0 7e
b4 2e 5a a0 7e b4 2e 5a
:3 a0 7e 6e b4 2e :2 51 a5 b
d b7 19 3c :3 a0 7e a0 b4
2e :2 51 a5 b d b7 19 3c
a0 7e b4 2e 5a :3 a0 7e a0
b4 2e :2 51 a5 b d b7 19
3c a0 7e b4 2e 5a a0 7e
b4 2e 5a :3 a0 7e 6e b4 2e
:2 51 a5 b d b7 19 3c :3 a0
7e a0 b4 2e :2 51 a5 b d
b7 19 3c a0 7e b4 2e 5a
:3 a0 7e a0 b4 2e :2 51 a5 b
d b7 19 3c a0 7e b4 2e
5a a0 7e b4 2e 5a :3 a0 7e
6e b4 2e :2 51 a5 b d b7
19 3c :3 a0 7e a0 b4 2e :2 51
a5 b d b7 19 3c a0 7e
b4 2e 5a a0 7e b4 2e 5a
:3 a0 7e 6e b4 2e :2 51 a5 b
d b7 19 3c :3 a0 7e a0 b4
2e :2 51 a5 b d b7 19 3c
:2 a0 7e 51 b4 2e d :2 a0 d
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 7e
51 b4 2e :f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c b7 19
3c a0 7e b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e :e a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 51 d 4f b7 :2 19 3c
b7 19 3c :13 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b a0 7e a0 6b b4 2e :2 a0
6e 11e 11d :2 a0 6b 51 d :b a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:12 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :6 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 19 3c :cd a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
b7 a0 7e 51 b4 2e :12f a0 12a
e9 dd :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 65 b7
:2 a0 6e 11e 11d :2 a0 6b 51 d
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:15 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:1b9 a0 12a e9 dd :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
65 b7 :2 19 3c b7 :2 19 3c b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
3722
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 168
164 13a 170 179 175 163 181 18e
18a 160 196 19f 19b 189 1a7 1b4
1b0 186 1bc 1c5 1c1 1af 1cd 1da
1d6 1ac 1e2 1eb 1e7 1d5 1f3 200
1fc 1d2 208 211 20d 1fb 219 1f8
21e 222 226 22a 22d 231 24e 239
23d 240 241 249 238 26b 259 235
25d 25e 266 258 288 276 255 27a
27b 283 275 2a5 293 272 297 298
2a0 292 2c2 2b0 28f 2b4 2b5 2bd
2af 2df 2cd 2ac 2d1 2d2 2da 2cc
2fc 2ea 2c9 2ee 2ef 2f7 2e9 319
307 2e6 30b 30c 314 306 336 324
303 328 329 331 323 353 341 320
345 346 34e 340 370 35e 33d 362
363 36b 35d 38d 37b 35a 37f 380
388 37a 3aa 398 377 39c 39d 3a5
397 3c7 3b5 394 3b9 3ba 3c2 3b4
3e4 3d2 3b1 3d6 3d7 3df 3d1 401
3ef 3ce 3f3 3f4 3fc 3ee 41e 40c
3eb 410 411 419 40b 43b 429 408
42d 42e 436 428 458 446 425 44a
44b 453 445 475 463 442 467 468
470 462 492 480 45f 484 485 48d
47f 4ae 49d 4a1 4a9 47c 4ca 4b5
4b9 4bc 4bd 4c5 49c 4e7 4d5 499
4d9 4da 4e2 4d4 504 4f2 4d1 4f6
4f7 4ff 4f1 521 50f 4ee 513 514
51c 50e 53e 52c 50b 530 531 539
52b 55a 549 54d 555 528 576 561
565 568 569 571 548 593 581 545
585 586 58e 580 5b0 59e 57d 5a2
5a3 5ab 59d 5cd 5bb 59a 5bf 5c0
5c8 5ba 5ea 5d8 5b7 5dc 5dd 5e5
5d7 607 5f5 5d4 5f9 5fa 602 5f4
623 612 616 5f1 61e 611 63f 62e
632 60e 63a 62d 65b 64a 64e 62a
656 649 677 666 66a 646 672 665
693 682 686 662 68e 681 6af 69e
6a2 67e 6aa 69d 6cb 6ba 6be 69a
6c6 6b9 6e7 6d6 6da 6b6 6e2 6d5
703 6f2 6f6 6d2 6fe 6f1 71f 70e
712 6ee 71a 70d 73b 72a 72e 70a
736 729 757 746 74a 726 752 745
773 762 766 742 76e 761 78f 77e
782 75e 78a 77d 7ab 79a 79e 77a
7a6 799 7c7 7b6 7ba 796 7c2 7b5
7e3 7d2 7d6 7b2 7de 7d1 7ff 7ee
7f2 7ce 7fa 7ed 81b 80a 80e 7ea
816 809 837 826 82a 806 832 825
853 842 846 822 84e 841 86f 85e
862 83e 86a 85d 88b 87a 87e 85a
886 879 8a7 896 89a 876 8a2 895
8c3 8b2 8b6 892 8be 8b1 8df 8ce
8d2 8ae 8da 8cd 8fb 8ea 8ee 8ca
8f6 8e9 917 906 90a 8e6 912 905
933 922 926 902 92e 921 94f 93e
942 91e 94a 93d 96b 95a 95e 93a
966 959 987 976 97a 956 982 975
9a3 992 996 972 99e 991 9c0 9ae
98e 9b2 9b3 9bb 9ad 9dc 9cb 9cf
9aa 9d7 9ca 9f8 9e7 9eb 9c7 9f3
9e6 a14 a03 a07 9e3 a0f a02 a31
a1f 9ff a23 a24 a2c a1e a4e a3c
a1b a40 a41 a49 a3b a6b a59 a38
a5d a5e a66 a58 a87 a76 a7a a55
a82 a75 aa3 a92 a96 a72 a9e a91
ac0 aae a8e ab2 ab3 abb aad add
acb aaa acf ad0 ad8 aca afa ae8
ac7 aec aed af5 ae7 b17 b05 ae4
b09 b0a b12 b04 b34 b22 b01 b26
b27 b2f b21 b51 b3f b1e b43 b44
b4c b3e b6d b5c b60 b3b b68 b5b
b89 b78 b7c b58 b84 b77 ba5 b94
b98 b74 ba0 b93 bc1 bb0 bb4 b90
bbc baf bdd bcc bd0 bac bd8 bcb
bf9 be8 bec bc8 bf4 be7 c15 c04
c08 be4 c10 c03 c31 c20 c24 c00
c2c c1f c4e c3c c1c c40 c41 c49
c3b c6a c59 c5d c38 c65 c58 c86
c75 c79 c81 c55 c9e c8d c91 c99
c74 cba ca9 cad cb5 c71 cd2 cc1
cc5 ccd ca8 cee cdd ce1 ce9 ca5
d06 cf5 cf9 d01 cdc d22 d11 d15
d1d cd9 d41 d29 d2d d31 d34 d3c
d10 d48 d4c d0d d5d d60 d64 d68
d6c d70 d74 d78 d7c d80 d84 d90
d95 d97 da3 da7 da9 dad dbe dbf
dc2 dc6 dca dce dd2 dd6 dda dde
de2 de6 dea dee df2 df6 dfa dfe
e02 e06 e12 e17 e19 e25 e29 e47
e2f e33 e37 e3a e42 e2e e67 e52
e56 e2b e5a e62 e51 e87 e72 e76
e4e e7a e82 e71 ea7 e92 e96 e6e
e9a ea2 e91 eae eb2 e8e eb6 eba
ebe ec1 ec6 ec7 1 ec9 ece ed2
ed6 ed9 ede ee2 ee6 ee9 eee eef
ef1 ef6 ef9 efd efe f03 f08 f0b
f10 f11 f16 f19 f1d f1e f23 f26
f2b f2c f31 f34 f39 f3a f3f f42
f47 f48 f4d f50 f54 f55 f5a f5d
f62 f63 f68 f6b f70 f71 f76 f79
f7e f7f f84 f87 f8b f8c f91 f94
f99 f9a f9f fa2 fa7 fa8 fad fb0
fb4 fb8 fbc fbd fbf fc4 fc5 fc7
fc8 fcd fd0 fd5 fd6 fdb fde fe2
fe6 fea feb fed ff2 ff3 ff5 ff6
ffb ffe 1003 1004 1009 100c 1010 1014
1018 1019 101b 1020 1021 1023 1024 1029
102c 1031 1032 1037 103a 103e 1042 1046
1047 1049 104e 104f 1051 1052 1057 105a
105f 1060 1065 1068 106c 1070 1074 1075
1077 107c 107d 107f 1080 1085 1088 108d
108e 1093 1096 109a 109e 10a2 10a3 10a5
10aa 10ab 10ad 10ae 10b3 10b6 10bb 10bc
10c1 10c4 10c8 10cc 10d0 10d1 10d3 10d8
10d9 10db 10dc 10e1 10e4 10e9 10ea 10ef
10f2 10f6 10fa 10fe 10ff 1101 1106 1107
1109 110a 110f 1112 1117 1118 111d 1120
1125 1126 112b 112e 1132 1133 1138 113b
1140 1141 1146 1149 114e 114f 1154 1157
115c 115d 1162 1165 1169 116a 116f 1172
1177 1178 117d 1180 1185 1186 118b 118e
1193 1194 1199 119c 11a0 11a1 11a6 11a9
11ae 11af 11b4 11b7 11bc 11bd 11c2 11c5
11ca 11cb 11d0 11d3 11d7 11d8 11dd 11e0
11e5 11e6 11eb 11ee 11f3 11f4 11f9 11fc
1201 1202 1207 120a 120e 120f 1214 1217
121c 121d 1222 1225 122a 122b 1230 1233
1237 123b 123f 1240 1242 1247 1248 124a
124b 1250 1253 1258 1259 125e 1261 1266
1267 126c 126f 1273 1274 1279 127c 1281
1282 1287 128a 128f 1290 1295 1298 129d
129e 12a3 12a6 12aa 12ab 12b0 12b3 12b8
12b9 12be 12c1 12c6 12c7 12cc 12cf 12d4
12d5 12da 12dd 12e1 12e2 12e7 12ea 12ef
12f0 12f5 12f8 12fd 12fe 1303 1306 130b
130c 1311 1314 1318 1319 131e 1321 1326
1327 132c 132f 1334 1335 133a 133d 1341
1345 1349 134a 134c 1351 1352 1354 1355
135a 135d 1362 1363 1368 136b 136f 1373
1377 1378 137a 137f 1380 1382 1383 1388
138b 1390 1391 1396 1399 139d 13a1 13a5
13a6 13a8 13ad 13ae 13b0 13b1 13b6 13b9
13be 13bf 13c4 13c7 13cb 13cf 13d3 13d4
13d6 13db 13dc 13de 13df 13e4 13e7 13ec
13ed 13f2 13f5 13fa 13fb 1400 1403 1407
1408 140d 1410 1415 1416 141b 141e 1423
1424 1429 142c 1431 1432 1437 143a 143e
143f 1444 1447 144c 144d 1452 1455 145a
145b 1460 1461 1466 1468 146c 146f 1473
1477 147a 147e 1482 1485 1488 148d 1490
1493 1496 1497 149c 149d 1 149f 14a4
14a8 14ac 14af 14b4 14b9 14bc 14c0 14c1
14c6 14c7 14cc 14ce 14d2 14d5 14d9 14dd
14e1 14e5 14e9 14ed 14f1 14f5 14f9 14fd
1501 1505 1509 150d 1511 1515 1519 151d
1521 1525 1529 152d 1531 1535 1539 153d
1541 1545 1549 154d 1551 1555 1559 155d
1561 1565 1569 156d 1571 1575 1579 157d
1581 1585 1589 158d 1591 1595 1599 159d
15a1 15a5 15a9 15ad 15b1 15b5 15b9 15bd
15c1 15c5 15c9 15cd 15d1 15d5 15d9 15dd
15e1 15e4 15e8 15ec 15ef 15f3 15f7 15fb
15fe 15ff 1601 1605 1608 160c 160f 1610
1615 1618 161c 161f 1620 1625 1628 1
162b 1630 1634 1638 163b 163f 1643 1646
1649 164e 1651 1654 1657 1658 165d 165e
1 1660 1665 1669 166d 1670 1675 167a
167d 1681 1682 1687 168a 168f 1690 1695
1698 169d 169e 16a3 16a6 16aa 16ae 16b2
16b6 16b9 16ba 16bc 16c1 16c2 16c4 16c5
16ca 16cb 16d0 16d2 16d6 16d9 16dd 16e1
16e4 16e8 16ec 16ef 16f2 16f7 16fa 16fd
1700 1701 1706 1707 1 1709 170e 1712
1716 1719 171e 1723 1726 172a 172b 1730
1731 1736 1738 173c 173f 1743 1747 174a
174e 1752 1755 1759 175a 175f 1761 1765
1768 176c 176f 1770 1775 1778 177b 177f
1782 1783 1788 178b 1 178e 1793 1797
179a 179b 17a0 17a3 1 17a6 17ab 17af
17b2 17b3 17b8 17bb 1 17be 17c3 17c7
17cb 17ce 17cf 17d1 17d5 17d8 17dc 17df
17e0 17e5 1 17e8 17ed 17f1 17f4 17f5
17fa 17fd 1800 1804 1808 180b 180c 180e
1812 1815 1819 181c 181d 1822 1 1825
182a 182e 1832 1835 1839 183d 1840 1843
1848 184b 184e 1851 1852 1857 1858 1
185a 185f 1863 1867 186a 186f 1874 1877
187b 187c 1881 1884 1889 188a 188f 1892
1897 1898 189d 18a0 18a4 18a8 18ac 18b0
18b3 18b4 18b6 18bb 18bc 18be 18bf 18c4
18c5 18ca 18cc 18d0 18d3 18d7 18db 18de
18e2 18e6 18e9 18ec 18f1 18f4 18f7 18fa
18fb 1900 1901 1 1903 1908 190c 1910
1913 1918 191d 1920 1924 1925 192a 192b
1930 1932 1936 1939 193d 1941 1944 1948
194c 194f 1953 1954 1959 195d 195f 1963
1966 1967 196c 196f 1972 1976 1979 197a
197f 1982 1 1985 198a 198e 1992 1995
1999 199d 19a0 19a3 19a8 19ab 19ae 19b1
19b2 19b7 19b8 1 19ba 19bf 19c3 19c7
19ca 19cf 19d4 19d7 19db 19dc 19e1 19e4
19e9 19ea 19ef 19f2 19f7 19f8 19fd 1a00
1a04 1a08 1a0c 1a10 1a13 1a14 1a16 1a1b
1a1c 1a1e 1a1f 1a24 1a25 1a2a 1a2c 1a30
1a33 1a37 1a3b 1a3e 1a42 1a46 1a49 1a4c
1a51 1a54 1a57 1a5a 1a5b 1a60 1a61 1
1a63 1a68 1a6c 1a70 1a73 1a78 1a7d 1a80
1a84 1a85 1a8a 1a8b 1a90 1a92 1a96 1a99
1a9d 1aa1 1aa4 1aa8 1aac 1aaf 1ab3 1ab4
1ab9 1abb 1abf 1ac3 1ac6 1ac8 1acc 1acf
1ad3 1ad7 1ada 1adb 1add 1ae0 1ae3 1ae4
1ae9 1aed 1af1 1af4 1af5 1af7 1afa 1afd
1afe 1 1b03 1b08 1b0c 1b10 1b13 1b14
1b16 1b19 1b1c 1b1d 1 1b22 1b27 1b2b
1b2f 1b32 1b36 1b3a 1b3d 1b40 1b45 1b48
1b4b 1b4e 1b4f 1b54 1b55 1 1b57 1b5c
1b60 1b64 1b67 1b6c 1b71 1b74 1b78 1b79
1b7e 1b81 1b86 1b87 1b8c 1b8f 1b94 1b95
1b9a 1b9d 1ba1 1ba5 1ba9 1bad 1bb0 1bb1
1bb3 1bb8 1bb9 1bbb 1bbc 1bc1 1bc2 1bc7
1bc9 1bcd 1bd0 1bd4 1bd8 1bdb 1bdf 1be3
1be6 1be9 1bee 1bf1 1bf4 1bf7 1bf8 1bfd
1bfe 1 1c00 1c05 1c09 1c0d 1c10 1c15
1c1a 1c1d 1c21 1c22 1c27 1c28 1c2d 1c2f
1c33 1c36 1c3a 1c3e 1c41 1c45 1c49 1c4c
1c50 1c51 1c56 1c58 1c5c 1c5f 1c63 1c66
1c67 1c6c 1c6f 1c72 1c76 1c79 1c7d 1c7f
1c83 1c87 1c8b 1c8d 1c91 1c95 1c98 1c9c
1ca0 1ca3 1ca4 1ca6 1caa 1cad 1cb1 1cb4
1cb5 1cba 1cbd 1cc1 1cc4 1cc5 1cca 1ccd
1 1cd0 1cd5 1cd9 1cdc 1cdd 1ce2 1ce5
1 1ce8 1ced 1cf1 1cf5 1cf9 1cfd 1d01
1d05 1d09 1d0d 1d19 1d1d 1d21 1d24 1d28
1d2c 1d2e 1d32 1d36 1d3a 1d3d 1d41 1d45
1d47 1d48 1d4d 1 1d51 1d55 1d59 1d5c
1d60 1d64 1d68 1d6c 1d6f 1d73 1d77 1d7a
1d7d 1d82 1d85 1d88 1d8b 1d8c 1d91 1d92
1 1d94 1d99 1d9d 1da1 1da4 1da9 1dae
1db1 1db5 1db6 1dbb 1dbe 1dc3 1dc4 1dc9
1dcc 1dd1 1dd2 1dd7 1dda 1dde 1ddf 1de4
1de7 1dec 1ded 1df2 1df5 1df9 1dfd 1e00
1e03 1e04 1e06 1e07 1e0c 1e0d 1e12 1e14
1e18 1e1b 1e1d 1e21 1e23 1e2f 1e31 1e33
1e34 1e39 1e3d 1e3f 1e4b 1e4d 1e51 1e55
1e58 1e5c 1e5f 1e63 1e66 1e67 1e6c 1e6f
1e73 1e77 1e7a 1e7b 1e7d 1e80 1e83 1e84
1e89 1 1e8c 1e91 1e95 1e99 1e9c 1ea0
1ea4 1ea7 1eaa 1eaf 1eb2 1eb5 1eb8 1eb9
1ebe 1ebf 1 1ec1 1ec6 1eca 1ece 1ed1
1ed6 1edb 1ede 1ee2 1ee3 1ee8 1eeb 1ef0
1ef1 1ef6 1ef9 1efe 1eff 1f04 1f07 1f0b
1f0f 1f13 1f17 1f1a 1f1b 1f1d 1f22 1f23
1f25 1f26 1f2b 1f2c 1f31 1f33 1f37 1f3a
1f3e 1f42 1f45 1f49 1f4d 1f50 1f53 1f58
1f5b 1f5e 1f61 1f62 1f67 1f68 1 1f6a
1f6f 1f73 1f77 1f7a 1f7f 1f84 1f87 1f8b
1f8c 1f91 1f92 1f97 1f99 1f9d 1fa0 1fa4
1fa8 1fab 1faf 1fb3 1fb6 1fba 1fbb 1fc0
1fc2 1fc6 1fc9 1fcd 1fd0 1fd4 1fd6 1fda
1fdd 1fe1 1fe4 1fe5 1fea 1fed 1ff0 1ff4
1ff7 1ff8 1ffd 2000 1 2003 2008 200c
2010 2014 2020 2024 2028 202b 202f 2033
2035 2039 203d 2041 2044 2048 204c 204e
204f 2054 1 2058 205c 2060 2063 2067
206b 206f 2073 2076 207a 207e 2081 2084
2089 208c 208f 2092 2093 2098 2099 1
209b 20a0 20a4 20a8 20ab 20b0 20b5 20b8
20bc 20bd 20c2 20c5 20ca 20cb 20d0 20d3
20d8 20d9 20de 20e1 20e5 20e6 20eb 20ee
20f3 20f4 20f9 20fc 2100 2104 2107 210a
210b 210d 210e 2113 2114 2119 211b 211f
2122 2124 2128 212a 2136 2138 213a 213b
2140 2144 2146 2152 2154 2156 215a 215d
2161 2165 2169 216d 2171 2175 2178 217c
2180 2184 2187 2188 218a 218e 2192 2195
2196 2198 219b 219e 219f 21a1 21a5 21a9
21ad 21b1 21b5 21b8 21b9 21bb 21bf 21c3
21c6 21c7 21c9 21cd 21d1 21d5 21d9 21dc
21e0 21e4 21e8 21eb 21ec 21ee 21f2 21f6
21f9 21fa 21fc 21ff 2202 2203 2205 2209
220d 2211 2215 2219 221c 221d 221f 2223
2227 222a 222b 222d 2231 2235 2239 223c
223d 223f 2243 2246 224a 224d 224e 2253
2257 225c 2260 2264 2266 226a 226e 2271
2272 2274 2278 227b 227f 2282 2283 2288
228c 2291 2295 2297 229b 229f 22a3 22a6
22a7 22a9 22ad 22b0 22b4 22b7 22b8 22bd
22c1 22c6 22ca 22cc 22d0 22d5 22d9 22db
22df 22e3 22e6 22e8 22ec 22f0 22f3 22f7
22fb 22fe 22ff 2301 2304 2307 2308 230d
2311 2314 2318 231c 2320 2324 2328 232c
2338 233c 2340 2343 2347 234b 234d 2351
2355 2359 235c 2360 2364 2366 2367 236c
1 2370 2374 2378 237b 237f 2383 2387
238b 238e 2392 2396 2399 239c 23a1 23a4
23a7 23aa 23ab 23b0 23b1 1 23b3 23b8
23bc 23c0 23c3 23c8 23cd 23d0 23d4 23d5
23da 23dd 23e2 23e3 23e8 23eb 23f0 23f1
23f6 23f9 23fd 23fe 2403 2406 240b 240c
2411 2414 2418 241c 241f 2422 2423 2425
2426 242b 242c 2431 2433 2437 243a 243c
2440 2442 244e 2450 2452 2453 2458 245c
245e 246a 246c 2470 2474 2477 2478 247a
247d 2480 2481 2486 248a 248e 2492 2496
249a 24a6 24aa 24ae 24b1 24b5 24b9 24bb
24bf 24c3 24c7 24ca 24ce 24d2 24d4 24d5
24da 1 24de 24e2 24e6 24e9 24ed 24f1
24f5 24f9 24fc 2500 2504 2507 250a 250f
2512 2515 2518 2519 251e 251f 1 2521
2526 252a 252e 2531 2536 253b 253e 2542
2543 2548 254b 2550 2551 2556 2559 255e
255f 2564 2567 256b 256c 2571 2574 2579
257a 257f 2582 2586 258a 258d 2590 2591
2593 2594 2599 259a 259f 25a1 25a5 25a8
25aa 25ae 25b0 25bc 25be 25c0 25c1 25c6
25ca 25cc 25d8 25da 25de 25e2 25e5 25e9
25ee 25ef 25f1 25f4 25f7 25f8 25fd 2601
2605 2608 260c 2610 2613 2616 261b 261e
2621 2624 2625 262a 262b 1 262d 2632
2636 263a 263d 2642 2647 264a 264e 264f
2654 2657 265c 265d 2662 2665 266a 266b
2670 2673 2677 267b 267f 2683 2686 2687
2689 268e 268f 2691 2692 2697 269a 269f
26a0 26a5 26a8 26ad 26ae 26b3 26b6 26ba
26bb 26c0 26c3 26c8 26c9 26ce 26cf 26d4
26d6 26da 26dd 26e1 26e5 26e8 26ec 26f0
26f3 26f6 26fb 26fe 2701 2704 2705 270a
270b 1 270d 2712 2716 271a 271d 2722
2727 272a 272e 272f 2734 2735 273a 273c
2740 2743 2747 274b 274e 2752 2756 2759
275d 2761 2762 2767 2769 276d 2770 2772
2776 2779 277d 2781 2785 2789 278c 278d
278f 2790 2792 2796 279a 279e 27a1 27a2
27a4 27a7 27aa 27ab 27b0 27b4 27b8 27bc
27c0 27c3 27c4 27c6 27c7 27c9 27cd 27d1
27d5 27d8 27d9 27db 27de 27e1 27e2 27e7
27eb 27ef 27f2 27f6 27fa 27fd 2800 2805
2808 280b 280e 280f 2814 2815 1 2817
281c 2820 2824 2827 282c 2831 2834 2838
2839 283e 2841 2846 2847 284c 284f 2854
2855 285a 285d 2861 2865 2869 286d 2870
2871 2873 2878 2879 287b 287c 2881 2882
2887 2889 288d 2890 2894 2898 289b 289f
28a3 28a6 28a9 28ae 28b1 28b4 28b7 28b8
28bd 28be 1 28c0 28c5 28c9 28cd 28d0
28d5 28da 28dd 28e1 28e2 28e7 28e8 28ed
28ef 28f3 28f6 28fa 28fe 2901 2905 2909
290c 2910 2911 2916 2918 291c 291f 2923
2927 292b 292e 2932 2934 2938 293b 293f
2943 2947 294b 294f 2952 2953 2955 2958
295b 295c 2961 2965 2969 296d 296f 2973
2977 297a 297e 2982 2985 2988 298d 2990
2993 2996 2997 299c 299d 1 299f 29a4
29a8 29ac 29af 29b4 29b9 29bc 29c0 29c1
29c6 29c9 29ce 29cf 29d4 29d7 29dc 29dd
29e2 29e5 29e9 29ed 29f1 29f5 29f8 29f9
29fb 2a00 2a01 2a03 2a04 2a09 2a0a 2a0f
2a11 2a15 2a18 2a1c 2a20 2a23 2a27 2a2b
2a2e 2a31 2a36 2a39 2a3c 2a3f 2a40 2a45
2a46 1 2a48 2a4d 2a51 2a55 2a58 2a5d
2a62 2a65 2a69 2a6a 2a6f 2a70 2a75 2a77
2a7b 2a7e 2a82 2a86 2a89 2a8d 2a91 2a94
2a98 2a99 2a9e 2aa0 2aa4 2aa8 2aab 2aaf
2ab3 2ab7 2abb 2abf 2ac3 2ac7 2acb 2acc
2ace 2ad2 2ad6 2ada 2add 2ade 2ae0 2ae4
2ae7 2aeb 2aee 2aef 2af4 2af8 2afc 2aff
2b00 2b02 2b05 2b08 2b09 2b0e 2b12 2b16
2b1a 2b1d 2b21 2b23 2b27 2b2a 2b2e 2b32
2b35 2b39 2b3d 2b40 2b43 2b48 2b4b 2b4e
2b51 2b52 2b57 2b58 1 2b5a 2b5f 2b63
2b67 2b6a 2b6f 2b74 2b77 2b7b 2b7c 2b81
2b84 2b89 2b8a 2b8f 2b92 2b97 2b98 2b9d
2ba0 2ba4 2ba8 2bac 2bad 2baf 2bb4 2bb5
2bb7 2bb8 2bbd 2bc0 2bc5 2bc6 2bcb 2bce
2bd3 2bd4 2bd9 2bdc 2be0 2be1 2be6 2be9
2bee 2bef 2bf4 2bf5 2bfa 2bfc 2c00 2c03
2c07 2c0b 2c0e 2c12 2c16 2c19 2c1c 2c21
2c24 2c27 2c2a 2c2b 2c30 2c31 1 2c33
2c38 2c3c 2c40 2c43 2c48 2c4d 2c50 2c54
2c55 2c5a 2c5b 2c60 2c62 2c66 2c69 2c6d
2c71 2c74 2c78 2c7c 2c7f 2c80 2c82 2c86
2c8a 2c8b 2c90 2c92 2c96 2c99 2c9d 2ca1
2ca4 2ca5 2ca7 2caa 2cad 2cae 2cb3 2cb7
2cbb 2cbe 2cbf 2cc1 2cc4 2cc7 2cc8 1
2ccd 2cd2 2cd6 2cda 2cdd 2ce1 2ce5 2ce8
2ceb 2cf0 2cf3 2cf6 2cf9 2cfa 2cff 2d00
1 2d02 2d07 2d0b 2d0f 2d12 2d17 2d1c
2d1f 2d23 2d24 2d29 2d2c 2d31 2d32 2d37
2d3a 2d3f 2d40 2d45 2d48 2d4c 2d50 2d54
2d55 2d57 2d5c 2d5d 2d5f 2d60 2d65 2d68
2d6d 2d6e 2d73 2d76 2d7b 2d7c 2d81 2d84
2d88 2d89 2d8e 2d91 2d96 2d97 2d9c 2d9d
2da2 2da4 2da8 2dab 2daf 2db3 2db6 2dba
2dbe 2dc1 2dc4 2dc9 2dcc 2dcf 2dd2 2dd3
2dd8 2dd9 1 2ddb 2de0 2de4 2de8 2deb
2df0 2df5 2df8 2dfc 2dfd 2e02 2e03 2e08
2e0a 2e0e 2e11 2e15 2e19 2e1c 2e20 2e24
2e27 2e28 2e2a 2e2e 2e32 2e33 2e38 2e3a
2e3e 2e41 2e45 2e49 2e4c 2e4d 2e4f 2e53
2e56 2e5a 2e5d 2e5e 2e63 2e67 2e6b 2e6f
2e72 2e73 2e75 2e76 2e78 2e7b 2e7e 2e7f
2e84 2e88 2e8c 2e90 2e94 2e98 2e9c 2ea0
2ea4 2ea8 2eac 2eb0 2eb4 2eb8 2ec4 2ec8
2ecc 2ecf 2ed3 2ed7 2ed9 2edd 2ee1 2ee5
2ee8 2eec 2ef0 2ef2 2ef3 2ef8 1 2efc
2f00 2f04 2f07 2f0b 2f0f 2f13 2f17 2f1a
2f1e 2f22 2f25 2f28 2f2d 2f30 2f33 2f36
2f37 2f3c 2f3d 1 2f3f 2f44 2f48 2f4c
2f4f 2f54 2f59 2f5c 2f60 2f61 2f66 2f69
2f6e 2f6f 2f74 2f77 2f7c 2f7d 2f82 2f85
2f89 2f8a 2f8f 2f92 2f97 2f98 2f9d 2fa0
2fa4 2fa8 2fab 2fae 2faf 2fb1 2fb2 2fb7
2fb8 2fbd 2fbf 2fc3 2fc6 2fc8 2fcc 2fce
2fda 2fdc 2fde 2fdf 2fe4 2fe8 2fea 2ff6
2ff8 2ffa 2ffe 3002 3006 300a 300e 3012
3016 301a 301e 3022 3026 302a 302e 3032
3036 303a 303e 3042 3046 304a 304e 3052
3056 305a 305e 3062 3066 306a 306e 3072
3076 307a 307e 3082 3086 308a 308e 3092
3096 30a2 30a6 30aa 30ad 30b1 30b5 30b7
30bb 30bf 30c3 30c6 30ca 30ce 30d0 30d1
30d6 1 30da 30de 30e2 30e5 30e9 30ed
30f1 30f5 30f8 30fc 3100 3103 3106 310b
310e 3111 3114 3115 311a 311b 1 311d
3122 3126 312a 312d 3132 3137 313a 313e
313f 3144 3147 314c 314d 3152 3155 315a
315b 3160 3163 3167 3168 316d 3170 3175
3176 317b 317e 3182 3186 3189 318c 318d
318f 3190 3195 3196 319b 319d 31a1 31a4
31a6 31aa 31ac 31b8 31ba 31bc 31bd 31c2
31c6 31c8 31d4 31d6 31d8 31dc 31e0 31e3
31e7 31eb 31ee 31f2 31f5 31f9 31fc 31fd
3202 3205 3209 320d 3210 3214 3218 321b
321e 3223 3226 3229 322c 322d 3232 3233
1 3235 323a 323e 3242 3245 324a 324f
3252 3256 3257 325c 325f 3264 3265 326a
326d 3272 3273 3278 327b 327f 3283 3287
328b 328e 328f 3291 3296 3297 3299 329a
329f 32a2 32a7 32a8 32ad 32b0 32b5 32b6
32bb 32be 32c2 32c3 32c8 32cb 32d0 32d1
32d6 32d7 32dc 32de 32e2 32e5 32e9 32ed
32f0 32f4 32f8 32fb 32fe 3303 3306 3309
330c 330d 3312 3313 1 3315 331a 331e
3322 3325 332a 332f 3332 3336 3337 333c
333d 3342 3344 3348 334b 334f 3353 3356
335a 335e 3361 3365 3369 336a 336f 3371
3375 3378 337c 337e 3382 3386 3389 338a
338c 3390 3393 3397 339a 339b 33a0 33a4
33a8 33ac 33b0 33b4 33b8 33bc 33c0 33c4
33d0 33d4 33d8 33db 33df 33e3 33e5 33e9
33ed 33f1 33f4 33f8 33fc 33fe 33ff 3404
1 3408 340c 3410 3413 3417 341b 341f
3423 3426 342a 342e 3431 3434 3439 343c
343f 3442 3443 3448 3449 1 344b 3450
3454 3458 345b 3460 3465 3468 346c 346d
3472 3475 347a 347b 3480 3483 3488 3489
348e 3491 3495 3496 349b 349e 34a3 34a4
34a9 34ac 34b0 34b4 34b7 34ba 34bb 34bd
34be 34c3 34c4 34c9 34cb 34cf 34d2 34d4
34d8 34da 34e6 34e8 34ea 34eb 34f0 34f4
34f6 3502 3504 3508 350c 350f 3513 3516
351a 351d 351e 3523 3526 352a 352e 3531
3535 3539 353c 353f 3544 3547 354a 354d
354e 3553 3554 1 3556 355b 355f 3563
3566 356b 3570 3573 3577 3578 357d 3580
3585 3586 358b 358e 3593 3594 3599 359c
35a0 35a4 35a8 35ac 35af 35b0 35b2 35b7
35b8 35ba 35bb 35c0 35c3 35c8 35c9 35ce
35d1 35d6 35d7 35dc 35df 35e3 35e4 35e9
35ec 35f1 35f2 35f7 35f8 35fd 35ff 3603
3606 360a 360e 3611 3615 3619 361c 361f
3624 3627 362a 362d 362e 3633 3634 1
3636 363b 363f 3643 3646 364b 3650 3653
3657 3658 365d 365e 3663 3665 3669 366c
3670 3674 3677 367b 367f 3682 3686 368a
368b 3690 3692 3696 3699 369d 36a1 36a5
36a9 36ad 36b1 36b5 36b9 36bd 36c1 36c5
36c9 36cd 36d1 36d5 36d9 36dd 36e1 36e5
36f1 36f5 36f9 36fc 3700 3704 3706 370a
370e 3712 3715 3719 371d 371f 3720 3725
1 3729 372d 3731 3734 3738 373c 3740
3744 3747 374b 374f 3752 3755 375a 375d
3760 3763 3764 3769 376a 1 376c 3771
3775 3779 377c 3781 3786 3789 378d 378e
3793 3796 379b 379c 37a1 37a4 37a9 37aa
37af 37b2 37b6 37b7 37bc 37bf 37c4 37c5
37ca 37cd 37d1 37d5 37d8 37db 37dc 37de
37df 37e4 37e5 37ea 37ec 37f0 37f3 37f5
37f9 37fb 3807 3809 380b 380c 3811 3815
3817 3823 3825 3829 382d 3830 3834 3837
383b 383e 383f 3844 3847 384b 384f 3852
3856 385a 385d 3860 3865 3868 386b 386e
386f 3874 3875 1 3877 387c 3880 3884
3887 388c 3891 3894 3898 3899 389e 38a1
38a6 38a7 38ac 38af 38b4 38b5 38ba 38bd
38c1 38c5 38c9 38cd 38d0 38d1 38d3 38d8
38d9 38db 38dc 38e1 38e4 38e9 38ea 38ef
38f2 38f7 38f8 38fd 3900 3904 3905 390a
390d 3912 3913 3918 3919 391e 3920 3924
3927 392b 392f 3932 3936 393a 393d 3940
3945 3948 394b 394e 394f 3954 3955 1
3957 395c 3960 3964 3967 396c 3971 3974
3978 3979 397e 397f 3984 3986 398a 398d
3991 3995 3998 399c 39a0 39a3 39a7 39ab
39ac 39b1 39b3 39b7 39ba 39be 39c1 39c2
39c7 39ca 39ce 39d2 39d6 39d9 39dd 39e1
39e5 39e9 39ea 39ec 39f0 39f2 39f6 39f9
39fb 39ff 3a03 3a07 3a0a 3a0e 3a12 3a15
3a18 3a1d 3a20 3a23 3a26 3a27 3a2c 3a2d
1 3a2f 3a34 3a38 3a3c 3a3f 3a44 3a49
3a4c 3a50 3a51 3a56 3a59 3a5e 3a5f 3a64
3a67 3a6c 3a6d 3a72 3a75 3a79 3a7d 3a81
3a85 3a88 3a89 3a8b 3a90 3a91 3a93 3a94
3a99 3a9c 3aa1 3aa2 3aa7 3aaa 3aaf 3ab0
3ab5 3ab8 3abc 3abd 3ac2 3ac5 3aca 3acb
3ad0 3ad1 3ad6 3ad8 3adc 3adf 3ae3 3ae7
3aea 3aee 3af2 3af5 3af8 3afd 3b00 3b03
3b06 3b07 3b0c 3b0d 1 3b0f 3b14 3b18
3b1c 3b1f 3b24 3b29 3b2c 3b30 3b31 3b36
3b37 3b3c 3b3e 3b42 3b45 3b49 3b4d 3b50
3b54 3b58 3b5b 3b5f 3b63 3b64 3b69 3b6b
3b6f 3b73 3b76 3b7a 3b7e 3b81 3b82 3b84
3b88 3b8b 3b8f 3b92 3b93 3b98 3b9c 3ba0
3ba4 3ba8 3bac 3bb0 3bb4 3bb8 3bbc 3bc0
3bc4 3bc8 3bcc 3bd0 3bd4 3bd8 3bdc 3be0
3be4 3be8 3bec 3bf0 3bf4 3c00 3c04 3c08
3c0b 3c0f 3c13 3c15 3c19 3c1d 3c21 3c24
3c28 3c2c 3c2e 3c2f 3c34 1 3c38 3c3c
3c40 3c43 3c47 3c4b 3c4f 3c53 3c56 3c5a
3c5e 3c61 3c64 3c69 3c6c 3c6f 3c72 3c73
3c78 3c79 1 3c7b 3c80 3c84 3c88 3c8b
3c90 3c95 3c98 3c9c 3c9d 3ca2 3ca5 3caa
3cab 3cb0 3cb3 3cb8 3cb9 3cbe 3cc1 3cc5
3cc6 3ccb 3cce 3cd3 3cd4 3cd9 3cdc 3ce0
3ce4 3ce7 3cea 3ceb 3ced 3cee 3cf3 3cf4
3cf9 3cfb 3cff 3d02 3d04 3d08 3d0a 3d16
3d18 3d1a 3d1b 3d20 3d24 3d26 3d32 3d34
3d38 3d3c 3d3f 3d43 3d46 3d4a 3d4d 3d4e
3d53 3d56 3d5a 3d5e 3d61 3d65 3d69 3d6c
3d6f 3d74 3d77 3d7a 3d7d 3d7e 3d83 3d84
1 3d86 3d8b 3d8f 3d93 3d96 3d9b 3da0
3da3 3da7 3da8 3dad 3db0 3db5 3db6 3dbb
3dbe 3dc3 3dc4 3dc9 3dcc 3dd0 3dd4 3dd8
3ddc 3ddf 3de0 3de2 3de7 3de8 3dea 3deb
3df0 3df3 3df8 3df9 3dfe 3e01 3e06 3e07
3e0c 3e0f 3e13 3e14 3e19 3e1c 3e21 3e22
3e27 3e28 3e2d 3e2f 3e33 3e36 3e3a 3e3e
3e41 3e45 3e49 3e4c 3e4f 3e54 3e57 3e5a
3e5d 3e5e 3e63 3e64 1 3e66 3e6b 3e6f
3e73 3e76 3e7b 3e80 3e83 3e87 3e88 3e8d
3e8e 3e93 3e95 3e99 3e9c 3ea0 3ea4 3ea7
3eab 3eaf 3eb2 3eb6 3eba 3ebb 3ec0 3ec4
3ec6 3eca 3ece 3ed1 3ed5 3ed8 3edc 3edf
3ee0 3ee5 3ee8 3eec 3ef0 3ef3 3ef6 3ef7
3ef9 3efc 3f01 3f02 3f07 3f0b 3f0f 3f12
3f13 3f15 3f18 3f1b 3f1c 3f21 3f25 3f29
3f2c 3f2d 3f2f 3f33 3f36 3f3a 3f3d 3f3e
3f40 3f41 1 3f46 3f4b 1 3f4e 3f53
3f57 3f5b 3f5e 3f62 3f66 3f69 3f6c 3f71
3f74 3f77 3f7a 3f7b 3f80 3f81 1 3f83
3f88 3f8c 3f90 3f93 3f98 3f9d 3fa0 3fa4
3fa5 3faa 3fad 3fb2 3fb3 3fb8 3fbb 3fc0
3fc1 3fc6 3fc9 3fcd 3fd1 3fd5 3fd9 3fdc
3fdd 3fdf 3fe4 3fe5 3fe7 3fe8 3fed 3ff0
3ff5 3ff6 3ffb 3ffe 4003 4004 4009 400c
4010 4011 4016 4019 401e 401f 4024 4025
402a 402c 4030 4033 4037 403b 403e 4042
4046 4049 404c 4051 4054 4057 405a 405b
4060 4061 1 4063 4068 406c 4070 4073
4078 407d 4080 4084 4085 408a 408b 4090
4092 4096 4099 409d 40a1 40a4 40a8 40ac
40af 40b3 40b7 40b8 40bd 40bf 40c3 40c6
40ca 40ce 40d1 40d2 40d4 40d8 40db 40df
40e2 40e3 40e5 40e6 40eb 40ef 40f3 40f7
40fb 40ff 4103 4107 410b 410f 411b 411f
4123 4126 412a 412e 4130 4134 4138 413c
413f 4143 4147 4149 414a 414f 1 4153
4157 415b 415e 4162 4166 416a 416e 4171
4175 4179 417c 417f 4184 4187 418a 418d
418e 4193 4194 1 4196 419b 419f 41a3
41a6 41ab 41b0 41b3 41b7 41b8 41bd 41c0
41c5 41c6 41cb 41ce 41d3 41d4 41d9 41dc
41e0 41e1 41e6 41e9 41ee 41ef 41f4 41f7
41fb 41ff 4202 4205 4206 4208 4209 420e
420f 4214 4216 421a 421d 421f 4223 4225
4231 4233 4235 4236 423b 423f 4241 424d
424f 4251 4255 4258 425a 425e 4262 4265
4267 426b 426e 4270 4274 4277 427b 427f
4282 4283 4285 4288 428b 428c 4291 4295
4299 429c 429d 429f 42a3 42a6 42aa 42ad
42ae 42b3 42b7 42ba 42bb 42c0 1 42c3
42c8 42cc 42d0 42d3 42d4 42d6 42d9 42dc
42dd 1 42e2 42e7 42eb 42ef 42f2 42f6
42fa 42fd 4300 4305 4308 430b 430e 430f
4314 4315 1 4317 431c 4320 4324 4327
432c 4331 4334 4338 4339 433e 4341 4346
4347 434c 434f 4354 4355 435a 435d 4361
4365 4369 436d 4370 4371 4373 4378 4379
437b 437c 4381 4384 4389 438a 438f 4392
4397 4398 439d 43a0 43a4 43a5 43aa 43ad
43b2 43b3 43b8 43b9 43be 43c0 43c4 43c7
43cb 43cf 43d2 43d6 43da 43dd 43e0 43e5
43e8 43eb 43ee 43ef 43f4 43f5 1 43f7
43fc 4400 4404 4407 440c 4411 4414 4418
4419 441e 441f 4424 4426 442a 442d 4431
4435 4438 443c 4440 4443 4447 444b 444c
4451 4453 4457 445a 445e 4462 4465 4466
4468 446c 446f 4473 4476 4477 447c 4480
4484 4488 448c 4490 4494 4498 449c 44a0
44a4 44a8 44b4 44b8 44bc 44bf 44c3 44c7
44c9 44cd 44d1 44d5 44d8 44dc 44e0 44e2
44e3 44e8 1 44ec 44f0 44f4 44f7 44fb
44ff 4503 4507 450a 450e 4512 4515 4518
451d 4520 4523 4526 4527 452c 452d 1
452f 4534 4538 453c 453f 4544 4549 454c
4550 4551 4556 4559 455e 455f 4564 4567
456c 456d 4572 4575 4579 457a 457f 4582
4587 4588 458d 4590 4594 4598 459b 459e
459f 45a1 45a2 45a7 45a8 45ad 45af 45b3
45b6 45b8 45bc 45be 45ca 45cc 45ce 45cf
45d4 45d8 45da 45e6 45e8 45ec 45f0 45f3
45f7 45fa 45fe 4601 4602 4607 460a 460e
4612 4616 461a 461e 462a 462e 4632 4635
4639 463d 463f 4643 4647 464b 464e 4652
4656 4658 4659 465e 1 4662 4666 466a
466d 4671 4675 4679 467d 4680 4684 4688
468b 468e 4693 4696 4699 469c 469d 46a2
46a3 1 46a5 46aa 46ae 46b2 46b5 46ba
46bf 46c2 46c6 46c7 46cc 46cf 46d4 46d5
46da 46dd 46e2 46e3 46e8 46eb 46ef 46f0
46f5 46f8 46fd 46fe 4703 4706 470a 470e
4711 4714 4715 4717 4718 471d 471e 4723
4725 4729 472c 472e 4732 4734 4740 4742
4744 4745 474a 474e 4750 475c 475e 4762
4766 4769 476d 4770 4774 4777 4778 477d
4780 4784 4788 478b 478f 4793 4796 4799
479e 47a1 47a4 47a7 47a8 47ad 47ae 1
47b0 47b5 47b9 47bd 47c0 47c5 47ca 47cd
47d1 47d2 47d7 47da 47df 47e0 47e5 47e8
47ed 47ee 47f3 47f6 47fa 47fe 4802 4806
4809 480a 480c 4811 4812 4814 4815 481a
481d 4822 4823 4828 482b 4830 4831 4836
4839 483d 483e 4843 4846 484b 484c 4851
4852 4857 4859 485d 4860 4864 4868 486b
486f 4873 4876 4879 487e 4881 4884 4887
4888 488d 488e 1 4890 4895 4899 489d
48a0 48a5 48aa 48ad 48b1 48b2 48b7 48b8
48bd 48bf 48c3 48c6 48ca 48ce 48d1 48d5
48d9 48dc 48e0 48e4 48e5 48ea 48ec 48f0
48f3 48f5 48f9 48fc 48fe 4902 4905 4907
490b 490e 4912 4916 4919 491a 491c 491f
4922 4923 4928 492c 4930 4933 4934 4936
4939 493c 493d 1 4942 4947 494b 494e
4952 4954 4958 495b 495f 4963 4966 4967
4969 496d 4970 4974 4977 4978 497d 4981
4984 4985 498a 498d 4991 4996 499a 499e
49a3 49a7 49a9 49ad 49b1 49b5 49b9 49bd
49c1 49c3 49c7 49cb 49ce 49d2 49d5 49d9
49db 49df 49e2 49e5 49e6 49eb 49ef 49f4
49f8 49fc 4a00 4a04 4a08 4a0c 4a10 4a13
4a14 4a16 4a1a 4a1e 4a21 4a22 4a24 4a28
4a2c 4a2f 4a30 4a32 4a36 4a3a 4a3d 4a3e
4a40 4a44 4a48 4a4b 4a4c 4a4e 4a52 4a56
4a59 4a5a 4a5c 4a60 4a64 4a67 4a68 4a6a
4a6e 4a72 4a75 4a76 4a78 4a7c 4a80 4a84
4a85 4a87 4a8b 4a8f 4a93 4a96 4a97 4a99
4a9d 4aa0 4aa4 4aa7 4aa8 4aad 4ab1 4ab5
4ab8 4abc 4ac0 4ac3 4ac6 4acb 4ace 4ad1
4ad4 4ad5 4ada 4adb 1 4add 4ae2 4ae6
4aea 4aed 4af2 4af7 4afa 4afe 4aff 4b04
4b07 4b0c 4b0d 4b12 4b15 4b1a 4b1b 4b20
4b23 4b27 4b2b 4b2f 4b33 4b36 4b37 4b39
4b3e 4b3f 4b41 4b42 4b47 4b48 4b4d 4b4f
4b53 4b56 4b5a 4b5e 4b61 4b65 4b69 4b6c
4b6f 4b74 4b77 4b7a 4b7d 4b7e 4b83 4b84
1 4b86 4b8b 4b8f 4b93 4b96 4b9b 4ba0
4ba3 4ba7 4ba8 4bad 4bae 4bb3 4bb5 4bb9
4bbc 4bc0 4bc4 4bc7 4bcb 4bcf 4bd2 4bd6
4bd7 4bdc 4be0 4be2 4be6 4bea 4bed 4bee
4bf0 4bf3 4bf6 4bf7 4bfc 4c00 4c04 4c07
4c0b 4c0f 4c12 4c15 4c1a 4c1d 4c20 4c23
4c24 4c29 4c2a 1 4c2c 4c31 4c35 4c39
4c3c 4c41 4c46 4c49 4c4d 4c4e 4c53 4c56
4c5b 4c5c 4c61 4c64 4c69 4c6a 4c6f 4c72
4c76 4c7a 4c7e 4c7f 4c81 4c86 4c87 4c89
4c8a 4c8f 4c92 4c97 4c98 4c9d 4ca0 4ca5
4ca6 4cab 4cae 4cb2 4cb3 4cb8 4cbb 4cc0
4cc1 4cc6 4cc7 4ccc 4cce 4cd2 4cd5 4cd9
4cdd 4ce0 4ce4 4ce8 4ceb 4cee 4cf3 4cf6
4cf9 4cfc 4cfd 4d02 4d03 1 4d05 4d0a
4d0e 4d12 4d15 4d1a 4d1f 4d22 4d26 4d27
4d2c 4d2d 4d32 4d34 4d38 4d3b 4d3f 4d43
4d46 4d4a 4d4e 4d51 4d52 4d54 4d58 4d5c
4d5d 4d62 4d64 4d68 4d6c 4d6f 4d71 4d75
4d79 4d7d 4d7f 4d83 4d87 4d8a 4d8e 4d92
4d95 4d96 4d98 4d9b 4d9e 4d9f 4da4 4da7
4dab 4daf 4db2 4db3 4db5 4db8 4dbb 4dbc
4dc1 1 4dc4 4dc9 4dcd 4dd1 4dd4 4dd5
4dd7 4dda 4ddd 4dde 4de3 4de6 4dea 4dee
4df1 4df2 4df4 4df7 4dfa 4dfb 4e00 1
4e03 4e08 4e0c 4e0f 4e13 4e17 4e19 4e1d
4e21 4e24 4e25 4e27 4e2a 4e2d 4e2e 4e33
4e37 4e3a 4e3e 4e42 4e44 4e48 4e4c 4e50
4e53 4e54 4e56 4e59 4e5c 4e5d 4e62 4e65
4e69 4e6d 4e70 4e71 4e73 4e76 4e79 4e7a
4e7f 1 4e82 4e87 4e8b 4e8e 4e92 4e96
4e98 4e9c 4ea0 4ea4 4ea7 4ea8 4eaa 4ead
4eb0 4eb1 4eb6 4eba 4ebd 4ec1 4ec3 4ec7
4ecb 4ece 4ed0 4ed4 4ed7 4ed9 4edd 4ee1
4ee4 4ee8 4eec 4eef 4ef0 4ef2 4ef6 4ef9
4efd 4f00 4f01 4f06 4f0a 4f0d 4f11 4f15
4f19 4f1d 4f21 4f25 4f29 4f2d 4f31 4f35
4f38 4f3b 4f3c 4f3e 4f42 4f46 4f47 4f4b
4f4f 4f53 4f56 4f57 4f59 4f5c 4f5f 4f60
4f65 4f69 4f6d 4f6e 4f73 4f77 4f7b 4f7e
4f82 4f84 4f88 4f8c 4f90 4f94 4f98 4fa4
4fa8 4fac 4faf 4fb3 4fb7 4fb9 4fbd 4fc1
4fc5 4fc8 4fcc 4fd0 4fd2 4fd3 4fd8 1
4fdc 4fe0 4fe4 4fe7 4feb 4fef 4ff3 4ff7
4ffa 4ffe 5002 5005 5008 500d 5010 5013
5016 5017 501c 501d 1 501f 5024 5028
502c 502f 5034 5039 503c 5040 5041 5046
5049 504e 504f 5054 5057 505c 505d 5062
5065 5069 506a 506f 5072 5077 5078 507d
5080 5084 5088 508b 508e 508f 5091 5092
5097 5098 509d 509f 50a3 50a6 50a8 50ac
50ae 50ba 50bc 50be 50bf 50c4 50c8 50ca
50d6 50d8 50dc 50e0 50e3 50e7 50ea 50ee
50f1 50f2 50f7 50fa 50fe 5102 5105 5106
5108 510b 510e 510f 5114 5118 511c 5120
5124 5128 512c 5130 5134 5138 513c 5140
514c 5150 5154 5157 515b 515f 5161 5165
5169 516d 5170 5174 5178 517a 517b 5180
1 5184 5188 518c 518f 5193 5197 519b
519f 51a2 51a6 51aa 51ad 51b0 51b5 51b8
51bb 51be 51bf 51c4 51c5 1 51c7 51cc
51d0 51d4 51d7 51dc 51e1 51e4 51e8 51e9
51ee 51f1 51f6 51f7 51fc 51ff 5204 5205
520a 520d 5211 5212 5217 521a 521f 5220
5225 5228 522c 5230 5233 5236 5237 5239
523a 523f 5240 5245 5247 524b 524e 5250
5254 5256 5262 5264 5266 5267 526c 5270
5272 527e 5280 5282 5286 5289 528b 528f
5292 5296 5298 529c 52a0 52a3 52a5 52a9
52ad 52b0 52b4 52b7 52ba 52bb 52c0 52c4
52c8 52cc 52d0 52d4 52d8 52dc 52e0 52e4
52f0 52f4 52f8 52fb 52ff 5303 5305 5309
530d 5311 5314 5318 531c 531e 531f 5324
1 5328 532c 5330 5333 5337 533b 533f
5343 5346 534a 534e 5351 5354 5359 535c
535f 5362 5363 5368 5369 1 536b 5370
5374 5378 537b 5380 5385 5388 538c 538d
5392 5395 539a 539b 53a0 53a3 53a8 53a9
53ae 53b1 53b5 53b6 53bb 53be 53c3 53c4
53c9 53cc 53d0 53d4 53d7 53da 53db 53dd
53de 53e3 53e4 53e9 53eb 53ef 53f2 53f4
53f8 53fa 5406 5408 540a 540b 5410 5414
5416 5422 5424 5428 542c 5430 5434 5438
543c 5440 5444 5448 544c 5450 5454 5458
545c 5460 5464 5468 546c 5470 5474 5478
547c 5480 5484 5488 548c 5490 5494 5498
549c 54a0 54ac 54b0 54b4 54b7 54bb 54bf
54c1 54c5 54c9 54cd 54d0 54d4 54d8 54da
54db 54e0 1 54e4 54e8 54ec 54ef 54f3
54f7 54fb 54ff 5502 5506 550a 550d 5510
5515 5518 551b 551e 551f 5524 5525 1
5527 552c 5530 5534 5537 553c 5541 5544
5548 5549 554e 5551 5556 5557 555c 555f
5564 5565 556a 556d 5571 5572 5577 557a
557f 5580 5585 5588 558c 5590 5593 5596
5597 5599 559a 559f 55a0 55a5 55a7 55ab
55ae 55b0 55b4 55b6 55c2 55c4 55c6 55c7
55cc 55d0 55d2 55de 55e0 55e4 55e8 55eb
55ef 55f2 55f6 55f9 55fa 55ff 5602 5606
560a 560d 5611 5615 5618 561b 5620 5623
5626 5629 562a 562f 5630 1 5632 5637
563b 563f 5642 5647 564c 564f 5653 5654
5659 565c 5661 5662 5667 566a 566f 5670
5675 5678 567c 5680 5684 5688 568b 568c
568e 5693 5694 5696 5697 569c 569f 56a4
56a5 56aa 56ad 56b2 56b3 56b8 56bb 56bf
56c0 56c5 56c8 56cd 56ce 56d3 56d4 56d9
56db 56df 56e2 56e6 56ea 56ed 56f1 56f5
56f8 56fb 5700 5703 5706 5709 570a 570f
5710 1 5712 5717 571b 571f 5722 5727
572c 572f 5733 5734 5739 573a 573f 5741
5745 5748 574c 5750 5753 5757 575b 575e
5762 5766 5767 576c 576e 5772 5775 5779
577d 5780 5781 5783 5786 5789 578a 578f
5793 5798 579c 579e 57a2 57a7 57ab 57ad
57b1 57b5 57b8 57bc 57c0 57c4 57c8 57cc
57d0 57d4 57d8 57dc 57e0 57e4 57e8 57ec
57f0 57f4 57f8 57fc 5800 5804 5810 5814
5819 581d 5820 5821 5826 582a 582e 5831
5834 5838 583a 583e 5842 5845 5848 584c
584e 5852 5856 5859 585b 585f 5863 5867
586a 586e 5872 5874 5875 587a 1 587e
5882 5886 5889 588d 5891 5895 5899 589c
58a0 58a4 58a7 58aa 58af 58b2 58b5 58b8
58b9 58be 58bf 1 58c1 58c6 58ca 58ce
58d1 58d6 58db 58de 58e2 58e3 58e8 58eb
58f0 58f1 58f6 58f9 58fe 58ff 5904 5907
590b 590c 5911 5914 5919 591a 591f 5922
5926 592a 592d 5930 5931 5933 5934 5939
593a 593f 5941 5945 5948 594a 594e 5950
595c 595e 5960 5961 5966 596a 596c 5978
597a 597e 5980 5984 5988 598b 598e 598f
5991 5994 5999 599a 599f 59a3 59a7 59ab
59af 59b3 59b7 59bb 59bf 59c3 59c7 59d3
59d7 59dc 59e0 59e3 59e4 59e9 59ed 59f1
59f4 59f7 59fb 59fd 5a01 5a05 5a08 5a0b
5a0f 5a11 5a15 5a19 5a1c 5a1e 5a22 5a26
5a2a 5a2d 5a31 5a35 5a37 5a38 5a3d 1
5a41 5a45 5a49 5a4c 5a50 5a54 5a58 5a5c
5a5f 5a63 5a67 5a6a 5a6d 5a72 5a75 5a78
5a7b 5a7c 5a81 5a82 1 5a84 5a89 5a8d
5a91 5a94 5a99 5a9e 5aa1 5aa5 5aa6 5aab
5aae 5ab3 5ab4 5ab9 5abc 5ac1 5ac2 5ac7
5aca 5ace 5acf 5ad4 5ad7 5adc 5add 5ae2
5ae5 5ae9 5aed 5af0 5af3 5af4 5af6 5af7
5afc 5afd 5b02 5b04 5b08 5b0b 5b0d 5b11
5b13 5b1f 5b21 5b23 5b24 5b29 5b2d 5b2f
5b3b 5b3d 5b3f 5b43 5b47 5b4a 5b4e 5b52
5b56 5b5a 5b5e 5b62 5b66 5b6a 5b6e 5b7a
5b7e 5b83 5b87 5b8a 5b8b 5b90 5b94 5b98
5b9b 5b9e 5ba2 5ba4 5ba8 5bac 5baf 5bb2
5bb6 5bb8 5bbc 5bc0 5bc3 5bc5 5bc9 5bcd
5bd1 5bd4 5bd8 5bdc 5bde 5bdf 5be4 1
5be8 5bec 5bf0 5bf3 5bf7 5bfb 5bff 5c03
5c06 5c0a 5c0e 5c11 5c14 5c19 5c1c 5c1f
5c22 5c23 5c28 5c29 1 5c2b 5c30 5c34
5c38 5c3b 5c40 5c45 5c48 5c4c 5c4d 5c52
5c55 5c5a 5c5b 5c60 5c63 5c68 5c69 5c6e
5c71 5c75 5c76 5c7b 5c7e 5c83 5c84 5c89
5c8c 5c90 5c94 5c97 5c9a 5c9b 5c9d 5c9e
5ca3 5ca4 5ca9 5cab 5caf 5cb2 5cb4 5cb8
5cba 5cc6 5cc8 5cca 5ccb 5cd0 5cd4 5cd6
5ce2 5ce4 5ce8 5cec 5cf0 5cf4 5cf8 5cfc
5d00 5d04 5d08 5d14 5d18 5d1d 5d21 5d24
5d25 5d2a 5d2e 5d32 5d35 5d38 5d3c 5d3e
5d42 5d46 5d49 5d4c 5d50 5d52 5d56 5d5a
5d5d 5d5f 5d63 5d67 5d6b 5d6e 5d72 5d76
5d78 5d79 5d7e 1 5d82 5d86 5d8a 5d8d
5d91 5d95 5d99 5d9d 5da0 5da4 5da8 5dab
5dae 5db3 5db6 5db9 5dbc 5dbd 5dc2 5dc3
1 5dc5 5dca 5dce 5dd2 5dd5 5dda 5ddf
5de2 5de6 5de7 5dec 5def 5df4 5df5 5dfa
5dfd 5e02 5e03 5e08 5e0b 5e0f 5e10 5e15
5e18 5e1d 5e1e 5e23 5e26 5e2a 5e2e 5e31
5e34 5e35 5e37 5e38 5e3d 5e3e 5e43 5e45
5e49 5e4c 5e4e 5e52 5e54 5e60 5e62 5e64
5e65 5e6a 5e6e 5e70 5e7c 5e7e 5e82 5e86
5e8a 5e8e 5e92 5e96 5ea2 5ea6 5eab 5eaf
5eb2 5eb3 5eb8 5ebc 5ec0 5ec3 5ec6 5eca
5ecc 5ed0 5ed4 5ed7 5eda 5ede 5ee0 5ee4
5ee8 5eeb 5eed 5ef1 5ef5 5ef9 5efc 5f00
5f04 5f06 5f07 5f0c 1 5f10 5f14 5f18
5f1b 5f1f 5f23 5f27 5f2b 5f2e 5f32 5f36
5f39 5f3c 5f41 5f44 5f47 5f4a 5f4b 5f50
5f51 1 5f53 5f58 5f5c 5f60 5f63 5f68
5f6d 5f70 5f74 5f75 5f7a 5f7d 5f82 5f83
5f88 5f8b 5f90 5f91 5f96 5f99 5f9d 5f9e
5fa3 5fa6 5fab 5fac 5fb1 5fb4 5fb8 5fbc
5fbf 5fc2 5fc3 5fc5 5fc6 5fcb 5fcc 5fd1
5fd3 5fd7 5fda 5fdc 5fe0 5fe2 5fee 5ff0
5ff2 5ff3 5ff8 5ffc 5ffe 600a 600c 600e
6012 6015 6019 601d 601e 6023 6027 602b
602f 6032 6033 6035 6038 603b 603c 6041
6045 6049 604c 604d 604f 6053 6056 605a
605d 605e 1 6063 6068 606c 6070 6073
6074 6076 607a 607d 6081 6084 6085 1
608a 608f 6093 6096 6097 609c 609f 60a3
60a7 60ab 60ad 60b1 60b4 60b6 60ba 60bd
60c1 60c5 60c8 60c9 60cb 60ce 60d1 60d2
60d7 60db 60df 60e3 60e6 60ea 60ec 60f0
60f3 60f7 60fa 60fb 6100 6103 6107 610a
610b 6110 1 6113 6118 611c 611f 6120
6125 1 6128 612d 6131 6134 6135 613a
613d 1 6140 6145 6149 614c 6150 6152
6156 6159 615d 6162 6166 616a 616f 6173
6177 617b 617e 617f 6181 6184 6187 6188
618d 6191 6195 6198 6199 619b 619f 61a2
61a6 61a9 61aa 61af 61b3 61b8 61bb 61bf
61c0 61c5 61c8 61cd 61ce 61d3 61d6 61db
61dc 61e1 61e4 61e9 61ea 61ef 61f2 61f7
61f8 61fd 6200 6204 6205 620a 620d 6212
6213 6218 621c 6220 6222 6226 622a 622d
622e 6230 6233 6236 6237 623c 6240 6245
6248 624d 624e 6253 6256 625b 625c 6261
6264 6268 6269 626e 6271 6276 6277 627c
627f 6284 6285 628a 628d 6291 6292 6297
629a 629f 62a0 62a5 62a8 62ad 62ae 62b3
62b7 62b9 62bd 62c1 62c6 62c9 62ce 62cf
62d4 62d7 62dc 62dd 62e2 62e5 62ea 62eb
62f0 62f3 62f7 62f8 62fd 6300 6305 6306
630b 630f 6311 6315 6319 631c 631e 6322
6326 6329 632a 632c 6330 6333 6337 633a
633b 6340 6344 6348 634b 634c 634e 6352
6355 6359 635c 635d 1 6362 6367 636b
636f 6372 6373 6375 6379 637c 6380 6383
6384 1 6389 638e 6392 6396 639b 63a0
63a4 63a8 63ac 63af 63b2 63b6 63ba 63bd
63be 63c3 63c6 63ca 63ce 63d3 63d8 63dc
63e0 63e4 63e7 63ea 63ee 63f2 63f6 63fa
63fe 6402 6406 640a 640e 6412 6416 641a
641e 6422 6426 642a 642e 6432 6436 643a
643e 6442 6446 644a 6456 645a 645f 6463
6466 6467 646c 6470 6474 6477 647a 647e
6480 6484 6488 648b 648e 6492 6494 6498
649c 649f 64a1 64a5 64a9 64ad 64b0 64b4
64b8 64ba 64bb 64c0 1 64c4 64c8 64cc
64cf 64d3 64d7 64db 64df 64e2 64e6 64ea
64ed 64f0 64f5 64f8 64fb 64fe 64ff 6504
6505 1 6507 650c 6510 6514 6517 651c
6521 6524 6528 6529 652e 6531 6536 6537
653c 653f 6544 6545 654a 654d 6551 6552
6557 655a 655f 6560 6565 6568 656c 6570
6573 6576 6577 6579 657a 657f 6580 6585
6587 658b 658e 6590 6594 6596 65a2 65a4
65a6 65a7 65ac 65b0 65b2 65be 65c0 65c4
65c8 65cc 65d0 65d4 65d8 65dc 65e0 65e4
65e8 65ec 65f0 65f4 65f8 65fc 6600 6604
6608 660c 6610 6614 6620 6624 6629 662d
6630 6631 6636 663a 663e 6641 6644 6648
664a 664e 6652 6655 6658 665c 665e 6662
6666 6669 666b 666f 6673 6677 667a 667e
6682 6684 6685 668a 1 668e 6692 6696
6699 669d 66a1 66a5 66a9 66ac 66b0 66b4
66b7 66ba 66bf 66c2 66c5 66c8 66c9 66ce
66cf 1 66d1 66d6 66da 66de 66e1 66e6
66eb 66ee 66f2 66f3 66f8 66fb 6700 6701
6706 6709 670e 670f 6714 6717 671b 671c
6721 6724 6729 672a 672f 6732 6736 673a
673d 6740 6741 6743 6744 6749 674a 674f
6751 6755 6758 675a 675e 6760 676c 676e
6770 6771 6776 677a 677c 6788 678a 678c
6790 6794 6798 679a 679e 67a2 67a5 67a7
67ab 67ae 67b2 67b5 67b6 67bb 67be 67c2
67c6 67ca 67ce 67cf 67d1 67d4 67d5 67d7
67da 67dd 67de 67e3 67e7 67eb 67ef 67f3
67f4 67f6 67f9 67fa 67fc 67ff 6800 6802
6805 6808 6809 680e 680f 6811 6815 6819
681d 6821 6822 6824 6827 6828 682a 682d
682e 6830 6832 6836 683a 683e 6841 6845
6849 684d 6851 6854 6858 6859 685e 6860
6864 6868 686c 6870 6874 6877 687a 687b
6880 6883 6884 6886 6887 6889 688c 688d
688f 6892 6895 6896 689b 689f 68a3 68a7
68ab 68af 68b2 68b5 68b6 68bb 68be 68bf
68c1 68c2 68c4 68c7 68c8 68ca 68cd 68d0
68d1 1 68d6 68db 68df 68e5 68e7 68eb
68ee 68f2 68f6 68f9 68fc 68fd 6902 6906
6908 690c 6913 6917 691b 691e 691f 6924
6928 692c 692f 6933 6937 693a 693d 6942
6945 6948 694b 694c 6951 6952 1 6954
6959 695d 6961 6964 6969 696e 6971 6975
6976 697b 697e 6983 6984 6989 698c 6991
6992 6997 699a 699e 69a2 69a6 69aa 69ad
69ae 69b0 69b5 69b6 69b8 69b9 69be 69bf
69c4 69c6 69ca 69cd 69d1 69d5 69d8 69dc
69e0 69e3 69e6 69eb 69ee 69f1 69f4 69f5
69fa 69fb 1 69fd 6a02 6a06 6a0a 6a0d
6a12 6a17 6a1a 6a1e 6a1f 6a24 6a25 6a2a
6a2c 6a30 6a33 6a37 6a3b 6a3e 6a42 6a46
6a49 6a4d 6a4e 6a53 6a55 6a59 6a5c 6a60
6a64 6a68 6a6c 6a78 6a7c 6a80 6a83 6a87
6a8b 6a8d 6a91 6a95 6a99 6a9c 6aa0 6aa4
6aa6 6aa7 6aac 1 6ab0 6ab4 6ab8 6abb
6abf 6ac3 6ac7 6acb 6ace 6ad2 6ad6 6ad9
6adc 6ae1 6ae4 6ae7 6aea 6aeb 6af0 6af1
1 6af3 6af8 6afc 6b00 6b03 6b08 6b0d
6b10 6b14 6b15 6b1a 6b1d 6b22 6b23 6b28
6b2b 6b30 6b31 6b36 6b39 6b3d 6b3e 6b43
6b46 6b4b 6b4c 6b51 6b54 6b58 6b5c 6b5f
6b62 6b63 6b65 6b66 6b6b 6b6c 6b71 6b73
6b77 6b7a 6b7c 6b80 6b82 6b8e 6b90 6b92
6b93 6b98 6b9c 6b9e 6baa 6bac 6bae 6bb2
6bb5 6bb9 6bbd 6bc0 6bc1 6bc3 6bc7 6bca
6bce 6bd1 6bd2 6bd7 6bdb 6be0 6be4 6be8
6bed 6bf1 6bf5 6bf9 6bfc 6c00 6c01 6c06
6c0a 6c0e 6c12 6c15 6c1a 6c1b 6c20 6c24
6c28 6c2a 6c2e 6c32 6c35 6c36 6c38 6c3c
6c3f 6c43 6c46 6c47 6c4c 6c50 6c55 6c59
6c5d 6c61 6c64 6c68 6c69 6c6e 6c72 6c76
6c7a 6c7d 6c82 6c83 6c88 6c8c 6c90 6c95
6c99 6c9b 6c9f 6ca3 6ca7 6caa 6cab 6cad
6cb1 6cb4 6cb8 6cbb 6cbc 6cc1 6cc5 6cca
6cce 6cd2 6cd7 6cdb 6cdf 6ce2 6ce3 6ce8
6ceb 6cef 6cf3 6cf6 6cfb 6cfc 6d01 6d05
6d09 6d0d 6d10 6d14 6d15 6d1a 6d1e 6d22
6d26 6d29 6d2e 6d2f 6d34 6d38 6d3a 6d3e
6d41 6d45 6d49 6d4c 6d51 6d52 6d57 6d5b
6d5f 6d62 6d63 6d68 6d6b 6d6f 6d73 6d76
6d7b 6d7c 6d81 6d85 6d89 6d8d 6d90 6d94
6d95 6d9a 6d9e 6da2 6da6 6da9 6dae 6daf
6db4 6db8 6dba 6dbe 6dc1 6dc3 6dc7 6dca
6dcb 6dd0 6dd3 6dd7 6ddb 6dde 6de3 6de4
6de9 6ded 6df1 6df6 6dfa 6dfc 6e00 6e04
6e07 6e0c 6e0d 6e12 6e15 6e1a 6e1b 6e20
6e24 6e28 6e2d 6e31 6e35 6e38 6e39 6e3e
6e41 6e45 6e49 6e4c 6e51 6e52 6e57 6e5b
6e5f 6e63 6e66 6e6a 6e6b 6e70 6e74 6e78
6e7c 6e7f 6e84 6e85 6e8a 6e8e 6e90 6e94
6e97 6e9b 6e9f 6ea2 6ea7 6ea8 6ead 6eb0
6eb5 6eb6 6ebb 6ebe 6ec3 6ec4 6ec9 6ecc
6ed1 6ed2 6ed7 6eda 6edf 6ee0 6ee5 6ee8
6eed 6eee 6ef3 6ef7 6ef9 6efd 6f01 6f04
6f08 6f0b 6f0c 6f11 6f14 6f18 6f1c 6f1f
6f24 6f25 6f2a 6f2d 6f31 6f32 6f37 6f3a
6f3f 6f40 6f45 6f49 6f4b 6f4f 6f52 6f54
6f58 6f5c 6f5f 6f61 6f65 6f69 6f6c 6f70
6f74 6f77 6f78 6f7a 6f7e 6f81 6f85 6f88
6f89 6f8e 6f92 6f95 6f96 6f9b 6f9e 6fa2
6fa6 6faa 6fae 6fb2 6fbe 6fc2 6fc6 6fc9
6fcd 6fd1 6fd3 6fd7 6fdb 6fdf 6fe2 6fe6
6fea 6fec 6fed 6ff2 1 6ff6 6ffa 6ffe
7001 7005 7009 700d 7011 7014 7018 701c
701f 7022 7027 702a 702d 7030 7031 7036
7037 1 7039 703e 7042 7046 7049 704e
7053 7056 705a 705b 7060 7063 7068 7069
706e 7071 7076 7077 707c 707f 7083 7084
7089 708c 7091 7092 7097 709a 709e 70a2
70a5 70a8 70a9 70ab 70ac 70b1 70b2 70b7
70b9 70bd 70c0 70c2 70c6 70c8 70d4 70d6
70d8 70d9 70de 70e2 70e4 70f0 70f2 70f6
70fa 70fd 7101 7104 7108 710b 710c 7111
7114 7118 711c 7120 7124 7125 7127 712a
712b 712d 7131 7135 7139 713c 7141 7142
7147 714b 714f 7153 7156 715b 715c 7161
7164 7169 716a 716f 7172 7176 7177 717c
717f 7184 7185 718a 718e 7190 7194 7198
719b 719f 71a3 71a6 71a9 71ae 71b1 71b4
71b7 71b8 71bd 71be 1 71c0 71c5 71c9
71cd 71d0 71d5 71da 71dd 71e1 71e2 71e7
71ea 71ef 71f0 71f5 71f8 71fd 71fe 7203
7206 720a 720e 7212 7216 7219 721a 721c
7221 7222 7224 7225 722a 722d 7232 7233
7238 723b 7240 7241 7246 7249 724d 724e
7253 7256 725b 725c 7261 7262 7267 7269
726d 7270 7274 7278 727b 727f 7283 7286
7289 728e 7291 7294 7297 7298 729d 729e
1 72a0 72a5 72a9 72ad 72b0 72b5 72ba
72bd 72c1 72c2 72c7 72c8 72cd 72cf 72d3
72d6 72da 72de 72e1 72e5 72e9 72ec 72f0
72f4 72f5 72fa 72fc 7300 7304 7307 7309
730d 7310 7314 7317 7318 731d 7320 7324
7328 732c 7330 7334 7340 7344 7348 734b
734f 7353 7355 7359 735d 7361 7364 7368
736c 736e 736f 7374 1 7378 737c 7380
7383 7387 738b 738f 7393 7396 739a 739e
73a1 73a4 73a9 73ac 73af 73b2 73b3 73b8
73b9 1 73bb 73c0 73c4 73c8 73cb 73d0
73d5 73d8 73dc 73dd 73e2 73e5 73ea 73eb
73f0 73f3 73f8 73f9 73fe 7401 7405 7406
740b 740e 7413 7414 7419 741c 7420 7424
7427 742a 742b 742d 742e 7433 7434 7439
743b 743f 7442 7444 7448 744a 7456 7458
745a 745b 7460 7464 7466 7472 7474 7478
747c 747f 7483 7486 748a 748d 748e 7493
7496 749a 749e 74a1 74a6 74a7 74ac 74b0
74b4 74b8 74bb 74c0 74c1 74c6 74c9 74ce
74cf 74d4 74d7 74db 74dc 74e1 74e4 74e9
74ea 74ef 74f3 74f5 74f9 74fd 7500 7504
7508 750b 750e 7513 7516 7519 751c 751d
7522 7523 1 7525 752a 752e 7532 7535
753a 753f 7542 7546 7547 754c 754f 7554
7555 755a 755d 7562 7563 7568 756b 756f
7573 7577 757b 757e 757f 7581 7586 7587
7589 758a 758f 7592 7597 7598 759d 75a0
75a5 75a6 75ab 75ae 75b2 75b3 75b8 75bb
75c0 75c1 75c6 75c7 75cc 75ce 75d2 75d5
75d9 75dd 75e0 75e4 75e8 75eb 75ee 75f3
75f6 75f9 75fc 75fd 7602 7603 1 7605
760a 760e 7612 7615 761a 761f 7622 7626
7627 762c 762d 7632 7634 7638 763b 763f
7643 7646 764a 764e 7651 7655 7659 765a
765f 7661 7665 7669 766c 766e 7672 7675
7679 767c 767d 7682 7685 7689 768d 7691
7695 7699 76a5 76a9 76ad 76b0 76b4 76b8
76ba 76be 76c2 76c6 76c9 76cd 76d1 76d3
76d4 76d9 1 76dd 76e1 76e5 76e8 76ec
76f0 76f4 76f8 76fb 76ff 7703 7706 7709
770e 7711 7714 7717 7718 771d 771e 1
7720 7725 7729 772d 7730 7735 773a 773d
7741 7742 7747 774a 774f 7750 7755 7758
775d 775e 7763 7766 776a 776b 7770 7773
7778 7779 777e 7781 7785 7789 778c 778f
7790 7792 7793 7798 7799 779e 77a0 77a4
77a7 77a9 77ad 77af 77bb 77bd 77bf 77c0
77c5 77c9 77cb 77d7 77d9 77dd 77e1 77e4
77e8 77eb 77ef 77f2 77f3 77f8 77fb 77ff
7803 7806 780b 780c 7811 7815 7819 781d
7820 7825 7826 782b 782e 7833 7834 7839
783c 7840 7841 7846 7849 784e 784f 7854
7858 785a 785e 7862 7865 7869 786d 7870
7873 7878 787b 787e 7881 7882 7887 7888
1 788a 788f 7893 7897 789a 789f 78a4
78a7 78ab 78ac 78b1 78b4 78b9 78ba 78bf
78c2 78c7 78c8 78cd 78d0 78d4 78d8 78dc
78e0 78e3 78e4 78e6 78eb 78ec 78ee 78ef
78f4 78f7 78fc 78fd 7902 7905 790a 790b
7910 7913 7917 7918 791d 7920 7925 7926
792b 792c 7931 7933 7937 793a 793e 7942
7945 7949 794d 7950 7953 7958 795b 795e
7961 7962 7967 7968 1 796a 796f 7973
7977 797a 797f 7984 7987 798b 798c 7991
7992 7997 7999 799d 79a0 79a4 79a8 79ab
79af 79b3 79b6 79ba 79be 79bf 79c4 79c6
79ca 79ce 79d1 79d3 79d7 79da 79de 79e2
79e5 79e6 79e8 79eb 79ee 79ef 79f4 79f8
79fc 79ff 7a00 7a02 7a05 7a08 7a09 1
7a0e 7a13 7a17 7a1b 7a1e 7a23 7a24 7a29
7a2c 7a30 7a34 7a38 7a3b 7a3c 7a3e 7a3f
7a41 7a42 7a47 7a4a 7a4f 7a50 7a55 7a59
7a5b 7a5f 7a62 7a64 7a68 7a6b 7a6f 7a72
7a73 7a78 7a7b 7a7f 7a83 7a87 7a8b 7a8c
7a8e 7a91 7a92 7a94 7a98 7a9c 7a9f 7aa3
7aa7 7aab 7aaf 7ab2 7ab6 7ab7 7abc 7abe
7ac2 7ac6 7aca 7acd 7ad0 7ad3 7ad7 7ada
7add 7ade 7ae3 7ae7 7ae8 7aea 7aee 7af2
7af6 7afa 7afe 7b02 7b0e 7b12 7b16 7b19
7b1d 7b21 7b23 7b27 7b2b 7b2f 7b32 7b36
7b3a 7b3c 7b3d 7b42 1 7b46 7b4a 7b4e
7b51 7b55 7b59 7b5d 7b61 7b64 7b68 7b6c
7b6f 7b72 7b77 7b7a 7b7d 7b80 7b81 7b86
7b87 1 7b89 7b8e 7b92 7b96 7b99 7b9e
7ba3 7ba6 7baa 7bab 7bb0 7bb3 7bb8 7bb9
7bbe 7bc1 7bc6 7bc7 7bcc 7bcf 7bd3 7bd4
7bd9 7bdc 7be1 7be2 7be7 7bea 7bee 7bf2
7bf5 7bf8 7bf9 7bfb 7bfc 7c01 7c02 7c07
7c09 7c0d 7c10 7c12 7c16 7c18 7c24 7c26
7c28 7c29 7c2e 7c32 7c34 7c40 7c42 7c46
7c4a 7c4d 7c51 7c54 7c58 7c5b 7c5c 7c61
7c64 7c68 7c6c 7c6f 7c73 7c77 7c7a 7c7d
7c82 7c85 7c88 7c8b 7c8c 7c91 7c92 1
7c94 7c99 7c9d 7ca1 7ca4 7ca9 7cae 7cb1
7cb5 7cb6 7cbb 7cbe 7cc3 7cc4 7cc9 7ccc
7cd1 7cd2 7cd7 7cda 7cde 7ce2 7ce6 7cea
7ced 7cee 7cf0 7cf5 7cf6 7cf8 7cf9 7cfe
7d01 7d06 7d07 7d0c 7d0f 7d14 7d15 7d1a
7d1d 7d21 7d22 7d27 7d2a 7d2f 7d30 7d35
7d36 7d3b 7d3d 7d41 7d44 7d48 7d4c 7d4f
7d53 7d57 7d5a 7d5d 7d62 7d65 7d68 7d6b
7d6c 7d71 7d72 1 7d74 7d79 7d7d 7d81
7d84 7d89 7d8e 7d91 7d95 7d96 7d9b 7d9c
7da1 7da3 7da7 7daa 7dae 7db2 7db5 7db9
7dbd 7dc0 7dc4 7dc8 7dc9 7dce 7dd0 7dd4
7dd7 7ddb 7ddf 7de2 7de7 7de8 7ded 7df0
7df5 7df6 7dfb 7dfe 7e03 7e04 7e09 7e0c
7e11 7e12 7e17 7e1a 7e1e 7e1f 7e24 7e27
7e2c 7e2d 7e32 7e36 7e3a 7e3e 7e41 7e42
7e44 7e48 7e4b 7e4f 7e52 7e53 7e58 7e5c
7e60 7e63 7e68 7e69 7e6e 7e72 7e74 7e78
7e7c 7e7f 7e84 7e85 7e8a 7e8e 7e90 7e94
7e98 7e9b 7e9f 7ea3 7ea6 7ea7 7ea9 7ead
7eb0 7eb4 7eb7 7eb8 7ebd 7ec1 7ec7 7ec9
7ecd 7ed0 7ed4 7ed8 7edb 7ede 7edf 7ee4
7ee8 7eea 7eee 7ef5 7ef7 7efb 7efe 7f02
7f06 7f09 7f0a 7f0c 7f10 7f13 7f17 7f1a
7f1b 7f20 7f24 7f28 7f2c 7f30 7f31 7f33
7f36 7f37 7f39 7f3d 7f41 7f44 7f48 7f4c
7f50 7f54 7f57 7f5b 7f5c 7f61 7f63 7f67
7f6b 7f6f 7f72 7f75 7f78 7f7c 7f7f 7f82
7f83 7f88 7f8c 7f8d 7f8f 7f93 7f97 7f9b
7f9f 7fa3 7fa7 7fb3 7fb7 7fbb 7fbe 7fc2
7fc6 7fc8 7fcc 7fd0 7fd4 7fd7 7fdb 7fdf
7fe1 7fe2 7fe7 1 7feb 7fef 7ff3 7ff6
7ffa 7ffe 8002 8006 8009 800d 8011 8014
8017 801c 801f 8022 8025 8026 802b 802c
1 802e 8033 8037 803b 803e 8043 8048
804b 804f 8050 8055 8058 805d 805e 8063
8066 806b 806c 8071 8074 8078 8079 807e
8081 8086 8087 808c 808f 8093 8097 809a
809d 809e 80a0 80a1 80a6 80a7 80ac 80ae
80b2 80b5 80b7 80bb 80bd 80c9 80cb 80cd
80ce 80d3 80d7 80d9 80e5 80e7 80eb 80ef
80f2 80f6 80f9 80fd 8100 8101 8106 8109
810d 8111 8114 8118 811c 811f 8122 8127
812a 812d 8130 8131 8136 8137 1 8139
813e 8142 8146 8149 814e 8153 8156 815a
815b 8160 8163 8168 8169 816e 8171 8176
8177 817c 817f 8183 8187 818b 818f 8192
8193 8195 819a 819b 819d 819e 81a3 81a6
81ab 81ac 81b1 81b4 81b9 81ba 81bf 81c2
81c6 81c7 81cc 81cf 81d4 81d5 81da 81db
81e0 81e2 81e6 81e9 81ed 81f1 81f4 81f8
81fc 81ff 8202 8207 820a 820d 8210 8211
8216 8217 1 8219 821e 8222 8226 8229
822e 8233 8236 823a 823b 8240 8241 8246
8248 824c 824f 8253 8257 825a 825e 8262
8265 8269 826d 826e 8273 8275 8279 827c
8280 8284 8287 828c 828d 8292 8295 829a
829b 82a0 82a3 82a8 82a9 82ae 82b1 82b6
82b7 82bc 82bf 82c3 82c4 82c9 82cc 82d1
82d2 82d7 82da 82df 82e0 82e5 82e9 82ed
82f1 82f4 82f7 82f8 82fd 8301 8303 8307
830e 8310 8314 8317 831b 831f 8322 8326
8327 832c 8330 8332 8336 833a 833d 8341
8345 8348 834d 834e 8353 8357 835b 835f
8363 8366 836a 836e 8372 8376 837b 8380
8384 8388 838d 8391 8395 8398 839b 839f
83a1 83a5 83a9 83ac 83af 83b3 83b5 83b9
83bd 83c0 83c4 83c8 83cb 83cf 83d2 83d6
83d9 83da 83df 83e2 83e6 83ec 83ee 83f2
83f5 83f9 83fd 8400 8401 8403 8406 8409
840a 840f 8413 8417 841a 841b 841d 8421
8424 8428 842b 842c 1 8431 8436 843a
843e 8441 8442 8444 8448 844b 844f 8452
8453 1 8458 845d 8461 8465 8468 8469
846b 846f 8472 8476 8479 847a 847f 8483
8486 8487 848c 1 848f 8494 1 8497
849c 84a0 84a4 84a9 84ad 84ae 84b2 84b6
84bb 84c0 84c4 84c8 84cd 84d1 84d5 84d8
84db 84df 84e1 84e5 84e9 84ec 84ef 84f3
84f5 84f9 84fd 8500 8504 8508 850b 850f
8512 8516 8519 851a 851f 8522 8526 852a
852f 8531 8535 8539 853c 8540 8544 8546
854a 854e 8552 8555 8559 855d 855f 8560
8565 1 8569 856d 8571 8574 8578 857c
8580 8584 8587 858b 858f 8592 8595 859a
859d 85a0 85a3 85a4 85a9 85aa 1 85ac
85b1 85b5 85b9 85bc 85c1 85c6 85c9 85cd
85ce 85d3 85d6 85db 85dc 85e1 85e4 85e9
85ea 85ef 85f2 85f6 85f7 85fc 85ff 8604
8605 860a 860d 8611 8615 8618 861b 861c
861e 861f 8624 8625 862a 862c 8630 8633
8635 8639 863b 8647 8649 864b 864c 8651
8655 8657 8663 8665 8669 866f 8671 8675
8679 867e 8680 8684 8688 868b 868f 8693
8695 8699 869d 86a1 86a4 86a8 86ac 86ae
86af 86b4 1 86b8 86bc 86c0 86c3 86c7
86cb 86cf 86d3 86d6 86da 86de 86e1 86e4
86e9 86ec 86ef 86f2 86f3 86f8 86f9 1
86fb 8700 8704 8708 870b 8710 8715 8718
871c 871d 8722 8725 872a 872b 8730 8733
8738 8739 873e 8741 8745 8746 874b 874e
8753 8754 8759 875c 8760 8764 8767 876a
876b 876d 876e 8773 8774 8779 877b 877f
8782 8784 8788 878a 8796 8798 879a 879b
87a0 87a4 87a6 87b2 87b4 87b6 87ba 87be
87c1 87c3 87c7 87ca 87ce 87d2 87d6 87da
87de 87e2 87e6 87ea 87ed 87ee 87f0 87f3
87f6 87f7 87fc 8800 8804 8807 880a 880b
880d 8810 8815 8816 881b 881f 8823 8824
8829 882d 8831 8834 8838 883a 883e 8842
8846 8849 884a 884c 884d 884f 8852 8855
8856 885b 885f 8863 8867 886b 886f 8873
8877 887b 887f 888b 888f 8893 8896 889a
889e 88a0 88a4 88a8 88ac 88af 88b3 88b7
88b9 88ba 88bf 1 88c3 88c7 88cb 88ce
88d2 88d6 88da 88de 88e1 88e5 88e9 88ec
88ef 88f4 88f7 88fa 88fd 88fe 8903 8904
1 8906 890b 890f 8913 8916 891b 8920
8923 8927 8928 892d 8930 8935 8936 893b
893e 8943 8944 8949 894c 8950 8951 8956
8959 895e 895f 8964 8967 896b 896f 8972
8975 8976 8978 8979 897e 897f 8984 8986
898a 898d 898f 8993 8995 89a1 89a3 89a5
89a6 89ab 89af 89b1 89bd 89bf 89c3 89c7
89ca 89cb 89cd 89d0 89d3 89d4 89d9 89dd
89e1 89e6 89e8 89ec 89f0 89f3 89f7 89fb
89fd 8a01 8a05 8a09 8a0c 8a10 8a14 8a16
8a17 8a1c 1 8a20 8a24 8a28 8a2b 8a2f
8a33 8a37 8a3b 8a3e 8a42 8a46 8a49 8a4c
8a51 8a54 8a57 8a5a 8a5b 8a60 8a61 1
8a63 8a68 8a6c 8a70 8a73 8a78 8a7d 8a80
8a84 8a85 8a8a 8a8d 8a92 8a93 8a98 8a9b
8aa0 8aa1 8aa6 8aa9 8aad 8aae 8ab3 8ab6
8abb 8abc 8ac1 8ac4 8ac8 8acc 8acf 8ad2
8ad3 8ad5 8ad6 8adb 8adc 8ae1 8ae3 8ae7
8aea 8aec 8af0 8af2 8afe 8b00 8b02 8b03
8b08 8b0c 8b0e 8b1a 8b1c 8b20 8b24 8b27
8b2b 8b2f 8b32 8b35 8b3a 8b3d 8b40 8b43
8b44 8b49 8b4a 1 8b4c 8b51 8b55 8b59
8b5c 8b61 8b66 8b69 8b6d 8b6e 8b73 8b76
8b7b 8b7c 8b81 8b84 8b89 8b8a 8b8f 8b92
8b96 8b9a 8b9e 8ba2 8ba5 8ba6 8ba8 8bad
8bae 8bb0 8bb1 8bb6 8bb9 8bbe 8bbf 8bc4
8bc7 8bcc 8bcd 8bd2 8bd5 8bd9 8bda 8bdf
8be2 8be7 8be8 8bed 8bee 8bf3 8bf5 8bf9
8bfc 8c00 8c04 8c07 8c0b 8c0f 8c12 8c15
8c1a 8c1d 8c20 8c23 8c24 8c29 8c2a 1
8c2c 8c31 8c35 8c39 8c3c 8c41 8c46 8c49
8c4d 8c4e 8c53 8c54 8c59 8c5b 8c5f 8c62
8c66 8c6a 8c6d 8c71 8c75 8c78 8c7c 8c80
8c81 8c86 8c88 8c8c 8c8f 8c91 8c95 8c98
8c9a 8c9e 8ca2 8ca5 8ca9 8cad 8cb1 8cb5
8cb9 8cbd 8cc1 8cc5 8cc9 8ccd 8cd1 8cd5
8cd9 8cdd 8ce1 8ce5 8ce9 8ced 8cf1 8cf5
8cf9 8cfd 8d01 8d05 8d09 8d0d 8d11 8d15
8d19 8d1d 8d21 8d25 8d28 8d29 8d2b 8d2e
8d31 8d34 8d37 8d38 8d3a 8d3e 8d42 8d45
8d48 8d49 8d4e 8d52 8d56 8d5b 8d5d 8d61
8d65 8d68 8d6c 8d70 8d72 8d76 8d7a 8d7e
8d81 8d85 8d89 8d8b 8d8c 8d91 1 8d95
8d99 8d9d 8da0 8da4 8da8 8dac 8db0 8db3
8db7 8dbb 8dbe 8dc1 8dc6 8dc9 8dcc 8dcf
8dd0 8dd5 8dd6 1 8dd8 8ddd 8de1 8de5
8de8 8ded 8df2 8df5 8df9 8dfa 8dff 8e02
8e07 8e08 8e0d 8e10 8e15 8e16 8e1b 8e1e
8e22 8e23 8e28 8e2b 8e30 8e31 8e36 8e39
8e3d 8e41 8e44 8e47 8e48 8e4a 8e4b 8e50
8e51 8e56 8e58 8e5c 8e5f 8e61 8e65 8e67
8e73 8e75 8e77 8e78 8e7d 8e81 8e83 8e8f
8e91 8e95 8e99 8e9c 8ea0 8ea3 8ea4 8ea9
8ead 8eb1 8eb5 8eb8 8ebc 8ebe 8ec2 8ec5
8ec9 8ecd 8ed0 8ed4 8ed8 8edb 8ede 8ee3
8ee6 8ee9 8eec 8eed 8ef2 8ef3 1 8ef5
8efa 8efe 8f02 8f05 8f0a 8f0f 8f12 8f16
8f17 8f1c 8f1f 8f24 8f25 8f2a 8f2d 8f32
8f33 8f38 8f3b 8f3f 8f43 8f47 8f48 8f4a
8f4f 8f50 8f52 8f53 8f58 8f5b 8f60 8f61
8f66 8f69 8f6e 8f6f 8f74 8f77 8f7b 8f7c
8f81 8f84 8f89 8f8a 8f8f 8f90 8f95 8f97
8f9b 8f9e 8fa2 8fa6 8fa9 8fad 8fb1 8fb4
8fb7 8fbc 8fbf 8fc2 8fc5 8fc6 8fcb 8fcc
1 8fce 8fd3 8fd7 8fdb 8fde 8fe3 8fe8
8feb 8fef 8ff0 8ff5 8ff6 8ffb 8ffd 9001
9004 9008 900c 900f 9013 9017 901b 901c
9021 9025 9027 902b 902f 9032 9035 9036
9038 903b 9040 9041 9046 9049 904d 9051
9054 9057 9058 905a 905d 9062 9063 9068
1 906b 9070 9074 9078 907c 9080 9084
9090 9094 9099 909d 90a0 90a1 90a6 90aa
90ae 90b1 90b4 90b8 90ba 90be 90c2 90c5
90c8 90cc 90ce 90d2 90d6 90d9 90db 90df
90e3 90e7 90ea 90ee 90f2 90f4 90f5 90fa
1 90fe 9102 9106 9109 910d 9111 9115
9119 911c 9120 9124 9127 912a 912f 9132
9135 9138 9139 913e 913f 1 9141 9146
914a 914e 9151 9156 915b 915e 9162 9163
9168 916b 9170 9171 9176 9179 917e 917f
9184 9187 918b 918c 9191 9194 9199 919a
919f 91a2 91a6 91aa 91ad 91b0 91b1 91b3
91b4 91b9 91ba 91bf 91c1 91c5 91c8 91ca
91ce 91d0 91dc 91de 91e0 91e1 91e6 91ea
91ec 91f8 91fa 91fc 9200 9204 9207 920b
9211 9213 9217 921b 921e 921f 9221 9225
9228 922c 922f 9230 9235 9239 923d 9241
9245 9249 924d 924f 9253 9256 925a 925e
9262 9266 926a 926e 9272 9276 927a 927e
9282 9286 928a 928e 9292 9296 929a 929e
92a2 92a6 92aa 92ae 92b2 92b6 92ba 92be
92c2 92c6 92ca 92ce 92d1 92d4 92d7 92da
92dd 92de 92e0 92e4 92e8 92eb 92ee 92ef
92f4 92f8 92fc 92ff 9302 9303 9308 930c
9310 9312 9316 9319 931c 931d 9322 9326
932c 932e 9332 9336 9339 933d 9341 9344
9348 934b 934c 934e 934f 9354 9358 935e
9360 9364 9367 9369 936d 9371 9374 937c
937e 937f 9382 9384 9388 938f 9393 9397
939c 939e 93a2 93a6 93a9 93ad 93b1 93b3
93b7 93bb 93bf 93c2 93c6 93ca 93cc 93cd
93d2 1 93d6 93da 93de 93e1 93e5 93e9
93ed 93f1 93f4 93f8 93fc 93ff 9402 9407
940a 940d 9410 9411 9416 9417 1 9419
941e 9422 9426 9429 942e 9433 9436 943a
943b 9440 9443 9448 9449 944e 9451 9456
9457 945c 945f 9463 9464 9469 946c 9471
9472 9477 947a 947e 9482 9485 9488 9489
948b 948c 9491 9492 9497 9499 949d 94a0
94a2 94a6 94a8 94b4 94b6 94b8 94b9 94be
94c2 94c4 94d0 94d2 94d6 94da 94dd 94e1
94e4 94e5 94ea 94ed 94f1 94f4 94f7 94f8
94fd 1 9500 9505 9509 950c 950f 9510
9515 9519 951d 9520 9521 9523 9526 9529
952a 1 952f 9534 1 9537 953c 9540
9544 9547 954b 954f 9552 9555 955a 955d
9560 9563 9564 9569 956a 1 956c 9571
9575 9579 957c 9581 9586 9589 958d 958e
9593 9596 959b 959c 95a1 95a4 95a9 95aa
95af 95b2 95b6 95ba 95be 95bf 95c1 95c6
95c7 95c9 95ca 95cf 95d2 95d7 95d8 95dd
95e0 95e5 95e6 95eb 95ee 95f2 95f3 95f8
95fb 9600 9601 9606 9607 960c 960e 9612
9615 9619 961d 9620 9624 9628 962b 962e
9633 9636 9639 963c 963d 9642 9643 1
9645 964a 964e 9652 9655 965a 965f 9662
9666 9667 966c 966d 9672 9674 9678 967b
967f 9683 9686 968a 968e 9692 9693 9698
969a 969e 96a1 96a5 96a8 96ab 96ac 96b1
96b5 96ba 96be 96c2 96c7 96cb 96cf 96d4
96d8 96dc 96e0 96e5 96e9 96ea 96ee 96f1
96f5 96f9 96fd 9701 9705 9709 970d 9711
9715 9719 971d 9722 9727 972b 972f 9733
9738 973c 9740 9743 9746 974a 974c 9750
9754 9757 975a 975e 9760 9764 9768 976b
976f 9773 9776 977a 977d 9781 9784 9785
978a 978d 9791 9797 9799 979d 97a0 97a4
97a7 97a8 97ad 97b0 97b4 97b8 97bb 97bf
97c3 97c4 97c6 97c9 97cc 97cd 1 97d2
97d7 97db 97df 97e3 97e4 97e6 97e9 97ea
97ec 97ef 97f2 97f3 1 97f8 97fd 9801
9805 9809 980b 980f 9812 9816 981a 981d
9821 9825 9826 9828 982b 982e 982f 9834
9838 983b 983e 983f 9844 9848 984c 9850
9854 9858 985c 9860 9864 9868 986c 9870
9874 9878 987c 9880 988c 9890 9895 9899
989c 989d 98a2 98a6 98aa 98ad 98b0 98b4
98b6 98ba 98be 98c1 98c4 98c8 98ca 98ce
98d2 98d5 98d7 98db 98df 98e3 98e6 98ea
98ee 98f0 98f1 98f6 1 98fa 98fe 9902
9905 9909 990d 9911 9915 9918 991c 9920
9923 9926 992b 992e 9931 9934 9935 993a
993b 1 993d 9942 9946 994a 994d 9952
9957 995a 995e 995f 9964 9967 996c 996d
9972 9975 997a 997b 9980 9983 9987 9988
998d 9990 9995 9996 999b 999e 99a2 99a6
99a9 99ac 99ad 99af 99b0 99b5 99b6 99bb
99bd 99c1 99c4 99c6 99ca 99cc 99d8 99da
99dc 99dd 99e2 99e6 99e8 99f4 99f6 99f8
99fc 99ff 9a03 9a08 9a0c 9a10 9a15 9a19
9a1d 9a22 9a26 9a2a 9a2f 9a33 9a37 9a3c
9a40 9a44 9a49 9a4d 9a51 9a55 9a59 9a5d
9a60 9a64 9a66 9a6a 9a6d 9a71 9a74 9a77
9a78 9a7d 9a81 9a84 9a85 9a8a 1 9a8d
9a92 9a96 9a9a 9a9e 9aa2 9aa6 9aaa 9aae
9ab2 9ab6 9ac2 9ac6 9acb 9acf 9ad2 9ad3
9ad8 9adc 9ae0 9ae3 9ae6 9aea 9aec 9af0
9af4 9af7 9afa 9afe 9b00 9b04 9b08 9b0b
9b0d 9b11 9b15 9b19 9b1c 9b20 9b24 9b26
9b27 9b2c 1 9b30 9b34 9b38 9b3b 9b3f
9b43 9b47 9b4b 9b4e 9b52 9b56 9b59 9b5c
9b61 9b64 9b67 9b6a 9b6b 9b70 9b71 1
9b73 9b78 9b7c 9b80 9b83 9b88 9b8d 9b90
9b94 9b95 9b9a 9b9d 9ba2 9ba3 9ba8 9bab
9bb0 9bb1 9bb6 9bb9 9bbd 9bbe 9bc3 9bc6
9bcb 9bcc 9bd1 9bd4 9bd8 9bdc 9bdf 9be2
9be3 9be5 9be6 9beb 9bec 9bf1 9bf3 9bf7
9bfa 9bfc 9c00 9c02 9c0e 9c10 9c12 9c13
9c18 9c1c 9c1e 9c2a 9c2c 9c2e 9c32 9c35
9c39 9c3c 9c3d 9c42 9c45 9c49 9c4c 9c4d
9c52 9c55 9c59 9c5d 9c61 9c64 9c69 9c6a
9c6f 9c72 9c75 9c76 9c78 9c7c 9c7e 9c82
9c85 9c89 9c8d 9c91 9c94 9c98 9c99 9c9e
9ca1 9ca4 9ca5 9ca7 9cab 9cad 9cb1 9cb4
9cb8 9cbb 9cbc 9cc1 9cc4 9cc8 9ccc 9cd0
9cd3 9cd7 9cd8 9cdd 9ce0 9ce3 9ce4 9ce6
9cea 9cec 9cf0 9cf3 9cf7 9cfa 9cfb 9d00
9d03 9d07 9d0a 9d0b 9d10 9d13 9d17 9d1b
9d1f 9d22 9d27 9d28 9d2d 9d30 9d33 9d34
9d36 9d3a 9d3c 9d40 9d43 9d47 9d4b 9d4f
9d52 9d56 9d57 9d5c 9d5f 9d62 9d63 9d65
9d69 9d6b 9d6f 9d72 9d76 9d79 9d7a 9d7f
9d82 9d86 9d8a 9d8e 9d91 9d95 9d96 9d9b
9d9e 9da1 9da2 9da4 9da8 9daa 9dae 9db1
9db5 9db8 9db9 9dbe 9dc1 9dc5 9dc8 9dc9
9dce 9dd1 9dd5 9dd9 9ddd 9de0 9de5 9de6
9deb 9dee 9df1 9df2 9df4 9df8 9dfa 9dfe
9e01 9e05 9e09 9e0d 9e10 9e14 9e15 9e1a
9e1d 9e20 9e21 9e23 9e27 9e29 9e2d 9e30
9e34 9e37 9e38 9e3d 9e40 9e44 9e47 9e48
9e4d 9e50 9e54 9e58 9e5c 9e5f 9e64 9e65
9e6a 9e6d 9e70 9e71 9e73 9e77 9e79 9e7d
9e80 9e84 9e88 9e8c 9e8f 9e93 9e94 9e99
9e9c 9e9f 9ea0 9ea2 9ea6 9ea8 9eac 9eaf
9eb3 9eb7 9eba 9ebd 9ebe 9ec3 9ec7 9ecb
9ecf 9ed3 9ed5 9ed9 9ee0 9ee4 9ee8 9eed
9eef 9ef3 9ef7 9efa 9efe 9f02 9f04 9f08
9f0c 9f10 9f13 9f17 9f1b 9f1d 9f1e 9f23
1 9f27 9f2b 9f2f 9f32 9f36 9f3a 9f3e
9f42 9f45 9f49 9f4d 9f50 9f53 9f58 9f5b
9f5e 9f61 9f62 9f67 9f68 1 9f6a 9f6f
9f73 9f77 9f7a 9f7f 9f84 9f87 9f8b 9f8c
9f91 9f94 9f99 9f9a 9f9f 9fa2 9fa7 9fa8
9fad 9fb0 9fb4 9fb5 9fba 9fbd 9fc2 9fc3
9fc8 9fcb 9fcf 9fd3 9fd6 9fd9 9fda 9fdc
9fdd 9fe2 9fe3 9fe8 9fea 9fee 9ff1 9ff3
9ff7 9ff9 a005 a007 a009 a00a a00f a013
a015 a021 a023 a027 a02a a02d a02e a033
a037 a03b a03f a043 a047 a04b a04f a053
a057 a05b a05f a063 a067 a06b a06f a07b
a07f a084 a088 a08b a08c a091 a095 a099
a09c a09f a0a3 a0a5 a0a9 a0ad a0b0 a0b3
a0b7 a0b9 a0bd a0c1 a0c4 a0c6 a0ca a0ce
a0d2 a0d5 a0d9 a0dd a0df a0e0 a0e5 1
a0e9 a0ed a0f1 a0f4 a0f8 a0fc a100 a104
a107 a10b a10f a112 a115 a11a a11d a120
a123 a124 a129 a12a 1 a12c a131 a135
a139 a13c a141 a146 a149 a14d a14e a153
a156 a15b a15c a161 a164 a169 a16a a16f
a172 a176 a177 a17c a17f a184 a185 a18a
a18d a191 a195 a198 a19b a19c a19e a19f
a1a4 a1a5 a1aa a1ac a1b0 a1b3 a1b5 a1b9
a1bb a1c7 a1c9 a1cb a1cc a1d1 a1d5 a1d7
a1e3 a1e5 a1e7 a1eb a1ee a1f0 a1f4 a1f7
a1fb a1fe a1ff a204 a207 a20b a20f a212
a213 a215 a218 a21b a21c a221 a225 a229
a22d a231 a235 a239 a23d a241 a245 a249
a24d a251 a255 a259 a265 a269 a26d a270
a274 a278 a27a a27e a282 a286 a289 a28d
a291 a293 a294 a299 1 a29d a2a1 a2a5
a2a8 a2ac a2b0 a2b4 a2b8 a2bb a2bf a2c3
a2c6 a2c9 a2ce a2d1 a2d4 a2d7 a2d8 a2dd
a2de 1 a2e0 a2e5 a2e9 a2ed a2f0 a2f5
a2fa a2fd a301 a302 a307 a30a a30f a310
a315 a318 a31d a31e a323 a326 a32a a32b
a330 a333 a338 a339 a33e a341 a345 a349
a34c a34f a350 a352 a353 a358 a359 a35e
a360 a364 a367 a369 a36d a36f a37b a37d
a37f a380 a385 a389 a38b a397 a399 a39b
a39f a3a2 a3a6 a3a8 a3aa a3ae a3b2 a3b5
a3b7 a3bb a3be a3c2 a3c6 a3ca a3ce a3d2
a3d6 a3da a3de a3e2 a3e6 a3ea a3ee a3f2
a3f6 a3fa a3fe a402 a406 a40a a416 a41a
a41e a421 a425 a429 a42b a42f a433 a437
a43a a43e a442 a444 a445 a44a 1 a44e
a452 a456 a459 a45d a461 a465 a469 a46c
a470 a474 a477 a47a a47f a482 a485 a488
a489 a48e a48f 1 a491 a496 a49a a49e
a4a1 a4a6 a4ab a4ae a4b2 a4b3 a4b8 a4bb
a4c0 a4c1 a4c6 a4c9 a4ce a4cf a4d4 a4d7
a4db a4dc a4e1 a4e4 a4e9 a4ea a4ef a4f2
a4f6 a4fa a4fd a500 a501 a503 a504 a509
a50a a50f a511 a515 a518 a51a a51e a520
a52c a52e a530 a531 a536 a53a a53c a548
a54a a54e a552 a555 a556 a558 a55c a55f
a563 a566 a567 a56c a570 a574 a579 a57e
a582 a586 a58a a58d a590 a594 a598 a59c
a5a0 a5a4 a5a8 a5ac a5b0 a5b4 a5b8 a5bc
a5c0 a5cc a5d0 a5d5 a5d9 a5dc a5dd a5e2
a5e6 a5ea a5ed a5f0 a5f4 a5f6 a5fa a5fe
a601 a604 a608 a60a a60e a612 a615 a617
a61b a61f a623 a626 a62a a62e a630 a631
a636 1 a63a a63e a642 a645 a649 a64d
a651 a655 a658 a65c a660 a663 a666 a66b
a66e a671 a674 a675 a67a a67b 1 a67d
a682 a686 a68a a68d a692 a697 a69a a69e
a69f a6a4 a6a7 a6ac a6ad a6b2 a6b5 a6ba
a6bb a6c0 a6c3 a6c7 a6c8 a6cd a6d0 a6d5
a6d6 a6db a6de a6e2 a6e6 a6e9 a6ec a6ed
a6ef a6f0 a6f5 a6f6 a6fb a6fd a701 a704
a706 a70a a70c a718 a71a a71c a71d a722
a726 a728 a734 a736 a73a a73e a741 a745
a748 a74c a74f a750 a755 a758 a75c a760
a764 a768 a76c a770 a774 a778 a77c a780
a784 a788 a78c a790 a794 a798 a79c a7a0
a7ac a7b0 a7b5 a7b9 a7bc a7bd a7c2 a7c6
a7ca a7cd a7d0 a7d4 a7d6 a7da a7de a7e1
a7e4 a7e8 a7ea a7ee a7f2 a7f5 a7f7 a7fb
a7ff a803 a806 a80a a80e a810 a811 a816
1 a81a a81e a822 a825 a829 a82d a831
a835 a838 a83c a840 a843 a846 a84b a84e
a851 a854 a855 a85a a85b 1 a85d a862
a866 a86a a86d a872 a877 a87a a87e a87f
a884 a887 a88c a88d a892 a895 a89a a89b
a8a0 a8a3 a8a7 a8a8 a8ad a8b0 a8b5 a8b6
a8bb a8be a8c2 a8c6 a8c9 a8cc a8cd a8cf
a8d0 a8d5 a8d6 a8db a8dd a8e1 a8e4 a8e6
a8ea a8ec a8f8 a8fa a8fc a8fd a902 a906
a908 a914 a916 a91a a91e a921 a925 a928
a92c a92f a930 a935 a938 a93c a940 a944
a948 a94c a950 a95c a960 a965 a969 a96c
a96d a972 a976 a97a a97d a980 a984 a986
a98a a98e a991 a994 a998 a99a a99e a9a2
a9a5 a9a7 a9ab a9af a9b3 a9b6 a9ba a9be
a9c0 a9c1 a9c6 1 a9ca a9ce a9d2 a9d5
a9d9 a9dd a9e1 a9e5 a9e8 a9ec a9f0 a9f3
a9f6 a9fb a9fe aa01 aa04 aa05 aa0a aa0b
1 aa0d aa12 aa16 aa1a aa1d aa22 aa27
aa2a aa2e aa2f aa34 aa37 aa3c aa3d aa42
aa45 aa4a aa4b aa50 aa53 aa57 aa58 aa5d
aa60 aa65 aa66 aa6b aa6e aa72 aa76 aa79
aa7c aa7d aa7f aa80 aa85 aa86 aa8b aa8d
aa91 aa94 aa96 aa9a aa9c aaa8 aaaa aaac
aaad aab2 aab6 aab8 aac4 aac6 aac8 aacc
aacf aad1 aad5 aad8 aadc aae0 aae4 aae8
aaec aaf0 aaf4 aaf8 aafc ab00 ab04 ab08
ab0c ab10 ab14 ab18 ab1c ab20 ab24 ab28
ab2c ab30 ab34 ab38 ab3c ab40 ab44 ab48
ab4c ab50 ab54 ab58 ab5c ab60 ab64 ab68
ab6c ab70 ab74 ab78 ab7c ab80 ab84 ab88
ab8c ab90 ab94 ab98 ab9c aba0 aba4 aba8
abac abb0 abb4 abb8 abbc abc0 abc4 abc8
abcc abd0 abd4 abd8 abdc abe0 abe4 abe8
abec abf0 abf4 abf8 abfc ac00 ac04 ac08
ac0c ac10 ac14 ac18 ac1c ac20 ac24 ac28
ac2c ac30 ac34 ac38 ac3c ac40 ac44 ac48
ac4c ac50 ac54 ac58 ac5c ac60 ac64 ac68
ac6c ac70 ac74 ac78 ac7c ac80 ac84 ac88
ac8c ac90 ac94 ac98 ac9c aca0 aca4 aca8
acac acb0 acb4 acb8 acbc acc0 acc4 acc8
accc acd0 acd4 acd8 acdc ace0 ace4 ace8
acec acf0 acf4 acf8 acfc ad00 ad04 ad08
ad0c ad10 ad14 ad18 ad1c ad20 ad24 ad28
ad2c ad30 ad34 ad38 ad3c ad40 ad44 ad48
ad4c ad50 ad54 ad58 ad5c ad60 ad64 ad68
ad6c ad70 ad74 ad78 ad7c ad80 ad84 ad88
ad8c ad90 ad94 ad98 ad9c ada0 ada4 ada8
adac adb0 adb4 adb8 adbc adc0 adc4 adc8
adcc add0 add4 add8 addc ade0 ade4 ade8
adec adf0 adf4 adf8 adfc ae00 ae04 ae08
ae0c ae18 ae1d ae21 ae25 ae29 ae2c ae30
ae34 ae37 ae3a ae3f ae42 ae45 ae48 ae49
ae4e ae4f 1 ae51 ae56 ae5a ae5e ae61
ae66 ae6b ae6e ae72 ae73 ae78 ae79 ae7e
ae80 ae84 ae87 ae8b ae8f ae93 ae95 ae99
ae9c ae9f aea0 aea5 aea9 aead aeb1 aeb5
aeb9 aebd aec1 aec5 aec9 aecd aed1 aed5
aed9 aedd aee1 aee5 aee9 aeed aef1 aef5
aef9 aefd af01 af05 af09 af0d af11 af15
af19 af1d af21 af25 af29 af2d af31 af35
af39 af3d af41 af45 af49 af4d af51 af55
af59 af5d af61 af65 af69 af6d af71 af75
af79 af7d af81 af85 af89 af8d af91 af95
af99 af9d afa1 afa5 afa9 afad afb1 afb5
afb9 afbd afc1 afc5 afc9 afcd afd1 afd5
afd9 afdd afe1 afe5 afe9 afed aff1 aff5
aff9 affd b001 b005 b009 b00d b011 b015
b019 b01d b021 b025 b029 b02d b031 b035
b039 b03d b041 b045 b049 b04d b051 b055
b059 b05d b061 b065 b069 b06d b071 b075
b079 b07d b081 b085 b089 b08d b091 b095
b099 b09d b0a1 b0a5 b0a9 b0ad b0b1 b0b5
b0b9 b0bd b0c1 b0c5 b0c9 b0cd b0d1 b0d5
b0d9 b0dd b0e1 b0e5 b0e9 b0ed b0f1 b0f5
b0f9 b0fd b101 b105 b109 b10d b111 b115
b119 b11d b121 b125 b129 b12d b131 b135
b139 b13d b141 b145 b149 b14d b151 b155
b159 b15d b161 b165 b169 b16d b171 b175
b179 b17d b181 b185 b189 b18d b191 b195
b199 b19d b1a1 b1a5 b1a9 b1ad b1b1 b1b5
b1b9 b1bd b1c1 b1c5 b1c9 b1cd b1d1 b1d5
b1d9 b1dd b1e1 b1e5 b1e9 b1ed b1f1 b1f5
b1f9 b1fd b201 b205 b209 b20d b211 b215
b219 b21d b221 b225 b229 b22d b231 b235
b239 b23d b241 b245 b249 b24d b251 b255
b259 b25d b261 b265 b269 b26d b271 b275
b279 b27d b281 b285 b289 b28d b291 b295
b299 b29d b2a1 b2a5 b2a9 b2ad b2b1 b2b5
b2b9 b2bd b2c1 b2c5 b2c9 b2cd b2d1 b2d5
b2d9 b2dd b2e1 b2e5 b2e9 b2ed b2f1 b2f5
b2f9 b2fd b301 b305 b309 b30d b311 b315
b319 b31d b321 b325 b329 b32d b331 b335
b339 b33d b341 b345 b349 b34d b351 b355
b359 b35d b361 b36d b372 b376 b37a b37e
b381 b385 b389 b38c b38f b394 b397 b39a
b39d b39e b3a3 b3a4 1 b3a6 b3ab b3af
b3b3 b3b6 b3bb b3c0 b3c3 b3c7 b3c8 b3cd
b3ce b3d3 b3d5 b3d9 b3dc b3e0 b3e4 b3e8
b3ea b3ee b3f2 b3f7 b3fc b400 b404 b408
b40b b40e b412 b416 b41a b41e b422 b426
b42a b42e b432 b43e b442 b447 b44b b44e
b44f b454 b458 b45c b45f b462 b466 b468
b46c b470 b473 b476 b47a b47c b480 b484
b487 b489 b48d b491 b495 b498 b49c b4a0
b4a2 b4a3 b4a8 1 b4ac b4b0 b4b4 b4b7
b4bb b4bf b4c3 b4c7 b4ca b4ce b4d2 b4d5
b4d8 b4dd b4e0 b4e3 b4e6 b4e7 b4ec b4ed
1 b4ef b4f4 b4f8 b4fc b4ff b504 b509
b50c b510 b511 b516 b519 b51e b51f b524
b527 b52c b52d b532 b535 b539 b53a b53f
b542 b547 b548 b54d b550 b554 b558 b55b
b55e b55f b561 b562 b567 b568 b56d b56f
b573 b576 b578 b57c b57e b58a b58c b58e
b58f b594 b598 b59a b5a6 b5a8 b5ac b5b0
b5b4 b5b8 b5bc b5c0 b5c4 b5c8 b5cc b5d0
b5d4 b5d8 b5dc b5e0 b5e4 b5e8 b5ec b5f0
b5f4 b5f8 b5fc b608 b60c b611 b615 b618
b619 b61e b622 b626 b629 b62c b630 b632
b636 b63a b63d b640 b644 b646 b64a b64e
b651 b653 b657 b65b b65f b662 b666 b66a
b66c b66d b672 1 b676 b67a b67e b681
b685 b689 b68d b691 b694 b698 b69c b69f
b6a2 b6a7 b6aa b6ad b6b0 b6b1 b6b6 b6b7
1 b6b9 b6be b6c2 b6c6 b6c9 b6ce b6d3
b6d6 b6da b6db b6e0 b6e3 b6e8 b6e9 b6ee
b6f1 b6f6 b6f7 b6fc b6ff b703 b704 b709
b70c b711 b712 b717 b71a b71e b722 b725
b728 b729 b72b b72c b731 b732 b737 b739
b73d b740 b742 b746 b748 b754 b756 b758
b759 b75e b762 b764 b770 b772 b776 b77a
b77e b782 b786 b78a b78e b792 b796 b79a
b79e b7a2 b7a6 b7aa b7ae b7b2 b7b6 b7ba
b7be b7c2 b7c6 b7ca b7ce b7d2 b7d6 b7da
b7de b7e2 b7e6 b7ea b7ee b7f2 b7f6 b7fa
b7fe b802 b806 b80a b80e b812 b816 b81a
b81e b822 b826 b82a b82e b832 b836 b83a
b83e b842 b846 b84a b84e b852 b856 b85a
b85e b862 b866 b86a b86e b872 b876 b87a
b87e b882 b886 b88a b88e b892 b896 b89a
b89e b8a2 b8a6 b8aa b8ae b8b2 b8b6 b8ba
b8be b8c2 b8c6 b8ca b8ce b8d2 b8d6 b8da
b8de b8e2 b8e6 b8ea b8ee b8f2 b8f6 b8fa
b8fe b902 b906 b90a b90e b912 b916 b91a
b91e b922 b926 b92a b92e b932 b936 b93a
b93e b942 b946 b94a b94e b952 b956 b95a
b95e b962 b966 b96a b96e b972 b976 b97a
b97e b982 b986 b98a b98e b992 b996 b99a
b99e b9a2 b9a6 b9aa b9ae b9b2 b9b6 b9ba
b9be b9c2 b9c6 b9ca b9ce b9d2 b9d6 b9da
b9de b9e2 b9e6 b9ea b9ee b9f2 b9f6 b9fa
b9fe ba02 ba06 ba0a ba0e ba12 ba16 ba1a
ba1e ba22 ba26 ba2a ba2e ba32 ba36 ba3a
ba3e ba42 ba46 ba4a ba4e ba52 ba56 ba5a
ba5e ba62 ba66 ba6a ba6e ba72 ba76 ba7a
ba7e ba82 ba86 ba8a ba8e ba92 ba96 ba9a
ba9e baa2 baa6 baaa baae bab2 bab6 baba
babe bac2 bac6 baca bace bad2 bad6 bada
bade bae2 bae6 baea baee baf2 baf6 bafa
bafe bb02 bb06 bb0a bb0e bb12 bb16 bb1a
bb1e bb22 bb26 bb2a bb2e bb32 bb36 bb3a
bb3e bb42 bb46 bb4a bb4e bb52 bb56 bb5a
bb5e bb62 bb66 bb6a bb6e bb72 bb76 bb7a
bb7e bb82 bb86 bb8a bb8e bb92 bb96 bb9a
bb9e bba2 bba6 bbaa bbae bbb2 bbb6 bbba
bbbe bbc2 bbc6 bbca bbce bbd2 bbd6 bbda
bbde bbe2 bbe6 bbea bbee bbf2 bbf6 bbfa
bbfe bc02 bc06 bc0a bc0e bc12 bc16 bc1a
bc1e bc22 bc26 bc2a bc2e bc32 bc36 bc3a
bc3e bc42 bc46 bc4a bc4e bc52 bc56 bc5a
bc5e bc62 bc66 bc6a bc6e bc72 bc76 bc7a
bc7e bc82 bc86 bc8a bc8e bc92 bc96 bc9a
bc9e bca2 bca6 bcaa bcae bcb2 bcb6 bcba
bcbe bcc2 bcc6 bcca bcce bcd2 bcd6 bcda
bcde bce2 bce6 bcea bcee bcf2 bcf6 bcfa
bcfe bd02 bd06 bd0a bd0e bd12 bd16 bd1a
bd1e bd22 bd26 bd2a bd2e bd32 bd36 bd3a
bd3e bd42 bd46 bd4a bd4e bd52 bd56 bd5a
bd5e bd62 bd66 bd6a bd6e bd72 bd76 bd7a
bd7e bd82 bd86 bd8a bd8e bd92 bd96 bd9a
bd9e bda2 bda6 bdaa bdae bdb2 bdb6 bdba
bdbe bdc2 bdc6 bdca bdce bdd2 bdd6 bdda
bdde bde2 bde6 bdea bdee bdf2 bdf6 bdfa
bdfe be02 be06 be0a be0e be12 be16 be1a
be1e be22 be26 be2a be2e be32 be36 be3a
be3e be42 be46 be4a be4e be52 be56 be62
be67 be6b be6f be73 be76 be7a be7e be81
be84 be89 be8c be8f be92 be93 be98 be99
1 be9b bea0 bea4 bea8 beab beb0 beb5
beb8 bebc bebd bec2 bec3 bec8 beca bece
bed1 bed5 bed9 bedd bedf bee3 bee7 beea
beec bef0 bef4 bef7 bef9 befd bf01 bf04
bf08 bf0c bf0f bf13 bf17 bf1a bf1d bf22
bf25 bf28 bf2b bf2c bf31 bf32 1 bf34
bf39 bf3d bf41 bf44 bf49 bf4e bf51 bf55
bf56 bf5b bf5c bf61 bf65 bf69 bf6c bf71
bf76 bf79 bf7d bf81 bf84 bf85 bf8a bf8d
bf92 bf93 bf98 bf9b bf9f bfa3 bfa6 bfa7
bfac bfad bfb2 bfb4 bfb8 bfbb bfbf bfc3
bfc7 bfcb bfcf bfd3 bfd7 bfdb bfdf bfeb
bff0 bff4 bff8 bffc c000 c002 c003 c008
1 c00c c010 c014 c017 c01b c01f c023
c027 c02a c02e c032 c035 c038 c03d c040
c043 c046 c047 c04c c04d 1 c04f c054
c058 c05c c05f c064 c069 c06c c070 c071
c076 c077 c07c c080 c084 c087 c08c c091
c094 c098 c099 c09e c0a1 c0a6 c0a7 c0ac
c0af c0b3 c0b7 c0ba c0bd c0be c0c0 c0c1
c0c6 c0c7 c0cc c0ce c0d2 c0d5 c0d9 c0dd
c0e1 c0e5 c0e9 c0ed c0f1 c0fd c102 c106
c10a c10e c112 c114 c118 c11a c126 c128
c12a c12b c130 c134 c136 c142 c146 c148
c149 c152 
3722
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 c :3 6 e :3 6 10 :3 6
10 :3 6 11 :3 6 17 :3 6 10 :3 6
11 :3 6 10 :3 6 11 :3 6 f :3 6
f :3 6 10 :3 6 d :3 6 e :3 6
12 :2 6 1 3 a 13 a :2 1
4 d 16 15 :2 d :2 4 11 1a
19 :2 11 :2 4 e 17 16 :2 e :2 4
c 15 14 :2 c :2 4 f 18 17
:2 f :2 4 f 18 17 :2 f :2 4 c
15 14 :2 c :2 4 b 14 13 :2 b
:2 4 10 19 18 :2 10 :2 4 11 1a
19 :2 11 :2 4 10 19 18 :2 10 :2 4
11 1a 19 :2 11 :2 4 f 18 17
:2 f :2 4 10 19 18 :2 10 :2 4 f
18 17 :2 f :2 4 10 19 18 :2 10
:2 4 11 1a 19 :2 11 :2 4 11 1a
19 :2 11 :2 4 d 16 15 :2 d :2 4
e 17 16 :2 e :2 4 b 14 13
:2 b :2 4 :3 10 :2 4 11 1a 19 :2 11
:2 4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 14 1d 1c :2 14 :2 4
15 1e 1d :2 15 :2 4 :3 e :2 4 f
18 17 :2 f :2 4 10 19 18 :2 10
:2 4 e 17 16 :2 e :2 4 f 18
17 :2 f :2 4 10 19 18 :2 10 :2 4
11 1a 19 :2 11 :2 4 :2 e 1d e
:2 4 :2 d 1c d :2 4 :2 b 1a b
:2 4 :2 c 1b c :2 4 :2 d 1c d
:2 4 :2 10 1f 10 :2 4 :2 14 23 14
:2 4 :2 a 19 a :2 4 :2 f 1e f
:2 4 :2 b 1a b :2 4 :2 11 20 11
:2 4 :2 d 1c d :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 c 1b c
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 f 1e f :2 4 :2 12 21 12
:2 4 :2 d 1c d :2 4 :2 f 1e f
:2 4 :2 b 1a b :2 4 :2 f 19 f
:2 4 :2 13 1d 13 :2 4 :2 c 1b c
:2 4 :2 10 1f 10 :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 16 25 16
:2 4 :2 16 25 16 :2 4 :2 b 1a b
:2 4 d 16 15 :2 d :2 4 :2 10 1f
10 :2 4 :2 11 20 11 :2 4 :2 12 21
12 :2 4 9 12 11 :2 9 :2 4 c
15 14 :2 c :2 4 10 19 18 :2 10
:2 4 :2 11 20 11 :2 4 :2 17 26 17
:2 4 17 1c 1b :2 17 :2 4 18 1d
1c :2 18 :2 4 11 1a 19 :2 11 :2 4
12 1b 1a :2 12 :2 4 16 1f 1e
:2 16 :2 4 b 14 13 :2 b :2 4 :2 f
1e f :2 4 :2 13 22 13 :2 4 :2 14
23 14 :2 4 :2 6 1e 6 :2 4 :2 7
1f 7 :2 4 :2 a 22 a :2 4 :2 d
25 d :2 4 :2 8 20 8 :2 4 a
13 12 :2 a :2 4 :2 e 26 e :2 4
:3 d :2 4 :3 13 :2 4 :3 8 :2 4 :3 6 :2 4
:3 9 :2 4 :3 c :2 4 :3 c 4 7 b
14 :3 b :2 7 e 0 :2 7 11 f
10 1d e 18 e 1c a :6 7
e 0 :2 7 a :2 c 12 c 15
c 12 c 15 c 15 c 15
f 13 fffa :6 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e 7
4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 53 59 5c :2 53 6a 7f
8 :2 6a d 10 :2 6a 17 1a :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 2c 2f :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 2d 30 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
33 :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 31 :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 34 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 2f :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 2e :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 34
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 34 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 40 :2 16 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 24 27 :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 26 29 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 28 2b :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 28 2b :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 29 2c :2 6a b e :2 6a 13
16 1f 27 :2 1f 3a :2 16 :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
28 2b :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 29 2c :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
28 2b :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 29 2c :2 6a b
e :2 6a 13 16 1f 27 :2 1f 32
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 32 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 33 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
30 :2 16 :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 26 29 :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
2a 2d :2 6a 32 35 :2 6a :2 7 49
:2 4 7 :2 11 23 :2 2d 39 3c 4b
4e 4f :2 4b :2 23 :3 7 :2 d 12 1e
5b 5e :2 1e :2 7 52 :3 4 14 :2 4
14 :2 4 13 :2 4 f :2 4 e :2 4
13 :2 4 14 :2 4 13 :2 4 14 :2 4
12 :2 4 10 :2 4 e :2 4 14 :2 4
12 :2 4 f :2 4 12 :2 4 e :2 4
e :2 4 11 :2 4 11 :2 4 10 :2 4
13 :2 4 13 :2 4 14 4 8 11
1c :2 8 22 1f :2 2b :2 1f 7 :4 46
45 44 :2 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 6e 71 :2 21
75 78 :2 21 82 85 8e 96 :2 9f
:2 8e b5 :2 85 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 46
:2 7 57 :2 4 :4 9 8 7 :4 1f 1e
1d :2 7 :4 39 38 37 :2 7 :4 53 52
51 :2 7 f 18 24 :2 f 2a 27
:2 33 :2 27 e :2 7 :4 c b a 25
2e 3a :2 25 3f 3d :2 48 :2 3d 24
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
61 64 :2 24 71 74 :2 24 78 7b
:2 24 85 88 91 99 :2 a2 :2 91 b3
:2 88 :2 24 :2 d 58 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 61 64 :2 24 :2 d
58 :3 a :2 15 2b :2 34 44 :2 a 7
59 :4 f e d :4 29 28 27 :3 d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 61 64
:2 24 71 74 :2 24 78 7b :2 24 85
88 91 99 :2 a2 :2 91 b3 :2 88 :2 24
:2 d 58 :2 a d :2 17 29 :2 33 3f
42 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 61 64 :2 24 :2 d 58 :3 a
:2 15 2b :2 34 44 :2 a 3e 59 :2 7
49 :2 4 7 10 1b :2 7 1e 20
:2 1e 26 2f 37 :2 26 3a 3c :2 3a
:2 7 42 4b 53 :2 42 56 58 :2 56
:2 7 a :2 14 26 :2 30 3c 3f 4e
51 52 :2 4e :2 26 :3 a :2 10 15 21
5e 61 :2 21 6e 71 :2 21 75 78
:2 21 82 85 8e 96 :2 9f :2 8e b0
:2 85 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4e 51 52 :2 4e :2 26
:3 a :2 10 15 21 5e 61 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 41 :2 7 5a
:2 4 :4 9 8 :2 7 1a 7 24 7
1a 7 :4 4 8 11 1c :2 8 22
1f :2 2b :2 1f 7 :4 46 45 44 :2 7
:4 14 13 12 :2 7 11 1c 21 33
3e 43 :2 f :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 8a 8d :2 27 95
98 :2 27 a4 a7 ae b7 ba :2 a7
:2 27 :2 10 5c :2 d :2 a :4 16 :2 a 7
:3 31 b :2 14 1f 1d :2 28 :2 1d a
3d 46 4f :2 3d 52 54 :2 52 3c
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
61 64 :2 24 71 74 :2 24 78 7b
:2 24 85 88 91 99 :2 a2 :2 91 bf
:2 88 :2 24 :2 d 58 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 61 64 :2 24 :2 d
58 :3 a :2 15 2b :2 34 50 :2 a 57
:3 7 e 7 31 :2 4 :4 9 8 7
:4 27 26 25 :2 7 11 23 35 :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 74 77 :2 27 7b 7e :2 27
8a 8d :2 27 95 98 :2 27 a4 a7
ae b7 ba :2 a7 :2 27 :2 10 5c :2 d
:2 a :4 16 :2 a 7 :4 40 :3 4 12 :2 4
13 :2 1c 28 2f 38 40 :2 2f 44
:2 4d :2 28 27 5c :2 13 :2 4 e 15
1e 26 :2 15 2a :2 33 :2 e :2 4 d
:2 16 22 29 32 3e :2 29 42 :2 4b
:2 22 21 5a :2 d :2 4 12 19 22
2e :2 19 32 :2 3b :2 12 4 7 10
1c :2 7 21 1f :2 2a :2 1f 7 15
7 4 37 a 13 1f :2 a 24
22 :2 2d :2 22 7 15 7 39 37
a 13 1f :2 a 24 22 :2 2d :2 22
a 18 a 3d a 18 a :4 7
:4 4 7 10 18 :2 7 1b 1d :2 1b
7 15 7 11 21 f 10 1d
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
64 67 :2 27 74 77 :2 27 7b 7e
:2 27 8a 8d :2 27 95 98 :2 27 a4
a7 ae b7 ba :2 a7 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 1f a 13
1f :2 a 22 24 :2 22 14 24 12
13 20 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 67 6a :2 2a 77 7a :2 2a
7e 81 :2 2a 8d 90 :2 2a 98 9b
:2 2a a7 aa b1 ba bd :2 aa :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 26
d :2 18 1f 2d :2 d 32 34 :2 32
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 74 77 :2 27 7b 7e :2 27
88 8b 94 9c :2 a5 :2 94 ba :2 8b
:2 27 c2 c5 :2 27 cd d0 :2 27 d5
d8 :2 27 e5 e8 :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 :2 10 5b :3 d :2 18 2c :2 35
49 57 :2 d 36 :2 a 26 :3 7 17
20 29 31 :2 20 :2 17 7 a 13
21 :2 a 24 26 :2 24 a 14 20
29 31 :2 20 :2 14 a d 16 1e
:2 d 21 23 :2 21 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 88 8b 94 9c
:2 a5 :2 94 b6 :2 8b :2 27 :2 10 5b :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 :2 10 5b :3 d :2 18 2e :2 37
47 :2 d 25 :3 a 1a :2 23 a 28
:3 7 14 7 a 13 20 :2 a 23
26 :2 23 a 16 a 28 d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 61 64 :2 24
71 74 :2 24 78 7b :2 24 85 88
91 99 :2 a2 :2 91 b3 :2 88 :2 24 :2 d
58 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 61 64 :2 24 :2 d 58 :3 a :2 15
2b :2 34 44 :2 a :5 7 1a 29 37
3f 4a 54 25 :2 1a 7 a 13
1e :2 a 23 21 :2 2c :2 21 d 16
27 :2 d 2a 2c :2 2a d 20 :2 29
d 2e :2 a d :2 17 29 :2 33 3f
43 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 61 64 :2 24 71 74 :2 24
78 7b :2 24 85 88 91 99 :2 91
ab :2 88 :2 24 b3 b6 :2 24 be c1
:2 24 c6 c9 :2 24 d5 d8 :2 24 :2 d
59 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 61 64 :2 24 :2 d 58 :3 a :2 15
29 32 43 :2 29 47 54 :2 a 40
:2 7 a 13 24 :2 a 27 2a :2 27
30 39 4a :2 30 4d 50 :2 4d :2 a
d :2 17 29 :2 33 3f 43 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 61
64 :2 24 71 74 :2 24 78 7b :2 24
85 88 91 99 :2 91 ab :2 88 :2 24
b3 b6 :2 24 be c1 :2 24 c6 c9
:2 24 d5 d8 :2 24 :2 d 59 :2 a d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 61 64
:2 24 :2 d 58 :3 a :2 15 29 32 43
:2 29 47 54 :2 a 52 :2 7 a 13
21 :2 a 26 24 :2 2f :2 24 d 1b
24 2c :2 1b :2 d 30 33 :2 30 10
12 1b 12 1b 12 10 :3 12 15
16 23 fffa 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5e 5f :2 5b :2 32 :3 16
:2 1c 21 2d 6a 6d :2 2d 7a 7d
:2 2d 81 84 :2 2d 90 93 :2 2d 9b
9e :2 2d aa ad b4 bd c0 :2 ad
:2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10 d
:4 35 10 :2 12 14 12 14 12 14
12 1b 1d 12 1b 1d 12 14
12 14 25 27 10 :7 12 15 1d
20 28 16 18 25 14 16 23
25 fffa 10 :2 19 25 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5e 5f :2 5b :2 32 :3 16 :2 1c
21 2d 6a 6d :2 2d 7a 7d :2 2d
81 84 :2 2d 90 93 :2 2d 9b 9e
:2 2d aa ad b4 bd c0 :2 ad :2 2d
:2 16 62 :2 13 :2 10 :4 1c :2 10 d :7 a
e :2 17 23 20 :2 2c :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 64 67
:2 27 74 77 :2 27 7b 7e :2 27 88
8b 94 9c :2 a5 :2 94 b8 :2 8b :2 27
c0 c3 :2 27 cb ce :2 27 d3 d6
:2 27 e0 e3 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 64 67
:2 27 :2 10 5b :3 d :2 18 2c :2 35 47
52 :2 d 3c :2 a 7 3c d 16
24 :2 d 29 27 :2 32 :2 27 d :2 f
d :2 f 12 13 20 fffa d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 67 6a
:2 2a 77 7a :2 2a 7e 81 :2 2a 8d
90 :2 2a 98 9b :2 2a a7 aa b1
ba bd :2 aa :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 3f e :2 17 23 20
:2 2c :2 20 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 74 77 :2 27
7b 7e :2 27 88 8b 94 9c :2 a5
:2 94 b8 :2 8b :2 27 c0 c3 :2 27 cb
ce :2 27 d3 d6 :2 27 e0 e3 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 47 52 :2 d 3c :2 a
12 1d :2 12 1f f 18 f 18
f d :3 f 12 13 20 11 1e
fffa d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a 77 7a :2 2a 7e
81 :2 2a 8d 90 :2 2a 98 9b :2 2a
a7 aa b1 ba bd :2 aa :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 3f e
:2 17 23 20 :2 2c :2 20 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
74 77 :2 27 7b 7e :2 27 88 8b
94 9c :2 a5 :2 94 b8 :2 8b :2 27 c0
c3 :2 27 cb ce :2 27 d3 d6 :2 27
e3 e6 :2 27 :2 10 5c :2 d 10 :2 1a
2c :2 36 42 45 54 57 58 :2 54
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
:2 10 5b :3 d :2 18 2c :2 35 47 55
:2 d 3c :2 a :4 e :2 d 1d :2 26 :2 d
17 26 :2 17 d 24 :2 a 3f 3c
d :2 17 29 :2 33 3f 43 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 61
64 :2 24 71 74 :2 24 78 7b :2 24
85 88 91 99 :2 a2 :2 91 b3 :2 88
:2 24 bb be :2 24 c6 c9 :2 24 ce
d1 :2 24 de e1 :2 24 :2 d 59 :2 a
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 61
64 :2 24 :2 d 58 :3 a :2 15 29 :2 32
42 50 :2 a :4 7 a 13 1f :2 a
25 22 :2 2e :2 22 d f 1a 25
:3 f 18 23 2e f 18 23 2e
d :5 f 12 13 21 fffa d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 67 6a
:2 2a 77 7a :2 2a 7e 81 :2 2a 8d
90 :2 2a 98 9b :2 2a a7 aa b1
ba bd :2 aa :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 3e e :2 17 22 20
:2 2b :2 20 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 74 77 :2 27
7b 7e :2 27 88 8b 94 9c :2 a5
:2 94 b8 :2 8b :2 27 c0 c3 :2 27 cb
ce :2 27 d3 d6 :2 27 df e2 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 47 51 :2 d a 3b
11 :2 1a 25 23 :2 2e :2 23 :2 10 17
21 24 :2 10 27 29 :2 27 31 3a
4d :2 31 50 52 :2 50 58 13 21
:2 58 26 24 2f 42 :2 26 :2 24 :2 31
30 :2 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a 77 7a :2 2a 7e
81 :2 2a 8b 8e 97 9f :2 a8 :2 97
be :2 8e :2 2a c6 c9 :2 2a d1 d4
:2 2a d9 dc :2 2a e5 e8 :2 2a :2 13
5f :2 10 13 :2 1d 2f :2 39 45 48
57 5a 5b :2 57 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a :2 13 5e :3 10 :2 1b
2f :2 38 4d 57 :2 10 46 :2 d 10
19 27 :2 10 2c 2a 35 48 :2 2c
:2 2a 1a 25 32 3a 41 55 60
77 18 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5e 61 62 :2 5e :2 35 :3 19 :2 1f
24 30 6d 70 :2 30 7d 80 :2 30
84 87 :2 30 93 96 :2 30 9e a1
:2 30 ad b0 b7 c0 c3 :2 b0 :2 30
:2 19 65 :2 16 :2 13 :4 1f :2 13 10 :4 4b
:2 d 3e 3b :2 a 3e :2 7 1f :2 4
7 10 18 :2 7 1b 1d :2 1b a
13 1f :2 a 24 22 :2 2d :2 22 :4 42
41 :2 a 59 d 1a :2 59 1d 1f
:2 1d :2 a d :2 17 29 :2 33 3f 43
52 55 56 :2 52 :2 29 :3 d :2 13 18
24 61 64 :2 24 71 74 :2 24 78
7b :2 24 85 88 91 99 :2 a2 :2 91
bd :2 88 :2 24 c5 c8 :2 24 d0 d3
:2 24 d8 db :2 24 e8 eb :2 24 :2 d
59 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 61 64 :2 24 :2 d 58 :3 a :2 15
29 :2 32 4c 12 :2 a 21 :2 7 a
13 1e :2 a 24 21 :2 2d :2 21 d
f 18 f 18 d :2 f 12 13
20 fffa d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 67 6a :2 2a 77 7a :2 2a
7e 81 :2 2a 8d 90 :2 2a 98 9b
:2 2a a7 aa b1 ba bd :2 aa :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 41
e :2 17 22 20 :2 2b :2 20 d 10
12 15 25 32 fffa 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5e 5f :2 5b
:2 32 :3 16 :2 1c 21 2d 6a 6d :2 2d
7a 7d :2 2d 81 84 :2 2d 90 93
:2 2d 9b 9e :2 2d aa ad b4 bd
c0 :2 ad :2 2d :2 16 62 :2 13 :2 10 :4 1c
:2 10 d :3 3b 11 :2 1a 25 23 :2 2e
:2 23 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a 77 7a :2 2a 7e
81 :2 2a 8b 8e 97 9f :2 a8 :2 97
b9 :2 8e :2 2a c1 c4 :2 2a cc cf
:2 2a d4 d7 :2 2a e4 e7 :2 2a :2 13
5f :2 10 13 :2 1d 2f :2 39 45 48
57 5a 5b :2 57 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a :2 13 5e :3 10 :2 1b
2f :2 38 48 56 :2 10 3e :2 d 3b
:2 a 41 :2 7 1f :2 4 7 10 1c
:2 7 1f 21 :2 1f 27 30 38 :2 27
3b 3e :2 3b :3 7 11 7 42 :2 4
7 10 1b :2 7 20 1e :2 29 :2 1e
:4 b :2 a 18 :2 a 19 a 22 a
18 :2 a 19 a :5 7 13 7 3d
a e 10 :2 e a 19 :2 a 18
29 35 42 4b 54 :2 42 58 61
69 :2 58 22 2b 37 :2 22 3b 44
4f :2 3b 53 20 2b :2 53 2f 38
46 :2 2f 4a 53 5e :2 4a 22 2b
37 :2 22 3b 43 4d :2 18 a d
16 22 :2 d 27 25 :2 30 :2 25 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 64 67
:2 27 74 77 :2 27 7b 7e :2 27 88
8b 94 9c :2 a5 :2 94 b6 :2 8b :2 27
:2 10 5b :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 :2 10 5b :3 d
:2 18 2e :2 37 47 :2 d a 3f 10
19 25 :2 10 28 2b :2 28 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
74 77 :2 27 7b 7e :2 27 88 8b
94 9c :2 94 a9 :2 8b :2 27 b1 b4
:2 27 bc bf :2 27 c4 c7 :2 27 d4
d7 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 64 67 :2 27 :2 10
5b :3 d :2 18 2c 35 41 :2 2c 45
53 :2 d 2d 3f :2 a 12 a 19
a :4 7 b 14 1c :2 b 1f 21
:2 1f a 29 32 3a :2 29 3d 40
:2 3d 28 :2 a e 17 1f :2 e 22
24 :2 22 d 2b 34 3c :2 2b 3f
41 :2 3f 2a :3 d 18 d a 44
10 19 21 :2 10 24 26 :2 24 d
18 d a 28 44 11 1a 22
:2 11 25 27 :2 25 10 2e 37 3f
:2 2e 42 44 :2 42 2d :2 10 d 18
d a 47 44 10 19 21 :2 10
24 26 :2 24 d 18 d 28 44
:2 a 45 :2 7 :4 4 7 10 1c :2 7
21 1f :2 2a :2 1f 7 19 :2 7 16
:2 7 17 :2 7 14 1b 28 2b :2 14
:2 7 17 7 a 13 20 :2 a 23
25 :2 23 a :3 16 :2 a 1c a 27
14 24 12 13 20 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 7 e :2 17 22 20 :2 2b
:2 20 d 10 19 21 :2 10 24 26
:2 24 :2 13 18 19 26 17 25 :2 17
25 2e fffa 13 :2 1c 28 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5e 61 62 :2 5e :2 35 :3 19
:2 1f 24 30 6e 71 :2 30 7e 81
:2 30 85 88 :2 30 94 97 :2 30 9f
a2 :2 30 ae b1 b8 c1 c4 :2 b1
:2 30 :2 19 65 :2 16 :2 13 :4 1f :2 13 10
:4 28 :2 d 3b d 1f d :4 a :4 7
a 19 1c :2 19 d 16 1a d
12 13 1e 11 19 fffa d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 1e d 18 25 30
3d 48 55 60 6d 78 85 8b
8f 16 1c 1f 35 3b 43 :2 12
23 27 38 13 16 23 11 15
22 25 fffa d :2 16 22 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 1e e :2 17 22 20 :2 2b :2 20 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 75 78 :2 27 7c 7f :2 27
89 8c 95 9d :2 a6 :2 95 b9 :2 8c
:2 27 c1 c4 :2 27 cc cf :2 27 d4
d7 :2 27 e1 e4 :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 :2 10 5b :3 d :2 18 2c :2 35
47 52 :2 d 3b :2 a d 16 1e
:2 d 21 23 :2 21 d 17 d 25
d 17 d :4 a 19 d :8 f d
:8 f d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5c 5d :2 58 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :3 1e 7 1e d 14 22 25
:2 d 28 2a :2 28 14 21 d 17
d 17 d 17 13 20 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5c 5d :2 58 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8f 92 :2 2a 9a 9d :2 2a
a9 ac b3 bc bf :2 ac :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :4 2e 1e
:2 7 16 10 11 f 10 1d :2 e
1c a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 59 5a :2 55 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 3a 16 10 11 f 10 1d
:2 e 1c a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 59 5a :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8c 8f
:2 27 97 9a :2 27 a6 a9 b0 b9
bc :2 a9 :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 3a 16 10 1d :2 e 1c
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 59 5a :2 55 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :2 10 5d :2 d :2 a :4 16 :2 a 7
:4 3a :3 4 :3 17 4 7 10 18 :2 7
1b 1d :2 1b 23 2c 38 :2 23 3e
3b :2 47 :2 3b :2 7 5b d 19 :2 5b
1f 1c :2 28 :2 1c :2 7 :4 b :2 a 17
a 20 :2 7 3d :2 4 7 10 1c
:2 7 1f 21 :2 1f 7 15 :2 1e 7
23 :2 4 :4 8 7 :4 20 1f :2 7 :4 39
38 :2 7 :4 10 f e :3 7 14 7
25 :3 4 c :2 4 f 4 7 10
18 :2 7 1b 1d :2 1b a 13 1f
:2 a 24 22 :2 2d :2 22 a 12 1e
21 :2 12 2a 2d :2 12 11 14 :2 12
11 14 :2 12 11 14 :2 12 32 35
:2 12 3f 42 :2 12 a 7 3d d
16 22 :2 d 25 27 :2 25 a 12
11 14 :2 12 11 14 :2 12 43 46
:2 12 53 56 :2 12 11 14 :2 12 2c
2f :2 12 38 3b :2 12 11 14 :2 12
a 2a 3d a 12 11 14 :2 12
11 14 :2 12 11 14 :2 12 35 38
:2 12 41 44 :2 12 a :4 7 1f a
13 1f :2 a 25 22 :2 2e :2 22 42
d 19 :2 42 1f 1c :2 28 :2 1c :2 a
41 d 19 :2 41 1f 1c :2 28 :2 1c
:3 a 12 1c :3 a :2 13 1f a :4 e
:2 d 15 1f :3 d :2 16 22 d 1c
17 23 15 16 17 19 25 27
15 1f 10 15 2a 10 12 1f
22 14 17 14 17 25 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5b 5f 60 :2 5b :2 32 :3 16 :2 1c 21
2d 6c 6f :2 2d 7c 7f :2 2d 83
86 :2 2d 92 95 :2 2d 9d a0 :2 2d
ac af b6 bf c2 :2 af :2 2d :2 16
63 :2 13 :2 10 :4 1c :2 10 d :3 22 1c
17 19 15 27 17 19 15 27
16 18 1f 21 14 1b 1d 26
2d 2f 38 3a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
92 95 :2 2d 9d a0 :2 2d ac af
b6 bf c2 :2 af :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :4 22 d 19 d
:4 a 3c :2 7 :4 b :2 a 12 1b 22
:2 1b 2a :2 12 2d 2f :2 2d 3a 41
4a 51 :2 4a 59 :2 41 5d :2 3a 64
66 :2 3a :2 16 71 78 81 88 :2 81
90 :2 78 94 :2 71 :2 11 :2 a f :2 a
10 14 12 18 :2 12 a 10 19
1f 26 2f 31 33 :2 2f 36 :2 1f
:2 19 3b :2 10 3e 41 :2 3e 17 20
26 2d 36 38 3a :2 36 3d :2 26
:2 20 42 :2 17 45 48 :2 45 :4 10 4b
:3 d 12 14 16 :2 12 d 18 e
a d 11 :3 f 10 :2 1a 2c :2 36
42 45 54 58 59 :2 54 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8a 8d 96 9e
:2 a7 :2 96 b8 :2 8d :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 58
59 :2 54 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 :2 10 5c :3 d :2 18 2e :2 37
47 :2 d 15 :2 a 14 1c :2 12 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5c
5d :2 58 :2 2f :3 13 :2 19 1e 2a 69
6c :2 2a 79 7c :2 2a 80 83 :2 2a
8f 92 :2 2a 9a 9d :2 2a a9 ac
b3 bc bf :2 ac :2 2a :2 13 60 :2 10
:2 d :4 19 :2 d a :4 1e :2 7 a 13
1f :2 a 24 22 :2 2d :2 22 a 10
:2 a 15 :2 a 15 1d 20 :2 15 :2 a
15 1d 20 :2 15 a 7 3d d
16 22 :2 d 27 25 :2 30 :2 25 a
10 :2 a 12 17 1a :2 12 :2 a 12
17 1a :2 12 :2 a 15 a 45 3d
d 16 22 :2 d 27 25 :2 30 :2 25
d 15 :2 d 18 d :4 11 :2 10 1b
23 26 :2 1b :2 10 1b 23 26 :2 1b
:2 10 1b 23 26 :2 1b 10 26 :3 d
18 20 23 :2 18 d :4 11 :2 10 1b
23 26 :2 1b :2 10 1b 23 26 :2 1b
:2 10 1b 23 26 :2 1b 10 24 :2 d
44 :4 11 :2 10 18 1d 20 :2 18 :2 10
1b 10 29 10 18 1d 20 :2 18
17 1a :2 18 :2 10 1b 10 :4 14 :2 13
1e 26 29 :2 1e :2 13 1e 26 29
:2 1e :2 13 1e 26 29 :2 1e 13 29
:3 10 1b 23 26 :2 1b 17 1a :2 1b
17 1a :2 1b 17 1a :2 1b 17 1a
:2 1b 17 1a :2 1b 10 :4 d :4 11 :2 10
1b 23 26 :2 1b 4f 52 :2 1b 5a
5d :2 1b 10 24 :2 d :4 a :4 7 a
13 1f :2 a 25 22 :2 2e :2 22 :4 e
d 17 21 15 16 23 :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :3 26 11 :2 1a 25 23
:2 2e :2 23 :2 10 18 21 28 :2 21 31
:2 18 :2 10 18 1d 20 :2 18 :2 10 1b
23 26 :2 1b 17 1a :2 1b 2f 32
:2 1b 39 3c :2 1b 10 3e 13 :2 1d
2f :2 39 45 49 58 5c 5d :2 58
:2 2f :3 13 :2 19 1e 2a 69 6c :2 2a
79 7c :2 2a 80 83 :2 2a 8d 90
99 a1 :2 aa :2 99 bb :2 90 :2 2a c3
c6 :2 2a ce d1 :2 2a d6 d9 :2 2a
e4 e7 :2 2a :2 13 60 :2 10 13 :2 1d
2f :2 39 45 48 57 5b 5c :2 57
:2 2f :3 13 :2 19 1e 2a 69 6c :2 2a
:2 13 5f :3 10 :2 1b 2f :2 38 48 54
:2 10 :4 d 26 :2 a :4 e d 17 21
15 16 23 :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5f 60 :2 5b :2 32 :3 16
:2 1c 21 2d 6c 6f :2 2d 7c 7f
:2 2d 83 86 :2 2d 92 95 :2 2d 9d
a0 :2 2d ac af b6 bf c2 :2 af
:2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10 d
:3 25 11 :2 1a 25 23 :2 2e :2 23 :2 10
18 1d 20 :2 18 :2 10 1b 23 26
:2 1b 17 1a :2 1b 2f 32 :2 1b 39
3c :2 1b 10 3e 13 :2 1d 2f :2 39
45 49 58 5c 5d :2 58 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8d 90 99 a1
:2 aa :2 99 bb :2 90 :2 2a c3 c6 :2 2a
ce d1 :2 2a d6 d9 :2 2a e3 e6
:2 2a :2 13 60 :2 10 13 :2 1d 2f :2 39
45 48 57 5b 5c :2 57 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a :2 13 5f
:3 10 :2 1b 2f :2 38 48 53 :2 10 :4 d
25 :2 a :4 e d 17 21 15 16
23 :2 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5b 5f 60 :2 5b :2 32 :3 16 :2 1c 21
2d 6c 6f :2 2d 7c 7f :2 2d 83
86 :2 2d 92 95 :2 2d 9d a0 :2 2d
ac af b6 bf c2 :2 af :2 2d :2 16
63 :2 13 :2 10 :4 1c :2 10 d :3 25 11
:2 1a 25 23 :2 2e :2 23 :2 10 18 1d
20 :2 18 :2 10 1b 23 26 :2 1b 17
1a :2 1b 2f 32 :2 1b 39 3c :2 1b
10 3e 13 :2 1d 2f :2 39 45 49
58 5c 5d :2 58 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8d 90 99 a1 :2 aa :2 99
bb :2 90 :2 2a c3 c6 :2 2a ce d1
:2 2a d6 d9 :2 2a e3 e6 :2 2a :2 13
60 :2 10 13 :2 1d 2f :2 39 45 48
57 5b 5c :2 57 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a :2 13 5f :3 10 :2 1b
2f :2 38 48 53 :2 10 :4 d 25 :2 a
d 16 27 :2 d 2a 2c :2 2a 32
3b 4c :2 32 4f 52 :2 4f :3 d 18
20 23 :2 18 3b 3e 46 4f 61
:2 46 :2 3e :2 18 65 68 :2 18 d 56
:2 a 3e :2 7 :4 b :2 a 15 1e 25
:2 1e 33 :2 15 :2 a f :2 a 10 14
12 1c :2 12 a d 1a :2 23 2c
30 34 35 36 :2 34 39 :2 1a d
17 21 15 16 23 :2 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5f 60 :2 5b
:2 32 :3 16 :2 1c 21 2d 6c 6f :2 2d
7c 7f :2 2d 83 86 :2 2d 92 95
:2 2d 9d a0 :2 2d ac af b6 bf
c2 :2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c
:2 10 d :3 1c 11 :2 1a 26 23 :2 2f
:2 23 10 13 :2 1d 2f :2 39 45 49
58 5c 5d :2 58 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8d 90 99 a1 :2 aa :2 99
bb :2 90 :2 2a c3 c6 :2 2a ce d1
:2 2a d6 d9 :2 2a e3 e6 :2 2a :2 13
60 :2 10 13 :2 1d 2f :2 39 45 48
57 5b 5c :2 57 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a :2 13 5f :3 10 :2 1b
2f :2 38 48 53 :2 10 3f :3 d 18
20 23 :2 18 14 17 :2 18 14 17
:2 18 14 17 :2 18 31 34 :2 18 3b
3e :2 18 d 10 19 25 :2 10 2a
28 :2 33 :2 28 10 1b 23 26 :2 1b
10 43 10 1b 23 26 :2 1b 10
:4 d 10 19 25 :2 10 2a 28 :2 33
:2 28 :2 10 43 :2 d a f 11 13
:2 f a 1c e a 22 :2 7 a
13 1f :2 a 25 22 :2 2e :2 22 a
15 1e 25 :2 1e 34 :2 15 :2 a f
:2 a 10 14 12 1c :2 12 a d
1a :2 23 2c 30 34 35 36 :2 34
39 :2 1a d 17 21 15 16 23
:2 10 :2 19 25 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5b
5f 60 :2 5b :2 32 :3 16 :2 1c 21 2d
6c 6f :2 2d 7c 7f :2 2d 83 86
:2 2d 92 95 :2 2d 9d a0 :2 2d ac
af b6 bf c2 :2 af :2 2d :2 16 63
:2 13 :2 10 :4 1c :2 10 d :3 1c 11 :2 1a
26 23 :2 2f :2 23 10 13 :2 1d 2f
:2 39 45 49 58 5c 5d :2 58 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8d 90 99
a1 :2 aa :2 99 bb :2 90 :2 2a c3 c6
:2 2a ce d1 :2 2a d6 d9 :2 2a e3
e6 :2 2a :2 13 60 :2 10 13 :2 1d 2f
:2 39 45 48 57 5b 5c :2 57 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a :2 13
5f :3 10 :2 1b 2f :2 38 48 53 :2 10
3f :3 d 18 20 23 :2 18 14 17
:2 18 14 17 :2 18 14 17 :2 18 31
34 :2 18 3b 3e :2 18 14 17 :2 18
d a f 11 13 :2 f a 1c
e a 3e :3 7 f 14 17 :2 f
7 :5 4 c 11 14 :2 c :2 4 9
:2 11 :2 4 d 16 :2 7 a e :2 a
:2 13 1f a 14 a :2 13 1f a
:4 7 b :2 14 20 1d :2 29 :2 1d :3 a
39 :2 7 a 13 1b :2 a 1e 20
:2 1e 26 2f 3b :2 26 41 3e :2 4a
:2 3e :2 a 62 d 19 :2 62 1f 1c
:2 28 :2 1c :2 a 42 d 19 :2 42 1f
1c :2 28 :2 1c :4 3c 3b :2 42 41 :3 a
f :3 a 10 19 :2 a d 11 :2 d
:2 16 22 d 17 d :2 16 22 d
:4 a e :2 17 22 20 :2 2b :2 20 d
10 16 :3 10 :2 19 25 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5f 60 :2 5b :2 32 :3 16 :2 1c
21 2d 6c 6f :2 2d 7c 7f :2 2d
83 86 :2 2d 92 95 :2 2d 9d a0
:2 2d ac af b6 bf c2 :2 af :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :3 3b
12 d 3b 10 16 :3 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5f 60 :2 5b
:2 32 :3 16 :2 1c 21 2d 6c 6f :2 2d
7c 7f :2 2d 83 86 :2 2d 92 95
:2 2d 9d a0 :2 2d ac af b6 bf
c2 :2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c
:2 10 d :7 a 51 :3 7 16 :2 7 17
7 a 13 1b :2 a 1e 20 :2 1e
d 14 20 23 :2 d 26 28 :2 26
d :3 1c :2 d 19 d 2c 10 1e
27 2f :2 1e :2 10 33 36 :2 33 1a
20 38 18 19 26 17 25 17
:2 13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 5e
62 63 :2 5e :2 35 :3 19 :2 1f 24 30
6f 72 :2 30 7f 82 :2 30 86 89
:2 30 95 98 :2 30 a0 a3 :2 30 af
b2 b9 c2 c5 :2 b2 :2 30 :2 19 66
:2 16 :2 13 :4 1f :2 13 10 :3 38 13 1c
28 :2 13 2b 2d :2 2b 16 1c :3 16
:2 1f 2b 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 61 65
66 :2 61 :2 38 :3 1c :2 22 27 33 72
75 :2 33 82 85 :2 33 89 8c :2 33
98 9b :2 33 a3 a6 :2 33 b2 b5
bc c5 c8 :2 b5 :2 33 :2 1c 69 :2 19
:2 16 :4 22 :2 16 13 :3 2f 16 :2 20 32
:2 3c 48 4c 5b 5f 60 :2 5b :2 32
:3 16 :2 1c 21 2d 6c 6f :2 2d 7c
7f :2 2d 83 86 :2 2d 90 93 9c
a4 :2 ad :2 9c ce :2 93 :2 2d d6 d9
:2 2d e1 e4 :2 2d e9 ec :2 2d f5
f8 :2 2d :2 16 63 :2 13 16 :2 20 32
:2 3c 48 4b 5a 5e 5f :2 5a :2 32
:3 16 :2 1c 21 2d 6c 6f :2 2d :2 16
62 :3 13 :2 1e 32 :2 3b 5b 1b :2 13
2f :2 10 38 :2 d :5 a 16 22 2f
3d 48 52 5e 1b 28 36 43
51 1b 28 34 3e 46 4f 57
1b 27 33 40 4b 56 1b 25
30 3c 48 51 5c :2 48 60 1b
21 27 :2 16 a d 16 19 :2 16
10 16 :3 10 :2 19 25 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5f 60 :2 5b :2 32 :3 16 :2 1c
21 2d 6c 6f :2 2d 7c 7f :2 2d
83 86 :2 2d 92 95 :2 2d 9d a0
:2 2d ac af b6 bf c2 :2 af :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :3 1b
10 1b 19 :2 24 :2 19 10 1c :2 25
10 2e :2 d 10 :2 1a 2c :2 36 42
46 55 59 5a :2 55 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8a 8d 96 9e :2 96
a9 :2 8d :2 27 b1 b4 :2 27 bc bf
:2 27 c4 c7 :2 27 d3 d6 :2 27 :2 10
5d :2 d 10 :2 1a 2c :2 36 42 45
54 58 59 :2 54 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 :2 10 5c :3 d :2 18
2c 36 43 :2 d a 1b 11 18
24 27 :2 11 2a 2c :2 2a 10 36
3d 4b 4e :2 36 51 53 :2 51 35
:2 10 17 24 39 46 53 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5b 5f 60 :2 5b :2 32 :3 16 :2 1c 21
2d 6c 6f :2 2d 7c 7f :2 2d 83
86 :2 2d 92 95 :2 2d 9d a0 :2 2d
ac af b6 bf c2 :2 af :2 2d :2 16
63 :2 13 :2 10 :4 1c :2 10 d :4 58 1b
:4 a 22 d 16 21 :2 d 27 24
:2 30 :2 24 d 1b :2 d 1c d 44
:3 a 16 22 2f 3d 48 52 5e
1b 28 36 43 51 1b 28 34
3e 46 4f 57 1b 27 33 40
4b 56 1b 25 30 3c 48 4b
4e 54 5a :2 16 a d 16 18
:2 16 d 16 1c 1e :2 16 d a
1a 10 19 1b :2 19 :2 d 1d 1a
:2 a d 15 13 1e 2a :2 15 :2 13
:2 d 2d :2 a :4 7 9 7 :3 4 8
1 7 d :3 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 52 56 57 :2 52 :2 29 :3 d
:2 13 18 24 63 66 :2 24 73 76
:2 24 7a 7d :2 24 89 8c :2 24 94
97 :2 24 a3 a6 ad b6 b9 :2 a6
:2 24 :2 d 5a :2 a :2 7 :4 13 :2 7 4
:3 1 8 13 11 :2 1c :2 11 7 36
3f 41 :2 3f 35 :2 7 48 51 54
:2 51 5a a 12 :2 5a 15 17 :2 15
:2 48 47 :2 7 a :2 14 26 :2 30 3c
40 4f 53 54 :2 4f :2 26 :3 a :2 10
15 21 60 63 :2 21 70 73 :2 21
77 7a :2 21 84 87 90 98 :2 90
a3 :2 87 :2 21 ab ae :2 21 b6 b9
:2 21 be c1 :2 21 cd d0 :2 21 :2 a
57 :2 7 a :2 14 26 :2 30 3c 3f
4e 52 53 :2 4e :2 26 :3 a :2 10 15
21 60 63 :2 21 :2 a 56 :3 7 :2 12
26 30 3d :2 7 1a :2 4 7 11
14 :2 11 7 12 :2 7 15 :2 7 14
:2 7 c :4 7 c :2 7 10 a :7 c
:3 a d 12 :2 d :2 16 22 d 18
d :2 16 22 d :4 a e :2 17 23
20 :2 2c :2 20 :3 d 3c :2 a :4 e d
29 :2 34 3b 46 :2 29 50 52 :2 50
:2 d 14 1d 24 :2 1d 2e :2 14 31
33 :2 31 :3 d 18 d 35 :2 a d
:2 18 1f 2b :2 d 35 38 :2 35 10
12 15 :2 12 1a 13 1d 15 21
15 20 15 22 15 21 15 22
19 21 13 1a 16 22 :3 20 16
:2 1f 2b 16 27 16 :2 1f 2b 16
:4 13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 5e 62 63 :2 5e
:2 35 :3 19 :2 1f 24 30 6f 72 :2 30
7f 82 :2 30 86 89 :2 30 95 98
:2 30 a0 a3 :2 30 af b2 b9 c2
c5 :2 b2 :2 30 :2 19 66 :2 16 :2 13 :4 1f
:2 13 10 :4 17 :3 d 1c :2 d 1d :2 d
1c :2 d 1d :2 d 1d :2 d 1d :2 d
1b :2 d 12 d 3a :2 a d f
12 :2 f :4 19 18 :2 d 17 10 :5 12
16 1e 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5f 60 :2 5b
:2 32 :3 16 :2 1c 21 2d 6c 6f :2 2d
7c 7f :2 2d 83 86 :2 2d 92 95
:2 2d 9d a0 :2 2d ac af b6 bf
c2 :2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c
:2 10 d :4 30 :2 a :4 e d :4 11 :2 10
1f 26 32 35 :2 26 3a 3d :2 1f
10 2a :3 d 1c 23 2f 32 :2 23
3e 41 :2 1c d 26 :2 a :4 e :2 d
1d 24 31 34 :2 24 3f 42 :2 1d
d 25 :2 a :4 e d :4 11 :2 10 20
27 34 37 :2 27 3c 3f :2 20 10
2b :3 d 1d 24 31 34 :2 24 41
44 :2 1d d 27 :2 a :4 e :2 d 1d
24 31 34 :2 24 40 43 :2 1d d
26 :2 a :4 e d :4 11 :2 10 1f 26
32 35 :2 26 3a 3d :2 1f 10 2a
:3 d 1c 23 2f 32 :2 23 3e 41
:2 1c d 26 :2 a :4 e d :4 11 :2 10
20 27 34 37 :2 27 3c 3f :2 20
10 2b :3 d 1d 24 31 34 :2 24
41 44 :2 1d d 27 :3 a f 11
13 :2 f :2 a 17 a 7 b 16
a 10 :3 a :2 13 1f a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 59 5a :2 55 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8c 8f :2 27 97 9a
:2 27 a6 a9 b0 b9 bc :2 a9 :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 16
a c f :2 c 14 d 17 f
1b f 1a f 1c f 1b f
1c 13 1b d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5c 5d
:2 58 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a 79 7c :2 2a 80 83 :2 2a 8f
92 :2 2a 9a 9d :2 2a a9 ac b3
bc bf :2 ac :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :4 11 :2 7 16 :2 4 :4 8
7 a 13 1b :2 a 1e 20 :2 1e
14 1d 21 38 12 13 1e 11
22 2a 31 49 51 58 :2 d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5c 5d
:2 58 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a 79 7c :2 2a 80 83 :2 2a 8f
92 :2 2a 9a 9d :2 2a a9 ac b3
bc bf :2 ac :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :4 22 a 18 :2 a :4 7
24 :2 4 e 1b 26 30 33 4b
5a c 14 17 1c 2b 31 34
42 45 d 10 1d :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 52 56 57 :2 52
:2 29 :3 d :2 13 18 24 63 66 :2 24
73 76 :2 24 7a 7d :2 24 89 8c
:2 24 94 97 :2 24 a3 a6 ad b6
b9 :2 a6 :2 24 :2 d 5a :2 a :2 7 :4 13
:2 7 4 :3 1 7 10 1c :2 7 21
1f :2 2a :2 1f 7 f 19 :3 7 :2 10
1c 7 16 11 :4 c f 10 18
f 1e a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 59 5a :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8c 8f
:2 27 97 9a :2 27 a6 a9 b0 b9
bc :2 a9 :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 3a b :2 14 1f 1d :2 28
:2 1d a 19 14 f 13 24 f
13 24 f 13 24 f 13 24
12 13 1c 16 d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5c
5d :2 58 :2 2f :3 13 :2 19 1e 2a 69
6c :2 2a 79 7c :2 2a 80 83 :2 2a
8f 92 :2 2a 9a 9d :2 2a a9 ac
b3 bc bf :2 ac :2 2a :2 13 60 :2 10
:2 d :4 19 :2 d a :3 38 e :2 17 22
20 :2 2b :2 20 d 1c 17 15 16
1e 19 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5f 60 :2 5b
:2 32 :3 16 :2 1c 21 2d 6c 6f :2 2d
7c 7f :2 2d 83 86 :2 2d 92 95
:2 2d 9d a0 :2 2d ac af b6 bf
c2 :2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c
:2 10 d :4 3b :2 a 38 :3 7 c 1e
2a 3c 45 47 57 65 68 73
76 82 85 90 93 9f b2 7
a 1a 27 2a 3a 7 17 1a
2e 31 43 46 5b 60 6f 83
85 94 ad 7 17 1a 2e 31
43 46 5b 60 6f 83 85 94
ad 7 17 1a 2e 31 43 46
5b 60 6f 83 85 94 ad 7
17 1a 2e 31 43 46 5b 60
6f 83 85 94 ad 7 a 15
18 24 27 32 35 3d 40 51
54 66 69 77 87 94 9f ac
af bc bf c9 cc d6 d 1c
2e 39 3c 4c 5d 73 7e 8b
9b 9e a9 b8 c7 d0 e0 ef
15 24 4b 64 c 1e 23 28
37 3d 40 49 4e 7 c 12
17 2b 31 34 3f 50 53 5f
62 7 c 15 1a 1c 29 7
c 1d 22 24 2c 2e 7 c
12 17 1d 22 24 2c 2e 7
c 12 17 29 2f 31 3a 3d
7 c 12 17 27 2d 2f 38
3b 7 c 12 17 21 27 2a
37 39 12 15 2b 2e 45 48
5e 61 17 7 17 a :2 14 26
:2 30 3c 3f 4e 52 53 :2 4e :2 26
:3 a :2 10 15 21 60 63 :2 21 :2 a
56 :3 7 e 7 3a a 14 16
:2 14 a f 21 24 2e 40 49
4b 58 66 69 74 77 83 86
91 94 a0 a2 a d 1d 2a
2d 3d a 1a 1d 33 36 50
52 60 73 75 83 aa b5 bf
d7 ec f9 112 11d 127 13f 154
161 163 179 17c 192 195 1a7 1aa
1b9 1d2 a 1a 1d 33 36 50
52 60 73 75 83 aa b5 bf
d7 ec f9 112 11d 127 13f 154
161 163 179 17c 192 195 1a7 1aa
1b9 1d2 a 1a 1d 33 36 50
52 60 73 75 83 aa b5 bf
d7 ec f9 112 11d 127 13f 154
161 163 179 17c 192 195 1a7 1aa
1b9 1d2 a 1a 1d 33 36 50
52 60 73 75 83 aa b5 bf
d7 ec f9 112 11d 127 13f 154
161 163 179 17c 192 195 1a7 1aa
1b9 1d2 a d 19 1c 28 2b
36 39 41 44 55 58 6a 6d
7b 8b 98 a3 b0 b3 c0 c3
cd d0 da a d 1a 24 26
32 35 45 50 53 5e 61 77
82 8f 9f a2 ad bc bf c8
cb d5 de e1 f0 f3 104 a
c 1b 1d 2d 40 42 f 1e
21 26 30 35 38 3f 41 a
f 19 1f 22 2d 2f a f
15 1a 24 2a 2d 38 3b a
f 19 1e 21 28 2a 36 3b
41 46 50 56 59 65 67 a
f 15 1a 2e 34 37 42 53
56 62 65 a f 15 1a 2c
32 34 40 43 a f 15 1a
2c 32 35 3f 42 a f 15
1a 2a 30 32 3e 41 a f
15 1a 2a 30 33 3d 40 13
1a a 1a d :2 17 29 :2 33 3f
42 51 55 56 :2 51 :2 29 :3 d :2 13
18 24 63 66 :2 24 :2 d 59 :3 a
11 a 18 a 12 1c :3 a :2 13
1f a 19 14 1c 2a 38 46
12 27 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5c 5d :2 58
:2 2f :3 13 :2 19 1e 2a 69 6c :2 2a
79 7c :2 2a 80 83 :2 2a 8f 92
:2 2a 9a 9d :2 2a a9 ac b3 bc
bf :2 ac :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :3 7 19 15 39 3d 4e
d 11 22 31 35 46 d 11
22 12 13 29 35 4a 61 16
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5c 5d :2 58 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8f 92 :2 2a 9a
9d :2 2a a9 ac b3 bc bf :2 ac
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 7 a f 21 24 2e 40 49
4b 58 66 69 74 77 83 86
91 94 a0 a2 a d 1d 2a
2d 3d a 1a 1d 31 34 f
11 25 27 41 43 51 64 66
74 9b a6 b0 c8 dd ea 103
10e 118 130 145 152 154 f 13
27 2b 45 47 55 68 6a 78
9f aa b4 cc e1 ee 107 112
11c 134 149 156 158 f 13 22
14 a 1a 1d 32 35 f 11
27 29 43 45 53 66 68 76
9d a8 b2 ca df ec 105 110
11a 132 147 154 156 f 13 27
2b 45 47 55 68 6a 78 9f
aa b4 cc e1 ee 107 112 11c
134 149 156 158 f 13 22 14
a 1a 1d 31 34 f 11 25
27 41 43 51 64 66 74 9b
a6 b0 c8 dd ea 103 10e 118
130 145 152 154 f 13 27 2b
45 47 55 68 6a 78 9f aa
b4 cc e1 ee 107 112 11c 134
149 156 158 f 13 22 14 a
1a 1d 31 34 f 11 25 27
41 43 51 64 66 74 9b a6
b0 c8 dd ea 103 10e 118 130
145 152 154 f 13 27 2b 45
47 55 68 6a 78 9f aa b4
cc e1 ee 107 112 11c 134 149
156 158 f 13 22 14 a d
18 1b 27 2a 35 38 40 43
54 57 69 6c 7a 8a 97 a2
af b2 bf c2 cc cf d9 a
d 1a 24 26 32 35 45 50
53 5e 61 77 82 8f 9f a2
ad a d 16 19 23 2c 2f
3e 41 52 a c 1b 1d 2d
40 42 f 1e a f 14 26
2d 30 37 3b 46 4a a f
14 26 2d 30 37 3b 46 4a
a f 19 1e 21 28 2a a
f 19 1f 22 2d 2f a f
15 1a 24 2a 2d 38 3b a
f 19 1e 21 28 2a 36 3b
41 46 50 56 59 65 67 a
f 15 1a 2e 34 37 42 53
56 62 65 a f 15 1a 24
2a 2c 37 3a a f 15 1a
2c 32 34 40 43 4e 53 59
5e 70 76 79 83 86 a f
15 1a 2a 30 32 3e 41 4c
51 57 5c 6c 72 75 7f 82
a f 15 1a 20 25 27 2f
31 15 18 2e 31 48 4b 61
64 13 1a a 1a d :2 17 29
:2 33 3f 42 51 55 56 :2 51 :2 29
:3 d :2 13 18 24 63 66 :2 24 :2 d
59 :3 a 11 a :4 7 :4 4 1 9
12 9 a :2 14 26 :2 30 3c 40
4f 53 54 :2 4f :2 26 :3 a :2 10 15
21 60 63 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 57 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4c 50 51 :2 4c :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 54 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
3722
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 :4 14
:4 15 :4 16 :4 17 :4 18
:4 19 :4 1a :4 1b :4 1c
:4 1d 2 :4 1e :2 1
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :7 26 :7 27
:7 28 :7 29 :7 2a :7 2b
:7 2c :7 2d :7 2e :7 2f
:7 30 :7 31 :7 32 :7 33
:7 34 :5 35 :7 36 :7 37
:7 38 :7 39 :7 3a :5 3b
:7 3c :7 3d :7 3e :7 3f
:7 40 :7 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :6 5a :6 5b
:6 5c :6 5d :6 5e :6 5f
:6 60 :6 61 :6 62 :7 63
:6 64 :6 65 :6 66 :7 67
:7 68 :7 69 :6 6a :6 6b
:7 6c :7 6d :7 6e :7 6f
:7 70 :7 71 :6 72 :6 73
:6 74 :6 75 :6 76 :6 77
:6 78 :6 79 :7 7a :6 7b
:5 7c :5 7d :5 7e :5 7f
:5 80 :5 81 :5 82 :7 85
:2 87 0 :2 87 88
89 :2 8a :2 8b :2 8c
88 :5 87 :2 8e 0
:2 8e 90 91 :2 92
:2 93 :2 94 :2 95 :2 96
:2 97 98 99 90
:5 8e :7 9c :7 9f :7 a2
:7 a4 :b a6 :11 a7 a8
:2 a7 :2 a8 :2 a7 :2 a8
:2 a7 :2 a9 :2 a7 :2 a9
:2 a7 :2 a9 :2 a7 :2 a9
:2 a7 :2 aa :2 a7 :2 aa
:2 a7 :2 aa :2 a7 :2 aa
:2 a7 :2 ab :2 a7 :9 ab
:2 a7 :2 ac :2 a7 :9 ac
:2 a7 :2 ad :2 a7 :9 ad
:2 a7 :2 ae :2 a7 :9 ae
:2 a7 :2 af :2 a7 :9 af
:2 a7 :2 b0 :2 a7 :9 b0
:2 a7 :2 b1 :2 a7 :9 b1
:2 a7 :2 b2 :2 a7 :9 b2
:2 a7 :2 b3 :2 a7 :2 b3
:2 a7 :2 b3 :2 a7 :2 b3
:2 a7 :2 b4 :2 a7 :2 b4
:2 a7 :2 b4 :2 a7 :2 b4
:2 a7 :2 b5 :2 a7 :2 b5
:2 a7 :2 b5 :2 a7 :2 b5
:2 a7 :2 b6 :2 a7 :2 b6
:2 a7 :2 b6 :2 a7 :2 b6
:2 a7 :2 b7 :2 a7 :2 b7
:2 a7 :2 b7 :2 a7 :2 b7
:2 a7 :2 b8 :2 a7 :9 b8
:2 a7 :2 b9 :2 a7 :2 b9
:2 a7 :2 b9 :2 a7 :2 b9
:2 a7 :2 ba :2 a7 :2 ba
:2 a7 :2 ba :2 a7 :2 ba
:2 a7 :2 bb :2 a7 :2 bb
:2 a7 :2 bb :2 a7 :2 bb
:2 a7 :2 bc :2 a7 :2 bc
:2 a7 :2 bc :2 a7 :2 bc
:2 a7 :2 bd :2 a7 :9 bd
:2 a7 :2 be :2 a7 :9 be
:2 a7 :2 bf :2 a7 :9 bf
:2 a7 :2 c0 :2 a7 :9 c0
:2 a7 :2 c1 :2 a7 :2 c1
:2 a7 :2 c1 :2 a7 :2 c1
:2 a7 :2 c2 :2 a7 :2 c2
:2 a7 :2 c2 :2 a7 :2 c2
:2 a7 :2 c2 :4 a7 :3 a6
:11 c5 :b c6 :3 c5 :3 ce
:3 cf :3 d0 :3 d1 :3 d2
:3 d3 :3 d4 :3 d5 :3 d6
:3 d7 :3 d9 :3 db :3 dd
:3 df :3 e0 :3 e1 :3 e2
:3 e3 :3 e4 :3 e5 :3 e6
:3 e7 :3 e9 :3 ea :14 ef
:11 f0 :20 f1 :3 f0 :11 f3
:b f4 :3 f3 :9 f6 :3 ef
:1e f9 :c fa :2 f9 :14 fb
:11 fc :20 fd :3 fc :11 ff
:b 100 :3 ff :9 102 103
fb :e 103 :11 104 :20 105
:3 104 :11 107 :b 108 :3 107
:9 10a 103 :3 fb fa
:2 f9 :1f 10e :11 10f :20 110
:3 10f :11 112 :b 113 :3 112
:9 115 :3 10e :6 119 :3 11a
119 :3 11c 11b :3 119
:14 11f :6 120 :2 11f :6 122
123 124 122 :5 125
121 127 :5 128 :3 127
:2 129 :5 12b :11 12c :24 12d
:3 12c :2 12a :6 129 126
:3 120 :16 132 :11 133 :20 134
:3 133 :11 136 :b 137 :3 136
:9 139 :3 132 :3 13b 120
:2 11f :e 13e :4 140 :5 141
13f 143 :5 144 :3 143
:2 145 :5 147 :11 148 :24 149
:3 148 :2 146 :6 145 142
:6 13e :3 14f :14 153 :d 155
:14 157 :d 159 :b 15b :3 15c
15d 15b :b 15d :3 15e
15d 15b :b 160 :3 161
160 :3 163 162 :3 160
15f :3 15b :9 167 :3 168
:2 16a 16b :2 16c 16a
:5 16d 169 16f :5 170
:3 16f :2 171 :5 173 :11 174
:24 175 :3 174 :2 172 :6 171
16e :3 167 :9 17a :2 17c
17d :2 17e 17c :5 17f
17b 181 :5 182 :3 181
:2 183 :5 185 :11 186 :24 187
:3 186 :2 184 :6 183 180
:3 17a :b 18c :11 18d :30 18e
:3 18d :11 190 :b 191 :3 190
:a 193 :3 18c :3 17a :a 197
:9 198 :a 199 :9 19a :11 19b
:20 19c :3 19b :11 19e :b 19f
:3 19e :9 1a1 :3 19a :5 1a3
:3 198 :3 1a5 :9 1a7 :3 1a8
1a7 :11 1ab :20 1ac :3 1ab
:11 1ae :b 1af :3 1ae :9 1b1
1a9 :3 1a7 :7 1b9 1ba
:3 1b9 :b 1bc :9 1bd :5 1be
:3 1bd :11 1c1 :2e 1c2 :3 1c1
:11 1c4 :b 1c5 :3 1c4 :c 1c7
:3 1bc :14 1ca :11 1cb :2e 1cc
:3 1cb :11 1ce :b 1cf :3 1ce
:c 1d1 :3 1ca :b 1d3 :c 1d4
1d7 :2 1d8 :2 1d9 1da
1dc 1dd 1de 1df
1e0 :2 1e1 1d7 :5 1e2
1d5 1e4 :5 1e5 :3 1e4
:2 1e6 :5 1e8 :11 1e9 :24 1ea
:3 1e9 :2 1e7 :6 1e6 1e3
:4 1d4 :2 1f1 :2 1f2 :2 1f3
:2 1f4 :3 1f5 :3 1f6 :2 1f7
:4 1f8 1fa 1fb 1fc
1fd 1fe 1ff 200
201 :4 202 :3 203 :4 204
1f1 :5 205 1ef 207
:5 208 :3 207 :2 209 :5 20b
:11 20c :24 20d :3 20c :2 20a
:6 209 206 :4 1ee :3 1d4
:a 213 :11 214 :30 215 :3 214
:11 217 :b 218 :3 217 :a 21a
:3 213 21c 1d3 :b 21c
21f 220 221 223
224 225 226 :2 227
21f :5 228 21d 22a
:5 22b :3 22a :2 22c :5 22e
:11 22f :24 230 :3 22f :2 22d
:6 22c 229 :3 21c :a 235
:11 236 :30 237 :3 236 :11 239
:b 23a :3 239 :a 23c :3 235
:2 244 245 :2 246 :2 248
:2 249 24a 24c 24d
24e 24f 250 :2 251
:2 252 243 :5 253 241
255 :5 256 :3 255 :2 257
:5 259 :11 25a :24 25b :3 25a
:2 258 :6 257 254 :3 21c
:a 260 :11 261 :30 262 :3 261
:11 264 :b 265 :3 264 :a 267
:3 260 :5 26a :5 26e :6 26f
:3 26a 21c 1d3 :11 273
:30 274 :3 273 :11 276 :b 277
:3 276 :a 279 271 :3 1d3
:b 27d 281 :3 282 283
284 :4 285 :4 286 288
289 28a 28b 28c
28d 28e :2 28f 281
:5 290 27f 292 :5 293
:3 292 :2 294 :5 296 :11 297
:24 298 :3 297 :2 295 :6 294
291 :3 27d :a 29d :11 29e
:30 29f :3 29e :11 2a1 :b 2a2
:3 2a1 :a 2a4 2a5 29d
:a 2a5 :14 2a6 :2 2a7 :2 2a6
:8 2a7 :5 2a6 :11 2a8 :30 2a9
:3 2a8 :11 2ab :b 2ac :3 2ab
:a 2ae 2a7 :2 2a6 :d 2b1
:8 2b4 2b5 2b4 :5 2b6
2b3 2b8 :5 2b9 :3 2b8
:2 2ba :5 2bc :11 2bd :24 2be
:3 2bd :2 2bb :6 2ba 2b7
:6 2b1 2a5 :3 29d :3 27d
:3 167 :9 2c9 :13 2cf :2 2d0
:2 2cf :4 2d0 :2 2cf :11 2d1
:30 2d2 :3 2d1 :11 2d4 :b 2d5
:3 2d4 :7 2d7 2d8 :2 2d7
2d0 :2 2cf :b 2dc 2df
:2 2e0 :2 2e1 2e3 2e4
2e5 2e6 :2 2e7 2df
:5 2e8 2dd 2ea :5 2eb
:3 2ea :2 2ec :5 2ee :11 2ef
:24 2f0 :3 2ef :2 2ed :6 2ec
2e9 :3 2dc :a 2f7 2fd
2fe :3 2ff 2fa :5 300
2f8 302 :5 303 :3 302
:2 304 :5 306 :11 307 :24 308
:3 307 :2 305 :6 304 301
:3 2f7 :a 30d :11 30e :30 30f
:3 30e :11 311 :b 312 :3 311
:a 314 :3 30d :3 2f7 :3 2dc
:3 2c9 :14 31b :3 31c :3 31b
:b 31f :5 321 :3 322 :3 323
321 :3 325 :3 326 324
:3 321 :3 329 31f :5 32c
:3 32e :e 330 :b 331 :2 332
:2 331 :a 332 :8 333 :3 330
:b 335 :11 336 :20 337 :3 336
:11 339 :b 33a :3 339 :9 33c
33d 335 :9 33d :11 33e
:2e 33f :3 33e :11 341 :b 342
:3 341 :c 344 33d :3 335
32c :3 347 346 :3 32c
:16 349 :16 34a :3 34b 34c
34a :9 34c :3 34d 34e
34c 34a :16 34e :3 34f
350 34e 34a :9 350
:3 351 350 :3 34a :3 349
32a :3 31f :b 35b :3 35c
:3 35e :3 35f :8 362 :3 363
:9 36a :5 36b :3 36c 36a
:2 370 371 :2 372 370
:5 373 36f 375 :5 376
:3 375 :2 377 :5 379 :11 37a
:24 37b :3 37a :2 378 :6 377
374 :3 36d :a 380 :9 381
384 386 387 :2 388
:2 389 38a :3 38b 384
:5 38c 382 38e :5 38f
:3 38e :2 390 :5 392 :11 393
:24 394 :3 393 :2 391 :6 390
38d :6 381 380 :3 39f
39e :3 380 36d :3 36a
:5 3a3 :3 3a6 3a8 3a9
:2 3aa :2 3ab 3a6 :5 3ac
3a4 3ae :5 3af :3 3ae
:2 3b0 :5 3b2 :11 3b3 :24 3b4
:3 3b3 :2 3b1 :6 3b0 3ad
:3 3a3 :d 3bb :6 3bc 3bd
:4 3be :3 3bf :4 3c0 3bb
:5 3c1 3b9 3c3 :5 3c4
:3 3c3 :2 3c5 :5 3c7 :11 3c8
:24 3c9 :3 3c8 :2 3c6 :6 3c5
3c2 :3 3a3 :a 3ce :11 3cf
:30 3d0 :3 3cf :11 3d2 :b 3d3
:3 3d2 :a 3d5 :3 3ce :9 3d8
:3 3d9 3d8 :3 3db 3da
:3 3d8 3df 3e1 3e2
3e3 3e4 3e5 3e6
3e7 3e8 3e9 3ed
3ee 3ef 3f0 3f1
3f2 3f3 3f4 3f5
3df :6 3f7 :5 3f8 3f7
:5 3fa 3f9 :3 3f7 3de
3fd :5 3fe :3 3fd :2 3ff
:5 401 :11 402 :24 403 :3 402
:2 400 :6 3ff 3fc :3 3a3
407 3a3 :a 407 :2 40b
:2 40c :2 40d :2 40e :2 40f
40b :6 410 :5 411 410
:5 413 412 :3 410 40a
416 :5 417 :3 416 :2 418
:5 41a :11 41b :24 41c :3 41b
:2 419 :6 418 415 :4 407
:3 3a3 425 426 427
428 :2 429 42a :2 42b
425 :6 42c :5 42d 42c
:5 42f 42e :3 42c 424
432 :5 433 :3 432 :2 434
:5 436 :11 437 :24 438 :3 437
:2 435 :6 434 431 :3 35b
43e 43f 440 441
:2 442 443 :2 444 43e
:6 445 :5 446 445 :5 448
447 :3 445 43d 44b
:5 44c :3 44b :2 44d :5 44f
:11 450 :24 451 :3 450 :2 44e
:6 44d 44a :3 35b 457
:2 458 459 :2 45a 457
:6 45b :5 45c 45b :5 45e
45d :3 45b 456 461
:5 462 :3 461 :2 463 :5 465
:11 466 :24 467 :3 466 :2 464
:6 463 460 :6 35b :5 489
:17 48b :2 48c :2 48b :6 48c
:2 48b :5 48d :3 48e :3 48d
48c :2 48b :9 492 :5 493
:3 492 :13 496 :6 497 :2 496
:3 498 497 :2 496 :3 49c
:3 49d :9 49e :b 4a5 :a 4a6
:2 4a7 :2 4a6 :2 4a8 :2 4a6
:2 4a9 :2 4a6 :2 4a9 :2 4a6
:2 4a9 :3 4a6 4aa 4a5
:9 4aa :2 4ab :2 4ac :2 4ab
:2 4ad :2 4ab :2 4ad :2 4ab
:2 4ad :2 4ab :2 4ae :2 4ab
:2 4ae :2 4ab :2 4ae :2 4ab
:2 4af :3 4ab 4aa 4a5
:2 4b1 :2 4b2 :2 4b1 :2 4b3
:2 4b1 :2 4b4 :2 4b1 :2 4b4
:2 4b1 :2 4b4 :3 4b1 4b0
:3 4a5 49e :c 4be :2 4bf
:2 4be :6 4bf :2 4be 4bf
:2 4c0 :2 4bf :6 4c0 :2 4be
:5 4c4 :5 4c5 :5 4c7 :5 4ca
:5 4cb 4ce :2 4cf 4d0
4d1 :4 4d4 :2 4d5 :3 4d6
:4 4d7 :2 4d8 :3 4d9 4ce
:6 4da :5 4db 4da :5 4dd
4dc :3 4da 4cd 4e0
:5 4e1 :3 4e0 :2 4e2 :5 4e4
:11 4e5 :24 4e6 :3 4e5 :2 4e3
:6 4e2 4df :3 4c7 4ee
:2 4ef :2 4f0 :2 4f2 :2 4f3
:4 4f4 :8 4f5 4ee :6 4f6
:5 4f7 4f6 :5 4f9 4f8
:3 4f6 4ed 4fc :5 4fd
:3 4fc :2 4fe :5 500 :11 501
:24 502 :3 501 :2 4ff :6 4fe
4fb :4 4c7 :3 508 506
:3 4c7 4c0 :2 4be :5 50c
50e :1c 50f :2 50e :c 50f
:3 50e :3 510 :8 513 :15 514
:15 515 :2 514 :2 516 515
:2 514 :7 518 513 519
513 :5 51b :11 51c :20 51d
:3 51c :11 51f :b 520 :3 51f
:9 522 :3 51b :2 526 527
528 526 :5 529 525
52b :5 52c :3 52b :2 52d
:5 52f :11 530 :24 531 :3 530
:2 52e :6 52d 52a :6 50c
:b 537 539 53a 539
:3 53b :7 53c :7 53d 53e
537 :b 53e 540 541
540 :7 542 :7 543 :3 544
53e 537 :b 546 :3 549
:3 54a :5 54c :7 54d :7 54e
:7 54f :3 54c :7 552 :5 554
:7 555 :7 556 :7 557 :3 554
546 :5 55a :7 55b :3 55c
55a :6 55f :2 560 :3 55f
:3 562 :5 564 :7 565 :7 566
:7 567 :3 564 :6 56a :2 56b
:2 56a :2 56c :2 56a :2 56d
:2 56a :2 56e :2 56a :2 56f
:3 56a 55d :3 55a :5 572
:f 573 :3 572 559 :3 546
545 :3 537 :b 578 :5 579
:2 57b 57c :2 57d 57b
:5 57e 57a 580 :5 581
:3 580 :2 582 :5 584 :11 585
:24 586 :3 585 :2 583 :6 582
57f :3 579 :a 58b :a 58c
:7 58f :6 590 :2 591 :2 590
:2 591 :2 590 :2 591 :3 590
58b :11 593 :30 594 :3 593
:11 596 :b 597 :3 596 :a 599
592 :3 58b :3 579 :5 59d
:2 59f 5a0 :2 5a1 59f
:5 5a2 59e 5a4 :5 5a5
:3 5a4 :2 5a6 :5 5a8 :11 5a9
:24 5aa :3 5a9 :2 5a7 :6 5a6
5a3 :3 59d :a 5af :7 5b0
:6 5b1 :2 5b2 :2 5b1 :2 5b2
:2 5b1 :2 5b2 :3 5b1 5af
:11 5b4 :30 5b5 :3 5b4 :11 5b7
:b 5b8 :3 5b7 :a 5ba 5b3
:3 5af :3 59d :5 5be :2 5c0
5c1 :2 5c2 5c0 :5 5c3
5bf 5c5 :5 5c6 :3 5c5
:2 5c7 :5 5c9 :11 5ca :24 5cb
:3 5ca :2 5c8 :6 5c7 5c4
:3 5be :a 5d0 :7 5d1 :6 5d2
:2 5d3 :2 5d2 :2 5d3 :2 5d2
:2 5d3 :3 5d2 5d0 :11 5d5
:30 5d6 :3 5d5 :11 5d8 :b 5d9
:3 5d8 :a 5db 5d4 :3 5d0
:3 5be :14 5df :16 5e0 :3 5df
:3 578 :5 5e5 :a 5e6 :3 5e8
:8 5e9 :f 5eb :2 5ee 5ef
:2 5f0 5ee :5 5f1 5ed
5f3 :5 5f4 :3 5f3 :2 5f5
:5 5f7 :11 5f8 :24 5f9 :3 5f8
:2 5f6 :6 5f5 5f2 :3 5e9
:a 5fe :11 5ff :30 600 :3 5ff
:11 602 :b 603 :3 602 :a 605
:3 5fe :6 608 :2 609 :2 608
:2 60a :2 608 :2 60b :2 608
:2 60b :2 608 :2 60b :3 608
:b 60d :7 60e 60d :7 610
60f :3 60d :b 614 :2 615
:3 614 :7 617 5e9 618
5e9 :3 5e5 :b 61c :a 61d
:3 61f :8 620 :f 622 :2 625
626 :2 627 625 :5 628
624 62a :5 62b :3 62a
:2 62c :5 62e :11 62f :24 630
:3 62f :2 62d :6 62c 629
:3 620 :a 635 :11 636 :30 637
:3 636 :11 639 :b 63a :3 639
:a 63c :3 635 :6 63f :2 640
:2 63f :2 641 :2 63f :2 642
:2 63f :2 642 :2 63f :2 642
:2 63f :2 643 :3 63f :7 644
620 645 620 :3 61c
:7 648 4b6 :3 49e :7 64b
:5 64f 652 :4 653 :3 654
:5 655 654 :5 657 656
:3 654 :a 65b :2 65c :3 65b
:17 661 :2 662 :2 661 :6 662
:2 661 662 :2 663 :2 662
:b 663 :3 662 :2 661 :5 666
:4 668 :3 669 :5 66a 669
:5 66c 66b :3 669 :a 66f
:4 671 :5 672 670 674
:5 675 :3 674 :2 676 :5 678
:11 679 :24 67a :3 679 :2 677
:6 676 673 :3 66f :2 682
66f :4 685 :5 686 684
688 :5 689 :3 688 :2 68a
:5 68c :11 68d :24 68e :3 68d
:2 68b :6 68a 687 :4 683
:3 66f 663 :2 661 :3 695
:3 696 :9 697 :a 698 :5 69a
:3 69b 698 :c 69d :3 6a0
6a1 :2 6a2 :2 6a3 6a4
6a0 :5 6a5 69f 6a7
:5 6a8 :3 6a7 :2 6a9 :5 6ab
:11 6ac :24 6ad :3 6ac :2 6aa
:6 6a9 6a6 :3 69d :9 6b2
:4 6b4 :5 6b5 6b3 6b7
:5 6b8 :3 6b7 :2 6b9 :5 6bb
:11 6bc :24 6bd :3 6bc :2 6ba
:6 6b9 6b6 :3 6b2 :11 6c2
:30 6c3 :3 6c2 :11 6c5 :b 6c6
:3 6c5 :7 6c8 6c9 :2 6c8
:3 6b2 :3 69d 69c :3 698
:8 6ce :5 6cf :7 6d0 :6 6d1
:a 6d2 :3 6d3 :3 6ce :5 6d5
:4 6d7 :5 6d8 6d6 6da
:5 6db :3 6da :2 6dc :5 6de
:11 6df :24 6e0 :3 6df :2 6dd
:6 6dc 6d9 :3 6d5 :7 6e5
:5 6e6 :3 6e5 :11 6e9 :2e 6ea
:3 6e9 :11 6ec :b 6ed :3 6ec
:8 6ef 6f0 6d5 :18 6f0
:6 6f2 :6 6f3 :5 6f4 6f3
:5 6f6 6f5 :3 6f3 6f1
6f9 :5 6fa :3 6f9 :2 6fb
:5 6fd :11 6fe :24 6ff :3 6fe
:2 6fc :6 6fb 6f8 :4 6f0
:3 6d5 :2 705 697 :b 707
:3 708 :3 709 :3 707 :8 70c
:5 70d :7 70e :6 70f :9 710
:3 70c :5 712 :7 713 714
712 :5 714 :2 715 714
:3 712 :9 718 :2 719 :3 718
706 :3 697 71c 71d
:3 652 71e a5 :4 722
:5 723 721 725 :5 726
:3 725 :2 727 :5 729 :11 72a
:24 72b :3 72a :2 728 :6 727
724 :3 a5 :16 731 :2 732
:2 731 :4 732 :5 731 :11 733
:2e 734 :3 733 :11 736 :b 737
:3 736 :8 739 732 :2 731
:5 73c :3 73d :3 73e :3 73f
:5 741 :3 743 745 746
747 748 749 74a
74b 74c 74d 74e
:3 746 :3 74f :5 750 74f
:5 752 751 :3 74f :a 755
:2 756 :3 755 :12 75b :c 75c
:2 75b :3 75e 75c :2 75b
:b 762 :5 764 767 :2 768
:2 769 :2 76a :2 76b :2 76c
:2 76d :2 76e 767 :6 76f
:5 770 76f :5 772 771
:3 76f 766 775 :5 776
:3 775 :2 777 :5 779 :11 77a
:24 77b :3 77a :2 778 :6 777
774 :6 764 :3 781 :3 782
:3 783 :3 784 :3 785 :3 787
:3 78b :3 78c :3 762 :c 78f
792 793 794 795
796 797 798 :2 799
792 :6 79a :5 79b 79a
:5 79d 79c :3 79a 791
7a0 :5 7a1 :3 7a0 :2 7a2
:5 7a4 :11 7a5 :24 7a6 :3 7a5
:2 7a3 :6 7a2 79f :6 78f
:5 7ac :5 7ad :c 7ae :3 7ad
:c 7b1 :3 7ac :5 7b4 :c 7b5
:3 7b4 :5 7b8 :5 7b9 :c 7ba
:3 7b9 :c 7bd :3 7b8 :5 7c0
:c 7c1 :3 7c0 :5 7c4 :5 7c5
:c 7c6 :3 7c5 :c 7c9 :3 7c4
:5 7cc :5 7cd :c 7ce :3 7cd
:c 7d1 :3 7cc :7 7d5 :3 7d7
745 7d8 73c :4 7da
:5 7db 7d9 7dd :5 7de
:3 7dd :2 7df :5 7e1 :11 7e2
:24 7e3 :3 7e2 :2 7e0 :6 7df
7dc :3 73c :5 7e8 7eb
:2 7ec :2 7ed :2 7ee :2 7ef
:2 7f0 :2 7f1 :2 7f2 7eb
:6 7f3 :5 7f4 7f3 :5 7f6
7f5 :3 7f3 7ea 7f9
:5 7fa :3 7f9 :2 7fb :5 7fd
:11 7fe :24 7ff :3 7fe :2 7fc
:6 7fb 7f8 :6 7e8 :3 73c
:5 806 :9 807 :4 809 80a
:2 80b :7 80c 809 :5 80d
808 80f :5 810 :3 80f
:2 811 :5 813 :11 814 :24 815
:3 814 :2 812 :6 811 80e
:4 807 :3 81a 81b 819
:3 807 :3 806 :7 820 :9 821
:3 822 820 :5 823 81f
825 :5 826 :3 825 :2 827
:5 829 :11 82a :24 82b :3 82a
:2 828 :6 827 824 :3 a5
:b 833 :5 836 :5 837 83c
83d 83e 83f 840
841 842 :2 843 :2 844
83c :6 845 :5 846 845
:5 848 847 :3 845 83b
84b :5 84c :3 84b :2 84d
:5 84f :11 850 :24 851 :3 850
:2 84e :6 84d 84a :3 833
:a 857 859 85a :3 85b
:3 85c :3 85d :3 85e 85f
:2 860 861 859 :6 862
:5 863 862 :5 865 864
:3 862 858 868 :5 869
:3 868 :2 86a :5 86c :11 86d
:24 86e :3 86d :2 86b :6 86a
867 :3 857 :a 873 875
876 877 :2 878 879
875 :6 87a :5 87b 87a
:5 87d 87c :3 87a 874
880 :5 881 :3 880 :2 882
:5 884 :11 885 :24 886 :3 885
:2 883 :6 882 87f :6 873
:3 857 :12 88d :6 88e :e 88f
:e 890 :e 891 :e 892 :19 893
:12 894 :4 895 :9 896 :c 897
:6 898 :7 899 :9 89a :9 89b
:9 89c :9 89d :8 89e :3 88d
:11 89f :b 8a0 :3 89f :3 8a2
833 :5 8a4 :13 8a5 :6 8a6
:20 8a7 :20 8a8 :20 8a9 :20 8aa
:19 8ab :1c 8ac :7 8ad :9 8ae
:7 8af :9 8b0 :10 8b1 :c 8b2
:9 8b3 :9 8b4 :9 8b5 :9 8b6
8b7 :3 8a5 :11 8b8 :b 8b9
:3 8b8 :3 8bb 8a4 :5 8be
:5 8bf 8c1 :5 8c2 :2 8c3
8c1 :6 8c4 :5 8c5 8c4
:5 8c7 8c6 :3 8c4 8c0
8ca :5 8cb :3 8ca :2 8cc
:5 8ce :11 8cf :24 8d0 :3 8cf
:2 8cd :6 8cc 8c9 :3 8bc
8d6 :4 8d7 :6 8d8 :3 8d9
8da :5 8db 8dc 8d6
:6 8dd :5 8de 8dd :5 8e0
8df :3 8dd 8d5 8e3
:5 8e4 :3 8e3 :2 8e5 :5 8e7
:11 8e8 :24 8e9 :3 8e8 :2 8e6
:6 8e5 8e2 :3 8bc :13 8ee
:6 8ef :5 8f1 :17 8f2 :17 8f3
:3 8f4 8f5 :5 8f7 :17 8f8
:17 8f9 :3 8fa 8fb :5 8fd
:17 8fe :17 8ff :3 900 901
:5 903 :17 904 :17 905 :3 906
907 :19 909 :12 90a :a 90b
:7 90c :2 90d :a 90e :a 90f
:7 910 :7 911 :9 912 :10 913
:c 914 :9 915 :12 916 :12 917
:9 918 :8 919 91a :3 8ee
:11 91b :b 91c :3 91b :3 91e
8bc :3 8a4 8a3 :3 833
a5 :3 924 :11 925 :b 926
:17 927 :3 925 :2 929 :3 92a
:3 92b 92c 92a 929
92a :3 92d :3 924 :2 92e
:5 930 :11 931 :b 932 :18 933
:3 931 :2 935 936 :3 937
938 936 935 936
:3 939 :2 92f :6 92e 923
:7 1 
c154
4
:3 0 1 :3 0 2
:a 0 371d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 4 :3 0 10
:7 0 31 30 :3 0
4 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 4
:3 0 12 :7 0 39
38 :3 0 4 :3 0
13 :7 0 3d 3c
:3 0 25 160 0
23 4 :3 0 14
:7 0 41 40 :3 0
8 :3 0 15 :7 0
45 44 :3 0 29
186 0 27 4
:3 0 16 :7 0 49
48 :3 0 4 :3 0
17 :7 0 4d 4c
:3 0 2d 1ac 0
2b 4 :3 0 18
:7 0 51 50 :3 0
4 :3 0 19 :7 0
55 54 :3 0 31
1d2 0 2f 8
:3 0 1a :7 0 59
58 :3 0 8 :3 0
1b :7 0 5d 5c
:3 0 35 1f8 0
33 8 :3 0 1c
:7 0 61 60 :3 0
8 :3 0 1d :7 0
65 64 :3 0 39
:2 0 37 4 :3 0
1e :7 0 69 68
:3 0 4 :3 0 1f
:7 0 6d 6c :3 0
20 :3 0 21 :3 0
22 :2 0 4 71
72 0 6f 73
0 371d 2 74
:2 0 24 :2 0 57
4 :3 0 24 :2 0
55 77 79 :6 0
7c 7a 0 371b
0 23 :6 0 24
:2 0 5b 4 :3 0
59 7e 80 :6 0
83 81 0 371b
0 25 :6 0 24
:2 0 5f 4 :3 0
5d 85 87 :6 0
8a 88 0 371b
0 26 :6 0 24
:2 0 63 4 :3 0
61 8c 8e :6 0
91 8f 0 371b
0 27 :6 0 24
:2 0 67 4 :3 0
65 93 95 :6 0
98 96 0 371b
0 28 :6 0 2b
:2 0 6b 4 :3 0
69 9a 9c :6 0
9f 9d 0 371b
0 29 :6 0 2d
:2 0 6f 4 :3 0
6d a1 a3 :6 0
a6 a4 0 371b
0 2a :6 0 2f
:2 0 73 4 :3 0
71 a8 aa :6 0
ad ab 0 371b
0 2c :6 0 2f
:2 0 77 4 :3 0
75 af b1 :6 0
b4 b2 0 371b
0 2e :6 0 2f
:2 0 7b 4 :3 0
79 b6 b8 :6 0
bb b9 0 371b
0 30 :6 0 2f
:2 0 7f 4 :3 0
7d bd bf :6 0
c2 c0 0 371b
0 31 :6 0 2f
:2 0 83 4 :3 0
81 c4 c6 :6 0
c9 c7 0 371b
0 32 :6 0 2f
:2 0 87 4 :3 0
85 cb cd :6 0
d0 ce 0 371b
0 33 :6 0 2f
:2 0 8b 4 :3 0
89 d2 d4 :6 0
d7 d5 0 371b
0 34 :6 0 2f
:2 0 8f 4 :3 0
8d d9 db :6 0
de dc 0 371b
0 35 :6 0 2f
:2 0 93 4 :3 0
91 e0 e2 :6 0
e5 e3 0 371b
0 36 :6 0 2f
:2 0 97 4 :3 0
95 e7 e9 :6 0
ec ea 0 371b
0 37 :6 0 24
:2 0 9b 4 :3 0
99 ee f0 :6 0
f3 f1 0 371b
0 38 :6 0 24
:2 0 9f 4 :3 0
9d f5 f7 :6 0
fa f8 0 371b
0 39 :6 0 3c
:2 0 a3 4 :3 0
a1 fc fe :6 0
101 ff 0 371b
0 3a :6 0 a9
499 0 a7 4
:3 0 a5 103 105
:6 0 108 106 0
371b 0 3b :6 0
40 :2 0 ad 3e
:3 0 10a :7 0 10d
10b 0 371b 0
3d :6 0 4 :3 0
40 :2 0 ab 10f
111 :6 0 114 112
0 371b 0 3f
:6 0 40 :2 0 b1
4 :3 0 af 116
118 :6 0 11b 119
0 371b 0 41
:6 0 40 :2 0 b5
4 :3 0 b3 11d
11f :6 0 122 120
0 371b 0 42
:6 0 40 :2 0 b9
4 :3 0 b7 124
126 :6 0 129 127
0 371b 0 43
:6 0 bf 545 0
bd 4 :3 0 bb
12b 12d :6 0 130
12e 0 371b 0
44 :6 0 24 :2 0
c3 3e :3 0 132
:7 0 135 133 0
371b 0 45 :6 0
4 :3 0 47 :2 0
c1 137 139 :6 0
13c 13a 0 371b
0 46 :6 0 24
:2 0 c7 4 :3 0
c5 13e 140 :6 0
143 141 0 371b
0 48 :6 0 24
:2 0 cb 4 :3 0
c9 145 147 :6 0
14a 148 0 371b
0 49 :6 0 2b
:2 0 cf 4 :3 0
cd 14c 14e :6 0
151 14f 0 371b
0 4a :6 0 47
:2 0 d3 4 :3 0
d1 153 155 :6 0
158 156 0 371b
0 4b :6 0 4e
:2 0 d7 4 :3 0
d5 15a 15c :6 0
15f 15d 0 371b
0 4c :6 0 4e
:2 0 d9 8 :3 0
161 :7 0 165 162
163 371b 0 4d
:6 0 4e :2 0 db
8 :3 0 167 :7 0
16b 168 169 371b
0 4f :6 0 4e
:2 0 dd 8 :3 0
16d :7 0 171 16e
16f 371b 0 50
:6 0 4e :2 0 df
8 :3 0 173 :7 0
177 174 175 371b
0 51 :6 0 4e
:2 0 e1 8 :3 0
179 :7 0 17d 17a
17b 371b 0 52
:6 0 4e :2 0 e3
8 :3 0 17f :7 0
183 180 181 371b
0 53 :6 0 4e
:2 0 e5 8 :3 0
185 :7 0 189 186
187 371b 0 54
:6 0 4e :2 0 e7
8 :3 0 18b :7 0
18f 18c 18d 371b
0 55 :6 0 4e
:2 0 e9 8 :3 0
191 :7 0 195 192
193 371b 0 56
:6 0 4e :2 0 eb
8 :3 0 197 :7 0
19b 198 199 371b
0 57 :6 0 4e
:2 0 ed 8 :3 0
19d :7 0 1a1 19e
19f 371b 0 58
:6 0 4e :2 0 ef
8 :3 0 1a3 :7 0
1a7 1a4 1a5 371b
0 59 :6 0 4e
:2 0 f1 8 :3 0
1a9 :7 0 1ad 1aa
1ab 371b 0 5a
:6 0 4e :2 0 f3
8 :3 0 1af :7 0
1b3 1b0 1b1 371b
0 5b :6 0 4e
:2 0 f5 8 :3 0
1b5 :7 0 1b9 1b6
1b7 371b 0 5c
:6 0 4e :2 0 f7
8 :3 0 1bb :7 0
1bf 1bc 1bd 371b
0 5d :6 0 4e
:2 0 f9 8 :3 0
1c1 :7 0 1c5 1c2
1c3 371b 0 5e
:6 0 4e :2 0 fb
8 :3 0 1c7 :7 0
1cb 1c8 1c9 371b
0 5f :6 0 4e
:2 0 fd 8 :3 0
1cd :7 0 1d1 1ce
1cf 371b 0 60
:6 0 4e :2 0 ff
8 :3 0 1d3 :7 0
1d7 1d4 1d5 371b
0 61 :6 0 4e
:2 0 101 8 :3 0
1d9 :7 0 1dd 1da
1db 371b 0 62
:6 0 4e :2 0 103
8 :3 0 1df :7 0
1e3 1e0 1e1 371b
0 63 :6 0 4e
:2 0 105 8 :3 0
1e5 :7 0 1e9 1e6
1e7 371b 0 64
:6 0 68 :2 0 107
8 :3 0 1eb :7 0
1ef 1ec 1ed 371b
0 65 :6 0 68
:2 0 109 67 :3 0
1f1 :7 0 1f5 1f2
1f3 371b 0 66
:6 0 4e :2 0 10b
67 :3 0 1f7 :7 0
1fb 1f8 1f9 371b
0 69 :6 0 4e
:2 0 10d 8 :3 0
1fd :7 0 201 1fe
1ff 371b 0 6a
:6 0 4e :2 0 10f
8 :3 0 203 :7 0
207 204 205 371b
0 6b :6 0 4e
:2 0 111 8 :3 0
209 :7 0 20d 20a
20b 371b 0 6c
:6 0 4e :2 0 113
8 :3 0 20f :7 0
213 210 211 371b
0 6d :6 0 4e
:2 0 115 8 :3 0
215 :7 0 219 216
217 371b 0 6e
:6 0 4e :2 0 117
8 :3 0 21b :7 0
21f 21c 21d 371b
0 6f :6 0 47
:2 0 119 8 :3 0
221 :7 0 225 222
223 371b 0 70
:6 0 4e :2 0 11d
4 :3 0 11b 227
229 :6 0 22c 22a
0 371b 0 71
:6 0 4e :2 0 11f
8 :3 0 22e :7 0
232 22f 230 371b
0 72 :6 0 4e
:2 0 121 8 :3 0
234 :7 0 238 235
236 371b 0 73
:6 0 76 :2 0 123
8 :3 0 23a :7 0
23e 23b 23c 371b
0 74 :6 0 78
:2 0 127 4 :3 0
125 240 242 :6 0
245 243 0 371b
0 75 :6 0 76
:2 0 12b 4 :3 0
129 247 249 :6 0
24c 24a 0 371b
0 77 :6 0 4e
:2 0 12f 4 :3 0
12d 24e 250 :6 0
253 251 0 371b
0 79 :6 0 4e
:2 0 131 8 :3 0
255 :7 0 259 256
257 371b 0 7a
:6 0 24 :2 0 133
8 :3 0 25b :7 0
25f 25c 25d 371b
0 7b :6 0 24
:2 0 137 7d :3 0
135 261 263 :6 0
266 264 0 371b
0 7c :6 0 24
:2 0 13b 7d :3 0
139 268 26a :6 0
26d 26b 0 371b
0 7e :6 0 24
:2 0 13f 4 :3 0
13d 26f 271 :6 0
274 272 0 371b
0 7f :6 0 24
:2 0 143 4 :3 0
141 276 278 :6 0
27b 279 0 371b
0 80 :6 0 47
:2 0 147 4 :3 0
145 27d 27f :6 0
282 280 0 371b
0 81 :6 0 4e
:2 0 14b 4 :3 0
149 284 286 :6 0
289 287 0 371b
0 82 :6 0 4e
:2 0 14d 8 :3 0
28b :7 0 28f 28c
28d 371b 0 83
:6 0 4e :2 0 14f
8 :3 0 291 :7 0
295 292 293 371b
0 84 :6 0 47
:2 0 151 8 :3 0
297 :7 0 29b 298
299 371b 0 85
:6 0 47 :2 0 153
8 :3 0 29d 0
2 :5 0 2a1 29e
29f 371b 0 86
:6 0 4e :2 0 155
8 :3 0 2a3 0
2 :5 0 2a7 2a4
2a5 371b 0 87
:6 0 4e :2 0 157
8 :3 0 2a9 0
2 :5 0 2ad 2aa
2ab 371b 0 88
:6 0 4e :2 0 159
8 :3 0 2af 0
2 :5 0 2b3 2b0
2b1 371b 0 89
:6 0 24 :2 0 15b
8 :3 0 2b5 0
2 :5 0 2b9 2b6
2b7 371b 0 8a
:6 0 4e :2 0 15f
4 :3 0 15d 2bb
2bd :6 0 2c0 2be
0 371b 0 8b
:6 0 163 c71 0
161 8 :3 0 2c2
0 2 :5 0 2c6
2c3 2c4 371b 0
8c :6 0 167 ca5
0 165 8 :3 0
2c8 :7 0 2cb 2c9
0 371b 0 8d
:6 0 8 :3 0 2cd
:7 0 2d0 2ce 0
371b 0 8e :6 0
16b cd9 0 169
8 :3 0 2d2 :7 0
2d5 2d3 0 371b
0 8f :6 0 8
:3 0 2d7 :7 0 2da
2d8 0 371b 0
90 :6 0 16f d0d
0 16d 8 :3 0
2dc :7 0 2df 2dd
0 371b 0 91
:6 0 8 :3 0 2e1
:7 0 2e4 2e2 0
371b 0 92 :9 0
171 8 :3 0 2e6
:7 0 2e9 2e7 0
371b 0 93 :6 0
21 :3 0 22 :2 0
4 2eb 2ec 0
2ed :7 0 2f0 2ee
0 371b 0 94
:6 0 95 :3 0 96
:a 0 2 2ff :4 0
2f2 2f5 0 2f3
:3 0 97 :3 0 98
:3 0 99 :3 0 25
:3 0 9a :3 0 25
:3 0 9b :3 0 39
:4 0 9c 1 :8 0
300 2f2 2f5 301
0 371b 173 301
303 300 302 :6 0
2ff :7 0 301 95
:3 0 9d :a 0 3
31a :5 0 305 308
0 306 :3 0 9e
:3 0 9f :3 0 a0
:3 0 a1 :3 0 a2
:3 0 a3 :3 0 a0
:3 0 a4 :3 0 a2
:3 0 a5 :3 0 a2
:3 0 a6 :3 0 a2
:3 0 a7 :3 0 a8
:3 0 9f :4 0 a9
1 :8 0 31b 305
308 31c 0 371b
175 31c 31e 31b
31d :6 0 31a :7 0
31c 327 328 0
177 21 :3 0 22
:2 0 4 320 321
0 322 :7 0 325
323 0 371b 0
aa :6 0 32e 32f
0 179 21 :3 0
22 :2 0 4 329
:7 0 32c 32a 0
371b 0 ab :6 0
335 336 0 17b
21 :3 0 22 :2 0
4 330 :7 0 333
331 0 371b 0
ac :6 0 33b 33c
0 17d 21 :3 0
22 :2 0 4 337
:7 0 33a 338 0
371b 0 ad :6 0
ae :3 0 af :3 0
ae :3 0 b0 :3 0
33e 33f 0 2
:4 0 17f 340 342
33d 344 343 :2 0
b1 :3 0 b2 :3 0
346 347 0 b3
:4 0 ae :3 0 b4
:3 0 34a 34b 0
2 :4 0 181 34c
34e b5 :4 0 b6
:2 0 b7 :3 0 183
351 353 :3 0 b8
:4 0 b6 :2 0 b9
:4 0 186 356 358
:3 0 b6 :2 0 3
:3 0 189 35a 35c
:3 0 b6 :2 0 b9
:4 0 18c 35e 360
:3 0 b6 :2 0 ba
:4 0 18f 362 364
:3 0 b6 :2 0 b9
:4 0 192 366 368
:3 0 b6 :2 0 5
:3 0 195 36a 36c
:3 0 b6 :2 0 b9
:4 0 198 36e 370
:3 0 b6 :2 0 ba
:4 0 19b 372 374
:3 0 b6 :2 0 b9
:4 0 19e 376 378
:3 0 b6 :2 0 6
:3 0 1a1 37a 37c
:3 0 b6 :2 0 b9
:4 0 1a4 37e 380
:3 0 b6 :2 0 ba
:4 0 1a7 382 384
:3 0 b6 :2 0 a2
:3 0 bb :3 0 7
:3 0 1aa 388 38a
bc :4 0 1ac 387
38d 1af 386 38f
:3 0 b6 :2 0 ba
:4 0 1b2 391 393
:3 0 b6 :2 0 a2
:3 0 bb :3 0 9
:3 0 1b5 397 399
bc :4 0 1b7 396
39c 1ba 395 39e
:3 0 b6 :2 0 ba
:4 0 1bd 3a0 3a2
:3 0 b6 :2 0 a2
:3 0 bb :3 0 a
:3 0 1c0 3a6 3a8
bc :4 0 1c2 3a5
3ab 1c5 3a4 3ad
:3 0 b6 :2 0 ba
:4 0 1c8 3af 3b1
:3 0 b6 :2 0 a2
:3 0 bb :3 0 b
:3 0 1cb 3b5 3b7
bc :4 0 1cd 3b4
3ba 1d0 3b3 3bc
:3 0 b6 :2 0 ba
:4 0 1d3 3be 3c0
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c
:3 0 1d6 3c4 3c6
bc :4 0 1d8 3c3
3c9 1db 3c2 3cb
:3 0 b6 :2 0 ba
:4 0 1de 3cd 3cf
:3 0 b6 :2 0 a2
:3 0 bb :3 0 d
:3 0 1e1 3d3 3d5
bc :4 0 1e3 3d2
3d8 1e6 3d1 3da
:3 0 b6 :2 0 ba
:4 0 1e9 3dc 3de
:3 0 b6 :2 0 a2
:3 0 bb :3 0 e
:3 0 1ec 3e2 3e4
bc :4 0 1ee 3e1
3e7 1f1 3e0 3e9
:3 0 b6 :2 0 ba
:4 0 1f4 3eb 3ed
:3 0 b6 :2 0 a2
:3 0 bb :3 0 f
:3 0 1f7 3f1 3f3
bc :4 0 1f9 3f0
3f6 1fc 3ef 3f8
:3 0 b6 :2 0 ba
:4 0 1ff 3fa 3fc
:3 0 b6 :2 0 b9
:4 0 202 3fe 400
:3 0 b6 :2 0 10
:3 0 205 402 404
:3 0 b6 :2 0 b9
:4 0 208 406 408
:3 0 b6 :2 0 ba
:4 0 20b 40a 40c
:3 0 b6 :2 0 b9
:4 0 20e 40e 410
:3 0 b6 :2 0 11
:3 0 211 412 414
:3 0 b6 :2 0 b9
:4 0 214 416 418
:3 0 b6 :2 0 ba
:4 0 217 41a 41c
:3 0 b6 :2 0 b9
:4 0 21a 41e 420
:3 0 b6 :2 0 12
:3 0 21d 422 424
:3 0 b6 :2 0 b9
:4 0 220 426 428
:3 0 b6 :2 0 ba
:4 0 223 42a 42c
:3 0 b6 :2 0 b9
:4 0 226 42e 430
:3 0 b6 :2 0 13
:3 0 229 432 434
:3 0 b6 :2 0 b9
:4 0 22c 436 438
:3 0 b6 :2 0 ba
:4 0 22f 43a 43c
:3 0 b6 :2 0 b9
:4 0 232 43e 440
:3 0 b6 :2 0 14
:3 0 235 442 444
:3 0 b6 :2 0 b9
:4 0 238 446 448
:3 0 b6 :2 0 ba
:4 0 23b 44a 44c
:3 0 b6 :2 0 a2
:3 0 bb :3 0 15
:3 0 23e 450 452
bc :4 0 240 44f
455 243 44e 457
:3 0 b6 :2 0 ba
:4 0 246 459 45b
:3 0 b6 :2 0 b9
:4 0 249 45d 45f
:3 0 b6 :2 0 16
:3 0 24c 461 463
:3 0 b6 :2 0 b9
:4 0 24f 465 467
:3 0 b6 :2 0 ba
:4 0 252 469 46b
:3 0 b6 :2 0 b9
:4 0 255 46d 46f
:3 0 b6 :2 0 17
:3 0 258 471 473
:3 0 b6 :2 0 b9
:4 0 25b 475 477
:3 0 b6 :2 0 ba
:4 0 25e 479 47b
:3 0 b6 :2 0 b9
:4 0 261 47d 47f
:3 0 b6 :2 0 18
:3 0 264 481 483
:3 0 b6 :2 0 b9
:4 0 267 485 487
:3 0 b6 :2 0 ba
:4 0 26a 489 48b
:3 0 b6 :2 0 b9
:4 0 26d 48d 48f
:3 0 b6 :2 0 19
:3 0 270 491 493
:3 0 b6 :2 0 b9
:4 0 273 495 497
:3 0 b6 :2 0 ba
:4 0 276 499 49b
:3 0 b6 :2 0 a2
:3 0 bb :3 0 1a
:3 0 279 49f 4a1
bc :4 0 27b 49e
4a4 27e 49d 4a6
:3 0 b6 :2 0 ba
:4 0 281 4a8 4aa
:3 0 b6 :2 0 a2
:3 0 bb :3 0 1b
:3 0 284 4ae 4b0
bc :4 0 286 4ad
4b3 289 4ac 4b5
:3 0 b6 :2 0 ba
:4 0 28c 4b7 4b9
:3 0 b6 :2 0 a2
:3 0 bb :3 0 1c
:3 0 28f 4bd 4bf
bc :4 0 291 4bc
4c2 294 4bb 4c4
:3 0 b6 :2 0 ba
:4 0 297 4c6 4c8
:3 0 b6 :2 0 a2
:3 0 bb :3 0 1d
:3 0 29a 4cc 4ce
bc :4 0 29c 4cb
4d1 29f 4ca 4d3
:3 0 b6 :2 0 ba
:4 0 2a2 4d5 4d7
:3 0 b6 :2 0 b9
:4 0 2a5 4d9 4db
:3 0 b6 :2 0 1e
:3 0 2a8 4dd 4df
:3 0 b6 :2 0 b9
:4 0 2ab 4e1 4e3
:3 0 b6 :2 0 ba
:4 0 2ae 4e5 4e7
:3 0 b6 :2 0 b9
:4 0 2b1 4e9 4eb
:3 0 b6 :2 0 1f
:3 0 2b4 4ed 4ef
:3 0 b6 :2 0 b9
:4 0 2b7 4f1 4f3
:3 0 b6 :2 0 bd
:4 0 2ba 4f5 4f7
:3 0 2bd 348 4f9
:2 0 4fb 2c2 4fc
345 4fb 0 4fd
2c4 0 367b ae
:3 0 af :3 0 4fe
4ff 0 ae :3 0
be :3 0 501 502
0 47 :2 0 2
:4 0 bf :2 0 c0
:2 0 47 :2 0 2c6
507 509 :3 0 2c9
503 50b 500 50d
50c :2 0 b1 :3 0
c1 :3 0 50f 510
0 b3 :4 0 c2
:4 0 b6 :2 0 b7
:3 0 2cd 514 516
:3 0 2d0 511 518
:2 0 51a 2d3 51b
50e 51a 0 51c
2d5 0 367b 25
:3 0 3 :3 0 51d
51e 0 367b 3f
:3 0 5 :3 0 520
521 0 367b 42
:3 0 6 :3 0 523
524 0 367b 2a
:3 0 10 :3 0 526
527 0 367b 2c
:3 0 11 :3 0 529
52a 0 367b 2e
:3 0 16 :3 0 52c
52d 0 367b 30
:3 0 17 :3 0 52f
530 0 367b 31
:3 0 18 :3 0 532
533 0 367b 32
:3 0 19 :3 0 535
536 0 367b 29
:3 0 1f :3 0 538
539 0 367b 59
:3 0 7 :3 0 53b
53c 0 367b 57
:3 0 9 :3 0 53e
53f 0 367b 58
:3 0 e :3 0 541
542 0 367b 56
:3 0 1a :3 0 544
545 0 367b 5a
:3 0 b :3 0 547
548 0 367b 5c
:3 0 f :3 0 54a
54b 0 367b 5b
:3 0 c :3 0 54d
54e 0 367b 50
:3 0 1d :3 0 550
551 0 367b 4d
:3 0 a :3 0 553
554 0 367b 5d
:3 0 d :3 0 556
557 0 367b 52
:3 0 1b :3 0 559
55a 0 367b 53
:3 0 1c :3 0 55c
55d 0 367b 72
:3 0 4e :2 0 55f
560 0 367b 73
:3 0 4e :2 0 562
563 0 367b a2
:3 0 4d :3 0 4e
:2 0 2d7 565 568
c3 :3 0 c4 :2 0
c5 :3 0 56a 56c
0 2dc 56b 56e
:3 0 56f :2 0 3
:3 0 c6 :2 0 2df
572 573 :3 0 574
:2 0 575 :2 0 570
577 576 :2 0 ae
:3 0 af :3 0 579
57a 0 ae :3 0
be :3 0 57c 57d
0 c7 :2 0 2
:4 0 c8 :2 0 c0
:2 0 47 :2 0 2e1
582 584 :3 0 2e4
57e 586 57b 588
587 :2 0 b1 :3 0
c1 :3 0 58a 58b
0 b3 :4 0 c9
:4 0 b6 :2 0 b7
:3 0 2e8 58f 591
:3 0 b6 :2 0 ca
:4 0 2eb 593 595
:3 0 b6 :2 0 cb
:4 0 2ee 597 599
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 cc :3 0 59e
59f 0 2f1 59d
5a1 bc :4 0 2f3
59c 5a4 2f6 59b
5a6 :3 0 2f9 58c
5a8 :2 0 5aa 2fc
5ab 589 5aa 0
5ac 2fe 0 5d5
ae :3 0 af :3 0
5ad 5ae 0 ae
:3 0 be :3 0 5b0
5b1 0 47 :2 0
2 :4 0 cd :2 0
c0 :2 0 47 :2 0
300 5b6 5b8 :3 0
303 5b2 5ba 5af
5bc 5bb :2 0 b1
:3 0 c1 :3 0 5be
5bf 0 b3 :4 0
ce :4 0 b6 :2 0
b7 :3 0 307 5c3
5c5 :3 0 30a 5c0
5c7 :2 0 5c9 30d
5ca 5bd 5c9 0
5cb 30f 0 5d5
cf :3 0 d0 :3 0
5cc 5cd 0 c3
:3 0 cc :3 0 5cf
5d0 0 d1 :3 0
311 5ce 5d3 :2 0
5d5 314 5d6 578
5d5 0 5d7 318
0 367b 10 :3 0
c6 :2 0 31a 5d9
5da :3 0 5db :2 0
5dc :2 0 12 :3 0
c6 :2 0 31c 5df
5e0 :3 0 5e1 :2 0
5e2 :2 0 5dd 5e4
5e3 :2 0 13 :3 0
c6 :2 0 31e 5e7
5e8 :3 0 5e9 :2 0
5ea :2 0 5e5 5ec
5eb :2 0 14 :3 0
c6 :2 0 320 5ef
5f0 :3 0 5f1 :2 0
5f2 :2 0 5ed 5f4
5f3 :2 0 a2 :3 0
5c :3 0 4e :2 0
322 5f6 5f9 c3
:3 0 c4 :2 0 d2
:3 0 5fb 5fd 0
327 5fc 5ff :3 0
600 :2 0 5f5 602
601 :2 0 16 :3 0
c6 :2 0 32a 605
606 :3 0 607 :2 0
608 :2 0 a2 :3 0
5c :3 0 4e :2 0
32c 60a 60d c3
:3 0 d3 :2 0 d4
:3 0 60f 611 0
331 610 613 :3 0
614 :2 0 609 616
615 :2 0 ae :3 0
af :3 0 618 619
0 ae :3 0 be
:3 0 61b 61c 0
c7 :2 0 2 :4 0
d5 :2 0 c0 :2 0
47 :2 0 334 621
623 :3 0 337 61d
625 61a 627 626
:2 0 b1 :3 0 c1
:3 0 629 62a 0
b3 :4 0 d6 :4 0
b6 :2 0 b7 :3 0
33b 62e 630 :3 0
b6 :2 0 ca :4 0
33e 632 634 :3 0
b6 :2 0 cb :4 0
341 636 638 :3 0
b6 :2 0 a2 :3 0
bb :3 0 c3 :3 0
d7 :3 0 63d 63e
0 344 63c 640
bc :4 0 346 63b
643 349 63a 645
:3 0 34c 62b 647
:2 0 649 34f 64a
628 649 0 64b
351 0 675 ae
:3 0 af :3 0 64c
64d 0 ae :3 0
be :3 0 64f 650
0 47 :2 0 2
:4 0 2b :2 0 c0
:2 0 47 :2 0 353
655 657 :3 0 356
651 659 64e 65b
65a :2 0 b1 :3 0
c1 :3 0 65d 65e
0 b3 :4 0 d8
:4 0 b6 :2 0 b7
:3 0 35a 662 664
:3 0 35d 65f 666
:2 0 668 360 669
65c 668 0 66a
362 0 675 cf
:3 0 d0 :3 0 66b
66c 0 c3 :3 0
d7 :3 0 66e 66f
0 d1 :3 0 364
66d 672 :2 0 675
d9 :3 0 367 6e2
16 :3 0 c6 :2 0
36b 677 678 :3 0
679 :2 0 67a :2 0
17 :3 0 c6 :2 0
36d 67d 67e :3 0
67f :2 0 680 :2 0
67b 682 681 :2 0
ae :3 0 af :3 0
684 685 0 ae
:3 0 be :3 0 687
688 0 c7 :2 0
2 :4 0 da :2 0
c0 :2 0 47 :2 0
36f 68d 68f :3 0
372 689 691 686
693 692 :2 0 b1
:3 0 c1 :3 0 695
696 0 b3 :4 0
db :4 0 b6 :2 0
b7 :3 0 376 69a
69c :3 0 b6 :2 0
ca :4 0 379 69e
6a0 :3 0 b6 :2 0
cb :4 0 37c 6a2
6a4 :3 0 b6 :2 0
a2 :3 0 bb :3 0
c3 :3 0 d7 :3 0
6a9 6aa 0 37f
6a8 6ac bc :4 0
381 6a7 6af 384
6a6 6b1 :3 0 387
697 6b3 :2 0 6b5
38a 6b6 694 6b5
0 6b7 38c 0
6e0 ae :3 0 af
:3 0 6b8 6b9 0
ae :3 0 be :3 0
6bb 6bc 0 47
:2 0 2 :4 0 dc
:2 0 c0 :2 0 47
:2 0 38e 6c1 6c3
:3 0 391 6bd 6c5
6ba 6c7 6c6 :2 0
b1 :3 0 c1 :3 0
6c9 6ca 0 b3
:4 0 dd :4 0 b6
:2 0 b7 :3 0 395
6ce 6d0 :3 0 398
6cb 6d2 :2 0 6d4
39b 6d5 6c8 6d4
0 6d6 39d 0
6e0 cf :3 0 d0
:3 0 6d7 6d8 0
c3 :3 0 d7 :3 0
6da 6db 0 d1
:3 0 39f 6d9 6de
:2 0 6e0 3a2 6e1
683 6e0 0 6e3
617 675 0 6e3
3a6 0 6e4 3a9
6e5 603 6e4 0
6e6 3ab 0 367b
a2 :3 0 4d :3 0
4e :2 0 3ad 6e7
6ea d3 :2 0 de
:2 0 3b2 6ec 6ee
:3 0 a2 :3 0 5b
:3 0 4e :2 0 3b5
6f0 6f3 d3 :2 0
de :2 0 3ba 6f5
6f7 :3 0 6ef 6f9
6f8 :2 0 a2 :3 0
57 :3 0 4e :2 0
3bd 6fb 6fe d3
:2 0 de :2 0 3c2
700 702 :3 0 6fa
704 703 :2 0 ae
:3 0 af :3 0 706
707 0 ae :3 0
be :3 0 709 70a
0 c7 :2 0 2
:4 0 df :2 0 c0
:2 0 47 :2 0 3c5
70f 711 :3 0 3c8
70b 713 708 715
714 :2 0 b1 :3 0
c1 :3 0 717 718
0 b3 :4 0 e0
:4 0 b6 :2 0 b7
:3 0 3cc 71c 71e
:3 0 b6 :2 0 ca
:4 0 3cf 720 722
:3 0 b6 :2 0 cb
:4 0 3d2 724 726
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 72b
72c 0 3d5 72a
72e bc :4 0 3d7
729 731 3da 728
733 :3 0 3dd 719
735 :2 0 737 3e0
738 716 737 0
739 3e2 0 762
ae :3 0 af :3 0
73a 73b 0 ae
:3 0 be :3 0 73d
73e 0 47 :2 0
2 :4 0 e1 :2 0
c0 :2 0 47 :2 0
3e4 743 745 :3 0
3e7 73f 747 73c
749 748 :2 0 b1
:3 0 c1 :3 0 74b
74c 0 b3 :4 0
e2 :4 0 b6 :2 0
b7 :3 0 3eb 750
752 :3 0 3ee 74d
754 :2 0 756 3f1
757 74a 756 0
758 3f3 0 762
cf :3 0 d0 :3 0
759 75a 0 c3
:3 0 d7 :3 0 75c
75d 0 d1 :3 0
3f5 75b 760 :2 0
762 3f8 763 705
762 0 764 3fc
0 367b 15 :3 0
c6 :2 0 3fe 766
767 :3 0 768 :2 0
769 :2 0 54 :3 0
e3 :2 0 76b 76c
0 76e 400 773
54 :3 0 15 :3 0
76f 770 0 772
402 774 76a 76e
0 775 0 772
0 775 404 0
367b a2 :3 0 4d
:3 0 4e :2 0 407
776 779 c3 :3 0
c4 :2 0 c5 :3 0
77b 77d 0 40c
77c 77f :3 0 780
:2 0 5 :3 0 e4
:2 0 40f 783 784
:3 0 785 :2 0 786
:2 0 781 788 787
:2 0 6 :3 0 e4
:2 0 411 78b 78c
:3 0 78d :2 0 78e
:2 0 789 790 78f
:2 0 e5 :3 0 e6
:3 0 6 :3 0 e5
:3 0 e6 :3 0 5
:3 0 6a :3 0 e7
:4 0 e8 1 :8 0
7a0 21 :3 0 e9
:3 0 79b 79c 0
ea :3 0 79d 79e
0 7a0 413 7f3
eb :3 0 21 :3 0
e9 :3 0 7a2 7a3
0 ea :3 0 7a4
7a5 0 7a7 416
7a9 418 7a8 7a7
:2 0 7f1 ec :3 0
21 :3 0 e9 :3 0
7ac 7ad 0 ea
:3 0 7ae 7af 0
7e9 ae :3 0 af
:3 0 7b1 7b2 0
ae :3 0 be :3 0
7b4 7b5 0 ed
:2 0 2 :4 0 ee
:2 0 c0 :2 0 47
:2 0 41a 7ba 7bc
:3 0 41d 7b6 7be
7b3 7c0 7bf :2 0
b1 :3 0 c1 :3 0
7c2 7c3 0 b3
:4 0 ef :4 0 b6
:2 0 b7 :3 0 421
7c7 7c9 :3 0 b6
:2 0 ca :4 0 424
7cb 7cd :3 0 b6
:2 0 f0 :4 0 427
7cf 7d1 :3 0 b6
:2 0 ea :3 0 42a
7d3 7d5 :3 0 b6
:2 0 f1 :4 0 42d
7d7 7d9 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 430 7dc 7e0
434 7db 7e2 :3 0
437 7c4 7e4 :2 0
7e6 43a 7e7 7c1
7e6 0 7e8 43c
0 7e9 43e 7ec
:3 0 7ec 0 7ec
7eb 7e9 7ea :6 0
7ee 4 :3 0 441
7f0 443 7ef 7ee
:2 0 7f1 445 :2 0
7f3 0 7f3 7f2
7a0 7f1 :6 0 86d
1 :3 0 21 :3 0
e9 :3 0 7f5 7f6
0 21 :3 0 d3
:2 0 f5 :3 0 7f8
7fa 0 44a 7f9
7fc :3 0 7fd :2 0
a2 :3 0 6a :3 0
4e :2 0 44d 7ff
802 f6 :2 0 4e
:2 0 452 804 806
:3 0 807 :2 0 7fe
809 808 :2 0 ae
:3 0 af :3 0 80b
80c 0 ae :3 0
be :3 0 80e 80f
0 c7 :2 0 2
:4 0 f7 :2 0 c0
:2 0 47 :2 0 455
814 816 :3 0 458
810 818 80d 81a
819 :2 0 b1 :3 0
c1 :3 0 81c 81d
0 b3 :4 0 f8
:4 0 b6 :2 0 b7
:3 0 45c 821 823
:3 0 b6 :2 0 ca
:4 0 45f 825 827
:3 0 b6 :2 0 cb
:4 0 462 829 82b
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 f9 :3 0 830
831 0 465 82f
833 bc :4 0 467
82e 836 46a 82d
838 :3 0 46d 81e
83a :2 0 83c 470
83d 81b 83c 0
83e 472 0 867
ae :3 0 af :3 0
83f 840 0 ae
:3 0 be :3 0 842
843 0 47 :2 0
2 :4 0 fa :2 0
c0 :2 0 47 :2 0
474 848 84a :3 0
477 844 84c 841
84e 84d :2 0 b1
:3 0 c1 :3 0 850
851 0 b3 :4 0
fb :4 0 b6 :2 0
b7 :3 0 47b 855
857 :3 0 47e 852
859 :2 0 85b 481
85c 84f 85b 0
85d 483 0 867
cf :3 0 d0 :3 0
85e 85f 0 c3
:3 0 f9 :3 0 861
862 0 d1 :3 0
485 860 865 :2 0
867 488 868 80a
867 0 869 48c
0 86d 8a :3 0
47 :2 0 86a 86b
0 86d 48e 86e
791 86d 0 86f
492 0 367b 5
:3 0 c6 :2 0 494
871 872 :3 0 873
:2 0 874 :2 0 6
:3 0 c6 :2 0 496
877 878 :3 0 879
:2 0 87a :2 0 875
87c 87b :2 0 b7
:3 0 3f :3 0 e7
:4 0 fc 1 :8 0
887 21 :3 0 e9
:3 0 882 883 0
ea :3 0 884 885
0 887 498 8da
eb :3 0 21 :3 0
e9 :3 0 889 88a
0 ea :3 0 88b
88c 0 88e 49b
890 49d 88f 88e
:2 0 8d8 ec :3 0
21 :3 0 e9 :3 0
893 894 0 ea
:3 0 895 896 0
8d0 ae :3 0 af
:3 0 898 899 0
ae :3 0 be :3 0
89b 89c 0 ed
:2 0 2 :4 0 fd
:2 0 c0 :2 0 47
:2 0 49f 8a1 8a3
:3 0 4a2 89d 8a5
89a 8a7 8a6 :2 0
b1 :3 0 c1 :3 0
8a9 8aa 0 b3
:4 0 fe :4 0 b6
:2 0 b7 :3 0 4a6
8ae 8b0 :3 0 b6
:2 0 ca :4 0 4a9
8b2 8b4 :3 0 b6
:2 0 f0 :4 0 4ac
8b6 8b8 :3 0 b6
:2 0 ea :3 0 4af
8ba 8bc :3 0 b6
:2 0 f1 :4 0 4b2
8be 8c0 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 4b5 8c3 8c7
4b9 8c2 8c9 :3 0
4bc 8ab 8cb :2 0
8cd 4bf 8ce 8a8
8cd 0 8cf 4c1
0 8d0 4c3 8d3
:3 0 8d3 0 8d3
8d2 8d0 8d1 :6 0
8d5 6 :3 0 4c6
8d7 4c8 8d6 8d5
:2 0 8d8 4ca :2 0
8da 0 8da 8d9
887 8d8 :6 0 8dc
1 :3 0 4cd 8dd
87d 8dc 0 8de
4cf 0 367b 41
:3 0 3f :3 0 8df
8e0 0 367b 6b
:3 0 ff :3 0 100
:3 0 8e3 8e4 0
101 :3 0 a2 :3 0
50 :3 0 4e :2 0
4d1 8e7 8ea c3
:3 0 102 :3 0 8ec
8ed 0 4d4 8e6
8ef 8f0 :2 0 103
:2 0 4d7 8e5 8f3
8e2 8f4 0 367b
50 :3 0 101 :3 0
a2 :3 0 50 :3 0
4e :2 0 4da 8f8
8fb c3 :3 0 104
:3 0 8fd 8fe 0
4dd 8f7 900 8f6
901 0 367b 55
:3 0 ff :3 0 100
:3 0 904 905 0
101 :3 0 a2 :3 0
5c :3 0 4e :2 0
4e0 908 90b c3
:3 0 102 :3 0 90d
90e 0 4e3 907
910 911 :2 0 103
:2 0 4e6 906 914
903 915 0 367b
5c :3 0 101 :3 0
a2 :3 0 5c :3 0
4e :2 0 4e9 919
91c c3 :3 0 104
:3 0 91e 91f 0
4ec 918 921 917
922 0 367b a2
:3 0 5c :3 0 4e
:2 0 4ef 924 927
c3 :3 0 d3 :2 0
105 :3 0 929 92b
0 4f4 92a 92d
:3 0 46 :3 0 106
:4 0 92f 930 0
933 d9 :3 0 4f7
95b a2 :3 0 5c
:3 0 4e :2 0 4f9
934 937 c3 :3 0
d3 :2 0 107 :3 0
939 93b 0 4fe
93a 93d :3 0 46
:3 0 108 :4 0 93f
940 0 942 501
943 93e 942 0
95d a2 :3 0 5c
:3 0 4e :2 0 503
944 947 c3 :3 0
d3 :2 0 d4 :3 0
949 94b 0 508
94a 94d :3 0 46
:3 0 47 :4 0 94f
950 0 952 50b
957 46 :3 0 4e
:4 0 953 954 0
956 50d 958 94e
952 0 959 0
956 0 959 50f
0 95a 512 95c
92e 933 0 95d
0 95a 0 95d
514 0 367b a2
:3 0 50 :3 0 4e
:2 0 518 95e 961
109 :2 0 4e :2 0
51d 963 965 :3 0
83 :3 0 4e :2 0
967 968 0 12b2
10a :3 0 83 :3 0
10b :3 0 99 :3 0
25 :4 0 10c 1
:8 0 975 21 :3 0
e9 :3 0 970 971
0 ea :3 0 972
973 0 975 520
9c8 eb :3 0 21
:3 0 e9 :3 0 977
978 0 ea :3 0
979 97a 0 97c
523 97e 525 97d
97c :2 0 9c6 ec
:3 0 21 :3 0 e9
:3 0 981 982 0
ea :3 0 983 984
0 9be ae :3 0
af :3 0 986 987
0 ae :3 0 be
:3 0 989 98a 0
ed :2 0 2 :4 0
10d :2 0 c0 :2 0
47 :2 0 527 98f
991 :3 0 52a 98b
993 988 995 994
:2 0 b1 :3 0 c1
:3 0 997 998 0
b3 :4 0 10e :4 0
b6 :2 0 b7 :3 0
52e 99c 99e :3 0
b6 :2 0 ca :4 0
531 9a0 9a2 :3 0
b6 :2 0 f0 :4 0
534 9a4 9a6 :3 0
b6 :2 0 ea :3 0
537 9a8 9aa :3 0
b6 :2 0 f1 :4 0
53a 9ac 9ae :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 53d 9b1
9b5 541 9b0 9b7
:3 0 544 999 9b9
:2 0 9bb 547 9bc
996 9bb 0 9bd
549 0 9be 54b
9c1 :3 0 9c1 0
9c1 9c0 9be 9bf
:6 0 9c3 8 :3 0
54e 9c5 550 9c4
9c3 :2 0 9c6 552
:2 0 9c8 0 9c8
9c7 975 9c6 :6 0
12b2 1 :3 0 a2
:3 0 83 :3 0 4e
:2 0 555 9ca 9cd
109 :2 0 4e :2 0
55a 9cf 9d1 :3 0
10f :3 0 4c :3 0
110 :3 0 111 :3 0
25 :4 0 112 1
:8 0 9de 21 :3 0
e9 :3 0 9d9 9da
0 ea :3 0 9db
9dc 0 9de 55d
a31 eb :3 0 21
:3 0 e9 :3 0 9e0
9e1 0 ea :3 0
9e2 9e3 0 9e5
560 9e7 562 9e6
9e5 :2 0 a2f ec
:3 0 21 :3 0 e9
:3 0 9ea 9eb 0
ea :3 0 9ec 9ed
0 a27 ae :3 0
af :3 0 9ef 9f0
0 ae :3 0 be
:3 0 9f2 9f3 0
ed :2 0 2 :4 0
113 :2 0 c0 :2 0
47 :2 0 564 9f8
9fa :3 0 567 9f4
9fc 9f1 9fe 9fd
:2 0 b1 :3 0 c1
:3 0 a00 a01 0
b3 :4 0 114 :4 0
b6 :2 0 b7 :3 0
56b a05 a07 :3 0
b6 :2 0 ca :4 0
56e a09 a0b :3 0
b6 :2 0 f0 :4 0
571 a0d a0f :3 0
b6 :2 0 ea :3 0
574 a11 a13 :3 0
b6 :2 0 f1 :4 0
577 a15 a17 :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 57a a1a
a1e 57e a19 a20
:3 0 581 a02 a22
:2 0 a24 584 a25
9ff a24 0 a26
586 0 a27 588
a2a :3 0 a2a 0
a2a a29 a27 a28
:6 0 a2c a :3 0
58b a2e 58d a2d
a2c :2 0 a2f 58f
:2 0 a31 0 a31
a30 9de a2f :6 0
aae 1 :3 0 e5
:3 0 115 :3 0 a33
a34 0 4c :3 0
116 :4 0 592 a35
a38 d3 :2 0 4e
:2 0 597 a3a a3c
:3 0 ae :3 0 af
:3 0 a3e a3f 0
ae :3 0 be :3 0
a41 a42 0 24
:2 0 2 :4 0 117
:2 0 c0 :2 0 47
:2 0 59a a47 a49
:3 0 59d a43 a4b
a40 a4d a4c :2 0
b1 :3 0 c1 :3 0
a4f a50 0 b3
:4 0 118 :4 0 b6
:2 0 b7 :3 0 5a1
a54 a56 :3 0 b6
:2 0 ca :4 0 5a4
a58 a5a :3 0 b6
:2 0 cb :4 0 5a7
a5c a5e :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 119
:3 0 a63 a64 0
5aa a62 a66 bc
:4 0 5ac a61 a69
5af a60 a6b :3 0
b6 :2 0 11a :4 0
5b2 a6d a6f :3 0
b6 :2 0 b9 :4 0
5b5 a71 a73 :3 0
b6 :2 0 25 :3 0
5b8 a75 a77 :3 0
b6 :2 0 b9 :4 0
5bb a79 a7b :3 0
5be a51 a7d :2 0
a7f 5c1 a80 a4e
a7f 0 a81 5c3
0 aab ae :3 0
af :3 0 a82 a83
0 ae :3 0 be
:3 0 a85 a86 0
47 :2 0 2 :4 0
11b :2 0 c0 :2 0
47 :2 0 5c5 a8b
a8d :3 0 5c8 a87
a8f a84 a91 a90
:2 0 b1 :3 0 c1
:3 0 a93 a94 0
b3 :4 0 11c :4 0
b6 :2 0 b7 :3 0
5cc a98 a9a :3 0
5cf a95 a9c :2 0
a9e 5d2 a9f a92
a9e 0 aa0 5d4
0 aab cf :3 0
11d :3 0 aa1 aa2
0 c3 :3 0 119
:3 0 aa4 aa5 0
25 :3 0 d1 :3 0
5d6 aa3 aa9 :2 0
aab 5da aac a3d
aab 0 aad 5de
0 aae 5e0 aaf
9d2 aae 0 ab0
5e3 0 12b2 7a
:3 0 11e :3 0 a2
:3 0 50 :3 0 4e
:2 0 5e5 ab3 ab6
5e8 ab2 ab8 ab1
ab9 0 12b2 a2
:3 0 7a :3 0 4e
:2 0 5ea abb abe
d3 :2 0 4e :2 0
5ef ac0 ac2 :3 0
50 :3 0 11f :3 0
a2 :3 0 50 :3 0
4e :2 0 5f2 ac6
ac9 5f5 ac5 acb
ac4 acc 0 b3b
a2 :3 0 50 :3 0
4e :2 0 5f7 ace
ad1 d3 :2 0 4e
:2 0 5fc ad3 ad5
:3 0 ae :3 0 af
:3 0 ad7 ad8 0
ae :3 0 be :3 0
ada adb 0 c7
:2 0 2 :4 0 120
:2 0 c0 :2 0 47
:2 0 5ff ae0 ae2
:3 0 602 adc ae4
ad9 ae6 ae5 :2 0
b1 :3 0 c1 :3 0
ae8 ae9 0 b3
:4 0 121 :4 0 b6
:2 0 b7 :3 0 606
aed aef :3 0 b6
:2 0 ca :4 0 609
af1 af3 :3 0 b6
:2 0 cb :4 0 60c
af5 af7 :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 d7
:3 0 afc afd 0
60f afb aff bc
:4 0 611 afa b02
614 af9 b04 :3 0
617 aea b06 :2 0
b08 61a b09 ae7
b08 0 b0a 61c
0 b33 ae :3 0
af :3 0 b0b b0c
0 ae :3 0 be
:3 0 b0e b0f 0
47 :2 0 2 :4 0
122 :2 0 c0 :2 0
47 :2 0 61e b14
b16 :3 0 621 b10
b18 b0d b1a b19
:2 0 b1 :3 0 c1
:3 0 b1c b1d 0
b3 :4 0 123 :4 0
b6 :2 0 b7 :3 0
625 b21 b23 :3 0
628 b1e b25 :2 0
b27 62b b28 b1b
b27 0 b29 62d
0 b33 cf :3 0
d0 :3 0 b2a b2b
0 c3 :3 0 d7
:3 0 b2d b2e 0
d1 :3 0 62f b2c
b31 :2 0 b33 632
b34 ad6 b33 0
b35 636 0 b3b
7a :3 0 c3 :3 0
124 :3 0 b37 b38
0 b36 b39 0
b3b 638 b3c ac3
b3b 0 b3d 63c
0 12b2 26 :3 0
25 :3 0 b3e b3f
0 12b2 a2 :3 0
6b :3 0 4e :2 0
63e b41 b44 c4
:2 0 4e :2 0 643
b46 b48 :3 0 39
:3 0 14 :3 0 b4a
b4b 0 b4d 646
bab ae :3 0 af
:3 0 b4e b4f 0
ae :3 0 be :3 0
b51 b52 0 c7
:2 0 2 :4 0 125
:2 0 c0 :2 0 47
:2 0 648 b57 b59
:3 0 64b b53 b5b
b50 b5d b5c :2 0
b1 :3 0 c1 :3 0
b5f b60 0 b3
:4 0 126 :4 0 b6
:2 0 b7 :3 0 64f
b64 b66 :3 0 b6
:2 0 ca :4 0 652
b68 b6a :3 0 b6
:2 0 cb :4 0 655
b6c b6e :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 d7
:3 0 b73 b74 0
658 b72 b76 bc
:4 0 65a b71 b79
65d b70 b7b :3 0
660 b61 b7d :2 0
b7f 663 b80 b5e
b7f 0 b81 665
0 baa ae :3 0
af :3 0 b82 b83
0 ae :3 0 be
:3 0 b85 b86 0
47 :2 0 2 :4 0
127 :2 0 c0 :2 0
47 :2 0 667 b8b
b8d :3 0 66a b87
b8f b84 b91 b90
:2 0 b1 :3 0 c1
:3 0 b93 b94 0
b3 :4 0 128 :4 0
b6 :2 0 b7 :3 0
66e b98 b9a :3 0
671 b95 b9c :2 0
b9e 674 b9f b92
b9e 0 ba0 676
0 baa cf :3 0
d0 :3 0 ba1 ba2
0 c3 :3 0 d7
:3 0 ba4 ba5 0
d1 :3 0 678 ba3
ba8 :2 0 baa 67b
bac b49 b4d 0
bad 0 baa 0
bad 67f 0 12b2
85 :3 0 129 :3 0
7a :3 0 50 :3 0
26 :3 0 39 :3 0
29 :3 0 48 :3 0
682 baf bb6 bae
bb7 0 12b2 a2
:3 0 4d :3 0 4e
:2 0 689 bb9 bbc
c3 :3 0 d3 :2 0
c5 :3 0 bbe bc0
0 68e bbf bc2
:3 0 a2 :3 0 85
:3 0 4e :2 0 691
bc4 bc7 d3 :2 0
47 :2 0 696 bc9
bcb :3 0 85 :3 0
c3 :3 0 12a :3 0
bce bcf 0 bcd
bd0 0 bd2 699
bd3 bcc bd2 0
bd4 69b 0 c42
ae :3 0 af :3 0
bd5 bd6 0 ae
:3 0 be :3 0 bd8
bd9 0 24 :2 0
2 :4 0 12b :2 0
c0 :2 0 47 :2 0
69d bde be0 :3 0
6a0 bda be2 bd7
be4 be3 :2 0 b1
:3 0 c1 :3 0 be6
be7 0 b3 :4 0
12c :4 0 b6 :2 0
b7 :3 0 6a4 beb
bed :3 0 b6 :2 0
ca :4 0 6a7 bef
bf1 :3 0 b6 :2 0
cb :4 0 6aa bf3
bf5 :3 0 b6 :2 0
a2 :3 0 bb :3 0
85 :3 0 6ad bf9
bfb bc :4 0 6af
bf8 bfe 6b2 bf7
c00 :3 0 b6 :2 0
11a :4 0 6b5 c02
c04 :3 0 b6 :2 0
b9 :4 0 6b8 c06
c08 :3 0 b6 :2 0
48 :3 0 6bb c0a
c0c :3 0 b6 :2 0
b9 :4 0 6be c0e
c10 :3 0 6c1 be8
c12 :2 0 c14 6c4
c15 be5 c14 0
c16 6c6 0 c42
ae :3 0 af :3 0
c17 c18 0 ae
:3 0 be :3 0 c1a
c1b 0 47 :2 0
2 :4 0 12d :2 0
c0 :2 0 47 :2 0
6c8 c20 c22 :3 0
6cb c1c c24 c19
c26 c25 :2 0 b1
:3 0 c1 :3 0 c28
c29 0 b3 :4 0
12e :4 0 b6 :2 0
b7 :3 0 6cf c2d
c2f :3 0 6d2 c2a
c31 :2 0 c33 6d5
c34 c27 c33 0
c35 6d7 0 c42
cf :3 0 11d :3 0
c36 c37 0 a2
:3 0 85 :3 0 4e
:2 0 6d9 c39 c3c
48 :3 0 d1 :3 0
6dc c38 c40 :2 0
c42 6e0 c43 bc3
c42 0 c44 6e5
0 12b2 a2 :3 0
85 :3 0 4e :2 0
6e7 c45 c48 c4
:2 0 4e :2 0 6ec
c4a c4c :3 0 a2
:3 0 85 :3 0 4e
:2 0 6ef c4e c51
c4 :2 0 47 :2 0
6f4 c53 c55 :3 0
c4d c57 c56 :2 0
ae :3 0 af :3 0
c59 c5a 0 ae
:3 0 be :3 0 c5c
c5d 0 24 :2 0
2 :4 0 12f :2 0
c0 :2 0 47 :2 0
6f7 c62 c64 :3 0
6fa c5e c66 c5b
c68 c67 :2 0 b1
:3 0 c1 :3 0 c6a
c6b 0 b3 :4 0
130 :4 0 b6 :2 0
b7 :3 0 6fe c6f
c71 :3 0 b6 :2 0
ca :4 0 701 c73
c75 :3 0 b6 :2 0
cb :4 0 704 c77
c79 :3 0 b6 :2 0
a2 :3 0 bb :3 0
85 :3 0 707 c7d
c7f bc :4 0 709
c7c c82 70c c7b
c84 :3 0 b6 :2 0
11a :4 0 70f c86
c88 :3 0 b6 :2 0
b9 :4 0 712 c8a
c8c :3 0 b6 :2 0
48 :3 0 715 c8e
c90 :3 0 b6 :2 0
b9 :4 0 718 c92
c94 :3 0 71b c6c
c96 :2 0 c98 71e
c99 c69 c98 0
c9a 720 0 cc6
ae :3 0 af :3 0
c9b c9c 0 ae
:3 0 be :3 0 c9e
c9f 0 47 :2 0
2 :4 0 131 :2 0
c0 :2 0 47 :2 0
722 ca4 ca6 :3 0
725 ca0 ca8 c9d
caa ca9 :2 0 b1
:3 0 c1 :3 0 cac
cad 0 b3 :4 0
132 :4 0 b6 :2 0
b7 :3 0 729 cb1
cb3 :3 0 72c cae
cb5 :2 0 cb7 72f
cb8 cab cb7 0
cb9 731 0 cc6
cf :3 0 11d :3 0
cba cbb 0 a2
:3 0 85 :3 0 4e
:2 0 733 cbd cc0
48 :3 0 d1 :3 0
736 cbc cc4 :2 0
cc6 73a cc7 c58
cc6 0 cc8 73e
0 12b2 a2 :3 0
7a :3 0 4e :2 0
740 cc9 ccc c3
:3 0 d3 :2 0 124
:3 0 cce cd0 0
745 ccf cd2 :3 0
133 :3 0 a2 :3 0
50 :3 0 4e :2 0
748 cd5 cd8 74b
cd4 cda c4 :2 0
4e :2 0 74f cdc
cde :3 0 99 :3 0
a2 :3 0 134 :3 0
a2 :3 0 135 :3 0
136 :3 0 25 :3 0
5f :3 0 60 :3 0
64 :3 0 110 :3 0
111 :3 0 26 :4 0
137 1 :8 0 cf3
21 :3 0 e9 :3 0
cee cef 0 ea
:3 0 cf0 cf1 0
cf3 752 d46 eb
:3 0 21 :3 0 e9
:3 0 cf5 cf6 0
ea :3 0 cf7 cf8
0 cfa 755 cfc
757 cfb cfa :2 0
d44 ec :3 0 21
:3 0 e9 :3 0 cff
d00 0 ea :3 0
d01 d02 0 d3c
ae :3 0 af :3 0
d04 d05 0 ae
:3 0 be :3 0 d07
d08 0 ed :2 0
2 :4 0 138 :2 0
c0 :2 0 47 :2 0
759 d0d d0f :3 0
75c d09 d11 d06
d13 d12 :2 0 b1
:3 0 c1 :3 0 d15
d16 0 b3 :4 0
139 :4 0 b6 :2 0
b7 :3 0 760 d1a
d1c :3 0 b6 :2 0
ca :4 0 763 d1e
d20 :3 0 b6 :2 0
f0 :4 0 766 d22
d24 :3 0 b6 :2 0
ea :3 0 769 d26
d28 :3 0 b6 :2 0
f1 :4 0 76c d2a
d2c :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
76f d2f d33 773
d2e d35 :3 0 776
d17 d37 :2 0 d39
779 d3a d14 d39
0 d3b 77b 0
d3c 77d d3f :3 0
d3f 0 d3f d3e
d3c d3d :6 0 d41
c :3 0 780 d43
782 d42 d41 :2 0
d44 784 :2 0 d46
0 d46 d45 cf3
d44 :6 0 d48 1
:3 0 787 dcc 13a
:3 0 13b :3 0 13a
:3 0 13c :3 0 13a
:3 0 13d :3 0 13a
:3 0 99 :3 0 a2
:3 0 13e :3 0 134
:3 0 a2 :3 0 13e
:3 0 135 :3 0 13e
:3 0 136 :3 0 13a
:3 0 13f :3 0 13a
:3 0 140 :3 0 72
:3 0 43 :3 0 44
:3 0 25 :3 0 5f
:3 0 60 :3 0 64
:3 0 73 :3 0 110
:3 0 13e :3 0 110
:3 0 13a :3 0 13a
:3 0 111 :3 0 26
:3 0 13e :3 0 111
:3 0 13a :3 0 99
:4 0 141 1 :8 0
d76 21 :3 0 e9
:3 0 d71 d72 0
ea :3 0 d73 d74
0 d76 789 dc9
eb :3 0 21 :3 0
e9 :3 0 d78 d79
0 ea :3 0 d7a
d7b 0 d7d 78c
d7f 78e d7e d7d
:2 0 dc7 ec :3 0
21 :3 0 e9 :3 0
d82 d83 0 ea
:3 0 d84 d85 0
dbf ae :3 0 af
:3 0 d87 d88 0
ae :3 0 be :3 0
d8a d8b 0 ed
:2 0 2 :4 0 142
:2 0 c0 :2 0 47
:2 0 790 d90 d92
:3 0 793 d8c d94
d89 d96 d95 :2 0
b1 :3 0 c1 :3 0
d98 d99 0 b3
:4 0 143 :4 0 b6
:2 0 b7 :3 0 797
d9d d9f :3 0 b6
:2 0 ca :4 0 79a
da1 da3 :3 0 b6
:2 0 f0 :4 0 79d
da5 da7 :3 0 b6
:2 0 ea :3 0 7a0
da9 dab :3 0 b6
:2 0 f1 :4 0 7a3
dad daf :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 7a6 db2 db6
7aa db1 db8 :3 0
7ad d9a dba :2 0
dbc 7b0 dbd d97
dbc 0 dbe 7b2
0 dbf 7b4 dc2
:3 0 dc2 0 dc2
dc1 dbf dc0 :6 0
dc4 e :3 0 7b7
dc6 7b9 dc5 dc4
:2 0 dc7 7bb :2 0
dc9 0 dc9 dc8
d76 dc7 :6 0 dcb
1 :3 0 7be dcd
cdf d48 0 dce
0 dcb 0 dce
7c0 0 e4a 21
:3 0 e9 :3 0 dcf
dd0 0 21 :3 0
c4 :2 0 f5 :3 0
dd2 dd4 0 7c5
dd3 dd6 :3 0 dd7
:2 0 ae :3 0 af
:3 0 dd9 dda 0
ae :3 0 be :3 0
ddc ddd 0 24
:2 0 2 :4 0 144
:2 0 c0 :2 0 47
:2 0 7c8 de2 de4
:3 0 7cb dde de6
ddb de8 de7 :2 0
b1 :3 0 c1 :3 0
dea deb 0 b3
:4 0 145 :4 0 b6
:2 0 b7 :3 0 7cf
def df1 :3 0 b6
:2 0 ca :4 0 7d2
df3 df5 :3 0 b6
:2 0 cb :4 0 7d5
df7 df9 :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 146
:3 0 dfe dff 0
7d8 dfd e01 bc
:4 0 7da dfc e04
7dd dfb e06 :3 0
b6 :2 0 11a :4 0
7e0 e08 e0a :3 0
b6 :2 0 b9 :4 0
7e3 e0c e0e :3 0
b6 :2 0 26 :3 0
7e6 e10 e12 :3 0
b6 :2 0 b9 :4 0
7e9 e14 e16 :3 0
7ec dec e18 :2 0
e1a 7ef e1b de9
e1a 0 e1c 7f1
0 e46 ae :3 0
af :3 0 e1d e1e
0 ae :3 0 be
:3 0 e20 e21 0
47 :2 0 2 :4 0
147 :2 0 c0 :2 0
47 :2 0 7f3 e26
e28 :3 0 7f6 e22
e2a e1f e2c e2b
:2 0 b1 :3 0 c1
:3 0 e2e e2f 0
b3 :4 0 148 :4 0
b6 :2 0 b7 :3 0
7fa e33 e35 :3 0
7fd e30 e37 :2 0
e39 800 e3a e2d
e39 0 e3b 802
0 e46 cf :3 0
11d :3 0 e3c e3d
0 c3 :3 0 146
:3 0 e3f e40 0
26 :3 0 d1 :3 0
804 e3e e44 :2 0
e46 808 e47 dd8
e46 0 e48 80c
0 e4a d9 :3 0
80e 109f a2 :3 0
7a :3 0 4e :2 0
811 e4b e4e c3
:3 0 d3 :2 0 149
:3 0 e50 e52 0
816 e51 e54 :3 0
99 :3 0 14a :3 0
14b :3 0 25 :3 0
50 :3 0 23 :3 0
14c :3 0 111 :3 0
26 :4 0 14d 1
:8 0 e65 21 :3 0
e9 :3 0 e60 e61
0 ea :3 0 e62
e63 0 e65 819
eb8 eb :3 0 21
:3 0 e9 :3 0 e67
e68 0 ea :3 0
e69 e6a 0 e6c
81c e6e 81e e6d
e6c :2 0 eb6 ec
:3 0 21 :3 0 e9
:3 0 e71 e72 0
ea :3 0 e73 e74
0 eae ae :3 0
af :3 0 e76 e77
0 ae :3 0 be
:3 0 e79 e7a 0
ed :2 0 2 :4 0
14e :2 0 c0 :2 0
47 :2 0 820 e7f
e81 :3 0 823 e7b
e83 e78 e85 e84
:2 0 b1 :3 0 c1
:3 0 e87 e88 0
b3 :4 0 14f :4 0
b6 :2 0 b7 :3 0
827 e8c e8e :3 0
b6 :2 0 ca :4 0
82a e90 e92 :3 0
b6 :2 0 f0 :4 0
82d e94 e96 :3 0
b6 :2 0 ea :3 0
830 e98 e9a :3 0
b6 :2 0 f1 :4 0
833 e9c e9e :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 836 ea1
ea5 83a ea0 ea7
:3 0 83d e89 ea9
:2 0 eab 840 eac
e86 eab 0 ead
842 0 eae 844
eb1 :3 0 eb1 0
eb1 eb0 eae eaf
:6 0 eb3 10 :3 0
847 eb5 849 eb4
eb3 :2 0 eb6 84b
:2 0 eb8 0 eb8
eb7 e65 eb6 :6 0
102f 1 :3 0 21
:3 0 e9 :3 0 eba
ebb 0 21 :3 0
c4 :2 0 f5 :3 0
ebd ebf 0 850
ebe ec1 :3 0 ec2
:2 0 ae :3 0 af
:3 0 ec4 ec5 0
ae :3 0 be :3 0
ec7 ec8 0 24
:2 0 2 :4 0 150
:2 0 c0 :2 0 47
:2 0 853 ecd ecf
:3 0 856 ec9 ed1
ec6 ed3 ed2 :2 0
b1 :3 0 c1 :3 0
ed5 ed6 0 b3
:4 0 151 :4 0 b6
:2 0 b7 :3 0 85a
eda edc :3 0 b6
:2 0 ca :4 0 85d
ede ee0 :3 0 b6
:2 0 cb :4 0 860
ee2 ee4 :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 146
:3 0 ee9 eea 0
863 ee8 eec bc
:4 0 865 ee7 eef
868 ee6 ef1 :3 0
b6 :2 0 11a :4 0
86b ef3 ef5 :3 0
b6 :2 0 b9 :4 0
86e ef7 ef9 :3 0
b6 :2 0 26 :3 0
871 efb efd :3 0
b6 :2 0 b9 :4 0
874 eff f01 :3 0
877 ed7 f03 :2 0
f05 87a f06 ed4
f05 0 f07 87c
0 f31 ae :3 0
af :3 0 f08 f09
0 ae :3 0 be
:3 0 f0b f0c 0
47 :2 0 2 :4 0
152 :2 0 c0 :2 0
47 :2 0 87e f11
f13 :3 0 881 f0d
f15 f0a f17 f16
:2 0 b1 :3 0 c1
:3 0 f19 f1a 0
b3 :4 0 153 :4 0
b6 :2 0 b7 :3 0
885 f1e f20 :3 0
888 f1b f22 :2 0
f24 88b f25 f18
f24 0 f26 88d
0 f31 cf :3 0
11d :3 0 f27 f28
0 c3 :3 0 146
:3 0 f2a f2b 0
26 :3 0 d1 :3 0
88f f29 f2f :2 0
f31 893 f32 ec3
f31 0 f33 897
0 102f 154 :3 0
41 :3 0 154 :3 0
155 :3 0 41 :3 0
a2 :3 0 134 :3 0
a2 :3 0 135 :3 0
136 :3 0 41 :3 0
5f :3 0 60 :3 0
64 :3 0 110 :3 0
99 :3 0 25 :3 0
111 :3 0 25 :4 0
156 1 :8 0 f4d
21 :3 0 e9 :3 0
f48 f49 0 ea
:3 0 f4a f4b 0
f4d 899 fa0 eb
:3 0 21 :3 0 e9
:3 0 f4f f50 0
ea :3 0 f51 f52
0 f54 89c f56
89e f55 f54 :2 0
f9e ec :3 0 21
:3 0 e9 :3 0 f59
f5a 0 ea :3 0
f5b f5c 0 f96
ae :3 0 af :3 0
f5e f5f 0 ae
:3 0 be :3 0 f61
f62 0 ed :2 0
2 :4 0 157 :2 0
c0 :2 0 47 :2 0
8a0 f67 f69 :3 0
8a3 f63 f6b f60
f6d f6c :2 0 b1
:3 0 c1 :3 0 f6f
f70 0 b3 :4 0
158 :4 0 b6 :2 0
b7 :3 0 8a7 f74
f76 :3 0 b6 :2 0
ca :4 0 8aa f78
f7a :3 0 b6 :2 0
f0 :4 0 8ad f7c
f7e :3 0 b6 :2 0
ea :3 0 8b0 f80
f82 :3 0 b6 :2 0
f1 :4 0 8b3 f84
f86 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
8b6 f89 f8d 8ba
f88 f8f :3 0 8bd
f71 f91 :2 0 f93
8c0 f94 f6e f93
0 f95 8c2 0
f96 8c4 f99 :3 0
f99 0 f99 f98
f96 f97 :6 0 f9b
12 :3 0 8c7 f9d
8c9 f9c f9b :2 0
f9e 8cb :2 0 fa0
0 fa0 f9f f4d
f9e :6 0 102f 1
:3 0 21 :3 0 e9
:3 0 fa2 fa3 0
21 :3 0 c4 :2 0
f5 :3 0 fa5 fa7
0 8d0 fa6 fa9
:3 0 faa :2 0 ae
:3 0 af :3 0 fac
fad 0 ae :3 0
be :3 0 faf fb0
0 24 :2 0 2
:4 0 159 :2 0 c0
:2 0 47 :2 0 8d3
fb5 fb7 :3 0 8d6
fb1 fb9 fae fbb
fba :2 0 b1 :3 0
c1 :3 0 fbd fbe
0 b3 :4 0 15a
:4 0 b6 :2 0 b7
:3 0 8da fc2 fc4
:3 0 b6 :2 0 ca
:4 0 8dd fc6 fc8
:3 0 b6 :2 0 cb
:4 0 8e0 fca fcc
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 146 :3 0 fd1
fd2 0 8e3 fd0
fd4 bc :4 0 8e5
fcf fd7 8e8 fce
fd9 :3 0 b6 :2 0
11a :4 0 8eb fdb
fdd :3 0 b6 :2 0
b9 :4 0 8ee fdf
fe1 :3 0 b6 :2 0
25 :3 0 8f1 fe3
fe5 :3 0 b6 :2 0
b9 :4 0 8f4 fe7
fe9 :3 0 8f7 fbf
feb :2 0 fed 8fa
fee fbc fed 0
fef 8fc 0 1019
ae :3 0 af :3 0
ff0 ff1 0 ae
:3 0 be :3 0 ff3
ff4 0 47 :2 0
2 :4 0 15b :2 0
c0 :2 0 47 :2 0
8fe ff9 ffb :3 0
901 ff5 ffd ff2
fff ffe :2 0 b1
:3 0 c1 :3 0 1001
1002 0 b3 :4 0
15c :4 0 b6 :2 0
b7 :3 0 905 1006
1008 :3 0 908 1003
100a :2 0 100c 90b
100d 1000 100c 0
100e 90d 0 1019
cf :3 0 11d :3 0
100f 1010 0 c3
:3 0 146 :3 0 1012
1013 0 25 :3 0
d1 :3 0 90f 1011
1017 :2 0 1019 913
101a fab 1019 0
101b 917 0 102f
23 :3 0 e4 :2 0
919 101d 101e :3 0
101f :2 0 7a :3 0
c3 :3 0 124 :3 0
1022 1023 0 1021
1024 0 102c 50
:3 0 15d :3 0 50
:3 0 91b 1027 1029
1026 102a 0 102c
91d 102d 1020 102c
0 102e 920 0
102f 922 1030 e55
102f 0 10a1 ae
:3 0 af :3 0 1031
1032 0 ae :3 0
be :3 0 1034 1035
0 24 :2 0 2
:4 0 15e :2 0 c0
:2 0 47 :2 0 928
103a 103c :3 0 92b
1036 103e 1033 1040
103f :2 0 b1 :3 0
c1 :3 0 1042 1043
0 b3 :4 0 15f
:4 0 b6 :2 0 b7
:3 0 92f 1047 1049
:3 0 b6 :2 0 ca
:4 0 932 104b 104d
:3 0 b6 :2 0 cb
:4 0 935 104f 1051
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 1056
1057 0 938 1055
1059 bc :4 0 93a
1054 105c 93d 1053
105e :3 0 b6 :2 0
11a :4 0 940 1060
1062 :3 0 b6 :2 0
b9 :4 0 943 1064
1066 :3 0 b6 :2 0
25 :3 0 946 1068
106a :3 0 b6 :2 0
b9 :4 0 949 106c
106e :3 0 94c 1044
1070 :2 0 1072 94f
1073 1041 1072 0
1074 951 0 109e
ae :3 0 af :3 0
1075 1076 0 ae
:3 0 be :3 0 1078
1079 0 47 :2 0
2 :4 0 160 :2 0
c0 :2 0 47 :2 0
953 107e 1080 :3 0
956 107a 1082 1077
1084 1083 :2 0 b1
:3 0 c1 :3 0 1086
1087 0 b3 :4 0
161 :4 0 b6 :2 0
b7 :3 0 95a 108b
108d :3 0 95d 1088
108f :2 0 1091 960
1092 1085 1091 0
1093 962 0 109e
cf :3 0 11d :3 0
1094 1095 0 c3
:3 0 d7 :3 0 1097
1098 0 25 :3 0
d1 :3 0 964 1096
109c :2 0 109e 968
10a0 cd3 e4a 0
10a1 0 109e 0
10a1 96c 0 12b2
a2 :3 0 5c :3 0
4e :2 0 970 10a2
10a5 c3 :3 0 c4
:2 0 d4 :3 0 10a7
10a9 0 975 10a8
10ab :3 0 162 :3 0
e5 :3 0 163 :3 0
41 :3 0 164 :3 0
165 :3 0 a2 :3 0
e5 :3 0 163 :3 0
165 :3 0 a2 :3 0
e5 :3 0 163 :3 0
166 :3 0 4b :3 0
6d :3 0 71 :3 0
45 :3 0 6e :3 0
6f :3 0 167 :3 0
9b :3 0 39 :4 0
168 1 :8 0 10ca
21 :3 0 e9 :3 0
10c5 10c6 0 ea
:3 0 10c7 10c8 0
10ca 978 111d eb
:3 0 21 :3 0 e9
:3 0 10cc 10cd 0
ea :3 0 10ce 10cf
0 10d1 97b 10d3
97d 10d2 10d1 :2 0
111b ec :3 0 21
:3 0 e9 :3 0 10d6
10d7 0 ea :3 0
10d8 10d9 0 1113
ae :3 0 af :3 0
10db 10dc 0 ae
:3 0 be :3 0 10de
10df 0 ed :2 0
2 :4 0 169 :2 0
c0 :2 0 47 :2 0
97f 10e4 10e6 :3 0
982 10e0 10e8 10dd
10ea 10e9 :2 0 b1
:3 0 c1 :3 0 10ec
10ed 0 b3 :4 0
16a :4 0 b6 :2 0
b7 :3 0 986 10f1
10f3 :3 0 b6 :2 0
ca :4 0 989 10f5
10f7 :3 0 b6 :2 0
f0 :4 0 98c 10f9
10fb :3 0 b6 :2 0
ea :3 0 98f 10fd
10ff :3 0 b6 :2 0
f1 :4 0 992 1101
1103 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
995 1106 110a 999
1105 110c :3 0 99c
10ee 110e :2 0 1110
99f 1111 10eb 1110
0 1112 9a1 0
1113 9a3 1116 :3 0
1116 0 1116 1115
1113 1114 :6 0 1118
14 :3 0 9a6 111a
9a8 1119 1118 :2 0
111b 9aa :2 0 111d
0 111d 111c 10ca
111b :6 0 12af 1
:3 0 21 :3 0 e9
:3 0 111f 1120 0
21 :3 0 d3 :2 0
16b :3 0 1122 1124
0 9af 1123 1126
:3 0 1127 :2 0 ae
:3 0 af :3 0 1129
112a 0 ae :3 0
be :3 0 112c 112d
0 24 :2 0 2
:4 0 16c :2 0 c0
:2 0 47 :2 0 9b2
1132 1134 :3 0 9b5
112e 1136 112b 1138
1137 :2 0 b1 :3 0
c1 :3 0 113a 113b
0 b3 :4 0 16d
:4 0 b6 :2 0 b7
:3 0 9b9 113f 1141
:3 0 b6 :2 0 ca
:4 0 9bc 1143 1145
:3 0 b6 :2 0 cb
:4 0 9bf 1147 1149
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 146 :3 0 114e
114f 0 9c2 114d
1151 bc :4 0 9c4
114c 1154 9c7 114b
1156 :3 0 b6 :2 0
11a :4 0 9ca 1158
115a :3 0 b6 :2 0
b9 :4 0 9cd 115c
115e :3 0 b6 :2 0
39 :3 0 9d0 1160
1162 :3 0 b6 :2 0
b9 :4 0 9d3 1164
1166 :3 0 9d6 113c
1168 :2 0 116a 9d9
116b 1139 116a 0
116c 9db 0 1197
ae :3 0 af :3 0
116d 116e 0 ae
:3 0 be :3 0 1170
1171 0 47 :2 0
2 :4 0 16e :2 0
c0 :2 0 47 :2 0
9dd 1176 1178 :3 0
9e0 1172 117a 116f
117c 117b :2 0 b1
:3 0 c1 :3 0 117e
117f 0 b3 :4 0
16f :4 0 b6 :2 0
b7 :3 0 9e4 1183
1185 :3 0 9e7 1180
1187 :2 0 1189 9ea
118a 117d 1189 0
118b 9ec 0 1197
cf :3 0 11d :3 0
118c 118d 0 c3
:3 0 146 :3 0 118f
1190 0 39 :3 0
d1 :3 0 9ee 118e
1194 :2 0 1197 d9
:3 0 9f2 12ad 21
:3 0 e9 :3 0 1198
1199 0 21 :3 0
d3 :2 0 f5 :3 0
119b 119d 0 9f8
119c 119f :3 0 11a0
:2 0 f2 :3 0 71
:3 0 47 :2 0 47
:2 0 9fb 11a2 11a6
d3 :2 0 4e :4 0
a01 11a8 11aa :3 0
a2 :3 0 6f :3 0
4e :2 0 a04 11ac
11af 109 :2 0 4e
:2 0 a09 11b1 11b3
:3 0 a2 :3 0 6d
:3 0 4e :2 0 a0c
11b5 11b8 a2 :3 0
109 :2 0 6f :3 0
4e :2 0 a0f 11ba
11be a14 11bb 11c0
:3 0 11b4 11c2 11c1
:2 0 11c3 :2 0 11ab
11c5 11c4 :2 0 ae
:3 0 af :3 0 11c7
11c8 0 ae :3 0
be :3 0 11ca 11cb
0 24 :2 0 2
:4 0 170 :2 0 c0
:2 0 47 :2 0 a17
11d0 11d2 :3 0 a1a
11cc 11d4 11c9 11d6
11d5 :2 0 b1 :3 0
c1 :3 0 11d8 11d9
0 b3 :4 0 171
:4 0 b6 :2 0 b7
:3 0 a1e 11dd 11df
:3 0 b6 :2 0 ca
:4 0 a21 11e1 11e3
:3 0 b6 :2 0 cb
:4 0 a24 11e5 11e7
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 172 :3 0 11ec
11ed 0 a27 11eb
11ef bc :4 0 a29
11ea 11f2 a2c 11e9
11f4 :3 0 b6 :2 0
11a :4 0 a2f 11f6
11f8 :3 0 b6 :2 0
b9 :4 0 a32 11fa
11fc :3 0 b6 :2 0
39 :3 0 a35 11fe
1200 :3 0 b6 :2 0
b9 :4 0 a38 1202
1204 :3 0 a3b 11da
1206 :2 0 1208 a3e
1209 11d7 1208 0
120a a40 0 1234
ae :3 0 af :3 0
120b 120c 0 ae
:3 0 be :3 0 120e
120f 0 47 :2 0
2 :4 0 173 :2 0
c0 :2 0 47 :2 0
a42 1214 1216 :3 0
a45 1210 1218 120d
121a 1219 :2 0 b1
:3 0 c1 :3 0 121c
121d 0 b3 :4 0
174 :4 0 b6 :2 0
b7 :3 0 a49 1221
1223 :3 0 a4c 121e
1225 :2 0 1227 a4f
1228 121b 1227 0
1229 a51 0 1234
cf :3 0 11d :3 0
122a 122b 0 c3
:3 0 172 :3 0 122d
122e 0 39 :3 0
d1 :3 0 a53 122c
1232 :2 0 1234 a57
1235 11c6 1234 0
1236 a5b 0 12ab
a2 :3 0 6d :3 0
4e :2 0 a5d 1237
123a a2 :3 0 f6
:2 0 6e :3 0 4e
:2 0 a60 123c 1240
a65 123d 1242 :3 0
e5 :3 0 175 :3 0
176 :3 0 f2 :3 0
45 :3 0 e5 :3 0
177 :3 0 41 :3 0
e7 :4 0 178 1
:8 0 1253 21 :3 0
e9 :3 0 124e 124f
0 ea :3 0 1250
1251 0 1253 a68
12a6 eb :3 0 21
:3 0 e9 :3 0 1255
1256 0 ea :3 0
1257 1258 0 125a
a6b 125c a6d 125b
125a :2 0 12a4 ec
:3 0 21 :3 0 e9
:3 0 125f 1260 0
ea :3 0 1261 1262
0 129c ae :3 0
af :3 0 1264 1265
0 ae :3 0 be
:3 0 1267 1268 0
ed :2 0 2 :4 0
179 :2 0 c0 :2 0
47 :2 0 a6f 126d
126f :3 0 a72 1269
1271 1266 1273 1272
:2 0 b1 :3 0 c1
:3 0 1275 1276 0
b3 :4 0 17a :4 0
b6 :2 0 b7 :3 0
a76 127a 127c :3 0
b6 :2 0 ca :4 0
a79 127e 1280 :3 0
b6 :2 0 f0 :4 0
a7c 1282 1284 :3 0
b6 :2 0 ea :3 0
a7f 1286 1288 :3 0
b6 :2 0 f1 :4 0
a82 128a 128c :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 a85 128f
1293 a89 128e 1295
:3 0 a8c 1277 1297
:2 0 1299 a8f 129a
1274 1299 0 129b
a91 0 129c a93
129f :3 0 129f 0
129f 129e 129c 129d
:6 0 12a1 16 :3 0
a96 12a3 a98 12a2
12a1 :2 0 12a4 a9a
:2 0 12a6 0 12a6
12a5 1253 12a4 :6 0
12a8 1 :3 0 a9d
12a9 1243 12a8 0
12aa a9f 0 12ab
aa1 12ac 11a1 12ab
0 12ae 1128 1197
0 12ae aa4 0
12af aa7 12b0 10ac
12af 0 12b1 aaa
0 12b2 aac 12b3
966 12b2 0 12b4
ab9 0 367b a2
:3 0 50 :3 0 4e
:2 0 abb 12b5 12b8
d3 :2 0 4e :2 0
ac0 12ba 12bc :3 0
a2 :3 0 5c :3 0
4e :2 0 ac3 12be
12c1 c3 :3 0 d3
:2 0 d4 :3 0 12c3
12c5 0 ac8 12c4
12c7 :3 0 16 :3 0
c6 :2 0 acb 12ca
12cb :3 0 12cc :2 0
12c8 12ce 12cd :2 0
a2 :3 0 6b :3 0
4e :2 0 acd 12d0
12d3 d3 :2 0 4e
:2 0 ad2 12d5 12d7
:3 0 12cf 12d9 12d8
:2 0 ae :3 0 af
:3 0 12db 12dc 0
ae :3 0 be :3 0
12de 12df 0 24
:2 0 2 :4 0 17b
:2 0 c0 :2 0 47
:2 0 ad5 12e4 12e6
:3 0 ad8 12e0 12e8
12dd 12ea 12e9 :2 0
b1 :3 0 c1 :3 0
12ec 12ed 0 b3
:4 0 17c :4 0 b6
:2 0 b7 :3 0 adc
12f1 12f3 :3 0 b6
:2 0 ca :4 0 adf
12f5 12f7 :3 0 b6
:2 0 cb :4 0 ae2
12f9 12fb :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 17d
:3 0 1300 1301 0
ae5 12ff 1303 bc
:4 0 ae7 12fe 1306
aea 12fd 1308 :3 0
b6 :2 0 11a :4 0
aed 130a 130c :3 0
b6 :2 0 b9 :4 0
af0 130e 1310 :3 0
b6 :2 0 25 :3 0
af3 1312 1314 :3 0
b6 :2 0 b9 :4 0
af6 1316 1318 :3 0
af9 12ee 131a :2 0
131c afc 131d 12eb
131c 0 131e afe
0 1348 ae :3 0
af :3 0 131f 1320
0 ae :3 0 be
:3 0 1322 1323 0
47 :2 0 2 :4 0
17e :2 0 c0 :2 0
47 :2 0 b00 1328
132a :3 0 b03 1324
132c 1321 132e 132d
:2 0 b1 :3 0 c1
:3 0 1330 1331 0
b3 :4 0 17f :4 0
b6 :2 0 b7 :3 0
b07 1335 1337 :3 0
b0a 1332 1339 :2 0
133b b0d 133c 132f
133b 0 133d b0f
0 1348 cf :3 0
11d :3 0 133e 133f
0 c3 :3 0 17d
:3 0 1341 1342 0
25 :3 0 d1 :3 0
b11 1340 1346 :2 0
1348 b15 1349 12da
1348 0 134a b19
0 14a6 a2 :3 0
4d :3 0 4e :2 0
b1b 134b 134e c3
:3 0 c4 :2 0 c5
:3 0 1350 1352 0
b20 1351 1354 :3 0
136 :3 0 a2 :3 0
134 :3 0 a2 :3 0
135 :3 0 64 :3 0
5f :3 0 60 :3 0
110 :3 0 111 :3 0
25 :4 0 180 1
:8 0 1367 21 :3 0
e9 :3 0 1362 1363
0 ea :3 0 1364
1365 0 1367 b23
13ba eb :3 0 21
:3 0 e9 :3 0 1369
136a 0 ea :3 0
136b 136c 0 136e
b26 1370 b28 136f
136e :2 0 13b8 ec
:3 0 21 :3 0 e9
:3 0 1373 1374 0
ea :3 0 1375 1376
0 13b0 ae :3 0
af :3 0 1378 1379
0 ae :3 0 be
:3 0 137b 137c 0
ed :2 0 2 :4 0
181 :2 0 c0 :2 0
47 :2 0 b2a 1381
1383 :3 0 b2d 137d
1385 137a 1387 1386
:2 0 b1 :3 0 c1
:3 0 1389 138a 0
b3 :4 0 182 :4 0
b6 :2 0 b7 :3 0
b31 138e 1390 :3 0
b6 :2 0 ca :4 0
b34 1392 1394 :3 0
b6 :2 0 f0 :4 0
b37 1396 1398 :3 0
b6 :2 0 ea :3 0
b3a 139a 139c :3 0
b6 :2 0 f1 :4 0
b3d 139e 13a0 :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 b40 13a3
13a7 b44 13a2 13a9
:3 0 b47 138b 13ab
:2 0 13ad b4a 13ae
1388 13ad 0 13af
b4c 0 13b0 b4e
13b3 :3 0 13b3 0
13b3 13b2 13b0 13b1
:6 0 13b5 18 :3 0
b51 13b7 b53 13b6
13b5 :2 0 13b8 b55
:2 0 13ba 0 13ba
13b9 1367 13b8 :6 0
14a3 1 :3 0 21
:3 0 e9 :3 0 13bc
13bd 0 21 :3 0
d3 :2 0 16b :3 0
13bf 13c1 0 b5a
13c0 13c3 :3 0 13c4
:2 0 5f :3 0 60
:3 0 183 :3 0 111
:3 0 25 :4 0 184
1 :8 0 13d1 21
:3 0 e9 :3 0 13cc
13cd 0 ea :3 0
13ce 13cf 0 13d1
b5d 1424 eb :3 0
21 :3 0 e9 :3 0
13d3 13d4 0 ea
:3 0 13d5 13d6 0
13d8 b60 13da b62
13d9 13d8 :2 0 1422
ec :3 0 21 :3 0
e9 :3 0 13dd 13de
0 ea :3 0 13df
13e0 0 141a ae
:3 0 af :3 0 13e2
13e3 0 ae :3 0
be :3 0 13e5 13e6
0 ed :2 0 2
:4 0 185 :2 0 c0
:2 0 47 :2 0 b64
13eb 13ed :3 0 b67
13e7 13ef 13e4 13f1
13f0 :2 0 b1 :3 0
c1 :3 0 13f3 13f4
0 b3 :4 0 186
:4 0 b6 :2 0 b7
:3 0 b6b 13f8 13fa
:3 0 b6 :2 0 ca
:4 0 b6e 13fc 13fe
:3 0 b6 :2 0 f0
:4 0 b71 1400 1402
:3 0 b6 :2 0 ea
:3 0 b74 1404 1406
:3 0 b6 :2 0 f1
:4 0 b77 1408 140a
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 b7a
140d 1411 b7e 140c
1413 :3 0 b81 13f5
1415 :2 0 1417 b84
1418 13f2 1417 0
1419 b86 0 141a
b88 141d :3 0 141d
0 141d 141c 141a
141b :6 0 141f 1a
:3 0 b8b 1421 b8d
1420 141f :2 0 1422
b8f :2 0 1424 0
1424 1423 13d1 1422
:6 0 14a0 1 :3 0
21 :3 0 e9 :3 0
1426 1427 0 21
:3 0 d3 :2 0 16b
:3 0 1429 142b 0
b94 142a 142d :3 0
142e :2 0 ae :3 0
af :3 0 1430 1431
0 ae :3 0 be
:3 0 1433 1434 0
24 :2 0 2 :4 0
187 :2 0 c0 :2 0
47 :2 0 b97 1439
143b :3 0 b9a 1435
143d 1432 143f 143e
:2 0 b1 :3 0 c1
:3 0 1441 1442 0
b3 :4 0 188 :4 0
b6 :2 0 b7 :3 0
b9e 1446 1448 :3 0
b6 :2 0 ca :4 0
ba1 144a 144c :3 0
b6 :2 0 cb :4 0
ba4 144e 1450 :3 0
b6 :2 0 a2 :3 0
bb :3 0 c3 :3 0
d7 :3 0 1455 1456
0 ba7 1454 1458
bc :4 0 ba9 1453
145b bac 1452 145d
:3 0 b6 :2 0 11a
:4 0 baf 145f 1461
:3 0 b6 :2 0 b9
:4 0 bb2 1463 1465
:3 0 b6 :2 0 25
:3 0 bb5 1467 1469
:3 0 b6 :2 0 b9
:4 0 bb8 146b 146d
:3 0 bbb 1443 146f
:2 0 1471 bbe 1472
1440 1471 0 1473
bc0 0 149d ae
:3 0 af :3 0 1474
1475 0 ae :3 0
be :3 0 1477 1478
0 47 :2 0 2
:4 0 189 :2 0 c0
:2 0 47 :2 0 bc2
147d 147f :3 0 bc5
1479 1481 1476 1483
1482 :2 0 b1 :3 0
c1 :3 0 1485 1486
0 b3 :4 0 18a
:4 0 b6 :2 0 b7
:3 0 bc9 148a 148c
:3 0 bcc 1487 148e
:2 0 1490 bcf 1491
1484 1490 0 1492
bd1 0 149d cf
:3 0 11d :3 0 1493
1494 0 c3 :3 0
d7 :3 0 1496 1497
0 25 :3 0 d1
:3 0 bd3 1495 149b
:2 0 149d bd7 149e
142f 149d 0 149f
bdb 0 14a0 bdd
14a1 13c5 14a0 0
14a2 be0 0 14a3
be2 14a4 1355 14a3
0 14a5 be5 0
14a6 be7 14a7 12bd
14a6 0 14a8 bea
0 367b a2 :3 0
d :3 0 4e :2 0
bec 14a9 14ac d3
:2 0 4e :2 0 bf1
14ae 14b0 :3 0 a2
:3 0 5b :3 0 4e
:2 0 bf4 14b2 14b5
c4 :2 0 18b :2 0
bf9 14b7 14b9 :3 0
14b1 14bb 14ba :2 0
57 :3 0 4e :2 0
14bd 14be 0 14c0
bfc 14c1 14bc 14c0
0 14c2 bfe 0
367b a2 :3 0 4d
:3 0 4e :2 0 c00
14c3 14c6 c3 :3 0
d3 :2 0 c5 :3 0
14c8 14ca 0 c05
14c9 14cc :3 0 5
:3 0 c6 :2 0 c08
14cf 14d0 :3 0 14d1
:2 0 41 :3 0 18c
:4 0 14d3 14d4 0
14d9 42 :3 0 18c
:4 0 14d6 14d7 0
14d9 c0a 14e1 41
:3 0 5 :3 0 14da
14db 0 14e0 42
:3 0 5 :3 0 14dd
14de 0 14e0 c0d
14e2 14d2 14d9 0
14e3 0 14e0 0
14e3 c10 0 14e7
59 :3 0 4e :2 0
14e4 14e5 0 14e7
c13 167d 8a :3 0
d3 :2 0 4e :2 0
c18 14e9 14eb :3 0
42 :3 0 18d :4 0
14ed 14ee 0 1605
83 :3 0 18e :3 0
41 :3 0 42 :3 0
a2 :3 0 5a :3 0
4e :2 0 c1b 14f4
14f7 a2 :3 0 5b
:3 0 4e :2 0 c1e
14f9 14fc a2 :3 0
5c :3 0 4e :2 0
c21 14fe 1501 a2
:3 0 4d :3 0 4e
:2 0 c24 1503 1506
a2 :3 0 5d :3 0
4e :2 0 c27 1508
150b a2 :3 0 58
:3 0 4e :2 0 c2a
150d 1510 a2 :3 0
5f :3 0 4e :2 0
c2d 1512 1515 a2
:3 0 60 :3 0 4e
:2 0 c30 1517 151a
57 :3 0 59 :3 0
61 :3 0 c33 14f1
151f 14f0 1520 0
1605 a2 :3 0 83
:3 0 4e :2 0 c41
1522 1525 c3 :3 0
d3 :2 0 d7 :3 0
1527 1529 0 c46
1528 152b :3 0 ae
:3 0 af :3 0 152d
152e 0 ae :3 0
be :3 0 1530 1531
0 c7 :2 0 2
:4 0 18f :2 0 c0
:2 0 47 :2 0 c49
1536 1538 :3 0 c4c
1532 153a 152f 153c
153b :2 0 b1 :3 0
c1 :3 0 153e 153f
0 b3 :4 0 190
:4 0 b6 :2 0 b7
:3 0 c50 1543 1545
:3 0 b6 :2 0 ca
:4 0 c53 1547 1549
:3 0 b6 :2 0 cb
:4 0 c56 154b 154d
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 1552
1553 0 c59 1551
1555 bc :4 0 c5b
1550 1558 c5e 154f
155a :3 0 c61 1540
155c :2 0 155e c64
155f 153d 155e 0
1560 c66 0 158a
ae :3 0 af :3 0
1561 1562 0 ae
:3 0 be :3 0 1564
1565 0 47 :2 0
2 :4 0 191 :2 0
c0 :2 0 47 :2 0
c68 156a 156c :3 0
c6b 1566 156e 1563
1570 156f :2 0 b1
:3 0 c1 :3 0 1572
1573 0 b3 :4 0
192 :4 0 b6 :2 0
b7 :3 0 c6f 1577
1579 :3 0 c72 1574
157b :2 0 157d c75
157e 1571 157d 0
157f c77 0 158a
cf :3 0 d0 :3 0
1580 1581 0 c3
:3 0 d7 :3 0 1583
1584 0 d1 :3 0
c79 1582 1587 :2 0
158a d9 :3 0 c7c
1603 a2 :3 0 83
:3 0 4e :2 0 c80
158b 158e c4 :2 0
4e :2 0 c85 1590
1592 :3 0 ae :3 0
af :3 0 1594 1595
0 ae :3 0 be
:3 0 1597 1598 0
24 :2 0 2 :4 0
193 :2 0 c0 :2 0
47 :2 0 c88 159d
159f :3 0 c8b 1599
15a1 1596 15a3 15a2
:2 0 b1 :3 0 c1
:3 0 15a5 15a6 0
b3 :4 0 194 :4 0
b6 :2 0 b7 :3 0
c8f 15aa 15ac :3 0
b6 :2 0 ca :4 0
c92 15ae 15b0 :3 0
b6 :2 0 cb :4 0
c95 15b2 15b4 :3 0
b6 :2 0 a2 :3 0
bb :3 0 83 :3 0
c98 15b8 15ba bc
:4 0 c9a 15b7 15bd
c9d 15b6 15bf :3 0
b6 :2 0 11a :4 0
ca0 15c1 15c3 :3 0
b6 :2 0 b9 :4 0
ca3 15c5 15c7 :3 0
b6 :2 0 25 :3 0
ca6 15c9 15cb :3 0
b6 :2 0 b9 :4 0
ca9 15cd 15cf :3 0
cac 15a7 15d1 :2 0
15d3 caf 15d4 15a4
15d3 0 15d5 cb1
0 1601 ae :3 0
af :3 0 15d6 15d7
0 ae :3 0 be
:3 0 15d9 15da 0
47 :2 0 2 :4 0
195 :2 0 c0 :2 0
47 :2 0 cb3 15df
15e1 :3 0 cb6 15db
15e3 15d8 15e5 15e4
:2 0 b1 :3 0 c1
:3 0 15e7 15e8 0
b3 :4 0 196 :4 0
b6 :2 0 b7 :3 0
cba 15ec 15ee :3 0
cbd 15e9 15f0 :2 0
15f2 cc0 15f3 15e6
15f2 0 15f4 cc2
0 1601 cf :3 0
11d :3 0 15f5 15f6
0 a2 :3 0 83
:3 0 4e :2 0 cc4
15f8 15fb 25 :3 0
d1 :3 0 cc7 15f7
15ff :2 0 1601 ccb
1602 1593 1601 0
1604 152c 158a 0
1604 ccf 0 1605
cd2 160a 42 :3 0
6 :3 0 1606 1607
0 1609 cd6 160b
14ec 1605 0 160c
0 1609 0 160c
cd8 0 167c a2
:3 0 57 :3 0 4e
:2 0 cdb 160d 1610
109 :2 0 4e :2 0
ce0 1612 1614 :3 0
1615 :2 0 a2 :3 0
5b :3 0 4e :2 0
ce3 1617 161a c4
:2 0 18b :2 0 ce8
161c 161e :3 0 161f
:2 0 1616 1621 1620
:2 0 a2 :3 0 5b
:3 0 4e :2 0 ceb
1623 1626 d3 :2 0
47 :2 0 cf0 1628
162a :3 0 162b :2 0
a2 :3 0 5b :3 0
4e :2 0 cf3 162d
1630 d3 :2 0 106
:2 0 cf8 1632 1634
:3 0 1635 :2 0 162c
1637 1636 :2 0 5a
:3 0 106 :2 0 1639
163a 0 163d d9
:3 0 cfb 1677 a2
:3 0 5b :3 0 4e
:2 0 cfd 163e 1641
d3 :2 0 4e :2 0
d02 1643 1645 :3 0
5a :3 0 47 :2 0
1647 1648 0 164b
d9 :3 0 d05 164c
1646 164b 0 1678
a2 :3 0 5b :3 0
4e :2 0 d07 164d
1650 d3 :2 0 108
:2 0 d0c 1652 1654
:3 0 1655 :2 0 a2
:3 0 5b :3 0 4e
:2 0 d0f 1657 165a
d3 :2 0 197 :2 0
d14 165c 165e :3 0
165f :2 0 1656 1661
1660 :2 0 5a :3 0
47 :2 0 1663 1664
0 1667 d9 :3 0
d17 1668 1662 1667
0 1678 a2 :3 0
5b :3 0 4e :2 0
d19 1669 166c d3
:2 0 de :2 0 d1e
166e 1670 :3 0 5a
:3 0 108 :2 0 1672
1673 0 1675 d21
1676 1671 1675 0
1678 1638 163d 0
1678 d23 0 1679
d28 167a 1622 1679
0 167b d2a 0
167c d2c 167e 14cd
14e7 0 167f 0
167c 0 167f d2f
0 367b a2 :3 0
5c :3 0 4e :2 0
d32 1680 1683 c3
:3 0 d3 :2 0 d4
:3 0 1685 1687 0
d37 1686 1689 :3 0
8e :3 0 4e :2 0
168b 168c 0 1b66
2e :3 0 16 :3 0
168e 168f 0 1b66
30 :3 0 17 :3 0
1691 1692 0 1b66
49 :3 0 f2 :3 0
2e :3 0 47 :2 0
24 :2 0 d3a 1695
1699 1694 169a 0
1b66 4c :4 0 169c
169d 0 1b66 a2
:3 0 6b :3 0 4e
:2 0 d3e 169f 16a2
d3 :2 0 4e :2 0
d43 16a4 16a6 :3 0
39 :3 0 198 :4 0
16a9 16aa :3 0 16a8
16ab 0 16b0 8e
:3 0 47 :2 0 16ad
16ae 0 16b0 d46
1796 10f :3 0 4c
:3 0 199 :3 0 19a
:3 0 39 :4 0 19b
1 :8 0 16bc 21
:3 0 e9 :3 0 16b7
16b8 0 ea :3 0
16b9 16ba 0 16bc
d49 170f eb :3 0
21 :3 0 e9 :3 0
16be 16bf 0 ea
:3 0 16c0 16c1 0
16c3 d4c 16c5 d4e
16c4 16c3 :2 0 170d
ec :3 0 21 :3 0
e9 :3 0 16c8 16c9
0 ea :3 0 16ca
16cb 0 1705 ae
:3 0 af :3 0 16cd
16ce 0 ae :3 0
be :3 0 16d0 16d1
0 ed :2 0 2
:4 0 19c :2 0 c0
:2 0 47 :2 0 d50
16d6 16d8 :3 0 d53
16d2 16da 16cf 16dc
16db :2 0 b1 :3 0
c1 :3 0 16de 16df
0 b3 :4 0 19d
:4 0 b6 :2 0 b7
:3 0 d57 16e3 16e5
:3 0 b6 :2 0 ca
:4 0 d5a 16e7 16e9
:3 0 b6 :2 0 f0
:4 0 d5d 16eb 16ed
:3 0 b6 :2 0 ea
:3 0 d60 16ef 16f1
:3 0 b6 :2 0 f1
:4 0 d63 16f3 16f5
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 d66
16f8 16fc d6a 16f7
16fe :3 0 d6d 16e0
1700 :2 0 1702 d70
1703 16dd 1702 0
1704 d72 0 1705
d74 1708 :3 0 1708
0 1708 1707 1705
1706 :6 0 170a 1c
:3 0 d77 170c d79
170b 170a :2 0 170d
d7b :2 0 170f 0
170f 170e 16bc 170d
:6 0 1795 1 :3 0
21 :3 0 e9 :3 0
1711 1712 0 21
:3 0 d3 :2 0 f5
:3 0 1714 1716 0
d80 1715 1718 :3 0
1719 :2 0 a2 :3 0
50 :3 0 4e :2 0
d83 171b 171e 109
:2 0 4e :2 0 d88
1720 1722 :3 0 19e
:3 0 28 :3 0 19f
:3 0 111 :3 0 26
:3 0 9b :3 0 39
:3 0 1a0 :3 0 1a1
:3 0 c3 :3 0 1a2
:4 0 1a3 1 :8 0
1735 21 :3 0 e9
:3 0 1730 1731 0
ea :3 0 1732 1733
0 1735 d8b 1788
eb :3 0 21 :3 0
e9 :3 0 1737 1738
0 ea :3 0 1739
173a 0 173c d8e
173e d90 173d 173c
:2 0 1786 ec :3 0
21 :3 0 e9 :3 0
1741 1742 0 ea
:3 0 1743 1744 0
177e ae :3 0 af
:3 0 1746 1747 0
ae :3 0 be :3 0
1749 174a 0 ed
:2 0 2 :4 0 1a4
:2 0 c0 :2 0 47
:2 0 d92 174f 1751
:3 0 d95 174b 1753
1748 1755 1754 :2 0
b1 :3 0 c1 :3 0
1757 1758 0 b3
:4 0 1a5 :4 0 b6
:2 0 b7 :3 0 d99
175c 175e :3 0 b6
:2 0 ca :4 0 d9c
1760 1762 :3 0 b6
:2 0 f0 :4 0 d9f
1764 1766 :3 0 b6
:2 0 ea :3 0 da2
1768 176a :3 0 b6
:2 0 f1 :4 0 da5
176c 176e :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 da8 1771 1775
dac 1770 1777 :3 0
daf 1759 1779 :2 0
177b db2 177c 1756
177b 0 177d db4
0 177e db6 1781
:3 0 1781 0 1781
1780 177e 177f :6 0
1783 1e :3 0 db9
1785 dbb 1784 1783
:2 0 1786 dbd :2 0
1788 0 1788 1787
1735 1786 :6 0 178a
1 :3 0 dc0 178b
1723 178a 0 178c
dc2 0 178d dc4
1792 8e :3 0 47
:2 0 178e 178f 0
1791 dc6 1793 171a
178d 0 1794 0
1791 0 1794 dc8
0 1795 dcb 1797
16a7 16b0 0 1798
0 1795 0 1798
dce 0 1b66 8e
:3 0 c4 :2 0 4e
:2 0 dd3 179a 179c
:3 0 a2 :3 0 1a6
:3 0 1a7 :3 0 63
:3 0 199 :3 0 99
:3 0 25 :3 0 a1
:3 0 49 :4 0 1a8
1 :8 0 17ad 21
:3 0 e9 :3 0 17a8
17a9 0 ea :3 0
17aa 17ab 0 17ad
dd6 1800 eb :3 0
21 :3 0 e9 :3 0
17af 17b0 0 ea
:3 0 17b1 17b2 0
17b4 dd9 17b6 ddb
17b5 17b4 :2 0 17fe
ec :3 0 21 :3 0
e9 :3 0 17b9 17ba
0 ea :3 0 17bb
17bc 0 17f6 ae
:3 0 af :3 0 17be
17bf 0 ae :3 0
be :3 0 17c1 17c2
0 ed :2 0 2
:4 0 1a9 :2 0 c0
:2 0 47 :2 0 ddd
17c7 17c9 :3 0 de0
17c3 17cb 17c0 17cd
17cc :2 0 b1 :3 0
c1 :3 0 17cf 17d0
0 b3 :4 0 1aa
:4 0 b6 :2 0 b7
:3 0 de4 17d4 17d6
:3 0 b6 :2 0 ca
:4 0 de7 17d8 17da
:3 0 b6 :2 0 f0
:4 0 dea 17dc 17de
:3 0 b6 :2 0 ea
:3 0 ded 17e0 17e2
:3 0 b6 :2 0 f1
:4 0 df0 17e4 17e6
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 df3
17e9 17ed df7 17e8
17ef :3 0 dfa 17d1
17f1 :2 0 17f3 dfd
17f4 17ce 17f3 0
17f5 dff 0 17f6
e01 17f9 :3 0 17f9
0 17f9 17f8 17f6
17f7 :6 0 17fb 20
:3 0 e04 17fd e06
17fc 17fb :2 0 17fe
e08 :2 0 1800 0
1800 17ff 17ad 17fe
:6 0 1989 1 :3 0
e5 :3 0 1ab :3 0
e5 :3 0 1ab :3 0
e5 :3 0 1ab :3 0
e5 :3 0 1ab :3 0
e5 :3 0 1ab :3 0
a0 :3 0 1ac :3 0
1ad :3 0 a0 :3 0
1ae :3 0 1ad :3 0
a0 :3 0 bb :3 0
63 :3 0 4b :3 0
1af :3 0 1ae :3 0
1af :3 0 1ac :3 0
1ae :3 0 111 :3 0
49 :3 0 1ac :3 0
111 :3 0 1ae :3 0
1b0 :4 0 1b1 1
:8 0 1827 21 :3 0
e9 :3 0 1822 1823
0 ea :3 0 1824
1825 0 1827 e0b
187a eb :3 0 21
:3 0 e9 :3 0 1829
182a 0 ea :3 0
182b 182c 0 182e
e0e 1830 e10 182f
182e :2 0 1878 ec
:3 0 21 :3 0 e9
:3 0 1833 1834 0
ea :3 0 1835 1836
0 1870 ae :3 0
af :3 0 1838 1839
0 ae :3 0 be
:3 0 183b 183c 0
ed :2 0 2 :4 0
1b2 :2 0 c0 :2 0
47 :2 0 e12 1841
1843 :3 0 e15 183d
1845 183a 1847 1846
:2 0 b1 :3 0 c1
:3 0 1849 184a 0
b3 :4 0 1b3 :4 0
b6 :2 0 b7 :3 0
e19 184e 1850 :3 0
b6 :2 0 ca :4 0
e1c 1852 1854 :3 0
b6 :2 0 f0 :4 0
e1f 1856 1858 :3 0
b6 :2 0 ea :3 0
e22 185a 185c :3 0
b6 :2 0 f1 :4 0
e25 185e 1860 :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 e28 1863
1867 e2c 1862 1869
:3 0 e2f 184b 186b
:2 0 186d e32 186e
1848 186d 0 186f
e34 0 1870 e36
1873 :3 0 1873 0
1873 1872 1870 1871
:6 0 1875 22 :3 0
e39 1877 e3b 1876
1875 :2 0 1878 e3d
:2 0 187a 0 187a
1879 1827 1878 :6 0
1989 1 :3 0 21
:3 0 e9 :3 0 187c
187d 0 21 :3 0
d3 :2 0 16b :3 0
187f 1881 0 e42
1880 1883 :3 0 1884
:2 0 ae :3 0 af
:3 0 1886 1887 0
ae :3 0 be :3 0
1889 188a 0 24
:2 0 2 :4 0 1b4
:2 0 c0 :2 0 47
:2 0 e45 188f 1891
:3 0 e48 188b 1893
1888 1895 1894 :2 0
b1 :3 0 c1 :3 0
1897 1898 0 b3
:4 0 1b5 :4 0 b6
:2 0 b7 :3 0 e4c
189c 189e :3 0 b6
:2 0 ca :4 0 e4f
18a0 18a2 :3 0 b6
:2 0 cb :4 0 e52
18a4 18a6 :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 146
:3 0 18ab 18ac 0
e55 18aa 18ae bc
:4 0 e57 18a9 18b1
e5a 18a8 18b3 :3 0
b6 :2 0 11a :4 0
e5d 18b5 18b7 :3 0
b6 :2 0 b9 :4 0
e60 18b9 18bb :3 0
b6 :2 0 49 :3 0
e63 18bd 18bf :3 0
b6 :2 0 b9 :4 0
e66 18c1 18c3 :3 0
e69 1899 18c5 :2 0
18c7 e6c 18c8 1896
18c7 0 18c9 e6e
0 18f3 ae :3 0
af :3 0 18ca 18cb
0 ae :3 0 be
:3 0 18cd 18ce 0
47 :2 0 2 :4 0
1b6 :2 0 c0 :2 0
47 :2 0 e70 18d3
18d5 :3 0 e73 18cf
18d7 18cc 18d9 18d8
:2 0 b1 :3 0 c1
:3 0 18db 18dc 0
b3 :4 0 1b7 :4 0
b6 :2 0 b7 :3 0
e77 18e0 18e2 :3 0
e7a 18dd 18e4 :2 0
18e6 e7d 18e7 18da
18e6 0 18e8 e7f
0 18f3 cf :3 0
11d :3 0 18e9 18ea
0 c3 :3 0 146
:3 0 18ec 18ed 0
49 :3 0 d1 :3 0
e81 18eb 18f1 :2 0
18f3 e85 18f4 1885
18f3 0 18f5 e89
0 1989 a2 :3 0
50 :3 0 4e :2 0
e8b 18f6 18f9 109
:2 0 4e :2 0 e90
18fb 18fd :3 0 82
:3 0 1b8 :4 0 18ff
1900 0 1902 e93
1907 82 :3 0 1b9
:4 0 1903 1904 0
1906 e95 1908 18fe
1902 0 1909 0
1906 0 1909 e97
0 1989 199 :3 0
19a :3 0 99 :3 0
a1 :3 0 1a7 :3 0
1ba :3 0 10f :3 0
1bb :3 0 1bc :3 0
1bd :3 0 39 :3 0
25 :3 0 49 :3 0
63 :3 0 4b :3 0
82 :3 0 14 :3 0
13 :3 0 12 :4 0
1be 1 :8 0 1933
1bf :4 0 191e :3 0
d1 :3 0 d3 :2 0
e9c 1921 1922 :3 0
21 :3 0 e9 :3 0
1924 1925 0 4e
:2 0 1926 1927 0
1929 e9f 1930 21
:3 0 e9 :3 0 192a
192b 0 18b :2 0
192c 192d 0 192f
ea1 1931 1923 1929
0 1932 0 192f
0 1932 ea3 0
1933 ea6 1986 eb
:3 0 21 :3 0 e9
:3 0 1935 1936 0
ea :3 0 1937 1938
0 193a ea9 193c
eab 193b 193a :2 0
1984 ec :3 0 21
:3 0 e9 :3 0 193f
1940 0 ea :3 0
1941 1942 0 197c
ae :3 0 af :3 0
1944 1945 0 ae
:3 0 be :3 0 1947
1948 0 ed :2 0
2 :4 0 1c0 :2 0
c0 :2 0 47 :2 0
ead 194d 194f :3 0
eb0 1949 1951 1946
1953 1952 :2 0 b1
:3 0 c1 :3 0 1955
1956 0 b3 :4 0
1c1 :4 0 b6 :2 0
b7 :3 0 eb4 195a
195c :3 0 b6 :2 0
ca :4 0 eb7 195e
1960 :3 0 b6 :2 0
f0 :4 0 eba 1962
1964 :3 0 b6 :2 0
ea :3 0 ebd 1966
1968 :3 0 b6 :2 0
f1 :4 0 ec0 196a
196c :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
ec3 196f 1973 ec7
196e 1975 :3 0 eca
1957 1977 :2 0 1979
ecd 197a 1954 1979
0 197b ecf 0
197c ed1 197f :3 0
197f 0 197f 197e
197c 197d :6 0 1981
24 :3 0 ed4 1983
ed6 1982 1981 :2 0
1984 ed8 :2 0 1986
0 1986 1985 1933
1984 :6 0 1989 1
:3 0 d9 :3 0 edb
1a0b f2 :3 0 4c
:3 0 47 :2 0 47
:2 0 ee1 198a 198e
d3 :2 0 1b9 :4 0
ee7 1990 1992 :3 0
199 :3 0 10f :3 0
1bb :3 0 14 :3 0
1bc :3 0 13 :3 0
1bd :3 0 12 :3 0
19a :3 0 39 :4 0
1c2 1 :8 0 19b4
1bf :4 0 199f :3 0
d1 :3 0 d3 :2 0
eec 19a2 19a3 :3 0
21 :3 0 e9 :3 0
19a5 19a6 0 4e
:2 0 19a7 19a8 0
19aa eef 19b1 21
:3 0 e9 :3 0 19ab
19ac 0 18b :2 0
19ad 19ae 0 19b0
ef1 19b2 19a4 19aa
0 19b3 0 19b0
0 19b3 ef3 0
19b4 ef6 1a07 eb
:3 0 21 :3 0 e9
:3 0 19b6 19b7 0
ea :3 0 19b8 19b9
0 19bb ef9 19bd
efb 19bc 19bb :2 0
1a05 ec :3 0 21
:3 0 e9 :3 0 19c0
19c1 0 ea :3 0
19c2 19c3 0 19fd
ae :3 0 af :3 0
19c5 19c6 0 ae
:3 0 be :3 0 19c8
19c9 0 ed :2 0
2 :4 0 1c3 :2 0
c0 :2 0 47 :2 0
efd 19ce 19d0 :3 0
f00 19ca 19d2 19c7
19d4 19d3 :2 0 b1
:3 0 c1 :3 0 19d6
19d7 0 b3 :4 0
1c4 :4 0 b6 :2 0
b7 :3 0 f04 19db
19dd :3 0 b6 :2 0
ca :4 0 f07 19df
19e1 :3 0 b6 :2 0
f0 :4 0 f0a 19e3
19e5 :3 0 b6 :2 0
ea :3 0 f0d 19e7
19e9 :3 0 b6 :2 0
f1 :4 0 f10 19eb
19ed :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
f13 19f0 19f4 f17
19ef 19f6 :3 0 f1a
19d8 19f8 :2 0 19fa
f1d 19fb 19d5 19fa
0 19fc f1f 0
19fd f21 1a00 :3 0
1a00 0 1a00 19ff
19fd 19fe :6 0 1a02
26 :3 0 f24 1a04
f26 1a03 1a02 :2 0
1a05 f28 :2 0 1a07
0 1a07 1a06 19b4
1a05 :6 0 1a09 1
:3 0 f2b 1a0a 1993
1a09 0 1a0c 179d
1989 0 1a0c f2d
0 1b66 1c5 :3 0
19e :3 0 19a :3 0
199 :3 0 99 :3 0
25 :3 0 10f :3 0
19a :3 0 39 :4 0
1c6 1 :8 0 1a2c
1bf :4 0 1a17 :3 0
d1 :3 0 d3 :2 0
f32 1a1a 1a1b :3 0
21 :3 0 e9 :3 0
1a1d 1a1e 0 4e
:2 0 1a1f 1a20 0
1a22 f35 1a29 21
:3 0 e9 :3 0 1a23
1a24 0 18b :2 0
1a25 1a26 0 1a28
f37 1a2a 1a1c 1a22
0 1a2b 0 1a28
0 1a2b f39 0
1a2c f3c 1a7f eb
:3 0 21 :3 0 e9
:3 0 1a2e 1a2f 0
ea :3 0 1a30 1a31
0 1a33 f3f 1a35
f41 1a34 1a33 :2 0
1a7d ec :3 0 21
:3 0 e9 :3 0 1a38
1a39 0 ea :3 0
1a3a 1a3b 0 1a75
ae :3 0 af :3 0
1a3d 1a3e 0 ae
:3 0 be :3 0 1a40
1a41 0 ed :2 0
2 :4 0 1c7 :2 0
c0 :2 0 47 :2 0
f43 1a46 1a48 :3 0
f46 1a42 1a4a 1a3f
1a4c 1a4b :2 0 b1
:3 0 c1 :3 0 1a4e
1a4f 0 b3 :4 0
1c8 :4 0 b6 :2 0
b7 :3 0 f4a 1a53
1a55 :3 0 b6 :2 0
ca :4 0 f4d 1a57
1a59 :3 0 b6 :2 0
f0 :4 0 f50 1a5b
1a5d :3 0 b6 :2 0
ea :3 0 f53 1a5f
1a61 :3 0 b6 :2 0
f1 :4 0 f56 1a63
1a65 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
f59 1a68 1a6c f5d
1a67 1a6e :3 0 f60
1a50 1a70 :2 0 1a72
f63 1a73 1a4d 1a72
0 1a74 f65 0
1a75 f67 1a78 :3 0
1a78 0 1a78 1a77
1a75 1a76 :6 0 1a7a
28 :3 0 f6a 1a7c
f6c 1a7b 1a7a :2 0
1a7d f6e :2 0 1a7f
0 1a7f 1a7e 1a2c
1a7d :6 0 1b66 1
:3 0 1c9 :3 0 19e
:3 0 19a :3 0 199
:3 0 99 :3 0 25
:3 0 10f :3 0 19a
:3 0 39 :4 0 1ca
1 :8 0 1aa0 1bf
:4 0 1a8b :3 0 d1
:3 0 d3 :2 0 f73
1a8e 1a8f :3 0 21
:3 0 e9 :3 0 1a91
1a92 0 4e :2 0
1a93 1a94 0 1a96
f76 1a9d 21 :3 0
e9 :3 0 1a97 1a98
0 18b :2 0 1a99
1a9a 0 1a9c f78
1a9e 1a90 1a96 0
1a9f 0 1a9c 0
1a9f f7a 0 1aa0
f7d 1af3 eb :3 0
21 :3 0 e9 :3 0
1aa2 1aa3 0 ea
:3 0 1aa4 1aa5 0
1aa7 f80 1aa9 f82
1aa8 1aa7 :2 0 1af1
ec :3 0 21 :3 0
e9 :3 0 1aac 1aad
0 ea :3 0 1aae
1aaf 0 1ae9 ae
:3 0 af :3 0 1ab1
1ab2 0 ae :3 0
be :3 0 1ab4 1ab5
0 ed :2 0 2
:4 0 1cb :2 0 c0
:2 0 47 :2 0 f84
1aba 1abc :3 0 f87
1ab6 1abe 1ab3 1ac0
1abf :2 0 b1 :3 0
c1 :3 0 1ac2 1ac3
0 b3 :4 0 1cc
:4 0 b6 :2 0 b7
:3 0 f8b 1ac7 1ac9
:3 0 b6 :2 0 ca
:4 0 f8e 1acb 1acd
:3 0 b6 :2 0 f0
:4 0 f91 1acf 1ad1
:3 0 b6 :2 0 ea
:3 0 f94 1ad3 1ad5
:3 0 b6 :2 0 f1
:4 0 f97 1ad7 1ad9
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 f9a
1adc 1ae0 f9e 1adb
1ae2 :3 0 fa1 1ac4
1ae4 :2 0 1ae6 fa4
1ae7 1ac1 1ae6 0
1ae8 fa6 0 1ae9
fa8 1aec :3 0 1aec
0 1aec 1aeb 1ae9
1aea :6 0 1aee 2a
:3 0 fab 1af0 fad
1aef 1aee :2 0 1af1
faf :2 0 1af3 0
1af3 1af2 1aa0 1af1
:6 0 1b66 1 :3 0
199 :3 0 99 :3 0
25 :3 0 10f :3 0
19a :3 0 39 :4 0
1cd 1 :8 0 1b11
1bf :4 0 1afc :3 0
d1 :3 0 d3 :2 0
fb4 1aff 1b00 :3 0
21 :3 0 e9 :3 0
1b02 1b03 0 4e
:2 0 1b04 1b05 0
1b07 fb7 1b0e 21
:3 0 e9 :3 0 1b08
1b09 0 18b :2 0
1b0a 1b0b 0 1b0d
fb9 1b0f 1b01 1b07
0 1b10 0 1b0d
0 1b10 fbb 0
1b11 fbe 1b64 eb
:3 0 21 :3 0 e9
:3 0 1b13 1b14 0
ea :3 0 1b15 1b16
0 1b18 fc1 1b1a
fc3 1b19 1b18 :2 0
1b62 ec :3 0 21
:3 0 e9 :3 0 1b1d
1b1e 0 ea :3 0
1b1f 1b20 0 1b5a
ae :3 0 af :3 0
1b22 1b23 0 ae
:3 0 be :3 0 1b25
1b26 0 ed :2 0
2 :4 0 1ce :2 0
c0 :2 0 47 :2 0
fc5 1b2b 1b2d :3 0
fc8 1b27 1b2f 1b24
1b31 1b30 :2 0 b1
:3 0 c1 :3 0 1b33
1b34 0 b3 :4 0
1cf :4 0 b6 :2 0
b7 :3 0 fcc 1b38
1b3a :3 0 b6 :2 0
ca :4 0 fcf 1b3c
1b3e :3 0 b6 :2 0
f0 :4 0 fd2 1b40
1b42 :3 0 b6 :2 0
ea :3 0 fd5 1b44
1b46 :3 0 b6 :2 0
f1 :4 0 fd8 1b48
1b4a :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
fdb 1b4d 1b51 fdf
1b4c 1b53 :3 0 fe2
1b35 1b55 :2 0 1b57
fe5 1b58 1b32 1b57
0 1b59 fe7 0
1b5a fe9 1b5d :3 0
1b5d 0 1b5d 1b5c
1b5a 1b5b :6 0 1b5f
2c :3 0 fec 1b61
fee 1b60 1b5f :2 0
1b62 ff0 :2 0 1b64
0 1b64 1b63 1b11
1b62 :6 0 1b66 1
:3 0 ff3 1b67 168a
1b66 0 1b68 ffe
0 367b 85 :3 0
1d0 :4 0 1b6a 1b6b
:3 0 1b69 1b6c 0
367b a2 :3 0 50
:3 0 4e :2 0 1000
1b6e 1b71 d3 :2 0
4e :2 0 1005 1b73
1b75 :3 0 a2 :3 0
5c :3 0 4e :2 0
1008 1b77 1b7a c3
:3 0 c4 :2 0 d4
:3 0 1b7c 1b7e 0
100d 1b7d 1b80 :3 0
1b76 1b82 1b81 :2 0
a2 :3 0 5c :3 0
4e :2 0 1010 1b84
1b87 c3 :3 0 c4
:2 0 d2 :3 0 1b89
1b8b 0 1015 1b8a
1b8d :3 0 1b83 1b8f
1b8e :2 0 1e :3 0
e4 :2 0 1018 1b92
1b93 :3 0 1b94 :2 0
3a :3 0 1e :3 0
1b96 1b97 0 1b99
101a 1b9a 1b95 1b99
0 1b9b 101c 0
1b9c 101e 1b9d 1b90
1b9c 0 1b9e 1020
0 367b a2 :3 0
56 :3 0 4e :2 0
1022 1b9f 1ba2 d3
:2 0 4e :2 0 1027
1ba4 1ba6 :3 0 56
:3 0 c3 :3 0 1d1
:3 0 1ba9 1baa 0
1ba8 1bab 0 1bad
102a 1bae 1ba7 1bad
0 1baf 102c 0
367b 16 :3 0 c6
:2 0 102e 1bb1 1bb2
:3 0 1bb3 :2 0 17
:3 0 c6 :2 0 1030
1bb6 1bb7 :3 0 1bb8
:2 0 1bb4 1bba 1bb9
:2 0 18 :3 0 c6
:2 0 1032 1bbd 1bbe
:3 0 1bbf :2 0 1bbb
1bc1 1bc0 :2 0 19
:3 0 c6 :2 0 1034
1bc4 1bc5 :3 0 1bc6
:2 0 1bc7 :2 0 1bc2
1bc9 1bc8 :2 0 8c
:3 0 47 :2 0 1bcb
1bcc 0 1bce 1036
1bcf 1bca 1bce 0
1bd0 1038 0 367b
75 :3 0 18d :4 0
1bd1 1bd2 0 367b
77 :3 0 18d :4 0
1bd4 1bd5 0 367b
a2 :3 0 50 :3 0
4e :2 0 103a 1bd7
1bda 109 :2 0 4e
:2 0 103f 1bdc 1bde
:3 0 a2 :3 0 5c
:3 0 4e :2 0 1042
1be0 1be3 c3 :3 0
d3 :2 0 d4 :3 0
1be5 1be7 0 1047
1be6 1be9 :3 0 75
:3 0 1d2 :4 0 b6
:2 0 39 :3 0 104a
1bed 1bef :3 0 b6
:2 0 1d3 :4 0 104d
1bf1 1bf3 :3 0 b6
:2 0 1d4 :4 0 1050
1bf5 1bf7 :3 0 b6
:2 0 1d5 :4 0 1053
1bf9 1bfb :3 0 b6
:2 0 1d6 :4 0 1056
1bfd 1bff :3 0 b6
:2 0 49 :3 0 1059
1c01 1c03 :3 0 b6
:2 0 b9 :4 0 105c
1c05 1c07 :3 0 1beb
1c08 0 1c0b d9
:3 0 105f 1c52 a2
:3 0 5c :3 0 4e
:2 0 1061 1c0c 1c0f
d3 :2 0 2d :2 0
1066 1c11 1c13 :3 0
75 :3 0 1d7 :4 0
b6 :2 0 1d8 :4 0
1069 1c17 1c19 :3 0
b6 :2 0 1d9 :4 0
106c 1c1b 1c1d :3 0
b6 :2 0 25 :3 0
106f 1c1f 1c21 :3 0
b6 :2 0 1da :4 0
1072 1c23 1c25 :3 0
b6 :2 0 1db :4 0
1075 1c27 1c29 :3 0
b6 :2 0 39 :3 0
1078 1c2b 1c2d :3 0
b6 :2 0 1da :4 0
107b 1c2f 1c31 :3 0
b6 :2 0 1dc :4 0
107e 1c33 1c35 :3 0
1c15 1c36 0 1c38
1081 1c39 1c14 1c38
0 1c54 75 :3 0
1dd :4 0 b6 :2 0
1de :4 0 1083 1c3c
1c3e :3 0 b6 :2 0
1df :4 0 1086 1c40
1c42 :3 0 b6 :2 0
1e0 :4 0 1089 1c44
1c46 :3 0 b6 :2 0
39 :3 0 108c 1c48
1c4a :3 0 b6 :2 0
1da :4 0 108f 1c4c
1c4e :3 0 1c3a 1c4f
0 1c51 1092 1c53
1bea 1c0b 0 1c54
0 1c51 0 1c54
1094 0 1c55 1098
25c3 a2 :3 0 5c
:3 0 4e :2 0 109a
1c56 1c59 c3 :3 0
c4 :2 0 d4 :3 0
1c5b 1c5d 0 109f
1c5c 1c5f :3 0 a2
:3 0 5c :3 0 4e
:2 0 10a2 1c61 1c64
c3 :3 0 c4 :2 0
d2 :3 0 1c66 1c68
0 10a7 1c67 1c6a
:3 0 1c60 1c6c 1c6b
:2 0 a2 :3 0 a
:3 0 4e :2 0 10aa
1c6e 1c71 c3 :3 0
c4 :2 0 c5 :3 0
1c73 1c75 0 10af
1c74 1c77 :3 0 1c6d
1c79 1c78 :2 0 1e1
:3 0 1e2 :3 0 1e3
:4 0 1c7d :4 0 1c7e
:2 0 1d9e 21 :3 0
e9 :3 0 1c80 1c81
0 4e :2 0 1c82
1c83 0 1d9e 14
:3 0 c6 :2 0 10b2
1c86 1c87 :3 0 1c88
:2 0 1e1 :3 0 1e2
:3 0 1e4 :4 0 1c8c
:4 0 1c8d :2 0 1d96
21 :3 0 e9 :3 0
1c8f 1c90 0 4e
:2 0 1c91 1c92 0
1d96 1e5 :3 0 111
:3 0 1e6 :3 0 183
:3 0 1e7 :3 0 1e8
:3 0 111 :3 0 1e8
:3 0 1e6 :3 0 183
:3 0 1e8 :3 0 1e9
:3 0 19f :3 0 1ea
:3 0 1e8 :3 0 111
:3 0 1ea :3 0 111
:3 0 1ea :3 0 1eb
:3 0 1ea :3 0 9b
:3 0 29 :4 0 1ec
1 :8 0 1cc1 1bf
:4 0 1cac :3 0 d1
:3 0 d3 :2 0 10b6
1caf 1cb0 :3 0 21
:3 0 e9 :3 0 1cb2
1cb3 0 4e :2 0
1cb4 1cb5 0 1cb7
10b9 1cbe 21 :3 0
e9 :3 0 1cb8 1cb9
0 18b :2 0 1cba
1cbb 0 1cbd 10bb
1cbf 1cb1 1cb7 0
1cc0 0 1cbd 0
1cc0 10bd 0 1cc1
10c0 1d14 eb :3 0
21 :3 0 e9 :3 0
1cc3 1cc4 0 ea
:3 0 1cc5 1cc6 0
1cc8 10c3 1cca 10c5
1cc9 1cc8 :2 0 1d12
ec :3 0 21 :3 0
e9 :3 0 1ccd 1cce
0 ea :3 0 1ccf
1cd0 0 1d0a ae
:3 0 af :3 0 1cd2
1cd3 0 ae :3 0
be :3 0 1cd5 1cd6
0 ed :2 0 2
:4 0 1ed :2 0 c0
:2 0 47 :2 0 10c7
1cdb 1cdd :3 0 10ca
1cd7 1cdf 1cd4 1ce1
1ce0 :2 0 b1 :3 0
c1 :3 0 1ce3 1ce4
0 b3 :4 0 1ee
:4 0 b6 :2 0 b7
:3 0 10ce 1ce8 1cea
:3 0 b6 :2 0 ca
:4 0 10d1 1cec 1cee
:3 0 b6 :2 0 f0
:4 0 10d4 1cf0 1cf2
:3 0 b6 :2 0 ea
:3 0 10d7 1cf4 1cf6
:3 0 b6 :2 0 f1
:4 0 10da 1cf8 1cfa
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 10dd
1cfd 1d01 10e1 1cfc
1d03 :3 0 10e4 1ce5
1d05 :2 0 1d07 10e7
1d08 1ce2 1d07 0
1d09 10e9 0 1d0a
10eb 1d0d :3 0 1d0d
0 1d0d 1d0c 1d0a
1d0b :6 0 1d0f 2e
:3 0 10ee 1d11 10f0
1d10 1d0f :2 0 1d12
10f2 :2 0 1d14 0
1d14 1d13 1cc1 1d12
:6 0 1d96 1 :3 0
1ef :3 0 1f0 :3 0
1e6 :3 0 1e5 :3 0
1f0 :3 0 13e :3 0
111 :3 0 1e5 :3 0
13e :3 0 13e :3 0
1e6 :3 0 1f0 :3 0
1e6 :3 0 f2 :3 0
1f0 :3 0 1e6 :3 0
1f1 :3 0 13e :3 0
1e6 :3 0 13e :3 0
1e6 :4 0 1f2 1
:8 0 1d41 1bf :4 0
1d2c :3 0 d1 :3 0
d3 :2 0 10f7 1d2f
1d30 :3 0 21 :3 0
e9 :3 0 1d32 1d33
0 4e :2 0 1d34
1d35 0 1d37 10fa
1d3e 21 :3 0 e9
:3 0 1d38 1d39 0
18b :2 0 1d3a 1d3b
0 1d3d 10fc 1d3f
1d31 1d37 0 1d40
0 1d3d 0 1d40
10fe 0 1d41 1101
1d94 eb :3 0 21
:3 0 e9 :3 0 1d43
1d44 0 ea :3 0
1d45 1d46 0 1d48
1104 1d4a 1106 1d49
1d48 :2 0 1d92 ec
:3 0 21 :3 0 e9
:3 0 1d4d 1d4e 0
ea :3 0 1d4f 1d50
0 1d8a ae :3 0
af :3 0 1d52 1d53
0 ae :3 0 be
:3 0 1d55 1d56 0
ed :2 0 2 :4 0
1f3 :2 0 c0 :2 0
47 :2 0 1108 1d5b
1d5d :3 0 110b 1d57
1d5f 1d54 1d61 1d60
:2 0 b1 :3 0 c1
:3 0 1d63 1d64 0
b3 :4 0 1f4 :4 0
b6 :2 0 b7 :3 0
110f 1d68 1d6a :3 0
b6 :2 0 ca :4 0
1112 1d6c 1d6e :3 0
b6 :2 0 f0 :4 0
1115 1d70 1d72 :3 0
b6 :2 0 ea :3 0
1118 1d74 1d76 :3 0
b6 :2 0 f1 :4 0
111b 1d78 1d7a :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 111e 1d7d
1d81 1122 1d7c 1d83
:3 0 1125 1d65 1d85
:2 0 1d87 1128 1d88
1d62 1d87 0 1d89
112a 0 1d8a 112c
1d8d :3 0 1d8d 0
1d8d 1d8c 1d8a 1d8b
:6 0 1d8f 30 :3 0
112f 1d91 1131 1d90
1d8f :2 0 1d92 1133
:2 0 1d94 0 1d94
1d93 1d41 1d92 :6 0
1d96 1 :3 0 1136
1d9b 39 :3 0 14
:3 0 1d97 1d98 0
1d9a 113b 1d9c 1c89
1d96 0 1d9d 0
1d9a 0 1d9d 113d
0 1d9e 1140 1d9f
1c7a 1d9e 0 1da0
1144 0 25c2 10
:3 0 e4 :2 0 1146
1da2 1da3 :3 0 1da4
:2 0 8f :3 0 a2
:3 0 1f1 :3 0 10
:3 0 1148 1da8 1daa
4e :2 0 114a 1da7
1dad 109 :2 0 1f5
:2 0 114f 1daf 1db1
:3 0 101 :3 0 a2
:3 0 1f1 :3 0 10
:3 0 1152 1db5 1db7
4e :2 0 1154 1db4
1dba 1f6 :2 0 1157
1db3 1dbd 1f7 :2 0
1f8 :2 0 115a 1dbf
1dc1 :3 0 115d 1dc3
1dc2 101 :3 0 a2
:3 0 1f1 :3 0 10
:3 0 115f 1dc7 1dc9
4e :2 0 1161 1dc6
1dcc 1f6 :2 0 1164
1dc5 1dcf 0 1dd0
0 1167 :2 0 1da6
1dd2 0 1edd 90
:3 0 4e :2 0 1dd4
1dd5 0 1edd 1f9
:3 0 90 :3 0 8f
:3 0 f6 :2 0 1fa
:3 0 116c 1dda 1ddc
:3 0 1ddd 1e19 a2
:3 0 1fb :3 0 f2
:3 0 2a :3 0 90
:3 0 c0 :2 0 47
:2 0 116f 1de4 1de6
:3 0 47 :2 0 1172
1de1 1de9 1176 1de0
1deb 4e :2 0 1178
1ddf 1dee c4 :2 0
1fc :2 0 117d 1df0
1df2 :3 0 a2 :3 0
1fb :3 0 f2 :3 0
2a :3 0 90 :3 0
c0 :2 0 47 :2 0
1180 1df9 1dfb :3 0
47 :2 0 1183 1df6
1dfe 1187 1df5 1e00
4e :2 0 1189 1df4
1e03 c4 :2 0 1fd
:2 0 118e 1e05 1e07
:3 0 1df3 1e09 1e08
:2 0 1fe :8 0 1e0d
1191 1e0e 1e0a 1e0d
0 1e0f 1193 0
1e17 90 :3 0 90
:3 0 c0 :2 0 47
:2 0 1195 1e12 1e14
:3 0 1e10 1e15 0
1e17 1198 1e19 1fa
:3 0 1dde 1e17 :4 0
1edd 90 :3 0 8f
:3 0 d3 :2 0 119d
1e1c 1e1d :3 0 ae
:3 0 af :3 0 1e1f
1e20 0 ae :3 0
be :3 0 1e22 1e23
0 c7 :2 0 2
:4 0 1ff :2 0 c0
:2 0 47 :2 0 11a0
1e28 1e2a :3 0 11a3
1e24 1e2c 1e21 1e2e
1e2d :2 0 b1 :3 0
c1 :3 0 1e30 1e31
0 b3 :4 0 200
:4 0 b6 :2 0 b7
:3 0 11a7 1e35 1e37
:3 0 b6 :2 0 ca
:4 0 11aa 1e39 1e3b
:3 0 b6 :2 0 cb
:4 0 11ad 1e3d 1e3f
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 1e44
1e45 0 11b0 1e43
1e47 bc :4 0 11b2
1e42 1e4a 11b5 1e41
1e4c :3 0 11b8 1e32
1e4e :2 0 1e50 11bb
1e51 1e2f 1e50 0
1e52 11bd 0 1e7b
ae :3 0 af :3 0
1e53 1e54 0 ae
:3 0 be :3 0 1e56
1e57 0 47 :2 0
2 :4 0 201 :2 0
c0 :2 0 47 :2 0
11bf 1e5c 1e5e :3 0
11c2 1e58 1e60 1e55
1e62 1e61 :2 0 b1
:3 0 c1 :3 0 1e64
1e65 0 b3 :4 0
202 :4 0 b6 :2 0
b7 :3 0 11c6 1e69
1e6b :3 0 11c9 1e66
1e6d :2 0 1e6f 11cc
1e70 1e63 1e6f 0
1e71 11ce 0 1e7b
cf :3 0 d0 :3 0
1e72 1e73 0 c3
:3 0 d7 :3 0 1e75
1e76 0 d1 :3 0
11d0 1e74 1e79 :2 0
1e7b 11d3 1e7c 1e1e
1e7b 0 1e7d 11d7
0 1edd 203 :3 0
2a :3 0 2a :3 0
e7 :4 0 204 1
:8 0 1e88 21 :3 0
e9 :3 0 1e83 1e84
0 ea :3 0 1e85
1e86 0 1e88 11d9
1edb eb :3 0 21
:3 0 e9 :3 0 1e8a
1e8b 0 ea :3 0
1e8c 1e8d 0 1e8f
11dc 1e91 11de 1e90
1e8f :2 0 1ed9 ec
:3 0 21 :3 0 e9
:3 0 1e94 1e95 0
ea :3 0 1e96 1e97
0 1ed1 ae :3 0
af :3 0 1e99 1e9a
0 ae :3 0 be
:3 0 1e9c 1e9d 0
ed :2 0 2 :4 0
205 :2 0 c0 :2 0
47 :2 0 11e0 1ea2
1ea4 :3 0 11e3 1e9e
1ea6 1e9b 1ea8 1ea7
:2 0 b1 :3 0 c1
:3 0 1eaa 1eab 0
b3 :4 0 206 :4 0
b6 :2 0 b7 :3 0
11e7 1eaf 1eb1 :3 0
b6 :2 0 ca :4 0
11ea 1eb3 1eb5 :3 0
b6 :2 0 f0 :4 0
11ed 1eb7 1eb9 :3 0
b6 :2 0 ea :3 0
11f0 1ebb 1ebd :3 0
b6 :2 0 f1 :4 0
11f3 1ebf 1ec1 :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 11f6 1ec4
1ec8 11fa 1ec3 1eca
:3 0 11fd 1eac 1ecc
:2 0 1ece 1200 1ecf
1ea9 1ece 0 1ed0
1202 0 1ed1 1204
1ed4 :3 0 1ed4 0
1ed4 1ed3 1ed1 1ed2
:6 0 1ed6 33 :3 0
1207 1ed8 1209 1ed7
1ed6 :2 0 1ed9 120b
:2 0 1edb 0 1edb
1eda 1e88 1ed9 :6 0
1edd 1 :3 0 120e
1ede 1da5 1edd 0
1edf 1214 0 25c2
a2 :3 0 5c :3 0
4e :2 0 1216 1ee0
1ee3 c3 :3 0 d3
:2 0 d4 :3 0 1ee5
1ee7 0 121b 1ee6
1ee9 :3 0 75 :3 0
207 :4 0 1eeb 1eec
0 1f00 77 :3 0
208 :4 0 1eee 1eef
0 1f00 77 :3 0
77 :3 0 b6 :2 0
39 :3 0 121e 1ef3
1ef5 :3 0 1ef1 1ef6
0 1f00 77 :3 0
77 :3 0 b6 :2 0
b9 :4 0 1221 1efa
1efc :3 0 1ef8 1efd
0 1f00 d9 :3 0
1224 1feb a2 :3 0
5c :3 0 4e :2 0
1229 1f01 1f04 c3
:3 0 d3 :2 0 d2
:3 0 1f06 1f08 0
122e 1f07 1f0a :3 0
75 :3 0 209 :4 0
1f0c 1f0d 0 1f20
75 :3 0 75 :3 0
b6 :2 0 25 :3 0
1231 1f11 1f13 :3 0
1f0f 1f14 0 1f20
75 :3 0 75 :3 0
b6 :2 0 20a :4 0
1234 1f18 1f1a :3 0
1f16 1f1b 0 1f20
77 :3 0 20b :4 0
1f1d 1f1e 0 1f20
1237 1f21 1f0b 1f20
0 1fed a2 :3 0
a :3 0 4e :2 0
123c 1f22 1f25 c3
:3 0 d3 :2 0 c5
:3 0 1f27 1f29 0
1241 1f28 1f2b :3 0
75 :3 0 20c :4 0
1f2d 1f2e 0 1f74
77 :3 0 20b :4 0
1f30 1f31 0 1f74
1e :3 0 e4 :2 0
1244 1f34 1f35 :3 0
1f36 :2 0 77 :3 0
77 :3 0 b6 :2 0
20d :4 0 1246 1f3a
1f3c :3 0 1f38 1f3d
0 1f4d 77 :3 0
77 :3 0 b6 :2 0
3a :3 0 1249 1f41
1f43 :3 0 1f3f 1f44
0 1f4d 77 :3 0
77 :3 0 b6 :2 0
1da :4 0 124c 1f48
1f4a :3 0 1f46 1f4b
0 1f4d 124f 1f4e
1f37 1f4d 0 1f4f
1253 0 1f74 77
:3 0 77 :3 0 b6
:2 0 20e :4 0 1255
1f52 1f54 :3 0 1f50
1f55 0 1f74 10
:3 0 e4 :2 0 1258
1f58 1f59 :3 0 1f5a
:2 0 77 :3 0 77
:3 0 b6 :2 0 20f
:4 0 125a 1f5e 1f60
:3 0 1f5c 1f61 0
1f71 77 :3 0 77
:3 0 b6 :2 0 2a
:3 0 125d 1f65 1f67
:3 0 1f63 1f68 0
1f71 77 :3 0 77
:3 0 b6 :2 0 210
:4 0 1260 1f6c 1f6e
:3 0 1f6a 1f6f 0
1f71 1263 1f72 1f5b
1f71 0 1f73 1267
0 1f74 1269 1fe7
14 :3 0 e4 :2 0
126f 1f76 1f77 :3 0
1f78 :2 0 75 :3 0
75 :3 0 b6 :2 0
211 :4 0 1271 1f7c
1f7e :3 0 1f7a 1f7f
0 1f84 77 :3 0
20b :4 0 1f81 1f82
0 1f84 1274 1fcc
75 :3 0 75 :3 0
b6 :2 0 212 :4 0
1277 1f87 1f89 :3 0
b6 :2 0 213 :4 0
127a 1f8b 1f8d :3 0
1f85 1f8e 0 1fcb
77 :3 0 20b :4 0
1f90 1f91 0 1fcb
1e :3 0 e4 :2 0
127d 1f94 1f95 :3 0
1f96 :2 0 77 :3 0
77 :3 0 b6 :2 0
20d :4 0 127f 1f9a
1f9c :3 0 1f98 1f9d
0 1fad 77 :3 0
77 :3 0 b6 :2 0
3a :3 0 1282 1fa1
1fa3 :3 0 1f9f 1fa4
0 1fad 77 :3 0
77 :3 0 b6 :2 0
1da :4 0 1285 1fa8
1faa :3 0 1fa6 1fab
0 1fad 1288 1fae
1f97 1fad 0 1faf
128c 0 1fcb 77
:3 0 77 :3 0 b6
:2 0 214 :4 0 128e
1fb2 1fb4 :3 0 b6
:2 0 215 :4 0 1291
1fb6 1fb8 :3 0 b6
:2 0 216 :4 0 1294
1fba 1fbc :3 0 b6
:2 0 217 :4 0 1297
1fbe 1fc0 :3 0 b6
:2 0 218 :4 0 129a
1fc2 1fc4 :3 0 b6
:2 0 219 :4 0 129d
1fc6 1fc8 :3 0 1fb0
1fc9 0 1fcb 12a0
1fcd 1f79 1f84 0
1fce 0 1fcb 0
1fce 12a5 0 1fe6
10 :3 0 e4 :2 0
12a8 1fd0 1fd1 :3 0
1fd2 :2 0 77 :3 0
77 :3 0 b6 :2 0
21a :4 0 12aa 1fd6
1fd8 :3 0 b6 :2 0
2a :3 0 12ad 1fda
1fdc :3 0 b6 :2 0
210 :4 0 12b0 1fde
1fe0 :3 0 1fd4 1fe1
0 1fe3 12b3 1fe4
1fd3 1fe3 0 1fe5
12b5 0 1fe6 12b7
1fe8 1f2c 1f74 0
1fe9 0 1fe6 0
1fe9 12ba 0 1fea
12bd 1fec 1eea 1f00
0 1fed 0 1fea
0 1fed 12bf 0
25c2 a2 :3 0 5c
:3 0 4e :2 0 12c3
1fee 1ff1 c3 :3 0
c4 :2 0 d4 :3 0
1ff3 1ff5 0 12c8
1ff4 1ff7 :3 0 14
:3 0 e4 :2 0 12cb
1ffa 1ffb :3 0 1ffc
:2 0 1e6 :3 0 3b
:3 0 183 :3 0 111
:3 0 14 :4 0 21b
1 :8 0 2009 21
:3 0 e9 :3 0 2004
2005 0 ea :3 0
2006 2007 0 2009
12cd 205c eb :3 0
21 :3 0 e9 :3 0
200b 200c 0 ea
:3 0 200d 200e 0
2010 12d0 2012 12d2
2011 2010 :2 0 205a
ec :3 0 21 :3 0
e9 :3 0 2015 2016
0 ea :3 0 2017
2018 0 2052 ae
:3 0 af :3 0 201a
201b 0 ae :3 0
be :3 0 201d 201e
0 ed :2 0 2
:4 0 21c :2 0 c0
:2 0 47 :2 0 12d4
2023 2025 :3 0 12d7
201f 2027 201c 2029
2028 :2 0 b1 :3 0
c1 :3 0 202b 202c
0 b3 :4 0 21d
:4 0 b6 :2 0 b7
:3 0 12db 2030 2032
:3 0 b6 :2 0 ca
:4 0 12de 2034 2036
:3 0 b6 :2 0 f0
:4 0 12e1 2038 203a
:3 0 b6 :2 0 ea
:3 0 12e4 203c 203e
:3 0 b6 :2 0 f1
:4 0 12e7 2040 2042
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 12ea
2045 2049 12ee 2044
204b :3 0 12f1 202d
204d :2 0 204f 12f4
2050 202a 204f 0
2051 12f6 0 2052
12f8 2055 :3 0 2055
0 2055 2054 2052
2053 :6 0 2057 35
:3 0 12fb 2059 12fd
2058 2057 :2 0 205a
12ff :2 0 205c 0
205c 205b 2009 205a
:6 0 20fe 1 :3 0
21 :3 0 e9 :3 0
205e 205f 0 21
:3 0 d3 :2 0 f5
:3 0 2061 2063 0
1304 2062 2065 :3 0
2066 :2 0 91 :3 0
a2 :3 0 1f1 :3 0
3b :3 0 1307 206a
206c 4e :2 0 1309
2069 206f 2068 2070
0 208c 75 :3 0
75 :3 0 b6 :2 0
21e :4 0 130c 2074
2076 :3 0 2072 2077
0 208c 77 :3 0
77 :3 0 b6 :2 0
21f :4 0 130f 207b
207d :3 0 b6 :2 0
220 :4 0 1312 207f
2081 :3 0 b6 :2 0
3b :3 0 1315 2083
2085 :3 0 b6 :2 0
221 :4 0 1318 2087
2089 :3 0 2079 208a
0 208c 131b 20fb
ae :3 0 af :3 0
208d 208e 0 ae
:3 0 be :3 0 2090
2091 0 24 :2 0
2 :4 0 222 :2 0
c0 :2 0 47 :2 0
131f 2096 2098 :3 0
1322 2092 209a 208f
209c 209b :2 0 b1
:3 0 c1 :3 0 209e
209f 0 b3 :4 0
223 :4 0 b6 :2 0
b7 :3 0 1326 20a3
20a5 :3 0 b6 :2 0
ca :4 0 1329 20a7
20a9 :3 0 b6 :2 0
cb :4 0 132c 20ab
20ad :3 0 b6 :2 0
a2 :3 0 bb :3 0
c3 :3 0 d7 :3 0
20b2 20b3 0 132f
20b1 20b5 bc :4 0
1331 20b0 20b8 1334
20af 20ba :3 0 b6
:2 0 11a :4 0 1337
20bc 20be :3 0 b6
:2 0 b9 :4 0 133a
20c0 20c2 :3 0 b6
:2 0 14 :3 0 133d
20c4 20c6 :3 0 b6
:2 0 b9 :4 0 1340
20c8 20ca :3 0 1343
20a0 20cc :2 0 20ce
1346 20cf 209d 20ce
0 20d0 1348 0
20fa ae :3 0 af
:3 0 20d1 20d2 0
ae :3 0 be :3 0
20d4 20d5 0 47
:2 0 2 :4 0 224
:2 0 c0 :2 0 47
:2 0 134a 20da 20dc
:3 0 134d 20d6 20de
20d3 20e0 20df :2 0
b1 :3 0 c1 :3 0
20e2 20e3 0 b3
:4 0 225 :4 0 b6
:2 0 b7 :3 0 1351
20e7 20e9 :3 0 1354
20e4 20eb :2 0 20ed
1357 20ee 20e1 20ed
0 20ef 1359 0
20fa cf :3 0 11d
:3 0 20f0 20f1 0
c3 :3 0 d7 :3 0
20f3 20f4 0 14
:3 0 d1 :3 0 135b
20f2 20f8 :2 0 20fa
135f 20fc 2067 208c
0 20fd 0 20fa
0 20fd 1363 0
20fe 1366 20ff 1ffd
20fe 0 2100 1369
0 232a 12 :3 0
e4 :2 0 136b 2102
2103 :3 0 2104 :2 0
1e6 :3 0 3b :3 0
226 :3 0 111 :3 0
12 :4 0 227 1
:8 0 2111 21 :3 0
e9 :3 0 210c 210d
0 ea :3 0 210e
210f 0 2111 136d
2164 eb :3 0 21
:3 0 e9 :3 0 2113
2114 0 ea :3 0
2115 2116 0 2118
1370 211a 1372 2119
2118 :2 0 2162 ec
:3 0 21 :3 0 e9
:3 0 211d 211e 0
ea :3 0 211f 2120
0 215a ae :3 0
af :3 0 2122 2123
0 ae :3 0 be
:3 0 2125 2126 0
ed :2 0 2 :4 0
228 :2 0 c0 :2 0
47 :2 0 1374 212b
212d :3 0 1377 2127
212f 2124 2131 2130
:2 0 b1 :3 0 c1
:3 0 2133 2134 0
b3 :4 0 229 :4 0
b6 :2 0 b7 :3 0
137b 2138 213a :3 0
b6 :2 0 ca :4 0
137e 213c 213e :3 0
b6 :2 0 f0 :4 0
1381 2140 2142 :3 0
b6 :2 0 ea :3 0
1384 2144 2146 :3 0
b6 :2 0 f1 :4 0
1387 2148 214a :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 138a 214d
2151 138e 214c 2153
:3 0 1391 2135 2155
:2 0 2157 1394 2158
2132 2157 0 2159
1396 0 215a 1398
215d :3 0 215d 0
215d 215c 215a 215b
:6 0 215f 37 :3 0
139b 2161 139d 2160
215f :2 0 2162 139f
:2 0 2164 0 2164
2163 2111 2162 :6 0
21fc 1 :3 0 21
:3 0 e9 :3 0 2166
2167 0 21 :3 0
d3 :2 0 f5 :3 0
2169 216b 0 13a4
216a 216d :3 0 216e
:2 0 75 :3 0 75
:3 0 b6 :2 0 22a
:4 0 13a7 2172 2174
:3 0 2170 2175 0
218a 77 :3 0 77
:3 0 b6 :2 0 22b
:4 0 13aa 2179 217b
:3 0 b6 :2 0 22c
:4 0 13ad 217d 217f
:3 0 b6 :2 0 3b
:3 0 13b0 2181 2183
:3 0 b6 :2 0 221
:4 0 13b3 2185 2187
:3 0 2177 2188 0
218a 13b6 21f9 ae
:3 0 af :3 0 218b
218c 0 ae :3 0
be :3 0 218e 218f
0 24 :2 0 2
:4 0 22d :2 0 c0
:2 0 47 :2 0 13b9
2194 2196 :3 0 13bc
2190 2198 218d 219a
2199 :2 0 b1 :3 0
c1 :3 0 219c 219d
0 b3 :4 0 22e
:4 0 b6 :2 0 b7
:3 0 13c0 21a1 21a3
:3 0 b6 :2 0 ca
:4 0 13c3 21a5 21a7
:3 0 b6 :2 0 cb
:4 0 13c6 21a9 21ab
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 21b0
21b1 0 13c9 21af
21b3 bc :4 0 13cb
21ae 21b6 13ce 21ad
21b8 :3 0 b6 :2 0
11a :4 0 13d1 21ba
21bc :3 0 b6 :2 0
b9 :4 0 13d4 21be
21c0 :3 0 b6 :2 0
12 :3 0 13d7 21c2
21c4 :3 0 b6 :2 0
b9 :4 0 13da 21c6
21c8 :3 0 13dd 219e
21ca :2 0 21cc 13e0
21cd 219b 21cc 0
21ce 13e2 0 21f8
ae :3 0 af :3 0
21cf 21d0 0 ae
:3 0 be :3 0 21d2
21d3 0 47 :2 0
2 :4 0 22f :2 0
c0 :2 0 47 :2 0
13e4 21d8 21da :3 0
13e7 21d4 21dc 21d1
21de 21dd :2 0 b1
:3 0 c1 :3 0 21e0
21e1 0 b3 :4 0
230 :4 0 b6 :2 0
b7 :3 0 13eb 21e5
21e7 :3 0 13ee 21e2
21e9 :2 0 21eb 13f1
21ec 21df 21eb 0
21ed 13f3 0 21f8
cf :3 0 11d :3 0
21ee 21ef 0 c3
:3 0 d7 :3 0 21f1
21f2 0 12 :3 0
d1 :3 0 13f5 21f0
21f6 :2 0 21f8 13f9
21fa 216f 218a 0
21fb 0 21f8 0
21fb 13fd 0 21fc
1400 21fd 2105 21fc
0 21fe 1403 0
232a 13 :3 0 e4
:2 0 1405 2200 2201
:3 0 2202 :2 0 1e6
:3 0 3b :3 0 231
:3 0 111 :3 0 13
:4 0 232 1 :8 0
220f 21 :3 0 e9
:3 0 220a 220b 0
ea :3 0 220c 220d
0 220f 1407 2262
eb :3 0 21 :3 0
e9 :3 0 2211 2212
0 ea :3 0 2213
2214 0 2216 140a
2218 140c 2217 2216
:2 0 2260 ec :3 0
21 :3 0 e9 :3 0
221b 221c 0 ea
:3 0 221d 221e 0
2258 ae :3 0 af
:3 0 2220 2221 0
ae :3 0 be :3 0
2223 2224 0 ed
:2 0 2 :4 0 233
:2 0 c0 :2 0 47
:2 0 140e 2229 222b
:3 0 1411 2225 222d
2222 222f 222e :2 0
b1 :3 0 c1 :3 0
2231 2232 0 b3
:4 0 234 :4 0 b6
:2 0 b7 :3 0 1415
2236 2238 :3 0 b6
:2 0 ca :4 0 1418
223a 223c :3 0 b6
:2 0 f0 :4 0 141b
223e 2240 :3 0 b6
:2 0 ea :3 0 141e
2242 2244 :3 0 b6
:2 0 f1 :4 0 1421
2246 2248 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 1424 224b 224f
1428 224a 2251 :3 0
142b 2233 2253 :2 0
2255 142e 2256 2230
2255 0 2257 1430
0 2258 1432 225b
:3 0 225b 0 225b
225a 2258 2259 :6 0
225d 39 :3 0 1435
225f 1437 225e 225d
:2 0 2260 1439 :2 0
2262 0 2262 2261
220f 2260 :6 0 22fa
1 :3 0 21 :3 0
e9 :3 0 2264 2265
0 21 :3 0 d3
:2 0 f5 :3 0 2267
2269 0 143e 2268
226b :3 0 226c :2 0
75 :3 0 75 :3 0
b6 :2 0 235 :4 0
1441 2270 2272 :3 0
226e 2273 0 2288
77 :3 0 77 :3 0
b6 :2 0 236 :4 0
1444 2277 2279 :3 0
b6 :2 0 237 :4 0
1447 227b 227d :3 0
b6 :2 0 3b :3 0
144a 227f 2281 :3 0
b6 :2 0 221 :4 0
144d 2283 2285 :3 0
2275 2286 0 2288
1450 22f7 ae :3 0
af :3 0 2289 228a
0 ae :3 0 be
:3 0 228c 228d 0
24 :2 0 2 :4 0
238 :2 0 c0 :2 0
47 :2 0 1453 2292
2294 :3 0 1456 228e
2296 228b 2298 2297
:2 0 b1 :3 0 c1
:3 0 229a 229b 0
b3 :4 0 239 :4 0
b6 :2 0 b7 :3 0
145a 229f 22a1 :3 0
b6 :2 0 ca :4 0
145d 22a3 22a5 :3 0
b6 :2 0 cb :4 0
1460 22a7 22a9 :3 0
b6 :2 0 a2 :3 0
bb :3 0 c3 :3 0
d7 :3 0 22ae 22af
0 1463 22ad 22b1
bc :4 0 1465 22ac
22b4 1468 22ab 22b6
:3 0 b6 :2 0 11a
:4 0 146b 22b8 22ba
:3 0 b6 :2 0 b9
:4 0 146e 22bc 22be
:3 0 b6 :2 0 13
:3 0 1471 22c0 22c2
:3 0 b6 :2 0 b9
:4 0 1474 22c4 22c6
:3 0 1477 229c 22c8
:2 0 22ca 147a 22cb
2299 22ca 0 22cc
147c 0 22f6 ae
:3 0 af :3 0 22cd
22ce 0 ae :3 0
be :3 0 22d0 22d1
0 47 :2 0 2
:4 0 23a :2 0 c0
:2 0 47 :2 0 147e
22d6 22d8 :3 0 1481
22d2 22da 22cf 22dc
22db :2 0 b1 :3 0
c1 :3 0 22de 22df
0 b3 :4 0 23b
:4 0 b6 :2 0 b7
:3 0 1485 22e3 22e5
:3 0 1488 22e0 22e7
:2 0 22e9 148b 22ea
22dd 22e9 0 22eb
148d 0 22f6 cf
:3 0 11d :3 0 22ec
22ed 0 c3 :3 0
d7 :3 0 22ef 22f0
0 13 :3 0 d1
:3 0 148f 22ee 22f4
:2 0 22f6 1493 22f8
226d 2288 0 22f9
0 22f6 0 22f9
1497 0 22fa 149a
22fb 2203 22fa 0
22fc 149d 0 232a
a2 :3 0 54 :3 0
4e :2 0 149f 22fd
2300 109 :2 0 4e
:2 0 14a4 2302 2304
:3 0 a2 :3 0 54
:3 0 4e :2 0 14a7
2306 2309 c4 :2 0
e3 :2 0 14ac 230b
230d :3 0 2305 230f
230e :2 0 77 :3 0
77 :3 0 b6 :2 0
23c :4 0 14af 2313
2315 :3 0 b6 :2 0
bb :3 0 a2 :3 0
15 :3 0 4e :2 0
14b2 2319 231c 14b5
2318 231e 14b7 2317
2320 :3 0 b6 :2 0
ca :4 0 14ba 2322
2324 :3 0 2311 2325
0 2327 14bd 2328
2310 2327 0 2329
14bf 0 232a 14c1
232b 1ff8 232a 0
232c 14c6 0 25c2
16 :3 0 e4 :2 0
14c8 232e 232f :3 0
2330 :2 0 92 :3 0
a2 :3 0 1f1 :3 0
2e :3 0 14ca 2334
2336 4e :2 0 14cc
2333 2339 2332 233a
0 2483 86 :3 0
4e :2 0 233c 233d
0 2483 1f9 :3 0
86 :3 0 92 :3 0
f6 :2 0 1fa :3 0
14d1 2342 2344 :3 0
2345 2482 49 :3 0
23d :3 0 23e :3 0
2348 2349 0 24
:2 0 24 :2 0 86
:3 0 c0 :2 0 47
:2 0 14d4 234e 2350
:3 0 2e :3 0 14d7
234a 2353 2347 2354
0 2480 1e6 :3 0
3b :3 0 1af :3 0
111 :3 0 49 :4 0
23f 1 :8 0 2361
21 :3 0 e9 :3 0
235c 235d 0 ea
:3 0 235e 235f 0
2361 14dc 23b4 eb
:3 0 21 :3 0 e9
:3 0 2363 2364 0
ea :3 0 2365 2366
0 2368 14df 236a
14e1 2369 2368 :2 0
23b2 ec :3 0 21
:3 0 e9 :3 0 236d
236e 0 ea :3 0
236f 2370 0 23aa
ae :3 0 af :3 0
2372 2373 0 ae
:3 0 be :3 0 2375
2376 0 ed :2 0
2 :4 0 240 :2 0
c0 :2 0 47 :2 0
14e3 237b 237d :3 0
14e6 2377 237f 2374
2381 2380 :2 0 b1
:3 0 c1 :3 0 2383
2384 0 b3 :4 0
241 :4 0 b6 :2 0
b7 :3 0 14ea 2388
238a :3 0 b6 :2 0
ca :4 0 14ed 238c
238e :3 0 b6 :2 0
f0 :4 0 14f0 2390
2392 :3 0 b6 :2 0
ea :3 0 14f3 2394
2396 :3 0 b6 :2 0
f1 :4 0 14f6 2398
239a :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
14f9 239d 23a1 14fd
239c 23a3 :3 0 1500
2385 23a5 :2 0 23a7
1503 23a8 2382 23a7
0 23a9 1505 0
23aa 1507 23ad :3 0
23ad 0 23ad 23ac
23aa 23ab :6 0 23af
3c :3 0 150a 23b1
150c 23b0 23af :2 0
23b2 150e :2 0 23b4
0 23b4 23b3 2361
23b2 :6 0 2480 3b
:3 0 21 :3 0 e9
:3 0 23b6 23b7 0
21 :3 0 c4 :2 0
f5 :3 0 23b9 23bb
0 1513 23ba 23bd
:3 0 23be :2 0 ae
:3 0 af :3 0 23c0
23c1 0 ae :3 0
be :3 0 23c3 23c4
0 24 :2 0 2
:4 0 242 :2 0 c0
:2 0 47 :2 0 1516
23c9 23cb :3 0 1519
23c5 23cd 23c2 23cf
23ce :2 0 b1 :3 0
c1 :3 0 23d1 23d2
0 b3 :4 0 243
:4 0 b6 :2 0 b7
:3 0 151d 23d6 23d8
:3 0 b6 :2 0 ca
:4 0 1520 23da 23dc
:3 0 b6 :2 0 cb
:4 0 1523 23de 23e0
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 23e5
23e6 0 1526 23e4
23e8 bc :4 0 1528
23e3 23eb 152b 23e2
23ed :3 0 b6 :2 0
11a :4 0 152e 23ef
23f1 :3 0 b6 :2 0
b9 :4 0 1531 23f3
23f5 :3 0 b6 :2 0
49 :3 0 1534 23f7
23f9 :3 0 b6 :2 0
b9 :4 0 1537 23fb
23fd :3 0 153a 23d3
23ff :2 0 2401 153d
2402 23d0 2401 0
2403 153f 0 242d
ae :3 0 af :3 0
2404 2405 0 ae
:3 0 be :3 0 2407
2408 0 47 :2 0
2 :4 0 244 :2 0
c0 :2 0 47 :2 0
1541 240d 240f :3 0
1544 2409 2411 2406
2413 2412 :2 0 b1
:3 0 c1 :3 0 2415
2416 0 b3 :4 0
245 :4 0 b6 :2 0
b7 :3 0 1548 241a
241c :3 0 154b 2417
241e :2 0 2420 154e
2421 2414 2420 0
2422 1550 0 242d
cf :3 0 11d :3 0
2423 2424 0 c3
:3 0 d7 :3 0 2426
2427 0 49 :3 0
d1 :3 0 1552 2425
242b :2 0 242d 1556
242e 23bf 242d 0
242f 155a 0 2480
77 :3 0 77 :3 0
b6 :2 0 246 :4 0
155c 2432 2434 :3 0
b6 :2 0 247 :4 0
155f 2436 2438 :3 0
b6 :2 0 248 :4 0
1562 243a 243c :3 0
b6 :2 0 249 :4 0
1565 243e 2440 :3 0
b6 :2 0 3b :3 0
1568 2442 2444 :3 0
b6 :2 0 24a :4 0
156b 2446 2448 :3 0
2430 2449 0 2480
a2 :3 0 5c :3 0
4e :2 0 156e 244b
244e c3 :3 0 d3
:2 0 d4 :3 0 2450
2452 0 1573 2451
2454 :3 0 77 :3 0
77 :3 0 b6 :2 0
24b :4 0 1576 2458
245a :3 0 2456 245b
0 245d 1579 2466
77 :3 0 77 :3 0
b6 :2 0 24c :4 0
157b 2460 2462 :3 0
245e 2463 0 2465
157e 2467 2455 245d
0 2468 0 2465
0 2468 1580 0
2480 a2 :3 0 5c
:3 0 4e :2 0 1583
2469 246c c3 :3 0
d3 :2 0 d4 :3 0
246e 2470 0 1588
246f 2472 :3 0 1fe
:8 0 2476 158b 2477
2473 2476 0 2478
158d 0 2480 86
:3 0 86 :3 0 c0
:2 0 24 :2 0 158f
247b 247d :3 0 2479
247e 0 2480 1592
2482 1fa :3 0 2346
2480 :4 0 2483 159a
2484 2331 2483 0
2485 159e 0 25c2
a2 :3 0 5c :3 0
4e :2 0 15a0 2486
2489 c3 :3 0 c4
:2 0 d4 :3 0 248b
248d 0 15a5 248c
248f :3 0 93 :3 0
a2 :3 0 1f1 :3 0
30 :3 0 15a8 2493
2495 4e :2 0 15aa
2492 2498 2491 2499
0 25b8 86 :3 0
4e :2 0 249b 249c
0 25b8 1f9 :3 0
86 :3 0 93 :3 0
f6 :2 0 1fa :3 0
15af 24a1 24a3 :3 0
24a4 25b7 49 :3 0
23d :3 0 23e :3 0
24a7 24a8 0 24
:2 0 24 :2 0 86
:3 0 c0 :2 0 47
:2 0 15b2 24ad 24af
:3 0 30 :3 0 15b5
24a9 24b2 24a6 24b3
0 25b5 1e6 :3 0
3b :3 0 1af :3 0
111 :3 0 49 :4 0
23f 1 :8 0 24c0
21 :3 0 e9 :3 0
24bb 24bc 0 ea
:3 0 24bd 24be 0
24c0 15ba 2513 eb
:3 0 21 :3 0 e9
:3 0 24c2 24c3 0
ea :3 0 24c4 24c5
0 24c7 15bd 24c9
15bf 24c8 24c7 :2 0
2511 ec :3 0 21
:3 0 e9 :3 0 24cc
24cd 0 ea :3 0
24ce 24cf 0 2509
ae :3 0 af :3 0
24d1 24d2 0 ae
:3 0 be :3 0 24d4
24d5 0 ed :2 0
2 :4 0 24d :2 0
c0 :2 0 47 :2 0
15c1 24da 24dc :3 0
15c4 24d6 24de 24d3
24e0 24df :2 0 b1
:3 0 c1 :3 0 24e2
24e3 0 b3 :4 0
24e :4 0 b6 :2 0
b7 :3 0 15c8 24e7
24e9 :3 0 b6 :2 0
ca :4 0 15cb 24eb
24ed :3 0 b6 :2 0
f0 :4 0 15ce 24ef
24f1 :3 0 b6 :2 0
ea :3 0 15d1 24f3
24f5 :3 0 b6 :2 0
f1 :4 0 15d4 24f7
24f9 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
15d7 24fc 2500 15db
24fb 2502 :3 0 15de
24e4 2504 :2 0 2506
15e1 2507 24e1 2506
0 2508 15e3 0
2509 15e5 250c :3 0
250c 0 250c 250b
2509 250a :6 0 250e
3f :3 0 15e8 2510
15ea 250f 250e :2 0
2511 15ec :2 0 2513
0 2513 2512 24c0
2511 :6 0 25b5 3e
:3 0 21 :3 0 e9
:3 0 2515 2516 0
21 :3 0 c4 :2 0
f5 :3 0 2518 251a
0 15f1 2519 251c
:3 0 251d :2 0 ae
:3 0 af :3 0 251f
2520 0 ae :3 0
be :3 0 2522 2523
0 24 :2 0 2
:4 0 24f :2 0 c0
:2 0 47 :2 0 15f4
2528 252a :3 0 15f7
2524 252c 2521 252e
252d :2 0 b1 :3 0
c1 :3 0 2530 2531
0 b3 :4 0 250
:4 0 b6 :2 0 b7
:3 0 15fb 2535 2537
:3 0 b6 :2 0 ca
:4 0 15fe 2539 253b
:3 0 b6 :2 0 cb
:4 0 1601 253d 253f
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 2544
2545 0 1604 2543
2547 bc :4 0 1606
2542 254a 1609 2541
254c :3 0 b6 :2 0
11a :4 0 160c 254e
2550 :3 0 b6 :2 0
b9 :4 0 160f 2552
2554 :3 0 b6 :2 0
49 :3 0 1612 2556
2558 :3 0 b6 :2 0
b9 :4 0 1615 255a
255c :3 0 1618 2532
255e :2 0 2560 161b
2561 252f 2560 0
2562 161d 0 258c
ae :3 0 af :3 0
2563 2564 0 ae
:3 0 be :3 0 2566
2567 0 47 :2 0
2 :4 0 251 :2 0
c0 :2 0 47 :2 0
161f 256c 256e :3 0
1622 2568 2570 2565
2572 2571 :2 0 b1
:3 0 c1 :3 0 2574
2575 0 b3 :4 0
252 :4 0 b6 :2 0
b7 :3 0 1626 2579
257b :3 0 1629 2576
257d :2 0 257f 162c
2580 2573 257f 0
2581 162e 0 258c
cf :3 0 11d :3 0
2582 2583 0 c3
:3 0 d7 :3 0 2585
2586 0 49 :3 0
d1 :3 0 1630 2584
258a :2 0 258c 1634
258d 251e 258c 0
258e 1638 0 25b5
77 :3 0 77 :3 0
b6 :2 0 246 :4 0
163a 2591 2593 :3 0
b6 :2 0 247 :4 0
163d 2595 2597 :3 0
b6 :2 0 248 :4 0
1640 2599 259b :3 0
b6 :2 0 249 :4 0
1643 259d 259f :3 0
b6 :2 0 3b :3 0
1646 25a1 25a3 :3 0
b6 :2 0 24a :4 0
1649 25a5 25a7 :3 0
b6 :2 0 253 :4 0
164c 25a9 25ab :3 0
258f 25ac 0 25b5
86 :3 0 86 :3 0
c0 :2 0 24 :2 0
164f 25b0 25b2 :3 0
25ae 25b3 0 25b5
1652 25b7 1fa :3 0
24a5 25b5 :4 0 25b8
1658 25b9 2490 25b8
0 25ba 165c 0
25c2 75 :3 0 75
:3 0 b6 :2 0 77
:3 0 165e 25bd 25bf
:3 0 25bb 25c0 0
25c2 1661 25c4 1bdf
1c55 0 25c5 0
25c2 0 25c5 1669
0 367b 75 :3 0
75 :3 0 b6 :2 0
254 :4 0 166c 25c8
25ca :3 0 25c6 25cb
0 367b 255 :3 0
94 :3 0 75 :3 0
25ce 25cf 0 25d0
:2 0 367b 1fa :3 0
94 :3 0 39 :4 0
25d6 :2 0 2a8a 25d3
25d4 :3 0 94 :3 0
1bf :3 0 25d7 25d8
:3 0 21 :3 0 e9
:3 0 25da 25db 0
4e :2 0 25dc 25dd
0 25df 166f 25e6
21 :3 0 e9 :3 0
25e0 25e1 0 18b
:2 0 25e2 25e3 0
25e5 1671 25e7 25d9
25df 0 25e8 0
25e5 0 25e8 1673
0 2a8a 21 :3 0
e9 :3 0 25e9 25ea
0 21 :3 0 c4
:2 0 f5 :3 0 25ec
25ee 0 1678 25ed
25f0 :3 0 25f1 :2 0
1fe :8 0 25f5 167b
25f6 25f2 25f5 0
25f7 167d 0 2a8a
a2 :3 0 50 :3 0
4e :2 0 167f 25f8
25fb d3 :2 0 4e
:2 0 1684 25fd 25ff
:3 0 a2 :3 0 5c
:3 0 4e :2 0 1687
2601 2604 c3 :3 0
c4 :2 0 c5 :3 0
2606 2608 0 168c
2607 260a :3 0 2600
260c 260b :2 0 a2
:3 0 5c :3 0 4e
:2 0 168f 260e 2611
c3 :3 0 c4 :2 0
d2 :3 0 2613 2615
0 1694 2614 2617
:3 0 260d 2619 2618
:2 0 a2 :3 0 5c
:3 0 4e :2 0 1697
261b 261e c3 :3 0
c4 :2 0 d4 :3 0
2620 2622 0 169c
2621 2624 :3 0 14
:3 0 c6 :2 0 169f
2627 2628 :3 0 2629
:2 0 2625 262b 262a
:2 0 262c :2 0 261a
262e 262d :2 0 255
:3 0 96 :4 0 2633
:2 0 2718 2631 2634
:3 0 96 :3 0 28
:4 0 2638 :2 0 2718
2635 2636 :3 0 96
:3 0 1bf :3 0 2639
263a :3 0 21 :3 0
e9 :3 0 263c 263d
0 4e :2 0 263e
263f 0 2641 16a1
2648 21 :3 0 e9
:3 0 2642 2643 0
18b :2 0 2644 2645
0 2647 16a3 2649
263b 2641 0 264a
0 2647 0 264a
16a5 0 2718 21
:3 0 e9 :3 0 264b
264c 0 21 :3 0
d3 :2 0 f5 :3 0
264e 2650 0 16aa
264f 2652 :3 0 2653
:2 0 256 :3 0 96
:4 0 2658 :2 0 265e
2656 0 21 :3 0
e9 :3 0 2659 265a
0 ea :3 0 265b
265c 0 265e 16ad
26b1 eb :3 0 21
:3 0 e9 :3 0 2660
2661 0 ea :3 0
2662 2663 0 2665
16b0 2667 16b2 2666
2665 :2 0 26af ec
:3 0 21 :3 0 e9
:3 0 266a 266b 0
ea :3 0 266c 266d
0 26a7 ae :3 0
af :3 0 266f 2670
0 ae :3 0 be
:3 0 2672 2673 0
ed :2 0 2 :4 0
257 :2 0 c0 :2 0
47 :2 0 16b4 2678
267a :3 0 16b7 2674
267c 2671 267e 267d
:2 0 b1 :3 0 c1
:3 0 2680 2681 0
b3 :4 0 258 :4 0
b6 :2 0 b7 :3 0
16bb 2685 2687 :3 0
b6 :2 0 ca :4 0
16be 2689 268b :3 0
b6 :2 0 f0 :4 0
16c1 268d 268f :3 0
b6 :2 0 ea :3 0
16c4 2691 2693 :3 0
b6 :2 0 f1 :4 0
16c7 2695 2697 :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 16ca 269a
269e 16ce 2699 26a0
:3 0 16d1 2682 26a2
:2 0 26a4 16d4 26a5
267f 26a4 0 26a6
16d6 0 26a7 16d8
26aa :3 0 26aa 0
26aa 26a9 26a7 26a8
:6 0 26ac 42 :3 0
16db 26ae 16dd 26ad
26ac :2 0 26af 16df
:2 0 26b1 0 26b1
26b0 265e 26af :6 0
26b5 41 :3 0 259
:3 0 26b3 :4 0 26b5
16e2 2715 256 :3 0
96 :4 0 26b9 :2 0
26bf 26b7 0 21
:3 0 e9 :3 0 26ba
26bb 0 ea :3 0
26bc 26bd 0 26bf
16e5 2712 eb :3 0
21 :3 0 e9 :3 0
26c1 26c2 0 ea
:3 0 26c3 26c4 0
26c6 16e8 26c8 16ea
26c7 26c6 :2 0 2710
ec :3 0 21 :3 0
e9 :3 0 26cb 26cc
0 ea :3 0 26cd
26ce 0 2708 ae
:3 0 af :3 0 26d0
26d1 0 ae :3 0
be :3 0 26d3 26d4
0 ed :2 0 2
:4 0 25a :2 0 c0
:2 0 47 :2 0 16ec
26d9 26db :3 0 16ef
26d5 26dd 26d2 26df
26de :2 0 b1 :3 0
c1 :3 0 26e1 26e2
0 b3 :4 0 25b
:4 0 b6 :2 0 b7
:3 0 16f3 26e6 26e8
:3 0 b6 :2 0 ca
:4 0 16f6 26ea 26ec
:3 0 b6 :2 0 f0
:4 0 16f9 26ee 26f0
:3 0 b6 :2 0 ea
:3 0 16fc 26f2 26f4
:3 0 b6 :2 0 f1
:4 0 16ff 26f6 26f8
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 1702
26fb 26ff 1706 26fa
2701 :3 0 1709 26e3
2703 :2 0 2705 170c
2706 26e0 2705 0
2707 170e 0 2708
1710 270b :3 0 270b
0 270b 270a 2708
2709 :6 0 270d 44
:3 0 1713 270f 1715
270e 270d :2 0 2710
1717 :2 0 2712 0
2712 2711 26bf 2710
:6 0 2714 41 :3 0
171a 2716 2654 26b5
0 2717 0 2714
0 2717 171c 0
2718 171f 2719 262f
2718 0 271a 1724
0 2a8a 2e :3 0
16 :3 0 271b 271c
0 2a8a 30 :3 0
17 :3 0 271e 271f
0 2a8a a2 :3 0
50 :3 0 4e :2 0
1726 2721 2724 109
:2 0 4e :2 0 172b
2726 2728 :3 0 f2
:3 0 46 :3 0 47
:2 0 47 :2 0 172e
272a 272e d3 :2 0
47 :4 0 1734 2730
2732 :3 0 48 :3 0
198 :4 0 2735 2736
:3 0 2734 2737 0
273c 4f :3 0 4e
:2 0 2739 273a 0
273c 1737 2888 133
:3 0 a2 :3 0 50
:3 0 4e :2 0 173a
273e 2741 173d 273d
2743 c4 :2 0 4e
:2 0 1741 2745 2747
:3 0 25c :3 0 25d
:3 0 83 :3 0 98
:3 0 99 :3 0 25
:3 0 9b :3 0 39
:3 0 1a0 :4 0 25e
1 :8 0 2758 21
:3 0 e9 :3 0 2753
2754 0 ea :3 0
2755 2756 0 2758
1744 27ab eb :3 0
21 :3 0 e9 :3 0
275a 275b 0 ea
:3 0 275c 275d 0
275f 1747 2761 1749
2760 275f :2 0 27a9
ec :3 0 21 :3 0
e9 :3 0 2764 2765
0 ea :3 0 2766
2767 0 27a1 ae
:3 0 af :3 0 2769
276a 0 ae :3 0
be :3 0 276c 276d
0 ed :2 0 2
:4 0 25f :2 0 c0
:2 0 47 :2 0 174b
2772 2774 :3 0 174e
276e 2776 276b 2778
2777 :2 0 b1 :3 0
c1 :3 0 277a 277b
0 b3 :4 0 260
:4 0 b6 :2 0 b7
:3 0 1752 277f 2781
:3 0 b6 :2 0 ca
:4 0 1755 2783 2785
:3 0 b6 :2 0 f0
:4 0 1758 2787 2789
:3 0 b6 :2 0 ea
:3 0 175b 278b 278d
:3 0 b6 :2 0 f1
:4 0 175e 278f 2791
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 1761
2794 2798 1765 2793
279a :3 0 1768 277c
279c :2 0 279e 176b
279f 2779 279e 0
27a0 176d 0 27a1
176f 27a4 :3 0 27a4
0 27a4 27a3 27a1
27a2 :6 0 27a6 46
:3 0 1772 27a8 1774
27a7 27a6 :2 0 27a9
1776 :2 0 27ab 0
27ab 27aa 2758 27a9
:6 0 2884 41 :3 0
a2 :3 0 83 :3 0
4e :2 0 1779 27ad
27b0 109 :2 0 4e
:2 0 177e 27b2 27b4
:3 0 256 :3 0 94
:4 0 27b9 :2 0 27bf
27b7 0 21 :3 0
e9 :3 0 27ba 27bb
0 ea :3 0 27bc
27bd 0 27bf 1781
2812 eb :3 0 21
:3 0 e9 :3 0 27c1
27c2 0 ea :3 0
27c3 27c4 0 27c6
1784 27c8 1786 27c7
27c6 :2 0 2810 ec
:3 0 21 :3 0 e9
:3 0 27cb 27cc 0
ea :3 0 27cd 27ce
0 2808 ae :3 0
af :3 0 27d0 27d1
0 ae :3 0 be
:3 0 27d3 27d4 0
ed :2 0 2 :4 0
261 :2 0 c0 :2 0
47 :2 0 1788 27d9
27db :3 0 178b 27d5
27dd 27d2 27df 27de
:2 0 b1 :3 0 c1
:3 0 27e1 27e2 0
b3 :4 0 262 :4 0
b6 :2 0 b7 :3 0
178f 27e6 27e8 :3 0
b6 :2 0 ca :4 0
1792 27ea 27ec :3 0
b6 :2 0 f0 :4 0
1795 27ee 27f0 :3 0
b6 :2 0 ea :3 0
1798 27f2 27f4 :3 0
b6 :2 0 f1 :4 0
179b 27f6 27f8 :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 179e 27fb
27ff 17a2 27fa 2801
:3 0 17a5 27e3 2803
:2 0 2805 17a8 2806
27e0 2805 0 2807
17aa 0 2808 17ac
280b :3 0 280b 0
280b 280a 2808 2809
:6 0 280d 48 :3 0
17af 280f 17b1 280e
280d :2 0 2810 17b3
:2 0 2812 0 2812
2811 27bf 2810 :6 0
2881 41 :3 0 ae
:3 0 af :3 0 2814
2815 0 ae :3 0
be :3 0 2817 2818
0 24 :2 0 2
:4 0 263 :2 0 c0
:2 0 47 :2 0 17b6
281d 281f :3 0 17b9
2819 2821 2816 2823
2822 :2 0 b1 :3 0
c1 :3 0 2825 2826
0 b3 :4 0 264
:4 0 b6 :2 0 b7
:3 0 17bd 282a 282c
:3 0 b6 :2 0 ca
:4 0 17c0 282e 2830
:3 0 b6 :2 0 cb
:4 0 17c3 2832 2834
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 265 :3 0 2839
283a 0 17c6 2838
283c bc :4 0 17c8
2837 283f 17cb 2836
2841 :3 0 b6 :2 0
11a :4 0 17ce 2843
2845 :3 0 b6 :2 0
b9 :4 0 17d1 2847
2849 :3 0 b6 :2 0
39 :3 0 17d4 284b
284d :3 0 b6 :2 0
b9 :4 0 17d7 284f
2851 :3 0 17da 2827
2853 :2 0 2855 17dd
2856 2824 2855 0
2857 17df 0 2881
ae :3 0 af :3 0
2858 2859 0 ae
:3 0 be :3 0 285b
285c 0 47 :2 0
2 :4 0 266 :2 0
c0 :2 0 47 :2 0
17e1 2861 2863 :3 0
17e4 285d 2865 285a
2867 2866 :2 0 b1
:3 0 c1 :3 0 2869
286a 0 b3 :4 0
267 :4 0 b6 :2 0
b7 :3 0 17e8 286e
2870 :3 0 17eb 286b
2872 :2 0 2874 17ee
2875 2868 2874 0
2876 17f0 0 2881
cf :3 0 11d :3 0
2877 2878 0 c3
:3 0 265 :3 0 287a
287b 0 39 :3 0
d1 :3 0 17f2 2879
287f :2 0 2881 17f6
2882 27b5 2881 0
2883 17fb 0 2884
17fd 2885 2748 2884
0 2886 1800 0
2887 1802 2889 2733
273c 0 288a 0
2887 0 288a 1804
0 2a20 89 :3 0
268 :3 0 48 :3 0
25 :3 0 26 :3 0
39 :3 0 66 :3 0
50 :3 0 2e :3 0
30 :3 0 31 :3 0
32 :3 0 41 :3 0
42 :3 0 61 :3 0
59 :3 0 57 :3 0
5a :3 0 5b :3 0
55 :3 0 5c :3 0
46 :3 0 53 :3 0
4d :3 0 5d :3 0
58 :3 0 52 :3 0
5f :3 0 64 :3 0
29 :3 0 a2 :3 0
5f :3 0 4e :2 0
1807 28a9 28ac 4e
:2 0 68 :2 0 68
:2 0 4e :2 0 180a
288c 28b2 288b 28b3
0 2a20 89 :3 0
c4 :2 0 4e :2 0
182e 28b6 28b8 :3 0
256 :3 0 94 :4 0
28bd :2 0 28c3 28bb
0 21 :3 0 e9
:3 0 28be 28bf 0
ea :3 0 28c0 28c1
0 28c3 1831 2916
eb :3 0 21 :3 0
e9 :3 0 28c5 28c6
0 ea :3 0 28c7
28c8 0 28ca 1834
28cc 1836 28cb 28ca
:2 0 2914 ec :3 0
21 :3 0 e9 :3 0
28cf 28d0 0 ea
:3 0 28d1 28d2 0
290c ae :3 0 af
:3 0 28d4 28d5 0
ae :3 0 be :3 0
28d7 28d8 0 ed
:2 0 2 :4 0 269
:2 0 c0 :2 0 47
:2 0 1838 28dd 28df
:3 0 183b 28d9 28e1
28d6 28e3 28e2 :2 0
b1 :3 0 c1 :3 0
28e5 28e6 0 b3
:4 0 26a :4 0 b6
:2 0 b7 :3 0 183f
28ea 28ec :3 0 b6
:2 0 ca :4 0 1842
28ee 28f0 :3 0 b6
:2 0 f0 :4 0 1845
28f2 28f4 :3 0 b6
:2 0 ea :3 0 1848
28f6 28f8 :3 0 b6
:2 0 f1 :4 0 184b
28fa 28fc :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 184e 28ff 2903
1852 28fe 2905 :3 0
1855 28e7 2907 :2 0
2909 1858 290a 28e4
2909 0 290b 185a
0 290c 185c 290f
:3 0 290f 0 290f
290e 290c 290d :6 0
2911 4a :3 0 185f
2913 1861 2912 2911
:2 0 2914 1863 :2 0
2916 0 2916 2915
28c3 2914 :6 0 2991
41 :3 0 89 :3 0
c3 :3 0 f6 :2 0
26b :3 0 2919 291b
0 1868 291a 291d
:3 0 89 :3 0 c3
:3 0 26c :3 0 2920
2921 0 291f 2922
0 2924 186b 2925
291e 2924 0 2926
186d 0 2991 ae
:3 0 af :3 0 2927
2928 0 ae :3 0
be :3 0 292a 292b
0 24 :2 0 2
:4 0 26d :2 0 c0
:2 0 47 :2 0 186f
2930 2932 :3 0 1872
292c 2934 2929 2936
2935 :2 0 b1 :3 0
c1 :3 0 2938 2939
0 b3 :4 0 26e
:4 0 b6 :2 0 b7
:3 0 1876 293d 293f
:3 0 b6 :2 0 ca
:4 0 1879 2941 2943
:3 0 b6 :2 0 cb
:4 0 187c 2945 2947
:3 0 b6 :2 0 a2
:3 0 bb :3 0 89
:3 0 187f 294b 294d
bc :4 0 1881 294a
2950 1884 2949 2952
:3 0 b6 :2 0 11a
:4 0 1887 2954 2956
:3 0 b6 :2 0 b9
:4 0 188a 2958 295a
:3 0 b6 :2 0 48
:3 0 188d 295c 295e
:3 0 b6 :2 0 b9
:4 0 1890 2960 2962
:3 0 1893 293a 2964
:2 0 2966 1896 2967
2937 2966 0 2968
1898 0 2991 ae
:3 0 af :3 0 2969
296a 0 ae :3 0
be :3 0 296c 296d
0 47 :2 0 2
:4 0 26f :2 0 c0
:2 0 47 :2 0 189a
2972 2974 :3 0 189d
296e 2976 296b 2978
2977 :2 0 b1 :3 0
c1 :3 0 297a 297b
0 b3 :4 0 270
:4 0 b6 :2 0 b7
:3 0 18a1 297f 2981
:3 0 18a4 297c 2983
:2 0 2985 18a7 2986
2979 2985 0 2987
18a9 0 2991 cf
:3 0 11d :3 0 2988
2989 0 89 :3 0
48 :3 0 d1 :3 0
18ab 298a 298e :2 0
2991 d9 :3 0 18af
2a1c f2 :3 0 46
:3 0 47 :2 0 47
:2 0 18b5 2992 2996
d3 :2 0 47 :4 0
18bb 2998 299a :3 0
299b :2 0 f2 :3 0
4c :3 0 47 :2 0
47 :2 0 18be 299d
29a1 d3 :2 0 1b9
:4 0 18c4 29a3 29a5
:3 0 29a6 :2 0 299c
29a8 29a7 :2 0 199
:3 0 10f :3 0 19a
:3 0 39 :3 0 10f
:4 0 271 1 :8 0
29c5 1bf :4 0 29b0
:3 0 d1 :3 0 d3
:2 0 18c9 29b3 29b4
:3 0 21 :3 0 e9
:3 0 29b6 29b7 0
4e :2 0 29b8 29b9
0 29bb 18cc 29c2
21 :3 0 e9 :3 0
29bc 29bd 0 18b
:2 0 29be 29bf 0
29c1 18ce 29c3 29b5
29bb 0 29c4 0
29c1 0 29c4 18d0
0 29c5 18d3 2a18
eb :3 0 21 :3 0
e9 :3 0 29c7 29c8
0 ea :3 0 29c9
29ca 0 29cc 18d6
29ce 18d8 29cd 29cc
:2 0 2a16 ec :3 0
21 :3 0 e9 :3 0
29d1 29d2 0 ea
:3 0 29d3 29d4 0
2a0e ae :3 0 af
:3 0 29d6 29d7 0
ae :3 0 be :3 0
29d9 29da 0 ed
:2 0 2 :4 0 272
:2 0 c0 :2 0 47
:2 0 18da 29df 29e1
:3 0 18dd 29db 29e3
29d8 29e5 29e4 :2 0
b1 :3 0 c1 :3 0
29e7 29e8 0 b3
:4 0 273 :4 0 b6
:2 0 b7 :3 0 18e1
29ec 29ee :3 0 b6
:2 0 ca :4 0 18e4
29f0 29f2 :3 0 b6
:2 0 f0 :4 0 18e7
29f4 29f6 :3 0 b6
:2 0 ea :3 0 18ea
29f8 29fa :3 0 b6
:2 0 f1 :4 0 18ed
29fc 29fe :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 18f0 2a01 2a05
18f4 2a00 2a07 :3 0
18f7 29e9 2a09 :2 0
2a0b 18fa 2a0c 29e6
2a0b 0 2a0d 18fc
0 2a0e 18fe 2a11
:3 0 2a11 0 2a11
2a10 2a0e 2a0f :6 0
2a13 4c :3 0 1901
2a15 1903 2a14 2a13
:2 0 2a16 1905 :2 0
2a18 0 2a18 2a17
29c5 2a16 :6 0 2a1a
41 :3 0 1908 2a1b
29a9 2a1a 0 2a1d
28b9 2991 0 2a1d
190a 0 2a20 1fe
:8 0 2a20 190d 2a83
a2 :3 0 4d :3 0
4e :2 0 1912 2a21
2a24 c3 :3 0 c4
:2 0 c5 :3 0 2a26
2a28 0 1917 2a27
2a2a :3 0 41 :3 0
5 :3 0 2a2c 2a2d
0 2a32 42 :3 0
6 :3 0 2a2f 2a30
0 2a32 191a 2a33
2a2b 2a32 0 2a34
191d 0 2a82 89
:3 0 268 :3 0 48
:3 0 25 :3 0 26
:3 0 39 :3 0 66
:3 0 50 :3 0 2e
:3 0 30 :3 0 31
:3 0 32 :3 0 41
:3 0 42 :3 0 61
:3 0 59 :3 0 57
:3 0 5a :3 0 5b
:3 0 55 :3 0 5c
:3 0 46 :3 0 53
:3 0 4d :3 0 5d
:3 0 58 :3 0 52
:3 0 5f :3 0 64
:3 0 29 :3 0 4e
:2 0 4e :2 0 68
:2 0 68 :2 0 4e
:2 0 191f 2a36 2a58
2a35 2a59 0 2a82
89 :3 0 d3 :2 0
4e :2 0 1943 2a5c
2a5e :3 0 88 :3 0
88 :3 0 c0 :2 0
47 :2 0 1946 2a62
2a64 :3 0 2a60 2a65
0 2a68 d9 :3 0
1949 2a72 89 :3 0
f6 :2 0 4e :2 0
194d 2a6a 2a6c :3 0
1fe :8 0 2a70 1950
2a71 2a6d 2a70 0
2a73 2a5f 2a68 0
2a73 1952 0 2a82
88 :3 0 a2 :3 0
d3 :2 0 56 :3 0
4e :2 0 1955 2a75
2a79 195a 2a76 2a7b
:3 0 1fe :8 0 2a7f
195d 2a80 2a7c 2a7f
0 2a81 195f 0
2a82 1961 2a84 2729
2a20 0 2a85 0
2a82 0 2a85 1966
0 2a8a 259 :5 0
2a88 4e 0 2a89
1969 2a88 2a87 2a8a
196b 2a8c 1fa :4 0
2a8a :4 0 367b 256
:3 0 94 :4 0 2a90
:2 0 2a96 2a8e 0
21 :3 0 e9 :3 0
2a91 2a92 0 ea
:3 0 2a93 2a94 0
2a96 1974 2ae9 eb
:3 0 21 :3 0 e9
:3 0 2a98 2a99 0
ea :3 0 2a9a 2a9b
0 2a9d 1977 2a9f
1979 2a9e 2a9d :2 0
2ae7 ec :3 0 21
:3 0 e9 :3 0 2aa2
2aa3 0 ea :3 0
2aa4 2aa5 0 2adf
ae :3 0 af :3 0
2aa7 2aa8 0 ae
:3 0 be :3 0 2aaa
2aab 0 ed :2 0
2 :4 0 274 :2 0
c0 :2 0 47 :2 0
197b 2ab0 2ab2 :3 0
197e 2aac 2ab4 2aa9
2ab6 2ab5 :2 0 b1
:3 0 c1 :3 0 2ab8
2ab9 0 b3 :4 0
275 :4 0 b6 :2 0
b7 :3 0 1982 2abd
2abf :3 0 b6 :2 0
ca :4 0 1985 2ac1
2ac3 :3 0 b6 :2 0
f0 :4 0 1988 2ac5
2ac7 :3 0 b6 :2 0
ea :3 0 198b 2ac9
2acb :3 0 b6 :2 0
f1 :4 0 198e 2acd
2acf :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
1991 2ad2 2ad6 1995
2ad1 2ad8 :3 0 1998
2aba 2ada :2 0 2adc
199b 2add 2ab7 2adc
0 2ade 199d 0
2adf 199f 2ae2 :3 0
2ae2 0 2ae2 2ae1
2adf 2ae0 :6 0 2ae4
4e :3 0 19a2 2ae6
19a4 2ae5 2ae4 :2 0
2ae7 19a6 :2 0 2ae9
0 2ae9 2ae8 2a96
2ae7 :6 0 367b 1
:3 0 89 :3 0 c3
:3 0 d3 :2 0 276
:3 0 2aec 2aee 0
19ab 2aed 2af0 :3 0
2af1 :2 0 89 :3 0
f6 :2 0 4e :2 0
19b0 2af4 2af6 :3 0
2af7 :2 0 2af2 2af9
2af8 :2 0 89 :3 0
c4 :2 0 4e :2 0
19b5 2afc 2afe :3 0
a2 :3 0 50 :3 0
4e :2 0 19b8 2b00
2b03 109 :2 0 4e
:2 0 19bd 2b05 2b07
:3 0 2aff 2b09 2b08
:2 0 2b0a :2 0 2afa
2b0c 2b0b :2 0 ae
:3 0 af :3 0 2b0e
2b0f 0 ae :3 0
be :3 0 2b11 2b12
0 24 :2 0 2
:4 0 277 :2 0 c0
:2 0 47 :2 0 19c0
2b17 2b19 :3 0 19c3
2b13 2b1b 2b10 2b1d
2b1c :2 0 b1 :3 0
c1 :3 0 2b1f 2b20
0 b3 :4 0 278
:4 0 b6 :2 0 b7
:3 0 19c7 2b24 2b26
:3 0 b6 :2 0 ca
:4 0 19ca 2b28 2b2a
:3 0 b6 :2 0 cb
:4 0 19cd 2b2c 2b2e
:3 0 b6 :2 0 a2
:3 0 bb :3 0 89
:3 0 19d0 2b32 2b34
bc :4 0 19d2 2b31
2b37 19d5 2b30 2b39
:3 0 b6 :2 0 11a
:4 0 19d8 2b3b 2b3d
:3 0 b6 :2 0 b9
:4 0 19db 2b3f 2b41
:3 0 b6 :2 0 48
:3 0 19de 2b43 2b45
:3 0 b6 :2 0 b9
:4 0 19e1 2b47 2b49
:3 0 19e4 2b21 2b4b
:2 0 2b4d 19e7 2b4e
2b1e 2b4d 0 2b4f
19e9 0 2b77 ae
:3 0 af :3 0 2b50
2b51 0 ae :3 0
be :3 0 2b53 2b54
0 47 :2 0 2
:4 0 279 :2 0 c0
:2 0 47 :2 0 19eb
2b59 2b5b :3 0 19ee
2b55 2b5d 2b52 2b5f
2b5e :2 0 b1 :3 0
c1 :3 0 2b61 2b62
0 b3 :4 0 27a
:4 0 b6 :2 0 b7
:3 0 19f2 2b66 2b68
:3 0 19f5 2b63 2b6a
:2 0 2b6c 19f8 2b6d
2b60 2b6c 0 2b6e
19fa 0 2b77 cf
:3 0 11d :3 0 2b6f
2b70 0 89 :3 0
48 :3 0 d1 :3 0
19fc 2b71 2b75 :2 0
2b77 1a00 2b78 2b0d
2b77 0 2b79 1a04
0 367b 8c :3 0
c4 :2 0 47 :2 0
1a08 2b7b 2b7d :3 0
27 :3 0 27b :4 0
2b7f 2b80 0 2ec4
28 :3 0 18d :4 0
2b82 2b83 0 2ec4
3a :3 0 18d :4 0
2b85 2b86 0 2ec4
255 :3 0 9d :4 0
2b8b :2 0 2ec4 2b89
2b8c :3 0 86 :3 0
4e :2 0 2b8d 2b8e
0 2ec4 1fa :3 0
9d :3 0 26 :3 0
39 :3 0 49 :3 0
33 :3 0 4a :3 0
34 :3 0 35 :3 0
36 :4 0 2b9b :2 0
2de1 2b91 2b9c :3 0
1a0b :3 0 9d :3 0
1bf :3 0 2b9d 2b9e
:3 0 21 :3 0 e9
:3 0 2ba0 2ba1 0
4e :2 0 2ba2 2ba3
0 2ba5 1a14 2bac
21 :3 0 e9 :3 0
2ba6 2ba7 0 18b
:2 0 2ba8 2ba9 0
2bab 1a16 2bad 2b9f
2ba5 0 2bae 0
2bab 0 2bae 1a18
0 2de1 21 :3 0
e9 :3 0 2baf 2bb0
0 21 :3 0 c4
:2 0 f5 :3 0 2bb2
2bb4 0 1a1d 2bb3
2bb6 :3 0 2bb7 :2 0
1fe :8 0 2bbb 1a20
2bbc 2bb8 2bbb 0
2bbd 1a22 0 2de1
49 :3 0 e4 :2 0
1a24 2bbf 2bc0 :3 0
2bc1 :2 0 e5 :3 0
115 :3 0 2bc3 2bc4
0 49 :3 0 39
:3 0 1a26 2bc5 2bc8
d3 :2 0 4e :2 0
1a2b 2bca 2bcc :3 0
2bc2 2bce 2bcd :2 0
a2 :3 0 1f1 :3 0
27 :3 0 1a2e 2bd1
2bd3 4e :2 0 1a30
2bd0 2bd6 d3 :2 0
4e :2 0 1a35 2bd8
2bda :3 0 2bcf 2bdc
2bdb :2 0 27 :3 0
26 :3 0 2bde 2bdf
0 2be1 1a38 2be2
2bdd 2be1 0 2be3
1a3a 0 2de1 e5
:3 0 115 :3 0 2be4
2be5 0 28 :3 0
39 :3 0 1a3c 2be6
2be9 c4 :2 0 4e
:2 0 1a41 2beb 2bed
:3 0 86 :3 0 c4
:2 0 4e :2 0 1a46
2bf0 2bf2 :3 0 a8
:3 0 a1 :3 0 37
:3 0 a3 :3 0 2e
:3 0 a4 :3 0 38
:3 0 a5 :3 0 30
:3 0 a6 :3 0 31
:3 0 a7 :3 0 32
:3 0 9e :3 0 3a
:4 0 27c 1 :8 0
2c19 1bf :4 0 2c04
:3 0 d1 :3 0 d3
:2 0 1a4b 2c07 2c08
:3 0 21 :3 0 e9
:3 0 2c0a 2c0b 0
4e :2 0 2c0c 2c0d
0 2c0f 1a4e 2c16
21 :3 0 e9 :3 0
2c10 2c11 0 18b
:2 0 2c12 2c13 0
2c15 1a50 2c17 2c09
2c0f 0 2c18 0
2c15 0 2c18 1a52
0 2c19 1a55 2c6c
eb :3 0 21 :3 0
e9 :3 0 2c1b 2c1c
0 ea :3 0 2c1d
2c1e 0 2c20 1a58
2c22 1a5a 2c21 2c20
:2 0 2c6a ec :3 0
21 :3 0 e9 :3 0
2c25 2c26 0 ea
:3 0 2c27 2c28 0
2c62 ae :3 0 af
:3 0 2c2a 2c2b 0
ae :3 0 be :3 0
2c2d 2c2e 0 ed
:2 0 2 :4 0 27d
:2 0 c0 :2 0 47
:2 0 1a5c 2c33 2c35
:3 0 1a5f 2c2f 2c37
2c2c 2c39 2c38 :2 0
b1 :3 0 c1 :3 0
2c3b 2c3c 0 b3
:4 0 27e :4 0 b6
:2 0 b7 :3 0 1a63
2c40 2c42 :3 0 b6
:2 0 ca :4 0 1a66
2c44 2c46 :3 0 b6
:2 0 f0 :4 0 1a69
2c48 2c4a :3 0 b6
:2 0 ea :3 0 1a6c
2c4c 2c4e :3 0 b6
:2 0 f1 :4 0 1a6f
2c50 2c52 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 1a72 2c55 2c59
1a76 2c54 2c5b :3 0
1a79 2c3d 2c5d :2 0
2c5f 1a7c 2c60 2c3a
2c5f 0 2c61 1a7e
0 2c62 1a80 2c65
:3 0 2c65 0 2c65
2c64 2c62 2c63 :6 0
2c67 51 :3 0 1a83
2c69 1a85 2c68 2c67
:2 0 2c6a 1a87 :2 0
2c6c 0 2c6c 2c6b
2c19 2c6a :6 0 2c6e
50 :3 0 1a8a 2c6f
2bf3 2c6e 0 2c70
1a8c 0 2c89 2e
:3 0 18d :4 0 2c71
2c72 0 2c89 30
:3 0 18d :4 0 2c74
2c75 0 2c89 31
:3 0 18d :4 0 2c77
2c78 0 2c89 32
:3 0 18d :4 0 2c7a
2c7b 0 2c89 37
:3 0 18d :4 0 2c7d
2c7e 0 2c89 38
:3 0 18d :4 0 2c80
2c81 0 2c89 28
:3 0 39 :3 0 2c83
2c84 0 2c89 86
:3 0 4e :2 0 2c86
2c87 0 2c89 1a8e
2c8a 2bee 2c89 0
2c8b 1a98 0 2de1
86 :3 0 c4 :2 0
4e :2 0 1a9c 2c8d
2c8f :3 0 3a :3 0
e4 :2 0 1a9f 2c92
2c93 :3 0 2c94 :2 0
2c90 2c96 2c95 :2 0
a8 :3 0 a1 :3 0
a3 :3 0 a4 :3 0
a5 :3 0 a6 :3 0
a7 :3 0 9e :3 0
3a :4 0 27f 1
:8 0 2cb7 1bf :4 0
2ca2 :3 0 d1 :3 0
d3 :2 0 1aa3 2ca5
2ca6 :3 0 21 :3 0
e9 :3 0 2ca8 2ca9
0 4e :2 0 2caa
2cab 0 2cad 1aa6
2cb4 21 :3 0 e9
:3 0 2cae 2caf 0
18b :2 0 2cb0 2cb1
0 2cb3 1aa8 2cb5
2ca7 2cad 0 2cb6
0 2cb3 0 2cb6
1aaa 0 2cb7 1aad
2d0a eb :3 0 21
:3 0 e9 :3 0 2cb9
2cba 0 ea :3 0
2cbb 2cbc 0 2cbe
1ab0 2cc0 1ab2 2cbf
2cbe :2 0 2d08 ec
:3 0 21 :3 0 e9
:3 0 2cc3 2cc4 0
ea :3 0 2cc5 2cc6
0 2d00 ae :3 0
af :3 0 2cc8 2cc9
0 ae :3 0 be
:3 0 2ccb 2ccc 0
ed :2 0 2 :4 0
280 :2 0 c0 :2 0
47 :2 0 1ab4 2cd1
2cd3 :3 0 1ab7 2ccd
2cd5 2cca 2cd7 2cd6
:2 0 b1 :3 0 c1
:3 0 2cd9 2cda 0
b3 :4 0 281 :4 0
b6 :2 0 b7 :3 0
1abb 2cde 2ce0 :3 0
b6 :2 0 ca :4 0
1abe 2ce2 2ce4 :3 0
b6 :2 0 f0 :4 0
1ac1 2ce6 2ce8 :3 0
b6 :2 0 ea :3 0
1ac4 2cea 2cec :3 0
b6 :2 0 f1 :4 0
1ac7 2cee 2cf0 :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 1aca 2cf3
2cf7 1ace 2cf2 2cf9
:3 0 1ad1 2cdb 2cfb
:2 0 2cfd 1ad4 2cfe
2cd8 2cfd 0 2cff
1ad6 0 2d00 1ad8
2d03 :3 0 2d03 0
2d03 2d02 2d00 2d01
:6 0 2d05 53 :3 0
1adb 2d07 1add 2d06
2d05 :2 0 2d08 1adf
:2 0 2d0a 0 2d0a
2d09 2cb7 2d08 :6 0
2d0c 50 :3 0 1ae2
2d0d 2c97 2d0c 0
2d0e 1ae4 0 2de1
33 :3 0 e4 :2 0
1ae6 2d10 2d11 :3 0
2d12 :2 0 2e :3 0
e4 :2 0 1ae8 2d15
2d16 :3 0 2d17 :2 0
2e :3 0 f2 :3 0
2e :3 0 b6 :2 0
282 :4 0 1aea 2d1c
2d1e :3 0 47 :2 0
2f :2 0 1aed 2d1a
2d22 2d19 2d23 0
2d25 1af1 2d26 2d18
2d25 0 2d27 1af3
0 2d34 2e :3 0
f2 :3 0 2e :3 0
b6 :2 0 33 :3 0
1af5 2d2b 2d2d :3 0
47 :2 0 2f :2 0
1af8 2d29 2d31 2d28
2d32 0 2d34 1afc
2d35 2d13 2d34 0
2d36 1aff 0 2de1
49 :3 0 e4 :2 0
1b01 2d38 2d39 :3 0
2d3a :2 0 37 :3 0
f2 :3 0 37 :3 0
b6 :2 0 49 :3 0
1b03 2d3f 2d41 :3 0
47 :2 0 2f :2 0
1b06 2d3d 2d45 2d3c
2d46 0 2d48 1b0a
2d49 2d3b 2d48 0
2d4a 1b0c 0 2de1
34 :3 0 e4 :2 0
1b0e 2d4c 2d4d :3 0
2d4e :2 0 30 :3 0
e4 :2 0 1b10 2d51
2d52 :3 0 2d53 :2 0
30 :3 0 f2 :3 0
30 :3 0 b6 :2 0
282 :4 0 1b12 2d58
2d5a :3 0 47 :2 0
2f :2 0 1b15 2d56
2d5e 2d55 2d5f 0
2d61 1b19 2d62 2d54
2d61 0 2d63 1b1b
0 2d70 30 :3 0
f2 :3 0 30 :3 0
b6 :2 0 34 :3 0
1b1d 2d67 2d69 :3 0
47 :2 0 2f :2 0
1b20 2d65 2d6d 2d64
2d6e 0 2d70 1b24
2d71 2d4f 2d70 0
2d72 1b27 0 2de1
4a :3 0 e4 :2 0
1b29 2d74 2d75 :3 0
2d76 :2 0 38 :3 0
f2 :3 0 38 :3 0
b6 :2 0 4a :3 0
1b2b 2d7b 2d7d :3 0
47 :2 0 2f :2 0
1b2e 2d79 2d81 2d78
2d82 0 2d84 1b32
2d85 2d77 2d84 0
2d86 1b34 0 2de1
35 :3 0 e4 :2 0
1b36 2d88 2d89 :3 0
2d8a :2 0 31 :3 0
e4 :2 0 1b38 2d8d
2d8e :3 0 2d8f :2 0
31 :3 0 f2 :3 0
31 :3 0 b6 :2 0
282 :4 0 1b3a 2d94
2d96 :3 0 47 :2 0
2f :2 0 1b3d 2d92
2d9a 2d91 2d9b 0
2d9d 1b41 2d9e 2d90
2d9d 0 2d9f 1b43
0 2dac 31 :3 0
f2 :3 0 31 :3 0
b6 :2 0 35 :3 0
1b45 2da3 2da5 :3 0
47 :2 0 2f :2 0
1b48 2da1 2da9 2da0
2daa 0 2dac 1b4c
2dad 2d8b 2dac 0
2dae 1b4f 0 2de1
36 :3 0 e4 :2 0
1b51 2db0 2db1 :3 0
2db2 :2 0 32 :3 0
e4 :2 0 1b53 2db5
2db6 :3 0 2db7 :2 0
32 :3 0 f2 :3 0
32 :3 0 b6 :2 0
282 :4 0 1b55 2dbc
2dbe :3 0 47 :2 0
2f :2 0 1b58 2dba
2dc2 2db9 2dc3 0
2dc5 1b5c 2dc6 2db8
2dc5 0 2dc7 1b5e
0 2dd4 32 :3 0
f2 :3 0 32 :3 0
b6 :2 0 36 :3 0
1b60 2dcb 2dcd :3 0
47 :2 0 2f :2 0
1b63 2dc9 2dd1 2dc8
2dd2 0 2dd4 1b67
2dd5 2db3 2dd4 0
2dd6 1b6a 0 2de1
86 :3 0 86 :3 0
c0 :2 0 47 :2 0
1b6c 2dd9 2ddb :3 0
2dd7 2ddc 0 2de1
3a :3 0 26 :3 0
2dde 2ddf 0 2de1
1b6f 2de3 1fa :4 0
2de1 :4 0 2ec4 256
:3 0 9d :4 0 2de7
:2 0 2ded 2de5 0
21 :3 0 e9 :3 0
2de8 2de9 0 ea
:3 0 2dea 2deb 0
2ded 1b7e 2e40 eb
:3 0 21 :3 0 e9
:3 0 2def 2df0 0
ea :3 0 2df1 2df2
0 2df4 1b81 2df6
1b83 2df5 2df4 :2 0
2e3e ec :3 0 21
:3 0 e9 :3 0 2df9
2dfa 0 ea :3 0
2dfb 2dfc 0 2e36
ae :3 0 af :3 0
2dfe 2dff 0 ae
:3 0 be :3 0 2e01
2e02 0 ed :2 0
2 :4 0 283 :2 0
c0 :2 0 47 :2 0
1b85 2e07 2e09 :3 0
1b88 2e03 2e0b 2e00
2e0d 2e0c :2 0 b1
:3 0 c1 :3 0 2e0f
2e10 0 b3 :4 0
284 :4 0 b6 :2 0
b7 :3 0 1b8c 2e14
2e16 :3 0 b6 :2 0
ca :4 0 1b8f 2e18
2e1a :3 0 b6 :2 0
f0 :4 0 1b92 2e1c
2e1e :3 0 b6 :2 0
ea :3 0 1b95 2e20
2e22 :3 0 b6 :2 0
f1 :4 0 1b98 2e24
2e26 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
1b9b 2e29 2e2d 1b9f
2e28 2e2f :3 0 1ba2
2e11 2e31 :2 0 2e33
1ba5 2e34 2e0e 2e33
0 2e35 1ba7 0
2e36 1ba9 2e39 :3 0
2e39 0 2e39 2e38
2e36 2e37 :6 0 2e3b
55 :3 0 1bac 2e3d
1bae 2e3c 2e3b :2 0
2e3e 1bb0 :2 0 2e40
0 2e40 2e3f 2ded
2e3e :6 0 2ec4 1
:3 0 86 :3 0 c4
:2 0 4e :2 0 1bb5
2e43 2e45 :3 0 a8
:3 0 a1 :3 0 37
:3 0 a3 :3 0 2e
:3 0 a4 :3 0 38
:3 0 a5 :3 0 30
:3 0 a6 :3 0 31
:3 0 a7 :3 0 32
:3 0 9e :3 0 3a
:4 0 285 1 :8 0
2e6c 1bf :4 0 2e57
:3 0 d1 :3 0 d3
:2 0 1bba 2e5a 2e5b
:3 0 21 :3 0 e9
:3 0 2e5d 2e5e 0
4e :2 0 2e5f 2e60
0 2e62 1bbd 2e69
21 :3 0 e9 :3 0
2e63 2e64 0 18b
:2 0 2e65 2e66 0
2e68 1bbf 2e6a 2e5c
2e62 0 2e6b 0
2e68 0 2e6b 1bc1
0 2e6c 1bc4 2ebf
eb :3 0 21 :3 0
e9 :3 0 2e6e 2e6f
0 ea :3 0 2e70
2e71 0 2e73 1bc7
2e75 1bc9 2e74 2e73
:2 0 2ebd ec :3 0
21 :3 0 e9 :3 0
2e78 2e79 0 ea
:3 0 2e7a 2e7b 0
2eb5 ae :3 0 af
:3 0 2e7d 2e7e 0
ae :3 0 be :3 0
2e80 2e81 0 ed
:2 0 2 :4 0 286
:2 0 c0 :2 0 47
:2 0 1bcb 2e86 2e88
:3 0 1bce 2e82 2e8a
2e7f 2e8c 2e8b :2 0
b1 :3 0 c1 :3 0
2e8e 2e8f 0 b3
:4 0 287 :4 0 b6
:2 0 b7 :3 0 1bd2
2e93 2e95 :3 0 b6
:2 0 ca :4 0 1bd5
2e97 2e99 :3 0 b6
:2 0 f0 :4 0 1bd8
2e9b 2e9d :3 0 b6
:2 0 ea :3 0 1bdb
2e9f 2ea1 :3 0 b6
:2 0 f1 :4 0 1bde
2ea3 2ea5 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 1be1 2ea8 2eac
1be5 2ea7 2eae :3 0
1be8 2e90 2eb0 :2 0
2eb2 1beb 2eb3 2e8d
2eb2 0 2eb4 1bed
0 2eb5 1bef 2eb8
:3 0 2eb8 0 2eb8
2eb7 2eb5 2eb6 :6 0
2eba 57 :3 0 1bf2
2ebc 1bf4 2ebb 2eba
:2 0 2ebd 1bf6 :2 0
2ebf 0 2ebf 2ebe
2e6c 2ebd :6 0 2ec1
1 :3 0 1bf9 2ec2
2e46 2ec1 0 2ec3
1bfb 0 2ec4 1bfd
2ec5 2b7e 2ec4 0
2ec6 1c06 0 367b
6 :3 0 e4 :2 0
1c08 2ec8 2ec9 :3 0
2eca :2 0 a2 :3 0
57 :3 0 4e :2 0
1c0a 2ecc 2ecf d3
:2 0 4e :2 0 1c0f
2ed1 2ed3 :3 0 a2
:3 0 288 :3 0 289
:3 0 59 :3 0 28a
:3 0 111 :3 0 25
:3 0 28b :3 0 176
:3 0 f2 :3 0 41
:3 0 176 :3 0 f2
:3 0 42 :4 0 28c
1 :8 0 2ee9 21
:3 0 e9 :3 0 2ee4
2ee5 0 ea :3 0
2ee6 2ee7 0 2ee9
1c12 2f3c eb :3 0
21 :3 0 e9 :3 0
2eeb 2eec 0 ea
:3 0 2eed 2eee 0
2ef0 1c15 2ef2 1c17
2ef1 2ef0 :2 0 2f3a
ec :3 0 21 :3 0
e9 :3 0 2ef5 2ef6
0 ea :3 0 2ef7
2ef8 0 2f32 ae
:3 0 af :3 0 2efa
2efb 0 ae :3 0
be :3 0 2efd 2efe
0 ed :2 0 2
:4 0 28d :2 0 c0
:2 0 47 :2 0 1c19
2f03 2f05 :3 0 1c1c
2eff 2f07 2efc 2f09
2f08 :2 0 b1 :3 0
c1 :3 0 2f0b 2f0c
0 b3 :4 0 28e
:4 0 b6 :2 0 b7
:3 0 1c20 2f10 2f12
:3 0 b6 :2 0 ca
:4 0 1c23 2f14 2f16
:3 0 b6 :2 0 f0
:4 0 1c26 2f18 2f1a
:3 0 b6 :2 0 ea
:3 0 1c29 2f1c 2f1e
:3 0 b6 :2 0 f1
:4 0 1c2c 2f20 2f22
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 1c2f
2f25 2f29 1c33 2f24
2f2b :3 0 1c36 2f0d
2f2d :2 0 2f2f 1c39
2f30 2f0a 2f2f 0
2f31 1c3b 0 2f32
1c3d 2f35 :3 0 2f35
0 2f35 2f34 2f32
2f33 :6 0 2f37 59
:3 0 1c40 2f39 1c42
2f38 2f37 :2 0 2f3a
1c44 :2 0 2f3c 0
2f3c 2f3b 2ee9 2f3a
:6 0 2f3e 1 :3 0
1c47 2f44 61 :3 0
4e :2 0 2f3f 2f40
0 2f43 0 2f43
1c49 2f45 2ed4 2f3e
0 2f46 0 2f43
0 2f46 1c4c 0
2f47 1c4f 2f48 2ecb
2f47 0 2f49 1c51
0 367b 28f :3 0
e5 :3 0 290 :3 0
291 :3 0 1ad :3 0
6c :3 0 69 :3 0
110 :3 0 292 :3 0
1e9 :3 0 293 :3 0
291 :3 0 292 :3 0
28f :3 0 291 :3 0
111 :3 0 292 :3 0
111 :3 0 25 :4 0
294 1 :8 0 2f63
21 :3 0 e9 :3 0
2f5e 2f5f 0 ea
:3 0 2f60 2f61 0
2f63 1c53 2fb6 eb
:3 0 21 :3 0 e9
:3 0 2f65 2f66 0
ea :3 0 2f67 2f68
0 2f6a 1c56 2f6c
1c58 2f6b 2f6a :2 0
2fb4 ec :3 0 21
:3 0 e9 :3 0 2f6f
2f70 0 ea :3 0
2f71 2f72 0 2fac
ae :3 0 af :3 0
2f74 2f75 0 ae
:3 0 be :3 0 2f77
2f78 0 ed :2 0
2 :4 0 295 :2 0
c0 :2 0 47 :2 0
1c5a 2f7d 2f7f :3 0
1c5d 2f79 2f81 2f76
2f83 2f82 :2 0 b1
:3 0 c1 :3 0 2f85
2f86 0 b3 :4 0
296 :4 0 b6 :2 0
b7 :3 0 1c61 2f8a
2f8c :3 0 b6 :2 0
ca :4 0 1c64 2f8e
2f90 :3 0 b6 :2 0
f0 :4 0 1c67 2f92
2f94 :3 0 b6 :2 0
ea :3 0 1c6a 2f96
2f98 :3 0 b6 :2 0
f1 :4 0 1c6d 2f9a
2f9c :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
1c70 2f9f 2fa3 1c74
2f9e 2fa5 :3 0 1c77
2f87 2fa7 :2 0 2fa9
1c7a 2faa 2f84 2fa9
0 2fab 1c7c 0
2fac 1c7e 2faf :3 0
2faf 0 2faf 2fae
2fac 2fad :6 0 2fb1
5b :3 0 1c81 2fb3
1c83 2fb2 2fb1 :2 0
2fb4 1c85 :2 0 2fb6
0 2fb6 2fb5 2f63
2fb4 :6 0 367b 1
:3 0 a2 :3 0 5c
:3 0 4e :2 0 1c88
2fb8 2fbb c3 :3 0
d3 :2 0 d4 :3 0
2fbd 2fbf 0 1c8d
2fbe 2fc1 :3 0 1e1
:3 0 1e2 :3 0 297
:4 0 2fc5 :4 0 2fc6
:2 0 323d 21 :3 0
e9 :3 0 2fc8 2fc9
0 4e :2 0 2fca
2fcb 0 323d 298
:3 0 9f :3 0 299
:3 0 29a :3 0 29b
:3 0 29c :3 0 a8
:3 0 9e :3 0 27
:3 0 299 :3 0 29a
:4 0 29d 1 :8 0
2fee 1bf :4 0 2fd9
:3 0 d1 :3 0 d3
:2 0 1c92 2fdc 2fdd
:3 0 21 :3 0 e9
:3 0 2fdf 2fe0 0
4e :2 0 2fe1 2fe2
0 2fe4 1c95 2feb
21 :3 0 e9 :3 0
2fe5 2fe6 0 18b
:2 0 2fe7 2fe8 0
2fea 1c97 2fec 2fde
2fe4 0 2fed 0
2fea 0 2fed 1c99
0 2fee 1c9c 3041
eb :3 0 21 :3 0
e9 :3 0 2ff0 2ff1
0 ea :3 0 2ff2
2ff3 0 2ff5 1c9f
2ff7 1ca1 2ff6 2ff5
:2 0 303f ec :3 0
21 :3 0 e9 :3 0
2ffa 2ffb 0 ea
:3 0 2ffc 2ffd 0
3037 ae :3 0 af
:3 0 2fff 3000 0
ae :3 0 be :3 0
3002 3003 0 ed
:2 0 2 :4 0 29e
:2 0 c0 :2 0 47
:2 0 1ca3 3008 300a
:3 0 1ca6 3004 300c
3001 300e 300d :2 0
b1 :3 0 c1 :3 0
3010 3011 0 b3
:4 0 29f :4 0 b6
:2 0 b7 :3 0 1caa
3015 3017 :3 0 b6
:2 0 ca :4 0 1cad
3019 301b :3 0 b6
:2 0 f0 :4 0 1cb0
301d 301f :3 0 b6
:2 0 ea :3 0 1cb3
3021 3023 :3 0 b6
:2 0 f1 :4 0 1cb6
3025 3027 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 1cb9 302a 302e
1cbd 3029 3030 :3 0
1cc0 3012 3032 :2 0
3034 1cc3 3035 300f
3034 0 3036 1cc5
0 3037 1cc7 303a
:3 0 303a 0 303a
3039 3037 3038 :6 0
303c 5d :3 0 1cca
303e 1ccc 303d 303c
:2 0 303f 1cce :2 0
3041 0 3041 3040
2fee 303f :6 0 323d
1 :3 0 21 :3 0
e9 :3 0 3043 3044
0 21 :3 0 d3
:2 0 16b :3 0 3046
3048 0 1cd3 3047
304a :3 0 304b :2 0
298 :3 0 9f :3 0
1a6 :3 0 299 :3 0
299 :3 0 1a6 :3 0
29a :3 0 29a :3 0
1a6 :3 0 29b :3 0
29b :3 0 1a6 :3 0
29c :3 0 29c :3 0
a8 :3 0 9e :3 0
27 :3 0 9f :4 0
2a0 1 :8 0 3075
1bf :4 0 3060 :3 0
d1 :3 0 d3 :2 0
1cd8 3063 3064 :3 0
21 :3 0 e9 :3 0
3066 3067 0 4e
:2 0 3068 3069 0
306b 1cdb 3072 21
:3 0 e9 :3 0 306c
306d 0 18b :2 0
306e 306f 0 3071
1cdd 3073 3065 306b
0 3074 0 3071
0 3074 1cdf 0
3075 1ce2 30c8 eb
:3 0 21 :3 0 e9
:3 0 3077 3078 0
ea :3 0 3079 307a
0 307c 1ce5 307e
1ce7 307d 307c :2 0
30c6 ec :3 0 21
:3 0 e9 :3 0 3081
3082 0 ea :3 0
3083 3084 0 30be
ae :3 0 af :3 0
3086 3087 0 ae
:3 0 be :3 0 3089
308a 0 ed :2 0
2 :4 0 2a1 :2 0
c0 :2 0 47 :2 0
1ce9 308f 3091 :3 0
1cec 308b 3093 3088
3095 3094 :2 0 b1
:3 0 c1 :3 0 3097
3098 0 b3 :4 0
2a2 :4 0 b6 :2 0
b7 :3 0 1cf0 309c
309e :3 0 b6 :2 0
ca :4 0 1cf3 30a0
30a2 :3 0 b6 :2 0
f0 :4 0 1cf6 30a4
30a6 :3 0 b6 :2 0
ea :3 0 1cf9 30a8
30aa :3 0 b6 :2 0
f1 :4 0 1cfc 30ac
30ae :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
1cff 30b1 30b5 1d03
30b0 30b7 :3 0 1d06
3099 30b9 :2 0 30bb
1d09 30bc 3096 30bb
0 30bd 1d0b 0
30be 1d0d 30c1 :3 0
30c1 0 30c1 30c0
30be 30bf :6 0 30c3
5f :3 0 1d10 30c5
1d12 30c4 30c3 :2 0
30c6 1d14 :2 0 30c8
0 30c8 30c7 3075
30c6 :6 0 3148 1
:3 0 21 :3 0 e9
:3 0 30ca 30cb 0
21 :3 0 d3 :2 0
16b :3 0 30cd 30cf
0 1d19 30ce 30d1
:3 0 30d2 :2 0 298
:3 0 9f :3 0 a8
:3 0 9e :3 0 27
:3 0 9f :4 0 2a3
1 :8 0 30f0 1bf
:4 0 30db :3 0 d1
:3 0 d3 :2 0 1d1e
30de 30df :3 0 21
:3 0 e9 :3 0 30e1
30e2 0 4e :2 0
30e3 30e4 0 30e6
1d21 30ed 21 :3 0
e9 :3 0 30e7 30e8
0 18b :2 0 30e9
30ea 0 30ec 1d23
30ee 30e0 30e6 0
30ef 0 30ec 0
30ef 1d25 0 30f0
1d28 3143 eb :3 0
21 :3 0 e9 :3 0
30f2 30f3 0 ea
:3 0 30f4 30f5 0
30f7 1d2b 30f9 1d2d
30f8 30f7 :2 0 3141
ec :3 0 21 :3 0
e9 :3 0 30fc 30fd
0 ea :3 0 30fe
30ff 0 3139 ae
:3 0 af :3 0 3101
3102 0 ae :3 0
be :3 0 3104 3105
0 ed :2 0 2
:4 0 2a4 :2 0 c0
:2 0 47 :2 0 1d2f
310a 310c :3 0 1d32
3106 310e 3103 3110
310f :2 0 b1 :3 0
c1 :3 0 3112 3113
0 b3 :4 0 2a5
:4 0 b6 :2 0 b7
:3 0 1d36 3117 3119
:3 0 b6 :2 0 ca
:4 0 1d39 311b 311d
:3 0 b6 :2 0 f0
:4 0 1d3c 311f 3121
:3 0 b6 :2 0 ea
:3 0 1d3f 3123 3125
:3 0 b6 :2 0 f1
:4 0 1d42 3127 3129
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 1d45
312c 3130 1d49 312b
3132 :3 0 1d4c 3114
3134 :2 0 3136 1d4f
3137 3111 3136 0
3138 1d51 0 3139
1d53 313c :3 0 313c
0 313c 313b 3139
313a :6 0 313e 61
:3 0 1d56 3140 1d58
313f 313e :2 0 3141
1d5a :2 0 3143 0
3143 3142 30f0 3141
:6 0 3145 1 :3 0
1d5d 3146 30d3 3145
0 3147 1d5f 0
3148 1d61 3149 304c
3148 0 314a 1d64
0 323d 255 :3 0
aa :3 0 39 :3 0
111 :3 0 14a :3 0
1e8 :3 0 1ba :3 0
1ad :3 0 2a6 :3 0
a3 :3 0 2a6 :3 0
a5 :3 0 2a6 :3 0
a6 :3 0 2a6 :3 0
a7 :3 0 54 :3 0
2a7 :3 0 2a8 :3 0
1ad :3 0 2a9 :3 0
2aa :3 0 1ad :3 0
2ab :3 0 2ac :3 0
2ad :3 0 299 :3 0
2ad :3 0 299 :3 0
2a6 :3 0 2ae :3 0
2af :3 0 299 :3 0
69 :3 0 13e :3 0
299 :3 0 69 :3 0
299 :3 0 2ac :3 0
2ad :3 0 2b0 :3 0
2ad :3 0 2b0 :3 0
2a6 :3 0 2ae :3 0
2af :3 0 29a :3 0
69 :3 0 13e :3 0
29a :3 0 69 :3 0
29a :3 0 2ac :3 0
2ad :3 0 29b :3 0
2ad :3 0 29b :3 0
2a6 :3 0 2ae :3 0
2af :3 0 29b :3 0
69 :3 0 13e :3 0
29b :3 0 69 :3 0
29b :3 0 2ac :3 0
2ad :3 0 2b1 :3 0
2ad :3 0 2b1 :3 0
2a6 :3 0 2ae :3 0
2af :3 0 29c :3 0
69 :3 0 13e :3 0
29c :3 0 69 :3 0
29c :3 0 2a6 :3 0
2b2 :3 0 2a6 :3 0
2b3 :3 0 2a6 :3 0
2b4 :3 0 2a6 :3 0
2b5 :3 0 2a6 :3 0
2b6 :3 0 2a6 :3 0
2b7 :3 0 2a6 :3 0
2b7 :3 0 59 :3 0
2b8 :3 0 5a :3 0
2b9 :3 0 2a6 :3 0
2b4 :3 0 2a6 :3 0
2b5 :3 0 2a6 :3 0
2b6 :3 0 2ba :3 0
2bb :3 0 2bc :3 0
2bd :3 0 2be :3 0
1ad :3 0 2bf :3 0
2c0 :3 0 2c1 :3 0
5f :3 0 134 :3 0
2a6 :3 0 2c2 :3 0
2c3 :3 0 2e :3 0
a1 :3 0 30 :3 0
a4 :3 0 2c4 :3 0
2c5 :3 0 155 :3 0
2c6 :3 0 2c7 :3 0
298 :3 0 2af :3 0
1e9 :3 0 a8 :3 0
2a6 :3 0 2a6 :3 0
9f :3 0 2af :3 0
9f :3 0 2c8 :3 0
2c9 :3 0 1e9 :3 0
2ca :3 0 2ad :3 0
2ad :3 0 99 :3 0
25 :3 0 2ad :3 0
9b :3 0 2a6 :3 0
9f :3 0 1e9 :3 0
199 :3 0 1e8 :3 0
1e8 :3 0 19a :3 0
39 :3 0 1e9 :3 0
1af :3 0 2cb :3 0
1e8 :3 0 a1 :3 0
2cb :3 0 111 :3 0
2c8 :3 0 2c9 :3 0
1e9 :3 0 2cc :3 0
13e :3 0 2cb :3 0
2cd :3 0 13e :3 0
2cd :3 0 2c8 :3 0
2c9 :3 0 1e9 :3 0
226 :3 0 2a8 :3 0
1e8 :3 0 1bd :3 0
2a8 :3 0 111 :3 0
2c8 :3 0 2c9 :3 0
1e9 :3 0 231 :3 0
2aa :3 0 1e8 :3 0
1bc :3 0 2aa :3 0
111 :3 0 2c8 :3 0
2c9 :3 0 1e9 :3 0
183 :3 0 2be :3 0
2be :3 0 111 :3 0
1e8 :3 0 1bb :3 0
2a6 :3 0 a3 :3 0
2a6 :3 0 a5 :3 0
2a6 :3 0 a6 :3 0
2a6 :3 0 a7 :4 0
2ce 1 :a 0 321a
:2 0 323d 314c 3218
:2 0 ae :3 0 af
:3 0 321b 321c 0
ae :3 0 be :3 0
321e 321f 0 47
:2 0 2 :4 0 2cf
:2 0 c0 :2 0 47
:2 0 1d66 3224 3226
:3 0 1d69 3220 3228
321d 322a 3229 :2 0
b1 :3 0 c1 :3 0
322c 322d 0 b3
:4 0 2d0 :4 0 b6
:2 0 b7 :3 0 1d6d
3231 3233 :3 0 1d70
322e 3235 :2 0 3237
1d73 3238 322b 3237
0 3239 1d75 0
323d 20 :3 0 aa
:3 0 323b :2 0 323d
1d77 3678 8c :3 0
d3 :2 0 47 :2 0
1d81 323f 3241 :3 0
255 :3 0 ab :3 0
2a6 :3 0 9f :3 0
111 :3 0 14a :3 0
2cb :3 0 2bd :3 0
1ad :3 0 2a6 :3 0
a3 :3 0 2a6 :3 0
a5 :3 0 2a6 :3 0
a6 :3 0 2a6 :3 0
a7 :3 0 2cb :3 0
2a7 :3 0 2d1 :3 0
1ad :3 0 2a9 :3 0
2d2 :3 0 1ad :3 0
2ab :3 0 2ac :3 0
2a6 :3 0 2d3 :3 0
2a6 :3 0 299 :3 0
2cb :3 0 28f :3 0
6c :3 0 2cb :3 0
28f :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 2cb :3 0
28f :3 0 2a6 :3 0
2d3 :3 0 2a6 :3 0
299 :3 0 2a6 :3 0
299 :3 0 69 :3 0
299 :3 0 2ac :3 0
2a6 :3 0 2d3 :3 0
2a6 :3 0 29a :3 0
2cb :3 0 28f :3 0
6c :3 0 2cb :3 0
28f :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 2cb :3 0
28f :3 0 2a6 :3 0
2d3 :3 0 2a6 :3 0
29a :3 0 2a6 :3 0
29a :3 0 69 :3 0
29a :3 0 2ac :3 0
2a6 :3 0 2d3 :3 0
2a6 :3 0 29b :3 0
2cb :3 0 28f :3 0
6c :3 0 2cb :3 0
28f :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 2cb :3 0
28f :3 0 2a6 :3 0
2d3 :3 0 2a6 :3 0
29b :3 0 2a6 :3 0
29b :3 0 69 :3 0
29b :3 0 2ac :3 0
2a6 :3 0 2d3 :3 0
2a6 :3 0 29c :3 0
2cb :3 0 28f :3 0
6c :3 0 2cb :3 0
28f :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 2cb :3 0
28f :3 0 2a6 :3 0
2d3 :3 0 2a6 :3 0
29c :3 0 2a6 :3 0
29c :3 0 69 :3 0
29c :3 0 2a6 :3 0
2b2 :3 0 2a6 :3 0
2b3 :3 0 2a6 :3 0
2b4 :3 0 2a6 :3 0
2b5 :3 0 2a6 :3 0
2b6 :3 0 2a6 :3 0
2b7 :3 0 2a6 :3 0
2b7 :3 0 59 :3 0
2b8 :3 0 5a :3 0
2b9 :3 0 2a6 :3 0
2b4 :3 0 2a6 :3 0
2b5 :3 0 2a6 :3 0
2b6 :3 0 2ba :3 0
2d4 :3 0 2bd :3 0
2bb :3 0 2cb :3 0
2bc :3 0 2be :3 0
1ad :3 0 2bf :3 0
2d5 :3 0 2bd :3 0
2d5 :3 0 2c0 :3 0
2c1 :3 0 5f :3 0
134 :3 0 2a6 :3 0
2c2 :3 0 2c3 :3 0
2a6 :3 0 a1 :3 0
2a6 :3 0 a4 :3 0
a2 :3 0 2ad :3 0
2d6 :3 0 2ad :3 0
2d7 :3 0 2c4 :3 0
2cb :3 0 2c5 :3 0
2cb :3 0 2d8 :3 0
2c6 :3 0 2cb :3 0
2c7 :3 0 a8 :3 0
2a6 :3 0 1e9 :3 0
183 :3 0 1e8 :3 0
2a6 :3 0 9f :3 0
1e8 :3 0 111 :3 0
1e9 :3 0 183 :3 0
2be :3 0 2be :3 0
111 :3 0 1e8 :3 0
1b0 :3 0 2c8 :3 0
2c9 :3 0 1e9 :3 0
167 :3 0 2d5 :3 0
2be :3 0 2d9 :3 0
2d5 :3 0 9b :3 0
1e9 :3 0 167 :3 0
2cb :3 0 2a6 :3 0
9f :3 0 2cb :3 0
9b :3 0 2c8 :3 0
2c9 :3 0 1e9 :3 0
167 :3 0 2d4 :3 0
2d4 :3 0 9b :3 0
2cb :3 0 2da :3 0
2c8 :3 0 2c9 :3 0
1e9 :3 0 2ca :3 0
2ad :3 0 2ad :3 0
99 :3 0 25 :3 0
2ad :3 0 9b :3 0
2a6 :3 0 9f :3 0
2c8 :3 0 2c9 :3 0
1e9 :3 0 226 :3 0
2a8 :3 0 2cb :3 0
9b :3 0 2a8 :3 0
111 :3 0 2c8 :3 0
2c9 :3 0 1e9 :3 0
226 :3 0 2d1 :3 0
2a8 :3 0 1b0 :3 0
2d1 :3 0 111 :3 0
2c8 :3 0 2c9 :3 0
1e9 :3 0 231 :3 0
2aa :3 0 2cb :3 0
9b :3 0 2aa :3 0
111 :3 0 2c8 :3 0
2c9 :3 0 1e9 :3 0
231 :3 0 2d2 :3 0
2aa :3 0 1b0 :3 0
2d2 :3 0 111 :3 0
111 :4 0 2db 1
:a 0 3374 :2 0 3397
3244 3372 :2 0 ae
:3 0 af :3 0 3375
3376 0 ae :3 0
be :3 0 3378 3379
0 47 :2 0 2
:4 0 2dc :2 0 c0
:2 0 47 :2 0 1d84
337e 3380 :3 0 1d87
337a 3382 3377 3384
3383 :2 0 b1 :3 0
c1 :3 0 3386 3387
0 b3 :4 0 2dd
:4 0 b6 :2 0 b7
:3 0 1d8b 338b 338d
:3 0 1d8e 3388 338f
:2 0 3391 1d91 3392
3385 3391 0 3393
1d93 0 3397 20
:3 0 ab :3 0 3395
:2 0 3397 1d95 3674
1e1 :3 0 1e2 :3 0
2de :4 0 339a :4 0
339b :2 0 3673 21
:3 0 e9 :3 0 339d
339e 0 4e :2 0
339f 33a0 0 3673
2df :3 0 9f :3 0
299 :3 0 29a :3 0
29b :3 0 29c :3 0
a8 :3 0 2d3 :4 0
2e0 1 :8 0 33c0
1bf :4 0 33ab :3 0
d1 :3 0 d3 :2 0
1d9b 33ae 33af :3 0
21 :3 0 e9 :3 0
33b1 33b2 0 4e
:2 0 33b3 33b4 0
33b6 1d9e 33bd 21
:3 0 e9 :3 0 33b7
33b8 0 18b :2 0
33b9 33ba 0 33bc
1da0 33be 33b0 33b6
0 33bf 0 33bc
0 33bf 1da2 0
33c0 1da5 3413 eb
:3 0 21 :3 0 e9
:3 0 33c2 33c3 0
ea :3 0 33c4 33c5
0 33c7 1da8 33c9
1daa 33c8 33c7 :2 0
3411 ec :3 0 21
:3 0 e9 :3 0 33cc
33cd 0 ea :3 0
33ce 33cf 0 3409
ae :3 0 af :3 0
33d1 33d2 0 ae
:3 0 be :3 0 33d4
33d5 0 ed :2 0
2 :4 0 2e1 :2 0
c0 :2 0 47 :2 0
1dac 33da 33dc :3 0
1daf 33d6 33de 33d3
33e0 33df :2 0 b1
:3 0 c1 :3 0 33e2
33e3 0 b3 :4 0
2e2 :4 0 b6 :2 0
b7 :3 0 1db3 33e7
33e9 :3 0 b6 :2 0
ca :4 0 1db6 33eb
33ed :3 0 b6 :2 0
f0 :4 0 1db9 33ef
33f1 :3 0 b6 :2 0
ea :3 0 1dbc 33f3
33f5 :3 0 b6 :2 0
f1 :4 0 1dbf 33f7
33f9 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
1dc2 33fc 3400 1dc6
33fb 3402 :3 0 1dc9
33e4 3404 :2 0 3406
1dcc 3407 33e1 3406
0 3408 1dce 0
3409 1dd0 340c :3 0
340c 0 340c 340b
3409 340a :6 0 340e
63 :3 0 1dd3 3410
1dd5 340f 340e :2 0
3411 1dd7 :2 0 3413
0 3413 3412 33c0
3411 :6 0 3673 1
:3 0 2df :3 0 9f
:3 0 1a6 :3 0 299
:3 0 299 :3 0 1a6
:3 0 29a :3 0 29a
:3 0 1a6 :3 0 29b
:3 0 29b :3 0 1a6
:3 0 29c :3 0 29c
:3 0 a8 :3 0 9f
:3 0 9f :3 0 a8
:3 0 2d3 :3 0 9f
:3 0 9f :4 0 2e3
1 :8 0 3440 1bf
:4 0 342b :3 0 d1
:3 0 d3 :2 0 1ddc
342e 342f :3 0 21
:3 0 e9 :3 0 3431
3432 0 4e :2 0
3433 3434 0 3436
1ddf 343d 21 :3 0
e9 :3 0 3437 3438
0 18b :2 0 3439
343a 0 343c 1de1
343e 3430 3436 0
343f 0 343c 0
343f 1de3 0 3440
1de6 3493 eb :3 0
21 :3 0 e9 :3 0
3442 3443 0 ea
:3 0 3444 3445 0
3447 1de9 3449 1deb
3448 3447 :2 0 3491
ec :3 0 21 :3 0
e9 :3 0 344c 344d
0 ea :3 0 344e
344f 0 3489 ae
:3 0 af :3 0 3451
3452 0 ae :3 0
be :3 0 3454 3455
0 ed :2 0 2
:4 0 2e4 :2 0 c0
:2 0 47 :2 0 1ded
345a 345c :3 0 1df0
3456 345e 3453 3460
345f :2 0 b1 :3 0
c1 :3 0 3462 3463
0 b3 :4 0 2e5
:4 0 b6 :2 0 b7
:3 0 1df4 3467 3469
:3 0 b6 :2 0 ca
:4 0 1df7 346b 346d
:3 0 b6 :2 0 f0
:4 0 1dfa 346f 3471
:3 0 b6 :2 0 ea
:3 0 1dfd 3473 3475
:3 0 b6 :2 0 f1
:4 0 1e00 3477 3479
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 1e03
347c 3480 1e07 347b
3482 :3 0 1e0a 3464
3484 :2 0 3486 1e0d
3487 3461 3486 0
3488 1e0f 0 3489
1e11 348c :3 0 348c
0 348c 348b 3489
348a :6 0 348e 65
:3 0 1e14 3490 1e16
348f 348e :2 0 3491
1e18 :2 0 3493 0
3493 3492 3440 3491
:6 0 3673 1 :3 0
255 :3 0 ac :3 0
2a6 :3 0 9f :3 0
111 :3 0 14a :3 0
2cb :3 0 2bd :3 0
1ad :3 0 2a6 :3 0
a3 :3 0 2a6 :3 0
a5 :3 0 2a6 :3 0
a6 :3 0 2a6 :3 0
a7 :3 0 2cb :3 0
2a7 :3 0 2d1 :3 0
1ad :3 0 2a9 :3 0
2d2 :3 0 1ad :3 0
2ab :3 0 2ac :3 0
2ad :3 0 299 :3 0
2ad :3 0 299 :3 0
13e :3 0 299 :3 0
13e :3 0 299 :3 0
2cb :3 0 28f :3 0
6c :3 0 2cb :3 0
28f :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 2cb :3 0
28f :3 0 2e6 :3 0
299 :3 0 2e6 :3 0
299 :3 0 2cb :3 0
28f :3 0 6c :3 0
2cb :3 0 28f :3 0
6c :3 0 e5 :3 0
290 :3 0 1ad :3 0
293 :3 0 111 :3 0
6c :3 0 e5 :3 0
290 :3 0 1ad :3 0
293 :3 0 111 :3 0
2cb :3 0 28f :3 0
2e7 :3 0 299 :3 0
69 :3 0 299 :3 0
2ac :3 0 2ad :3 0
299 :3 0 2ad :3 0
2b0 :3 0 13e :3 0
299 :3 0 13e :3 0
29a :3 0 2cb :3 0
28f :3 0 6c :3 0
2cb :3 0 28f :3 0
6c :3 0 e5 :3 0
290 :3 0 1ad :3 0
293 :3 0 111 :3 0
6c :3 0 e5 :3 0
290 :3 0 1ad :3 0
293 :3 0 111 :3 0
2cb :3 0 28f :3 0
2e6 :3 0 299 :3 0
2e6 :3 0 29a :3 0
2cb :3 0 28f :3 0
6c :3 0 2cb :3 0
28f :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 2cb :3 0
28f :3 0 2e7 :3 0
29a :3 0 69 :3 0
29a :3 0 2ac :3 0
2ad :3 0 299 :3 0
2ad :3 0 29b :3 0
13e :3 0 299 :3 0
13e :3 0 29b :3 0
2cb :3 0 28f :3 0
6c :3 0 2cb :3 0
28f :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 2cb :3 0
28f :3 0 2e6 :3 0
299 :3 0 2e6 :3 0
29b :3 0 2cb :3 0
28f :3 0 6c :3 0
2cb :3 0 28f :3 0
6c :3 0 e5 :3 0
290 :3 0 1ad :3 0
293 :3 0 111 :3 0
6c :3 0 e5 :3 0
290 :3 0 1ad :3 0
293 :3 0 111 :3 0
2cb :3 0 28f :3 0
2e7 :3 0 29b :3 0
69 :3 0 29b :3 0
2ac :3 0 2ad :3 0
2b0 :3 0 2ad :3 0
2b1 :3 0 13e :3 0
29a :3 0 13e :3 0
29c :3 0 2cb :3 0
28f :3 0 6c :3 0
2cb :3 0 28f :3 0
6c :3 0 e5 :3 0
290 :3 0 1ad :3 0
293 :3 0 111 :3 0
6c :3 0 e5 :3 0
290 :3 0 1ad :3 0
293 :3 0 111 :3 0
2cb :3 0 28f :3 0
2e6 :3 0 299 :3 0
2e6 :3 0 29c :3 0
2cb :3 0 28f :3 0
6c :3 0 2cb :3 0
28f :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 6c :3 0
e5 :3 0 290 :3 0
1ad :3 0 293 :3 0
111 :3 0 2cb :3 0
28f :3 0 2e7 :3 0
29c :3 0 69 :3 0
29c :3 0 2a6 :3 0
2b2 :3 0 2a6 :3 0
2b3 :3 0 2a6 :3 0
2b4 :3 0 2a6 :3 0
2b5 :3 0 2a6 :3 0
2b6 :3 0 2a6 :3 0
2b7 :3 0 2a6 :3 0
2b7 :3 0 59 :3 0
2b8 :3 0 5a :3 0
2b9 :3 0 2a6 :3 0
2b4 :3 0 2a6 :3 0
2b5 :3 0 2a6 :3 0
2b6 :3 0 2ba :3 0
2d4 :3 0 2bd :3 0
2bb :3 0 2cb :3 0
2bc :3 0 2be :3 0
1ad :3 0 2bf :3 0
2d5 :3 0 2bd :3 0
2d5 :3 0 2c0 :3 0
2c1 :3 0 5f :3 0
134 :3 0 2a6 :3 0
2c2 :3 0 2c3 :3 0
2a6 :3 0 a1 :3 0
2a6 :3 0 a4 :3 0
a2 :3 0 2ad :3 0
2d6 :3 0 2ad :3 0
2d7 :3 0 2c4 :3 0
2cb :3 0 2c5 :3 0
2cb :3 0 2d8 :3 0
2c6 :3 0 2cb :3 0
2c7 :3 0 a8 :3 0
2a6 :3 0 2c8 :3 0
1e9 :3 0 2df :3 0
2e6 :3 0 2a6 :3 0
9f :3 0 2e6 :3 0
9f :3 0 2e6 :3 0
2d3 :3 0 2c8 :3 0
1e9 :3 0 2df :3 0
2e7 :3 0 2a6 :3 0
9f :3 0 2e7 :3 0
9f :3 0 2e7 :3 0
2d3 :3 0 1e9 :3 0
183 :3 0 1e8 :3 0
2a6 :3 0 9f :3 0
1e8 :3 0 111 :3 0
1e9 :3 0 183 :3 0
2be :3 0 2be :3 0
111 :3 0 1e8 :3 0
1b0 :3 0 2c8 :3 0
2c9 :3 0 1e9 :3 0
167 :3 0 2d5 :3 0
2be :3 0 2d9 :3 0
2d5 :3 0 9b :3 0
1e9 :3 0 167 :3 0
2cb :3 0 2a6 :3 0
9f :3 0 2cb :3 0
9b :3 0 2c8 :3 0
2c9 :3 0 1e9 :3 0
167 :3 0 2d4 :3 0
2d4 :3 0 9b :3 0
2cb :3 0 2da :3 0
2c8 :3 0 2c9 :3 0
1e9 :3 0 2ca :3 0
2ad :3 0 2ad :3 0
99 :3 0 25 :3 0
2ad :3 0 9b :3 0
2a6 :3 0 9f :3 0
2c8 :3 0 2c9 :3 0
1e9 :3 0 167 :3 0
2e8 :3 0 2cb :3 0
2da :3 0 2e8 :3 0
9b :3 0 2c8 :3 0
2c9 :3 0 1e9 :3 0
226 :3 0 2a8 :3 0
2cb :3 0 9b :3 0
2a8 :3 0 111 :3 0
2c8 :3 0 2c9 :3 0
1e9 :3 0 226 :3 0
2d1 :3 0 2a8 :3 0
1b0 :3 0 2d1 :3 0
111 :3 0 2c8 :3 0
2c9 :3 0 1e9 :3 0
231 :3 0 2aa :3 0
2cb :3 0 9b :3 0
2aa :3 0 111 :3 0
2c8 :3 0 2c9 :3 0
1e9 :3 0 231 :3 0
2d2 :3 0 2aa :3 0
1b0 :3 0 2d2 :3 0
111 :3 0 2c8 :3 0
2c9 :3 0 1e9 :3 0
2cc :3 0 13e :3 0
2cb :3 0 2cd :3 0
13e :3 0 2cd :3 0
2a6 :3 0 a3 :3 0
2a6 :3 0 a5 :3 0
2a6 :3 0 a6 :3 0
2a6 :3 0 a7 :3 0
111 :4 0 2e9 1
:a 0 3650 :2 0 3673
3496 364e :2 0 ae
:3 0 af :3 0 3651
3652 0 ae :3 0
be :3 0 3654 3655
0 47 :2 0 2
:4 0 2ea :2 0 c0
:2 0 47 :2 0 1e1b
365a 365c :3 0 1e1e
3656 365e 3653 3660
365f :2 0 b1 :3 0
c1 :3 0 3662 3663
0 b3 :4 0 2eb
:4 0 b6 :2 0 b7
:3 0 1e22 3667 3669
:3 0 1e25 3664 366b
:2 0 366d 1e28 366e
3661 366d 0 366f
1e2a 0 3673 20
:3 0 ac :3 0 3671
:2 0 3673 1e2c 3675
3242 3397 0 3676
0 3673 0 3676
1e34 0 3677 1e37
3679 2fc2 323d 0
367a 0 3677 0
367a 1e39 0 367b
1e3c 371c 21 :3 0
2ec :2 0 4 367c
367d 0 ae :3 0
af :3 0 367f 3680
0 ae :3 0 be
:3 0 3682 3683 0
ed :2 0 2 :4 0
2ed :2 0 c0 :2 0
47 :2 0 1e78 3688
368a :3 0 1e7b 3684
368c 3681 368e 368d
:2 0 b1 :3 0 c1
:3 0 3690 3691 0
b3 :4 0 2ee :4 0
b6 :2 0 b7 :3 0
1e7f 3695 3697 :3 0
1e82 3692 3699 :2 0
36b2 b1 :3 0 c1
:3 0 369b 369c 0
b3 :4 0 2ef :4 0
b6 :2 0 21 :3 0
2f0 :3 0 36a1 36a2
0 1e85 36a0 36a4
:3 0 b6 :2 0 11a
:4 0 1e88 36a6 36a8
:3 0 b6 :2 0 21
:3 0 2f1 :3 0 36ab
36ac 0 1e8b 36aa
36ae :3 0 1e8e 369d
36b0 :2 0 36b2 1e91
36b3 368f 36b2 0
36b4 1e94 0 36c4
255 :3 0 ad :3 0
21 :3 0 2f0 :3 0
2f2 :3 0 21 :3 0
2f1 :3 0 2f3 :3 0
e7 :4 0 2f4 1
:a 0 36c0 :2 0 36c4
36b6 36be :2 0 20
:3 0 ad :3 0 36c2
:2 0 36c4 1e96 36c6
1e9a 36c5 36c4 :2 0
371a ec :3 0 21
:3 0 e9 :3 0 36c9
36ca 0 ea :3 0
36cb 36cc 0 3712
ae :3 0 af :3 0
36ce 36cf 0 ae
:3 0 be :3 0 36d1
36d2 0 ed :2 0
2 :4 0 2f5 :2 0
c0 :2 0 47 :2 0
1e9c 36d7 36d9 :3 0
1e9f 36d3 36db 36d0
36dd 36dc :2 0 b1
:3 0 c1 :3 0 36df
36e0 0 b3 :4 0
2f6 :4 0 b6 :2 0
b7 :3 0 1ea3 36e4
36e6 :3 0 1ea6 36e1
36e8 :2 0 3702 b1
:3 0 c1 :3 0 36ea
36eb 0 b3 :4 0
f0 :4 0 b6 :2 0
ea :3 0 1ea9 36ef
36f1 :3 0 b6 :2 0
f1 :4 0 1eac 36f3
36f5 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
1eaf 36f8 36fc 1eb3
36f7 36fe :3 0 1eb6
36ec 3700 :2 0 3702
1eb9 3703 36de 3702
0 3704 1ebc 0
3712 255 :3 0 ad
:3 0 2f2 :3 0 21
:3 0 2f1 :3 0 2f3
:3 0 e7 :4 0 2f7
1 :a 0 370e :2 0
3712 3706 370c :2 0
20 :3 0 ad :3 0
3710 :2 0 3712 1ebe
3715 :3 0 3715 0
3715 3714 3712 3713
:6 0 3717 1 :3 0
1ec3 3719 1ec5 3718
3717 :2 0 371a 1ec7
:2 0 371c 1eca 371c
371b 367b 371a :6 0
371d :2 0 2 74
371c 3720 :3 0 371f
371d 3721 :8 0 
1f35
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 1
47 1 4b 1
4f 1 53 1
57 1 5b 1
5f 1 63 1
67 1 6b 1b
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 4a 4e 52
56 5a 5e 62
66 6a 6e 1
78 1 76 1
7f 1 7d 1
86 1 84 1
8d 1 8b 1
94 1 92 1
9b 1 99 1
a2 1 a0 1
a9 1 a7 1
b0 1 ae 1
b7 1 b5 1
be 1 bc 1
c5 1 c3 1
cc 1 ca 1
d3 1 d1 1
da 1 d8 1
e1 1 df 1
e8 1 e6 1
ef 1 ed 1
f6 1 f4 1
fd 1 fb 1
104 1 102 1
109 1 110 1
10e 1 117 1
115 1 11e 1
11c 1 125 1
123 1 12c 1
12a 1 131 1
138 1 136 1
13f 1 13d 1
146 1 144 1
14d 1 14b 1
154 1 152 1
15b 1 159 1
160 1 166 1
16c 1 172 1
178 1 17e 1
184 1 18a 1
190 1 196 1
19c 1 1a2 1
1a8 1 1ae 1
1b4 1 1ba 1
1c0 1 1c6 1
1cc 1 1d2 1
1d8 1 1de 1
1e4 1 1ea 1
1f0 1 1f6 1
1fc 1 202 1
208 1 20e 1
214 1 21a 1
220 1 228 1
226 1 22d 1
233 1 239 1
241 1 23f 1
248 1 246 1
24f 1 24d 1
254 1 25a 1
262 1 260 1
269 1 267 1
270 1 26e 1
277 1 275 1
27e 1 27c 1
285 1 283 1
28a 1 290 1
296 1 29c 1
2a2 1 2a8 1
2ae 1 2b4 1
2bc 1 2ba 1
2c1 1 2c7 1
2cc 1 2d1 1
2d6 1 2db 1
2e0 1 2e5 1
2ea 1 2fe 1
319 1 31f 1
326 1 32d 1
334 1 341 1
34d 2 350 352
2 355 357 2
359 35b 2 35d
35f 2 361 363
2 365 367 2
369 36b 2 36d
36f 2 371 373
2 375 377 2
379 37b 2 37d
37f 2 381 383
1 389 2 38b
38c 2 385 38e
2 390 392 1
398 2 39a 39b
2 394 39d 2
39f 3a1 1 3a7
2 3a9 3aa 2
3a3 3ac 2 3ae
3b0 1 3b6 2
3b8 3b9 2 3b2
3bb 2 3bd 3bf
1 3c5 2 3c7
3c8 2 3c1 3ca
2 3cc 3ce 1
3d4 2 3d6 3d7
2 3d0 3d9 2
3db 3dd 1 3e3
2 3e5 3e6 2
3df 3e8 2 3ea
3ec 1 3f2 2
3f4 3f5 2 3ee
3f7 2 3f9 3fb
2 3fd 3ff 2
401 403 2 405
407 2 409 40b
2 40d 40f 2
411 413 2 415
417 2 419 41b
2 41d 41f 2
421 423 2 425
427 2 429 42b
2 42d 42f 2
431 433 2 435
437 2 439 43b
2 43d 43f 2
441 443 2 445
447 2 449 44b
1 451 2 453
454 2 44d 456
2 458 45a 2
45c 45e 2 460
462 2 464 466
2 468 46a 2
46c 46e 2 470
472 2 474 476
2 478 47a 2
47c 47e 2 480
482 2 484 486
2 488 48a 2
48c 48e 2 490
492 2 494 496
2 498 49a 1
4a0 2 4a2 4a3
2 49c 4a5 2
4a7 4a9 1 4af
2 4b1 4b2 2
4ab 4b4 2 4b6
4b8 1 4be 2
4c0 4c1 2 4ba
4c3 2 4c5 4c7
1 4cd 2 4cf
4d0 2 4c9 4d2
2 4d4 4d6 2
4d8 4da 2 4dc
4de 2 4e0 4e2
2 4e4 4e6 2
4e8 4ea 2 4ec
4ee 2 4f0 4f2
2 4f4 4f6 4
349 34f 354 4f8
1 4fa 1 4fc
2 506 508 3
504 505 50a 2
513 515 2 512
517 1 519 1
51b 2 566 567
1 56d 2 569
56d 1 571 2
581 583 3 57f
580 585 2 58e
590 2 592 594
2 596 598 1
5a0 2 5a2 5a3
2 59a 5a5 2
58d 5a7 1 5a9
1 5ab 2 5b5
5b7 3 5b3 5b4
5b9 2 5c2 5c4
2 5c1 5c6 1
5c8 1 5ca 2
5d1 5d2 3 5ac
5cb 5d4 1 5d6
1 5d8 1 5de
1 5e6 1 5ee
2 5f7 5f8 1
5fe 2 5fa 5fe
1 604 2 60b
60c 1 612 2
60e 612 2 620
622 3 61e 61f
624 2 62d 62f
2 631 633 2
635 637 1 63f
2 641 642 2
639 644 2 62c
646 1 648 1
64a 2 654 656
3 652 653 658
2 661 663 2
660 665 1 667
1 669 2 670
671 3 64b 66a
673 1 676 1
67c 2 68c 68e
3 68a 68b 690
2 699 69b 2
69d 69f 2 6a1
6a3 1 6ab 2
6ad 6ae 2 6a5
6b0 2 698 6b2
1 6b4 1 6b6
2 6c0 6c2 3
6be 6bf 6c4 2
6cd 6cf 2 6cc
6d1 1 6d3 1
6d5 2 6dc 6dd
3 6b7 6d6 6df
2 6e2 6e1 1
6e3 1 6e5 2
6e8 6e9 1 6ed
2 6eb 6ed 2
6f1 6f2 1 6f6
2 6f4 6f6 2
6fc 6fd 1 701
2 6ff 701 2
70e 710 3 70c
70d 712 2 71b
71d 2 71f 721
2 723 725 1
72d 2 72f 730
2 727 732 2
71a 734 1 736
1 738 2 742
744 3 740 741
746 2 74f 751
2 74e 753 1
755 1 757 2
75e 75f 3 739
758 761 1 763
1 765 1 76d
1 771 2 773
774 2 777 778
1 77e 2 77a
77e 1 782 1
78a 2 79a 79f
1 7a6 1 7a1
2 7b9 7bb 3
7b7 7b8 7bd 2
7c6 7c8 2 7ca
7cc 2 7ce 7d0
2 7d2 7d4 2
7d6 7d8 3 7dd
7de 7df 2 7da
7e1 2 7c5 7e3
1 7e5 1 7e7
2 7b0 7e8 1
7ec 1 7ab 2
7a9 7f0 1 7fb
2 7f7 7fb 2
800 801 1 805
2 803 805 2
813 815 3 811
812 817 2 820
822 2 824 826
2 828 82a 1
832 2 834 835
2 82c 837 2
81f 839 1 83b
1 83d 2 847
849 3 845 846
84b 2 854 856
2 853 858 1
85a 1 85c 2
863 864 3 83e
85d 866 1 868
3 7f3 869 86c
1 86e 1 870
1 876 2 881
886 1 88d 1
888 2 8a0 8a2
3 89e 89f 8a4
2 8ad 8af 2
8b1 8b3 2 8b5
8b7 2 8b9 8bb
2 8bd 8bf 3
8c4 8c5 8c6 2
8c1 8c8 2 8ac
8ca 1 8cc 1
8ce 2 897 8cf
1 8d3 1 892
2 890 8d7 1
8da 1 8dd 2
8e8 8e9 2 8eb
8ee 2 8f1 8f2
2 8f9 8fa 2
8fc 8ff 2 909
90a 2 90c 90f
2 912 913 2
91a 91b 2 91d
920 2 925 926
1 92c 2 928
92c 1 931 2
935 936 1 93c
2 938 93c 1
941 2 945 946
1 94c 2 948
94c 1 951 1
955 2 957 958
1 959 3 95b
943 95c 2 95f
960 1 964 2
962 964 2 96f
974 1 97b 1
976 2 98e 990
3 98c 98d 992
2 99b 99d 2
99f 9a1 2 9a3
9a5 2 9a7 9a9
2 9ab 9ad 3
9b2 9b3 9b4 2
9af 9b6 2 99a
9b8 1 9ba 1
9bc 2 985 9bd
1 9c1 1 980
2 97e 9c5 2
9cb 9cc 1 9d0
2 9ce 9d0 2
9d8 9dd 1 9e4
1 9df 2 9f7
9f9 3 9f5 9f6
9fb 2 a04 a06
2 a08 a0a 2
a0c a0e 2 a10
a12 2 a14 a16
3 a1b a1c a1d
2 a18 a1f 2
a03 a21 1 a23
1 a25 2 9ee
a26 1 a2a 1
9e9 2 9e7 a2e
2 a36 a37 1
a3b 2 a39 a3b
2 a46 a48 3
a44 a45 a4a 2
a53 a55 2 a57
a59 2 a5b a5d
1 a65 2 a67
a68 2 a5f a6a
2 a6c a6e 2
a70 a72 2 a74
a76 2 a78 a7a
2 a52 a7c 1
a7e 1 a80 2
a8a a8c 3 a88
a89 a8e 2 a97
a99 2 a96 a9b
1 a9d 1 a9f
3 aa6 aa7 aa8
3 a81 aa0 aaa
1 aac 2 a31
aad 1 aaf 2
ab4 ab5 1 ab7
2 abc abd 1
ac1 2 abf ac1
2 ac7 ac8 1
aca 2 acf ad0
1 ad4 2 ad2
ad4 2 adf ae1
3 add ade ae3
2 aec aee 2
af0 af2 2 af4
af6 1 afe 2
b00 b01 2 af8
b03 2 aeb b05
1 b07 1 b09
2 b13 b15 3
b11 b12 b17 2
b20 b22 2 b1f
b24 1 b26 1
b28 2 b2f b30
3 b0a b29 b32
1 b34 3 acd
b35 b3a 1 b3c
2 b42 b43 1
b47 2 b45 b47
1 b4c 2 b56
b58 3 b54 b55
b5a 2 b63 b65
2 b67 b69 2
b6b b6d 1 b75
2 b77 b78 2
b6f b7a 2 b62
b7c 1 b7e 1
b80 2 b8a b8c
3 b88 b89 b8e
2 b97 b99 2
b96 b9b 1 b9d
1 b9f 2 ba6
ba7 3 b81 ba0
ba9 2 bab bac
6 bb0 bb1 bb2
bb3 bb4 bb5 2
bba bbb 1 bc1
2 bbd bc1 2
bc5 bc6 1 bca
2 bc8 bca 1
bd1 1 bd3 2
bdd bdf 3 bdb
bdc be1 2 bea
bec 2 bee bf0
2 bf2 bf4 1
bfa 2 bfc bfd
2 bf6 bff 2
c01 c03 2 c05
c07 2 c09 c0b
2 c0d c0f 2
be9 c11 1 c13
1 c15 2 c1f
c21 3 c1d c1e
c23 2 c2c c2e
2 c2b c30 1
c32 1 c34 2
c3a c3b 3 c3d
c3e c3f 4 bd4
c16 c35 c41 1
c43 2 c46 c47
1 c4b 2 c49
c4b 2 c4f c50
1 c54 2 c52
c54 2 c61 c63
3 c5f c60 c65
2 c6e c70 2
c72 c74 2 c76
c78 1 c7e 2
c80 c81 2 c7a
c83 2 c85 c87
2 c89 c8b 2
c8d c8f 2 c91
c93 2 c6d c95
1 c97 1 c99
2 ca3 ca5 3
ca1 ca2 ca7 2
cb0 cb2 2 caf
cb4 1 cb6 1
cb8 2 cbe cbf
3 cc1 cc2 cc3
3 c9a cb9 cc5
1 cc7 2 cca
ccb 1 cd1 2
ccd cd1 2 cd6
cd7 1 cd9 1
cdd 2 cdb cdd
2 ced cf2 1
cf9 1 cf4 2
d0c d0e 3 d0a
d0b d10 2 d19
d1b 2 d1d d1f
2 d21 d23 2
d25 d27 2 d29
d2b 3 d30 d31
d32 2 d2d d34
2 d18 d36 1
d38 1 d3a 2
d03 d3b 1 d3f
1 cfe 2 cfc
d43 1 d46 2
d70 d75 1 d7c
1 d77 2 d8f
d91 3 d8d d8e
d93 2 d9c d9e
2 da0 da2 2
da4 da6 2 da8
daa 2 dac dae
3 db3 db4 db5
2 db0 db7 2
d9b db9 1 dbb
1 dbd 2 d86
dbe 1 dc2 1
d81 2 d7f dc6
1 dc9 2 dcc
dcd 1 dd5 2
dd1 dd5 2 de1
de3 3 ddf de0
de5 2 dee df0
2 df2 df4 2
df6 df8 1 e00
2 e02 e03 2
dfa e05 2 e07
e09 2 e0b e0d
2 e0f e11 2
e13 e15 2 ded
e17 1 e19 1
e1b 2 e25 e27
3 e23 e24 e29
2 e32 e34 2
e31 e36 1 e38
1 e3a 3 e41
e42 e43 3 e1c
e3b e45 1 e47
2 dce e48 2
e4c e4d 1 e53
2 e4f e53 2
e5f e64 1 e6b
1 e66 2 e7e
e80 3 e7c e7d
e82 2 e8b e8d
2 e8f e91 2
e93 e95 2 e97
e99 2 e9b e9d
3 ea2 ea3 ea4
2 e9f ea6 2
e8a ea8 1 eaa
1 eac 2 e75
ead 1 eb1 1
e70 2 e6e eb5
1 ec0 2 ebc
ec0 2 ecc ece
3 eca ecb ed0
2 ed9 edb 2
edd edf 2 ee1
ee3 1 eeb 2
eed eee 2 ee5
ef0 2 ef2 ef4
2 ef6 ef8 2
efa efc 2 efe
f00 2 ed8 f02
1 f04 1 f06
2 f10 f12 3
f0e f0f f14 2
f1d f1f 2 f1c
f21 1 f23 1
f25 3 f2c f2d
f2e 3 f07 f26
f30 1 f32 2
f47 f4c 1 f53
1 f4e 2 f66
f68 3 f64 f65
f6a 2 f73 f75
2 f77 f79 2
f7b f7d 2 f7f
f81 2 f83 f85
3 f8a f8b f8c
2 f87 f8e 2
f72 f90 1 f92
1 f94 2 f5d
f95 1 f99 1
f58 2 f56 f9d
1 fa8 2 fa4
fa8 2 fb4 fb6
3 fb2 fb3 fb8
2 fc1 fc3 2
fc5 fc7 2 fc9
fcb 1 fd3 2
fd5 fd6 2 fcd
fd8 2 fda fdc
2 fde fe0 2
fe2 fe4 2 fe6
fe8 2 fc0 fea
1 fec 1 fee
2 ff8 ffa 3
ff6 ff7 ffc 2
1005 1007 2 1004
1009 1 100b 1
100d 3 1014 1015
1016 3 fef 100e
1018 1 101a 1
101c 1 1028 2
1025 102b 1 102d
5 eb8 f33 fa0
101b 102e 2 1039
103b 3 1037 1038
103d 2 1046 1048
2 104a 104c 2
104e 1050 1 1058
2 105a 105b 2
1052 105d 2 105f
1061 2 1063 1065
2 1067 1069 2
106b 106d 2 1045
106f 1 1071 1
1073 2 107d 107f
3 107b 107c 1081
2 108a 108c 2
1089 108e 1 1090
1 1092 3 1099
109a 109b 3 1074
1093 109d 3 109f
1030 10a0 2 10a3
10a4 1 10aa 2
10a6 10aa 2 10c4
10c9 1 10d0 1
10cb 2 10e3 10e5
3 10e1 10e2 10e7
2 10f0 10f2 2
10f4 10f6 2 10f8
10fa 2 10fc 10fe
2 1100 1102 3
1107 1108 1109 2
1104 110b 2 10ef
110d 1 110f 1
1111 2 10da 1112
1 1116 1 10d5
2 10d3 111a 1
1125 2 1121 1125
2 1131 1133 3
112f 1130 1135 2
113e 1140 2 1142
1144 2 1146 1148
1 1150 2 1152
1153 2 114a 1155
2 1157 1159 2
115b 115d 2 115f
1161 2 1163 1165
2 113d 1167 1
1169 1 116b 2
1175 1177 3 1173
1174 1179 2 1182
1184 2 1181 1186
1 1188 1 118a
3 1191 1192 1193
3 116c 118b 1195
1 119e 2 119a
119e 3 11a3 11a4
11a5 1 11a9 2
11a7 11a9 2 11ad
11ae 1 11b2 2
11b0 11b2 2 11b6
11b7 2 11bc 11bd
1 11bf 2 11b9
11bf 2 11cf 11d1
3 11cd 11ce 11d3
2 11dc 11de 2
11e0 11e2 2 11e4
11e6 1 11ee 2
11f0 11f1 2 11e8
11f3 2 11f5 11f7
2 11f9 11fb 2
11fd 11ff 2 1201
1203 2 11db 1205
1 1207 1 1209
2 1213 1215 3
1211 1212 1217 2
1220 1222 2 121f
1224 1 1226 1
1228 3 122f 1230
1231 3 120a 1229
1233 1 1235 2
1238 1239 2 123e
123f 1 1241 2
123b 1241 2 124d
1252 1 1259 1
1254 2 126c 126e
3 126a 126b 1270
2 1279 127b 2
127d 127f 2 1281
1283 2 1285 1287
2 1289 128b 3
1290 1291 1292 2
128d 1294 2 1278
1296 1 1298 1
129a 2 1263 129b
1 129f 1 125e
2 125c 12a3 1
12a6 1 12a9 2
1236 12aa 2 12ad
12ac 2 111d 12ae
1 12b0 c 969
9c8 ab0 aba b3d
b40 bad bb8 c44
cc8 10a1 12b1 1
12b3 2 12b6 12b7
1 12bb 2 12b9
12bb 2 12bf 12c0
1 12c6 2 12c2
12c6 1 12c9 2
12d1 12d2 1 12d6
2 12d4 12d6 2
12e3 12e5 3 12e1
12e2 12e7 2 12f0
12f2 2 12f4 12f6
2 12f8 12fa 1
1302 2 1304 1305
2 12fc 1307 2
1309 130b 2 130d
130f 2 1311 1313
2 1315 1317 2
12ef 1319 1 131b
1 131d 2 1327
1329 3 1325 1326
132b 2 1334 1336
2 1333 1338 1
133a 1 133c 3
1343 1344 1345 3
131e 133d 1347 1
1349 2 134c 134d
1 1353 2 134f
1353 2 1361 1366
1 136d 1 1368
2 1380 1382 3
137e 137f 1384 2
138d 138f 2 1391
1393 2 1395 1397
2 1399 139b 2
139d 139f 3 13a4
13a5 13a6 2 13a1
13a8 2 138c 13aa
1 13ac 1 13ae
2 1377 13af 1
13b3 1 1372 2
1370 13b7 1 13c2
2 13be 13c2 2
13cb 13d0 1 13d7
1 13d2 2 13ea
13ec 3 13e8 13e9
13ee 2 13f7 13f9
2 13fb 13fd 2
13ff 1401 2 1403
1405 2 1407 1409
3 140e 140f 1410
2 140b 1412 2
13f6 1414 1 1416
1 1418 2 13e1
1419 1 141d 1
13dc 2 13da 1421
1 142c 2 1428
142c 2 1438 143a
3 1436 1437 143c
2 1445 1447 2
1449 144b 2 144d
144f 1 1457 2
1459 145a 2 1451
145c 2 145e 1460
2 1462 1464 2
1466 1468 2 146a
146c 2 1444 146e
1 1470 1 1472
2 147c 147e 3
147a 147b 1480 2
1489 148b 2 1488
148d 1 148f 1
1491 3 1498 1499
149a 3 1473 1492
149c 1 149e 2
1424 149f 1 14a1
2 13ba 14a2 1
14a4 2 134a 14a5
1 14a7 2 14aa
14ab 1 14af 2
14ad 14af 2 14b3
14b4 1 14b8 2
14b6 14b8 1 14bf
1 14c1 2 14c4
14c5 1 14cb 2
14c7 14cb 1 14ce
2 14d5 14d8 2
14dc 14df 2 14e1
14e2 2 14e3 14e6
1 14ea 2 14e8
14ea 2 14f5 14f6
2 14fa 14fb 2
14ff 1500 2 1504
1505 2 1509 150a
2 150e 150f 2
1513 1514 2 1518
1519 d 14f2 14f3
14f8 14fd 1502 1507
150c 1511 1516 151b
151c 151d 151e 2
1523 1524 1 152a
2 1526 152a 2
1535 1537 3 1533
1534 1539 2 1542
1544 2 1546 1548
2 154a 154c 1
1554 2 1556 1557
2 154e 1559 2
1541 155b 1 155d
1 155f 2 1569
156b 3 1567 1568
156d 2 1576 1578
2 1575 157a 1
157c 1 157e 2
1585 1586 3 1560
157f 1588 2 158c
158d 1 1591 2
158f 1591 2 159c
159e 3 159a 159b
15a0 2 15a9 15ab
2 15ad 15af 2
15b1 15b3 1 15b9
2 15bb 15bc 2
15b5 15be 2 15c0
15c2 2 15c4 15c6
2 15c8 15ca 2
15cc 15ce 2 15a8
15d0 1 15d2 1
15d4 2 15de 15e0
3 15dc 15dd 15e2
2 15eb 15ed 2
15ea 15ef 1 15f1
1 15f3 2 15f9
15fa 3 15fc 15fd
15fe 3 15d5 15f4
1600 2 1603 1602
3 14ef 1521 1604
1 1608 2 160a
160b 2 160e 160f
1 1613 2 1611
1613 2 1618 1619
1 161d 2 161b
161d 2 1624 1625
1 1629 2 1627
1629 2 162e 162f
1 1633 2 1631
1633 1 163b 2
163f 1640 1 1644
2 1642 1644 1
1649 2 164e 164f
1 1653 2 1651
1653 2 1658 1659
1 165d 2 165b
165d 1 1665 2
166a 166b 1 166f
2 166d 166f 1
1674 4 1677 164c
1668 1676 1 1678
1 167a 2 160c
167b 2 167d 167e
2 1681 1682 1
1688 2 1684 1688
3 1696 1697 1698
2 16a0 16a1 1
16a5 2 16a3 16a5
2 16ac 16af 2
16b6 16bb 1 16c2
1 16bd 2 16d5
16d7 3 16d3 16d4
16d9 2 16e2 16e4
2 16e6 16e8 2
16ea 16ec 2 16ee
16f0 2 16f2 16f4
3 16f9 16fa 16fb
2 16f6 16fd 2
16e1 16ff 1 1701
1 1703 2 16cc
1704 1 1708 1
16c7 2 16c5 170c
1 1717 2 1713
1717 2 171c 171d
1 1721 2 171f
1721 2 172f 1734
1 173b 1 1736
2 174e 1750 3
174c 174d 1752 2
175b 175d 2 175f
1761 2 1763 1765
2 1767 1769 2
176b 176d 3 1772
1773 1774 2 176f
1776 2 175a 1778
1 177a 1 177c
2 1745 177d 1
1781 1 1740 2
173e 1785 1 1788
1 178b 1 178c
1 1790 2 1792
1793 2 170f 1794
2 1796 1797 1
179b 2 1799 179b
2 17a7 17ac 1
17b3 1 17ae 2
17c6 17c8 3 17c4
17c5 17ca 2 17d3
17d5 2 17d7 17d9
2 17db 17dd 2
17df 17e1 2 17e3
17e5 3 17ea 17eb
17ec 2 17e7 17ee
2 17d2 17f0 1
17f2 1 17f4 2
17bd 17f5 1 17f9
1 17b8 2 17b6
17fd 2 1821 1826
1 182d 1 1828
2 1840 1842 3
183e 183f 1844 2
184d 184f 2 1851
1853 2 1855 1857
2 1859 185b 2
185d 185f 3 1864
1865 1866 2 1861
1868 2 184c 186a
1 186c 1 186e
2 1837 186f 1
1873 1 1832 2
1830 1877 1 1882
2 187e 1882 2
188e 1890 3 188c
188d 1892 2 189b
189d 2 189f 18a1
2 18a3 18a5 1
18ad 2 18af 18b0
2 18a7 18b2 2
18b4 18b6 2 18b8
18ba 2 18bc 18be
2 18c0 18c2 2
189a 18c4 1 18c6
1 18c8 2 18d2
18d4 3 18d0 18d1
18d6 2 18df 18e1
2 18de 18e3 1
18e5 1 18e7 3
18ee 18ef 18f0 3
18c9 18e8 18f2 1
18f4 2 18f7 18f8
1 18fc 2 18fa
18fc 1 1901 1
1905 2 1907 1908
1 1920 2 191f
1920 1 1928 1
192e 2 1930 1931
2 191d 1932 1
1939 1 1934 2
194c 194e 3 194a
194b 1950 2 1959
195b 2 195d 195f
2 1961 1963 2
1965 1967 2 1969
196b 3 1970 1971
1972 2 196d 1974
2 1958 1976 1
1978 1 197a 2
1943 197b 1 197f
1 193e 2 193c
1983 5 1800 187a
18f5 1909 1986 3
198b 198c 198d 1
1991 2 198f 1991
1 19a1 2 19a0
19a1 1 19a9 1
19af 2 19b1 19b2
2 199e 19b3 1
19ba 1 19b5 2
19cd 19cf 3 19cb
19cc 19d1 2 19da
19dc 2 19de 19e0
2 19e2 19e4 2
19e6 19e8 2 19ea
19ec 3 19f1 19f2
19f3 2 19ee 19f5
2 19d9 19f7 1
19f9 1 19fb 2
19c4 19fc 1 1a00
1 19bf 2 19bd
1a04 1 1a07 2
1a0b 1a0a 1 1a19
2 1a18 1a19 1
1a21 1 1a27 2
1a29 1a2a 2 1a16
1a2b 1 1a32 1
1a2d 2 1a45 1a47
3 1a43 1a44 1a49
2 1a52 1a54 2
1a56 1a58 2 1a5a
1a5c 2 1a5e 1a60
2 1a62 1a64 3
1a69 1a6a 1a6b 2
1a66 1a6d 2 1a51
1a6f 1 1a71 1
1a73 2 1a3c 1a74
1 1a78 1 1a37
2 1a35 1a7c 1
1a8d 2 1a8c 1a8d
1 1a95 1 1a9b
2 1a9d 1a9e 2
1a8a 1a9f 1 1aa6
1 1aa1 2 1ab9
1abb 3 1ab7 1ab8
1abd 2 1ac6 1ac8
2 1aca 1acc 2
1ace 1ad0 2 1ad2
1ad4 2 1ad6 1ad8
3 1add 1ade 1adf
2 1ada 1ae1 2
1ac5 1ae3 1 1ae5
1 1ae7 2 1ab0
1ae8 1 1aec 1
1aab 2 1aa9 1af0
1 1afe 2 1afd
1afe 1 1b06 1
1b0c 2 1b0e 1b0f
2 1afb 1b10 1
1b17 1 1b12 2
1b2a 1b2c 3 1b28
1b29 1b2e 2 1b37
1b39 2 1b3b 1b3d
2 1b3f 1b41 2
1b43 1b45 2 1b47
1b49 3 1b4e 1b4f
1b50 2 1b4b 1b52
2 1b36 1b54 1
1b56 1 1b58 2
1b21 1b59 1 1b5d
1 1b1c 2 1b1a
1b61 a 168d 1690
1693 169b 169e 1798
1a0c 1a7f 1af3 1b64
1 1b67 2 1b6f
1b70 1 1b74 2
1b72 1b74 2 1b78
1b79 1 1b7f 2
1b7b 1b7f 2 1b85
1b86 1 1b8c 2
1b88 1b8c 1 1b91
1 1b98 1 1b9a
1 1b9b 1 1b9d
2 1ba0 1ba1 1
1ba5 2 1ba3 1ba5
1 1bac 1 1bae
1 1bb0 1 1bb5
1 1bbc 1 1bc3
1 1bcd 1 1bcf
2 1bd8 1bd9 1
1bdd 2 1bdb 1bdd
2 1be1 1be2 1
1be8 2 1be4 1be8
2 1bec 1bee 2
1bf0 1bf2 2 1bf4
1bf6 2 1bf8 1bfa
2 1bfc 1bfe 2
1c00 1c02 2 1c04
1c06 1 1c09 2
1c0d 1c0e 1 1c12
2 1c10 1c12 2
1c16 1c18 2 1c1a
1c1c 2 1c1e 1c20
2 1c22 1c24 2
1c26 1c28 2 1c2a
1c2c 2 1c2e 1c30
2 1c32 1c34 1
1c37 2 1c3b 1c3d
2 1c3f 1c41 2
1c43 1c45 2 1c47
1c49 2 1c4b 1c4d
1 1c50 3 1c52
1c39 1c53 1 1c54
2 1c57 1c58 1
1c5e 2 1c5a 1c5e
2 1c62 1c63 1
1c69 2 1c65 1c69
2 1c6f 1c70 1
1c76 2 1c72 1c76
1 1c85 1 1cae
2 1cad 1cae 1
1cb6 1 1cbc 2
1cbe 1cbf 2 1cab
1cc0 1 1cc7 1
1cc2 2 1cda 1cdc
3 1cd8 1cd9 1cde
2 1ce7 1ce9 2
1ceb 1ced 2 1cef
1cf1 2 1cf3 1cf5
2 1cf7 1cf9 3
1cfe 1cff 1d00 2
1cfb 1d02 2 1ce6
1d04 1 1d06 1
1d08 2 1cd1 1d09
1 1d0d 1 1ccc
2 1cca 1d11 1
1d2e 2 1d2d 1d2e
1 1d36 1 1d3c
2 1d3e 1d3f 2
1d2b 1d40 1 1d47
1 1d42 2 1d5a
1d5c 3 1d58 1d59
1d5e 2 1d67 1d69
2 1d6b 1d6d 2
1d6f 1d71 2 1d73
1d75 2 1d77 1d79
3 1d7e 1d7f 1d80
2 1d7b 1d82 2
1d66 1d84 1 1d86
1 1d88 2 1d51
1d89 1 1d8d 1
1d4c 2 1d4a 1d91
4 1c8e 1c93 1d14
1d94 1 1d99 2
1d9b 1d9c 3 1c7f
1c84 1d9d 1 1d9f
1 1da1 1 1da9
2 1dab 1dac 1
1db0 2 1dae 1db0
1 1db6 2 1db8
1db9 2 1dbb 1dbc
2 1dbe 1dc0 1
1db2 1 1dc8 2
1dca 1dcb 2 1dcd
1dce 2 1dc4 1dd1
1 1dd9 2 1dd8
1dd9 2 1de3 1de5
3 1de2 1de7 1de8
1 1dea 2 1dec
1ded 1 1df1 2
1def 1df1 2 1df8
1dfa 3 1df7 1dfc
1dfd 1 1dff 2
1e01 1e02 1 1e06
2 1e04 1e06 1
1e0c 1 1e0e 2
1e11 1e13 2 1e0f
1e16 1 1e1b 2
1e1a 1e1b 2 1e27
1e29 3 1e25 1e26
1e2b 2 1e34 1e36
2 1e38 1e3a 2
1e3c 1e3e 1 1e46
2 1e48 1e49 2
1e40 1e4b 2 1e33
1e4d 1 1e4f 1
1e51 2 1e5b 1e5d
3 1e59 1e5a 1e5f
2 1e68 1e6a 2
1e67 1e6c 1 1e6e
1 1e70 2 1e77
1e78 3 1e52 1e71
1e7a 1 1e7c 2
1e82 1e87 1 1e8e
1 1e89 2 1ea1
1ea3 3 1e9f 1ea0
1ea5 2 1eae 1eb0
2 1eb2 1eb4 2
1eb6 1eb8 2 1eba
1ebc 2 1ebe 1ec0
3 1ec5 1ec6 1ec7
2 1ec2 1ec9 2
1ead 1ecb 1 1ecd
1 1ecf 2 1e98
1ed0 1 1ed4 1
1e93 2 1e91 1ed8
5 1dd3 1dd6 1e19
1e7d 1edb 1 1ede
2 1ee1 1ee2 1
1ee8 2 1ee4 1ee8
2 1ef2 1ef4 2
1ef9 1efb 4 1eed
1ef0 1ef7 1efe 2
1f02 1f03 1 1f09
2 1f05 1f09 2
1f10 1f12 2 1f17
1f19 4 1f0e 1f15
1f1c 1f1f 2 1f23
1f24 1 1f2a 2
1f26 1f2a 1 1f33
2 1f39 1f3b 2
1f40 1f42 2 1f47
1f49 3 1f3e 1f45
1f4c 1 1f4e 2
1f51 1f53 1 1f57
2 1f5d 1f5f 2
1f64 1f66 2 1f6b
1f6d 3 1f62 1f69
1f70 1 1f72 5
1f2f 1f32 1f4f 1f56
1f73 1 1f75 2
1f7b 1f7d 2 1f80
1f83 2 1f86 1f88
2 1f8a 1f8c 1
1f93 2 1f99 1f9b
2 1fa0 1fa2 2
1fa7 1fa9 3 1f9e
1fa5 1fac 1 1fae
2 1fb1 1fb3 2
1fb5 1fb7 2 1fb9
1fbb 2 1fbd 1fbf
2 1fc1 1fc3 2
1fc5 1fc7 4 1f8f
1f92 1faf 1fca 2
1fcc 1fcd 1 1fcf
2 1fd5 1fd7 2
1fd9 1fdb 2 1fdd
1fdf 1 1fe2 1
1fe4 2 1fce 1fe5
2 1fe7 1fe8 1
1fe9 3 1feb 1f21
1fec 2 1fef 1ff0
1 1ff6 2 1ff2
1ff6 1 1ff9 2
2003 2008 1 200f
1 200a 2 2022
2024 3 2020 2021
2026 2 202f 2031
2 2033 2035 2
2037 2039 2 203b
203d 2 203f 2041
3 2046 2047 2048
2 2043 204a 2
202e 204c 1 204e
1 2050 2 2019
2051 1 2055 1
2014 2 2012 2059
1 2064 2 2060
2064 1 206b 2
206d 206e 2 2073
2075 2 207a 207c
2 207e 2080 2
2082 2084 2 2086
2088 3 2071 2078
208b 2 2095 2097
3 2093 2094 2099
2 20a2 20a4 2
20a6 20a8 2 20aa
20ac 1 20b4 2
20b6 20b7 2 20ae
20b9 2 20bb 20bd
2 20bf 20c1 2
20c3 20c5 2 20c7
20c9 2 20a1 20cb
1 20cd 1 20cf
2 20d9 20db 3
20d7 20d8 20dd 2
20e6 20e8 2 20e5
20ea 1 20ec 1
20ee 3 20f5 20f6
20f7 3 20d0 20ef
20f9 2 20fb 20fc
2 205c 20fd 1
20ff 1 2101 2
210b 2110 1 2117
1 2112 2 212a
212c 3 2128 2129
212e 2 2137 2139
2 213b 213d 2
213f 2141 2 2143
2145 2 2147 2149
3 214e 214f 2150
2 214b 2152 2
2136 2154 1 2156
1 2158 2 2121
2159 1 215d 1
211c 2 211a 2161
1 216c 2 2168
216c 2 2171 2173
2 2178 217a 2
217c 217e 2 2180
2182 2 2184 2186
2 2176 2189 2
2193 2195 3 2191
2192 2197 2 21a0
21a2 2 21a4 21a6
2 21a8 21aa 1
21b2 2 21b4 21b5
2 21ac 21b7 2
21b9 21bb 2 21bd
21bf 2 21c1 21c3
2 21c5 21c7 2
219f 21c9 1 21cb
1 21cd 2 21d7
21d9 3 21d5 21d6
21db 2 21e4 21e6
2 21e3 21e8 1
21ea 1 21ec 3
21f3 21f4 21f5 3
21ce 21ed 21f7 2
21f9 21fa 2 2164
21fb 1 21fd 1
21ff 2 2209 220e
1 2215 1 2210
2 2228 222a 3
2226 2227 222c 2
2235 2237 2 2239
223b 2 223d 223f
2 2241 2243 2
2245 2247 3 224c
224d 224e 2 2249
2250 2 2234 2252
1 2254 1 2256
2 221f 2257 1
225b 1 221a 2
2218 225f 1 226a
2 2266 226a 2
226f 2271 2 2276
2278 2 227a 227c
2 227e 2280 2
2282 2284 2 2274
2287 2 2291 2293
3 228f 2290 2295
2 229e 22a0 2
22a2 22a4 2 22a6
22a8 1 22b0 2
22b2 22b3 2 22aa
22b5 2 22b7 22b9
2 22bb 22bd 2
22bf 22c1 2 22c3
22c5 2 229d 22c7
1 22c9 1 22cb
2 22d5 22d7 3
22d3 22d4 22d9 2
22e2 22e4 2 22e1
22e6 1 22e8 1
22ea 3 22f1 22f2
22f3 3 22cc 22eb
22f5 2 22f7 22f8
2 2262 22f9 1
22fb 2 22fe 22ff
1 2303 2 2301
2303 2 2307 2308
1 230c 2 230a
230c 2 2312 2314
2 231a 231b 1
231d 2 2316 231f
2 2321 2323 1
2326 1 2328 4
2100 21fe 22fc 2329
1 232b 1 232d
1 2335 2 2337
2338 1 2341 2
2340 2341 2 234d
234f 4 234b 234c
2351 2352 2 235b
2360 1 2367 1
2362 2 237a 237c
3 2378 2379 237e
2 2387 2389 2
238b 238d 2 238f
2391 2 2393 2395
2 2397 2399 3
239e 239f 23a0 2
239b 23a2 2 2386
23a4 1 23a6 1
23a8 2 2371 23a9
1 23ad 1 236c
2 236a 23b1 1
23bc 2 23b8 23bc
2 23c8 23ca 3
23c6 23c7 23cc 2
23d5 23d7 2 23d9
23db 2 23dd 23df
1 23e7 2 23e9
23ea 2 23e1 23ec
2 23ee 23f0 2
23f2 23f4 2 23f6
23f8 2 23fa 23fc
2 23d4 23fe 1
2400 1 2402 2
240c 240e 3 240a
240b 2410 2 2419
241b 2 2418 241d
1 241f 1 2421
3 2428 2429 242a
3 2403 2422 242c
1 242e 2 2431
2433 2 2435 2437
2 2439 243b 2
243d 243f 2 2441
2443 2 2445 2447
2 244c 244d 1
2453 2 244f 2453
2 2457 2459 1
245c 2 245f 2461
1 2464 2 2466
2467 2 246a 246b
1 2471 2 246d
2471 1 2475 1
2477 2 247a 247c
7 2355 23b4 242f
244a 2468 2478 247f
3 233b 233e 2482
1 2484 2 2487
2488 1 248e 2
248a 248e 1 2494
2 2496 2497 1
24a0 2 249f 24a0
2 24ac 24ae 4
24aa 24ab 24b0 24b1
2 24ba 24bf 1
24c6 1 24c1 2
24d9 24db 3 24d7
24d8 24dd 2 24e6
24e8 2 24ea 24ec
2 24ee 24f0 2
24f2 24f4 2 24f6
24f8 3 24fd 24fe
24ff 2 24fa 2501
2 24e5 2503 1
2505 1 2507 2
24d0 2508 1 250c
1 24cb 2 24c9
2510 1 251b 2
2517 251b 2 2527
2529 3 2525 2526
252b 2 2534 2536
2 2538 253a 2
253c 253e 1 2546
2 2548 2549 2
2540 254b 2 254d
254f 2 2551 2553
2 2555 2557 2
2559 255b 2 2533
255d 1 255f 1
2561 2 256b 256d
3 2569 256a 256f
2 2578 257a 2
2577 257c 1 257e
1 2580 3 2587
2588 2589 3 2562
2581 258b 1 258d
2 2590 2592 2
2594 2596 2 2598
259a 2 259c 259e
2 25a0 25a2 2
25a4 25a6 2 25a8
25aa 2 25af 25b1
5 24b4 2513 258e
25ad 25b4 3 249a
249d 25b7 1 25b9
2 25bc 25be 7
1da0 1edf 1fed 232c
2485 25ba 25c1 2
25c3 25c4 2 25c7
25c9 1 25de 1
25e4 2 25e6 25e7
1 25ef 2 25eb
25ef 1 25f4 1
25f6 2 25f9 25fa
1 25fe 2 25fc
25fe 2 2602 2603
1 2609 2 2605
2609 2 260f 2610
1 2616 2 2612
2616 2 261c 261d
1 2623 2 261f
2623 1 2626 1
2640 1 2646 2
2648 2649 1 2651
2 264d 2651 2
2657 265d 1 2664
1 265f 2 2677
2679 3 2675 2676
267b 2 2684 2686
2 2688 268a 2
268c 268e 2 2690
2692 2 2694 2696
3 269b 269c 269d
2 2698 269f 2
2683 26a1 1 26a3
1 26a5 2 266e
26a6 1 26aa 1
2669 2 2667 26ae
2 26b1 26b4 2
26b8 26be 1 26c5
1 26c0 2 26d8
26da 3 26d6 26d7
26dc 2 26e5 26e7
2 26e9 26eb 2
26ed 26ef 2 26f1
26f3 2 26f5 26f7
3 26fc 26fd 26fe
2 26f9 2700 2
26e4 2702 1 2704
1 2706 2 26cf
2707 1 270b 1
26ca 2 26c8 270f
1 2712 2 2715
2716 4 2632 2637
264a 2717 1 2719
2 2722 2723 1
2727 2 2725 2727
3 272b 272c 272d
1 2731 2 272f
2731 2 2738 273b
2 273f 2740 1
2742 1 2746 2
2744 2746 2 2752
2757 1 275e 1
2759 2 2771 2773
3 276f 2770 2775
2 277e 2780 2
2782 2784 2 2786
2788 2 278a 278c
2 278e 2790 3
2795 2796 2797 2
2792 2799 2 277d
279b 1 279d 1
279f 2 2768 27a0
1 27a4 1 2763
2 2761 27a8 2
27ae 27af 1 27b3
2 27b1 27b3 2
27b8 27be 1 27c5
1 27c0 2 27d8
27da 3 27d6 27d7
27dc 2 27e5 27e7
2 27e9 27eb 2
27ed 27ef 2 27f1
27f3 2 27f5 27f7
3 27fc 27fd 27fe
2 27f9 2800 2
27e4 2802 1 2804
1 2806 2 27cf
2807 1 280b 1
27ca 2 27c8 280f
2 281c 281e 3
281a 281b 2820 2
2829 282b 2 282d
282f 2 2831 2833
1 283b 2 283d
283e 2 2835 2840
2 2842 2844 2
2846 2848 2 284a
284c 2 284e 2850
2 2828 2852 1
2854 1 2856 2
2860 2862 3 285e
285f 2864 2 286d
286f 2 286c 2871
1 2873 1 2875
3 287c 287d 287e
4 2812 2857 2876
2880 1 2882 2
27ab 2883 1 2885
1 2886 2 2888
2889 2 28aa 28ab
21 288d 288e 288f
2890 2891 2892 2893
2894 2895 2896 2897
2898 2899 289a 289b
289c 289d 289e 289f
28a0 28a1 28a2 28a3
28a4 28a5 28a6 28a7
28a8 28ad 28ae 28af
28b0 28b1 1 28b7
2 28b5 28b7 2
28bc 28c2 1 28c9
1 28c4 2 28dc
28de 3 28da 28db
28e0 2 28e9 28eb
2 28ed 28ef 2
28f1 28f3 2 28f5
28f7 2 28f9 28fb
3 2900 2901 2902
2 28fd 2904 2
28e8 2906 1 2908
1 290a 2 28d3
290b 1 290f 1
28ce 2 28cc 2913
1 291c 2 2918
291c 1 2923 1
2925 2 292f 2931
3 292d 292e 2933
2 293c 293e 2
2940 2942 2 2944
2946 1 294c 2
294e 294f 2 2948
2951 2 2953 2955
2 2957 2959 2
295b 295d 2 295f
2961 2 293b 2963
1 2965 1 2967
2 2971 2973 3
296f 2970 2975 2
297e 2980 2 297d
2982 1 2984 1
2986 3 298b 298c
298d 5 2916 2926
2968 2987 298f 3
2993 2994 2995 1
2999 2 2997 2999
3 299e 299f 29a0
1 29a4 2 29a2
29a4 1 29b2 2
29b1 29b2 1 29ba
1 29c0 2 29c2
29c3 2 29af 29c4
1 29cb 1 29c6
2 29de 29e0 3
29dc 29dd 29e2 2
29eb 29ed 2 29ef
29f1 2 29f3 29f5
2 29f7 29f9 2
29fb 29fd 3 2a02
2a03 2a04 2 29ff
2a06 2 29ea 2a08
1 2a0a 1 2a0c
2 29d5 2a0d 1
2a11 1 29d0 2
29ce 2a15 1 2a18
2 2a1c 2a1b 4
288a 28b4 2a1d 2a1f
2 2a22 2a23 1
2a29 2 2a25 2a29
2 2a2e 2a31 1
2a33 21 2a37 2a38
2a39 2a3a 2a3b 2a3c
2a3d 2a3e 2a3f 2a40
2a41 2a42 2a43 2a44
2a45 2a46 2a47 2a48
2a49 2a4a 2a4b 2a4c
2a4d 2a4e 2a4f 2a50
2a51 2a52 2a53 2a54
2a55 2a56 2a57 1
2a5d 2 2a5b 2a5d
2 2a61 2a63 1
2a66 1 2a6b 2
2a69 2a6b 1 2a6f
2 2a72 2a71 2
2a77 2a78 1 2a7a
2 2a74 2a7a 1
2a7e 1 2a80 4
2a34 2a5a 2a73 2a81
2 2a83 2a84 1
2a86 8 25d5 25e8
25f7 271a 271d 2720
2a85 2a89 2 2a8f
2a95 1 2a9c 1
2a97 2 2aaf 2ab1
3 2aad 2aae 2ab3
2 2abc 2abe 2
2ac0 2ac2 2 2ac4
2ac6 2 2ac8 2aca
2 2acc 2ace 3
2ad3 2ad4 2ad5 2
2ad0 2ad7 2 2abb
2ad9 1 2adb 1
2add 2 2aa6 2ade
1 2ae2 1 2aa1
2 2a9f 2ae6 1
2aef 2 2aeb 2aef
1 2af5 2 2af3
2af5 1 2afd 2
2afb 2afd 2 2b01
2b02 1 2b06 2
2b04 2b06 2 2b16
2b18 3 2b14 2b15
2b1a 2 2b23 2b25
2 2b27 2b29 2
2b2b 2b2d 1 2b33
2 2b35 2b36 2
2b2f 2b38 2 2b3a
2b3c 2 2b3e 2b40
2 2b42 2b44 2
2b46 2b48 2 2b22
2b4a 1 2b4c 1
2b4e 2 2b58 2b5a
3 2b56 2b57 2b5c
2 2b65 2b67 2
2b64 2b69 1 2b6b
1 2b6d 3 2b72
2b73 2b74 3 2b4f
2b6e 2b76 1 2b78
1 2b7c 2 2b7a
2b7c 8 2b92 2b93
2b94 2b95 2b96 2b97
2b98 2b99 1 2ba4
1 2baa 2 2bac
2bad 1 2bb5 2
2bb1 2bb5 1 2bba
1 2bbc 1 2bbe
2 2bc6 2bc7 1
2bcb 2 2bc9 2bcb
1 2bd2 2 2bd4
2bd5 1 2bd9 2
2bd7 2bd9 1 2be0
1 2be2 2 2be7
2be8 1 2bec 2
2bea 2bec 1 2bf1
2 2bef 2bf1 1
2c06 2 2c05 2c06
1 2c0e 1 2c14
2 2c16 2c17 2
2c03 2c18 1 2c1f
1 2c1a 2 2c32
2c34 3 2c30 2c31
2c36 2 2c3f 2c41
2 2c43 2c45 2
2c47 2c49 2 2c4b
2c4d 2 2c4f 2c51
3 2c56 2c57 2c58
2 2c53 2c5a 2
2c3e 2c5c 1 2c5e
1 2c60 2 2c29
2c61 1 2c65 1
2c24 2 2c22 2c69
1 2c6c 1 2c6f
9 2c70 2c73 2c76
2c79 2c7c 2c7f 2c82
2c85 2c88 1 2c8a
1 2c8e 2 2c8c
2c8e 1 2c91 1
2ca4 2 2ca3 2ca4
1 2cac 1 2cb2
2 2cb4 2cb5 2
2ca1 2cb6 1 2cbd
1 2cb8 2 2cd0
2cd2 3 2cce 2ccf
2cd4 2 2cdd 2cdf
2 2ce1 2ce3 2
2ce5 2ce7 2 2ce9
2ceb 2 2ced 2cef
3 2cf4 2cf5 2cf6
2 2cf1 2cf8 2
2cdc 2cfa 1 2cfc
1 2cfe 2 2cc7
2cff 1 2d03 1
2cc2 2 2cc0 2d07
1 2d0a 1 2d0d
1 2d0f 1 2d14
2 2d1b 2d1d 3
2d1f 2d20 2d21 1
2d24 1 2d26 2
2d2a 2d2c 3 2d2e
2d2f 2d30 2 2d27
2d33 1 2d35 1
2d37 2 2d3e 2d40
3 2d42 2d43 2d44
1 2d47 1 2d49
1 2d4b 1 2d50
2 2d57 2d59 3
2d5b 2d5c 2d5d 1
2d60 1 2d62 2
2d66 2d68 3 2d6a
2d6b 2d6c 2 2d63
2d6f 1 2d71 1
2d73 2 2d7a 2d7c
3 2d7e 2d7f 2d80
1 2d83 1 2d85
1 2d87 1 2d8c
2 2d93 2d95 3
2d97 2d98 2d99 1
2d9c 1 2d9e 2
2da2 2da4 3 2da6
2da7 2da8 2 2d9f
2dab 1 2dad 1
2daf 1 2db4 2
2dbb 2dbd 3 2dbf
2dc0 2dc1 1 2dc4
1 2dc6 2 2dca
2dcc 3 2dce 2dcf
2dd0 2 2dc7 2dd3
1 2dd5 2 2dd8
2dda e 2b9a 2bae
2bbd 2be3 2c8b 2d0e
2d36 2d4a 2d72 2d86
2dae 2dd6 2ddd 2de0
2 2de6 2dec 1
2df3 1 2dee 2
2e06 2e08 3 2e04
2e05 2e0a 2 2e13
2e15 2 2e17 2e19
2 2e1b 2e1d 2
2e1f 2e21 2 2e23
2e25 3 2e2a 2e2b
2e2c 2 2e27 2e2e
2 2e12 2e30 1
2e32 1 2e34 2
2dfd 2e35 1 2e39
1 2df8 2 2df6
2e3d 1 2e44 2
2e42 2e44 1 2e59
2 2e58 2e59 1
2e61 1 2e67 2
2e69 2e6a 2 2e56
2e6b 1 2e72 1
2e6d 2 2e85 2e87
3 2e83 2e84 2e89
2 2e92 2e94 2
2e96 2e98 2 2e9a
2e9c 2 2e9e 2ea0
2 2ea2 2ea4 3
2ea9 2eaa 2eab 2
2ea6 2ead 2 2e91
2eaf 1 2eb1 1
2eb3 2 2e7c 2eb4
1 2eb8 1 2e77
2 2e75 2ebc 1
2ebf 1 2ec2 8
2b81 2b84 2b87 2b8a
2b8f 2de3 2e40 2ec3
1 2ec5 1 2ec7
2 2ecd 2ece 1
2ed2 2 2ed0 2ed2
2 2ee3 2ee8 1
2eef 1 2eea 2
2f02 2f04 3 2f00
2f01 2f06 2 2f0f
2f11 2 2f13 2f15
2 2f17 2f19 2
2f1b 2f1d 2 2f1f
2f21 3 2f26 2f27
2f28 2 2f23 2f2a
2 2f0e 2f2c 1
2f2e 1 2f30 2
2ef9 2f31 1 2f35
1 2ef4 2 2ef2
2f39 1 2f3c 2
2f41 2f42 2 2f44
2f45 1 2f46 1
2f48 2 2f5d 2f62
1 2f69 1 2f64
2 2f7c 2f7e 3
2f7a 2f7b 2f80 2
2f89 2f8b 2 2f8d
2f8f 2 2f91 2f93
2 2f95 2f97 2
2f99 2f9b 3 2fa0
2fa1 2fa2 2 2f9d
2fa4 2 2f88 2fa6
1 2fa8 1 2faa
2 2f73 2fab 1
2faf 1 2f6e 2
2f6c 2fb3 2 2fb9
2fba 1 2fc0 2
2fbc 2fc0 1 2fdb
2 2fda 2fdb 1
2fe3 1 2fe9 2
2feb 2fec 2 2fd8
2fed 1 2ff4 1
2fef 2 3007 3009
3 3005 3006 300b
2 3014 3016 2
3018 301a 2 301c
301e 2 3020 3022
2 3024 3026 3
302b 302c 302d 2
3028 302f 2 3013
3031 1 3033 1
3035 2 2ffe 3036
1 303a 1 2ff9
2 2ff7 303e 1
3049 2 3045 3049
1 3062 2 3061
3062 1 306a 1
3070 2 3072 3073
2 305f 3074 1
307b 1 3076 2
308e 3090 3 308c
308d 3092 2 309b
309d 2 309f 30a1
2 30a3 30a5 2
30a7 30a9 2 30ab
30ad 3 30b2 30b3
30b4 2 30af 30b6
2 309a 30b8 1
30ba 1 30bc 2
3085 30bd 1 30c1
1 3080 2 307e
30c5 1 30d0 2
30cc 30d0 1 30dd
2 30dc 30dd 1
30e5 1 30eb 2
30ed 30ee 2 30da
30ef 1 30f6 1
30f1 2 3109 310b
3 3107 3108 310d
2 3116 3118 2
311a 311c 2 311e
3120 2 3122 3124
2 3126 3128 3
312d 312e 312f 2
312a 3131 2 3115
3133 1 3135 1
3137 2 3100 3138
1 313c 1 30fb
2 30f9 3140 1
3143 1 3146 2
30c8 3147 1 3149
2 3223 3225 3
3221 3222 3227 2
3230 3232 2 322f
3234 1 3236 1
3238 7 2fc7 2fcc
3041 314a 3219 3239
323c 1 3240 2
323e 3240 2 337d
337f 3 337b 337c
3381 2 338a 338c
2 3389 338e 1
3390 1 3392 3
3373 3393 3396 1
33ad 2 33ac 33ad
1 33b5 1 33bb
2 33bd 33be 2
33aa 33bf 1 33c6
1 33c1 2 33d9
33db 3 33d7 33d8
33dd 2 33e6 33e8
2 33ea 33ec 2
33ee 33f0 2 33f2
33f4 2 33f6 33f8
3 33fd 33fe 33ff
2 33fa 3401 2
33e5 3403 1 3405
1 3407 2 33d0
3408 1 340c 1
33cb 2 33c9 3410
1 342d 2 342c
342d 1 3435 1
343b 2 343d 343e
2 342a 343f 1
3446 1 3441 2
3459 345b 3 3457
3458 345d 2 3466
3468 2 346a 346c
2 346e 3470 2
3472 3474 2 3476
3478 3 347d 347e
347f 2 347a 3481
2 3465 3483 1
3485 1 3487 2
3450 3488 1 348c
1 344b 2 3449
3490 2 3659 365b
3 3657 3658 365d
2 3666 3668 2
3665 366a 1 366c
1 366e 7 339c
33a1 3413 3493 364f
366f 3672 2 3674
3675 1 3676 2
3678 3679 3b 4fd
51c 51f 522 525
528 52b 52e 531
534 537 53a 53d
540 543 546 549
54c 54f 552 555
558 55b 55e 561
564 5d7 6e6 764
775 86f 8de 8e1
8f5 902 916 923
95d 12b4 14a8 14c2
167f 1b68 1b6d 1b9e
1baf 1bd0 1bd3 1bd6
25c5 25cc 25d1 2a8c
2ae9 2b79 2ec6 2f49
2fb6 367a 2 3687
3689 3 3685 3686
368b 2 3694 3696
2 3693 3698 2
369f 36a3 2 36a5
36a7 2 36a9 36ad
2 369e 36af 2
369a 36b1 1 36b3
3 36b4 36bf 36c3
1 367e 2 36d6
36d8 3 36d4 36d5
36da 2 36e3 36e5
2 36e2 36e7 2
36ee 36f0 2 36f2
36f4 3 36f9 36fa
36fb 2 36f6 36fd
2 36ed 36ff 2
36e9 3701 1 3703
4 36cd 3704 370d
3711 1 3715 1
36c8 2 36c6 3719
6a 7b 82 89
90 97 9e a5
ac b3 ba c1
c8 cf d6 dd
e4 eb f2 f9
100 107 10c 113
11a 121 128 12f
134 13b 142 149
150 157 15e 164
16a 170 176 17c
182 188 18e 194
19a 1a0 1a6 1ac
1b2 1b8 1be 1c4
1ca 1d0 1d6 1dc
1e2 1e8 1ee 1f4
1fa 200 206 20c
212 218 21e 224
22b 231 237 23d
244 24b 252 258
25e 265 26c 273
27a 281 288 28e
294 29a 2a0 2a6
2ac 2b2 2b8 2bf
2c5 2ca 2cf 2d4
2d9 2de 2e3 2e8
2ef 2ff 31a 324
32b 332 339 
1
4
0 
3720
0
1
a0
67
87
0 1 1 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 1 33 1 35 1 37
1 39 1 3b 3c 1 3e 3f
1 41 42 41 44 41 46 41
48 41 4a 41 4c 1 4e 1
50 51 50 53 1 55 1 57
1 59 1 5b 1 5d 1 5f
1 61 1 63 1 65 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

2a8 1 0
6b 1 0
2b 1 0
e6 1 0
25a 1 0
2ae 1 0
220 1 0
bc 1 0
5f 1 0
275 1 0
4b 1 0
28a 1 0
d8 1 0
2ea 1 0
2c1 1 0
1b4 1 0
21a 1 0
18a 1 0
8b 1 0
2a2 1 0
27 1 0
2d1 1 0
2f2 1 2
260 1 0
1f 1 0
53 1 0
202 1 0
a7 1 0
1b 1 0
1f6 1 0
2f 1 0
2b4 1 0
136 1 0
305 1 3
144 1 0
fb 1 0
2a86 41 4e
172 1 0
d1 1 0
13d 1 0
178 1 0
63 1 0
43 1 0
23f 1 0
67 1 0
239 1 0
109 1 0
2c7 1 0
296 1 0
4f 1 0
2db 1 0
1d8 1 0
13 1 0
1ae 1 0
ed 1 0
b5 1 0
1a2 1 0
123 1 0
115 1 0
159 1 0
3f 1 0
24d 1 0
1de 1 0
226 1 0
10e 1 0
ae 1 0
3b 1 0
37 1 0
33 1 0
f 1 0
19c 1 0
31f 1 0
92 1 0
3 1 0
c3 1 0
283 1 0
160 1 0
5b 1 0
32d 1 0
14b 1 0
326 1 0
233 1 0
20e 1 0
12a 1 0
11c 1 0
290 1 0
190 1 0
1fc 1 0
2 0 1
1cc 1 0
1c0 1 0
23 1 0
84 1 0
102 1 0
29c 1 0
214 1 0
7 1 0
1f0 1 0
1a8 1 0
2d6 1 0
196 1 0
a0 1 0
246 1 0
1e4 1 0
17e 1 0
27c 1 0
26e 1 0
208 1 0
166 1 0
254 1 0
22d 1 0
16c 1 0
57 1 0
131 1 0
f4 1 0
7d 1 0
1c6 1 0
ca 1 0
47 1 0
184 1 0
df 1 0
2e0 1 0
1ea 1 0
17 1 0
2e5 1 0
152 1 0
2ba 1 0
1d2 1 0
99 1 0
2cc 1 0
76 1 0
1ba 1 0
b 1 0
334 1 0
267 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_2;
ALTER FUNCTION SP_SEARCH_2 COMPILE DEBUG;
/*#################################################################################################*/
/*#################################################################################################*/
/*
#Stored Procedure  :SP_SEARCH_1
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_SEARCH_1 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_1 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
2a8
2 :e:
1FUNCTION:
1SP_SEARCH_1:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1TYPE001:
1AND_ROLES:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PROJECT_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_TASK_ID:
1H_UNIQUEID:
1H_REC_USER:
1H_RES_ID:
1H_SECURITY_ID:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_FINISH_D:
1H_RES_TYPE:
11:
1H_ASSIGN_ID:
1H_AND_ROLES:
18000:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_FULL_NAME:
1255:
1H_COUNT:
10:
1H_BITFLAG:
1H_TYPE:
1H_WORK_TYPE:
1H_CRI:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_UPDATE:
1H_DAYS:
1H_DURATION:
1H_PARTICIPANT:
1H_PRIORITY:
1H_TOTAL:
1H_TOTPR:
1H_FROM_PRJ:
1H_SCHED_WORK:
1H_JULIAN_DAY:
1H_J_EFECTIVE_DATE:
1H_J_DISCONTI_DATE:
1H_WEEK:
1H_ACTIVE:
1H_REC_STATUS:
1H_RES_COST:
1NUMBER:
1STMT:
17999:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_CRI_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TABLE_TYPE:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_TASK_TYPE:
1H_TEMP_VAR:
1ID:
1I:
1II:
1I_RETURN:
1ISF:
1NUMITEMS:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_1(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1109:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_1(110) :: cplan.sql(2639) :: :
1:
1GETTABLE:
10.00:
1IS NULL:
18:
1150:
1      RETURN_INVALID:: SP_SEARCH_1(151) :: cplan.sql(2680) :: :
1 :
1STATE:: :
1PMO_CNST:
1ELEMENT_ID_REQUIRED:
1153:
1                EXIT:: SP_SEARCH_1(154) :: cplan.sql(2683) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1160:
1      RETURN_INVALID:: SP_SEARCH_1(161) :: cplan.sql(2690) :: :
1163:
1                EXIT:: SP_SEARCH_1(164) :: cplan.sql(2693) :: :
1=:
15:
1170:
1      RETURN_INVALID:: SP_SEARCH_1(171) :: cplan.sql(2700) :: :
1INVALID_PARAMS:
1173:
1                EXIT:: SP_SEARCH_1(174) :: cplan.sql(2703) :: :
1IS NOT NULL:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1191:
1           EXCEPTION:: SP_SEARCH_1(192) :: cplan.sql(2721) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1<:
1198:
1      RETURN_INVALID:: SP_SEARCH_1(199) :: cplan.sql(2728) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1201:
1                EXIT:: SP_SEARCH_1(202) :: cplan.sql(2731) :: :
1ELSIF:
1SELECT SYSTIMESTAMP INTO h_start_date:n         FROM DUAL:
1219:
1           EXCEPTION:: SP_SEARCH_1(220) :: cplan.sql(2749) :: :
1>:
1PMO_STPU:
1STRNPCPY:
133:
1ISPROJECTTYPE:
1!=:
1PROJECT_ID:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2+
1400), PRIORITY:n            INTO h_project_id, h_per_day, h_per_week, h_prior+
1ity:n            FROM TMT_WBS WHERE ELEMENT_ID = h_task_id:
1252:
1           EXCEPTION:: SP_SEARCH_1(253) :: cplan.sql(2782) :: :
1B:
1TYPE_ID:
1TASK_TYPE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1A:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1SELECT B.TYPE_ID, B.TASK_TYPE, B.UNRESOLVED_START, B.UNRESOLVED_FINISH, B.PRO+
1JECT_ID,:n            COALESCE(A.MINUTE_PER_DAY, 480), COALESCE(A.MINUTE_PER_+
1WEEK, 2400), A.PRIORITY:n            INTO h_type, h_task_type, h_task_start_D+
1T, h_task_finish_DT, h_project_id,:n            h_per_day, h_per_week, h_prio+
1rity FROM TMT_WBS A, TMT_WBS B:n            WHERE B.ELEMENT_ID = h_task_id AN+
1D B.TYPE_ID IN (pmo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,pmo_cnst.SC_TASK_TYPE+
12,pmo_cnst.SC_TASK_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.SC_PERSONAL_TASK,pmo_+
1cnst.SC_ACTIVE_ADM_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pmo_cnst.SC_WBS_CHANGE_+
1REQUEST_TASK,pmo_cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.SC_WBS_RISK_TASK,pmo_c+
1nst.SC_WBS_ISSUE_TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,pmo_cnst.SC_WBS_DEFECT+
1_TASK,pmo_cnst.SC_WBS_SERVICE_REQUEST_TASK) AND A.ELEMENT_ID = B.PROJECT_ID:
1271:
1           EXCEPTION:: SP_SEARCH_1(272) :: cplan.sql(2801) :: :
1SC_SQL_NO_DATA:
1WBS_ID:
1TMT_CRI:
1SELECT PROJECT_ID, WBS_ID INTO h_project_id, id:n            FROM TMT_CRI WHE+
1RE ELEMENT_ID = h_task_id:
1289:
1           EXCEPTION:: SP_SEARCH_1(290) :: cplan.sql(2819) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n               INTO h_per_day, h_per_week, h_priority:n               FRO+
1M TMT_WBS WHERE ELEMENT_ID = h_project_id:
1310:
1           EXCEPTION:: SP_SEARCH_1(311) :: cplan.sql(2840) :: :
1316:
1        RETURN_ERROR:: SP_SEARCH_1(317) :: cplan.sql(2846) :: :
1RECORD_NOT_FOUND:
1 ID:: :
1319:
1                EXIT:: SP_SEARCH_1(320) :: cplan.sql(2849) :: :
1PMO_RETURN_ERROR_SP:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1340:
1           EXCEPTION:: SP_SEARCH_1(341) :: cplan.sql(2870) :: :
1REC_STATUS:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1358:
1           EXCEPTION:: SP_SEARCH_1(359) :: cplan.sql(2888) :: :
1STRCMP:
1L:
1365:
1        RETURN_ERROR:: SP_SEARCH_1(366) :: cplan.sql(2895) :: :
1LEV_LOCKED_BY_COPY:
1368:
1                EXIT:: SP_SEARCH_1(369) :: cplan.sql(2898) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n         INTO h_per_day, h_per_week, h_priority:n         FROM TMT_WBS WH+
1ERE ELEMENT_ID = h_project_id:
1386:
1           EXCEPTION:: SP_SEARCH_1(387) :: cplan.sql(2916) :: :
1TMT_POOLS:
1SELECT 480, 2400 INTO h_per_day, h_per_week FROM TMT_POOLS WHERE ELEMENT_ID =+
1 h_project_id:
1401:
1           EXCEPTION:: SP_SEARCH_1(402) :: cplan.sql(2931) :: :
1407:
1        RETURN_ERROR:: SP_SEARCH_1(408) :: cplan.sql(2937) :: :
1410:
1                EXIT:: SP_SEARCH_1(411) :: cplan.sql(2940) :: :
1SC_FD_EFFORT_DRIVEN:
1SC_FIXED_DURATION:
1SC_SRCH_PROFILE:
1SC_SRCH_FROM_PROJECT:
17:
1FC_CALC_DURATION:
1437:
1      RETURN_INVALID:: SP_SEARCH_1(438) :: cplan.sql(2967) :: :
1440:
1                EXIT:: SP_SEARCH_1(441) :: cplan.sql(2970) :: :
1445:
1        RETURN_ERROR:: SP_SEARCH_1(446) :: cplan.sql(2975) :: :
1448:
1                EXIT:: SP_SEARCH_1(449) :: cplan.sql(2978) :: :
1100:
12:
13:
14:
1*:
1FC_DECLARE_PMO_TMP_SEARCH:
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1ASSIGNRESOURCE:
1SC_SRCH_PARTICIPANT:
1RECORD_ALREADY_ASSIGNED:
1490:
1        RETURN_ERROR:: SP_SEARCH_1(491) :: cplan.sql(3020) :: :
1493:
1                EXIT:: SP_SEARCH_1(494) :: cplan.sql(3023) :: :
1        RETURN_ERROR:: SP_SEARCH_1(501) :: cplan.sql(3030) :: :
1503:
1                EXIT:: SP_SEARCH_1(504) :: cplan.sql(3033) :: :
1MIN:
1BAK_START_DT:
1TASK_ASSIGNMENTS:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1SELECT MIN(BAK_START_DT), PMO_ORASTD.DAYS(h_start_date) - PMO_ORASTD.DAYS(MIN+
1(BAK_START_DT)):n         INTO h_start_DT, h_total :n         FROM TASK_ASSIG+
1NMENTS:n         WHERE PROJECT_ID = h_project_id :n         AND TASK_ID = h_p+
1roject_id :n         AND RESOURCE_ID = h_res_id :n         AND RESOURCE_TYPE +
1= h_res_type:
1526:
1           EXCEPTION:: SP_SEARCH_1(527) :: cplan.sql(3056) :: :
1PROJECT_ASSIGNMENT_ID:
1SCHED_START:
1TO_DATE:
1SCHED_FINISH:
1SCHED_WORK:
1BIT_FLAG:
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START, :n               CASE WHEN (TO_DAT+
1E(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AN+
1D TO_DATE(SubStr(SCHED_FINISH, 1, 10)) OR :n               TO_DATE(SubStr(h_f+
1inish_DT, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AND TO_DATE(Sub+
1Str(SCHED_FINISH, 1, 10))) AND :n               SCHED_WORK >= h_effort THEN 0+
1 ELSE 1 END,SCHED_WORK:n               INTO h_prj_assign_id, h_start_DT, h_to+
1tal, h_sched_work:n               FROM TASK_ASSIGNMENTS:n               WHERE+
1 TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_+
1FLAG = '2':
1558:
1           EXCEPTION:: SP_SEARCH_1(559) :: cplan.sql(3088) :: :
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_WORK:
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, :n                     CASE WHEN+
1 (TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, +
11, 10)) AND TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) OR :n                     +
1TO_DATE(SubStr(h_finish_DT, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, +
110)) AND TO_DATE(SubStr(PLANNED_FINISH, 1, 10))) AND :n                     P+
1LANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                     INTO h_prj_as+
1sign_id, h_start_DT, h_total:n                     FROM TASK_ASSIGNMENTS:n   +
1                  WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RES+
1OURCE_TYPE='0' AND BIT_FLAG = '0':
1582:
1           EXCEPTION:: SP_SEARCH_1(583) :: cplan.sql(3112) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, :n                  CASE WHEN (T+
1O_DATE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, +
110)) AND TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) OR :n                  TO_DAT+
1E(SubStr(h_finish_DT, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) A+
1ND TO_DATE(SubStr(PLANNED_FINISH, 1, 10))) AND :n                  PLANNED_WO+
1RK >= h_effort THEN 0 ELSE 1 END:n                  INTO h_prj_assign_id, h_s+
1tart_DT, h_total:n                  FROM TASK_ASSIGNMENTS:n                  +
1WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND+
1 BIT_FLAG = '0':
1606:
1           EXCEPTION:: SP_SEARCH_1(607) :: cplan.sql(3136) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, :n               CASE WHEN(TO_DA+
1TE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10))+
1 AND TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) OR :n               TO_DATE(SubSt+
1r(h_finish_DT, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_D+
1ATE(SubStr(PLANNED_FINISH, 1, 10))) AND :n               PLANNED_WORK >= h_ef+
1fort THEN 0 ELSE 1 END:n               INTO h_prj_assign_id, h_start_DT, h_to+
1tal:n               FROM TASK_ASSIGNMENTS:n               WHERE TASK_ID=h_pro+
1ject_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1' AND BIT_FLAG = '0':
1628:
1           EXCEPTION:: SP_SEARCH_1(629) :: cplan.sql(3158) :: :
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START,CASE WHEN TO_DATE(SubStr(h_start_da+
1te, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AND TO_DATE(SubStr(SC+
1HED_FINISH, 1, 10)) AND h_effort <= SCHED_WORK THEN 0 ELSE 1 END, SCHED_WORK+
1:n               INTO h_prj_assign_id, h_start_DT,h_total, h_sched_work :n   +
1            FROM TASK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_id +
1AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
1648:
1           EXCEPTION:: SP_SEARCH_1(649) :: cplan.sql(3178) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLAN+
1NED_WORK THEN 0 ELSE 1 END:n                     INTO h_prj_assign_id, h_star+
1t_DT,h_total :n                     FROM TASK_ASSIGNMENTS:n                  +
1   WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' +
1AND BIT_FLAG = '0':
1669:
1           EXCEPTION:: SP_SEARCH_1(670) :: cplan.sql(3199) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1               INTO h_prj_assign_id, h_start_DT,h_total :n                  F+
1ROM TASK_ASSIGNMENTS:n                  WHERE TASK_ID=h_project_id AND RESOUR+
1CE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
1691:
1           EXCEPTION:: SP_SEARCH_1(692) :: cplan.sql(3221) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1            INTO h_prj_assign_id, h_start_DT,h_total :n               FROM TA+
1SK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_r+
1es_id AND RESOURCE_TYPE='1' AND BIT_FLAG = '0':
1710:
1           EXCEPTION:: SP_SEARCH_1(711) :: cplan.sql(3240) :: :
1720:
1        RETURN_ERROR:: SP_SEARCH_1(721) :: cplan.sql(3250) :: :
1TASK_ASSIGNMENT_ERROR:
1723:
1                EXIT:: SP_SEARCH_1(724) :: cplan.sql(3253) :: :
1SUM:
1SCHED_MIN:
1TASK_DAY_OF_YEAR:
1TSK_ASSIGNMENT_ID:
1DAY_YEAR:
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                  FROM TASK_DAY_OF_+
1YEAR:n                  WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID+
1 = h_prj_assign_id :n                  AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_+
1start_date, 1, 10)) AND TO_DATE(SubStr(h_finish_DT, 1, 10)):
1742:
1           EXCEPTION:: SP_SEARCH_1(743) :: cplan.sql(3272) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                  FROM TASK_DAY_OF_+
1YEAR:n                  WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID+
1 = h_prj_assign_id :n                  AND DAY_YEAR >= TO_DATE(SubStr(h_start+
1_date, 1, 10)):
1761:
1           EXCEPTION:: SP_SEARCH_1(762) :: cplan.sql(3291) :: :
1769:
1        RETURN_ERROR:: SP_SEARCH_1(770) :: cplan.sql(3299) :: :
1772:
1                EXIT:: SP_SEARCH_1(773) :: cplan.sql(3302) :: :
1ISNOTPROJECTTYPE:
1780:
1        RETURN_ERROR:: SP_SEARCH_1(781) :: cplan.sql(3310) :: :
1783:
1                EXIT:: SP_SEARCH_1(784) :: cplan.sql(3313) :: :
1NICK_NAME:
1JULIAN_DAY:
1ACTIVE:
1EFFECTIVE_DATE:
1DISCONTINUE_DATE:
1RESOURCES:
1SELECT NICK_NAME, PMO_ORASTD.JULIAN_DAY(h_start_DT), ACTIVE, COALESCE(PMO_ORA+
1STD.JULIAN_DAY(EFFECTIVE_DATE),0),COALESCE(PMO_ORASTD.JULIAN_DAY(DISCONTINUE_+
1DATE),0):n            INTO h_full_name, h_julian_day, h_active, h_j_efective_+
1date, h_j_disconti_date:n            FROM RESOURCES :n            WHERE RESOU+
1RCE_ID = h_res_id:
1804:
1           EXCEPTION:: SP_SEARCH_1(805) :: cplan.sql(3334) :: :
1811:
1        RETURN_ERROR:: SP_SEARCH_1(812) :: cplan.sql(3341) :: :
1814:
1                EXIT:: SP_SEARCH_1(815) :: cplan.sql(3344) :: :
1822:
1        RETURN_ERROR:: SP_SEARCH_1(823) :: cplan.sql(3352) :: :
1RESOURCE_NOT_ACTIVE:
1825:
1                EXIT:: SP_SEARCH_1(826) :: cplan.sql(3355) :: :
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_assign_id, h_partic+
1ipant, h_security_id:n            FROM RESOURCE_ASSIGNMENTS:n            WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_TYPE = '0' AND RESOURCE_ID = h_res_id:
1842:
1           EXCEPTION:: SP_SEARCH_1(843) :: cplan.sql(3372) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME INTO h_full_name FROM PROFILES WHERE PROFILE_ID = h_res_i+
1d:
1859:
1           EXCEPTION:: SP_SEARCH_1(860) :: cplan.sql(3389) :: :
1866:
1        RETURN_ERROR:: SP_SEARCH_1(867) :: cplan.sql(3396) :: :
1869:
1                EXIT:: SP_SEARCH_1(870) :: cplan.sql(3399) :: :
1BAK_FINISH_DT:
1BAK_WORK:
1SELECT BAK_START_DT, CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN T+
1O_DATE(SubStr(BAK_START_DT, 1, 10)) AND TO_DATE(SubStr(BAK_FINISH_DT, 1, 10))+
1 AND BAK_WORK >= h_effort THEN 0 ELSE 1 END:n            INTO h_start_DT, h_t+
1otal :n            FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project+
1_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1':
1887:
1           EXCEPTION:: SP_SEARCH_1(888) :: cplan.sql(3417) :: :
1894:
1        RETURN_ERROR:: SP_SEARCH_1(895) :: cplan.sql(3424) :: :
1897:
1                EXIT:: SP_SEARCH_1(898) :: cplan.sql(3427) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_assign_id, h_partic+
1ipant, h_security_id:n            FROM RESOURCE_ASSIGNMENTS:n            WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_TYPE = '1' AND RESOURCE_ID = h_res_id:
1914:
1           EXCEPTION:: SP_SEARCH_1(915) :: cplan.sql(3444) :: :
1DB2TIMESTAMP:
1TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_DT, 1, 10)), PMO_ORASTD+
1.TIME(h_start_date)) INTO h_start_DT:n            FROM DUAL:
1934:
1           EXCEPTION:: SP_SEARCH_1(935) :: cplan.sql(3464) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) > TO_DATE(SubStr(h_star+
1t_DT, 1, 10)) THEN h_start_date:n            ELSE h_start_DT END:n           +
1 INTO h_start_DT:n            FROM DUAL:
1952:
1           EXCEPTION:: SP_SEARCH_1(953) :: cplan.sql(3482) :: :
110:
1FC_SEARCH_2:
1PMO_TMP_SEARCH:
1PLANNED_SCHED_FLAG:
1RES_ID:
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='0' WHERE RES_ID=h_res_id:
1FOUND:
1985:
1           EXCEPTION:: SP_SEARCH_1(986) :: cplan.sql(3515) :: :
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='1' WHERE RES_ID=h_res_id:
11004:
1           EXCEPTION:: SP_SEARCH_1(1005) :: cplan.sql(3534) :: :
11042:
1           EXCEPTION:: SP_SEARCH_1(1043) :: cplan.sql(3572) :: :
1LENGTH:
1TRUNC:
1/:
1WHILE:
1LOOP:
1COUNT:
1PROPOSED_START:
1SELECT COUNT(*), MIN(PROPOSED_START) INTO h_total, h_start_DT :n             +
1  FROM TASK_ASSIGNMENTS:n               WHERE PROJECT_ID = h_project_id AND T+
1ASK_ID = h_project_id:n               AND RESOURCE_ID = h_res_id AND RESOURCE+
1_TYPE = h_res_type:
11084:
1           EXCEPTION:: SP_SEARCH_1(1085) :: cplan.sql(3614) :: :
1',':
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START, CASE WHEN TO_DATE(SubStr(h_start_d+
1ate, 1, 10)) >= TO_DATE(SubStr(SCHED_START, 1, 10)) AND:n                    +
1    TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(SCHED_FINISH, 1, 10+
1)) AND SCHED_WORK >= h_effort THEN 0 ELSE 1 END,SCHED_WORK:n                 +
1       INTO h_prj_assign_id, h_start_DT, h_total, h_sched_work:n             +
1           FROM TASK_ASSIGNMENTS:n                        WHERE TASK_ID=h_pro+
1ject_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '2':
11133:
1           EXCEPTION:: SP_SEARCH_1(1134) :: cplan.sql(3663) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1              TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_F+
1INISH, 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n              +
1                INTO h_prj_assign_id, h_start_DT, h_total :n                 +
1             FROM TASK_ASSIGNMENTS:n                              WHERE TASK_+
1ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG =+
1 '0':
11155:
1           EXCEPTION:: SP_SEARCH_1(1156) :: cplan.sql(3685) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1           TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINI+
1SH, 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                 +
1          INTO h_prj_assign_id, h_start_DT, h_total :n                       +
1    FROM TASK_ASSIGNMENTS:n                           WHERE TASK_ID=h_project+
1_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
11177:
1           EXCEPTION:: SP_SEARCH_1(1178) :: cplan.sql(3707) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1        TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH,+
1 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                    +
1    INTO h_prj_assign_id, h_start_DT, h_total FROM TASK_ASSIGNMENTS:n        +
1                WHERE PROJECT_ID = h_project_id AND TASK_ID=h_project_id:n   +
1                     AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1' AND BIT_F+
1LAG = '0':
11197:
1           EXCEPTION:: SP_SEARCH_1(1198) :: cplan.sql(3727) :: :
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START,CASE WHEN TO_DATE(SubStr(h_start_da+
1te, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AND TO_DATE(SubStr(SC+
1HED_FINISH, 1, 10)) AND h_effort <= SCHED_WORK THEN 0 ELSE 1 END, SCHED_WORK+
1:n                        INTO h_prj_assign_id, h_start_DT,h_total, h_sched_w+
1ork FROM TASK_ASSIGNMENTS:n                        WHERE PROJECT_ID = h_proje+
1ct_id AND TASK_ID=h_project_id:n                        AND RESOURCE_ID=h_res+
1_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
11217:
1           EXCEPTION:: SP_SEARCH_1(1218) :: cplan.sql(3747) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLAN+
1NED_WORK THEN 0 ELSE 1 END:n                              INTO h_prj_assign_i+
1d, h_start_DT,h_total FROM TASK_ASSIGNMENTS:n                              WH+
1ERE PROJECT_ID = h_project_id AND TASK_ID=h_project_id:n                     +
1         AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
11237:
1           EXCEPTION:: SP_SEARCH_1(1238) :: cplan.sql(3767) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubS+
1tr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n  +
1                         INTO h_prj_assign_id, h_start_DT,h_total FROM TASK_A+
1SSIGNMENTS:n                           WHERE PROJECT_ID = h_project_id AND TA+
1SK_ID=h_project_id:n                           AND RESOURCE_ID=h_res_id AND R+
1ESOURCE_TYPE='0' AND BIT_FLAG = '0':
11259:
1           EXCEPTION:: SP_SEARCH_1(1260) :: cplan.sql(3789) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1                     INTO h_prj_assign_id, h_start_DT,h_total FROM TASK_ASSIG+
1NMENTS:n                        WHERE PROJECT_ID = h_project_id AND TASK_ID=h+
1_project_id:n                        AND RESOURCE_ID=h_res_id AND RESOURCE_TY+
1PE='1' AND BIT_FLAG = '0':
11278:
1           EXCEPTION:: SP_SEARCH_1(1279) :: cplan.sql(3808) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                              FROM +
1TASK_DAY_OF_YEAR:n                              WHERE PROJECT_ID = h_project_+
1id AND TSK_ASSIGNMENT_ID = h_prj_assign_id :n                              AN+
1D DAY_YEAR BETWEEN TO_DATE(SubStr(h_start_date, 1, 10)) AND TO_DATE(SubStr(h_+
1finish_DT, 1, 10)):
11305:
1           EXCEPTION:: SP_SEARCH_1(1306) :: cplan.sql(3835) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                              FROM +
1TASK_DAY_OF_YEAR:n                              WHERE PROJECT_ID = h_project_+
1id AND TSK_ASSIGNMENT_ID = h_prj_assign_id :n                              AN+
1D DAY_YEAR >= TO_DATE(SubStr(h_start_date, 1, 10)):
11324:
1           EXCEPTION:: SP_SEARCH_1(1325) :: cplan.sql(3854) :: :
1CONTINUE0000:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_DT, 1, 10)), PMO_ORASTD+
1.TIME(h_start_date)):n                  INTO h_start_DT:n                  FR+
1OM DUAL:
11356:
1           EXCEPTION:: SP_SEARCH_1(1357) :: cplan.sql(3886) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) > TO_DATE(SubStr(h_star+
1t_DT, 1, 10)) THEN h_start_date ELSE h_start_DT END:n                  INTO h+
1_start_DT:n                  FROM DUAL:
11373:
1           EXCEPTION:: SP_SEARCH_1(1374) :: cplan.sql(3903) :: :
11406:
1           EXCEPTION:: SP_SEARCH_1(1407) :: cplan.sql(3936) :: :
11425:
1           EXCEPTION:: SP_SEARCH_1(1426) :: cplan.sql(3955) :: :
11461:
1           EXCEPTION:: SP_SEARCH_1(1462) :: cplan.sql(3991) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
11491:
1           EXCEPTION:: SP_SEARCH_1(1492) :: cplan.sql(4021) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET SECURITY_ID = h_security_id, PARTICIPANT = h_+
1participant:n            WHERE RES_ASSIGNMENT_ID = h_assign_id:
11511:
1           EXCEPTION:: SP_SEARCH_1(1512) :: cplan.sql(4041) :: :
11519:
1        RETURN_ERROR:: SP_SEARCH_1(1520) :: cplan.sql(4049) :: :
11522:
1                EXIT:: SP_SEARCH_1(1523) :: cplan.sql(4052) :: :
1CANNOT_ASSIGN_TO_DEFAULT_CRI:
11527:
1        RETURN_ERROR:: SP_SEARCH_1(1528) :: cplan.sql(4057) :: :
11530:
1                EXIT:: SP_SEARCH_1(1531) :: cplan.sql(4060) :: :
1CANNOT_CHANGE_OBJECT_TYPE:
11536:
1        RETURN_ERROR:: SP_SEARCH_1(1537) :: cplan.sql(4066) :: :
11539:
1                EXIT:: SP_SEARCH_1(1540) :: cplan.sql(4069) :: :
11545:
1        RETURN_ERROR:: SP_SEARCH_1(1546) :: cplan.sql(4075) :: :
11548:
1                EXIT:: SP_SEARCH_1(1549) :: cplan.sql(4078) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN_0003:
1INSERT INTO PMO_TMP_CPLN_0003 SELECT RESOURCE_ID, RESOURCE_TYPE, :
1 MIN(PLANNED_START) AS PLANNED_START,  MAX(PLANNED_FINISH) AS PLANNED_FINISH,+
1 :
1 SUM(PLANNED_WORK) AS PLANNED_EFFORT,  MIN(SCHED_START) AS START_DATE,  :
1 MAX(SCHED_FINISH) AS FINISH_DATE,     SUM(SCHED_WORK) AS WORK,  :
1 SUM(ETC) AS REMAINING :
1 FROM TASK_ASSIGNMENTS WHERE PROJECT_ID=':
1' AND :
1      (RESOURCE_ID IN (':
1') OR RESOURCE_ID IN (':
1')) GROUP BY RESOURCE_ID, RESOURCE_TYPE :
11582:
1           EXCEPTION:: SP_SEARCH_1(1583) :: cplan.sql(4112) :: :
1SQL :: :
1DELETE FROM PMO_TMP_CPLN_0002:
1INSERT INTO PMO_TMP_CPLN_0002 SELECT RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,MIN+
1(PLANNED_START) AS PRJ_PLANNED_START, :
1 MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH,  SUM(PLANNED_WORK) AS PLANNED_REM+
1AINING, :
1 MIN(SCHED_START) AS PRJ_SCHED_START,        MAX(SCHED_FINISH) AS PRJ_SCHED_F+
1INISH, :
1 SUM(SCHED_WORK) AS SCHED_REMAINING  :
1 FROM TASK_ASSIGNMENTS :
1 WHERE TASK_ID=':
1 (RESOURCE_ID IN (':
1')) GROUP BY RESOURCE_ID :
11616:
1           EXCEPTION:: SP_SEARCH_1(1617) :: cplan.sql(4146) :: :
1FC_U_CREATETMPTABLE:
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME,RESOURCE_TYPE,TYPE_ID+
1,E_MAIL_ADDRESS,PLANNED_START,:
1PLANNED_FINISH,PLANNED_EFFORT,START_DATE,FINISH_DATE,WORK,REMAINING,BEST_STAR+
1T,BEST_FINISH,:
1ASSIGNABLE,PLANNED,SCHED,WORK_EFFORT,PERIOD_AVAILABILITY,PROJECT_ASSIGNMENT_I+
1D,PRJ_PLANNED_START,:
1PRJ_PLANNED_FINISH,PLANNED_REMAINING,PRJ_SCHED_START,PRJ_SCHED_FINISH,SCHED_R+
1EMAINING,REGULAR_COST,:
1REGULAR_RATE,SPECIAL_COST,SPECIAL_RATE, EXTERNAL_ID) :
1SELECT DISTINCT r.RESOURCE_ID,r.FULL_NAME AS ELEMENT_NAME,'0',:
1CASE WHEN ta.TSK_ASSIGNMENT_ID IS NuLL THEN 185 ELSE 13 END AS TYPE_ID,:
1r.E_MAIL_ADDRESS, a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.STAR+
1T_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,:
1rs.START_DATE, rs.FINISH_DATE, rs.ASSIGNABLE, rs.PLANNED, rs.SCHED, rs.PROPOS+
1ED, (rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) ,:
1tb.PROJECT_ASSIGNMENT_ID,tb.PRJ_PLANNED_START, tb.PRJ_PLANNED_FINISH, tb.PLAN+
1NED_REMAINING,:
1tb.PRJ_SCHED_START, tb.PRJ_SCHED_FINISH, tb.SCHED_REMAINING, pa.REGULAR_COST,+
1 pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE, r.EXTERNAL_ID :
1FROM RESOURCES r LEFT OUTER JOIN PMO_TMP_CPLN_0003 a ON a.RESOURCE_TYPE='0' A+
1ND a.RESOURCE_ID=r.RESOURCE_ID :
1LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID=':
1' AND r.RESOURCE_ID = pa.RESOURCE_ID :
1LEFT OUTER JOIN TASK_ASSIGNMENTS ta ON ta.PROJECT_ID=':
1' AND r.RESOURCE_ID = ta.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_CPLN_0002 tb ON r.RESOURCE_ID = tb.PROJECT_ASSIGNMENT+
1_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON r.RESOURCE_ID=rs.RES_ID WHERE r.RESOURCE+
1_ID IN (':
1') :
1UNION ALL :
1SELECT DISTINCT p.PROFILE_ID , p.PROFILE_NAME AS ELEMENT_NAME, '1', 41 AS TYP+
1E_ID,:
1'', a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.START_DATE, a.FINI+
1SH_DATE, a.WORK, a.REMAINING,:
1rs.START_DATE , rs.FINISH_DATE, rs.ASSIGNABLE ,rs.PLANNED,rs.SCHED, rs.PROPOS+
1ED,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) ,:
1tb.PRJ_SCHED_START, tb.PRJ_SCHED_FINISH, tb.SCHED_REMAINING, pa.REGULAR_COST,+
1 pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE, '' AS EXTERNAL_ID :
1FROM PROFILES p LEFT OUTER JOIN PMO_TMP_CPLN_0003 a ON a.RESOURCE_TYPE='1' AN+
1D p.PROFILE_ID=a.RESOURCE_ID :
1LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID= ':
1' AND p.PROFILE_ID = pa.RESOURCE_ID :
1JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=p.ROLE_ID :
1JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID LEFT OUTER JOIN PMO_TMP_S+
1EARCH rs ON a.RESOURCE_ID=rs.RES_ID :
1LEFT OUTER JOIN PMO_TMP_CPLN_0002 tb ON p.PROFILE_ID = tb.PROJECT_ASSIGNMENT_+
1ID :
1WHERE p.PROFILE_ID IN (':
1ORDER BY TYPE_ID,ELEMENT_NAME:
11673:
1           EXCEPTION:: SP_SEARCH_1(1674) :: cplan.sql(4203) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME AS ELEMENT_NAME,+
1 T.TYPE_ID AS TYPE_ID, :
1 T.E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T.STA+
1RT_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1 T.BEST_START, T.BEST_FINISH, T.ASSIGNABLE AS CALENDAR,T.PLANNED AS PLANNED_W+
1ORK,:
1 T.SCHED AS SCHED_WORK, T.WORK_EFFORT, :
1 AS UNIT_EFFORT,T.PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED_+
1REMAINING, :
1T.PRJ_SCHED_START, T.PRJ_SCHED_FINISH, T.SCHED_REMAINING, T.REGULAR_COST, T.R+
1EGULAR_RATE, T.SPECIAL_COST, T.SPECIAL_RATE, T.EXTERNAL_ID :
1 FROM PMO_TMP_CPLN01_TEMP T:
1 LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=rs.RES_ID WHERE T.RESOURCE+
1_TYPE IN ('0') :
1 UNION ALL :
1 SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME, T.TYPE_ID, :
1 '' AS E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T+
1.START_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1 T.BEST_START, T.BEST_FINISH, T.ASSIGNABLE AS CALENDAR, :
1 T.PLANNED AS PLANNED_WORK,T.SCHED AS SCHED_WORK, T.WORK_EFFORT, :
1 AS UNIT_EFFORT, :
1 T.PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING,'' AS OBJECTIVES,'' AS RANK, :
1 T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED+
1_REMAINING, :
1  T.PRJ_SCHED_START, T.PRJ_SCHED_FINISH, T.SCHED_REMAINING, T.REGULAR_COST, T+
1.REGULAR_RATE, T.SPECIAL_COST, T.SPECIAL_RATE, T.EXTERNAL_ID :
1 FROM PMO_TMP_CPLN01_TEMP T LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID+
1=rs.RES_ID :
1 WHERE T.RESOURCE_TYPE = '1' ORDER BY TYPE_ID,ELEMENT_NAME:
1DELETE FROM PMO_TMP_CPLN_0001:
1INSERT INTO PMO_TMP_CPLN_0001 :
1SELECT  RESOURCE_ID, MIN(PLANNED_START) AS PLANNED_START, :
1 MAX(PLANNED_FINISH) AS PLANNED_FINISH,   SUM(PLANNED_WORK) AS PLANNED_EFFORT+
1, :
1 MIN(SCHED_START) AS START_DATE,          MAX(SCHED_FINISH) AS FINISH_DATE, :
1 SUM(SCHED_WORK) AS WORK,                 SUM(ETC) AS REMAINING :
1 RESOURCE_ID IN (':
1') AND PROJECT_ID<>TASK_ID GROUP BY RESOURCE_ID:
11729:
1           EXCEPTION:: SP_SEARCH_1(1730) :: cplan.sql(4259) :: :
1INSERT INTO PMO_TMP_CPLN_0002 :
1SELECT RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,      MIN(PLANNED_START) AS PRJ_P+
1LANNED_START, :
1 MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH, SUM(PLANNED_WORK) AS PLANNED_REMA+
1INING, :
1 MIN(SCHED_START) AS PRJ_SCHED_START,       MAX(SCHED_FINISH) AS PRJ_SCHED_FI+
1NISH, :
1 SUM(SCHED_WORK) AS SCHED_REMAINING :
1 FROM TASK_ASSIGNMENTS WHERE TASK_ID=':
1' AND RESOURCE_ID IN (':
1') GROUP BY RESOURCE_ID:
11761:
1           EXCEPTION:: SP_SEARCH_1(1762) :: cplan.sql(4291) :: :
1PLANNED_FINISH,PLANNED_EFFORT,START_DATE,FINISH_DATE,WORK,REMAINING,PROJECT_A+
1SSIGNMENT_ID,PRJ_PLANNED_START,:
1REGULAR_RATE,SPECIAL_COST,SPECIAL_RATE, EXTERNAL_ID):
1SELECT DISTINCT r.RESOURCE_ID, r.FULL_NAME,'0',CASE WHEN ta.TSK_ASSIGNMENT_ID+
1 IS NuLL THEN 185 ELSE 13 END ,:
1tb.PROJECT_ASSIGNMENT_ID, tb.PRJ_PLANNED_START, tb.PRJ_PLANNED_FINISH, tb.PLA+
1NNED_REMAINING,:
1FROM RESOURCES r LEFT OUTER JOIN PMO_TMP_CPLN_0001 a ON a.RESOURCE_ID=r.RESOU+
1RCE_ID :
1WHERE r.RESOURCE_ID IN (':
1'):
11799:
1           EXCEPTION:: SP_SEARCH_1(1800) :: cplan.sql(4329) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME AS ELEMENT_NAME,+
1 T.TYPE_ID, :
1T.E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T.STAR+
1T_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR,rs.PLANNED AS PLANNED_WORK, :
1rs.SCHED AS SCHED_WORK, rs.PROPOSED AS WORK_EFFORT, :
1 AS UNIT_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILIT+
1Y, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1T.PROJECT_ASSIGNMENT_ID, T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED+
1_REMAINING, :
1FROM PMO_TMP_CPLN01_TEMP T :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=rs.RES_ID :
1ORDER BY ELEMENT_NAME:
1SELECT RESOURCE_ID, MIN(PLANNED_START) AS PLANNED_START, :
1       MAX(PLANNED_FINISH) AS PLANNED_FINISH,    SUM(PLANNED_WORK) AS PLANNED+
1_EFFORT, :
1       MIN(SCHED_START) AS START_DATE,           MAX(SCHED_FINISH) AS FINISH_+
1DATE, :
1       SUM(SCHED_WORK) AS WORK,                  SUM(ETC) AS REMAINING :
1 WHERE PROJECT_ID=':
1'        AND :
1       RESOURCE_ID IN (':
1')   AND :
1       PROJECT_ID<>TASK_ID GROUP BY RESOURCE_ID :
11846:
1           EXCEPTION:: SP_SEARCH_1(1847) :: cplan.sql(4376) :: :
1SELECT    RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,          MIN(PLANNED_START) A+
1S PRJ_PLANNED_START, :
1          MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH,     SUM(PLANNED_WORK) AS+
1 PLANNED_REMAINING, :
1          MIN(SCHED_START) AS PRJ_SCHED_START,           MAX(SCHED_FINISH) AS+
1 PRJ_SCHED_FINISH, :
1          SUM(SCHED_WORK) AS SCHED_REMAINING  :
1') GROUP BY RESOURCE_ID :
11878:
1           EXCEPTION:: SP_SEARCH_1(1879) :: cplan.sql(4408) :: :
1REGULAR_RATE,SPECIAL_COST,SPECIAL_RATE) :
1SELECT DISTINCT p.PROFILE_ID , p.PROFILE_NAME ,'1', 41 ,:
1'' , a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.START_DATE, a.FIN+
1ISH_DATE, a.WORK, a.REMAINING,:
1tb.PRJ_SCHED_START, tb.PRJ_SCHED_FINISH, tb.SCHED_REMAINING, pa.REGULAR_COST,+
1 pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE :
1FROM PROFILES p LEFT OUTER JOIN PMO_TMP_CPLN_0001 a ON p.PROFILE_ID=a.RESOURC+
1E_ID JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=p.ROLE_ID :
1JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID :
11916:
1           EXCEPTION:: SP_SEARCH_1(1917) :: cplan.sql(4446) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME, T.TYPE_ID, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR, :
1rs.PLANNED AS PLANNED_WORK,rs.SCHED AS SCHED_WORK, rs.PROPOSED AS WORK_EFFORT+
1, :
1(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1  :
1T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED_+
1REMAINING, :
1FROM PMO_TMP_CPLN01_TEMP T LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=+
1rs.RES_ID :
11938:
1                EXIT:: SP_SEARCH_1(1939) :: cplan.sql(4468) :: :
11941:
1                EXIT:: SP_SEARCH_1(1942) :: cplan.sql(4471) :: :
1PMO_SELECT_READ:
1RETURN_ERROR_EXCEPTION:
11949:
1           EXCEPTION:: SP_SEARCH_1(1950) :: cplan.sql(4479) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11961:
1           EXCEPTION:: SP_SEARCH_1(1962) :: cplan.sql(4491) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
32fc
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 81 b0 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d a0 6e d a0 4d d :4 a0
51 a5 b a5 b d a0 51
d a0 51 d a0 51 d a0
7e b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 b7 19 3c a0 7e
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e a 10 :2 a0
51 a5 b 7e 51 b4 2e a
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a a 10 :8 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 19 3c a0
51 d a0 b7 a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a a 10
:3 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 d a0
7e b4 2e 5a a0 6e d b7
19 3c :3 a0 :2 51 a5 b d :3 a0
:2 51 a5 b d :2 a0 d :2 a0 51
a5 b 7e 51 b4 2e :4 a0 :2 51
a5 b :2 51 a5 b d :3 a0 6b
:3 51 a0 a5 b d :3 a0 51 a5
b a5 b 7e 51 b4 2e :d a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :45 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
:7 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 7e b4 2e 5a
a0 51 d b7 19 3c :b a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c b7 a0 51 d b7
:2 19 3c a0 51 d :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 6e a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 19 3c
b7 :b a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 19 3c b7 :2 19 3c :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 51 a5 b a0 7e a0
6b b4 2e 52 10 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 51 a5 b a0
7e a0 6b b4 2e a 10 a0
51 d b7 19 3c a0 51 d
a0 51 d b7 a0 7e 51 b4
2e :2 a0 d :2 a0 d :6 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :3 a0 a5 b
d :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 :2 19 3c :2 a0
d a0 7e b4 2e 5a a0 6e
d b7 19 3c a0 b7 :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 a0 51
d a0 b7 :2 a0 51 a5 b 7e
51 b4 2e a0 51 d a0 b7
19 :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 a0 51 d
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e d a0
51 d b7 :2 19 3c b7 :2 19 3c
b7 :2 19 3c :2 a0 b4 2e d a0
6e d a0 6e d :3 a0 6b :3 a0
51 a5 b :2 a0 6b a5 b 5a
51 a5 b d :4 a0 51 a5 b
:2 a0 6b a5 b d :2 a0 51 a5
b 7e 51 b4 2e :8 a0 a5 b
d :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 51 a5 b 7e
51 b4 2e :3 a0 6b d b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 51 a5 b :2 a0 a5
57 b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
51 a5 b :2 a0 a5 57 b7 19
3c a0 4d d :14 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
7e b4 2e :2 5a a 10 a0 51
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d b7 19 3c b7 19
3c a0 51 d a0 51 d a0
7e 51 b4 2e :2 a0 :2 51 a5 b
7e 6e b4 2e :22 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
51 d :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :20 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 51 d b7 :2 19 3c a0
b7 :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 :20 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :20 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :2 a0 :2 51 a5 b 7e 6e b4
2e :19 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a a0 51 d :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a 52 10 :14 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 a0 51
d 4f b7 :2 19 3c a0 b7 :2 a0
6b a0 7e a0 6b b4 2e 5a
:17 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 :17 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 a0 b7
a0 7e b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e a 10 a0
7e 51 b4 2e a0 51 d :f a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 a0 51 d :c a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 :2 19 3c a0 51 d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
5a :3 a0 51 a5 b a5 b 5a
7e 51 b4 2e a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 19 3c
:2 a0 :2 51 a5 b 7e 6e b4 2e
:3 a0 7e a0 b4 2e :2 51 a5 b
d :15 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :2 a0 :2 51
a5 b 7e 6e b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 5a a 10 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :c a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :3 a0
7e a0 b4 2e :2 51 a5 b d
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :14 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :c a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 d :2 a0 51 a5 b
7e 51 b4 2e :a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :a a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 51 d :2 a0 d :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
b7 19 3c :1e a0 :5 51 a5 b d
a0 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :4 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 19 3c b7 :2 a0 d :2 a0
d :2 a0 :2 51 a5 b 7e 6e b4
2e :3 a0 6b d b7 :4 a0 51 a5
b :2 a0 6b a5 b d b7 :2 19
3c :1e a0 :5 51 a5 b d a0 7e
51 b4 2e :4 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c b7 :2 19
3c b7 :3 a0 a5 b 51 a5 b
7e 51 b4 2e a0 51 d b7
:5 a0 a5 b 51 a5 b 7e 51
b4 2e 5a 7e 51 b4 2e a5
b d b7 :2 19 3c a0 7e 51
b4 2e a0 51 d :3 a0 51 a5
b a0 7e a0 b4 2e 82 a0
51 d :3 a0 6b :2 51 :2 a0 51 a5
b 7e 51 b4 2e 7e 51 b4
2e a0 a5 b d :3 a0 6b :2 51
:2 a0 51 a5 b 7e 51 b4 2e
7e 51 b4 2e 7e 51 b4 2e
a0 a5 b d :2 a0 d a0 51
d a0 51 d :2 a0 d :e a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
5a a0 7e b4 2e :2 5a a 10
a0 51 d :2 a0 6b :2 a0 a5 b
7e 51 b4 2e :2 a0 d b7 19
3c b7 19 3c :2 a0 :2 51 a5 b
7e 6e b4 2e :3 a0 6b d :3 a0
a5 b 51 a5 b 7e 51 b4
2e :2 a0 d b7 :3 a0 7e 6e b4
2e :2 51 a5 b d :3 a0 7e a0
b4 2e :2 51 a5 b d b7 :2 19
3c b7 :3 a0 a5 b 51 a5 b
7e 51 b4 2e :2 a0 d b7 :3 a0
7e 6e b4 2e :2 51 a5 b d
:3 a0 7e a0 b4 2e :2 51 a5 b
d b7 :2 19 3c b7 :2 19 3c a0
51 d a0 51 d :2 a0 51 a5
b 7e 51 b4 2e a0 7e 51
b4 2e :2 a0 :2 51 a5 b 7e 6e
b4 2e :1c a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 51 d
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 :1a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 a0
51 d b7 :2 19 3c a0 b7 :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a 52 10 :1a a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :1c a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :2 a0
:2 51 a5 b 7e 6e b4 2e :1b a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :16 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 51 d 4f b7 :2 19 3c
a0 b7 :2 a0 6b a0 7e a0 6b
b4 2e 5a :19 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :19 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 a0 7e
b4 2e 5a a0 7e 51 b4 2e
a0 51 d :f a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 a0 51
d :c a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :3 a0 51 a5 b 7e 51
b4 2e d a0 3b b7 19 3c
b7 19 3c a0 51 d b7 :2 19
3c b7 :3 a0 51 a5 b 7e 51
b4 2e d a0 3b b7 :2 19 3c
:2 a0 d a0 51 d :a a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :a a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 51 d :2 a0 d :2 a0 51
a5 b 7e 51 b4 2e a0 51
d b7 19 3c :1e a0 :5 51 a5 b
d a0 7e 51 b4 2e :2 a0 51
a5 b 7e 51 b4 2e :4 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :4 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 19 3c a0 b7 :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d :2 a0 d :2 a0 :2 51 a5 b 7e
6e b4 2e :3 a0 6b d b7 :3 a0
51 a5 b d b7 :2 19 3c :1e a0
:5 51 a5 b d a0 7e 51 b4
2e :4 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 :2 19 3c :3 a0
51 a5 b 7e 51 b4 2e d
93 4f b0 46 b7 a0 47 b7
19 3c b7 :2 19 3c a0 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 51
a5 b 7e 51 b4 2e :3 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :7 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c a0 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 a0 b7
:2 a0 7e a0 6b b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 a0 b7 19
:2 a0 7e a0 6b b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 19
3c b7 19 3c :3 a0 a5 b 51
a5 b 7e 51 b4 2e 5a :3 a0
a5 b 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 6e 11e 11d
:2 a0 6b 51 d a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d :3 a0
11e 11d a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6e 11e 11d :2 a0 6b 51
d a0 6e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e d :3 a0 11e 11d a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 b4 2e d a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e d :3 a0
11e 11d a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 6e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 51 a5 b a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e d a0 b7 :3 a0 a5
b 51 a5 b 7e 51 b4 2e
:2 a0 6e 11e 11d :2 a0 6b 51 d
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d :3 a0 11e 11d a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6e 11e
11d :2 a0 6b 51 d a0 6e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e d :3 a0 11e 11d a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 b4 2e d a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d :3 a0
11e 11d a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 6e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e d b7 19 :2 a0 6e 11e 11d
:2 a0 6b 51 d a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e d :3 a0
11e 11d a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6e 11e 11d :2 a0 6b 51
d a0 6e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e d
:3 a0 11e 11d a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 b4 2e d
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d :3 a0 11e 11d a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 6e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e d b7 :2 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b a0 a5 b
65 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
32fc
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 16a 155
159 15c 15d 165 154 187 175 151
179 17a 182 174 1a4 192 171 196
197 19f 191 1c1 1af 18e 1b3 1b4
1bc 1ae 1de 1cc 1ab 1d0 1d1 1d9
1cb 1fb 1e9 1c8 1ed 1ee 1f6 1e8
218 206 1e5 20a 20b 213 205 235
223 202 227 228 230 222 252 240
21f 244 245 24d 23f 26f 25d 23c
261 262 26a 25c 28b 27a 27e 286
259 2a3 292 296 29e 279 2c0 2ae
276 2b2 2b3 2bb 2ad 2dd 2cb 2aa
2cf 2d0 2d8 2ca 2fa 2e8 2c7 2ec
2ed 2f5 2e7 317 305 2e4 309 30a
312 304 334 322 301 326 327 32f
321 351 33f 31e 343 344 34c 33e
36d 35c 360 33b 368 35b 389 378
37c 358 384 377 3a5 394 398 374
3a0 393 3c1 3b0 3b4 390 3bc 3af
3dd 3cc 3d0 3ac 3d8 3cb 3f9 3e8
3ec 3c8 3f4 3e7 415 404 408 3e4
410 403 431 420 424 400 42c 41f
44d 43c 440 41c 448 43b 469 458
45c 438 464 457 485 474 478 454
480 473 4a1 490 494 470 49c 48f
4bd 4ac 4b0 48c 4b8 4ab 4d9 4c8
4cc 4a8 4d4 4c7 4f5 4e4 4e8 4c4
4f0 4e3 511 500 504 4e0 50c 4ff
52d 51c 520 4fc 528 51b 549 538
53c 518 544 537 565 554 558 534
560 553 581 570 574 550 57c 56f
59d 58c 590 56c 598 58b 5b9 5a8
5ac 588 5b4 5a7 5d5 5c4 5c8 5a4
5d0 5c3 5f1 5e0 5e4 5c0 5ec 5df
60d 5fc 600 5dc 608 5fb 629 618
61c 5f8 624 617 645 634 638 614
640 633 661 650 654 630 65c 64f
67e 66c 64c 670 671 679 66b 69b
689 668 68d 68e 696 688 6b7 6a6
6aa 685 6b2 6a5 6d4 6c2 6a2 6c6
6c7 6cf 6c1 6f0 6df 6e3 6be 6eb
6de 70d 6fb 6db 6ff 700 708 6fa
72a 718 6f7 71c 71d 725 717 747
735 714 739 73a 742 734 763 752
756 731 75e 751 77f 76e 772 74e
77a 76d 79b 78a 78e 76a 796 789
7b8 7a6 786 7aa 7ab 7b3 7a5 7d5
7c3 7a2 7c7 7c8 7d0 7c2 7f1 7e0
7e4 7bf 7ec 7df 80d 7fc 800 7dc
808 7fb 82a 818 7f8 81c 81d 825
817 846 835 839 814 841 834 862
851 855 831 85d 850 87e 86d 871
84d 879 86c 89a 889 88d 869 895
888 8b6 8a5 8a9 8b1 885 8d5 8bd
8c1 8c5 8c8 8d0 8a4 8dc 8e0 8a1
8e4 8e8 8ec 8ef 8f4 8f5 1 8f7
8fc 900 904 907 90c 910 914 917
91c 91d 91f 924 927 92b 92c 931
936 939 93e 93f 944 947 94b 94c
951 954 959 95a 95f 962 967 968
96d 970 975 976 97b 97e 982 983
988 98b 990 991 996 999 99e 99f
9a4 9a7 9ac 9ad 9b2 9b5 9b9 9ba
9bf 9c2 9c7 9c8 9cd 9d0 9d5 9d6
9db 9de 9e2 9e6 9ea 9eb 9ed 9f2
9f3 9f5 9f6 9fb 9fe a03 a04 a09
a0c a10 a14 a18 a19 a1b a20 a21
a23 a24 a29 a2c a31 a32 a37 a3a
a3e a42 a46 a47 a49 a4e a4f a51
a52 a57 a5a a5f a60 a65 a68 a6c
a70 a74 a75 a77 a7c a7d a7f a80
a85 a88 a8d a8e a93 a96 a9a a9e
aa2 aa3 aa5 aaa aab aad aae ab3
ab6 abb abc ac1 ac4 ac8 acc ad0
ad1 ad3 ad8 ad9 adb adc ae1 ae4
ae9 aea aef af2 af6 afa afe aff
b01 b06 b07 b09 b0a b0f b12 b17
b18 b1d b20 b24 b28 b2c b2d b2f
b34 b35 b37 b38 b3d b40 b45 b46
b4b b4e b52 b56 b5a b5b b5d b62
b63 b65 b66 b6b b6e b73 b74 b79
b7c b80 b84 b88 b89 b8b b90 b91
b93 b94 b99 b9c ba1 ba2 ba7 baa
baf bb0 bb5 bb8 bbc bbd bc2 bc5
bca bcb bd0 bd3 bd8 bd9 bde be1
be6 be7 bec bef bf3 bf4 bf9 bfc
c01 c02 c07 c0a c0f c10 c15 c16
c1b c1d c21 c24 c28 c2c c2f c33
c37 c3a c3d c42 c45 c48 c4b c4c
c51 c52 1 c54 c59 c5d c61 c64
c69 c6e c71 c75 c76 c7b c7c c81
c83 c87 c8a c8e c92 c96 c9a c9e
ca2 ca6 caa cae cb2 cb6 cba cbe
cc2 cc6 cca cce cd2 cd6 cda cde
ce2 ce6 cea cee cf2 cf6 cfa cfe
d02 d06 d0a d0e d12 d16 d1a d1e
d22 d26 d2a d2e d32 d36 d3a d3e
d42 d47 d4b d4f d50 d54 d58 d5c
d60 d64 d67 d68 d6a d6b d6d d71
d75 d78 d7c d80 d83 d87 d8b d8e
d92 d96 d99 d9a d9f da2 da6 daa
dad db1 db5 db8 dbb dc0 dc3 dc6
dc9 dca dcf dd0 1 dd2 dd7 ddb
ddf de2 de7 dec def df3 df4 df9
dfc e01 e02 e07 e0a e0f e10 e15
e18 e1c e20 e24 e28 e2b e2c e2e
e33 e34 e36 e37 e3c e3d e42 e44
e48 e4b e4f e53 e56 e5a e5e e61
e64 e69 e6c e6f e72 e73 e78 e79
1 e7b e80 e84 e88 e8b e90 e95
e98 e9c e9d ea2 ea3 ea8 eaa eae
eb1 eb5 eb9 ebc ec0 ec4 ec7 ecb
ecc ed1 ed3 ed7 eda ede ee1 ee2
ee7 eea eee ef2 ef5 ef9 efd f00
f03 f08 f0b f0e f11 f12 f17 f18
1 f1a f1f f23 f27 f2a f2f f34
f37 f3b f3c f41 f44 f49 f4a f4f
f52 f57 f58 f5d f60 f64 f68 f6c
f70 f73 f74 f76 f7b f7c f7e f7f
f84 f85 f8a f8c f90 f93 f97 f9b
f9e fa2 fa6 fa9 fac fb1 fb4 fb7
fba fbb fc0 fc1 1 fc3 fc8 fcc
fd0 fd3 fd8 fdd fe0 fe4 fe5 fea
feb ff0 ff2 ff6 ff9 ffd 1001 1004
1008 100c 100f 1013 1014 1019 101b 101f
1022 1026 102a 102d 102e 1030 1033 1036
1037 103c 1040 1044 1047 1048 104a 104d
1050 1051 1 1056 105b 105f 1063 1066
1067 1069 106c 106f 1070 1 1075 107a
107e 1082 1085 1089 108d 1090 1093 1098
109b 109e 10a1 10a2 10a7 10a8 1 10aa
10af 10b3 10b7 10ba 10bf 10c4 10c7 10cb
10cc 10d1 10d4 10d9 10da 10df 10e2 10e7
10e8 10ed 10f0 10f4 10f8 10fc 1100 1103
1104 1106 110b 110c 110e 110f 1114 1115
111a 111c 1120 1123 1127 112b 112e 1132
1136 1139 113c 1141 1144 1147 114a 114b
1150 1151 1 1153 1158 115c 1160 1163
1168 116d 1170 1174 1175 117a 117b 1180
1182 1186 1189 118d 1191 1194 1198 119c
119f 11a3 11a4 11a9 11ab 11af 11b2 11b6
11b9 11ba 11bf 11c2 11c5 11c9 11cc 11cd
11d2 11d5 1 11d8 11dd 11e1 11e5 11e9
11ed 11f1 11f5 11f9 11fd 1209 120d 1211
1214 1218 121c 121e 1222 1226 122a 122d
1231 1235 1237 1238 123d 1 1241 1245
1249 124c 1250 1254 1258 125c 125f 1263
1267 126a 126d 1272 1275 1278 127b 127c
1281 1282 1 1284 1289 128d 1291 1294
1299 129e 12a1 12a5 12a6 12ab 12ae 12b3
12b4 12b9 12bc 12c1 12c2 12c7 12ca 12ce
12cf 12d4 12d7 12dc 12dd 12e2 12e5 12e9
12ed 12f0 12f3 12f4 12f6 12f7 12fc 12fd
1302 1304 1308 130b 130d 1311 1313 131f
1321 1323 1324 1329 132d 132f 133b 133d
1341 1345 1348 134c 134f 1353 1356 1357
135c 135f 1363 1367 136a 136b 136d 1370
1373 1374 1379 1 137c 1381 1385 1389
138c 1390 1394 1397 139a 139f 13a2 13a5
13a8 13a9 13ae 13af 1 13b1 13b6 13ba
13be 13c1 13c6 13cb 13ce 13d2 13d3 13d8
13db 13e0 13e1 13e6 13e9 13ee 13ef 13f4
13f7 13fb 13ff 1403 1407 140a 140b 140d
1412 1413 1415 1416 141b 141c 1421 1423
1427 142a 142e 1432 1435 1439 143d 1440
1443 1448 144b 144e 1451 1452 1457 1458
1 145a 145f 1463 1467 146a 146f 1474
1477 147b 147c 1481 1482 1487 1489 148d
1490 1494 1498 149b 149f 14a3 14a6 14aa
14ab 14b0 14b2 14b6 14b9 14bd 14c0 14c4
14c8 14ca 14ce 14d1 14d2 14d7 14da 14dd
14e1 14e4 14e5 14ea 14ed 1 14f0 14f5
14f9 14fd 1501 150d 1511 1515 1518 151c
1520 1522 1526 152a 152e 1531 1535 1539
153b 153c 1541 1 1545 1549 154d 1550
1554 1558 155c 1560 1563 1567 156b 156e
1571 1576 1579 157c 157f 1580 1585 1586
1 1588 158d 1591 1595 1598 159d 15a2
15a5 15a9 15aa 15af 15b2 15b7 15b8 15bd
15c0 15c5 15c6 15cb 15ce 15d2 15d3 15d8
15db 15e0 15e1 15e6 15e9 15ed 15f1 15f4
15f7 15f8 15fa 15fb 1600 1601 1606 1608
160c 160f 1611 1615 1617 1623 1625 1627
1628 162d 1631 1633 163f 1641 1643 1647
164b 164e 1652 1656 165a 165e 1661 1662
1667 166a 166e 1673 1677 1679 167d 1680
1684 1688 168c 168f 1692 1693 1695 1699
169d 16a1 16a5 16a8 16ab 16ac 16ae 16b2
16b6 16ba 16be 16c2 16c6 16c9 16ca 16cc
16cf 16d2 16d3 16d8 16dc 16e0 16e4 16e8
16eb 16ee 16ef 16f1 16f4 16f7 16f8 16fa
16fe 1702 1706 170a 170d 1710 1713 1716
171a 171b 171d 1721 1725 1729 172d 1730
1731 1733 1734 1736 1739 173c 173d 1742
1746 174a 174e 1752 1756 175a 175e 1762
1766 176a 176e 1772 1776 1782 1786 178a
178d 1791 1795 1797 179b 179f 17a3 17a6
17aa 17ae 17b0 17b1 17b6 1 17ba 17be
17c2 17c5 17c9 17cd 17d1 17d5 17d8 17dc
17e0 17e3 17e6 17eb 17ee 17f1 17f4 17f5
17fa 17fb 1 17fd 1802 1806 180a 180d
1812 1817 181a 181e 181f 1824 1827 182c
182d 1832 1835 183a 183b 1840 1843 1847
1848 184d 1850 1855 1856 185b 185e 1862
1866 1869 186c 186d 186f 1870 1875 1876
187b 187d 1881 1884 1886 188a 188c 1898
189a 189c 189d 18a2 18a6 18a8 18b4 18b6
18b8 18bc 18c0 18c4 18c8 18cc 18d0 18d4
18d8 18dc 18e0 18e4 18e8 18ec 18f0 18f4
18f8 18fc 1900 1904 1908 190c 1910 1914
1918 191c 1920 1924 1928 192c 1930 1934
1938 193c 1940 1944 1948 194c 1950 1954
1958 195c 1960 1964 1968 196c 1970 1974
1978 197c 1980 1984 1988 198c 1990 1994
1998 199c 19a0 19a4 19a8 19ac 19b0 19b4
19b8 19bc 19c0 19c4 19c8 19cc 19d8 19dc
19e0 19e3 19e7 19eb 19ed 19f1 19f5 19f9
19fc 1a00 1a04 1a06 1a07 1a0c 1 1a10
1a14 1a18 1a1b 1a1f 1a23 1a27 1a2b 1a2e
1a32 1a36 1a39 1a3c 1a41 1a44 1a47 1a4a
1a4b 1a50 1a51 1 1a53 1a58 1a5c 1a60
1a63 1a68 1a6d 1a70 1a74 1a75 1a7a 1a7d
1a82 1a83 1a88 1a8b 1a90 1a91 1a96 1a99
1a9d 1a9e 1aa3 1aa6 1aab 1aac 1ab1 1ab4
1ab8 1abc 1abf 1ac2 1ac3 1ac5 1ac6 1acb
1acc 1ad1 1ad3 1ad7 1ada 1adc 1ae0 1ae2
1aee 1af0 1af2 1af3 1af8 1afc 1afe 1b0a
1b0c 1b0e 1b12 1b16 1b19 1b1d 1b21 1b24
1b28 1b2b 1b2f 1b32 1b33 1b38 1b3b 1b3f
1b43 1b47 1b4b 1b4f 1b53 1b57 1b63 1b67
1b6b 1b6e 1b72 1b76 1b78 1b7c 1b80 1b84
1b87 1b8b 1b8f 1b91 1b92 1b97 1 1b9b
1b9f 1ba3 1ba6 1baa 1bae 1bb2 1bb6 1bb9
1bbd 1bc1 1bc4 1bc7 1bcc 1bcf 1bd2 1bd5
1bd6 1bdb 1bdc 1 1bde 1be3 1be7 1beb
1bee 1bf3 1bf8 1bfb 1bff 1c00 1c05 1c08
1c0d 1c0e 1c13 1c16 1c1b 1c1c 1c21 1c24
1c28 1c29 1c2e 1c31 1c36 1c37 1c3c 1c3f
1c43 1c47 1c4a 1c4d 1c4e 1c50 1c51 1c56
1c57 1c5c 1c5e 1c62 1c65 1c67 1c6b 1c6d
1c79 1c7b 1c7d 1c7e 1c83 1c87 1c89 1c95
1c97 1c9b 1c9f 1ca2 1ca6 1ca9 1cad 1cb0
1cb1 1cb6 1cb9 1cbd 1cc0 1cc1 1cc6 1cc9
1ccd 1cd0 1cd4 1cd6 1cda 1cdd 1ce1 1ce5
1ce9 1ced 1cf1 1cf5 1cf9 1cfd 1d01 1d05
1d09 1d15 1d19 1d1d 1d20 1d24 1d28 1d2a
1d2e 1d32 1d36 1d39 1d3d 1d41 1d43 1d44
1d49 1 1d4d 1d51 1d55 1d58 1d5c 1d60
1d64 1d68 1d6b 1d6f 1d73 1d76 1d79 1d7e
1d81 1d84 1d87 1d88 1d8d 1d8e 1 1d90
1d95 1d99 1d9d 1da0 1da5 1daa 1dad 1db1
1db2 1db7 1dba 1dbf 1dc0 1dc5 1dc8 1dcd
1dce 1dd3 1dd6 1dda 1ddb 1de0 1de3 1de8
1de9 1dee 1df1 1df5 1df9 1dfc 1dff 1e00
1e02 1e03 1e08 1e09 1e0e 1e10 1e14 1e17
1e19 1e1d 1e1f 1e2b 1e2d 1e2f 1e30 1e35
1e39 1e3b 1e47 1e49 1e4b 1e4f 1e53 1e56
1e5a 1e5e 1e61 1e64 1e69 1e6c 1e6f 1e72
1e73 1e78 1e79 1 1e7b 1e80 1e84 1e88
1e8b 1e90 1e95 1e98 1e9c 1e9d 1ea2 1ea5
1eaa 1eab 1eb0 1eb3 1eb8 1eb9 1ebe 1ec1
1ec5 1ec9 1ecd 1ed1 1ed4 1ed5 1ed7 1edc
1edd 1edf 1ee0 1ee5 1ee8 1eed 1eee 1ef3
1ef6 1efb 1efc 1f01 1f04 1f08 1f09 1f0e
1f11 1f16 1f17 1f1c 1f1d 1f22 1f24 1f28
1f2b 1f2f 1f33 1f36 1f3a 1f3e 1f41 1f44
1f49 1f4c 1f4f 1f52 1f53 1f58 1f59 1
1f5b 1f60 1f64 1f68 1f6b 1f70 1f75 1f78
1f7c 1f7d 1f82 1f83 1f88 1f8a 1f8e 1f91
1f95 1f99 1f9c 1fa0 1fa4 1fa7 1fab 1faf
1fb0 1fb5 1fb7 1fbb 1fbf 1fc2 1fc4 1fc8
1fcb 1fcf 1fd1 1fd5 1fd9 1fdc 1fe0 1fe3
1fe7 1feb 1fef 1ff3 1ff7 1ffb 2007 200b
200f 2012 2016 201a 201c 2020 2024 2028
202b 202f 2033 2035 2036 203b 1 203f
2043 2047 204a 204e 2052 2056 205a 205d
2061 2065 2068 206b 2070 2073 2076 2079
207a 207f 2080 1 2082 2087 208b 208f
2092 2097 209c 209f 20a3 20a4 20a9 20ac
20b1 20b2 20b7 20ba 20bf 20c0 20c5 20c8
20cc 20cd 20d2 20d5 20da 20db 20e0 20e3
20e7 20eb 20ee 20f1 20f2 20f4 20f5 20fa
20fb 2100 2102 2106 2109 210b 210f 2111
211d 211f 2121 2122 2127 212b 212d 2139
213b 213f 2143 2146 2147 2149 214c 214f
2150 2155 2159 215d 2161 2165 2169 2175
2179 217d 2180 2184 2188 218a 218e 2192
2196 2199 219d 21a1 21a3 21a4 21a9 1
21ad 21b1 21b5 21b8 21bc 21c0 21c4 21c8
21cb 21cf 21d3 21d6 21d9 21de 21e1 21e4
21e7 21e8 21ed 21ee 1 21f0 21f5 21f9
21fd 2200 2205 220a 220d 2211 2212 2217
221a 221f 2220 2225 2228 222d 222e 2233
2236 223a 223b 2240 2243 2248 2249 224e
2251 2255 2259 225c 225f 2260 2262 2263
2268 2269 226e 2270 2274 2277 2279 227d
227f 228b 228d 228f 2290 2295 2299 229b
22a7 22a9 22ad 22b1 22b4 22b8 22bd 22be
22c0 22c3 22c6 22c7 22cc 22d0 22d4 22d7
22db 22df 22e2 22e5 22ea 22ed 22f0 22f3
22f4 22f9 22fa 1 22fc 2301 2305 2309
230c 2311 2316 2319 231d 231e 2323 2326
232b 232c 2331 2334 2339 233a 233f 2342
2346 234a 234e 2352 2355 2356 2358 235d
235e 2360 2361 2366 2369 236e 236f 2374
2377 237c 237d 2382 2385 2389 238a 238f
2392 2397 2398 239d 239e 23a3 23a5 23a9
23ac 23b0 23b4 23b7 23bb 23bf 23c2 23c5
23ca 23cd 23d0 23d3 23d4 23d9 23da 1
23dc 23e1 23e5 23e9 23ec 23f1 23f6 23f9
23fd 23fe 2403 2404 2409 240b 240f 2412
2416 241a 241d 2421 2425 2428 242c 2430
2431 2436 2438 243c 243f 2441 2445 2448
244a 244e 2452 2456 245a 245e 2462 2466
246a 246e 2472 2476 2482 2486 248a 248d
2491 2495 2497 249b 249f 24a3 24a6 24aa
24ae 24b0 24b1 24b6 1 24ba 24be 24c2
24c5 24c9 24cd 24d1 24d5 24d8 24dc 24e0
24e3 24e6 24eb 24ee 24f1 24f4 24f5 24fa
24fb 1 24fd 2502 2506 250a 250d 2512
2517 251a 251e 251f 2524 2527 252c 252d
2532 2535 253a 253b 2540 2543 2547 2548
254d 2550 2555 2556 255b 255e 2562 2566
2569 256c 256d 256f 2570 2575 2576 257b
257d 2581 2584 2586 258a 258c 2598 259a
259c 259d 25a2 25a6 25a8 25b4 25b6 25ba
25be 25c1 25c5 25c8 25cc 25cf 25d0 25d5
25d8 25dc 25e0 25e4 25e8 25ec 25f8 25fc
2600 2603 2607 260b 260d 2611 2615 2619
261c 2620 2624 2626 2627 262c 1 2630
2634 2638 263b 263f 2643 2647 264b 264e
2652 2656 2659 265c 2661 2664 2667 266a
266b 2670 2671 1 2673 2678 267c 2680
2683 2688 268d 2690 2694 2695 269a 269d
26a2 26a3 26a8 26ab 26b0 26b1 26b6 26b9
26bd 26be 26c3 26c6 26cb 26cc 26d1 26d4
26d8 26dc 26df 26e2 26e3 26e5 26e6 26eb
26ec 26f1 26f3 26f7 26fa 26fc 2700 2702
270e 2710 2712 2713 2718 271c 271e 272a
272c 2730 2734 2737 273b 273e 2742 2745
2746 274b 274e 2752 2756 2759 275d 2761
2764 2767 276c 276f 2772 2775 2776 277b
277c 1 277e 2783 2787 278b 278e 2793
2798 279b 279f 27a0 27a5 27a8 27ad 27ae
27b3 27b6 27bb 27bc 27c1 27c4 27c8 27cc
27d0 27d4 27d7 27d8 27da 27df 27e0 27e2
27e3 27e8 27eb 27f0 27f1 27f6 27f9 27fe
27ff 2804 2807 280b 280c 2811 2814 2819
281a 281f 2820 2825 2827 282b 282e 2832
2836 2839 283d 2841 2844 2847 284c 284f
2852 2855 2856 285b 285c 1 285e 2863
2867 286b 286e 2873 2878 287b 287f 2880
2885 2886 288b 288d 2891 2894 2898 289c
289f 28a3 28a7 28aa 28ae 28b2 28b3 28b8
28ba 28be 28c1 28c3 28c7 28ca 28cc 28d0
28d4 28d7 28db 28df 28e2 28e3 28e5 28e9
28ec 28f0 28f3 28f4 28f9 28fd 2901 2904
2905 2907 290b 290e 2912 2915 2916 1
291b 2920 2923 2927 292b 292e 292f 2931
2934 2937 2938 293d 1 2940 2945 2949
294d 2950 2951 2953 2957 295a 295e 2961
2962 2967 296b 296f 2972 2973 2975 2979
297c 2980 2983 2984 1 2989 298e 2992
2995 2999 299b 299f 29a2 29a6 29a9 29ad
29b1 29b4 29b8 29ba 29be 29c1 29c4 29c5
29ca 29ce 29d2 29d6 29da 29de 29e2 29e6
29ea 29ee 29f2 29f6 29fa 29fd 29fe 2a00
2a04 2a08 2a0b 2a0c 2a0e 2a12 2a16 2a19
2a1a 2a1c 2a20 2a24 2a27 2a28 2a2a 2a2e
2a32 2a35 2a36 2a38 2a3c 2a40 2a43 2a44
2a46 2a4a 2a4e 2a51 2a52 2a54 2a58 2a5c
2a5f 2a60 2a62 2a66 2a6a 2a6e 2a6f 2a71
2a75 2a79 2a7d 2a80 2a81 2a83 2a87 2a8a
2a8e 2a91 2a92 2a97 2a9b 2a9f 2aa2 2aa6
2aaa 2aad 2ab0 2ab5 2ab8 2abb 2abe 2abf
2ac4 2ac5 1 2ac7 2acc 2ad0 2ad4 2ad7
2adc 2ae1 2ae4 2ae8 2ae9 2aee 2af1 2af6
2af7 2afc 2aff 2b04 2b05 2b0a 2b0d 2b11
2b15 2b19 2b1d 2b20 2b21 2b23 2b28 2b29
2b2b 2b2c 2b31 2b32 2b37 2b39 2b3d 2b40
2b44 2b48 2b4b 2b4f 2b53 2b56 2b59 2b5e
2b61 2b64 2b67 2b68 2b6d 2b6e 1 2b70
2b75 2b79 2b7d 2b80 2b85 2b8a 2b8d 2b91
2b92 2b97 2b98 2b9d 2b9f 2ba3 2ba6 2baa
2bae 2bb1 2bb5 2bb9 2bbc 2bc0 2bc1 2bc6
2bca 2bcc 2bd0 2bd4 2bd7 2bd8 2bda 2bdd
2be0 2be1 2be6 2bea 2bee 2bf1 2bf5 2bf9
2bfc 2bff 2c04 2c07 2c0a 2c0d 2c0e 2c13
2c14 1 2c16 2c1b 2c1f 2c23 2c26 2c2b
2c30 2c33 2c37 2c38 2c3d 2c40 2c45 2c46
2c4b 2c4e 2c53 2c54 2c59 2c5c 2c60 2c64
2c68 2c69 2c6b 2c70 2c71 2c73 2c74 2c79
2c7c 2c81 2c82 2c87 2c8a 2c8f 2c90 2c95
2c98 2c9c 2c9d 2ca2 2ca5 2caa 2cab 2cb0
2cb1 2cb6 2cb8 2cbc 2cbf 2cc3 2cc7 2cca
2cce 2cd2 2cd5 2cd8 2cdd 2ce0 2ce3 2ce6
2ce7 2cec 2ced 1 2cef 2cf4 2cf8 2cfc
2cff 2d04 2d09 2d0c 2d10 2d11 2d16 2d17
2d1c 2d1e 2d22 2d25 2d29 2d2d 2d30 2d34
2d38 2d3b 2d3c 2d3e 2d42 2d46 2d47 2d4c
2d4e 2d52 2d56 2d59 2d5d 2d61 2d65 2d69
2d6c 2d6d 2d72 2d75 2d79 2d7e 2d82 2d84
2d88 2d8b 2d8f 2d91 2d95 2d99 2d9c 2d9d
2d9f 2da2 2da5 2da6 2dab 2dae 2db2 2db6
2db9 2dba 2dbc 2dbf 2dc2 2dc3 2dc8 1
2dcb 2dd0 2dd4 2dd8 2ddb 2ddc 2dde 2de1
2de4 2de5 2dea 2ded 2df1 2df5 2df8 2df9
2dfb 2dfe 2e01 2e02 2e07 1 2e0a 2e0f
2e13 2e16 2e1a 2e1e 2e20 2e24 2e28 2e2b
2e2c 2e2e 2e31 2e34 2e35 2e3a 2e3e 2e41
2e45 2e49 2e4b 2e4f 2e53 2e57 2e5a 2e5b
2e5d 2e60 2e63 2e64 2e69 2e6c 2e70 2e74
2e77 2e78 2e7a 2e7d 2e80 2e81 2e86 1
2e89 2e8e 2e92 2e95 2e99 2e9d 2e9f 2ea3
2ea7 2eab 2eae 2eaf 2eb1 2eb4 2eb7 2eb8
2ebd 2ec1 2ec5 2ec9 2ecc 2ecd 2ecf 2ed2
2ed6 2eda 2edd 2ede 2ee0 2ee1 2ee6 2eea
2eee 2ef1 2ef5 2ef7 2efb 2eff 2f02 2f04
2f08 2f0c 2f0f 2f11 2f15 2f19 2f1c 2f20
2f24 2f25 2f2a 2f2e 2f32 2f37 2f3b 2f3f
2f44 2f48 2f4c 2f50 2f54 2f57 2f5b 2f5f
2f63 2f66 2f67 2f69 2f6d 2f71 2f74 2f75
2f77 2f7a 2f7d 2f7e 2f80 2f84 2f88 2f8c
2f90 2f94 2f97 2f98 2f9a 2f9e 2fa2 2fa5
2fa6 2fa8 2fac 2fb0 2fb4 2fb7 2fb8 2fba
2fbd 2fc0 2fc1 2fc6 2fca 2fce 2fd2 2fd6
2fda 2fde 2fe2 2fe6 2fe7 2fe9 2fed 2ff1
2ff5 2ff8 2ff9 2ffb 2fff 3002 3006 3009
300a 300f 3013 3017 301a 301b 301d 3020
3023 3024 3029 302d 3031 3035 3038 303c
303e 3042 3045 3049 304d 3050 3054 3058
305b 305e 3063 3066 3069 306c 306d 3072
3073 1 3075 307a 307e 3082 3085 308a
308f 3092 3096 3097 309c 309f 30a4 30a5
30aa 30ad 30b2 30b3 30b8 30bb 30bf 30c3
30c7 30c8 30ca 30cf 30d0 30d2 30d3 30d8
30db 30e0 30e1 30e6 30e9 30ee 30ef 30f4
30f7 30fb 30fc 3101 3104 3109 310a 310f
3110 3115 3117 311b 311e 3122 3126 3129
312d 3131 3134 3137 313c 313f 3142 3145
3146 314b 314c 1 314e 3153 3157 315b
315e 3163 3168 316b 316f 3170 3175 3176
317b 317d 3181 3184 3188 318c 318f 3193
3197 319a 319b 319d 31a1 31a5 31a6 31ab
31ad 31b1 31b4 31b8 31bc 31bf 31c0 31c2
31c5 31c8 31c9 31ce 31d2 31d6 31d9 31da
31dc 31df 31e2 31e3 1 31e8 31ed 31f1
31f5 31f8 31fc 3200 3203 3206 320b 320e
3211 3214 3215 321a 321b 1 321d 3222
3226 322a 322d 3232 3237 323a 323e 323f
3244 3247 324c 324d 3252 3255 325a 325b
3260 3263 3267 326b 326f 3270 3272 3277
3278 327a 327b 3280 3283 3288 3289 328e
3291 3296 3297 329c 329f 32a3 32a4 32a9
32ac 32b1 32b2 32b7 32b8 32bd 32bf 32c3
32c6 32ca 32ce 32d1 32d5 32d9 32dc 32df
32e4 32e7 32ea 32ed 32ee 32f3 32f4 1
32f6 32fb 32ff 3303 3306 330b 3310 3313
3317 3318 331d 331e 3323 3325 3329 332c
3330 3334 3337 333b 333f 3342 3343 3345
3349 334d 334e 3353 3355 3359 335c 3360
3361 3365 3369 336d 3371 3375 3379 337d
3381 3385 3389 338d 3391 3395 3399 339d
33a1 33a5 33a9 33ad 33b1 33b5 33c1 33c5
33c9 33cc 33d0 33d4 33d6 33da 33de 33e2
33e5 33e9 33ed 33ef 33f0 33f5 1 33f9
33fd 3401 3404 3408 340c 3410 3414 3417
341b 341f 3422 3425 342a 342d 3430 3433
3434 3439 343a 1 343c 3441 3445 3449
344c 3451 3456 3459 345d 345e 3463 3466
346b 346c 3471 3474 3479 347a 347f 3482
3486 3487 348c 348f 3494 3495 349a 349d
34a1 34a5 34a8 34ab 34ac 34ae 34af 34b4
34b5 34ba 34bc 34c0 34c3 34c5 34c9 34cb
34d7 34d9 34db 34dc 34e1 34e5 34e7 34f3
34f5 34f9 34fd 3500 3504 3507 350b 350e
350f 3514 3517 351b 351e 351f 3524 3527
1 352a 352f 3533 3536 353a 353e 3542
3545 3546 3548 354b 354e 354f 3554 3558
355c 3560 3562 3566 3569 356b 356f 3572
3576 3579 357d 3581 3584 3588 358c 358f
3592 3593 3598 359c 35a0 35a3 35a6 35a7
35a9 35ac 35b1 35b2 35b7 35bb 35bf 35c3
35c7 35cb 35cf 35d3 35d7 35db 35df 35e3
35e7 35eb 35ef 35f3 35f7 35fb 35ff 3603
3607 360b 360f 3613 3617 361b 361f 3623
3627 362b 362f 3633 3637 363b 363f 364b
364f 3653 3656 365a 365e 3660 3664 3668
366c 366f 3673 3677 3679 367a 367f 1
3683 3687 368b 368e 3692 3696 369a 369e
36a1 36a5 36a9 36ac 36af 36b4 36b7 36ba
36bd 36be 36c3 36c4 1 36c6 36cb 36cf
36d3 36d6 36db 36e0 36e3 36e7 36e8 36ed
36f0 36f5 36f6 36fb 36fe 3703 3704 3709
370c 3710 3711 3716 3719 371e 371f 3724
3727 372b 372f 3732 3735 3736 3738 3739
373e 373f 3744 3746 374a 374d 374f 3753
3755 3761 3763 3765 3766 376b 376f 3771
377d 377f 3783 3787 378a 378e 3791 3795
3798 3799 379e 37a1 37a5 37a8 37ac 37b0
37b4 37b7 37b8 37ba 37bd 37c0 37c1 37c6
37c9 37cd 37d1 37d4 37d5 37d7 37da 37dd
37de 37e3 1 37e6 37eb 37ef 37f3 37f7
37fb 37ff 3803 3807 380b 380f 3813 3817
381b 381f 3823 3827 382b 382f 3833 3837
383b 383f 3843 3847 384b 384f 3853 3857
385b 385f 3863 3867 386b 3877 387b 387f
3882 3886 388a 388c 3890 3894 3898 389b
389f 38a3 38a5 38a6 38ab 1 38af 38b3
38b7 38ba 38be 38c2 38c6 38ca 38cd 38d1
38d5 38d8 38db 38e0 38e3 38e6 38e9 38ea
38ef 38f0 1 38f2 38f7 38fb 38ff 3902
3907 390c 390f 3913 3914 3919 391c 3921
3922 3927 392a 392f 3930 3935 3938 393c
393d 3942 3945 394a 394b 3950 3953 3957
395b 395e 3961 3962 3964 3965 396a 396b
3970 3972 3976 3979 397b 397f 3981 398d
398f 3991 3992 3997 399b 399d 39a9 39ab
39ad 39b1 39b4 39b8 39ba 39be 39c2 39c5
39c9 39cb 39cf 39d3 39d6 39da 39dd 39e1
39e4 39e5 39ea 39ed 39f1 39f5 39f8 39f9
39fb 39fe 3a01 3a02 3a07 1 3a0a 3a0f
3a13 3a17 3a1b 3a1f 3a23 3a27 3a2b 3a2f
3a33 3a37 3a3b 3a3f 3a43 3a47 3a4b 3a4f
3a53 3a57 3a5b 3a5f 3a63 3a67 3a6b 3a6f
3a73 3a77 3a7b 3a7f 3a83 3a87 3a8b 3a8f
3a9b 3a9f 3aa3 3aa6 3aaa 3aae 3ab0 3ab4
3ab8 3abc 3abf 3ac3 3ac7 3ac9 3aca 3acf
1 3ad3 3ad7 3adb 3ade 3ae2 3ae6 3aea
3aee 3af1 3af5 3af9 3afc 3aff 3b04 3b07
3b0a 3b0d 3b0e 3b13 3b14 1 3b16 3b1b
3b1f 3b23 3b26 3b2b 3b30 3b33 3b37 3b38
3b3d 3b40 3b45 3b46 3b4b 3b4e 3b53 3b54
3b59 3b5c 3b60 3b61 3b66 3b69 3b6e 3b6f
3b74 3b77 3b7b 3b7f 3b82 3b85 3b86 3b88
3b89 3b8e 3b8f 3b94 3b96 3b9a 3b9d 3b9f
3ba3 3ba5 3bb1 3bb3 3bb5 3bb6 3bbb 3bbf
3bc1 3bcd 3bcf 3bd1 3bd5 3bd9 3bdc 3bde
3be2 3be6 3bea 3bee 3bf2 3bf6 3bfa 3bfe
3c02 3c06 3c0a 3c0e 3c12 3c16 3c1a 3c1e
3c22 3c26 3c2a 3c2e 3c32 3c36 3c3a 3c3e
3c42 3c46 3c4a 3c4e 3c52 3c56 3c5a 3c5e
3c6a 3c6e 3c72 3c75 3c79 3c7d 3c7f 3c83
3c87 3c8b 3c8e 3c92 3c96 3c98 3c99 3c9e
1 3ca2 3ca6 3caa 3cad 3cb1 3cb5 3cb9
3cbd 3cc0 3cc4 3cc8 3ccb 3cce 3cd3 3cd6
3cd9 3cdc 3cdd 3ce2 3ce3 1 3ce5 3cea
3cee 3cf2 3cf5 3cfa 3cff 3d02 3d06 3d07
3d0c 3d0f 3d14 3d15 3d1a 3d1d 3d22 3d23
3d28 3d2b 3d2f 3d30 3d35 3d38 3d3d 3d3e
3d43 3d46 3d4a 3d4e 3d51 3d54 3d55 3d57
3d58 3d5d 3d5e 3d63 3d65 3d69 3d6c 3d6e
3d72 3d74 3d80 3d82 3d84 3d85 3d8a 3d8e
3d90 3d9c 3d9e 3da0 3da4 3da8 3dab 3dad
3db1 3db5 3db8 3dbb 3dbc 3dbe 3dc1 3dc6
3dc7 3dcc 3dd0 3dd4 3dd8 3ddc 3de0 3de4
3de8 3dec 3df0 3df4 3df8 3dfc 3e00 3e04
3e08 3e0c 3e10 3e14 3e18 3e1c 3e20 3e24
3e28 3e2c 3e30 3e3c 3e40 3e44 3e47 3e4b
3e4f 3e51 3e55 3e59 3e5d 3e60 3e64 3e68
3e6a 3e6b 3e70 1 3e74 3e78 3e7c 3e7f
3e83 3e87 3e8b 3e8f 3e92 3e96 3e9a 3e9d
3ea0 3ea5 3ea8 3eab 3eae 3eaf 3eb4 3eb5
1 3eb7 3ebc 3ec0 3ec4 3ec7 3ecc 3ed1
3ed4 3ed8 3ed9 3ede 3ee1 3ee6 3ee7 3eec
3eef 3ef4 3ef5 3efa 3efd 3f01 3f02 3f07
3f0a 3f0f 3f10 3f15 3f18 3f1c 3f20 3f23
3f26 3f27 3f29 3f2a 3f2f 3f30 3f35 3f37
3f3b 3f3e 3f40 3f44 3f46 3f52 3f54 3f56
3f57 3f5c 3f60 3f62 3f6e 3f70 3f74 3f78
3f7b 3f7f 3f82 3f86 3f89 3f8a 3f8f 3f92
3f96 3f99 3f9d 3fa1 3fa5 3fa8 3fa9 3fab
3fae 3fb1 3fb2 3fb7 3fba 3fbe 3fc2 3fc5
3fc6 3fc8 3fcb 3fce 3fcf 3fd4 1 3fd7
3fdc 3fe0 3fe4 3fe8 3fec 3ff0 3ff4 3ff8
3ffc 4000 4004 4008 400c 4010 4014 4018
401c 4020 4024 4028 402c 4038 403c 4040
4043 4047 404b 404d 4051 4055 4059 405c
4060 4064 4066 4067 406c 1 4070 4074
4078 407b 407f 4083 4087 408b 408e 4092
4096 4099 409c 40a1 40a4 40a7 40aa 40ab
40b0 40b1 1 40b3 40b8 40bc 40c0 40c3
40c8 40cd 40d0 40d4 40d5 40da 40dd 40e2
40e3 40e8 40eb 40f0 40f1 40f6 40f9 40fd
40fe 4103 4106 410b 410c 4111 4114 4118
411c 411f 4122 4123 4125 4126 412b 412c
4131 4133 4137 413a 413c 4140 4142 414e
4150 4152 4153 4158 415c 415e 416a 416c
416e 4172 4175 4179 417b 417d 4181 4185
4188 418c 418e 4192 4196 4199 419d 41a0
41a4 41a7 41a8 41ad 41b0 41b4 41b8 41bc
41c0 41c4 41c8 41cc 41d0 41d4 41d8 41dc
41e0 41e4 41e8 41ec 41f0 41f4 41f8 41fc
4200 4204 4208 420c 4218 421c 4220 4223
4227 422b 422d 4231 4235 4239 423c 4240
4244 4246 4247 424c 1 4250 4254 4258
425b 425f 4263 4267 426b 426e 4272 4276
4279 427c 4281 4284 4287 428a 428b 4290
4291 1 4293 4298 429c 42a0 42a3 42a8
42ad 42b0 42b4 42b5 42ba 42bd 42c2 42c3
42c8 42cb 42d0 42d1 42d6 42d9 42dd 42de
42e3 42e6 42eb 42ec 42f1 42f4 42f8 42fc
42ff 4302 4303 4305 4306 430b 430c 4311
4313 4317 431a 431c 4320 4322 432e 4330
4332 4333 4338 433c 433e 434a 434c 434e
4352 4356 4359 435b 435f 4363 4367 436b
436f 4373 4377 437b 437f 4383 4387 438b
438f 4393 4397 439b 439f 43a3 43a7 43ab
43af 43b3 43b7 43c3 43c7 43cb 43ce 43d2
43d6 43d8 43dc 43e0 43e4 43e7 43eb 43ef
43f1 43f2 43f7 1 43fb 43ff 4403 4406
440a 440e 4412 4416 4419 441d 4421 4424
4427 442c 442f 4432 4435 4436 443b 443c
1 443e 4443 4447 444b 444e 4453 4458
445b 445f 4460 4465 4468 446d 446e 4473
4476 447b 447c 4481 4484 4488 4489 448e
4491 4496 4497 449c 449f 44a3 44a7 44aa
44ad 44ae 44b0 44b1 44b6 44b7 44bc 44be
44c2 44c5 44c7 44cb 44cd 44d9 44db 44dd
44de 44e3 44e7 44e9 44f5 44f7 44f9 44fd
4501 4504 4506 450a 450e 4511 4515 4519
451c 4520 4523 4527 452a 452b 4530 4533
4537 453b 453e 453f 4541 4544 4547 4548
454d 4551 4555 4558 455c 4560 4563 4566
456b 456e 4571 4574 4575 457a 457b 1
457d 4582 4586 458a 458d 4592 4597 459a
459e 459f 45a4 45a7 45ac 45ad 45b2 45b5
45ba 45bb 45c0 45c3 45c7 45cb 45cf 45d3
45d6 45d7 45d9 45de 45df 45e1 45e2 45e7
45ea 45ef 45f0 45f5 45f8 45fd 45fe 4603
4606 460a 460b 4610 4613 4618 4619 461e
461f 4624 4626 462a 462d 4631 4635 4638
463c 4640 4643 4646 464b 464e 4651 4654
4655 465a 465b 1 465d 4662 4666 466a
466d 4672 4677 467a 467e 467f 4684 4685
468a 468c 4690 4693 4697 469b 469e 46a2
46a6 46a9 46ad 46b1 46b2 46b7 46bb 46bd
46c1 46c4 46c5 46ca 46cd 46d1 46d5 46d8
46d9 46db 46de 46e1 46e2 1 46e7 46ec
46f0 46f3 46f6 46f7 46fc 4700 4703 4707
470b 470f 4713 4717 471b 471f 4723 4727
472b 472f 4733 4737 473b 473f 4743 474f
4753 4757 475a 475e 4762 4764 4768 476c
4770 4773 4777 477b 477d 477e 4783 1
4787 478b 478f 4792 4796 479a 479e 47a2
47a5 47a9 47ad 47b0 47b3 47b8 47bb 47be
47c1 47c2 47c7 47c8 1 47ca 47cf 47d3
47d7 47da 47df 47e4 47e7 47eb 47ec 47f1
47f4 47f9 47fa 47ff 4802 4807 4808 480d
4810 4814 4815 481a 481d 4822 4823 4828
482b 482f 4833 4836 4839 483a 483c 483d
4842 4843 4848 484a 484e 4851 4853 4857
4859 4865 4867 4869 486a 486f 4873 4875
4881 4883 4885 4889 488c 4890 4894 4898
489c 48a0 48a4 48a8 48ac 48b0 48b4 48b8
48bc 48c0 48cc 48d0 48d4 48d7 48db 48df
48e1 48e5 48e9 48ed 48f0 48f4 48f8 48fa
48fb 4900 1 4904 4908 490c 490f 4913
4917 491b 491f 4922 4926 492a 492d 4930
4935 4938 493b 493e 493f 4944 4945 1
4947 494c 4950 4954 4957 495c 4961 4964
4968 4969 496e 4971 4976 4977 497c 497f
4984 4985 498a 498d 4991 4992 4997 499a
499f 49a0 49a5 49a8 49ac 49b0 49b3 49b6
49b7 49b9 49ba 49bf 49c0 49c5 49c7 49cb
49ce 49d0 49d4 49d6 49e2 49e4 49e6 49e7
49ec 49f0 49f2 49fe 4a00 4a02 4a06 4a0a
4a0d 4a11 4a15 4a18 4a19 4a1b 4a1f 4a22
4a26 4a29 4a2a 4a2c 4a2d 4a32 4a36 4a3a
4a3d 4a41 4a45 4a48 4a4b 4a50 4a53 4a56
4a59 4a5a 4a5f 4a60 1 4a62 4a67 4a6b
4a6f 4a72 4a77 4a7c 4a7f 4a83 4a84 4a89
4a8c 4a91 4a92 4a97 4a9a 4a9f 4aa0 4aa5
4aa8 4aac 4ab0 4ab4 4ab8 4abb 4abc 4abe
4ac3 4ac4 4ac6 4ac7 4acc 4acf 4ad4 4ad5
4ada 4add 4ae2 4ae3 4ae8 4aeb 4aef 4af0
4af5 4af8 4afd 4afe 4b03 4b04 4b09 4b0b
4b0f 4b12 4b16 4b1a 4b1d 4b21 4b25 4b28
4b2b 4b30 4b33 4b36 4b39 4b3a 4b3f 4b40
1 4b42 4b47 4b4b 4b4f 4b52 4b57 4b5c
4b5f 4b63 4b64 4b69 4b6a 4b6f 4b71 4b75
4b78 4b7c 4b80 4b83 4b87 4b8b 4b8e 4b92
4b96 4b97 4b9c 4b9e 4ba2 4ba5 4ba7 4bab
4baf 4bb2 4bb6 4bb9 4bbd 4bc1 4bc3 4bc7
4bcb 4bce 4bcf 4bd1 4bd4 4bd7 4bd8 4bdd
4be0 4be4 4be8 4bec 4bef 4bf0 4bf2 4bf3
4bf5 4bf8 4bfb 4bfe 4bff 1 4c04 4c09
4c0d 4c11 4c14 4c18 4c1c 4c1f 4c22 4c27
4c2a 4c2d 4c30 4c31 4c36 4c37 1 4c39
4c3e 4c42 4c46 4c49 4c4e 4c53 4c56 4c5a
4c5b 4c60 4c63 4c68 4c69 4c6e 4c71 4c76
4c77 4c7c 4c7f 4c83 4c87 4c8b 4c8f 4c92
4c93 4c95 4c9a 4c9b 4c9d 4c9e 4ca3 4ca6
4cab 4cac 4cb1 4cb4 4cb9 4cba 4cbf 4cc2
4cc6 4cc7 4ccc 4ccf 4cd4 4cd5 4cda 4cdb
4ce0 4ce2 4ce6 4ce9 4ced 4cf1 4cf4 4cf8
4cfc 4cff 4d02 4d07 4d0a 4d0d 4d10 4d11
4d16 4d17 1 4d19 4d1e 4d22 4d26 4d29
4d2e 4d33 4d36 4d3a 4d3b 4d40 4d41 4d46
4d48 4d4c 4d4f 4d53 4d57 4d5a 4d5e 4d62
4d65 4d69 4d6d 4d6e 4d73 4d75 4d79 4d7d
4d80 4d84 4d88 4d8b 4d8e 4d8f 4d91 4d94
4d99 4d9a 4d9f 4da3 4da7 4dab 4dae 4db2
4db3 4db8 4dbb 4dbe 4dbf 4dc1 4dc5 4dc9
4dcd 4dd1 4dd5 4dd9 4ddd 4de1 4de5 4de9
4ded 4df1 4df5 4df9 4dfd 4e01 4e05 4e09
4e0d 4e11 4e15 4e19 4e25 4e29 4e2d 4e30
4e34 4e38 4e3a 4e3e 4e42 4e46 4e49 4e4d
4e51 4e53 4e54 4e59 1 4e5d 4e61 4e65
4e68 4e6c 4e70 4e74 4e78 4e7b 4e7f 4e83
4e86 4e89 4e8e 4e91 4e94 4e97 4e98 4e9d
4e9e 1 4ea0 4ea5 4ea9 4ead 4eb0 4eb5
4eba 4ebd 4ec1 4ec2 4ec7 4eca 4ecf 4ed0
4ed5 4ed8 4edd 4ede 4ee3 4ee6 4eea 4eeb
4ef0 4ef3 4ef8 4ef9 4efe 4f01 4f05 4f09
4f0c 4f0f 4f10 4f12 4f13 4f18 4f19 4f1e
4f20 4f24 4f27 4f29 4f2d 4f2f 4f3b 4f3d
4f3f 4f40 4f45 4f49 4f4b 4f57 4f59 4f5d
4f61 4f64 4f68 4f6b 4f6f 4f72 4f73 4f78
4f7b 4f7f 4f83 4f86 4f8a 4f8e 4f91 4f94
4f99 4f9c 4f9f 4fa2 4fa3 4fa8 4fa9 1
4fab 4fb0 4fb4 4fb8 4fbb 4fc0 4fc5 4fc8
4fcc 4fcd 4fd2 4fd5 4fda 4fdb 4fe0 4fe3
4fe8 4fe9 4fee 4ff1 4ff5 4ff9 4ffd 5001
5004 5005 5007 500c 500d 500f 5010 5015
5018 501d 501e 5023 5026 502b 502c 5031
5034 5038 5039 503e 5041 5046 5047 504c
504d 5052 5054 5058 505b 505f 5063 5066
506a 506e 5071 5074 5079 507c 507f 5082
5083 5088 5089 1 508b 5090 5094 5098
509b 50a0 50a5 50a8 50ac 50ad 50b2 50b3
50b8 50ba 50be 50c1 50c5 50c9 50cc 50d0
50d4 50d7 50db 50df 50e0 50e5 50e7 50eb
50ee 50f2 50f6 50f9 50fc 50fd 50ff 5102
5107 5108 510d 5110 5114 5118 511b 511c
511e 5121 5124 5125 512a 512d 5131 5135
5138 5139 513b 513f 5142 5146 5149 514a
514c 514d 5152 1 5155 515a 1 515d
5162 5166 516a 516d 5171 5175 5178 517b
5180 5183 5186 5189 518a 518f 5190 1
5192 5197 519b 519f 51a2 51a7 51ac 51af
51b3 51b4 51b9 51bc 51c1 51c2 51c7 51ca
51cf 51d0 51d5 51d8 51dc 51e0 51e4 51e8
51eb 51ec 51ee 51f3 51f4 51f6 51f7 51fc
51ff 5204 5205 520a 520d 5212 5213 5218
521b 521f 5220 5225 5228 522d 522e 5233
5234 5239 523b 523f 5242 5246 524a 524d
5251 5255 5258 525b 5260 5263 5266 5269
526a 526f 5270 1 5272 5277 527b 527f
5282 5287 528c 528f 5293 5294 5299 529a
529f 52a1 52a5 52a8 52ac 52b0 52b3 52b7
52bb 52be 52c2 52c6 52c7 52cc 52ce 52d2
52d5 52d9 52dd 52e1 52e5 52e9 52ed 52f1
52f5 52f9 52fd 5301 5305 5311 5315 5319
531c 5320 5324 5326 532a 532e 5332 5335
5339 533d 533f 5340 5345 1 5349 534d
5351 5354 5358 535c 5360 5364 5367 536b
536f 5372 5375 537a 537d 5380 5383 5384
5389 538a 1 538c 5391 5395 5399 539c
53a1 53a6 53a9 53ad 53ae 53b3 53b6 53bb
53bc 53c1 53c4 53c9 53ca 53cf 53d2 53d6
53d7 53dc 53df 53e4 53e5 53ea 53ed 53f1
53f5 53f8 53fb 53fc 53fe 53ff 5404 5405
540a 540c 5410 5413 5415 5419 541b 5427
5429 542b 542c 5431 5435 5437 5443 5445
5447 544b 544f 5453 5456 545a 545b 5460
5463 5466 5467 5469 546d 5471 5475 5479
547d 5481 548d 5491 5495 5498 549c 54a0
54a2 54a6 54aa 54ae 54b1 54b5 54b9 54bb
54bc 54c1 1 54c5 54c9 54cd 54d0 54d4
54d8 54dc 54e0 54e3 54e7 54eb 54ee 54f1
54f6 54f9 54fc 54ff 5500 5505 5506 1
5508 550d 5511 5515 5518 551d 5522 5525
5529 552a 552f 5532 5537 5538 553d 5540
5545 5546 554b 554e 5552 5553 5558 555b
5560 5561 5566 5569 556d 5571 5574 5577
5578 557a 557b 5580 5581 5586 5588 558c
558f 5591 5595 5597 55a3 55a5 55a7 55a8
55ad 55b1 55b3 55bf 55c1 55c5 55c9 55cc
55d0 55d3 55d7 55da 55db 55e0 55e3 55e7
55eb 55ee 55f2 55f6 55f9 55fc 5601 5604
5607 560a 560b 5610 5611 1 5613 5618
561c 5620 5623 5628 562d 5630 5634 5635
563a 563d 5642 5643 5648 564b 5650 5651
5656 5659 565d 5661 5665 5669 566c 566d
566f 5674 5675 5677 5678 567d 5680 5685
5686 568b 568e 5693 5694 5699 569c 56a0
56a1 56a6 56a9 56ae 56af 56b4 56b5 56ba
56bc 56c0 56c3 56c7 56cb 56ce 56d2 56d6
56d9 56dc 56e1 56e4 56e7 56ea 56eb 56f0
56f1 1 56f3 56f8 56fc 5700 5703 5708
570d 5710 5714 5715 571a 571b 5720 5722
5726 5729 572d 5731 5734 5738 573c 573f
5743 5747 5748 574d 574f 5753 5756 575a
575e 5762 5766 576a 576e 5772 5776 577a
577e 5782 5786 578a 578e 5792 5796 579a
579e 57a2 57a6 57b2 57b6 57ba 57bd 57c1
57c5 57c7 57cb 57cf 57d3 57d6 57da 57de
57e0 57e1 57e6 1 57ea 57ee 57f2 57f5
57f9 57fd 5801 5805 5808 580c 5810 5813
5816 581b 581e 5821 5824 5825 582a 582b
1 582d 5832 5836 583a 583d 5842 5847
584a 584e 584f 5854 5857 585c 585d 5862
5865 586a 586b 5870 5873 5877 5878 587d
5880 5885 5886 588b 588e 5892 5896 5899
589c 589d 589f 58a0 58a5 58a6 58ab 58ad
58b1 58b4 58b6 58ba 58bc 58c8 58ca 58cc
58cd 58d2 58d6 58d8 58e4 58e6 58ea 58ee
58f1 58f5 58f8 58fc 58ff 5900 5905 5908
590c 5910 5913 5914 5916 5919 591c 591d
5922 1 5925 592a 592e 5932 5935 5939
593d 5940 5943 5948 594b 594e 5951 5952
5957 5958 1 595a 595f 5963 5967 596a
596f 5974 5977 597b 597c 5981 5984 5989
598a 598f 5992 5997 5998 599d 59a0 59a4
59a8 59ac 59b0 59b3 59b4 59b6 59bb 59bc
59be 59bf 59c4 59c7 59cc 59cd 59d2 59d5
59da 59db 59e0 59e3 59e7 59e8 59ed 59f0
59f5 59f6 59fb 59fc 5a01 5a03 5a07 5a0a
5a0e 5a12 5a15 5a19 5a1d 5a20 5a23 5a28
5a2b 5a2e 5a31 5a32 5a37 5a38 1 5a3a
5a3f 5a43 5a47 5a4a 5a4f 5a54 5a57 5a5b
5a5c 5a61 5a62 5a67 5a69 5a6d 5a70 5a74
5a78 5a7b 5a7f 5a83 5a86 5a8a 5a8e 5a8f
5a94 5a96 5a9a 5a9d 5aa1 5aa5 5aa9 5aad
5ab1 5ab5 5ab9 5abd 5ac1 5ac5 5ac9 5acd
5ad9 5add 5ae1 5ae4 5ae8 5aec 5aee 5af2
5af6 5afa 5afd 5b01 5b05 5b07 5b08 5b0d
1 5b11 5b15 5b19 5b1c 5b20 5b24 5b28
5b2c 5b2f 5b33 5b37 5b3a 5b3d 5b42 5b45
5b48 5b4b 5b4c 5b51 5b52 1 5b54 5b59
5b5d 5b61 5b64 5b69 5b6e 5b71 5b75 5b76
5b7b 5b7e 5b83 5b84 5b89 5b8c 5b91 5b92
5b97 5b9a 5b9e 5b9f 5ba4 5ba7 5bac 5bad
5bb2 5bb5 5bb9 5bbd 5bc0 5bc3 5bc4 5bc6
5bc7 5bcc 5bcd 5bd2 5bd4 5bd8 5bdb 5bdd
5be1 5be3 5bef 5bf1 5bf3 5bf4 5bf9 5bfd
5bff 5c0b 5c0d 5c0f 5c13 5c17 5c1a 5c1e
5c22 5c26 5c2a 5c2e 5c31 5c32 5c34 5c37
5c3a 5c3b 5c40 5c44 5c48 5c4c 5c50 5c54
5c58 5c5c 5c60 5c64 5c68 5c74 5c78 5c7c
5c7f 5c83 5c87 5c89 5c8d 5c91 5c95 5c98
5c9c 5ca0 5ca2 5ca3 5ca8 1 5cac 5cb0
5cb4 5cb7 5cbb 5cbf 5cc3 5cc7 5cca 5cce
5cd2 5cd5 5cd8 5cdd 5ce0 5ce3 5ce6 5ce7
5cec 5ced 1 5cef 5cf4 5cf8 5cfc 5cff
5d04 5d09 5d0c 5d10 5d11 5d16 5d19 5d1e
5d1f 5d24 5d27 5d2c 5d2d 5d32 5d35 5d39
5d3a 5d3f 5d42 5d47 5d48 5d4d 5d50 5d54
5d58 5d5b 5d5e 5d5f 5d61 5d62 5d67 5d68
5d6d 5d6f 5d73 5d76 5d78 5d7c 5d7e 5d8a
5d8c 5d8e 5d8f 5d94 5d98 5d9a 5da6 5da8
5dac 5db0 5db4 5db8 5dbc 5dc0 5dc4 5dc8
5dcc 5dd0 5ddc 5de0 5de4 5de7 5deb 5def
5df1 5df5 5df9 5dfd 5e00 5e04 5e08 5e0a
5e0b 5e10 1 5e14 5e18 5e1c 5e1f 5e23
5e27 5e2b 5e2f 5e32 5e36 5e3a 5e3d 5e40
5e45 5e48 5e4b 5e4e 5e4f 5e54 5e55 1
5e57 5e5c 5e60 5e64 5e67 5e6c 5e71 5e74
5e78 5e79 5e7e 5e81 5e86 5e87 5e8c 5e8f
5e94 5e95 5e9a 5e9d 5ea1 5ea2 5ea7 5eaa
5eaf 5eb0 5eb5 5eb8 5ebc 5ec0 5ec3 5ec6
5ec7 5ec9 5eca 5ecf 5ed0 5ed5 5ed7 5edb
5ede 5ee0 5ee4 5ee6 5ef2 5ef4 5ef6 5ef7
5efc 5f00 5f02 5f0e 5f10 5f14 5f17 5f1b
5f1f 5f23 5f27 5f2b 5f2f 5f32 5f33 5f35
5f38 5f3b 5f3c 5f41 5f45 5f48 5f4c 5f4e
5f52 5f55 5f59 5f5d 5f61 5f65 5f69 5f6d
5f71 5f75 5f79 5f7d 5f81 5f85 5f89 5f8d
5f91 5f95 5f99 5f9d 5fa1 5fa5 5fa9 5fad
5fb1 5fb5 5fb9 5fbd 5fc1 5fc5 5fc9 5fcd
5fd0 5fd3 5fd6 5fd9 5fdc 5fdd 5fdf 5fe3
5fe7 5fea 5fed 5fee 5ff3 5ff7 5ffb 5ffe
5fff 6001 6004 6007 6008 600d 6011 6015
6019 601d 6029 602d 6032 6036 6039 603a
603f 6043 6047 604a 604d 6051 6053 6057
605b 605e 6061 6065 6067 606b 606f 6072
6074 6078 607c 6080 6083 6087 608b 608d
608e 6093 1 6097 609b 609f 60a2 60a6
60aa 60ae 60b2 60b5 60b9 60bd 60c0 60c3
60c8 60cb 60ce 60d1 60d2 60d7 60d8 1
60da 60df 60e3 60e7 60ea 60ef 60f4 60f7
60fb 60fc 6101 6104 6109 610a 610f 6112
6117 6118 611d 6120 6124 6125 612a 612d
6132 6133 6138 613b 613f 6143 6146 6149
614a 614c 614d 6152 6153 6158 615a 615e
6161 6163 6167 6169 6175 6177 6179 617a
617f 6183 6185 6191 6193 6195 6199 619d
61a1 61a5 61b1 61b5 61ba 61be 61c1 61c2
61c7 61cb 61cf 61d2 61d5 61d9 61db 61df
61e3 61e6 61e9 61ed 61ef 61f3 61f7 61fa
61fc 6200 6204 6208 620b 620f 6213 6215
6216 621b 1 621f 6223 6227 622a 622e
6232 6236 623a 623d 6241 6245 6248 624b
6250 6253 6256 6259 625a 625f 6260 1
6262 6267 626b 626f 6272 6277 627c 627f
6283 6284 6289 628c 6291 6292 6297 629a
629f 62a0 62a5 62a8 62ac 62ad 62b2 62b5
62ba 62bb 62c0 62c3 62c7 62cb 62ce 62d1
62d2 62d4 62d5 62da 62db 62e0 62e2 62e6
62e9 62eb 62ef 62f1 62fd 62ff 6301 6302
6307 630b 630d 6319 631b 631d 6321 6325
6328 632a 632e 6331 6333 6337 633b 633f
6343 6347 634b 634f 6353 6356 6359 635a
635c 635f 6364 6365 636a 636e 6372 6376
6379 637d 637f 6383 6387 638b 638f 6392
6393 6395 6399 639d 63a0 63a1 63a3 63a7
63a9 63ad 63b1 63b4 63b8 63bc 63c0 63c4
63c8 63cc 63d0 63d4 63d8 63dc 63e0 63e4
63e8 63ec 63f0 63f4 63f8 63fc 6400 6404
6408 640c 6410 6414 6418 641c 6420 6424
6428 642c 642f 6432 6435 6438 643b 643c
643e 6442 6446 6449 644c 644d 6452 6456
645a 645e 6462 646e 6472 6477 647b 647e
647f 6484 6488 648c 648f 6492 6496 6498
649c 64a0 64a3 64a6 64aa 64ac 64b0 64b4
64b7 64b9 64bd 64c1 64c5 64c8 64cc 64d0
64d2 64d3 64d8 1 64dc 64e0 64e4 64e7
64eb 64ef 64f3 64f7 64fa 64fe 6502 6505
6508 650d 6510 6513 6516 6517 651c 651d
1 651f 6524 6528 652c 652f 6534 6539
653c 6540 6541 6546 6549 654e 654f 6554
6557 655c 655d 6562 6565 6569 656a 656f
6572 6577 6578 657d 6580 6584 6588 658b
658e 658f 6591 6592 6597 6598 659d 659f
65a3 65a6 65a8 65ac 65ae 65ba 65bc 65be
65bf 65c4 65c8 65ca 65d6 65d8 65da 65de
65e1 65e3 65e7 65eb 65ee 65f0 65f4 65f8
65fc 65fd 65ff 6602 6603 6605 6608 660b
660c 6611 6615 6618 661c 661e 6622 6626
662a 662e 6632 6633 6635 6638 6639 663b
663e 6641 6642 6647 664a 664d 6650 6651
6656 6657 6659 665d 665f 6663 6667 666a
666e 6671 6674 6675 667a 667e 6681 6685
6689 668d 6691 6694 6695 6697 669b 669e
66a2 66a3 66a8 66aa 66ae 66b1 66b5 66b9
66bd 66c1 66c4 66c7 66ca 66ce 66d2 66d5
66d6 66d8 66db 66de 66df 66e4 66e7 66ea
66eb 66f0 66f4 66f5 66f7 66fb 66ff 6703
6707 670a 670d 6710 6714 6718 671b 671c
671e 6721 6724 6725 672a 672d 6730 6731
6736 6739 673c 673d 6742 6746 6747 6749
674d 6751 6755 6759 675d 6760 6764 6768
676b 676f 6773 6777 677b 677f 6783 6787
678b 678f 6793 6797 679b 679f 67a3 67a7
67ab 67af 67b3 67bf 67c3 67c7 67ca 67ce
67d2 67d4 67d8 67dc 67e0 67e3 67e7 67eb
67ed 67ee 67f3 1 67f7 67fb 67ff 6802
6806 680a 680e 6812 6815 6819 681d 6820
6823 6828 682b 682e 6831 6832 6837 6838
1 683a 683f 6843 6847 684a 684f 6854
6857 685b 685c 6861 6864 6869 686a 686f
6872 6877 6878 687d 6880 6884 6885 688a
688d 6892 6893 6898 689b 689f 68a3 68a6
68a9 68aa 68ac 68ad 68b2 68b3 68b8 68ba
68be 68c1 68c3 68c7 68c9 68d5 68d7 68d9
68da 68df 68e3 68e5 68f1 68f3 68f7 68fb
68fe 68ff 6901 6904 6907 6908 690d 6910
6914 6917 6918 691d 6920 1 6923 6928
692c 692f 6933 6937 693b 693e 6942 6946
6947 6949 694c 694f 6950 6955 6959 695d
6961 6963 6967 696a 696c 6970 6973 6977
697b 697e 6981 6982 6984 6987 698c 698d
6992 6996 699a 699e 69a1 69a5 69a9 69ad
69b1 69b2 69b4 69b7 69b8 69ba 69bd 69c0
69c1 69c6 69ca 69ce 69d2 69d4 69d8 69dc
69e0 69e3 69e8 69e9 69ee 69f1 69f4 69f5
69f7 69fb 69ff 6a03 6a07 6a0a 6a0e 6a0f
6a14 6a17 6a1a 6a1b 6a1d 6a21 6a23 6a27
6a2b 6a2e 6a30 6a34 6a38 6a3c 6a3d 6a3f
6a42 6a43 6a45 6a48 6a4b 6a4c 6a51 6a55
6a59 6a5d 6a5f 6a63 6a67 6a6b 6a6e 6a73
6a74 6a79 6a7c 6a7f 6a80 6a82 6a86 6a8a
6a8e 6a92 6a95 6a99 6a9a 6a9f 6aa2 6aa5
6aa6 6aa8 6aac 6aae 6ab2 6ab6 6ab9 6abb
6abf 6ac3 6ac6 6aca 6acd 6ad1 6ad5 6ad8
6adc 6ae0 6ae4 6ae7 6ae8 6aea 6aed 6af0
6af1 6af6 6afa 6afd 6b00 6b01 6b06 6b0a
6b0e 6b11 6b14 6b15 6b17 6b1a 6b1f 6b20
6b25 6b29 6b2d 6b31 6b35 6b39 6b3d 6b41
6b45 6b49 6b4d 6b51 6b55 6b59 6b5d 6b61
6b65 6b69 6b6d 6b71 6b75 6b79 6b7d 6b81
6b85 6b89 6b8d 6b91 6b95 6ba1 6ba5 6ba9
6bac 6bb0 6bb4 6bb6 6bba 6bbe 6bc2 6bc5
6bc9 6bcd 6bcf 6bd0 6bd5 1 6bd9 6bdd
6be1 6be4 6be8 6bec 6bf0 6bf4 6bf7 6bfb
6bff 6c02 6c05 6c0a 6c0d 6c10 6c13 6c14
6c19 6c1a 1 6c1c 6c21 6c25 6c29 6c2c
6c31 6c36 6c39 6c3d 6c3e 6c43 6c46 6c4b
6c4c 6c51 6c54 6c59 6c5a 6c5f 6c62 6c66
6c67 6c6c 6c6f 6c74 6c75 6c7a 6c7d 6c81
6c85 6c88 6c8b 6c8c 6c8e 6c8f 6c94 6c95
6c9a 6c9c 6ca0 6ca3 6ca5 6ca9 6cab 6cb7
6cb9 6cbb 6cbc 6cc1 6cc5 6cc7 6cd3 6cd5
6cd9 6cdd 6ce0 6ce4 6ce7 6ceb 6cee 6cef
6cf4 6cf7 6cfb 6cfe 6d02 6d06 6d0a 6d0d
6d0e 6d10 6d13 6d16 6d17 6d1c 6d1f 6d23
6d27 6d2a 6d2b 6d2d 6d30 6d33 6d34 6d39
1 6d3c 6d41 6d45 6d49 6d4d 6d51 6d55
6d59 6d5d 6d61 6d65 6d69 6d6d 6d71 6d75
6d79 6d7d 6d81 6d85 6d89 6d8d 6d91 6d95
6d99 6d9d 6da1 6da5 6da9 6db5 6db9 6dbd
6dc0 6dc4 6dc8 6dca 6dce 6dd2 6dd6 6dd9
6ddd 6de1 6de3 6de4 6de9 1 6ded 6df1
6df5 6df8 6dfc 6e00 6e04 6e08 6e0b 6e0f
6e13 6e16 6e19 6e1e 6e21 6e24 6e27 6e28
6e2d 6e2e 1 6e30 6e35 6e39 6e3d 6e40
6e45 6e4a 6e4d 6e51 6e52 6e57 6e5a 6e5f
6e60 6e65 6e68 6e6d 6e6e 6e73 6e76 6e7a
6e7b 6e80 6e83 6e88 6e89 6e8e 6e91 6e95
6e99 6e9c 6e9f 6ea0 6ea2 6ea3 6ea8 6ea9
6eae 6eb0 6eb4 6eb7 6eb9 6ebd 6ebf 6ecb
6ecd 6ecf 6ed0 6ed5 6ed9 6edb 6ee7 6ee9
6eeb 6eef 6ef2 6ef6 6ef8 6efc 6f00 6f03
6f07 6f09 6f0d 6f11 6f14 6f18 6f1b 6f1f
6f22 6f23 6f28 6f2b 6f2f 6f33 6f36 6f37
6f39 6f3c 6f3f 6f40 6f45 1 6f48 6f4d
6f51 6f55 6f59 6f5d 6f61 6f65 6f69 6f6d
6f71 6f75 6f79 6f7d 6f81 6f85 6f89 6f8d
6f91 6f95 6f99 6f9d 6fa1 6fa5 6fa9 6fad
6fb1 6fb5 6fc1 6fc5 6fc9 6fcc 6fd0 6fd4
6fd6 6fda 6fde 6fe2 6fe5 6fe9 6fed 6fef
6ff0 6ff5 1 6ff9 6ffd 7001 7004 7008
700c 7010 7014 7017 701b 701f 7022 7025
702a 702d 7030 7033 7034 7039 703a 1
703c 7041 7045 7049 704c 7051 7056 7059
705d 705e 7063 7066 706b 706c 7071 7074
7079 707a 707f 7082 7086 7087 708c 708f
7094 7095 709a 709d 70a1 70a5 70a8 70ab
70ac 70ae 70af 70b4 70b5 70ba 70bc 70c0
70c3 70c5 70c9 70cb 70d7 70d9 70db 70dc
70e1 70e5 70e7 70f3 70f5 70f7 70fb 70ff
7102 7104 7108 710c 7110 7114 7118 711c
7120 7124 7128 712c 7130 7134 7138 713c
7140 7144 7148 714c 7150 7154 7158 715c
7160 7164 7168 716c 7170 7174 7180 7184
7188 718b 718f 7193 7195 7199 719d 71a1
71a4 71a8 71ac 71ae 71af 71b4 1 71b8
71bc 71c0 71c3 71c7 71cb 71cf 71d3 71d6
71da 71de 71e1 71e4 71e9 71ec 71ef 71f2
71f3 71f8 71f9 1 71fb 7200 7204 7208
720b 7210 7215 7218 721c 721d 7222 7225
722a 722b 7230 7233 7238 7239 723e 7241
7245 7246 724b 724e 7253 7254 7259 725c
7260 7264 7267 726a 726b 726d 726e 7273
7274 7279 727b 727f 7282 7284 7288 728a
7296 7298 729a 729b 72a0 72a4 72a6 72b2
72b4 72b6 72ba 72be 72c1 72c3 72c7 72cb
72ce 72d1 72d2 72d4 72d7 72dc 72dd 72e2
72e6 72ea 72ee 72f2 72f6 72fa 72fe 7302
7306 730a 730e 7312 7316 731a 731e 7322
7326 732a 732e 7332 7336 733a 733e 7342
7346 734a 734e 735a 735e 7362 7365 7369
736d 736f 7373 7377 737b 737e 7382 7386
7388 7389 738e 1 7392 7396 739a 739d
73a1 73a5 73a9 73ad 73b0 73b4 73b8 73bb
73be 73c3 73c6 73c9 73cc 73cd 73d2 73d3
1 73d5 73da 73de 73e2 73e5 73ea 73ef
73f2 73f6 73f7 73fc 73ff 7404 7405 740a
740d 7412 7413 7418 741b 741f 7420 7425
7428 742d 742e 7433 7436 743a 743e 7441
7444 7445 7447 7448 744d 744e 7453 7455
7459 745c 745e 7462 7464 7470 7472 7474
7475 747a 747e 7480 748c 748e 7492 7496
7499 749d 74a0 74a4 74a7 74a8 74ad 74b0
74b4 74b8 74bb 74bc 74be 74c1 74c4 74c5
74ca 74cd 74d1 74d5 74d8 74d9 74db 74de
74e1 74e2 74e7 1 74ea 74ef 74f3 74f7
74fb 74ff 7503 7507 750b 750f 7513 7517
751b 751f 7523 7527 752b 752f 7533 7537
753b 753f 7543 7547 7553 7557 755b 755e
7562 7566 7568 756c 7570 7574 7577 757b
757f 7581 7582 7587 1 758b 758f 7593
7596 759a 759e 75a2 75a6 75a9 75ad 75b1
75b4 75b7 75bc 75bf 75c2 75c5 75c6 75cb
75cc 1 75ce 75d3 75d7 75db 75de 75e3
75e8 75eb 75ef 75f0 75f5 75f8 75fd 75fe
7603 7606 760b 760c 7611 7614 7618 7619
761e 7621 7626 7627 762c 762f 7633 7637
763a 763d 763e 7640 7641 7646 7647 764c
764e 7652 7655 7657 765b 765d 7669 766b
766d 766e 7673 7677 7679 7685 7687 7689
768d 7690 7694 7696 7698 769c 76a0 76a3
76a7 76a9 76ad 76b1 76b4 76b8 76bb 76bf
76c2 76c3 76c8 76cb 76cf 76d3 76d7 76db
76df 76e3 76e7 76eb 76ef 76f3 76f7 76fb
76ff 7703 7707 770b 770f 7713 7717 771b
771f 7723 7727 772b 772f 773b 773f 7743
7746 774a 774e 7750 7754 7758 775c 775f
7763 7767 7769 776a 776f 1 7773 7777
777b 777e 7782 7786 778a 778e 7791 7795
7799 779c 779f 77a4 77a7 77aa 77ad 77ae
77b3 77b4 1 77b6 77bb 77bf 77c3 77c6
77cb 77d0 77d3 77d7 77d8 77dd 77e0 77e5
77e6 77eb 77ee 77f3 77f4 77f9 77fc 7800
7801 7806 7809 780e 780f 7814 7817 781b
781f 7822 7825 7826 7828 7829 782e 782f
7834 7836 783a 783d 783f 7843 7845 7851
7853 7855 7856 785b 785f 7861 786d 786f
7871 7875 7879 787c 787e 7882 7886 788a
788e 7892 7896 789a 789e 78a2 78a6 78aa
78ae 78b2 78b6 78ba 78be 78c2 78c6 78ca
78ce 78d2 78d6 78da 78de 78e2 78ee 78f2
78f6 78f9 78fd 7901 7903 7907 790b 790f
7912 7916 791a 791c 791d 7922 1 7926
792a 792e 7931 7935 7939 793d 7941 7944
7948 794c 794f 7952 7957 795a 795d 7960
7961 7966 7967 1 7969 796e 7972 7976
7979 797e 7983 7986 798a 798b 7990 7993
7998 7999 799e 79a1 79a6 79a7 79ac 79af
79b3 79b4 79b9 79bc 79c1 79c2 79c7 79ca
79ce 79d2 79d5 79d8 79d9 79db 79dc 79e1
79e2 79e7 79e9 79ed 79f0 79f2 79f6 79f8
7a04 7a06 7a08 7a09 7a0e 7a12 7a14 7a20
7a22 7a24 7a28 7a2c 7a2f 7a31 7a35 7a39
7a3c 7a40 7a44 7a47 7a4b 7a4e 7a52 7a55
7a56 7a5b 7a5e 7a62 7a66 7a69 7a6a 7a6c
7a6f 7a72 7a73 7a78 7a7c 7a7f 7a83 7a85
7a89 7a8c 7a8d 7a92 7a95 7a99 7a9c 7a9f
7aa0 7aa5 7aa9 7aac 7ab0 7ab4 7ab8 7abc
7ac0 7ac4 7ac8 7acc 7ad0 7ad4 7ad8 7adc
7ae0 7ae4 7ae8 7aec 7af8 7afc 7b00 7b03
7b07 7b0b 7b0d 7b11 7b15 7b19 7b1c 7b20
7b24 7b26 7b27 7b2c 1 7b30 7b34 7b38
7b3b 7b3f 7b43 7b47 7b4b 7b4e 7b52 7b56
7b59 7b5c 7b61 7b64 7b67 7b6a 7b6b 7b70
7b71 1 7b73 7b78 7b7c 7b80 7b83 7b88
7b8d 7b90 7b94 7b95 7b9a 7b9d 7ba2 7ba3
7ba8 7bab 7bb0 7bb1 7bb6 7bb9 7bbd 7bbe
7bc3 7bc6 7bcb 7bcc 7bd1 7bd4 7bd8 7bdc
7bdf 7be2 7be3 7be5 7be6 7beb 7bec 7bf1
7bf3 7bf7 7bfa 7bfc 7c00 7c02 7c0e 7c10
7c12 7c13 7c18 7c1c 7c1e 7c2a 7c2c 7c2e
7c32 7c35 7c39 7c3d 7c41 7c45 7c49 7c4d
7c51 7c55 7c59 7c5d 7c61 7c65 7c69 7c75
7c79 7c7d 7c80 7c84 7c88 7c8a 7c8e 7c92
7c96 7c99 7c9d 7ca1 7ca3 7ca4 7ca9 1
7cad 7cb1 7cb5 7cb8 7cbc 7cc0 7cc4 7cc8
7ccb 7ccf 7cd3 7cd6 7cd9 7cde 7ce1 7ce4
7ce7 7ce8 7ced 7cee 1 7cf0 7cf5 7cf9
7cfd 7d00 7d05 7d0a 7d0d 7d11 7d12 7d17
7d1a 7d1f 7d20 7d25 7d28 7d2d 7d2e 7d33
7d36 7d3a 7d3b 7d40 7d43 7d48 7d49 7d4e
7d51 7d55 7d59 7d5c 7d5f 7d60 7d62 7d63
7d68 7d69 7d6e 7d70 7d74 7d77 7d79 7d7d
7d7f 7d8b 7d8d 7d8f 7d90 7d95 7d99 7d9b
7da7 7da9 7dab 7daf 7db3 7db6 7dba 7dbe
7dc1 7dc2 7dc4 7dc8 7dcb 7dcf 7dd2 7dd3
7dd5 7dd6 7ddb 7ddf 7de3 7de7 7dea 7deb
7ded 7df0 7df3 7df4 7df9 7dfd 7e01 7e07
7e09 7e0d 7e10 7e12 7e16 7e19 7e1d 7e20
7e24 7e26 7e2a 7e2e 7e31 7e33 7e37 7e3b
7e3f 7e42 7e43 7e45 7e48 7e4b 7e4c 7e51
7e55 7e59 7e5f 7e61 7e65 7e69 7e6c 7e70
7e74 7e78 7e7c 7e7f 7e83 7e87 7e8b 7e8f
7e93 7e97 7e9b 7e9f 7ea3 7ea7 7eab 7eb7
7ebb 7ebf 7ec2 7ec6 7eca 7ecc 7ed0 7ed4
7ed8 7edb 7edf 7ee3 7ee5 7ee6 7eeb 1
7eef 7ef3 7ef7 7efa 7efe 7f02 7f06 7f0a
7f0d 7f11 7f15 7f18 7f1b 7f20 7f23 7f26
7f29 7f2a 7f2f 7f30 1 7f32 7f37 7f3b
7f3f 7f42 7f47 7f4c 7f4f 7f53 7f54 7f59
7f5c 7f61 7f62 7f67 7f6a 7f6f 7f70 7f75
7f78 7f7c 7f7d 7f82 7f85 7f8a 7f8b 7f90
7f93 7f97 7f9b 7f9e 7fa1 7fa2 7fa4 7fa5
7faa 7fab 7fb0 7fb2 7fb6 7fb9 7fbb 7fbf
7fc1 7fcd 7fcf 7fd1 7fd2 7fd7 7fdb 7fdd
7fe9 7feb 7fef 7ff3 7ff7 7ffb 7fff 8003
8007 800b 800f 8013 801f 8023 8027 802a
802e 8032 8034 8038 803c 8040 8043 8047
804b 804d 804e 8053 1 8057 805b 805f
8062 8066 806a 806e 8072 8075 8079 807d
8080 8083 8088 808b 808e 8091 8092 8097
8098 1 809a 809f 80a3 80a7 80aa 80af
80b4 80b7 80bb 80bc 80c1 80c4 80c9 80ca
80cf 80d2 80d7 80d8 80dd 80e0 80e4 80e5
80ea 80ed 80f2 80f3 80f8 80fb 80ff 8103
8106 8109 810a 810c 810d 8112 8113 8118
811a 811e 8121 8123 8127 8129 8135 8137
8139 813a 813f 8143 8145 8151 8153 8157
815a 815e 8162 8166 816a 816e 8172 8175
8176 8178 817b 817e 817f 8184 8188 818b
818f 8191 8195 8198 819c 81a0 81a4 81a8
81ac 81b0 81b4 81b8 81bc 81c0 81c4 81c8
81cc 81d0 81d4 81d8 81dc 81e0 81e4 81e8
81ec 81f0 81f4 81f8 81fc 8200 8204 8208
820c 8210 8213 8216 8219 821c 821f 8220
8222 8226 822a 822d 8230 8231 8236 823a
823e 8241 8242 8244 8247 824a 824b 8250
8254 8258 825c 8260 826c 8270 8275 8279
827c 827d 8282 8286 828a 828d 8290 8294
8296 829a 829e 82a1 82a4 82a8 82aa 82ae
82b2 82b5 82b7 82bb 82bf 82c3 82c6 82ca
82ce 82d0 82d1 82d6 1 82da 82de 82e2
82e5 82e9 82ed 82f1 82f5 82f8 82fc 8300
8303 8306 830b 830e 8311 8314 8315 831a
831b 1 831d 8322 8326 832a 832d 8332
8337 833a 833e 833f 8344 8347 834c 834d
8352 8355 835a 835b 8360 8363 8367 8368
836d 8370 8375 8376 837b 837e 8382 8386
8389 838c 838d 838f 8390 8395 8396 839b
839d 83a1 83a4 83a6 83aa 83ac 83b8 83ba
83bc 83bd 83c2 83c6 83c8 83d4 83d6 83d8
83dc 83e0 83e4 83e8 83f4 83f8 83fd 8401
8404 8405 840a 840e 8412 8415 8418 841c
841e 8422 8426 8429 842c 8430 8432 8436
843a 843d 843f 8443 8447 844b 844e 8452
8456 8458 8459 845e 1 8462 8466 846a
846d 8471 8475 8479 847d 8480 8484 8488
848b 848e 8493 8496 8499 849c 849d 84a2
84a3 1 84a5 84aa 84ae 84b2 84b5 84ba
84bf 84c2 84c6 84c7 84cc 84cf 84d4 84d5
84da 84dd 84e2 84e3 84e8 84eb 84ef 84f0
84f5 84f8 84fd 84fe 8503 8506 850a 850e
8511 8514 8515 8517 8518 851d 851e 8523
8525 8529 852c 852e 8532 8534 8540 8542
8544 8545 854a 854e 8550 855c 855e 8560
8564 8568 856b 856d 8571 8574 8578 857a
857e 8582 8585 8586 8588 858b 858e 858f
8594 8598 859c 85a0 85a4 85a8 85ac 85b0
85b4 85b7 85ba 85bb 85bd 85c0 85c5 85c6
85cb 85cf 85d3 85d7 85da 85de 85e0 85e4
85e8 85ec 85ef 85f0 85f2 85f6 85f8 85fc
8600 8603 8607 860b 860f 8613 8617 861b
861f 8623 8627 862b 862f 8633 8637 863b
863f 8643 8647 864b 864f 8653 8657 865b
865f 8663 8667 866b 866f 8673 8677 867b
867e 8681 8684 8687 868a 868b 868d 8691
8695 8698 869b 869c 86a1 86a5 86a9 86ad
86b1 86bd 86c1 86c6 86ca 86cd 86ce 86d3
86d7 86db 86de 86e1 86e5 86e7 86eb 86ef
86f2 86f5 86f9 86fb 86ff 8703 8706 8708
870c 8710 8714 8717 871b 871f 8721 8722
8727 1 872b 872f 8733 8736 873a 873e
8742 8746 8749 874d 8751 8754 8757 875c
875f 8762 8765 8766 876b 876c 1 876e
8773 8777 877b 877e 8783 8788 878b 878f
8790 8795 8798 879d 879e 87a3 87a6 87ab
87ac 87b1 87b4 87b8 87b9 87be 87c1 87c6
87c7 87cc 87cf 87d3 87d7 87da 87dd 87de
87e0 87e1 87e6 87e7 87ec 87ee 87f2 87f5
87f7 87fb 87fd 8809 880b 880d 880e 8813
8817 8819 8825 8827 8829 882d 8830 8832
8836 883a 883d 8841 8845 8849 884c 884d
884f 8852 8855 8856 885b 885f 8867 8869
886a 886d 886f 8873 887a 887c 8880 8883
8885 8889 888d 8890 8894 8897 889a 889b
88a0 88a3 88a7 88ab 88ae 88af 88b1 88b4
88b7 88b8 88bd 1 88c0 88c5 88c9 88cd
88d0 88d1 88d3 88d6 88d9 88da 88df 88e3
88e7 88eb 88f7 88fb 8900 8904 8907 8908
890d 8911 8915 8918 891b 891f 8921 8925
8929 892c 892f 8933 8935 8939 893d 8940
8942 8946 894a 894e 8951 8955 8959 895b
895c 8961 1 8965 8969 896d 8970 8974
8978 897c 8980 8983 8987 898b 898e 8991
8996 8999 899c 899f 89a0 89a5 89a6 1
89a8 89ad 89b1 89b5 89b8 89bd 89c2 89c5
89c9 89ca 89cf 89d2 89d7 89d8 89dd 89e0
89e5 89e6 89eb 89ee 89f2 89f3 89f8 89fb
8a00 8a01 8a06 8a09 8a0d 8a11 8a14 8a17
8a18 8a1a 8a1b 8a20 8a21 8a26 8a28 8a2c
8a2f 8a31 8a35 8a37 8a43 8a45 8a47 8a48
8a4d 8a51 8a53 8a5f 8a61 8a63 8a67 8a6b
8a6f 8a73 8a77 8a7b 8a7f 8a8b 8a8f 8a94
8a98 8a9b 8a9c 8aa1 8aa5 8aa9 8aac 8aaf
8ab3 8ab5 8ab9 8abd 8ac0 8ac3 8ac7 8ac9
8acd 8ad1 8ad4 8ad6 8ada 8ade 8ae2 8ae5
8ae9 8aed 8aef 8af0 8af5 1 8af9 8afd
8b01 8b04 8b08 8b0c 8b10 8b14 8b17 8b1b
8b1f 8b22 8b25 8b2a 8b2d 8b30 8b33 8b34
8b39 8b3a 1 8b3c 8b41 8b45 8b49 8b4c
8b51 8b56 8b59 8b5d 8b5e 8b63 8b66 8b6b
8b6c 8b71 8b74 8b79 8b7a 8b7f 8b82 8b86
8b87 8b8c 8b8f 8b94 8b95 8b9a 8b9d 8ba1
8ba5 8ba8 8bab 8bac 8bae 8baf 8bb4 8bb5
8bba 8bbc 8bc0 8bc3 8bc5 8bc9 8bcb 8bd7
8bd9 8bdb 8bdc 8be1 8be5 8be7 8bf3 8bf5
8bf7 8bfb 8bff 8c02 8c06 8c09 8c0c 8c0d
8c12 8c16 8c1a 8c1d 8c21 8c25 8c28 8c2b
8c30 8c33 8c36 8c39 8c3a 8c3f 8c40 1
8c42 8c47 8c4b 8c4f 8c52 8c57 8c5c 8c5f
8c63 8c64 8c69 8c6c 8c71 8c72 8c77 8c7a
8c7f 8c80 8c85 8c88 8c8c 8c90 8c94 8c98
8c9b 8c9c 8c9e 8ca3 8ca4 8ca6 8ca7 8cac
8caf 8cb4 8cb5 8cba 8cbd 8cc2 8cc3 8cc8
8ccb 8ccf 8cd0 8cd5 8cd8 8cdd 8cde 8ce3
8ce4 8ce9 8ceb 8cef 8cf2 8cf6 8cfa 8cfd
8d01 8d05 8d08 8d0b 8d10 8d13 8d16 8d19
8d1a 8d1f 8d20 1 8d22 8d27 8d2b 8d2f
8d32 8d37 8d3c 8d3f 8d43 8d44 8d49 8d4a
8d4f 8d51 8d55 8d58 8d5c 8d60 8d63 8d67
8d6b 8d6e 8d72 8d76 8d77 8d7c 8d80 8d82
8d86 8d8a 8d8d 8d91 8d94 8d95 8d9a 8d9e
8da2 8da5 8da9 8dad 8db0 8db3 8db8 8dbb
8dbe 8dc1 8dc2 8dc7 8dc8 1 8dca 8dcf
8dd3 8dd7 8dda 8ddf 8de4 8de7 8deb 8dec
8df1 8df4 8df9 8dfa 8dff 8e02 8e07 8e08
8e0d 8e10 8e14 8e18 8e1c 8e20 8e23 8e24
8e26 8e2b 8e2c 8e2e 8e2f 8e34 8e37 8e3c
8e3d 8e42 8e45 8e4a 8e4b 8e50 8e53 8e57
8e58 8e5d 8e60 8e65 8e66 8e6b 8e6c 8e71
8e73 8e77 8e7a 8e7e 8e82 8e85 8e89 8e8d
8e90 8e93 8e98 8e9b 8e9e 8ea1 8ea2 8ea7
8ea8 1 8eaa 8eaf 8eb3 8eb7 8eba 8ebf
8ec4 8ec7 8ecb 8ecc 8ed1 8ed2 8ed7 8ed9
8edd 8ee0 8ee4 8ee8 8eeb 8eef 8ef3 8ef6
8efa 8efe 8eff 8f04 8f08 8f0a 8f0e 8f12
8f16 8f19 8f1d 8f20 8f21 8f26 8f2a 8f2e
8f31 8f35 8f39 8f3c 8f3f 8f44 8f47 8f4a
8f4d 8f4e 8f53 8f54 1 8f56 8f5b 8f5f
8f63 8f66 8f6b 8f70 8f73 8f77 8f78 8f7d
8f80 8f85 8f86 8f8b 8f8e 8f93 8f94 8f99
8f9c 8fa0 8fa4 8fa8 8fac 8faf 8fb0 8fb2
8fb7 8fb8 8fba 8fbb 8fc0 8fc3 8fc8 8fc9
8fce 8fd1 8fd6 8fd7 8fdc 8fdf 8fe3 8fe4
8fe9 8fec 8ff1 8ff2 8ff7 8ff8 8ffd 8fff
9003 9006 900a 900e 9011 9015 9019 901c
901f 9024 9027 902a 902d 902e 9033 9034
1 9036 903b 903f 9043 9046 904b 9050
9053 9057 9058 905d 905e 9063 9065 9069
906c 9070 9074 9077 907b 907f 9082 9086
908a 908b 9090 9092 9096 909a 909e 90a1
90a5 90a9 90ac 90af 90b4 90b7 90ba 90bd
90be 90c3 90c4 1 90c6 90cb 90cf 90d3
90d6 90db 90e0 90e3 90e7 90e8 90ed 90f0
90f5 90f6 90fb 90fe 9103 9104 9109 910c
9110 9114 9118 911c 911f 9120 9122 9127
9128 912a 912b 9130 9133 9138 9139 913e
9141 9146 9147 914c 914f 9153 9154 9159
915c 9161 9162 9167 9168 916d 916f 9173
9176 917a 917e 9181 9185 9189 918c 918f
9194 9197 919a 919d 919e 91a3 91a4 1
91a6 91ab 91af 91b3 91b6 91bb 91c0 91c3
91c7 91c8 91cd 91ce 91d3 91d5 91d9 91dc
91e0 91e4 91e7 91eb 91ef 91f2 91f6 91fa
91fb 9200 9202 9206 920a 920d 920f 9213
9216 921a 921e 9222 9223 9225 9228 9229
922b 922e 9231 9232 9237 923a 923e 9242
9246 9247 9249 924c 924d 924f 9252 9255
9256 925b 1 925e 9263 9267 926b 9270
9275 9279 927d 9281 9284 9287 928b 928f
9294 9297 929c 929d 92a2 92a5 92aa 92ab
92b0 92b3 92b8 92b9 92be 92c1 92c6 92c7
92cc 92cf 92d4 92d5 92da 92dd 92e1 92e2
92e7 92ea 92ef 92f0 92f5 92f8 92fd 92fe
9303 9306 930a 930b 9310 9313 9318 9319
931e 9321 9325 9326 932b 932e 9333 9334
9339 933d 9341 9345 9349 934e 9352 9356
935b 935f 9362 9363 9368 936c 9370 9373
9376 937a 937c 9380 9384 9387 938a 938e
9390 9394 9398 939b 939d 93a1 93a5 93a9
93ac 93b0 93b4 93b6 93b7 93bc 1 93c0
93c4 93c8 93cb 93cf 93d3 93d7 93db 93de
93e2 93e6 93e9 93ec 93f1 93f4 93f7 93fa
93fb 9400 9401 1 9403 9408 940c 9410
9413 9418 941d 9420 9424 9425 942a 942d
9432 9433 9438 943b 9440 9441 9446 9449
944d 944e 9453 9456 945b 945c 9461 9464
9468 946c 946f 9472 9473 9475 9476 947b
947c 9481 9485 9489 948c 9491 9496 9499
949d 949e 94a3 94a4 94a9 94ab 94af 94b2
94b4 94b8 94ba 94c6 94c8 94ca 94cb 94d0
94d4 94d6 94e2 94e4 94e8 94ec 94f1 94f6
94fa 94fe 9502 9505 9508 950c 9510 9515
9518 951d 951e 9523 9526 952b 952c 9531
9534 9539 953a 953f 9542 9547 9548 954d
9550 9555 9556 955b 955e 9562 9563 9568
956b 9570 9571 9576 9579 957e 957f 9584
9587 958b 958c 9591 9594 9599 959a 959f
95a2 95a6 95a7 95ac 95af 95b4 95b5 95ba
95be 95c2 95c6 95ca 95cf 95d3 95d7 95dc
95e0 95e3 95e4 95e9 95ed 95f1 95f4 95f7
95fb 95fd 9601 9605 9608 960b 960f 9611
9615 9619 961c 961e 9622 9626 962a 962d
9631 9635 9637 9638 963d 1 9641 9645
9649 964c 9650 9654 9658 965c 965f 9663
9667 966a 966d 9672 9675 9678 967b 967c
9681 9682 1 9684 9689 968d 9691 9694
9699 969e 96a1 96a5 96a6 96ab 96ae 96b3
96b4 96b9 96bc 96c1 96c2 96c7 96ca 96ce
96cf 96d4 96d7 96dc 96dd 96e2 96e5 96e9
96ed 96f0 96f3 96f4 96f6 96f7 96fc 96fd
9702 9706 970a 970d 9712 9717 971a 971e
971f 9724 9725 972a 972c 9730 9733 9735
9739 973b 9747 9749 974b 974c 9751 9755
9757 9763 9765 9769 976d 9770 9774 9775
977a 977e 9782 9787 978a 978f 9790 9795
9798 979d 979e 97a3 97a6 97ab 97ac 97b1
97b4 97b9 97ba 97bf 97c2 97c7 97c8 97cd
97d0 97d5 97d6 97db 97de 97e3 97e4 97e9
97ec 97f1 97f2 97f7 97fa 97ff 9800 9805
9808 980d 980e 9813 9816 981b 981c 9821
9824 9829 982a 982f 9832 9836 9837 983c
983f 9844 9845 984a 984d 9852 9853 9858
985b 985f 9860 9865 9868 986d 986e 9873
9876 987b 987c 9881 9884 9889 988a 988f
9892 9896 9897 989c 989f 98a4 98a5 98aa
98ad 98b2 98b3 98b8 98bb 98c0 98c1 98c6
98c9 98ce 98cf 98d4 98d7 98dc 98dd 98e2
98e5 98ea 98eb 98f0 98f3 98f8 98f9 98fe
9901 9906 9907 990c 990f 9914 9915 991a
991d 9921 9922 9927 992a 992f 9930 9935
9938 993d 993e 9943 9946 994b 994c 9951
9954 9959 995a 995f 9962 9967 9968 996d
9970 9974 9975 997a 997d 9982 9983 9988
998b 9990 9991 9996 999a 999e 99a2 99a6
99ab 99af 99b3 99b8 99bc 99bf 99c0 99c5
99c9 99cd 99d0 99d3 99d7 99d9 99dd 99e1
99e4 99e7 99eb 99ed 99f1 99f5 99f8 99fa
99fe 9a02 9a06 9a09 9a0d 9a11 9a13 9a14
9a19 1 9a1d 9a21 9a25 9a28 9a2c 9a30
9a34 9a38 9a3b 9a3f 9a43 9a46 9a49 9a4e
9a51 9a54 9a57 9a58 9a5d 9a5e 1 9a60
9a65 9a69 9a6d 9a70 9a75 9a7a 9a7d 9a81
9a82 9a87 9a8a 9a8f 9a90 9a95 9a98 9a9d
9a9e 9aa3 9aa6 9aaa 9aab 9ab0 9ab3 9ab8
9ab9 9abe 9ac1 9ac5 9ac9 9acc 9acf 9ad0
9ad2 9ad3 9ad8 9ad9 9ade 9ae2 9ae6 9ae9
9aee 9af3 9af6 9afa 9afb 9b00 9b01 9b06
9b08 9b0c 9b0f 9b11 9b15 9b17 9b23 9b25
9b27 9b28 9b2d 9b31 9b33 9b3f 9b41 9b45
9b4a 9b4d 9b52 9b53 9b58 9b5b 9b60 9b61
9b66 9b69 9b6e 9b6f 9b74 9b77 9b7b 9b7f
9b83 9b86 9b87 9b89 9b8a 9b8c 9b8d 9b92
9b95 9b9a 9b9b 9ba0 9ba3 9ba8 9ba9 9bae
9bb1 9bb5 9bb9 9bbd 9bc0 9bc1 9bc3 9bc4
9bc6 9bc7 9bcc 9bcf 9bd4 9bd5 9bda 9bdd
9be2 9be3 9be8 9beb 9bf0 9bf1 9bf6 9bf9
9bfe 9bff 9c04 9c07 9c0c 9c0d 9c12 9c15
9c1a 9c1b 9c20 9c23 9c28 9c29 9c2e 9c31
9c36 9c37 9c3c 9c3f 9c44 9c45 9c4a 9c4d
9c51 9c55 9c59 9c5c 9c5d 9c5f 9c60 9c62
9c63 9c68 9c6b 9c70 9c71 9c76 9c79 9c7e
9c7f 9c84 9c87 9c8b 9c8f 9c93 9c96 9c97
9c99 9c9a 9c9c 9c9d 9ca2 9ca5 9caa 9cab
9cb0 9cb3 9cb8 9cb9 9cbe 9cc1 9cc6 9cc7
9ccc 9ccf 9cd4 9cd5 9cda 9cdd 9ce2 9ce3
9ce8 9cec 9cf0 9cf2 9cf6 9cfa 9cfe 9cff
9d01 9d04 9d05 9d07 9d0a 9d0d 9d0e 9d13
9d17 9d1b 9d20 9d25 9d29 9d2d 9d31 9d34
9d37 9d3b 9d3f 9d44 9d47 9d4c 9d4d 9d52
9d55 9d5a 9d5b 9d60 9d63 9d68 9d69 9d6e
9d71 9d76 9d77 9d7c 9d7f 9d84 9d85 9d8a
9d8d 9d91 9d92 9d97 9d9a 9d9f 9da0 9da5
9da8 9dad 9dae 9db3 9db6 9dba 9dbb 9dc0
9dc3 9dc8 9dc9 9dce 9dd2 9dd6 9dda 9dde
9de3 9de7 9deb 9df0 9df4 9df7 9df8 9dfd
9e01 9e05 9e08 9e0b 9e0f 9e11 9e15 9e19
9e1c 9e1f 9e23 9e25 9e29 9e2d 9e30 9e32
9e36 9e3a 9e3e 9e41 9e45 9e49 9e4b 9e4c
9e51 1 9e55 9e59 9e5d 9e60 9e64 9e68
9e6c 9e70 9e73 9e77 9e7b 9e7e 9e81 9e86
9e89 9e8c 9e8f 9e90 9e95 9e96 1 9e98
9e9d 9ea1 9ea5 9ea8 9ead 9eb2 9eb5 9eb9
9eba 9ebf 9ec2 9ec7 9ec8 9ecd 9ed0 9ed5
9ed6 9edb 9ede 9ee2 9ee3 9ee8 9eeb 9ef0
9ef1 9ef6 9ef9 9efd 9f01 9f04 9f07 9f08
9f0a 9f0b 9f10 9f11 9f16 9f1a 9f1e 9f21
9f26 9f2b 9f2e 9f32 9f33 9f38 9f39 9f3e
9f40 9f44 9f47 9f49 9f4d 9f4f 9f5b 9f5d
9f5f 9f60 9f65 9f69 9f6b 9f77 9f79 9f7d
9f81 9f86 9f8b 9f8f 9f93 9f97 9f9a 9f9d
9fa1 9fa5 9faa 9fad 9fb2 9fb3 9fb8 9fbb
9fc0 9fc1 9fc6 9fc9 9fce 9fcf 9fd4 9fd7
9fdc 9fdd 9fe2 9fe5 9fea 9feb 9ff0 9ff3
9ff7 9ff8 9ffd a000 a005 a006 a00b a00e
a012 a013 a018 a01b a020 a021 a026 a02a
a02e a032 a036 a03b a03f a043 a048 a04c
a04f a050 a055 a059 a05d a060 a063 a067
a069 a06d a071 a074 a077 a07b a07d a081
a085 a088 a08a a08e a092 a096 a099 a09d
a0a1 a0a3 a0a4 a0a9 1 a0ad a0b1 a0b5
a0b8 a0bc a0c0 a0c4 a0c8 a0cb a0cf a0d3
a0d6 a0d9 a0de a0e1 a0e4 a0e7 a0e8 a0ed
a0ee 1 a0f0 a0f5 a0f9 a0fd a100 a105
a10a a10d a111 a112 a117 a11a a11f a120
a125 a128 a12d a12e a133 a136 a13a a13b
a140 a143 a148 a149 a14e a151 a155 a159
a15c a15f a160 a162 a163 a168 a169 a16e
a172 a176 a179 a17e a183 a186 a18a a18b
a190 a191 a196 a198 a19c a19f a1a1 a1a5
a1a7 a1b3 a1b5 a1b7 a1b8 a1bd a1c1 a1c3
a1cf a1d1 a1d5 a1d9 a1dc a1e0 a1e1 a1e6
a1ea a1ee a1f3 a1f6 a1fb a1fc a201 a204
a209 a20a a20f a212 a217 a218 a21d a220
a225 a226 a22b a22e a233 a234 a239 a23c
a241 a242 a247 a24a a24f a250 a255 a258
a25d a25e a263 a266 a26b a26c a271 a274
a278 a279 a27e a281 a286 a287 a28c a28f
a294 a295 a29a a29d a2a1 a2a2 a2a7 a2aa
a2af a2b0 a2b5 a2b8 a2bd a2be a2c3 a2c6
a2cb a2cc a2d1 a2d4 a2d8 a2d9 a2de a2e1
a2e6 a2e7 a2ec a2f0 a2f4 a2f8 a2fc a301
a305 a309 a30e a312 a315 a316 a31b a31f
a323 a326 a329 a32d a32f a333 a337 a33a
a33d a341 a343 a347 a34b a34e a350 a354
a358 a35c a35f a363 a367 a369 a36a a36f
1 a373 a377 a37b a37e a382 a386 a38a
a38e a391 a395 a399 a39c a39f a3a4 a3a7
a3aa a3ad a3ae a3b3 a3b4 1 a3b6 a3bb
a3bf a3c3 a3c6 a3cb a3d0 a3d3 a3d7 a3d8
a3dd a3e0 a3e5 a3e6 a3eb a3ee a3f3 a3f4
a3f9 a3fc a400 a401 a406 a409 a40e a40f
a414 a417 a41b a41f a422 a425 a426 a428
a429 a42e a42f a434 a438 a43c a43f a444
a449 a44c a450 a451 a456 a457 a45c a45e
a462 a465 a467 a46b a46d a479 a47b a47d
a47e a483 a487 a489 a495 a497 a49b a4a0
a4a3 a4a8 a4a9 a4ae a4b1 a4b6 a4b7 a4bc
a4bf a4c4 a4c5 a4ca a4cd a4d1 a4d5 a4d9
a4dc a4dd a4df a4e0 a4e2 a4e3 a4e8 a4eb
a4f0 a4f1 a4f6 a4f9 a4fd a501 a505 a508
a509 a50b a50c a50e a50f a514 a517 a51c
a51d a522 a525 a52a a52b a530 a533 a538
a539 a53e a541 a546 a547 a54c a54f a554
a555 a55a a55e a560 a564 a568 a56c a571
a576 a57a a57e a582 a585 a588 a58c a590
a595 a598 a59d a59e a5a3 a5a6 a5ab a5ac
a5b1 a5b4 a5b9 a5ba a5bf a5c2 a5c7 a5c8
a5cd a5d0 a5d5 a5d6 a5db a5de a5e3 a5e4
a5e9 a5ec a5f0 a5f1 a5f6 a5f9 a5fe a5ff
a604 a607 a60c a60d a612 a615 a619 a61a
a61f a622 a627 a628 a62d a630 a635 a636
a63b a63f a643 a647 a64b a650 a654 a658
a65d a661 a664 a665 a66a a66e a672 a675
a678 a67c a67e a682 a686 a689 a68c a690
a692 a696 a69a a69d a69f a6a3 a6a7 a6ab
a6ae a6b2 a6b6 a6b8 a6b9 a6be 1 a6c2
a6c6 a6ca a6cd a6d1 a6d5 a6d9 a6dd a6e0
a6e4 a6e8 a6eb a6ee a6f3 a6f6 a6f9 a6fc
a6fd a702 a703 1 a705 a70a a70e a712
a715 a71a a71f a722 a726 a727 a72c a72f
a734 a735 a73a a73d a742 a743 a748 a74b
a74f a750 a755 a758 a75d a75e a763 a766
a76a a76e a771 a774 a775 a777 a778 a77d
a77e a783 a787 a78b a78e a793 a798 a79b
a79f a7a0 a7a5 a7a6 a7ab a7ad a7b1 a7b4
a7b6 a7ba a7bc a7c8 a7ca a7cc a7cd a7d2
a7d6 a7d8 a7e4 a7e6 a7ea a7ee a7f3 a7f8
a7fc a800 a804 a807 a80a a80e a812 a817
a81a a81f a820 a825 a828 a82d a82e a833
a836 a83b a83c a841 a844 a849 a84a a84f
a852 a857 a858 a85d a860 a864 a865 a86a
a86d a872 a873 a878 a87b a87f a880 a885
a888 a88d a88e a893 a897 a89b a89f a8a3
a8a8 a8ac a8b0 a8b5 a8b9 a8bc a8bd a8c2
a8c6 a8ca a8cd a8d0 a8d4 a8d6 a8da a8de
a8e1 a8e4 a8e8 a8ea a8ee a8f2 a8f5 a8f7
a8fb a8ff a903 a906 a90a a90e a910 a911
a916 1 a91a a91e a922 a925 a929 a92d
a931 a935 a938 a93c a940 a943 a946 a94b
a94e a951 a954 a955 a95a a95b 1 a95d
a962 a966 a96a a96d a972 a977 a97a a97e
a97f a984 a987 a98c a98d a992 a995 a99a
a99b a9a0 a9a3 a9a7 a9a8 a9ad a9b0 a9b5
a9b6 a9bb a9be a9c2 a9c6 a9c9 a9cc a9cd
a9cf a9d0 a9d5 a9d6 a9db a9df a9e3 a9e6
a9eb a9f0 a9f3 a9f7 a9f8 a9fd a9fe aa03
aa05 aa09 aa0c aa0e aa12 aa14 aa20 aa22
aa24 aa25 aa2a aa2e aa30 aa3c aa3e aa42
aa46 aa49 aa4d aa4e aa53 aa57 aa5b aa60
aa63 aa68 aa69 aa6e aa71 aa76 aa77 aa7c
aa7f aa84 aa85 aa8a aa8d aa92 aa93 aa98
aa9b aaa0 aaa1 aaa6 aaa9 aaae aaaf aab4
aab7 aabc aabd aac2 aac5 aaca aacb aad0
aad3 aad8 aad9 aade aae1 aae5 aae6 aaeb
aaee aaf3 aaf4 aaf9 aafc ab01 ab02 ab07
ab0a ab0f ab10 ab15 ab18 ab1d ab1e ab23
ab26 ab2a ab2b ab30 ab33 ab38 ab39 ab3e
ab42 ab46 ab4a ab4e ab53 ab57 ab5b ab60
ab64 ab67 ab68 ab6d ab71 ab75 ab78 ab7b
ab7f ab81 ab85 ab89 ab8c ab8f ab93 ab95
ab99 ab9d aba0 aba2 aba6 abaa abae abb1
abb5 abb9 abbb abbc abc1 1 abc5 abc9
abcd abd0 abd4 abd8 abdc abe0 abe3 abe7
abeb abee abf1 abf6 abf9 abfc abff ac00
ac05 ac06 1 ac08 ac0d ac11 ac15 ac18
ac1d ac22 ac25 ac29 ac2a ac2f ac32 ac37
ac38 ac3d ac40 ac45 ac46 ac4b ac4e ac52
ac53 ac58 ac5b ac60 ac61 ac66 ac69 ac6d
ac71 ac74 ac77 ac78 ac7a ac7b ac80 ac81
ac86 ac8a ac8e ac91 ac96 ac9b ac9e aca2
aca3 aca8 aca9 acae acb0 acb4 acb7 acb9
acbd acbf accb accd accf acd0 acd5 acd9
acdb ace7 ace9 aced acf2 acf5 acfa acfb
ad00 ad03 ad08 ad09 ad0e ad11 ad16 ad17
ad1c ad1f ad23 ad27 ad2b ad2e ad2f ad31
ad32 ad34 ad35 ad3a ad3d ad42 ad43 ad48
ad4b ad50 ad51 ad56 ad59 ad5d ad61 ad65
ad68 ad69 ad6b ad6c ad6e ad6f ad74 ad77
ad7c ad7d ad82 ad85 ad8a ad8b ad90 ad93
ad98 ad99 ad9e ada1 ada6 ada7 adac adaf
adb4 adb5 adba adbe adc0 adc4 adc8 adcb
adcf add3 add6 adda adde ade1 ade4 ade9
adec adef adf2 adf3 adf8 adf9 1 adfb
ae00 ae04 ae08 ae0b ae10 ae15 ae18 ae1c
ae1d ae22 ae23 ae28 ae2a ae2e ae31 ae35
ae39 ae3c ae40 ae44 ae47 ae4a ae4f ae52
ae55 ae58 ae59 ae5e ae5f 1 ae61 ae66
ae6a ae6e ae71 ae76 ae7b ae7e ae82 ae83
ae88 ae89 ae8e ae90 ae94 ae97 ae9b ae9f
aea3 aea6 aeaa aeab aead aeb1 aeb3 aeb7
aebb aebe aec2 aec6 aec9 aecd aed1 aed4
aed7 aedc aedf aee2 aee5 aee6 aeeb aeec
1 aeee aef3 aef7 aefb aefe af03 af08
af0b af0f af10 af15 af16 af1b af1f af23
af26 af2b af30 af33 af37 af3b af3e af3f
af44 af47 af4c af4d af52 af55 af59 af5d
af60 af61 af66 af67 af6c af6e af72 af75
af79 af7d af81 af85 af89 af8d af91 af95
af99 afa5 afaa afae afb2 afb6 afba afbc
afbd afc2 1 afc6 afca afce afd1 afd5
afd9 afdd afe1 afe4 afe8 afec afef aff2
aff7 affa affd b000 b001 b006 b007 1
b009 b00e b012 b016 b019 b01e b023 b026
b02a b02b b030 b031 b036 b03a b03e b041
b046 b04b b04e b052 b053 b058 b05b b060
b061 b066 b069 b06d b071 b074 b077 b078
b07a b07b b080 b081 b086 b088 b08c b08f
b093 b097 b09b b09f b0a3 b0a7 b0ab b0b7
b0bc b0c0 b0c4 b0c8 b0cc b0ce b0d2 b0d4
b0e0 b0e2 b0e4 b0e5 b0ea b0ee b0f0 b0fc
b100 b102 b103 b10c 
32fc
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 10 :3 6 e :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 14 1d
1c :2 14 :2 4 e 17 16 :2 e :2 4
f 18 17 :2 f :2 4 f 18 17
:2 f :2 4 d 16 15 :2 d :2 4 12
1b 1a :2 12 :2 4 11 1a 19 :2 11
:2 4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 :3 10 :2 4 :3 f :2 4 f
18 17 :2 f :2 4 10 19 18 :2 10
:2 4 10 19 18 :2 10 :2 4 f 18
17 :2 f :2 4 10 19 18 :2 10 :2 4
10 19 18 :2 10 :2 4 :2 c 1b c
:2 4 :2 e 1d e :2 4 :2 b 1a b
:2 4 :2 10 1f 10 :2 4 :2 a 19 a
:2 4 :2 b 1a b :2 4 :2 11 20 11
:2 4 :2 d 1c d :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 c 1b c
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 12 21 12
:2 4 :2 f 1e f :2 4 :2 c 1b c
:2 4 :2 c 1b c :2 4 :2 f 1e f
:2 4 :2 11 20 11 :2 4 :2 11 20 11
:2 4 :2 16 25 16 :2 4 :2 16 25 16
:2 4 :2 b 1a b :2 4 d 16 15
:2 d :2 4 11 1a 19 :2 11 :2 4 :2 f
19 f :2 4 9 12 11 :2 9 :2 4
:2 17 26 17 :2 4 17 1c 1b :2 17
:2 4 18 1d 1c :2 18 :2 4 16 1f
1e :2 16 :2 4 :2 13 22 13 :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 14
1d 1c :2 14 :2 4 15 1e 1d :2 15
:2 4 :2 10 1f 10 :2 4 :2 f 1e f
:2 4 7 10 f :2 7 :2 4 :2 6 1e
6 :2 4 :2 7 1f 7 :2 4 :2 d 25
d :2 4 :2 8 20 8 :2 4 :3 d :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 53 59 5c :2 53 6a 7f 8
:2 6a d 10 :2 6a 17 1a :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
2c 2f :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 2d 30 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 34 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
2f :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 2e :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 34 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 34 :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 40 :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4e 4f :2 4b :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e :2 7 52 :3 4
14 :2 4 14 :2 4 13 :2 4 12 :2 4
10 :2 4 e :2 4 14 :2 4 f :2 4
12 :2 4 e :2 4 e :2 4 11 :2 4
11 :2 4 13 :2 4 11 :2 4 13 :2 4
17 :2 4 14 1d 26 2e :2 1d :2 14
:2 4 13 :2 4 12 :2 4 10 4 :4 8
7 a :2 14 26 :2 30 3c 3f 4e
51 52 :2 4e :2 26 :3 a :2 10 15 21
5f 62 :2 21 6f 72 :2 21 76 79
:2 21 83 86 8f 97 :2 a0 :2 8f b6
:2 86 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4e 51 52 :2 4e :2 26
:3 a :2 10 15 21 5f 62 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 46 :2 7 18
:2 4 :4 8 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b6 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 46
:2 7 1b :2 4 7 10 1b :2 7 1e
20 :2 1e 26 2f 37 :2 26 3a 3c
:2 3a :2 7 42 4b 53 :2 42 56 58
:2 56 :2 7 a :2 14 26 :2 30 3c 3f
4e 51 52 :2 4e :2 26 :3 a :2 10 15
21 5f 62 :2 21 6f 72 :2 21 76
79 :2 21 83 86 8f 97 :2 a0 :2 8f
b1 :2 86 :2 21 :2 a 55 :2 7 a :2 14
26 :2 30 3c 3f 4e 51 52 :2 4e
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:2 a 55 :3 7 :2 12 28 :2 31 41 :2 7
5a :2 4 :4 9 8 7 :4 2b 2a 29
:2 7 11 1c 21 33 3e 43 :2 f
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 8b 8e :2 27 96 99 :2 27 a5
a8 af b8 bb :2 a8 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 48 b :2 14
1f 1d :2 28 :2 1d a 3d 46 4f
:2 3d 52 54 :2 52 3c :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 62 65 :2 24
72 75 :2 24 79 7c :2 24 86 89
92 9a :2 a3 :2 92 c0 :2 89 :2 24 :2 d
58 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 62 65 :2 24 :2 d 58 :3 a :2 15
2b :2 34 50 :2 a 57 :3 7 e 7
4 48 :4 c b a :4 2a 29 28
:2 a 11 23 f :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 8b 8e :2 27
96 99 :2 27 a5 a8 af b8 bb
:2 a8 :2 27 :2 10 5c :2 d :2 a :4 16 :2 a
7 :4 43 48 :3 4 12 4 :4 8 :2 7
16 7 20 :3 4 10 17 21 24
:2 10 :2 4 12 19 25 28 :2 12 :2 4
13 4 7 10 18 :2 7 1b 1d
:2 1b 7 13 1a 21 2e 31 :2 1a
36 39 :2 13 :2 7 15 :2 1e 27 2a
2d 31 :2 15 7 a 18 21 29
:2 18 :2 a 2d 30 :2 2d 14 20 29
3f 48 60 12 20 2b 37 12
20 2d :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :4 32
14 16 1f 21 2c 2e 40 42
55 57 d 16 18 2e 37 39
51 53 12 1a 27 38 4a d
18 24 34 3c 3f 47 13 15
22 30 32 3e 47 4f 58 66
6f 7d 86 94 9d aa b3 c4
cd e0 e9 fe 107 122 12b 143
14c 15d 166 178 181 199 1a2 1b5
1be 1df 1e1 1ee 1f0 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :7 7 b :2 14 1f 1d :2 28
:2 1d a 14 20 2c 3a 12 20
2d :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 38 e
:2 17 22 20 :2 2b :2 20 d :4 11 :2 10
20 10 21 :2 d 17 20 36 3f
57 15 20 2c 15 23 30 :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5e
5f :2 5b :2 32 :3 16 :2 1c 21 2d 6b
6e :2 2d 7b 7e :2 2d 82 85 :2 2d
91 94 :2 2d 9c 9f :2 2d ab ae
b5 be c1 :2 ae :2 2d :2 16 62 :2 13
:2 10 :4 1c :2 10 d :4 3b 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 b9 :2 8c :2 27 c1 c4
:2 27 cc cf :2 27 d4 d7 :2 27 e1
e4 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 47 52 :2 d
:4 a 38 a 1a a :5 7 15 7
11 21 f 10 1d :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 1f a 13 1f :2 a 22
24 :2 22 14 24 12 13 20 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 26 d :2 18 1f
2d :2 d 32 34 :2 32 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 bb :2 8c :2 27 c3 c6
:2 27 ce d1 :2 27 d6 d9 :2 27 e6
e9 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 49 57 :2 d
36 :2 a 26 :2 7 1f 11 1a 30
39 51 f 1a 26 f 1d 2a
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 8b 8e :2 27 96 99 :2 27 a5
a8 af b8 bb :2 a8 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 4 b :2 14
1f 1d :2 28 :2 1d a 23 2e 3e
4e 5b :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 38
e :2 17 22 20 :2 2b :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 89
8c 95 9d :2 a6 :2 95 b7 :2 8c :2 27
bf c2 :2 27 ca cd :2 27 d2 d5
:2 27 e2 e5 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 :2 10 5b :3 d :2 18 2c :2 35 45
53 :2 d 3b :2 a 38 :2 7 :4 4 8
11 1e :2 8 23 21 :2 2c :2 21 43
e 1b :2 43 20 1e :2 29 :2 1e :2 8
7 41 4a 52 :2 41 55 57 :2 55
40 :2 7 a 13 1f :2 a 25 22
:2 2e :2 22 42 d 19 :2 42 1f 1c
:2 28 :2 1c :3 a 18 a 3d :3 7 e
:2 7 11 7 5a a e 10 :2 e
a 18 :2 a 19 :2 a 18 29 35
42 4b 54 :2 42 58 61 69 :2 58
22 2b 37 :2 22 3b 44 4f :2 3b
53 20 2b :2 53 2f 38 46 :2 2f
4a 53 5e :2 4a 22 2b 37 :2 22
3b 43 4d :2 18 a d 16 22
:2 d 27 25 :2 30 :2 25 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 b7 :2 8c :2 27 :2 10 5b
:2 d 10 :2 1a 2c :2 36 42 45 54
57 58 :2 54 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 :2 10 5b :3 d :2 18 2e
:2 37 47 :2 d a 3f 10 19 25
:2 10 28 2b :2 28 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 89 8c 95 9d
:2 95 aa :2 8c :2 27 b2 b5 :2 27 bd
c0 :2 27 c5 c8 :2 27 d5 d8 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 :2 10 5b :3 d
:2 18 2c 35 41 :2 2c 45 53 :2 d
2d 3f :3 a 19 a :4 e :2 d 1c
d 23 :2 a 7 12 e 17 1f
:2 e 22 24 :2 22 d 2c 35 3d
:2 2c 40 43 :2 40 2b :2 d e 17
1f :2 e 22 24 :2 22 d 2b 34
3c :2 2b 3f 41 :2 3f 2a :3 d 18
d a 44 10 19 21 :2 10 24
26 :2 24 d 18 d a 28 44
11 1a 22 :2 11 25 27 :2 25 10
2e 37 3f :2 2e 42 44 :2 42 2d
:2 10 d 18 d a 47 44 10
19 21 :2 10 24 26 :2 24 d 17
20 2c :2 17 2f 31 3a 42 :2 31
:2 17 :2 d 18 d 28 44 :2 a 48
12 :2 7 :5 4 :3 17 :2 4 12 :2 4 13
:2 4 d :2 16 22 29 32 3e :2 29
42 :2 4b :2 22 21 5a :2 d :2 4 12
19 22 2e :2 19 32 :2 3b :2 12 4
7 10 18 :2 7 1b 1d :2 1b 7
1a 29 37 3f 4a 54 25 :2 1a
7 a 13 1e :2 a 23 21 :2 2c
:2 21 d 16 27 :2 d 2a 2c :2 2a
d 20 :2 29 d 2e :2 a d :2 17
29 :2 33 3f 43 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 62 65 :2 24
72 75 :2 24 79 7c :2 24 86 89
92 9a :2 92 ac :2 89 :2 24 b4 b7
:2 24 bf c2 :2 24 c7 ca :2 24 d6
d9 :2 24 :2 d 59 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 :2 d
58 :3 a :2 15 29 32 43 :2 29 47
54 :2 a 40 :2 7 a 13 24 :2 a
27 2a :2 27 30 39 4a :2 30 4d
50 :2 4d :2 a d :2 17 29 :2 33 3f
43 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 62 65 :2 24 72 75 :2 24
79 7c :2 24 86 89 92 9a :2 92
ac :2 89 :2 24 b4 b7 :2 24 bf c2
:2 24 c7 ca :2 24 d6 d9 :2 24 :2 d
59 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 62 65 :2 24 :2 d 58 :3 a :2 15
29 32 43 :2 29 47 54 :2 a 52
:3 7 15 7 11 15 24 2f 34
44 4f 54 58 f 1b f 10
1d e 18 e 1c e 1e :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 75 78 :2 27 7c 7f :2 27
8b 8e :2 27 96 99 :2 27 a5 a8
af b8 bb :2 a8 :2 27 :2 10 5c :2 d
:2 a :4 16 :2 a 7 :3 1f b :2 14 1f
1d :2 28 :2 1d a :4 3e 3d 3c :3 a
18 a d 16 1f :2 d 22 24
:2 22 d 1d d 26 :2 a 57 :3 7
16 :2 7 12 7 a e 10 :2 e
d 14 20 23 :2 d 26 28 :2 26
17 2e 1b 23 2a 48 50 57
70 78 7f 10 18 1f 3c 44
4b 64 6c 73 10 1e 39 15
26 32 3b 15 16 1e 2f 3b
48 5e :2 10 :2 19 25 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5e 5f :2 5b :2 32 :3 16 :2 1c
21 2d 6b 6e :2 2d 7b 7e :2 2d
82 85 :2 2d 91 94 :2 2d 9c 9f
:2 2d ab ae b5 be c1 :2 ae :2 2d
:2 16 62 :2 13 :2 10 :4 1c :2 10 d :3 2c
11 :2 1a 25 23 :2 2e :2 23 :2 10 1e
10 14 1d 2b :2 14 2e 30 :2 2e
13 37 40 49 :2 37 4c 4e :2 4c
36 :2 13 1d 34 21 29 30 4e
56 5d 78 80 87 16 1e 25
42 4a 51 6c 74 7b 16 26
1b 2c 38 1b 1c 24 35 41
4e 64 :2 16 :2 1f 2b 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 61 64 65 :2 61 :2 38 :3 1c :2 22
27 33 71 74 :2 33 81 84 :2 33
88 8b :2 33 97 9a :2 33 a2 a5
:2 33 b1 b4 bb c4 c7 :2 b4 :2 33
:2 1c 68 :2 19 :2 16 :4 22 :2 16 13 :4 51
13 22 13 :4 10 d 3e 14 :2 1d
28 26 :2 31 :2 26 13 45 4e 57
:2 45 5a 5c :2 5a 44 :2 13 1a 31
1e 26 2d 4b 53 5a 75 7d
84 13 1b 22 3f 47 4e 69
71 78 13 23 18 29 35 18
19 21 32 3e 4b 61 :2 13 :2 1c
28 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 5e 61 62
:2 5e :2 35 :3 19 :2 1f 24 30 6e 71
:2 30 7e 81 :2 30 85 88 :2 30 94
97 :2 30 9f a2 :2 30 ae b1 b8
c1 c4 :2 b1 :2 30 :2 19 65 :2 16 :2 13
:4 1f :2 13 10 :4 5f 3e :2 d 2c 17
2e 1a 22 29 47 4f 56 71
79 80 10 18 1f 3c 44 4b
66 6e 75 10 20 15 26 32
15 16 1e 2f 3b 48 5e :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5e
5f :2 5b :2 32 :3 16 :2 1c 21 2d 6b
6e :2 2d 7b 7e :2 2d 82 85 :2 2d
91 94 :2 2d 9c 9f :2 2d ab ae
b5 be c1 :2 ae :2 2d :2 16 62 :2 13
:2 10 :4 1c :2 10 d :7 a 12 d 14
20 23 :2 d 26 28 :2 26 17 2e
44 4c 53 71 79 80 99 a1
a8 c2 ce ec 15 26 31 3a
15 16 1e 2f 3b 48 5e :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5e
5f :2 5b :2 32 :3 16 :2 1c 21 2d 6b
6e :2 2d 7b 7e :2 2d 82 85 :2 2d
91 94 :2 2d 9c 9f :2 2d ab ae
b5 be c1 :2 ae :2 2d :2 16 62 :2 13
:2 10 :4 1c :2 10 d :3 2c 11 :2 1a 25
23 :2 2e :2 23 :2 10 1e 10 14 1d
2b :2 14 2e 30 :2 2e 13 37 40
49 :2 37 4c 4e :2 4c 36 :2 13 1d
34 4d 55 5c 75 7d 84 a0
ac 1b 2c 37 1b 1c 24 35
41 4e 64 :2 16 :2 1f 2b 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 61 64 65 :2 61 :2 38 :3 1c
:2 22 27 33 71 74 :2 33 81 84
:2 33 88 8b :2 33 97 9a :2 33 a2
a5 :2 33 b1 b4 bb c4 c7 :2 b4
:2 33 :2 1c 68 :2 19 :2 16 :4 22 :2 16 13
:4 51 13 22 :2 13 :4 10 d 3e 14
:2 1d 28 26 :2 31 :2 26 13 1a 31
49 51 58 76 7e 85 a0 a8
af cb d7 18 29 34 18 19
21 32 3e 4b 61 :2 13 :2 1c 28
13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 5e 61 62 :2 5e
:2 35 :3 19 :2 1f 24 30 6e 71 :2 30
7e 81 :2 30 85 88 :2 30 94 97
:2 30 9f a2 :2 30 ae b1 b8 c1
c4 :2 b1 :2 30 :2 19 65 :2 16 :2 13 :4 1f
:2 13 10 :4 41 3e :2 d 2c 17 2e
46 4e 55 73 7b 82 9d a5
ac c8 d4 15 26 31 15 16
1e 2f 3b 48 5e :2 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5e 5f :2 5b
:2 32 :3 16 :2 1c 21 2d 6b 6e :2 2d
7b 7e :2 2d 82 85 :2 2d 91 94
:2 2d 9c 9f :2 2d ab ae b5 be
c1 :2 ae :2 2d :2 16 62 :2 13 :2 10 :4 1c
:2 10 d :7 a :4 7 b :2 14 1f 1d
:2 28 :2 1d a d 16 1f :2 d 22
24 :2 22 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 89 8c 95 9d :2 a6 :2 95
be :2 8c :2 27 c6 c9 :2 27 d1 d4
:2 27 d9 dc :2 27 e5 e8 :2 27 :2 10
5c :2 d 10 :2 1a 2c :2 36 42 45
54 57 58 :2 54 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 :2 10 5b :3 d :2 18
2c :2 35 4c 56 :2 d a 26 :4 11
10 32 3b 45 :2 32 48 4a :2 48
:3 10 14 16 :2 14 10 20 10 1a
1e 2e 18 19 26 37 4b 17
28 30 37 51 59 60 :2 13 :2 1c
28 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 5e 61 62
:2 5e :2 35 :3 19 :2 1f 24 30 6e 71
:2 30 7e 81 :2 30 85 88 :2 30 94
97 :2 30 9f a2 :2 30 ae b1 b8
c1 c4 :2 b1 :2 30 :2 19 65 :2 16 :2 13
:4 1f :2 13 10 :4 18 10 20 10 1a
1e 2e 18 19 26 37 4b 17
23 2b 32 :2 13 :2 1c 28 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5e 61 62 :2 5e :2 35 :3 19
:2 1f 24 30 6e 71 :2 30 7e 81
:2 30 85 88 :2 30 94 97 :2 30 9f
a2 :2 30 ae b1 b8 c1 c4 :2 b1
:2 30 :2 19 65 :2 16 :2 13 :4 1f :2 13 10
:7 d 10 19 27 :2 10 2c 2a 35
3f :2 2c :2 2a 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8c 8f 98 a0 :2 a9
:2 98 c1 :2 8f :2 2a c9 cc :2 2a d4
d7 :2 2a dc df :2 2a e8 eb :2 2a
:2 13 5f :2 10 13 :2 1d 2f :2 39 45
48 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a :2 13 5e :3 10
:2 1b 2f :2 38 4f 59 :2 10 42 :2 d
4c 26 :3 a 18 a 7 38 e
17 23 :2 e 26 28 :2 26 d 30
41 4a 52 :2 41 :2 30 2f 57 5a
:2 57 :3 d :2 17 29 :2 33 3f 43 52
55 56 :2 52 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 86 89 92 9a :2 a3 :2 92 bb
:2 89 :2 24 c3 c6 :2 24 ce d1 :2 24
d6 d9 :2 24 e2 e5 :2 24 :2 d 59
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
62 65 :2 24 :2 d 58 :3 a :2 15 29
:2 32 49 53 :2 a 5c 38 :2 7 a
11 1d 20 :2 a 23 25 :2 23 a
18 1f 2a 2d :2 1f 37 3a :2 18
a 14 1f 2a 35 42 4a 53
5e 69 7c 85 90 9b 12 1f
2d 37 4a 12 13 21 :2 d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 29 e :2 17 22 20
:2 2b :2 20 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 89 8c 95 9d :2 a6
:2 95 b9 :2 8c :2 27 c1 c4 :2 27 cc
cf :2 27 d4 d7 :2 27 e0 e3 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 47 51 :2 d 3b :2 a
e 15 1f 22 :2 e 25 27 :2 25
d 31 3a 4d :2 31 50 52 :2 50
30 5a 10 1e :2 5a 23 21 2c
3f :2 23 :2 21 59 :2 30 2f :2 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 89
8c 95 9d :2 a6 :2 95 bc :2 8c :2 27
c4 c7 :2 27 cf d2 :2 27 d7 da
:2 27 e3 e6 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 :2 10 5b :3 d :2 18 2c :2 35 4a
54 :2 d 44 :2 a 14 27 34 45
52 61 12 13 20 2e 46 54
:2 d :2 16 22 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :4 29 a 19
20 2c 2f :2 20 39 3c :2 19 a
14 26 37 46 53 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 7 e :2 17 22 20 :2 2b
:2 20 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 89 8c 95 9d :2 a6 :2 95
b9 :2 8c :2 27 c1 c4 :2 27 cc cf
:2 27 d4 d7 :2 27 e0 e3 :2 27 :2 10
5c :2 d 10 :2 1a 2c :2 36 42 45
54 57 58 :2 54 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 :2 10 5b :3 d :2 18
2c :2 35 47 51 :2 d 3b :2 a 14
2c 34 3b 59 61 68 82 8a
91 ac b8 12 1e 12 13 1b
2c 38 45 :2 d :2 16 22 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 7 e :2 17 22 20 :2 2b :2 20 d
40 49 52 :2 40 55 57 :2 55 3f
:2 d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 89 8c 95 9d :2 a6 :2 95 be
:2 8c :2 27 c6 c9 :2 27 d1 d4 :2 27
d9 dc :2 27 e5 e8 :2 27 :2 10 5c
:2 d 10 :2 1a 2c :2 36 42 45 54
57 58 :2 54 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 :2 10 5b :3 d :2 18 2c
:2 35 4c 56 :2 d 5a :2 a 14 27
34 45 52 61 12 13 20 2e
46 54 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :8 7
15 7 a 13 1f :2 a 22 24
:2 22 14 1f 2c 34 3b 50 5b
60 74 12 :2 d :2 16 22 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 26 1e 26 2d 45 4d 54 6d
:3 12 :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 26 a
15 :2 a 19 a d 16 23 :2 d
26 28 :2 26 d 19 d 2a :3 a
16 22 2f 3d 48 52 5e 1b
28 35 42 4f 1b 28 34 3e
46 4f 57 5e 1b 27 34 3f
4a 58 1b 26 32 3e 41 44
4a 50 :2 16 a d 16 18 :2 16
10 19 26 :2 10 29 2b :2 29 1a
2d 4a 51 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 5e 61 62
:2 5e :2 35 :3 19 :2 1f 24 30 6e 71
:2 30 7e 81 :2 30 85 88 :2 30 94
97 :2 30 9f a2 :2 30 ae b1 b8
c1 c4 :2 b1 :2 30 :2 19 65 :2 16 :2 13
:4 1f :2 13 10 :4 2d 1a 2d 4a 51
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5e 62 63 :2 5e :2 35 :3 19
:2 1f 24 30 6f 72 :2 30 7f 82
:2 30 86 89 :2 30 95 98 :2 30 a0
a3 :2 30 af b2 b9 c2 c5 :2 b2
:2 30 :2 19 66 :2 16 :2 13 :4 1f :2 13 10
:7 d 1a :2 a 26 a 18 :2 a 19
a d 14 20 23 :2 d 26 28
:2 26 d 18 :2 21 d 2c d 18
1f 28 34 :2 1f 38 :2 41 :2 18 d
:5 a 16 22 2f 3d 48 52 5e
1b 28 35 42 4f 1b 28 34
3e 46 4f 57 5e 1b 27 34
3f 4a 58 1b 26 32 3e 41
44 4a 50 :2 16 a d 16 18
:2 16 17 2a 47 4e 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5b
5f 60 :2 5b :2 32 :3 16 :2 1c 21 2d
6c 6f :2 2d 7c 7f :2 2d 83 86
:2 2d 92 95 :2 2d 9d a0 :2 2d ac
af b6 bf c2 :2 af :2 2d :2 16 63
:2 13 :2 10 :4 1c :2 10 d :4 1a :2 a :4 7
1f a 13 1a :2 13 28 :2 a 2b
2d :2 2b a 16 a 30 a 16
1d 26 2d :2 26 3b :2 1d 3e 40
:2 1d 1c 43 45 :2 1c :2 16 a :4 7
a 13 15 :2 13 a 15 :2 a 10
19 22 :2 10 27 25 30 :2 25 a
d 1b :2 d 19 :2 22 2b 2f 33
3c 45 :2 33 48 4a :2 33 4c 4d
:2 33 50 :2 19 :2 d 1b :2 24 2d 30
33 3c 45 :2 33 48 4a :2 33 4d
4f :2 33 51 52 :2 33 55 :2 1b :2 d
1d :2 d 1b :2 d 18 :2 d 1b d
17 21 25 3a 43 15 16 23
34 3e 14 22 2f 3f :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :3 30 11 1a 23 :2 11
26 28 :2 26 10 :4 31 30 2f :3 10
1e 10 13 :2 1e 25 33 :2 13 3f
41 :2 3f 13 23 13 43 :2 10 4a
:2 d 10 17 23 26 :2 10 29 2b
:2 29 10 1e :2 27 10 13 1c 23
:2 1c 31 :2 13 34 36 :2 34 13 22
13 38 13 22 29 35 38 :2 29
41 44 :2 22 :2 13 22 29 35 38
:2 29 42 45 :2 22 13 :4 10 2f 13
1c 23 :2 1c 30 :2 13 33 35 :2 33
13 21 13 37 13 21 28 33
36 :2 28 3f 42 :2 21 :2 13 21 28
33 36 :2 28 40 43 :2 21 13 :4 10
:5 d 1c :2 d 18 d 10 19 25
:2 10 28 2a :2 28 13 17 19 :2 17
16 1d 29 2c :2 16 2f 31 :2 2f
20 37 4e 56 5d 76 7e 85
19 21 28 40 48 4f 69 77
92 1e 2f 3b 44 1e 1f 27
38 44 51 67 :2 19 :2 22 2e 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 64 68 69 :2 64 :2 3b
:3 1f :2 25 2a 36 75 78 :2 36 85
88 :2 36 8c 8f :2 36 9b 9e :2 36
a6 a9 :2 36 b5 b8 bf c8 cb
:2 b8 :2 36 :2 1f 6c :2 1c :2 19 :4 25 :2 19
16 :3 35 1a :2 23 2e 2c :2 37 :2 2c
:2 19 27 19 1d 26 34 :2 1d 37
39 :2 37 1c 40 49 52 :2 40 55
57 :2 55 3f :2 1c 26 3d 56 5e
65 7e 86 8d 1f 27 2e 46
4e 55 71 81 24 35 41 24
25 2d 3e 4a 57 6d :2 1f :2 28
34 1f 1c 24 22 :2 2b 37 22
32 :2 1f :2 24 22 :2 2b 37 22 25
:2 2f 41 :2 4b 57 5b 6a 6e 6f
:2 6a :2 41 :3 25 :2 2b 30 3c 7b 7e
:2 3c 8b 8e :2 3c 92 95 :2 3c a1
a4 :2 3c ac af :2 3c bb be c5
ce d1 :2 be :2 3c :2 25 72 :2 22 :2 1f
:4 2b :2 1f 1c :4 5a 1c 2b 1c :4 19
16 47 1d :2 26 31 2f :2 3a :2 2f
1c 4e 57 60 :2 4e 63 65 :2 63
4d :2 1c 23 3a 53 5b 62 7b
83 8a 1c 24 2b 43 4b 52
6e 7e 21 32 3e 21 22 2a
3b 47 54 6a :2 1c :2 25 31 1c
19 21 1f :2 28 34 1f 2f :2 1c
:2 21 1f :2 28 34 1f 22 :2 2c 3e
:2 48 54 58 67 6b 6c :2 67 :2 3e
:3 22 :2 28 2d 39 78 7b :2 39 88
8b :2 39 8f 92 :2 39 9e a1 :2 39
a9 ac :2 39 b8 bb c2 cb ce
:2 bb :2 39 :2 22 6f :2 1f :2 1c :4 28 :2 1c
19 :4 68 47 :2 16 35 20 37 50
58 5f 78 80 87 19 21 28
40 48 4f 6b 7b 1e 2f 3b
48 1f 2c 3d 45 1d 29 36
4c :2 19 :2 22 2e 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
64 68 69 :2 64 :2 3b :3 1f :2 25 2a
36 75 78 :2 36 85 88 :2 36 8c
8f :2 36 9b 9e :2 36 a6 a9 :2 36
b5 b8 bf c8 cb :2 b8 :2 36 :2 1f
6c :2 1c :2 19 :4 25 :2 19 16 :7 13 1b
16 1d 29 2c :2 16 2f 31 :2 2f
20 37 4d 55 5c 7a 82 89
a2 aa b1 cb d7 f5 1e 2f
3a 43 55 1f 2c 3d 45 1d
29 36 4c :2 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 64 68 69 :2 64 :2 3b :3 1f
:2 25 2a 36 75 78 :2 36 85 88
:2 36 8c 8f :2 36 9b 9e :2 36 a6
a9 :2 36 b5 b8 bf c8 cb :2 b8
:2 36 :2 1f 6c :2 1c :2 19 :4 25 :2 19 16
:3 35 1a :2 23 2e 2c :2 37 :2 2c 19
1d 26 34 :2 1d 37 39 :2 37 1c
40 49 52 :2 40 55 57 :2 55 3f
:2 1c 26 3d 56 5e 65 7e 86
8d a9 b5 24 35 40 4d 25
32 43 4b 23 2f 3c 52 :2 1f
:2 28 34 1f 1c 24 22 :2 2b 37
22 32 :2 1f :2 24 22 :2 2b 37 22
25 :2 2f 41 :2 4b 57 5b 6a 6e
6f :2 6a :2 41 :3 25 :2 2b 30 3c 7b
7e :2 3c 8b 8e :2 3c 92 95 :2 3c
a1 a4 :2 3c ac af :2 3c bb be
c5 ce d1 :2 be :2 3c :2 25 72 :2 22
:2 1f :4 2b :2 1f 1c :4 5a 1c 2b :2 1c
:4 19 16 47 1d :2 26 31 2f :2 3a
:2 2f 1c 23 3a 53 5b 62 80
88 8f aa b2 b9 d5 e1 21
32 3d 4a 22 2f 40 48 20
2c 39 4f :2 1c :2 25 31 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 67 6b 6c :2 67 :2 3e :3 22
:2 28 2d 39 78 7b :2 39 88 8b
:2 39 8f 92 :2 39 9e a1 :2 39 a9
ac :2 39 b8 bb c2 cb ce :2 bb
:2 39 :2 22 6f :2 1f :2 1c :4 28 :2 1c 19
:4 4a 47 :2 16 35 20 37 4f 57
5e 7c 84 8b a6 ae b5 d1
dd 1e 2f 3a 47 1f 2c 3d
45 1d 29 36 4c :2 19 :2 22 2e
19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 64 68 69 :2 64
:2 3b :3 1f :2 25 2a 36 75 78 :2 36
85 88 :2 36 8c 8f :2 36 9b 9e
:2 36 a6 a9 :2 36 b5 b8 bf c8
cb :2 b8 :2 36 :2 1f 6c :2 1c :2 19 :4 25
:2 19 16 :7 13 :4 10 14 :2 1d 28 26
:2 31 :2 26 13 16 1f 28 :2 16 2b
2d :2 2b 16 24 16 2f :4 1a 19
1c 20 22 :2 20 1c 2c 1c 26
2a 3a 24 25 32 43 57 23
34 3c 43 5d 65 6c :2 1f :2 28
34 1f 1c 24 22 :2 2b 37 22
32 :2 1f :2 24 22 :2 2b 37 22 25
:2 2f 41 :2 4b 57 5b 6a 6e 6f
:2 6a :2 41 :3 25 :2 2b 30 3c 7b 7e
:2 3c 8b 8e :2 3c 92 95 :2 3c a1
a4 :2 3c ac af :2 3c bb be c5
ce d1 :2 be :2 3c :2 25 72 :2 22 :2 1f
:4 2b :2 1f 1c :4 24 1c 2c 1c 26
2a 3a 24 25 32 43 57 23
2f 37 3e :2 1f :2 28 34 1f 1c
24 22 :2 2b 37 22 32 :2 1f :2 24
22 :2 2b 37 22 25 :2 2f 41 :2 4b
57 5b 6a 6e 6f :2 6a :2 41 :3 25
:2 2b 30 3c 7b 7e :2 3c 8b 8e
:2 3c 92 95 :2 3c a1 a4 :2 3c ac
af :2 3c bb be c5 ce d1 :2 be
:2 3c :2 25 72 :2 22 :2 1f :4 2b :2 1f 1c
:7 19 1c 25 33 :2 1c 38 36 41
4b :2 38 :2 36 1c 27 30 39 :2 27
3c 3e :2 27 1c 21 1c 4e :2 19
37 :3 16 24 16 :4 13 41 13 1e
27 30 :2 1e 33 35 :2 1e 13 18
13 :5 10 1e :2 10 1c 10 1a 25
32 3a 41 56 61 66 :2 18 :2 13
:2 1c 28 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5e 62
63 :2 5e :2 35 :3 19 :2 1f 24 30 6f
72 :2 30 7f 82 :2 30 86 89 :2 30
95 98 :2 30 a0 a3 :2 30 af b2
b9 c2 c5 :2 b2 :2 30 :2 19 66 :2 16
:2 13 :4 1f :2 13 10 :3 2c 24 2c 33
4b 53 5a 73 85 :2 18 :2 13 :2 1c
28 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 5e 62 63
:2 5e :2 35 :3 19 :2 1f 24 30 6f 72
:2 30 7f 82 :2 30 86 89 :2 30 95
98 :2 30 a0 a3 :2 30 af b2 b9
c2 c5 :2 b2 :2 30 :2 19 66 :2 16 :2 13
:4 1f :2 13 10 :3 2c 10 1b :2 10 1f
10 13 1c 29 :2 13 2c 2e :2 2c
13 1f 13 30 :3 10 1c 28 39
47 52 5c 68 1b 28 35 42
4f 1b 28 34 3e 46 4f 57
5e 1b 27 34 3f 4a 58 1b
26 32 3e 41 44 4a 50 :2 1c
10 13 1c 1e :2 1c 16 1f 2c
:2 16 2f 31 :2 2f 20 33 50 57
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 64 68 69 :2 64 :2 3b :3 1f
:2 25 2a 36 75 78 :2 36 85 88
:2 36 8c 8f :2 36 9b 9e :2 36 a6
a9 :2 36 b5 b8 bf c8 cb :2 b8
:2 36 :2 1f 6c :2 1c :2 19 :4 25 :2 19 16
:4 33 20 33 50 57 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 64
68 69 :2 64 :2 3b :3 1f :2 25 2a 36
75 78 :2 36 85 88 :2 36 8c 8f
:2 36 9b 9e :2 36 a6 a9 :2 36 b5
b8 bf c8 cb :2 b8 :2 36 :2 1f 6c
:2 1c :2 19 :4 25 :2 19 16 :7 13 20 :2 10
d 2c 13 1c 28 :2 13 2b 2d
:2 2b 10 1e :2 10 1f 10 13 1a
26 29 :2 13 2c 2e :2 2c 13 1e
:2 27 13 32 13 1e 27 33 :2 1e
13 :5 10 1c 28 35 43 4e 58
64 1b 28 35 42 4f 1b 28
34 3e 46 4f 57 5e 1b 27
34 3f 4a 58 1b 26 32 3e
41 44 4a 50 :2 1c 10 13 1c
1e :2 1c 1d 30 4d 54 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
61 65 66 :2 61 :2 38 :3 1c :2 22 27
33 72 75 :2 33 82 85 :2 33 89
8c :2 33 98 9b :2 33 a3 a6 :2 33
b2 b5 bc c5 c8 :2 b5 :2 33 :2 1c
69 :2 19 :2 16 :4 22 :2 16 13 :4 20 :2 10
2f 2c :3 d 18 21 2a :2 18 2d
2f :2 18 d f d :3 30 e a
17 :2 7 :4 4 8 11 14 :2 11 7
1c 25 2d :2 1c 30 32 :2 30 1b
:2 7 a 13 22 :2 a 25 27 :2 25
19 34 48 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5c 5d
:2 58 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a 79 7c :2 2a 80 83 :2 2a 8f
92 :2 2a 9a 9d :2 2a a9 ac b3
bc bf :2 ac :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :4 29 14 2d 3b 4a
58 13 27 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5c 5d
:2 58 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a 79 7c :2 2a 80 83 :2 2a 8f
92 :2 2a 9a 9d :2 2a a9 ac b3
bc bf :2 ac :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :7 7 a 13 15 :2 13
d :2 17 29 :2 33 3f 43 52 56
57 :2 52 :2 29 :3 d :2 13 18 24 63
66 :2 24 73 76 :2 24 7a 7d :2 24
87 8a 93 9b :2 a4 :2 93 ba :2 8a
:2 24 c2 c5 :2 24 cd d0 :2 24 d5
d8 :2 24 e1 e4 :2 24 :2 d 5a :2 a
d :2 17 29 :2 33 3f 42 51 55
56 :2 51 :2 29 :3 d :2 13 18 24 63
66 :2 24 :2 d 59 :3 a :2 15 29 :2 32
47 51 :2 a 7 19 d 18 16
:2 21 :2 16 d :2 17 29 :2 33 3f 43
52 56 57 :2 52 :2 29 :3 d :2 13 18
24 63 66 :2 24 73 76 :2 24 7a
7d :2 24 87 8a 93 9b :2 a4 :2 93
c3 :2 8a :2 24 cb ce :2 24 d6 d9
:2 24 de e1 :2 24 ea ed :2 24 :2 d
5a :2 a d :2 17 29 :2 33 3f 42
51 55 56 :2 51 :2 29 :3 d :2 13 18
24 63 66 :2 24 :2 d 59 :3 a :2 15
29 :2 32 50 12 :2 a 7 3e 19
d 18 16 :2 21 :2 16 d :2 17 29
:2 33 3f 43 52 56 57 :2 52 :2 29
:3 d :2 13 18 24 63 66 :2 24 73
76 :2 24 7a 7d :2 24 87 8a 93
9b :2 a4 :2 93 c0 :2 8a :2 24 c8 cb
:2 24 d3 d6 :2 24 db de :2 24 e7
ea :2 24 :2 d 5a :2 a d :2 17 29
:2 33 3f 42 51 55 56 :2 51 :2 29
:3 d :2 13 18 24 63 66 :2 24 :2 d
59 :3 a :2 15 29 :2 32 4d 12 :2 a
3b 19 d :2 17 29 :2 33 3f 43
52 56 57 :2 52 :2 29 :3 d :2 13 18
24 63 66 :2 24 73 76 :2 24 7a
7d :2 24 87 8a 93 9b :2 a4 :2 93
bc :2 8a :2 24 c4 c7 :2 24 cf d2
:2 24 d7 da :2 24 e6 e9 :2 24 :2 d
5a :2 a d :2 17 29 :2 33 3f 42
51 55 56 :2 51 :2 29 :3 d :2 13 18
24 63 66 :2 24 :2 d 59 :3 a :2 15
29 :2 32 49 56 :2 a :4 7 35 :2 4
8 11 18 :2 11 25 :2 8 28 2a
:2 28 7 32 3b 42 :2 3b 50 :2 32
53 55 :2 53 31 :3 7 f 19 :3 7
:2 10 1c :2 7 f e 11 :2 f e
11 :2 f e 11 :2 f e 11 :2 f
e 11 :2 f 3e 41 :2 f 4e 51
:2 f e 11 :2 f 2d 30 :2 f 3b
3e :2 f 5a 5d :2 f 13 16 :2 f
7 a 12 1c :2 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 59
5a :2 55 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :3 10 :2 16 1b
3f 48 4b :2 3f :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 58 7 f 19 :3 7
:2 10 1c :2 7 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d 25 28 :2 d 35 38
:2 d e 11 :2 d 28 2b :2 d 36
39 :2 d 55 58 :2 d 13 16 :2 d
7 a 12 1c :2 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 59
5a :2 55 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :3 10 :2 16 1b
3f 48 4b :2 3f :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 58 7 :2 10 :3 1c :2 7
d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d 4e 51 :2 d
13 16 :2 d e 11 :2 d 4b 4e
:2 d 13 16 :2 d e 11 :2 d e
11 :2 d 13 16 :2 d 21 24 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
4f 52 :2 d 13 16 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d 2d 30 :2 d 3c 3f :2 d
e 11 :2 d 7 a 12 1c :2 a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 59 5a :2 55 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8c 8f :2 27 97 9a
:2 27 a6 a9 b0 b9 bc :2 a9 :2 27
:3 10 :2 16 1b 3f 48 4b :2 3f :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 58 7
d e 11 :2 d e 11 :2 d e
11 :2 d 3b 3e 46 4f 58 :2 46
:2 3e :2 d 13 16 :2 d e 11 :2 d
15 18 20 29 34 :2 20 :2 18 :2 d
13 16 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d 55 58 60 13 1c
:2 60 :2 58 :2 d 20 23 :2 d e 11
:2 d 2c 2f 37 40 4b :2 37 :2 2f
:2 d 13 16 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
7 4 58 a 13 1a :2 13 28
:2 a 2b 2d :2 2b 7 f 19 :3 7
:2 10 1c :2 7 f e 11 :2 f e
11 :2 f e 11 :2 f e 11 :2 f
e 11 :2 f 3e 41 :2 f 4e 51
:2 f e 11 :2 f 27 2a :2 f 35
38 :2 f 7 a 12 1c :2 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 59 5a :2 55 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :3 10
:2 16 1b 3f 48 4b :2 3f :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 2f 7 f
19 :3 7 :2 10 1c :2 7 f e 11
:2 f e 11 :2 f e 11 :2 f e
11 :2 f e 11 :2 f 3b 3e :2 f
4b 4e :2 f 13 16 :2 f 21 24
:2 f 7 a 12 1c :2 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
59 5a :2 55 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 76 79 :2 27 7d 80
:2 27 8c 8f :2 27 97 9a :2 27 a6
a9 b0 b9 bc :2 a9 :2 27 :3 10 :2 16
1b 3f 48 4b :2 3f :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 2f 7 :2 10 :3 1c
:2 7 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d 4e 51 :2 d
13 16 :2 d e 11 :2 d 4b 4e
:2 d 13 16 :2 d e 11 :2 d e
11 :2 d 2e 31 :2 d 3c 3f :2 d
7 a 12 1c :2 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 59
5a :2 55 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :3 10 :2 16 1b
3f 48 4b :2 3f :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 2f 7 d e 11
:2 d e 11 :2 d e 11 :2 d 48
4b 53 5c 65 :2 53 :2 4b :2 d 13
16 :2 d e 11 19 22 2d :2 19
:2 11 :2 d 13 16 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d 7 2f 58 7 f 19 :3 7
:2 10 1c :2 7 f e 11 :2 f e
11 :2 f e 11 :2 f e 11 :2 f
e 11 :2 f e 11 :2 f 28 2b
:2 f 38 3b :2 f e 11 :2 f 2d
30 :2 f 3c 3f :2 f e 11 :2 f
7 a 12 1c :2 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 59
5a :2 55 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :3 10 :2 16 1b
3f 48 4b :2 3f :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 4 7 f 19 :3 7
:2 10 1c :2 7 f e 11 :2 f e
11 :2 f e 11 :2 f e 11 :2 f
e 11 :2 f 3b 3e :2 f 4b 4e
:2 f 13 16 :2 f 22 25 :2 f 7
a 12 1c :2 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 59 5a
:2 55 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :3 10 :2 16 1b 3f
48 4b :2 3f :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 4 7 :2 10 :3 1c :2 7 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d 4e 51 :2 d 13 16
:2 d e 11 :2 d e 11 :2 d e
11 :2 d 2d 30 :2 d 3c 3f :2 d
7 a 12 1c :2 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 59
5a :2 55 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :3 10 :2 16 1b
3f 48 4b :2 3f :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 4 7 f e 11
:2 f e 11 :2 f e 11 :2 f 13
16 1e 27 30 :2 1e :2 16 :2 f 34
37 :2 f e 11 :2 f 54 57 5f
13 1e :2 5f :2 57 :2 f 13 16 :2 f
e 11 :2 f e 11 :2 f e 11
:2 f e 11 :2 f 7 :4 4 7 :2 11
23 :2 2d 39 3c 4b 4f 50 :2 4b
:2 23 :3 7 :2 d 12 1e 5d 60 :2 1e
:2 7 53 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4f 50 :2 4b :2 23 :3 7 :2 d
12 1e 5d 60 :2 1e :2 7 53 :3 4
b :2 16 26 :2 b 4 1 9 12
9 a :2 14 26 :2 30 3c 40 4f
53 54 :2 4f :2 26 :3 a :2 10 15 21
60 63 :2 21 :3 a :2 10 15 39 5c
5f :2 68 :2 39 76 79 :2 39 81 84
:2 8d :2 39 :2 a 57 :3 7 c 15 1e
2c a 13 1e f e 7 e
7 e 7 29 :2 4 :2 9 7 :2 10
1c :2 7 :2 11 23 :2 2d 39 3d 4c
50 51 :2 4c :2 23 :3 7 :2 d 12 1e
5d 60 :2 1e :3 7 :2 d 12 36 42
45 :2 36 4d 50 :2 36 5c 5f 66
6f 72 :2 5f :2 36 :2 7 54 :2 4 7
c 1b a 13 1e f e 7
e 7 e 7 :2 4 :4 10 :2 4 :8 1

32fc
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :7 1b
:7 1c :7 1d :5 1e :5 1f
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :7 42 :7 43
:6 44 :7 45 :6 46 :7 47
:7 48 :7 49 :6 4a :6 4b
:6 4c :7 4d :7 4e :6 4f
:6 50 :7 51 :6 52 :6 53
:6 54 :6 55 :5 56 :7 58
:b 5a :11 5b 5c :2 5b
:2 5c :2 5b :2 5c :2 5b
:2 5d :2 5b :2 5d :2 5b
:2 5d :2 5b :2 5d :2 5b
:2 5e :2 5b :2 5e :2 5b
:2 5e :2 5b :2 5e :2 5b
:2 5f :2 5b :9 5f :2 5b
:2 60 :2 5b :9 60 :2 5b
:2 61 :2 5b :9 61 :2 5b
:2 62 :2 5b :9 62 :2 5b
:2 63 :2 5b :9 63 :2 5b
:2 64 :2 5b :9 64 :2 5b
:2 65 :2 5b :9 65 :2 5b
:2 66 :2 5b :9 66 :2 5b
:2 67 :2 5b :9 67 :2 5b
:2 68 :2 5b :9 68 :2 5b
:2 69 :2 5b :2 69 :2 5b
:2 69 :2 5b :2 69 :2 5b
:2 6a :2 5b :2 6a :2 5b
:2 6a :2 5b :2 6a :2 5b
:2 6a :4 5b :3 5a :11 6d
:b 6e :3 6d :3 76 :3 77
:3 78 :3 79 :3 7b :3 7d
:3 7f :3 81 :3 82 :3 83
:3 84 :3 85 :3 86 :3 87
:3 89 :3 8a :3 8b :a 8c
:3 8d :3 92 :3 93 :5 95
:11 96 :20 97 :3 96 :11 99
:b 9a :3 99 :9 9c :3 95
:5 9f :11 a0 :20 a1 :3 a0
:11 a3 :b a4 :3 a3 :9 a6
:3 9f :1f a9 :11 aa :20 ab
:3 aa :11 ad :b ae :3 ad
:9 b0 :3 a9 :e b3 :6 b5
b6 b7 b5 :5 b8
b4 ba :5 bb :3 ba
:2 bc :5 be :11 bf :24 c0
:3 bf :2 bd :6 bc b9
:3 b3 :16 c5 :11 c6 :20 c7
:3 c6 :11 c9 :b ca :3 c9
:9 cc :3 c5 :3 cf d0
b3 :e d0 :2 d2 d3
d2 :5 d4 d1 d6
:5 d7 :3 d6 :2 d8 :5 da
:11 db :24 dc :3 db :2 d9
:6 d8 d5 :4 d0 :3 b3
:3 e2 :5 e3 :3 e4 :3 e3
:8 e7 :8 e8 :3 e9 :9 eb
:d ed :b ee :c f0 :6 f2
:4 f3 :3 f4 f2 :5 f5
f1 f7 :5 f8 :3 f7
:2 f9 :5 fb :11 fc :24 fd
:3 fc :2 fa :6 f9 f6
:4 f0 :a 103 :8 104 :5 105
:7 106 :27 107 103 :5 108
102 10a :5 10b :3 10a
:2 10c :5 10e :11 10f :24 110
:3 10f :2 10d :6 10c 109
:4 101 :3 f0 :a 116 :4 118
:3 119 118 :5 11a 117
11c :5 11d :3 11c :2 11e
:5 120 :11 121 :24 122 :3 121
:2 11f :6 11e 11b :3 116
:a 127 :5 128 :3 129 :3 128
:5 12c :3 12d :3 12e 12c
:5 12f 12b 131 :5 132
:3 131 :2 133 :5 135 :11 136
:24 137 :3 136 :2 134 :6 133
130 :4 127 :11 13c :30 13d
:3 13c :11 13f :b 140 :3 13f
:a 142 13b :3 127 116
:3 145 144 :3 116 :3 148
:2 14a 14b :2 14c 14a
:5 14d 149 14f :5 150
:3 14f :2 151 :5 153 :11 154
:24 155 :3 154 :2 152 :6 151
14e :3 eb :9 15a :2 15c
15d :2 15e 15c :5 15f
15b 161 :5 162 :3 161
:2 163 :5 165 :11 166 :24 167
:3 166 :2 164 :6 163 160
:3 15a :b 16c :11 16d :30 16e
:3 16d :11 170 :b 171 :3 170
:a 173 :3 16c :3 15a eb
:5 178 :3 179 :3 17a 178
:5 17b 177 17d :5 17e
:3 17d :2 17f :5 181 :11 182
:24 183 :3 182 :2 180 :6 17f
17c :3 176 :a 187 :6 189
:5 18a 188 18c :5 18d
:3 18c :2 18e :5 190 :11 191
:24 192 :3 191 :2 18f :6 18e
18b :3 187 :a 196 :11 197
:30 198 :3 197 :11 19a :b 19b
:3 19a :a 19d :3 196 :3 187
176 :3 eb :c 1a2 :2 1a3
:2 1a2 :6 1a3 :3 1a2 :a 1a3
:2 1a2 :c 1a4 :2 1a5 :2 1a4
:6 1a5 :2 1a4 :3 1a6 1a5
:2 1a4 :3 1a9 :3 1aa 1a3
:5 1ac :3 1ad :3 1ae :e 1af
:b 1b0 :2 1b1 :2 1b0 :a 1b1
:8 1b2 :3 1af :b 1b4 :11 1b5
:20 1b6 :3 1b5 :11 1b8 :b 1b9
:3 1b8 :9 1bb 1bc 1b4
:9 1bc :11 1bd :2e 1be :3 1bd
:11 1c0 :b 1c1 :3 1c0 :c 1c3
1bc :3 1b4 :3 1c6 :5 1c7
:3 1c8 :3 1c7 1ca 1ac
:16 1ca :16 1cb :3 1cc 1cd
1cb :9 1cd :3 1ce 1cf
1cd 1cb :16 1cf :3 1d0
1d1 1cf 1cb :9 1d1
:f 1d2 :3 1d3 1d1 :3 1cb
1ca :3 1ac 1ab :3 1a2
:5 1d8 :3 1da :3 1db :14 1dd
:d 1df :9 1e1 :7 1e2 1e3
:3 1e2 :b 1e5 :9 1e6 :5 1e7
:3 1e6 :11 1ea :2e 1eb :3 1ea
:11 1ed :b 1ee :3 1ed :c 1f0
:3 1e5 :14 1f3 :11 1f4 :2e 1f5
:3 1f4 :11 1f7 :b 1f8 :3 1f7
:c 1fa :3 1f3 :3 1fd :9 200
:2 201 202 :2 203 :2 204
:2 205 :2 206 200 :5 207
1ff 209 :5 20a :3 209
:2 20b :5 20d :11 20e :24 20f
:3 20e :2 20c :6 20b 208
:3 1e1 :12 214 :3 215 :9 216
:3 217 :3 216 :3 214 :3 21b
:3 21c :5 21d :a 21e :2 220
:9 221 :9 222 :3 223 :4 224
225 :6 226 220 :5 227
21f 229 :5 22a :3 229
:2 22b :5 22d :11 22e :24 22f
:3 22e :2 22c :6 22b 228
:3 21e :a 234 :3 235 :16 236
:2 238 :9 239 :9 23a :2 23b
:3 23c 23d :6 23e 238
:5 23f 237 241 :5 242
:3 241 :2 243 :5 245 :11 246
:24 247 :3 246 :2 244 :6 243
240 :4 236 :3 24c 24b
:3 236 24e 234 :16 24e
:2 250 :9 251 :9 252 :2 253
:3 254 255 :6 256 250
:5 257 24f 259 :5 25a
:3 259 :2 25b :5 25d :11 25e
:24 25f :3 25e :2 25c :6 25b
258 :4 24e :3 234 21e
:2 266 :9 267 :9 268 :2 269
:3 26a 26b :6 26c 266
:5 26d 265 26f :5 270
:3 26f :2 271 :5 273 :11 274
:24 275 :3 274 :2 272 :6 271
26e :4 264 :3 21e 21d
:a 27b :e 27d :4 27e 27f
:6 280 27d :5 281 27c
283 :5 284 :3 283 :2 285
:5 287 :11 288 :24 289 :3 288
:2 286 :6 285 282 :3 27b
:a 28e :3 28f :16 290 :a 292
:3 293 294 :6 295 292
:5 296 291 298 :5 299
:3 298 :2 29a :5 29c :11 29d
:24 29e :3 29d :2 29b :6 29a
297 :4 290 :3 2a3 2a4
2a2 :3 290 2a6 28e
:a 2a6 :d 2a8 :3 2a9 2aa
:6 2ab 2a8 :5 2ac 2a7
2ae :5 2af :3 2ae :2 2b0
:5 2b2 :11 2b3 :24 2b4 :3 2b3
:2 2b1 :6 2b0 2ad :4 2a6
:3 28e 27b :d 2bb :3 2bc
2bd :6 2be 2bb :5 2bf
2ba 2c1 :5 2c2 :3 2c1
:2 2c3 :5 2c5 :11 2c6 :24 2c7
:3 2c6 :2 2c4 :6 2c3 2c0
:4 2b9 :3 27b 27a :3 21d
:a 2ce :9 2cf :11 2d0 :30 2d1
:3 2d0 :11 2d3 :b 2d4 :3 2d3
:a 2d6 2d7 2cf :10 2d7
:5 2d8 :3 2d9 :3 2db 2dc
:4 2dd :7 2de 2db :5 2df
2da 2e1 :5 2e2 :3 2e1
:2 2e3 :5 2e5 :11 2e6 :24 2e7
:3 2e6 :2 2e4 :6 2e3 2e0
:4 2d8 :3 2ec :3 2ee 2ef
:4 2f0 :4 2f1 2ee :5 2f2
2ed 2f4 :5 2f5 :3 2f4
:2 2f6 :5 2f8 :11 2f9 :24 2fa
:3 2f9 :2 2f7 :6 2f6 2f3
:4 2eb :3 2d8 :d 300 :11 301
:30 302 :3 301 :11 304 :b 305
:3 304 :a 307 :3 300 2d7
:3 2cf :3 30a 30b 2ce
:19 30b :11 30c :30 30d :3 30c
:11 30f :b 310 :3 30f :a 312
30b :3 2ce :a 315 :c 316
:d 319 :5 31a 31b :2 31c
319 :5 31d 318 31f
:5 320 :3 31f :2 321 :5 323
:11 324 :24 325 :3 324 :2 322
:6 321 31e :3 315 :a 32a
:11 32b :30 32c :3 32b :11 32e
:b 32f :3 32e :a 331 :3 32a
:16 334 :2 335 :2 334 :8 335
:6 334 :11 336 :30 337 :3 336
:11 339 :b 33a :3 339 :a 33c
335 :2 334 :6 340 341
:5 342 340 :5 343 33f
345 :5 346 :3 345 :2 347
:5 349 :11 34a :24 34b :3 34a
:2 348 :6 347 344 :4 315
:c 350 :6 353 :5 354 352
356 :5 357 :3 356 :2 358
:5 35a :11 35b :24 35c :3 35b
:2 359 :6 358 355 :3 34f
:a 361 :11 362 :30 363 :3 362
:11 365 :b 366 :3 365 :a 368
:3 361 :c 36c :2 36d 36e
:5 36f 36c :5 370 36b
372 :5 373 :3 372 :2 374
:5 376 :11 377 :24 378 :3 377
:2 375 :6 374 371 :3 34f
:16 37d :11 37e :30 37f :3 37e
:11 381 :b 382 :3 381 :a 384
:3 37d :6 388 389 :5 38a
388 :5 38b 387 38d
:5 38e :3 38d :2 38f :5 391
:11 392 :24 393 :3 392 :2 390
:6 38f 38c :4 34f :3 315
:3 399 :9 39b :9 39d 39e
39d :5 39f 39c 3a1
:5 3a2 :3 3a1 :2 3a3 :5 3a5
:11 3a6 :24 3a7 :3 3a6 :2 3a4
:6 3a3 3a0 :3 39b :7 3ad
3ae 3af 3b0 3ad
:5 3b1 3ac 3b3 :5 3b4
:3 3b3 :2 3b5 :5 3b7 :11 3b8
:24 3b9 :3 3b8 :2 3b6 :6 3b5
3b2 :3 39b :3 3be :3 3bf
:9 3c0 :3 3c1 :3 3c0 :8 3c4
:5 3c5 :8 3c6 :6 3c7 :8 3c8
:3 3c4 :5 3ca :9 3cb :5 3cd
:6 3ce :5 3cf 3ce :5 3d1
3d0 :3 3ce 3cc 3d4
:5 3d5 :3 3d4 :2 3d6 :5 3d8
:11 3d9 :24 3da :3 3d9 :2 3d7
:6 3d6 3d3 :4 3cb :5 3e0
:6 3e1 :5 3e2 3e1 :5 3e4
3e3 :3 3e1 3df 3e7
:5 3e8 :3 3e7 :2 3e9 :5 3eb
:11 3ec :24 3ed :3 3ec :2 3ea
:6 3e9 3e6 :4 3de :3 3cb
:3 3ca 39b :3 3f5 :3 3f6
:a 3f8 :5 3f9 3f8 :d 3fb
3fa :3 3f8 :8 3fe :5 3ff
:8 400 :6 401 :8 402 :3 3fe
:5 404 :5 406 :6 407 :5 408
407 :5 40a 409 :3 407
405 40d :5 40e :3 40d
:2 40f :5 411 :11 412 :24 413
:3 412 :2 410 :6 40f 40c
:6 404 3f3 :3 39b 1e1
:c 41c :3 41d 41c :16 41f
41e :3 41c :5 421 :3 422
:c 423 :3 424 :17 427 :1b 429
:3 42b :3 42c :3 42d :3 42e
:5 431 432 :4 433 :4 434
431 :5 435 430 437
:5 438 :3 437 :2 439 :5 43b
:11 43c :24 43d :3 43c :2 43a
:6 439 436 :3 423 :12 442
:3 443 :b 444 :3 445 :3 444
:3 442 :a 449 :5 44a :c 44b
:3 44c 44b :c 44e :c 44f
44d :3 44b 449 :c 452
:3 453 452 :c 455 :c 456
454 :3 452 451 :3 449
:3 45a :3 45b :9 45d :5 45e
:a 45f :8 461 :9 462 :4 463
464 :6 465 461 :5 466
460 468 :5 469 :3 468
:2 46a :5 46c :11 46d :24 46e
:3 46d :2 46b :6 46a 467
:3 45f :a 473 :3 474 :16 475
:8 477 :8 478 :3 479 47a
:6 47b 477 :5 47c 476
47e :5 47f :3 47e :2 480
:5 482 :11 483 :24 484 :3 483
:2 481 :6 480 47d :4 475
:3 489 488 :3 475 48b
473 :16 48b :8 48d :8 48e
:3 48f 490 :6 491 48d
:5 492 48c 494 :5 495
:3 494 :2 496 :5 498 :11 499
:24 49a :3 499 :2 497 :6 496
493 :4 48b :3 473 45f
:8 4a1 :8 4a2 :4 4a3 :4 4a4
:4 4a5 4a1 :5 4a6 4a0
4a8 :5 4a9 :3 4a8 :2 4aa
:5 4ac :11 4ad :24 4ae :3 4ad
:2 4ab :6 4aa 4a7 :4 49f
:3 45f 45e :a 4b4 :e 4b6
:5 4b7 :4 4b8 :4 4b9 4b6
:5 4ba 4b5 4bc :5 4bd
:3 4bc :2 4be :5 4c0 :11 4c1
:24 4c2 :3 4c1 :2 4bf :6 4be
4bb :3 4b4 :a 4c7 :16 4c8
:a 4ca :4 4cb :4 4cc :4 4cd
4ca :5 4ce 4c9 4d0
:5 4d1 :3 4d0 :2 4d2 :5 4d4
:11 4d5 :24 4d6 :3 4d5 :2 4d3
:6 4d2 4cf :4 4c8 :3 4db
4dc 4da :3 4c8 4de
4c7 :a 4de :d 4e0 :4 4e1
:4 4e2 :4 4e3 4e0 :5 4e4
4df 4e6 :5 4e7 :3 4e6
:2 4e8 :5 4ea :11 4eb :24 4ec
:3 4eb :2 4e9 :6 4e8 4e5
:4 4de :3 4c7 4b4 :d 4f3
:4 4f4 :4 4f5 :4 4f6 4f3
:5 4f7 4f2 4f9 :5 4fa
:3 4f9 :2 4fb :5 4fd :11 4fe
:24 4ff :3 4fe :2 4fc :6 4fb
4f8 :4 4f1 :3 4b4 4b3
:3 45e :a 506 :9 507 :3 508
507 :5 50a :5 50b :3 50c
:3 50e 50f :4 510 :7 511
50e :5 512 50d 514
:5 515 :3 514 :2 516 :5 518
:11 519 :24 51a :3 519 :2 517
:6 516 513 :4 50b :3 51f
:3 521 522 :4 523 :4 524
521 :5 525 520 527
:5 528 :3 527 :2 529 :5 52b
:11 52c :24 52d :3 52c :2 52a
:6 529 526 :4 51e :3 50b
:d 532 :b 533 :2 534 :3 532
:3 50a :3 537 509 :3 507
506 :b 53a :2 53b 539
:3 506 :3 53e :3 53f :8 542
543 544 542 :5 545
541 547 :5 548 :3 547
:2 549 :5 54b :11 54c :24 54d
:3 54c :2 54a :6 549 546
:3 45d :8 553 554 555
553 :5 556 552 558
:5 559 :3 558 :2 55a :5 55c
:11 55d :24 55e :3 55d :2 55b
:6 55a 557 :3 45d :3 563
:3 564 :9 565 :3 566 :3 565
:8 569 :5 56a :8 56b :6 56c
:8 56d :3 569 :5 56f :9 570
:5 572 :6 573 :5 574 573
:5 576 575 :3 573 571
579 :5 57a :3 579 :2 57b
:5 57d :11 57e :24 57f :3 57e
:2 57c :6 57b 578 :4 570
:5 585 :6 586 :5 587 586
:5 589 588 :3 586 584
58c :5 58d :3 58c :2 58e
:5 590 :11 591 :24 592 :3 591
:2 58f :6 58e 58b :4 583
:3 570 :3 56f 598 45d
:9 598 :3 599 :3 59a :a 59c
:5 59d 59c :7 59f 59e
:3 59c :8 5a2 :5 5a3 :8 5a4
:6 5a5 :8 5a6 :3 5a2 :5 5a7
:5 5a9 :6 5aa :5 5ab 5aa
:5 5ad 5ac :3 5aa 5a8
5b0 :5 5b1 :3 5b0 :2 5b2
:5 5b4 :11 5b5 :24 5b6 :3 5b5
:2 5b3 :6 5b2 5af :6 5a7
598 :3 45d :b 5bc 5bd
5be :3 423 5bf 423
:3 421 419 :3 1e1 :12 5c4
:9 5c5 :4 5c7 :6 5c8 :5 5c9
5c8 :5 5cb 5ca :3 5c8
5c6 5ce :5 5cf :3 5ce
:2 5d0 :5 5d2 :11 5d3 :24 5d4
:3 5d3 :2 5d1 :6 5d0 5cd
:4 5c5 :5 5da :2 5db 5da
:6 5dc :5 5dd 5dc :5 5df
5de :3 5dc 5d9 5e2
:5 5e3 :3 5e2 :2 5e4 :5 5e6
:11 5e7 :24 5e8 :3 5e7 :2 5e5
:6 5e4 5e1 :4 5d8 :3 5c5
:5 5ee :11 5ef :30 5f0 :3 5ef
:11 5f2 :b 5f3 :3 5f2 :a 5f5
5f6 5ee :7 5f6 :11 5f7
:30 5f8 :3 5f7 :11 5fa :b 5fb
:3 5fa :7 5fd 5fe :2 5fd
5ff 5f6 5ee :7 5ff
:11 600 :30 601 :3 600 :11 603
:b 604 :3 603 :7 606 607
:2 606 5ff 5ee :11 609
:30 60a :3 609 :11 60c :b 60d
:3 60c :a 60f 608 :3 5ee
:3 5c4 :1c 613 :5 615 :5 616
:2 618 :2 619 :2 618 :2 61a
:2 618 :2 61b :2 618 :2 61c
:2 618 :2 61d :2 618 :2 61d
:2 618 :2 61d :2 618 :2 61e
:2 618 :2 61e :2 618 :2 61e
:2 618 :2 61e :2 618 :2 61f
:3 618 :5 622 :6 623 :5 624
623 :5 626 625 :3 623
621 629 :5 62a :3 629
:2 62b :5 62d :11 62e :24 62f
:b 630 :3 62e :2 62c :6 62b
628 :3 613 :5 636 :5 637
639 63a :2 63b :2 63a
:2 63c :2 63a :2 63d :2 63a
:2 63e :2 63a :2 63f :2 63a
:2 63f :2 63a :2 63f :2 63a
:2 640 :2 63a :2 640 :2 63a
:2 640 :2 63a :2 640 :2 63a
:2 641 :2 63a 639 :5 644
:6 645 :5 646 645 :5 648
647 :3 645 643 64b
:5 64c :3 64b :2 64d :5 64f
:11 650 :24 651 :b 652 :3 650
:2 64e :6 64d 64a :3 613
:7 657 659 65a :2 65b
:2 65a :2 65c :2 65a :2 65d
:2 65a :2 65e :2 65a :2 65f
:2 65a :2 660 :2 65a :2 661
:2 65a :2 662 :2 65a :2 663
:2 65a :2 664 :2 65a :2 665
:2 65a :2 666 :2 65a :2 666
:2 65a :2 667 :2 65a :2 668
:2 65a :2 668 :2 65a :2 669
:2 65a :2 66a :2 65a :2 66b
:2 65a :2 66c :2 65a :2 66c
:2 65a :2 66d :2 65a :2 66e
:2 65a :2 66f :2 65a :2 670
:2 65a :2 671 :2 65a :2 672
:2 65a :2 673 :2 65a :2 674
:2 65a :2 674 :2 65a :2 675
:2 65a :2 676 :2 65a :2 677
:2 65a :2 678 :2 65a :2 679
:2 65a :2 679 :2 65a :2 679
:2 65a :2 67a :2 65a 659
:5 67d :6 67e :5 67f 67e
:5 681 680 :3 67e 67c
684 :5 685 :3 684 :2 686
:5 688 :11 689 :24 68a :b 68b
:3 689 :2 687 :6 686 683
:3 613 690 691 :2 692
:2 691 :2 693 :2 691 :2 694
:2 691 :9 694 :2 691 :2 695
:2 691 :2 696 :2 691 :9 696
:2 691 :2 697 :2 691 :2 698
:2 691 :2 699 :2 691 :2 69a
:2 691 :2 69b :2 691 :2 69c
:2 691 :2 69d :2 691 :2 69e
:2 691 :2 69f :2 691 :3 69f
:2 6a0 :4 69f :2 691 :2 6a0
:2 691 :2 6a1 :2 691 :9 6a1
:2 691 :2 6a2 :2 691 :2 6a3
:2 691 :2 6a4 :2 691 :2 6a5
:2 691 :2 6a6 :2 691 690
6a7 613 :c 6a7 :5 6a9
:5 6aa :2 6ac :2 6ad :2 6ac
:2 6ae :2 6ac :2 6af :2 6ac
:2 6b0 :2 6ac :2 6b1 :2 6ac
:2 6b1 :2 6ac :2 6b1 :2 6ac
:2 6b2 :2 6ac :2 6b2 :2 6ac
:2 6b2 :3 6ac :5 6b5 :6 6b6
:5 6b7 6b6 :5 6b9 6b8
:3 6b6 6b4 6bc :5 6bd
:3 6bc :2 6be :5 6c0 :11 6c1
:24 6c2 :b 6c3 :3 6c1 :2 6bf
:6 6be 6bb :3 6a7 :5 6c9
:5 6ca :2 6cc :2 6cd :2 6cc
:2 6ce :2 6cc :2 6cf :2 6cc
:2 6d0 :2 6cc :2 6d1 :2 6cc
:2 6d1 :2 6cc :2 6d1 :2 6cc
:2 6d2 :2 6cc :2 6d2 :3 6cc
:5 6d5 :6 6d6 :5 6d7 6d6
:5 6d9 6d8 :3 6d6 6d4
6dc :5 6dd :3 6dc :2 6de
:5 6e0 :11 6e1 :24 6e2 :b 6e3
:3 6e1 :2 6df :6 6de 6db
:3 6a7 :7 6e8 6e9 6ea
:2 6eb :2 6ea :2 6ec :2 6ea
:2 6ed :2 6ea :2 6ee :2 6ea
:2 6ef :2 6ea :2 6f0 :2 6ea
:2 6f1 :2 6ea :2 6f2 :2 6ea
:2 6f3 :2 6ea :2 6f3 :2 6ea
:2 6f4 :2 6ea :2 6f5 :2 6ea
:2 6f5 :2 6ea :2 6f6 :2 6ea
:2 6f7 :2 6ea :2 6f8 :2 6ea
:2 6f8 :2 6ea :2 6f8 :2 6ea
6e9 :5 6fb :6 6fc :5 6fd
6fc :5 6ff 6fe :3 6fc
6fa 702 :5 703 :3 702
:2 704 :5 706 :11 707 :24 708
:b 709 :3 707 :2 705 :6 704
701 :3 6a7 70e 70f
:2 710 :2 70f :2 711 :2 70f
:2 712 :2 70f :9 712 :2 70f
:2 713 :2 70f :9 714 :2 70f
:2 715 :2 70f :2 716 :2 70f
:2 717 :2 70f :2 718 :2 70f
:2 719 :2 70f 70e 6a7
613 :5 71c :5 71d :2 71f
:2 720 :2 71f :2 721 :2 71f
:2 722 :2 71f :2 723 :2 71f
:2 724 :2 71f :2 725 :2 71f
:2 725 :2 71f :2 725 :2 71f
:2 726 :2 71f :2 726 :2 71f
:2 726 :2 71f :2 727 :3 71f
:5 72a :6 72b :5 72c 72b
:5 72e 72d :3 72b 729
731 :5 732 :3 731 :2 733
:5 735 :11 736 :24 737 :b 738
:3 736 :2 734 :6 733 730
:3 71a :5 73e :5 73f :2 741
:2 742 :2 741 :2 743 :2 741
:2 744 :2 741 :2 745 :2 741
:2 746 :2 741 :2 746 :2 741
:2 746 :2 741 :2 747 :2 741
:2 747 :3 741 :5 74a :6 74b
:5 74c 74b :5 74e 74d
:3 74b 749 751 :5 752
:3 751 :2 753 :5 755 :11 756
:24 757 :b 758 :3 756 :2 754
:6 753 750 :3 71a :7 75d
75f 760 :2 761 :2 760
:2 762 :2 760 :2 763 :2 760
:2 764 :2 760 :2 765 :2 760
:2 766 :2 760 :2 767 :2 760
:2 768 :2 760 :2 769 :2 760
:2 769 :2 760 :2 76a :2 760
:2 76b :2 760 :2 76c :2 760
:2 76d :2 760 :2 76d :2 760
:2 76d :2 760 75f :5 770
:6 771 :5 772 771 :5 774
773 :3 771 76f 777
:5 778 :3 777 :2 779 :5 77b
:11 77c :24 77d :b 77e :3 77c
:2 77a :6 779 776 :3 71a
:2 783 :2 784 :2 783 :2 785
:2 783 :2 786 :2 783 :9 787
:2 783 :2 787 :2 783 :2 788
:2 783 :3 788 :2 789 :4 788
:2 783 :2 78a :2 783 :2 78b
:2 783 :2 78c :2 783 :2 78d
:2 783 :2 78e :3 783 71a
:3 613 :11 792 :b 793 :3 792
:11 795 :b 796 :3 795 :8 798
59 :3 79c :11 79d :b 79e
:17 79f :3 79d :2 7a1 :3 7a2
:3 7a3 7a4 7a2 7a1
7a2 :3 7a5 :3 79c :2 7a6
:5 7a8 :11 7a9 :b 7aa :18 7ab
:3 7a9 :2 7ad 7ae :3 7af
7b0 7ae 7ad 7ae
:3 7b1 :2 7a7 :6 7a6 79b
:7 1 
b10e
4
:3 0 1 :3 0 2
:a 0 32f7 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f 4 :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 32f7 2 44
:2 0 18 :2 0 33
4 :3 0 18 :2 0
31 47 49 :6 0
4c 4a 0 32f5
0 17 :6 0 18
:2 0 37 4 :3 0
35 4e 50 :6 0
53 51 0 32f5
0 19 :6 0 18
:2 0 3b 4 :3 0
39 55 57 :6 0
5a 58 0 32f5
0 1a :6 0 18
:2 0 3f 4 :3 0
3d 5c 5e :6 0
61 5f 0 32f5
0 1b :6 0 18
:2 0 43 4 :3 0
41 63 65 :6 0
68 66 0 32f5
0 1c :6 0 18
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 32f5
0 1d :6 0 20
:2 0 4b 4 :3 0
49 71 73 :6 0
76 74 0 32f5
0 1e :6 0 20
:2 0 4f 4 :3 0
4d 78 7a :6 0
7d 7b 0 32f5
0 1f :6 0 20
:2 0 53 4 :3 0
51 7f 81 :6 0
84 82 0 32f5
0 21 :6 0 59
276 0 57 4
:3 0 55 86 88
:6 0 8b 89 0
32f5 0 22 :6 0
27 :2 0 5b 24
:3 0 8d :7 0 90
8e 0 32f5 0
23 :6 0 24 :3 0
92 :7 0 95 93
0 32f5 0 25
:6 0 18 :2 0 5f
4 :3 0 5d 97
99 :6 0 9c 9a
0 32f5 0 26
:6 0 2a :2 0 63
4 :3 0 61 9e
a0 :6 0 a3 a1
0 32f5 0 28
:6 0 2a :2 0 67
4 :3 0 65 a5
a7 :6 0 aa a8
0 32f5 0 29
:6 0 2a :2 0 6b
4 :3 0 69 ac
ae :6 0 b1 af
0 32f5 0 2b
:6 0 2e :2 0 6f
4 :3 0 6d b3
b5 :6 0 b8 b6
0 32f5 0 2c
:6 0 30 :2 0 73
4 :3 0 71 ba
bc :6 0 bf bd
0 32f5 0 2d
:6 0 30 :2 0 75
8 :3 0 c1 :7 0
c5 c2 c3 32f5
0 2f :6 0 30
:2 0 77 8 :3 0
c7 :7 0 cb c8
c9 32f5 0 31
:6 0 30 :2 0 79
8 :3 0 cd :7 0
d1 ce cf 32f5
0 32 :6 0 30
:2 0 7b 8 :3 0
d3 :7 0 d7 d4
d5 32f5 0 33
:6 0 30 :2 0 7d
8 :3 0 d9 :7 0
dd da db 32f5
0 34 :6 0 30
:2 0 7f 8 :3 0
df :7 0 e3 e0
e1 32f5 0 35
:6 0 30 :2 0 81
8 :3 0 e5 :7 0
e9 e6 e7 32f5
0 36 :6 0 30
:2 0 83 8 :3 0
eb :7 0 ef ec
ed 32f5 0 37
:6 0 30 :2 0 85
8 :3 0 f1 :7 0
f5 f2 f3 32f5
0 38 :6 0 30
:2 0 87 8 :3 0
f7 :7 0 fb f8
f9 32f5 0 39
:6 0 30 :2 0 89
8 :3 0 fd :7 0
101 fe ff 32f5
0 3a :6 0 30
:2 0 8b 8 :3 0
103 :7 0 107 104
105 32f5 0 3b
:6 0 30 :2 0 8d
8 :3 0 109 :7 0
10d 10a 10b 32f5
0 3c :6 0 30
:2 0 8f 8 :3 0
10f :7 0 113 110
111 32f5 0 3d
:6 0 30 :2 0 91
8 :3 0 115 :7 0
119 116 117 32f5
0 3e :6 0 30
:2 0 93 8 :3 0
11b :7 0 11f 11c
11d 32f5 0 3f
:6 0 30 :2 0 95
8 :3 0 121 :7 0
125 122 123 32f5
0 40 :6 0 30
:2 0 97 8 :3 0
127 :7 0 12b 128
129 32f5 0 41
:6 0 30 :2 0 99
8 :3 0 12d :7 0
131 12e 12f 32f5
0 42 :6 0 30
:2 0 9b 8 :3 0
133 :7 0 137 134
135 32f5 0 43
:6 0 30 :2 0 9d
8 :3 0 139 :7 0
13d 13a 13b 32f5
0 44 :6 0 30
:2 0 9f 8 :3 0
13f :7 0 143 140
141 32f5 0 45
:6 0 30 :2 0 a1
8 :3 0 145 :7 0
149 146 147 32f5
0 46 :6 0 30
:2 0 a3 8 :3 0
14b :7 0 14f 14c
14d 32f5 0 47
:6 0 30 :2 0 a5
8 :3 0 151 :7 0
155 152 153 32f5
0 48 :6 0 30
:2 0 a7 8 :3 0
157 :7 0 15b 158
159 32f5 0 49
:6 0 30 :2 0 a9
8 :3 0 15d :7 0
161 15e 15f 32f5
0 4a :6 0 27
:2 0 ab 8 :3 0
163 :7 0 167 164
165 32f5 0 4b
:6 0 27 :2 0 af
4 :3 0 ad 169
16b :6 0 16e 16c
0 32f5 0 4c
:6 0 30 :2 0 b3
4 :3 0 b1 170
172 :6 0 175 173
0 32f5 0 4d
:6 0 51 :2 0 b5
4f :3 0 177 :7 0
17b 178 179 32f5
0 4e :6 0 30
:2 0 b9 4 :3 0
b7 17d 17f :6 0
182 180 0 32f5
0 50 :6 0 18
:2 0 bb 8 :3 0
184 :7 0 188 185
186 32f5 0 52
:6 0 18 :2 0 bf
54 :3 0 bd 18a
18c :6 0 18f 18d
0 32f5 0 53
:6 0 18 :2 0 c3
54 :3 0 c1 191
193 :6 0 196 194
0 32f5 0 55
:6 0 30 :2 0 c7
4 :3 0 c5 198
19a :6 0 19d 19b
0 32f5 0 56
:6 0 30 :2 0 c9
8 :3 0 19f :7 0
1a3 1a0 1a1 32f5
0 57 :6 0 30
:2 0 cb 8 :3 0
1a5 :7 0 1a9 1a6
1a7 32f5 0 58
:6 0 20 :2 0 cd
8 :3 0 1ab :7 0
1af 1ac 1ad 32f5
0 59 :6 0 20
:2 0 d1 4 :3 0
cf 1b1 1b3 :6 0
1b6 1b4 0 32f5
0 5a :6 0 30
:2 0 d5 4 :3 0
d3 1b8 1ba :6 0
1bd 1bb 0 32f5
0 5b :6 0 30
:2 0 d7 8 :3 0
1bf :7 0 1c3 1c0
1c1 32f5 0 5c
:6 0 18 :2 0 d9
8 :3 0 1c5 :7 0
1c9 1c6 1c7 32f5
0 5d :6 0 27
:2 0 dd 4 :3 0
db 1cb 1cd :6 0
1d0 1ce 0 32f5
0 5e :6 0 27
:2 0 df 8 :3 0
1d2 0 2 :5 0
1d6 1d3 1d4 32f5
0 5f :6 0 30
:2 0 e1 8 :3 0
1d8 0 2 :5 0
1dc 1d9 1da 32f5
0 60 :6 0 30
:2 0 e3 8 :3 0
1de 0 2 :5 0
1e2 1df 1e0 32f5
0 61 :6 0 e7
8a1 0 e5 8
:3 0 1e4 0 2
:5 0 1e8 1e5 1e6
32f5 0 62 :6 0
1f5 1f6 0 e9
8 :3 0 1ea :7 0
1ed 1eb 0 32f5
0 63 :6 0 15
:3 0 16 :2 0 4
1ef 1f0 0 1f1
:7 0 1f4 1f2 0
32f5 0 64 :6 0
65 :3 0 66 :3 0
65 :3 0 67 :3 0
1f8 1f9 0 2
:4 0 eb 1fa 1fc
1f7 1fe 1fd :2 0
68 :3 0 69 :3 0
200 201 0 6a
:4 0 65 :3 0 6b
:3 0 204 205 0
2 :4 0 ed 206
208 6c :4 0 6d
:2 0 6e :3 0 ef
20b 20d :3 0 6f
:4 0 6d :2 0 70
:4 0 f2 210 212
:3 0 6d :2 0 3
:3 0 f5 214 216
:3 0 6d :2 0 70
:4 0 f8 218 21a
:3 0 6d :2 0 71
:4 0 fb 21c 21e
:3 0 6d :2 0 70
:4 0 fe 220 222
:3 0 6d :2 0 5
:3 0 101 224 226
:3 0 6d :2 0 70
:4 0 104 228 22a
:3 0 6d :2 0 71
:4 0 107 22c 22e
:3 0 6d :2 0 70
:4 0 10a 230 232
:3 0 6d :2 0 6
:3 0 10d 234 236
:3 0 6d :2 0 70
:4 0 110 238 23a
:3 0 6d :2 0 71
:4 0 113 23c 23e
:3 0 6d :2 0 72
:3 0 73 :3 0 7
:3 0 116 242 244
74 :4 0 118 241
247 11b 240 249
:3 0 6d :2 0 71
:4 0 11e 24b 24d
:3 0 6d :2 0 72
:3 0 73 :3 0 9
:3 0 121 251 253
74 :4 0 123 250
256 126 24f 258
:3 0 6d :2 0 71
:4 0 129 25a 25c
:3 0 6d :2 0 72
:3 0 73 :3 0 a
:3 0 12c 260 262
74 :4 0 12e 25f
265 131 25e 267
:3 0 6d :2 0 71
:4 0 134 269 26b
:3 0 6d :2 0 72
:3 0 73 :3 0 b
:3 0 137 26f 271
74 :4 0 139 26e
274 13c 26d 276
:3 0 6d :2 0 71
:4 0 13f 278 27a
:3 0 6d :2 0 72
:3 0 73 :3 0 c
:3 0 142 27e 280
74 :4 0 144 27d
283 147 27c 285
:3 0 6d :2 0 71
:4 0 14a 287 289
:3 0 6d :2 0 72
:3 0 73 :3 0 d
:3 0 14d 28d 28f
74 :4 0 14f 28c
292 152 28b 294
:3 0 6d :2 0 71
:4 0 155 296 298
:3 0 6d :2 0 72
:3 0 73 :3 0 e
:3 0 158 29c 29e
74 :4 0 15a 29b
2a1 15d 29a 2a3
:3 0 6d :2 0 71
:4 0 160 2a5 2a7
:3 0 6d :2 0 72
:3 0 73 :3 0 f
:3 0 163 2ab 2ad
74 :4 0 165 2aa
2b0 168 2a9 2b2
:3 0 6d :2 0 71
:4 0 16b 2b4 2b6
:3 0 6d :2 0 72
:3 0 73 :3 0 10
:3 0 16e 2ba 2bc
74 :4 0 170 2b9
2bf 173 2b8 2c1
:3 0 6d :2 0 71
:4 0 176 2c3 2c5
:3 0 6d :2 0 72
:3 0 73 :3 0 11
:3 0 179 2c9 2cb
74 :4 0 17b 2c8
2ce 17e 2c7 2d0
:3 0 6d :2 0 71
:4 0 181 2d2 2d4
:3 0 6d :2 0 70
:4 0 184 2d6 2d8
:3 0 6d :2 0 12
:3 0 187 2da 2dc
:3 0 6d :2 0 70
:4 0 18a 2de 2e0
:3 0 6d :2 0 71
:4 0 18d 2e2 2e4
:3 0 6d :2 0 70
:4 0 190 2e6 2e8
:3 0 6d :2 0 13
:3 0 193 2ea 2ec
:3 0 6d :2 0 70
:4 0 196 2ee 2f0
:3 0 6d :2 0 75
:4 0 199 2f2 2f4
:3 0 19c 202 2f6
:2 0 2f8 1a1 2f9
1ff 2f8 0 2fa
1a3 0 3255 65
:3 0 66 :3 0 2fb
2fc 0 65 :3 0
76 :3 0 2fe 2ff
0 27 :2 0 2
:4 0 77 :2 0 78
:2 0 27 :2 0 1a5
304 306 :3 0 1a8
300 308 2fd 30a
309 :2 0 68 :3 0
79 :3 0 30c 30d
0 6a :4 0 7a
:4 0 6d :2 0 6e
:3 0 1ac 311 313
:3 0 1af 30e 315
:2 0 317 1b2 318
30b 317 0 319
1b4 0 3255 17
:3 0 3 :3 0 31a
31b 0 3255 1f
:3 0 5 :3 0 31d
31e 0 3255 22
:3 0 6 :3 0 320
321 0 3255 1c
:3 0 13 :3 0 323
324 0 3255 37
:3 0 7 :3 0 326
327 0 3255 35
:3 0 9 :3 0 329
32a 0 3255 36
:3 0 e :3 0 32c
32d 0 3255 38
:3 0 b :3 0 32f
330 0 3255 3a
:3 0 f :3 0 332
333 0 3255 39
:3 0 c :3 0 335
336 0 3255 32
:3 0 11 :3 0 338
339 0 3255 31
:3 0 a :3 0 33b
33c 0 3255 3b
:3 0 d :3 0 33e
33f 0 3255 33
:3 0 10 :3 0 341
342 0 3255 1a
:3 0 17 :3 0 344
345 0 3255 23
:3 0 7b :4 0 347
348 0 3255 19
:4 0 34a 34b 0
3255 59 :3 0 7c
:3 0 72 :3 0 32
:3 0 30 :2 0 1b6
34f 352 1b9 34e
354 34d 355 0
3255 5c :3 0 30
:2 0 357 358 0
3255 4e :3 0 7d
:2 0 35a 35b 0
3255 3f :3 0 30
:2 0 35d 35e 0
3255 3 :3 0 7e
:2 0 1bb 361 362
:3 0 363 :2 0 65
:3 0 66 :3 0 365
366 0 65 :3 0
76 :3 0 368 369
0 7f :2 0 2
:4 0 80 :2 0 78
:2 0 27 :2 0 1bd
36e 370 :3 0 1c0
36a 372 367 374
373 :2 0 68 :3 0
79 :3 0 376 377
0 6a :4 0 81
:4 0 6d :2 0 6e
:3 0 1c4 37b 37d
:3 0 6d :2 0 82
:4 0 1c7 37f 381
:3 0 6d :2 0 83
:4 0 1ca 383 385
:3 0 6d :2 0 72
:3 0 73 :3 0 84
:3 0 85 :3 0 38a
38b 0 1cd 389
38d 74 :4 0 1cf
388 390 1d2 387
392 :3 0 1d5 378
394 :2 0 396 1d8
397 375 396 0
398 1da 0 3c1
65 :3 0 66 :3 0
399 39a 0 65
:3 0 76 :3 0 39c
39d 0 27 :2 0
2 :4 0 86 :2 0
78 :2 0 27 :2 0
1dc 3a2 3a4 :3 0
1df 39e 3a6 39b
3a8 3a7 :2 0 68
:3 0 79 :3 0 3aa
3ab 0 6a :4 0
87 :4 0 6d :2 0
6e :3 0 1e3 3af
3b1 :3 0 1e6 3ac
3b3 :2 0 3b5 1e9
3b6 3a9 3b5 0
3b7 1eb 0 3c1
88 :3 0 89 :3 0
3b8 3b9 0 84
:3 0 85 :3 0 3bb
3bc 0 8a :3 0
1ed 3ba 3bf :2 0
3c1 1f0 3c2 364
3c1 0 3c3 1f4
0 3255 12 :3 0
7e :2 0 1f6 3c5
3c6 :3 0 3c7 :2 0
65 :3 0 66 :3 0
3c9 3ca 0 65
:3 0 76 :3 0 3cc
3cd 0 7f :2 0
2 :4 0 8b :2 0
78 :2 0 27 :2 0
1f8 3d2 3d4 :3 0
1fb 3ce 3d6 3cb
3d8 3d7 :2 0 68
:3 0 79 :3 0 3da
3db 0 6a :4 0
8c :4 0 6d :2 0
6e :3 0 1ff 3df
3e1 :3 0 6d :2 0
82 :4 0 202 3e3
3e5 :3 0 6d :2 0
83 :4 0 205 3e7
3e9 :3 0 6d :2 0
72 :3 0 73 :3 0
84 :3 0 85 :3 0
3ee 3ef 0 208
3ed 3f1 74 :4 0
20a 3ec 3f4 20d
3eb 3f6 :3 0 210
3dc 3f8 :2 0 3fa
213 3fb 3d9 3fa
0 3fc 215 0
425 65 :3 0 66
:3 0 3fd 3fe 0
65 :3 0 76 :3 0
400 401 0 27
:2 0 2 :4 0 8d
:2 0 78 :2 0 27
:2 0 217 406 408
:3 0 21a 402 40a
3ff 40c 40b :2 0
68 :3 0 79 :3 0
40e 40f 0 6a
:4 0 8e :4 0 6d
:2 0 6e :3 0 21e
413 415 :3 0 221
410 417 :2 0 419
224 41a 40d 419
0 41b 226 0
425 88 :3 0 89
:3 0 41c 41d 0
84 :3 0 85 :3 0
41f 420 0 8a
:3 0 228 41e 423
:2 0 425 22b 426
3c8 425 0 427
22f 0 3255 72
:3 0 31 :3 0 30
:2 0 231 428 42b
8f :2 0 90 :2 0
236 42d 42f :3 0
72 :3 0 39 :3 0
30 :2 0 239 431
434 8f :2 0 90
:2 0 23e 436 438
:3 0 430 43a 439
:2 0 72 :3 0 35
:3 0 30 :2 0 241
43c 43f 8f :2 0
90 :2 0 246 441
443 :3 0 43b 445
444 :2 0 65 :3 0
66 :3 0 447 448
0 65 :3 0 76
:3 0 44a 44b 0
7f :2 0 2 :4 0
91 :2 0 78 :2 0
27 :2 0 249 450
452 :3 0 24c 44c
454 449 456 455
:2 0 68 :3 0 79
:3 0 458 459 0
6a :4 0 92 :4 0
6d :2 0 6e :3 0
250 45d 45f :3 0
6d :2 0 82 :4 0
253 461 463 :3 0
6d :2 0 83 :4 0
256 465 467 :3 0
6d :2 0 72 :3 0
73 :3 0 84 :3 0
93 :3 0 46c 46d
0 259 46b 46f
74 :4 0 25b 46a
472 25e 469 474
:3 0 261 45a 476
:2 0 478 264 479
457 478 0 47a
266 0 4a3 65
:3 0 66 :3 0 47b
47c 0 65 :3 0
76 :3 0 47e 47f
0 27 :2 0 2
:4 0 94 :2 0 78
:2 0 27 :2 0 268
484 486 :3 0 26b
480 488 47d 48a
489 :2 0 68 :3 0
79 :3 0 48c 48d
0 6a :4 0 95
:4 0 6d :2 0 6e
:3 0 26f 491 493
:3 0 272 48e 495
:2 0 497 275 498
48b 497 0 499
277 0 4a3 88
:3 0 89 :3 0 49a
49b 0 84 :3 0
93 :3 0 49d 49e
0 8a :3 0 279
49c 4a1 :2 0 4a3
27c 4a4 446 4a3
0 4a5 280 0
3255 5 :3 0 96
:2 0 282 4a7 4a8
:3 0 4a9 :2 0 4aa
:2 0 6 :3 0 96
:2 0 284 4ad 4ae
:3 0 4af :2 0 4b0
:2 0 4ab 4b2 4b1
:2 0 97 :3 0 98
:3 0 6 :3 0 97
:3 0 98 :3 0 5
:3 0 44 :3 0 99
:4 0 9a 1 :8 0
4c2 15 :3 0 9b
:3 0 4bd 4be 0
9c :3 0 4bf 4c0
0 4c2 286 515
9d :3 0 15 :3 0
9b :3 0 4c4 4c5
0 9c :3 0 4c6
4c7 0 4c9 289
4cb 28b 4ca 4c9
:2 0 513 9e :3 0
15 :3 0 9b :3 0
4ce 4cf 0 9c
:3 0 4d0 4d1 0
50b 65 :3 0 66
:3 0 4d3 4d4 0
65 :3 0 76 :3 0
4d6 4d7 0 9f
:2 0 2 :4 0 a0
:2 0 78 :2 0 27
:2 0 28d 4dc 4de
:3 0 290 4d8 4e0
4d5 4e2 4e1 :2 0
68 :3 0 79 :3 0
4e4 4e5 0 6a
:4 0 a1 :4 0 6d
:2 0 6e :3 0 294
4e9 4eb :3 0 6d
:2 0 82 :4 0 297
4ed 4ef :3 0 6d
:2 0 a2 :4 0 29a
4f1 4f3 :3 0 6d
:2 0 9c :3 0 29d
4f5 4f7 :3 0 6d
:2 0 a3 :4 0 2a0
4f9 4fb :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 2a3 4fe 502
2a7 4fd 504 :3 0
2aa 4e6 506 :2 0
508 2ad 509 4e3
508 0 50a 2af
0 50b 2b1 50e
:3 0 50e 0 50e
50d 50b 50c :6 0
510 2 :3 0 2b4
512 2b6 511 510
:2 0 513 2b8 :2 0
515 0 515 514
4c2 513 :6 0 590
1 :3 0 15 :3 0
9b :3 0 517 518
0 15 :3 0 8f
:2 0 a7 :3 0 51a
51c 0 2bd 51b
51e :3 0 51f :2 0
72 :3 0 44 :3 0
30 :2 0 2c0 521
524 a8 :2 0 30
:2 0 2c5 526 528
:3 0 529 :2 0 520
52b 52a :2 0 65
:3 0 66 :3 0 52d
52e 0 65 :3 0
76 :3 0 530 531
0 7f :2 0 2
:4 0 a9 :2 0 78
:2 0 27 :2 0 2c8
536 538 :3 0 2cb
532 53a 52f 53c
53b :2 0 68 :3 0
79 :3 0 53e 53f
0 6a :4 0 aa
:4 0 6d :2 0 6e
:3 0 2cf 543 545
:3 0 6d :2 0 82
:4 0 2d2 547 549
:3 0 6d :2 0 83
:4 0 2d5 54b 54d
:3 0 6d :2 0 72
:3 0 73 :3 0 84
:3 0 ab :3 0 552
553 0 2d8 551
555 74 :4 0 2da
550 558 2dd 54f
55a :3 0 2e0 540
55c :2 0 55e 2e3
55f 53d 55e 0
560 2e5 0 589
65 :3 0 66 :3 0
561 562 0 65
:3 0 76 :3 0 564
565 0 27 :2 0
2 :4 0 ac :2 0
78 :2 0 27 :2 0
2e7 56a 56c :3 0
2ea 566 56e 563
570 56f :2 0 68
:3 0 79 :3 0 572
573 0 6a :4 0
ad :4 0 6d :2 0
6e :3 0 2ee 577
579 :3 0 2f1 574
57b :2 0 57d 2f4
57e 571 57d 0
57f 2f6 0 589
88 :3 0 89 :3 0
580 581 0 84
:3 0 ab :3 0 583
584 0 8a :3 0
2f8 582 587 :2 0
589 2fb 58a 52c
589 0 58b 2ff
0 590 62 :3 0
27 :2 0 58c 58d
0 590 ae :3 0
301 5ff 5 :3 0
7e :2 0 305 592
593 :3 0 594 :2 0
595 :2 0 6 :3 0
7e :2 0 307 598
599 :3 0 59a :2 0
59b :2 0 596 59d
59c :2 0 6e :3 0
1f :3 0 99 :4 0
af 1 :8 0 5a8
15 :3 0 9b :3 0
5a3 5a4 0 9c
:3 0 5a5 5a6 0
5a8 309 5fb 9d
:3 0 15 :3 0 9b
:3 0 5aa 5ab 0
9c :3 0 5ac 5ad
0 5af 30c 5b1
30e 5b0 5af :2 0
5f9 9e :3 0 15
:3 0 9b :3 0 5b4
5b5 0 9c :3 0
5b6 5b7 0 5f1
65 :3 0 66 :3 0
5b9 5ba 0 65
:3 0 76 :3 0 5bc
5bd 0 9f :2 0
2 :4 0 b0 :2 0
78 :2 0 27 :2 0
310 5c2 5c4 :3 0
313 5be 5c6 5bb
5c8 5c7 :2 0 68
:3 0 79 :3 0 5ca
5cb 0 6a :4 0
b1 :4 0 6d :2 0
6e :3 0 317 5cf
5d1 :3 0 6d :2 0
82 :4 0 31a 5d3
5d5 :3 0 6d :2 0
a2 :4 0 31d 5d7
5d9 :3 0 6d :2 0
9c :3 0 320 5db
5dd :3 0 6d :2 0
a3 :4 0 323 5df
5e1 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
326 5e4 5e8 32a
5e3 5ea :3 0 32d
5cc 5ec :2 0 5ee
330 5ef 5c9 5ee
0 5f0 332 0
5f1 334 5f4 :3 0
5f4 0 5f4 5f3
5f1 5f2 :6 0 5f6
4 :3 0 337 5f8
339 5f7 5f6 :2 0
5f9 33b :2 0 5fb
0 5fb 5fa 5a8
5f9 :6 0 5fd 1
:3 0 33e 5fe 59e
5fd 0 600 4b3
590 0 600 340
0 3255 21 :3 0
1f :3 0 601 602
0 3255 6 :3 0
7e :2 0 343 605
606 :3 0 607 :2 0
22 :3 0 7b :4 0
609 60a 0 60c
345 60d 608 60c
0 60e 347 0
3255 1d :3 0 a4
:3 0 1d :3 0 27
:2 0 18 :2 0 349
610 614 60f 615
0 3255 26 :3 0
a4 :3 0 26 :3 0
27 :2 0 27 :2 0
34d 618 61c 617
61d 0 3255 29
:3 0 12 :3 0 61f
620 0 3255 72
:3 0 32 :3 0 30
:2 0 351 622 625
b2 :2 0 30 :2 0
356 627 629 :3 0
1d :3 0 a4 :3 0
a4 :3 0 29 :3 0
27 :2 0 18 :2 0
359 62d 631 27
:2 0 18 :2 0 35d
62c 635 62b 636
0 a07 26 :3 0
b3 :3 0 b4 :3 0
639 63a 0 27
:2 0 27 :2 0 b5
:2 0 29 :3 0 361
63b 640 638 641
0 a07 b6 :3 0
72 :3 0 32 :3 0
30 :2 0 366 644
647 369 643 649
b7 :2 0 30 :2 0
36d 64b 64d :3 0
b8 :3 0 72 :3 0
b9 :3 0 72 :3 0
ba :3 0 bb :3 0
17 :3 0 3d :3 0
3e :3 0 43 :3 0
bc :3 0 bd :3 0
1a :4 0 be 1
:8 0 662 15 :3 0
9b :3 0 65d 65e
0 9c :3 0 65f
660 0 662 370
6b5 9d :3 0 15
:3 0 9b :3 0 664
665 0 9c :3 0
666 667 0 669
373 66b 375 66a
669 :2 0 6b3 9e
:3 0 15 :3 0 9b
:3 0 66e 66f 0
9c :3 0 670 671
0 6ab 65 :3 0
66 :3 0 673 674
0 65 :3 0 76
:3 0 676 677 0
9f :2 0 2 :4 0
bf :2 0 78 :2 0
27 :2 0 377 67c
67e :3 0 37a 678
680 675 682 681
:2 0 68 :3 0 79
:3 0 684 685 0
6a :4 0 c0 :4 0
6d :2 0 6e :3 0
37e 689 68b :3 0
6d :2 0 82 :4 0
381 68d 68f :3 0
6d :2 0 a2 :4 0
384 691 693 :3 0
6d :2 0 9c :3 0
387 695 697 :3 0
6d :2 0 a3 :4 0
38a 699 69b :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 38d 69e
6a2 391 69d 6a4
:3 0 394 686 6a6
:2 0 6a8 397 6a9
683 6a8 0 6aa
399 0 6ab 39b
6ae :3 0 6ae 0
6ae 6ad 6ab 6ac
:6 0 6b0 6 :3 0
39e 6b2 3a0 6b1
6b0 :2 0 6b3 3a2
:2 0 6b5 0 6b5
6b4 662 6b3 :6 0
6b7 1 :3 0 3a5
759 c1 :3 0 c2
:3 0 c1 :3 0 c3
:3 0 c1 :3 0 c4
:3 0 c1 :3 0 c5
:3 0 c1 :3 0 b8
:3 0 72 :3 0 c6
:3 0 b9 :3 0 72
:3 0 c6 :3 0 ba
:3 0 c6 :3 0 bb
:3 0 32 :3 0 5c
:3 0 5a :3 0 5b
:3 0 17 :3 0 3d
:3 0 3e :3 0 43
:3 0 bc :3 0 c6
:3 0 bc :3 0 c1
:3 0 c1 :3 0 bd
:3 0 1a :3 0 c1
:3 0 c2 :3 0 84
:3 0 c7 :3 0 84
:3 0 c8 :3 0 84
:3 0 c9 :3 0 84
:3 0 ca :3 0 84
:3 0 cb :3 0 84
:3 0 cc :3 0 84
:3 0 cd :3 0 84
:3 0 ce :3 0 84
:3 0 cf :3 0 84
:3 0 d0 :3 0 84
:3 0 d1 :3 0 84
:3 0 d2 :3 0 84
:3 0 d3 :3 0 84
:3 0 d4 :3 0 84
:3 0 d5 :3 0 c6
:3 0 bd :3 0 c1
:3 0 b8 :4 0 d6
1 :8 0 703 15
:3 0 9b :3 0 6fe
6ff 0 9c :3 0
700 701 0 703
3a7 756 9d :3 0
15 :3 0 9b :3 0
705 706 0 9c
:3 0 707 708 0
70a 3aa 70c 3ac
70b 70a :2 0 754
9e :3 0 15 :3 0
9b :3 0 70f 710
0 9c :3 0 711
712 0 74c 65
:3 0 66 :3 0 714
715 0 65 :3 0
76 :3 0 717 718
0 9f :2 0 2
:4 0 d7 :2 0 78
:2 0 27 :2 0 3ae
71d 71f :3 0 3b1
719 721 716 723
722 :2 0 68 :3 0
79 :3 0 725 726
0 6a :4 0 d8
:4 0 6d :2 0 6e
:3 0 3b5 72a 72c
:3 0 6d :2 0 82
:4 0 3b8 72e 730
:3 0 6d :2 0 a2
:4 0 3bb 732 734
:3 0 6d :2 0 9c
:3 0 3be 736 738
:3 0 6d :2 0 a3
:4 0 3c1 73a 73c
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 3c4
73f 743 3c8 73e
745 :3 0 3cb 727
747 :2 0 749 3ce
74a 724 749 0
74b 3d0 0 74c
3d2 74f :3 0 74f
0 74f 74e 74c
74d :6 0 751 8
:3 0 3d5 753 3d7
752 751 :2 0 754
3d9 :2 0 756 0
756 755 703 754
:6 0 758 1 :3 0
3dc 75a 64e 6b7
0 75b 0 758
0 75b 3de 0
a07 15 :3 0 9b
:3 0 75c 75d 0
15 :3 0 8f :2 0
d9 :3 0 75f 761
0 3e3 760 763
:3 0 764 :2 0 b8
:3 0 da :3 0 17
:3 0 5e :3 0 db
:3 0 bd :3 0 1a
:4 0 dc 1 :8 0
773 15 :3 0 9b
:3 0 76e 76f 0
9c :3 0 770 771
0 773 3e6 7c6
9d :3 0 15 :3 0
9b :3 0 775 776
0 9c :3 0 777
778 0 77a 3e9
77c 3eb 77b 77a
:2 0 7c4 9e :3 0
15 :3 0 9b :3 0
77f 780 0 9c
:3 0 781 782 0
7bc 65 :3 0 66
:3 0 784 785 0
65 :3 0 76 :3 0
787 788 0 9f
:2 0 2 :4 0 dd
:2 0 78 :2 0 27
:2 0 3ed 78d 78f
:3 0 3f0 789 791
786 793 792 :2 0
68 :3 0 79 :3 0
795 796 0 6a
:4 0 de :4 0 6d
:2 0 6e :3 0 3f4
79a 79c :3 0 6d
:2 0 82 :4 0 3f7
79e 7a0 :3 0 6d
:2 0 a2 :4 0 3fa
7a2 7a4 :3 0 6d
:2 0 9c :3 0 3fd
7a6 7a8 :3 0 6d
:2 0 a3 :4 0 400
7aa 7ac :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 403 7af 7b3
407 7ae 7b5 :3 0
40a 797 7b7 :2 0
7b9 40d 7ba 794
7b9 0 7bb 40f
0 7bc 411 7bf
:3 0 7bf 0 7bf
7be 7bc 7bd :6 0
7c1 a :3 0 414
7c3 416 7c2 7c1
:2 0 7c4 418 :2 0
7c6 0 7c6 7c5
773 7c4 :6 0 8b5
1 :3 0 15 :3 0
9b :3 0 7c8 7c9
0 15 :3 0 8f
:2 0 a7 :3 0 7cb
7cd 0 41d 7cc
7cf :3 0 7d0 :2 0
5e :3 0 96 :2 0
420 7d3 7d4 :3 0
7d5 :2 0 59 :3 0
27 :2 0 7d7 7d8
0 7da 422 7db
7d6 7da 0 7dc
424 0 843 72
:3 0 b9 :3 0 72
:3 0 ba :3 0 bb
:3 0 3d :3 0 3e
:3 0 43 :3 0 bc
:3 0 bd :3 0 17
:4 0 df 1 :8 0
7ee 15 :3 0 9b
:3 0 7e9 7ea 0
9c :3 0 7eb 7ec
0 7ee 426 841
9d :3 0 15 :3 0
9b :3 0 7f0 7f1
0 9c :3 0 7f2
7f3 0 7f5 429
7f7 42b 7f6 7f5
:2 0 83f 9e :3 0
15 :3 0 9b :3 0
7fa 7fb 0 9c
:3 0 7fc 7fd 0
837 65 :3 0 66
:3 0 7ff 800 0
65 :3 0 76 :3 0
802 803 0 9f
:2 0 2 :4 0 e0
:2 0 78 :2 0 27
:2 0 42d 808 80a
:3 0 430 804 80c
801 80e 80d :2 0
68 :3 0 79 :3 0
810 811 0 6a
:4 0 e1 :4 0 6d
:2 0 6e :3 0 434
815 817 :3 0 6d
:2 0 82 :4 0 437
819 81b :3 0 6d
:2 0 a2 :4 0 43a
81d 81f :3 0 6d
:2 0 9c :3 0 43d
821 823 :3 0 6d
:2 0 a3 :4 0 440
825 827 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 443 82a 82e
447 829 830 :3 0
44a 812 832 :2 0
834 44d 835 80f
834 0 836 44f
0 837 451 83a
:3 0 83a 0 83a
839 837 838 :6 0
83c c :3 0 454
83e 456 83d 83c
:2 0 83f 458 :2 0
841 0 841 840
7ee 83f :6 0 843
1 :3 0 45b 8b2
65 :3 0 66 :3 0
844 845 0 65
:3 0 76 :3 0 847
848 0 18 :2 0
2 :4 0 e2 :2 0
78 :2 0 27 :2 0
45e 84d 84f :3 0
461 849 851 846
853 852 :2 0 68
:3 0 79 :3 0 855
856 0 6a :4 0
e3 :4 0 6d :2 0
6e :3 0 465 85a
85c :3 0 6d :2 0
82 :4 0 468 85e
860 :3 0 6d :2 0
83 :4 0 46b 862
864 :3 0 6d :2 0
72 :3 0 73 :3 0
84 :3 0 e4 :3 0
869 86a 0 46e
868 86c 74 :4 0
470 867 86f 473
866 871 :3 0 6d
:2 0 e5 :4 0 476
873 875 :3 0 6d
:2 0 70 :4 0 479
877 879 :3 0 6d
:2 0 1a :3 0 47c
87b 87d :3 0 6d
:2 0 70 :4 0 47f
87f 881 :3 0 482
857 883 :2 0 885
485 886 854 885
0 887 487 0
8b1 65 :3 0 66
:3 0 888 889 0
65 :3 0 76 :3 0
88b 88c 0 27
:2 0 2 :4 0 e6
:2 0 78 :2 0 27
:2 0 489 891 893
:3 0 48c 88d 895
88a 897 896 :2 0
68 :3 0 79 :3 0
899 89a 0 6a
:4 0 e7 :4 0 6d
:2 0 6e :3 0 490
89e 8a0 :3 0 493
89b 8a2 :2 0 8a4
496 8a5 898 8a4
0 8a6 498 0
8b1 88 :3 0 e8
:3 0 8a7 8a8 0
84 :3 0 e4 :3 0
8aa 8ab 0 1a
:3 0 8a :3 0 49a
8a9 8af :2 0 8b1
49e 8b3 7d1 843
0 8b4 0 8b1
0 8b4 4a2 0
8b5 4a5 8ba 59
:3 0 27 :2 0 8b6
8b7 0 8b9 4a8
8bb 765 8b5 0
8bc 0 8b9 0
8bc 4aa 0 a07
5d :3 0 30 :2 0
8bd 8be 0 a07
e9 :3 0 5d :3 0
ea :3 0 b8 :3 0
17 :4 0 eb 1
:8 0 8cb 15 :3 0
9b :3 0 8c6 8c7
0 9c :3 0 8c8
8c9 0 8cb 4ad
91e 9d :3 0 15
:3 0 9b :3 0 8cd
8ce 0 9c :3 0
8cf 8d0 0 8d2
4b0 8d4 4b2 8d3
8d2 :2 0 91c 9e
:3 0 15 :3 0 9b
:3 0 8d7 8d8 0
9c :3 0 8d9 8da
0 914 65 :3 0
66 :3 0 8dc 8dd
0 65 :3 0 76
:3 0 8df 8e0 0
9f :2 0 2 :4 0
ec :2 0 78 :2 0
27 :2 0 4b4 8e5
8e7 :3 0 4b7 8e1
8e9 8de 8eb 8ea
:2 0 68 :3 0 79
:3 0 8ed 8ee 0
6a :4 0 ed :4 0
6d :2 0 6e :3 0
4bb 8f2 8f4 :3 0
6d :2 0 82 :4 0
4be 8f6 8f8 :3 0
6d :2 0 a2 :4 0
4c1 8fa 8fc :3 0
6d :2 0 9c :3 0
4c4 8fe 900 :3 0
6d :2 0 a3 :4 0
4c7 902 904 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 4ca 907
90b 4ce 906 90d
:3 0 4d1 8ef 90f
:2 0 911 4d4 912
8ec 911 0 913
4d6 0 914 4d8
917 :3 0 917 0
917 916 914 915
:6 0 919 e :3 0
4db 91b 4dd 91a
919 :2 0 91c 4df
:2 0 91e 0 91e
91d 8cb 91c :6 0
a07 1 :3 0 72
:3 0 5d :3 0 30
:2 0 4e2 920 923
b2 :2 0 30 :2 0
4e7 925 927 :3 0
ee :3 0 4d :3 0
bc :3 0 bd :3 0
17 :4 0 ef 1
:8 0 934 15 :3 0
9b :3 0 92f 930
0 9c :3 0 931
932 0 934 4ea
987 9d :3 0 15
:3 0 9b :3 0 936
937 0 9c :3 0
938 939 0 93b
4ed 93d 4ef 93c
93b :2 0 985 9e
:3 0 15 :3 0 9b
:3 0 940 941 0
9c :3 0 942 943
0 97d 65 :3 0
66 :3 0 945 946
0 65 :3 0 76
:3 0 948 949 0
9f :2 0 2 :4 0
f0 :2 0 78 :2 0
27 :2 0 4f1 94e
950 :3 0 4f4 94a
952 947 954 953
:2 0 68 :3 0 79
:3 0 956 957 0
6a :4 0 f1 :4 0
6d :2 0 6e :3 0
4f8 95b 95d :3 0
6d :2 0 82 :4 0
4fb 95f 961 :3 0
6d :2 0 a2 :4 0
4fe 963 965 :3 0
6d :2 0 9c :3 0
501 967 969 :3 0
6d :2 0 a3 :4 0
504 96b 96d :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 507 970
974 50b 96f 976
:3 0 50e 958 978
:2 0 97a 511 97b
955 97a 0 97c
513 0 97d 515
980 :3 0 980 0
980 97f 97d 97e
:6 0 982 10 :3 0
518 984 51a 983
982 :2 0 985 51c
:2 0 987 0 987
986 934 985 :6 0
a04 1 :3 0 97
:3 0 f2 :3 0 989
98a 0 4d :3 0
f3 :4 0 51f 98b
98e 8f :2 0 30
:2 0 524 990 992
:3 0 65 :3 0 66
:3 0 994 995 0
65 :3 0 76 :3 0
997 998 0 18
:2 0 2 :4 0 f4
:2 0 78 :2 0 27
:2 0 527 99d 99f
:3 0 52a 999 9a1
996 9a3 9a2 :2 0
68 :3 0 79 :3 0
9a5 9a6 0 6a
:4 0 f5 :4 0 6d
:2 0 6e :3 0 52e
9aa 9ac :3 0 6d
:2 0 82 :4 0 531
9ae 9b0 :3 0 6d
:2 0 83 :4 0 534
9b2 9b4 :3 0 6d
:2 0 72 :3 0 73
:3 0 84 :3 0 f6
:3 0 9b9 9ba 0
537 9b8 9bc 74
:4 0 539 9b7 9bf
53c 9b6 9c1 :3 0
6d :2 0 e5 :4 0
53f 9c3 9c5 :3 0
6d :2 0 70 :4 0
542 9c7 9c9 :3 0
6d :2 0 17 :3 0
545 9cb 9cd :3 0
6d :2 0 70 :4 0
548 9cf 9d1 :3 0
54b 9a7 9d3 :2 0
9d5 54e 9d6 9a4
9d5 0 9d7 550
0 a01 65 :3 0
66 :3 0 9d8 9d9
0 65 :3 0 76
:3 0 9db 9dc 0
27 :2 0 2 :4 0
f7 :2 0 78 :2 0
27 :2 0 552 9e1
9e3 :3 0 555 9dd
9e5 9da 9e7 9e6
:2 0 68 :3 0 79
:3 0 9e9 9ea 0
6a :4 0 f8 :4 0
6d :2 0 6e :3 0
559 9ee 9f0 :3 0
55c 9eb 9f2 :2 0
9f4 55f 9f5 9e8
9f4 0 9f6 561
0 a01 88 :3 0
e8 :3 0 9f7 9f8
0 84 :3 0 f6
:3 0 9fa 9fb 0
17 :3 0 8a :3 0
563 9f9 9ff :2 0
a01 567 a02 993
a01 0 a03 56b
0 a04 56d a05
928 a04 0 a06
570 0 a07 572
b56 72 :3 0 b9
:3 0 72 :3 0 ba
:3 0 bb :3 0 3d
:3 0 3e :3 0 43
:3 0 bc :3 0 bd
:3 0 17 :4 0 f9
1 :8 0 a19 15
:3 0 9b :3 0 a14
a15 0 9c :3 0
a16 a17 0 a19
57a a6c 9d :3 0
15 :3 0 9b :3 0
a1b a1c 0 9c
:3 0 a1d a1e 0
a20 57d a22 57f
a21 a20 :2 0 a6a
9e :3 0 15 :3 0
9b :3 0 a25 a26
0 9c :3 0 a27
a28 0 a62 65
:3 0 66 :3 0 a2a
a2b 0 65 :3 0
76 :3 0 a2d a2e
0 9f :2 0 2
:4 0 fa :2 0 78
:2 0 27 :2 0 581
a33 a35 :3 0 584
a2f a37 a2c a39
a38 :2 0 68 :3 0
79 :3 0 a3b a3c
0 6a :4 0 fb
:4 0 6d :2 0 6e
:3 0 588 a40 a42
:3 0 6d :2 0 82
:4 0 58b a44 a46
:3 0 6d :2 0 a2
:4 0 58e a48 a4a
:3 0 6d :2 0 9c
:3 0 591 a4c a4e
:3 0 6d :2 0 a3
:4 0 594 a50 a52
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 597
a55 a59 59b a54
a5b :3 0 59e a3d
a5d :2 0 a5f 5a1
a60 a3a a5f 0
a61 5a3 0 a62
5a5 a65 :3 0 a65
0 a65 a64 a62
a63 :6 0 a67 12
:3 0 5a8 a69 5aa
a68 a67 :2 0 a6a
5ac :2 0 a6c 0
a6c a6b a19 a6a
:6 0 b55 1 :3 0
15 :3 0 9b :3 0
a6e a6f 0 15
:3 0 8f :2 0 d9
:3 0 a71 a73 0
5b1 a72 a75 :3 0
a76 :2 0 3d :3 0
3e :3 0 fc :3 0
bd :3 0 17 :4 0
fd 1 :8 0 a83
15 :3 0 9b :3 0
a7e a7f 0 9c
:3 0 a80 a81 0
a83 5b4 ad6 9d
:3 0 15 :3 0 9b
:3 0 a85 a86 0
9c :3 0 a87 a88
0 a8a 5b7 a8c
5b9 a8b a8a :2 0
ad4 9e :3 0 15
:3 0 9b :3 0 a8f
a90 0 9c :3 0
a91 a92 0 acc
65 :3 0 66 :3 0
a94 a95 0 65
:3 0 76 :3 0 a97
a98 0 9f :2 0
2 :4 0 fe :2 0
78 :2 0 27 :2 0
5bb a9d a9f :3 0
5be a99 aa1 a96
aa3 aa2 :2 0 68
:3 0 79 :3 0 aa5
aa6 0 6a :4 0
ff :4 0 6d :2 0
6e :3 0 5c2 aaa
aac :3 0 6d :2 0
82 :4 0 5c5 aae
ab0 :3 0 6d :2 0
a2 :4 0 5c8 ab2
ab4 :3 0 6d :2 0
9c :3 0 5cb ab6
ab8 :3 0 6d :2 0
a3 :4 0 5ce aba
abc :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
5d1 abf ac3 5d5
abe ac5 :3 0 5d8
aa7 ac7 :2 0 ac9
5db aca aa4 ac9
0 acb 5dd 0
acc 5df acf :3 0
acf 0 acf ace
acc acd :6 0 ad1
14 :3 0 5e2 ad3
5e4 ad2 ad1 :2 0
ad4 5e6 :2 0 ad6
0 ad6 ad5 a83
ad4 :6 0 b52 1
:3 0 15 :3 0 9b
:3 0 ad8 ad9 0
15 :3 0 8f :2 0
d9 :3 0 adb add
0 5eb adc adf
:3 0 ae0 :2 0 65
:3 0 66 :3 0 ae2
ae3 0 65 :3 0
76 :3 0 ae5 ae6
0 18 :2 0 2
:4 0 100 :2 0 78
:2 0 27 :2 0 5ee
aeb aed :3 0 5f1
ae7 aef ae4 af1
af0 :2 0 68 :3 0
79 :3 0 af3 af4
0 6a :4 0 101
:4 0 6d :2 0 6e
:3 0 5f5 af8 afa
:3 0 6d :2 0 82
:4 0 5f8 afc afe
:3 0 6d :2 0 83
:4 0 5fb b00 b02
:3 0 6d :2 0 72
:3 0 73 :3 0 84
:3 0 93 :3 0 b07
b08 0 5fe b06
b0a 74 :4 0 600
b05 b0d 603 b04
b0f :3 0 6d :2 0
e5 :4 0 606 b11
b13 :3 0 6d :2 0
70 :4 0 609 b15
b17 :3 0 6d :2 0
17 :3 0 60c b19
b1b :3 0 6d :2 0
70 :4 0 60f b1d
b1f :3 0 612 af5
b21 :2 0 b23 615
b24 af2 b23 0
b25 617 0 b4f
65 :3 0 66 :3 0
b26 b27 0 65
:3 0 76 :3 0 b29
b2a 0 27 :2 0
2 :4 0 102 :2 0
78 :2 0 27 :2 0
619 b2f b31 :3 0
61c b2b b33 b28
b35 b34 :2 0 68
:3 0 79 :3 0 b37
b38 0 6a :4 0
103 :4 0 6d :2 0
6e :3 0 620 b3c
b3e :3 0 623 b39
b40 :2 0 b42 626
b43 b36 b42 0
b44 628 0 b4f
88 :3 0 e8 :3 0
b45 b46 0 84
:3 0 93 :3 0 b48
b49 0 17 :3 0
8a :3 0 62a b47
b4d :2 0 b4f 62e
b50 ae1 b4f 0
b51 632 0 b52
634 b53 a77 b52
0 b54 637 0
b55 639 b57 62a
a07 0 b58 0
b55 0 b58 63c
0 3255 72 :3 0
5c :3 0 30 :2 0
63f b59 b5c 84
:3 0 8f :2 0 104
:3 0 b5e b60 0
644 b5f b62 :3 0
72 :3 0 5c :3 0
30 :2 0 647 b64
b67 84 :3 0 8f
:2 0 105 :3 0 b69
b6b 0 64c b6a
b6d :3 0 b63 b6f
b6e :2 0 b70 :2 0
72 :3 0 32 :3 0
30 :2 0 64f b72
b75 b2 :2 0 30
:2 0 654 b77 b79
:3 0 b7a :2 0 b71
b7c b7b :2 0 72
:3 0 3a :3 0 30
:2 0 657 b7e b81
84 :3 0 b7 :2 0
106 :3 0 b83 b85
0 65c b84 b87
:3 0 72 :3 0 3a
:3 0 30 :2 0 65f
b89 b8c 84 :3 0
b7 :2 0 107 :3 0
b8e b90 0 664
b8f b92 :3 0 b88
b94 b93 :2 0 3a
:3 0 108 :2 0 b96
b97 0 b99 667
b9a b95 b99 0
b9b 669 0 ba2
62 :3 0 27 :2 0
b9c b9d 0 ba2
35 :3 0 30 :2 0
b9f ba0 0 ba2
66b d53 62 :3 0
8f :2 0 30 :2 0
671 ba4 ba6 :3 0
21 :3 0 5 :3 0
ba8 ba9 0 cd2
22 :3 0 6 :3 0
bab bac 0 cd2
5d :3 0 109 :3 0
21 :3 0 22 :3 0
72 :3 0 38 :3 0
30 :2 0 674 bb2
bb5 72 :3 0 39
:3 0 30 :2 0 677
bb7 bba 72 :3 0
3a :3 0 30 :2 0
67a bbc bbf 72
:3 0 31 :3 0 30
:2 0 67d bc1 bc4
72 :3 0 3b :3 0
30 :2 0 680 bc6
bc9 72 :3 0 36
:3 0 30 :2 0 683
bcb bce 72 :3 0
3d :3 0 30 :2 0
686 bd0 bd3 72
:3 0 3e :3 0 30
:2 0 689 bd5 bd8
35 :3 0 37 :3 0
41 :3 0 68c baf
bdd bae bde 0
cd2 72 :3 0 5d
:3 0 30 :2 0 69a
be0 be3 84 :3 0
8f :2 0 93 :3 0
be5 be7 0 69f
be6 be9 :3 0 65
:3 0 66 :3 0 beb
bec 0 65 :3 0
76 :3 0 bee bef
0 7f :2 0 2
:4 0 10a :2 0 78
:2 0 27 :2 0 6a2
bf4 bf6 :3 0 6a5
bf0 bf8 bed bfa
bf9 :2 0 68 :3 0
79 :3 0 bfc bfd
0 6a :4 0 10b
:4 0 6d :2 0 6e
:3 0 6a9 c01 c03
:3 0 6d :2 0 82
:4 0 6ac c05 c07
:3 0 6d :2 0 83
:4 0 6af c09 c0b
:3 0 6d :2 0 72
:3 0 73 :3 0 84
:3 0 93 :3 0 c10
c11 0 6b2 c0f
c13 74 :4 0 6b4
c0e c16 6b7 c0d
c18 :3 0 6ba bfe
c1a :2 0 c1c 6bd
c1d bfb c1c 0
c1e 6bf 0 c48
65 :3 0 66 :3 0
c1f c20 0 65
:3 0 76 :3 0 c22
c23 0 27 :2 0
2 :4 0 10c :2 0
78 :2 0 27 :2 0
6c1 c28 c2a :3 0
6c4 c24 c2c c21
c2e c2d :2 0 68
:3 0 79 :3 0 c30
c31 0 6a :4 0
10d :4 0 6d :2 0
6e :3 0 6c8 c35
c37 :3 0 6cb c32
c39 :2 0 c3b 6ce
c3c c2f c3b 0
c3d 6d0 0 c48
88 :3 0 89 :3 0
c3e c3f 0 84
:3 0 93 :3 0 c41
c42 0 8a :3 0
6d2 c40 c45 :2 0
c48 ae :3 0 6d5
cc1 72 :3 0 5d
:3 0 30 :2 0 6d9
c49 c4c b7 :2 0
30 :2 0 6de c4e
c50 :3 0 65 :3 0
66 :3 0 c52 c53
0 65 :3 0 76
:3 0 c55 c56 0
18 :2 0 2 :4 0
10e :2 0 78 :2 0
27 :2 0 6e1 c5b
c5d :3 0 6e4 c57
c5f c54 c61 c60
:2 0 68 :3 0 79
:3 0 c63 c64 0
6a :4 0 10f :4 0
6d :2 0 6e :3 0
6e8 c68 c6a :3 0
6d :2 0 82 :4 0
6eb c6c c6e :3 0
6d :2 0 83 :4 0
6ee c70 c72 :3 0
6d :2 0 72 :3 0
73 :3 0 5d :3 0
6f1 c76 c78 74
:4 0 6f3 c75 c7b
6f6 c74 c7d :3 0
6d :2 0 e5 :4 0
6f9 c7f c81 :3 0
6d :2 0 70 :4 0
6fc c83 c85 :3 0
6d :2 0 17 :3 0
6ff c87 c89 :3 0
6d :2 0 70 :4 0
702 c8b c8d :3 0
705 c65 c8f :2 0
c91 708 c92 c62
c91 0 c93 70a
0 cbf 65 :3 0
66 :3 0 c94 c95
0 65 :3 0 76
:3 0 c97 c98 0
27 :2 0 2 :4 0
110 :2 0 78 :2 0
27 :2 0 70c c9d
c9f :3 0 70f c99
ca1 c96 ca3 ca2
:2 0 68 :3 0 79
:3 0 ca5 ca6 0
6a :4 0 111 :4 0
6d :2 0 6e :3 0
713 caa cac :3 0
716 ca7 cae :2 0
cb0 719 cb1 ca4
cb0 0 cb2 71b
0 cbf 88 :3 0
e8 :3 0 cb3 cb4
0 72 :3 0 5d
:3 0 30 :2 0 71d
cb6 cb9 17 :3 0
8a :3 0 720 cb5
cbd :2 0 cbf 724
cc0 c51 cbf 0
cc2 bea c48 0
cc2 728 0 cd2
22 :3 0 22 :3 0
cc3 cc4 0 cd2
22 :3 0 7e :2 0
72b cc7 cc8 :3 0
cc9 :2 0 22 :3 0
7b :4 0 ccb ccc
0 cce 72d ccf
cca cce 0 cd0
72f 0 cd2 ae
:3 0 731 d50 72
:3 0 35 :3 0 30
:2 0 738 cd3 cd6
b2 :2 0 30 :2 0
73d cd8 cda :3 0
cdb :2 0 72 :3 0
39 :3 0 30 :2 0
740 cdd ce0 b7
:2 0 112 :2 0 745
ce2 ce4 :3 0 ce5
:2 0 cdc ce7 ce6
:2 0 72 :3 0 39
:3 0 30 :2 0 748
ce9 cec 8f :2 0
27 :2 0 74d cee
cf0 :3 0 cf1 :2 0
72 :3 0 39 :3 0
30 :2 0 750 cf3
cf6 8f :2 0 113
:2 0 755 cf8 cfa
:3 0 cfb :2 0 cf2
cfd cfc :2 0 38
:3 0 113 :2 0 cff
d00 0 d03 ae
:3 0 758 d4c 72
:3 0 39 :3 0 30
:2 0 75a d04 d07
8f :2 0 30 :2 0
75f d09 d0b :3 0
38 :3 0 27 :2 0
d0d d0e 0 d11
ae :3 0 762 d12
d0c d11 0 d4d
72 :3 0 39 :3 0
30 :2 0 764 d13
d16 8f :2 0 114
:2 0 769 d18 d1a
:3 0 d1b :2 0 72
:3 0 39 :3 0 30
:2 0 76c d1d d20
8f :2 0 115 :2 0
771 d22 d24 :3 0
d25 :2 0 d1c d27
d26 :2 0 38 :3 0
27 :2 0 d29 d2a
0 d2d ae :3 0
774 d2e d28 d2d
0 d4d 72 :3 0
39 :3 0 30 :2 0
776 d2f d32 8f
:2 0 90 :2 0 77b
d34 d36 :3 0 35
:3 0 72 :3 0 3e
:3 0 30 :2 0 77e
d39 d3c 116 :2 0
72 :3 0 35 :3 0
30 :2 0 781 d3f
d42 784 d3e d44
:3 0 d38 d45 0
d4a 38 :3 0 114
:2 0 d47 d48 0
d4a 787 d4b d37
d4a 0 d4d cfe
d03 0 d4d 78a
0 d4e 78f d4f
ce8 d4e 0 d51
ba7 cd2 0 d51
791 0 d52 794
d54 b7d ba2 0
d55 0 d52 0
d55 796 0 3255
58 :3 0 117 :4 0
d57 d58 :3 0 d56
d59 0 3255 2b
:3 0 7b :4 0 d5b
d5c 0 3255 2c
:3 0 7b :4 0 d5e
d5f 0 3255 34
:3 0 118 :3 0 119
:3 0 d62 d63 0
11a :3 0 72 :3 0
3a :3 0 30 :2 0
799 d66 d69 84
:3 0 11b :3 0 d6b
d6c 0 79c d65
d6e d6f :2 0 11c
:2 0 79f d64 d72
d61 d73 0 3255
3a :3 0 11a :3 0
72 :3 0 3a :3 0
30 :2 0 7a2 d77
d7a 84 :3 0 11d
:3 0 d7c d7d 0
7a5 d76 d7f d75
d80 0 3255 72
:3 0 32 :3 0 30
:2 0 7a8 d82 d85
b2 :2 0 30 :2 0
7ad d87 d89 :3 0
58 :3 0 11e :3 0
59 :3 0 32 :3 0
1a :3 0 1d :3 0
1c :3 0 28 :3 0
7b0 d8c d93 d8b
d94 0 1d3c 72
:3 0 31 :3 0 30
:2 0 7b7 d96 d99
84 :3 0 8f :2 0
11f :3 0 d9b d9d
0 7bc d9c d9f
:3 0 72 :3 0 58
:3 0 30 :2 0 7bf
da1 da4 8f :2 0
27 :2 0 7c4 da6
da8 :3 0 58 :3 0
84 :3 0 120 :3 0
dab dac 0 daa
dad 0 daf 7c7
db0 da9 daf 0
db1 7c9 0 e1f
65 :3 0 66 :3 0
db2 db3 0 65
:3 0 76 :3 0 db5
db6 0 18 :2 0
2 :4 0 121 :2 0
78 :2 0 27 :2 0
7cb dbb dbd :3 0
7ce db7 dbf db4
dc1 dc0 :2 0 68
:3 0 79 :3 0 dc3
dc4 0 6a :4 0
122 :4 0 6d :2 0
6e :3 0 7d2 dc8
dca :3 0 6d :2 0
82 :4 0 7d5 dcc
dce :3 0 6d :2 0
83 :4 0 7d8 dd0
dd2 :3 0 6d :2 0
72 :3 0 73 :3 0
58 :3 0 7db dd6
dd8 74 :4 0 7dd
dd5 ddb 7e0 dd4
ddd :3 0 6d :2 0
e5 :4 0 7e3 ddf
de1 :3 0 6d :2 0
70 :4 0 7e6 de3
de5 :3 0 6d :2 0
28 :3 0 7e9 de7
de9 :3 0 6d :2 0
70 :4 0 7ec deb
ded :3 0 7ef dc5
def :2 0 df1 7f2
df2 dc2 df1 0
df3 7f4 0 e1f
65 :3 0 66 :3 0
df4 df5 0 65
:3 0 76 :3 0 df7
df8 0 27 :2 0
2 :4 0 123 :2 0
78 :2 0 27 :2 0
7f6 dfd dff :3 0
7f9 df9 e01 df6
e03 e02 :2 0 68
:3 0 79 :3 0 e05
e06 0 6a :4 0
124 :4 0 6d :2 0
6e :3 0 7fd e0a
e0c :3 0 800 e07
e0e :2 0 e10 803
e11 e04 e10 0
e12 805 0 e1f
88 :3 0 e8 :3 0
e13 e14 0 72
:3 0 58 :3 0 30
:2 0 807 e16 e19
28 :3 0 8a :3 0
80a e15 e1d :2 0
e1f 80e e20 da0
e1f 0 e21 813
0 1d3c 72 :3 0
58 :3 0 30 :2 0
815 e22 e25 b7
:2 0 30 :2 0 81a
e27 e29 :3 0 72
:3 0 58 :3 0 30
:2 0 81d e2b e2e
b7 :2 0 27 :2 0
822 e30 e32 :3 0
e2a e34 e33 :2 0
65 :3 0 66 :3 0
e36 e37 0 65
:3 0 76 :3 0 e39
e3a 0 18 :2 0
2 :4 0 a6 :2 0
78 :2 0 27 :2 0
825 e3f e41 :3 0
828 e3b e43 e38
e45 e44 :2 0 68
:3 0 79 :3 0 e47
e48 0 6a :4 0
125 :4 0 6d :2 0
6e :3 0 82c e4c
e4e :3 0 6d :2 0
82 :4 0 82f e50
e52 :3 0 6d :2 0
83 :4 0 832 e54
e56 :3 0 6d :2 0
72 :3 0 73 :3 0
58 :3 0 835 e5a
e5c 74 :4 0 837
e59 e5f 83a e58
e61 :3 0 6d :2 0
e5 :4 0 83d e63
e65 :3 0 6d :2 0
70 :4 0 840 e67
e69 :3 0 6d :2 0
28 :3 0 843 e6b
e6d :3 0 6d :2 0
70 :4 0 846 e6f
e71 :3 0 849 e49
e73 :2 0 e75 84c
e76 e46 e75 0
e77 84e 0 ea3
65 :3 0 66 :3 0
e78 e79 0 65
:3 0 76 :3 0 e7b
e7c 0 27 :2 0
2 :4 0 126 :2 0
78 :2 0 27 :2 0
850 e81 e83 :3 0
853 e7d e85 e7a
e87 e86 :2 0 68
:3 0 79 :3 0 e89
e8a 0 6a :4 0
127 :4 0 6d :2 0
6e :3 0 857 e8e
e90 :3 0 85a e8b
e92 :2 0 e94 85d
e95 e88 e94 0
e96 85f 0 ea3
88 :3 0 e8 :3 0
e97 e98 0 72
:3 0 58 :3 0 30
:2 0 861 e9a e9d
28 :3 0 8a :3 0
864 e99 ea1 :2 0
ea3 868 ea4 e35
ea3 0 ea5 86c
0 1d3c 21 :4 0
ea6 ea7 0 1d3c
128 :3 0 129 :3 0
97 :3 0 98 :3 0
1f :3 0 97 :3 0
98 :3 0 128 :3 0
129 :3 0 21 :3 0
44 :3 0 12a :3 0
b8 :3 0 17 :3 0
12b :3 0 17 :3 0
12c :3 0 1d :3 0
12d :3 0 26 :4 0
12e 1 :8 0 ec3
15 :3 0 9b :3 0
ebe ebf 0 9c
:3 0 ec0 ec1 0
ec3 86e f16 9d
:3 0 15 :3 0 9b
:3 0 ec5 ec6 0
9c :3 0 ec7 ec8
0 eca 871 ecc
873 ecb eca :2 0
f14 9e :3 0 15
:3 0 9b :3 0 ecf
ed0 0 9c :3 0
ed1 ed2 0 f0c
65 :3 0 66 :3 0
ed4 ed5 0 65
:3 0 76 :3 0 ed7
ed8 0 9f :2 0
2 :4 0 12f :2 0
78 :2 0 27 :2 0
875 edd edf :3 0
878 ed9 ee1 ed6
ee3 ee2 :2 0 68
:3 0 79 :3 0 ee5
ee6 0 6a :4 0
130 :4 0 6d :2 0
6e :3 0 87c eea
eec :3 0 6d :2 0
82 :4 0 87f eee
ef0 :3 0 6d :2 0
a2 :4 0 882 ef2
ef4 :3 0 6d :2 0
9c :3 0 885 ef6
ef8 :3 0 6d :2 0
a3 :4 0 888 efa
efc :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
88b eff f03 88f
efe f05 :3 0 892
ee7 f07 :2 0 f09
895 f0a ee4 f09
0 f0b 897 0
f0c 899 f0f :3 0
f0f 0 f0f f0e
f0c f0d :6 0 f11
16 :3 0 89c f13
89e f12 f11 :2 0
f14 8a0 :2 0 f16
0 f16 f15 ec3
f14 :6 0 1d3c 1
:3 0 15 :3 0 9b
:3 0 f18 f19 0
15 :3 0 8f :2 0
a7 :3 0 f1b f1d
0 8a5 f1c f1f
:3 0 f20 :2 0 21
:3 0 96 :2 0 8a8
f23 f24 :3 0 f25
:2 0 f26 :2 0 f21
f28 f27 :2 0 46
:3 0 27 :2 0 f2a
f2b 0 f3c 72
:3 0 44 :3 0 30
:2 0 8aa f2d f30
a8 :2 0 30 :2 0
8af f32 f34 :3 0
1f :3 0 21 :3 0
f36 f37 0 f39
8b2 f3a f35 f39
0 f3b 8b4 0
f3c 8b6 f3d f29
f3c 0 f3e 8b9
0 1d3c 33 :3 0
30 :2 0 f3f f40
0 1d3c 44 :3 0
30 :2 0 f42 f43
0 1d3c 62 :3 0
8f :2 0 27 :2 0
8bd f46 f48 :3 0
a4 :3 0 26 :3 0
27 :2 0 27 :2 0
8c0 f4a f4e 8f
:2 0 30 :4 0 8c6
f50 f52 :3 0 131
:3 0 132 :3 0 133
:3 0 a4 :3 0 1f
:3 0 133 :3 0 a4
:3 0 132 :3 0 133
:3 0 a4 :3 0 134
:3 0 133 :3 0 a4
:3 0 22 :3 0 133
:3 0 a4 :3 0 132
:3 0 133 :3 0 a4
:3 0 134 :3 0 135
:3 0 37 :3 0 135
:3 0 19 :3 0 21
:3 0 44 :3 0 47
:3 0 12a :3 0 12b
:3 0 17 :3 0 12c
:3 0 1d :3 0 12d
:3 0 136 :4 0 137
1 :8 0 f7c 15
:3 0 9b :3 0 f77
f78 0 9c :3 0
f79 f7a 0 f7c
8c9 fcf 9d :3 0
15 :3 0 9b :3 0
f7e f7f 0 9c
:3 0 f80 f81 0
f83 8cc f85 8ce
f84 f83 :2 0 fcd
9e :3 0 15 :3 0
9b :3 0 f88 f89
0 9c :3 0 f8a
f8b 0 fc5 65
:3 0 66 :3 0 f8d
f8e 0 65 :3 0
76 :3 0 f90 f91
0 9f :2 0 2
:4 0 138 :2 0 78
:2 0 27 :2 0 8d0
f96 f98 :3 0 8d3
f92 f9a f8f f9c
f9b :2 0 68 :3 0
79 :3 0 f9e f9f
0 6a :4 0 139
:4 0 6d :2 0 6e
:3 0 8d7 fa3 fa5
:3 0 6d :2 0 82
:4 0 8da fa7 fa9
:3 0 6d :2 0 a2
:4 0 8dd fab fad
:3 0 6d :2 0 9c
:3 0 8e0 faf fb1
:3 0 6d :2 0 a3
:4 0 8e3 fb3 fb5
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 8e6
fb8 fbc 8ea fb7
fbe :3 0 8ed fa0
fc0 :2 0 fc2 8f0
fc3 f9d fc2 0
fc4 8f2 0 fc5
8f4 fc8 :3 0 fc8
0 fc8 fc7 fc5
fc6 :6 0 fca 18
:3 0 8f7 fcc 8f9
fcb fca :2 0 fcd
8fb :2 0 fcf 0
fcf fce f7c fcd
:6 0 110e 1 :3 0
15 :3 0 9b :3 0
fd1 fd2 0 15
:3 0 8f :2 0 a7
:3 0 fd4 fd6 0
900 fd5 fd8 :3 0
fd9 :2 0 46 :3 0
27 :2 0 fdb fdc
0 1078 72 :3 0
47 :3 0 30 :2 0
903 fde fe1 8f
:2 0 30 :2 0 908
fe3 fe5 :3 0 fe6
:2 0 72 :3 0 44
:3 0 30 :2 0 90b
fe8 feb 8f :2 0
27 :2 0 910 fed
fef :3 0 ff0 :2 0
fe7 ff2 ff1 :2 0
131 :3 0 13a :3 0
133 :3 0 a4 :3 0
1f :3 0 133 :3 0
a4 :3 0 13a :3 0
133 :3 0 a4 :3 0
13b :3 0 133 :3 0
a4 :3 0 22 :3 0
133 :3 0 a4 :3 0
13a :3 0 133 :3 0
a4 :3 0 13b :3 0
13c :3 0 37 :3 0
19 :3 0 21 :3 0
44 :3 0 12a :3 0
12b :3 0 17 :3 0
12c :3 0 1d :3 0
12d :3 0 136 :4 0
13d 1 :8 0 101a
15 :3 0 9b :3 0
1015 1016 0 9c
:3 0 1017 1018 0
101a 913 106d 9d
:3 0 15 :3 0 9b
:3 0 101c 101d 0
9c :3 0 101e 101f
0 1021 916 1023
918 1022 1021 :2 0
106b 9e :3 0 15
:3 0 9b :3 0 1026
1027 0 9c :3 0
1028 1029 0 1063
65 :3 0 66 :3 0
102b 102c 0 65
:3 0 76 :3 0 102e
102f 0 9f :2 0
2 :4 0 13e :2 0
78 :2 0 27 :2 0
91a 1034 1036 :3 0
91d 1030 1038 102d
103a 1039 :2 0 68
:3 0 79 :3 0 103c
103d 0 6a :4 0
13f :4 0 6d :2 0
6e :3 0 921 1041
1043 :3 0 6d :2 0
82 :4 0 924 1045
1047 :3 0 6d :2 0
a2 :4 0 927 1049
104b :3 0 6d :2 0
9c :3 0 92a 104d
104f :3 0 6d :2 0
a3 :4 0 92d 1051
1053 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
930 1056 105a 934
1055 105c :3 0 937
103e 105e :2 0 1060
93a 1061 103b 1060
0 1062 93c 0
1063 93e 1066 :3 0
1066 0 1066 1065
1063 1064 :6 0 1068
1a :3 0 941 106a
943 1069 1068 :2 0
106b 945 :2 0 106d
0 106d 106c 101a
106b :6 0 106f 1
:3 0 948 1074 33
:3 0 113 :2 0 1070
1071 0 1073 94a
1075 ff3 106f 0
1076 0 1073 0
1076 94c 0 1078
ae :3 0 94f 110c
15 :3 0 9b :3 0
1079 107a 0 15
:3 0 8f :2 0 d9
:3 0 107c 107e 0
954 107d 1080 :3 0
1081 :2 0 72 :3 0
44 :3 0 30 :2 0
957 1083 1086 8f
:2 0 27 :2 0 95c
1088 108a :3 0 108b
:2 0 1082 108d 108c
:2 0 131 :3 0 13a
:3 0 133 :3 0 a4
:3 0 1f :3 0 133
:3 0 a4 :3 0 13a
:3 0 133 :3 0 a4
:3 0 13b :3 0 133
:3 0 a4 :3 0 22
:3 0 133 :3 0 a4
:3 0 13a :3 0 133
:3 0 a4 :3 0 13b
:3 0 13c :3 0 37
:3 0 19 :3 0 21
:3 0 44 :3 0 12a
:3 0 12b :3 0 17
:3 0 12c :3 0 1d
:3 0 12d :3 0 136
:4 0 140 1 :8 0
10b5 15 :3 0 9b
:3 0 10b0 10b1 0
9c :3 0 10b2 10b3
0 10b5 95f 1108
9d :3 0 15 :3 0
9b :3 0 10b7 10b8
0 9c :3 0 10b9
10ba 0 10bc 962
10be 964 10bd 10bc
:2 0 1106 9e :3 0
15 :3 0 9b :3 0
10c1 10c2 0 9c
:3 0 10c3 10c4 0
10fe 65 :3 0 66
:3 0 10c6 10c7 0
65 :3 0 76 :3 0
10c9 10ca 0 9f
:2 0 2 :4 0 141
:2 0 78 :2 0 27
:2 0 966 10cf 10d1
:3 0 969 10cb 10d3
10c8 10d5 10d4 :2 0
68 :3 0 79 :3 0
10d7 10d8 0 6a
:4 0 142 :4 0 6d
:2 0 6e :3 0 96d
10dc 10de :3 0 6d
:2 0 82 :4 0 970
10e0 10e2 :3 0 6d
:2 0 a2 :4 0 973
10e4 10e6 :3 0 6d
:2 0 9c :3 0 976
10e8 10ea :3 0 6d
:2 0 a3 :4 0 979
10ec 10ee :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 97c 10f1 10f5
980 10f0 10f7 :3 0
983 10d9 10f9 :2 0
10fb 986 10fc 10d6
10fb 0 10fd 988
0 10fe 98a 1101
:3 0 1101 0 1101
1100 10fe 10ff :6 0
1103 1c :3 0 98d
1105 98f 1104 1103
:2 0 1106 991 :2 0
1108 0 1108 1107
10b5 1106 :6 0 110a
1 :3 0 994 110b
108e 110a 0 110d
fda 1078 0 110d
996 0 110e 999
118b 131 :3 0 13a
:3 0 133 :3 0 a4
:3 0 1f :3 0 133
:3 0 a4 :3 0 13a
:3 0 133 :3 0 a4
:3 0 13b :3 0 133
:3 0 a4 :3 0 22
:3 0 133 :3 0 a4
:3 0 13a :3 0 133
:3 0 a4 :3 0 13b
:3 0 13c :3 0 37
:3 0 19 :3 0 21
:3 0 44 :3 0 12a
:3 0 12b :3 0 17
:3 0 12c :3 0 1d
:3 0 12d :3 0 136
:4 0 143 1 :8 0
1135 15 :3 0 9b
:3 0 1130 1131 0
9c :3 0 1132 1133
0 1135 99c 1188
9d :3 0 15 :3 0
9b :3 0 1137 1138
0 9c :3 0 1139
113a 0 113c 99f
113e 9a1 113d 113c
:2 0 1186 9e :3 0
15 :3 0 9b :3 0
1141 1142 0 9c
:3 0 1143 1144 0
117e 65 :3 0 66
:3 0 1146 1147 0
65 :3 0 76 :3 0
1149 114a 0 9f
:2 0 2 :4 0 144
:2 0 78 :2 0 27
:2 0 9a3 114f 1151
:3 0 9a6 114b 1153
1148 1155 1154 :2 0
68 :3 0 79 :3 0
1157 1158 0 6a
:4 0 145 :4 0 6d
:2 0 6e :3 0 9aa
115c 115e :3 0 6d
:2 0 82 :4 0 9ad
1160 1162 :3 0 6d
:2 0 a2 :4 0 9b0
1164 1166 :3 0 6d
:2 0 9c :3 0 9b3
1168 116a :3 0 6d
:2 0 a3 :4 0 9b6
116c 116e :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 9b9 1171 1175
9bd 1170 1177 :3 0
9c0 1159 1179 :2 0
117b 9c3 117c 1156
117b 0 117d 9c5
0 117e 9c7 1181
:3 0 1181 0 1181
1180 117e 117f :6 0
1183 1e :3 0 9ca
1185 9cc 1184 1183
:2 0 1186 9ce :2 0
1188 0 1188 1187
1135 1186 :6 0 118a
1 :3 0 9d1 118c
f53 110e 0 118d
0 118a 0 118d
9d3 0 118e 9d6
13a2 a4 :3 0 26
:3 0 27 :2 0 27
:2 0 9d8 118f 1193
8f :2 0 30 :4 0
9de 1195 1197 :3 0
131 :3 0 132 :3 0
133 :3 0 a4 :3 0
1f :3 0 133 :3 0
a4 :3 0 132 :3 0
133 :3 0 a4 :3 0
134 :3 0 37 :3 0
135 :3 0 135 :3 0
19 :3 0 21 :3 0
44 :3 0 47 :3 0
12a :3 0 12b :3 0
17 :3 0 12c :3 0
1d :3 0 12d :3 0
136 :4 0 146 1
:8 0 11b8 15 :3 0
9b :3 0 11b3 11b4
0 9c :3 0 11b5
11b6 0 11b8 9e1
120b 9d :3 0 15
:3 0 9b :3 0 11ba
11bb 0 9c :3 0
11bc 11bd 0 11bf
9e4 11c1 9e6 11c0
11bf :2 0 1209 9e
:3 0 15 :3 0 9b
:3 0 11c4 11c5 0
9c :3 0 11c6 11c7
0 1201 65 :3 0
66 :3 0 11c9 11ca
0 65 :3 0 76
:3 0 11cc 11cd 0
9f :2 0 2 :4 0
147 :2 0 78 :2 0
27 :2 0 9e8 11d2
11d4 :3 0 9eb 11ce
11d6 11cb 11d8 11d7
:2 0 68 :3 0 79
:3 0 11da 11db 0
6a :4 0 148 :4 0
6d :2 0 6e :3 0
9ef 11df 11e1 :3 0
6d :2 0 82 :4 0
9f2 11e3 11e5 :3 0
6d :2 0 a2 :4 0
9f5 11e7 11e9 :3 0
6d :2 0 9c :3 0
9f8 11eb 11ed :3 0
6d :2 0 a3 :4 0
9fb 11ef 11f1 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 9fe 11f4
11f8 a02 11f3 11fa
:3 0 a05 11dc 11fc
:2 0 11fe a08 11ff
11d9 11fe 0 1200
a0a 0 1201 a0c
1204 :3 0 1204 0
1204 1203 1201 1202
:6 0 1206 20 :3 0
a0f 1208 a11 1207
1206 :2 0 1209 a13
:2 0 120b 0 120b
120a 11b8 1209 :6 0
132a 1 :3 0 15
:3 0 9b :3 0 120d
120e 0 15 :3 0
8f :2 0 a7 :3 0
1210 1212 0 a18
1211 1214 :3 0 1215
:2 0 46 :3 0 27
:2 0 1217 1218 0
12a9 72 :3 0 47
:3 0 30 :2 0 a1b
121a 121d 8f :2 0
30 :2 0 a20 121f
1221 :3 0 1222 :2 0
72 :3 0 44 :3 0
30 :2 0 a23 1224
1227 8f :2 0 27
:2 0 a28 1229 122b
:3 0 122c :2 0 1223
122e 122d :2 0 131
:3 0 13a :3 0 133
:3 0 a4 :3 0 1f
:3 0 133 :3 0 a4
:3 0 13b :3 0 37
:3 0 13c :3 0 19
:3 0 21 :3 0 44
:3 0 12a :3 0 12b
:3 0 17 :3 0 12c
:3 0 1d :3 0 12d
:3 0 136 :4 0 149
1 :8 0 124a 15
:3 0 9b :3 0 1245
1246 0 9c :3 0
1247 1248 0 124a
a2b 129d 9d :3 0
15 :3 0 9b :3 0
124c 124d 0 9c
:3 0 124e 124f 0
1251 a2e 1253 a30
1252 1251 :2 0 129b
9e :3 0 15 :3 0
9b :3 0 1256 1257
0 9c :3 0 1258
1259 0 1293 65
:3 0 66 :3 0 125b
125c 0 65 :3 0
76 :3 0 125e 125f
0 9f :2 0 2
:4 0 14a :2 0 78
:2 0 27 :2 0 a32
1264 1266 :3 0 a35
1260 1268 125d 126a
1269 :2 0 68 :3 0
79 :3 0 126c 126d
0 6a :4 0 14b
:4 0 6d :2 0 6e
:3 0 a39 1271 1273
:3 0 6d :2 0 82
:4 0 a3c 1275 1277
:3 0 6d :2 0 a2
:4 0 a3f 1279 127b
:3 0 6d :2 0 9c
:3 0 a42 127d 127f
:3 0 6d :2 0 a3
:4 0 a45 1281 1283
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 a48
1286 128a a4c 1285
128c :3 0 a4f 126e
128e :2 0 1290 a52
1291 126b 1290 0
1292 a54 0 1293
a56 1296 :3 0 1296
0 1296 1295 1293
1294 :6 0 1298 22
:3 0 a59 129a a5b
1299 1298 :2 0 129b
a5d :2 0 129d 0
129d 129c 124a 129b
:6 0 129f 1 :3 0
a60 12a5 33 :3 0
113 :2 0 12a0 12a1
0 12a4 0 12a4
a62 12a6 122f 129f
0 12a7 0 12a4
0 12a7 a65 0
12a9 ae :3 0 a68
1328 15 :3 0 9b
:3 0 12aa 12ab 0
15 :3 0 8f :2 0
d9 :3 0 12ad 12af
0 a6d 12ae 12b1
:3 0 12b2 :2 0 131
:3 0 13a :3 0 133
:3 0 a4 :3 0 1f
:3 0 133 :3 0 a4
:3 0 13a :3 0 133
:3 0 a4 :3 0 13b
:3 0 37 :3 0 13c
:3 0 19 :3 0 21
:3 0 44 :3 0 12a
:3 0 12b :3 0 17
:3 0 12c :3 0 1d
:3 0 12d :3 0 136
:4 0 14c 1 :8 0
12d1 15 :3 0 9b
:3 0 12cc 12cd 0
9c :3 0 12ce 12cf
0 12d1 a70 1324
9d :3 0 15 :3 0
9b :3 0 12d3 12d4
0 9c :3 0 12d5
12d6 0 12d8 a73
12da a75 12d9 12d8
:2 0 1322 9e :3 0
15 :3 0 9b :3 0
12dd 12de 0 9c
:3 0 12df 12e0 0
131a 65 :3 0 66
:3 0 12e2 12e3 0
65 :3 0 76 :3 0
12e5 12e6 0 9f
:2 0 2 :4 0 14d
:2 0 78 :2 0 27
:2 0 a77 12eb 12ed
:3 0 a7a 12e7 12ef
12e4 12f1 12f0 :2 0
68 :3 0 79 :3 0
12f3 12f4 0 6a
:4 0 14e :4 0 6d
:2 0 6e :3 0 a7e
12f8 12fa :3 0 6d
:2 0 82 :4 0 a81
12fc 12fe :3 0 6d
:2 0 a2 :4 0 a84
1300 1302 :3 0 6d
:2 0 9c :3 0 a87
1304 1306 :3 0 6d
:2 0 a3 :4 0 a8a
1308 130a :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 a8d 130d 1311
a91 130c 1313 :3 0
a94 12f5 1315 :2 0
1317 a97 1318 12f2
1317 0 1319 a99
0 131a a9b 131d
:3 0 131d 0 131d
131c 131a 131b :6 0
131f 24 :3 0 a9e
1321 aa0 1320 131f
:2 0 1322 aa2 :2 0
1324 0 1324 1323
12d1 1322 :6 0 1326
1 :3 0 aa5 1327
12b3 1326 0 1329
1216 12a9 0 1329
aa7 0 132a aaa
139e 131 :3 0 13a
:3 0 133 :3 0 a4
:3 0 1f :3 0 133
:3 0 a4 :3 0 13a
:3 0 133 :3 0 a4
:3 0 13b :3 0 37
:3 0 13c :3 0 19
:3 0 21 :3 0 44
:3 0 12a :3 0 12b
:3 0 17 :3 0 12c
:3 0 1d :3 0 12d
:3 0 136 :4 0 14f
1 :8 0 1348 15
:3 0 9b :3 0 1343
1344 0 9c :3 0
1345 1346 0 1348
aad 139b 9d :3 0
15 :3 0 9b :3 0
134a 134b 0 9c
:3 0 134c 134d 0
134f ab0 1351 ab2
1350 134f :2 0 1399
9e :3 0 15 :3 0
9b :3 0 1354 1355
0 9c :3 0 1356
1357 0 1391 65
:3 0 66 :3 0 1359
135a 0 65 :3 0
76 :3 0 135c 135d
0 9f :2 0 2
:4 0 150 :2 0 78
:2 0 27 :2 0 ab4
1362 1364 :3 0 ab7
135e 1366 135b 1368
1367 :2 0 68 :3 0
79 :3 0 136a 136b
0 6a :4 0 151
:4 0 6d :2 0 6e
:3 0 abb 136f 1371
:3 0 6d :2 0 82
:4 0 abe 1373 1375
:3 0 6d :2 0 a2
:4 0 ac1 1377 1379
:3 0 6d :2 0 9c
:3 0 ac4 137b 137d
:3 0 6d :2 0 a3
:4 0 ac7 137f 1381
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 aca
1384 1388 ace 1383
138a :3 0 ad1 136c
138c :2 0 138e ad4
138f 1369 138e 0
1390 ad6 0 1391
ad8 1394 :3 0 1394
0 1394 1393 1391
1392 :6 0 1396 26
:3 0 adb 1398 add
1397 1396 :2 0 1399
adf :2 0 139b 0
139b 139a 1348 1399
:6 0 139d 1 :3 0
ae2 139f 1198 132a
0 13a0 0 139d
0 13a0 ae4 0
13a1 ae7 13a3 f49
118e 0 13a4 0
13a1 0 13a4 ae9
0 1d3c 15 :3 0
9b :3 0 13a5 13a6
0 15 :3 0 8f
:2 0 a7 :3 0 13a8
13aa 0 aee 13a9
13ac :3 0 13ad :2 0
72 :3 0 44 :3 0
30 :2 0 af1 13af
13b2 8f :2 0 27
:2 0 af6 13b4 13b6
:3 0 65 :3 0 66
:3 0 13b8 13b9 0
65 :3 0 76 :3 0
13bb 13bc 0 18
:2 0 2 :4 0 152
:2 0 78 :2 0 27
:2 0 af9 13c1 13c3
:3 0 afc 13bd 13c5
13ba 13c7 13c6 :2 0
68 :3 0 79 :3 0
13c9 13ca 0 6a
:4 0 153 :4 0 6d
:2 0 6e :3 0 b00
13ce 13d0 :3 0 6d
:2 0 82 :4 0 b03
13d2 13d4 :3 0 6d
:2 0 83 :4 0 b06
13d6 13d8 :3 0 6d
:2 0 72 :3 0 73
:3 0 84 :3 0 154
:3 0 13dd 13de 0
b09 13dc 13e0 74
:4 0 b0b 13db 13e3
b0e 13da 13e5 :3 0
6d :2 0 e5 :4 0
b11 13e7 13e9 :3 0
6d :2 0 70 :4 0
b14 13eb 13ed :3 0
6d :2 0 1d :3 0
b17 13ef 13f1 :3 0
6d :2 0 70 :4 0
b1a 13f3 13f5 :3 0
b1d 13cb 13f7 :2 0
13f9 b20 13fa 13c8
13f9 0 13fb b22
0 1426 65 :3 0
66 :3 0 13fc 13fd
0 65 :3 0 76
:3 0 13ff 1400 0
27 :2 0 2 :4 0
155 :2 0 78 :2 0
27 :2 0 b24 1405
1407 :3 0 b27 1401
1409 13fe 140b 140a
:2 0 68 :3 0 79
:3 0 140d 140e 0
6a :4 0 156 :4 0
6d :2 0 6e :3 0
b2b 1412 1414 :3 0
b2e 140f 1416 :2 0
1418 b31 1419 140c
1418 0 141a b33
0 1426 88 :3 0
e8 :3 0 141b 141c
0 84 :3 0 154
:3 0 141e 141f 0
1d :3 0 8a :3 0
b35 141d 1423 :2 0
1426 ae :3 0 b39
1597 19 :3 0 96
:2 0 b3d 1428 1429
:3 0 142a :2 0 72
:3 0 37 :3 0 30
:2 0 b3f 142c 142f
b2 :2 0 30 :2 0
b44 1431 1433 :3 0
142b 1435 1434 :2 0
62 :3 0 8f :2 0
27 :2 0 b49 1438
143a :3 0 47 :3 0
30 :2 0 143c 143d
0 14a9 157 :3 0
158 :3 0 47 :3 0
159 :3 0 b8 :3 0
17 :3 0 15a :3 0
19 :3 0 15b :3 0
133 :3 0 a4 :3 0
1f :3 0 133 :3 0
a4 :3 0 22 :4 0
15c 1 :8 0 1454
15 :3 0 9b :3 0
144f 1450 0 9c
:3 0 1451 1452 0
1454 b4c 14a7 9d
:3 0 15 :3 0 9b
:3 0 1456 1457 0
9c :3 0 1458 1459
0 145b b4f 145d
b51 145c 145b :2 0
14a5 9e :3 0 15
:3 0 9b :3 0 1460
1461 0 9c :3 0
1462 1463 0 149d
65 :3 0 66 :3 0
1465 1466 0 65
:3 0 76 :3 0 1468
1469 0 9f :2 0
2 :4 0 15d :2 0
78 :2 0 27 :2 0
b53 146e 1470 :3 0
b56 146a 1472 1467
1474 1473 :2 0 68
:3 0 79 :3 0 1476
1477 0 6a :4 0
15e :4 0 6d :2 0
6e :3 0 b5a 147b
147d :3 0 6d :2 0
82 :4 0 b5d 147f
1481 :3 0 6d :2 0
a2 :4 0 b60 1483
1485 :3 0 6d :2 0
9c :3 0 b63 1487
1489 :3 0 6d :2 0
a3 :4 0 b66 148b
148d :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
b69 1490 1494 b6d
148f 1496 :3 0 b70
1478 1498 :2 0 149a
b73 149b 1475 149a
0 149c b75 0
149d b77 14a0 :3 0
14a0 0 14a0 149f
149d 149e :6 0 14a2
28 :3 0 b7a 14a4
b7c 14a3 14a2 :2 0
14a5 b7e :2 0 14a7
0 14a7 14a6 1454
14a5 :6 0 14a9 1
:3 0 b81 1515 47
:3 0 30 :2 0 14aa
14ab 0 1514 157
:3 0 158 :3 0 47
:3 0 159 :3 0 b8
:3 0 17 :3 0 15a
:3 0 19 :3 0 15b
:3 0 133 :3 0 a4
:3 0 1f :4 0 15f
1 :8 0 14bf 15
:3 0 9b :3 0 14ba
14bb 0 9c :3 0
14bc 14bd 0 14bf
b84 1512 9d :3 0
15 :3 0 9b :3 0
14c1 14c2 0 9c
:3 0 14c3 14c4 0
14c6 b87 14c8 b89
14c7 14c6 :2 0 1510
9e :3 0 15 :3 0
9b :3 0 14cb 14cc
0 9c :3 0 14cd
14ce 0 1508 65
:3 0 66 :3 0 14d0
14d1 0 65 :3 0
76 :3 0 14d3 14d4
0 9f :2 0 2
:4 0 160 :2 0 78
:2 0 27 :2 0 b8b
14d9 14db :3 0 b8e
14d5 14dd 14d2 14df
14de :2 0 68 :3 0
79 :3 0 14e1 14e2
0 6a :4 0 161
:4 0 6d :2 0 6e
:3 0 b92 14e6 14e8
:3 0 6d :2 0 82
:4 0 b95 14ea 14ec
:3 0 6d :2 0 a2
:4 0 b98 14ee 14f0
:3 0 6d :2 0 9c
:3 0 b9b 14f2 14f4
:3 0 6d :2 0 a3
:4 0 b9e 14f6 14f8
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 ba1
14fb 14ff ba5 14fa
1501 :3 0 ba8 14e3
1503 :2 0 1505 bab
1506 14e0 1505 0
1507 bad 0 1508
baf 150b :3 0 150b
0 150b 150a 1508
1509 :6 0 150d 2a
:3 0 bb2 150f bb4
150e 150d :2 0 1510
bb6 :2 0 1512 0
1512 1511 14bf 1510
:6 0 1514 1 :3 0
bb9 1516 143b 14a9
0 1517 0 1514
0 1517 bbc 0
1595 72 :3 0 47
:3 0 30 :2 0 bbf
1518 151b 72 :3 0
a8 :2 0 37 :3 0
30 :2 0 bc2 151d
1521 bc7 151e 1523
:3 0 65 :3 0 66
:3 0 1525 1526 0
65 :3 0 76 :3 0
1528 1529 0 18
:2 0 2 :4 0 162
:2 0 78 :2 0 27
:2 0 bca 152e 1530
:3 0 bcd 152a 1532
1527 1534 1533 :2 0
68 :3 0 79 :3 0
1536 1537 0 6a
:4 0 163 :4 0 6d
:2 0 6e :3 0 bd1
153b 153d :3 0 6d
:2 0 82 :4 0 bd4
153f 1541 :3 0 6d
:2 0 83 :4 0 bd7
1543 1545 :3 0 6d
:2 0 72 :3 0 73
:3 0 84 :3 0 154
:3 0 154a 154b 0
bda 1549 154d 74
:4 0 bdc 1548 1550
bdf 1547 1552 :3 0
6d :2 0 e5 :4 0
be2 1554 1556 :3 0
6d :2 0 70 :4 0
be5 1558 155a :3 0
6d :2 0 1d :3 0
be8 155c 155e :3 0
6d :2 0 70 :4 0
beb 1560 1562 :3 0
bee 1538 1564 :2 0
1566 bf1 1567 1535
1566 0 1568 bf3
0 1592 65 :3 0
66 :3 0 1569 156a
0 65 :3 0 76
:3 0 156c 156d 0
27 :2 0 2 :4 0
164 :2 0 78 :2 0
27 :2 0 bf5 1572
1574 :3 0 bf8 156e
1576 156b 1578 1577
:2 0 68 :3 0 79
:3 0 157a 157b 0
6a :4 0 165 :4 0
6d :2 0 6e :3 0
bfc 157f 1581 :3 0
bff 157c 1583 :2 0
1585 c02 1586 1579
1585 0 1587 c04
0 1592 88 :3 0
e8 :3 0 1588 1589
0 84 :3 0 154
:3 0 158b 158c 0
1d :3 0 8a :3 0
c06 158a 1590 :2 0
1592 c0a 1593 1524
1592 0 1594 c0e
0 1595 c10 1596
1436 1595 0 1598
13b7 1426 0 1598
c13 0 159d 46
:3 0 27 :2 0 1599
159a 0 159d ae
:3 0 c16 1626 72
:3 0 46 :3 0 30
:2 0 c19 159e 15a1
8f :2 0 27 :2 0
c1e 15a3 15a5 :3 0
15a6 :2 0 166 :3 0
72 :3 0 32 :3 0
30 :2 0 c21 15a9
15ac c24 15a8 15ae
15af :2 0 b7 :2 0
30 :2 0 c28 15b1
15b3 :3 0 15a7 15b5
15b4 :2 0 65 :3 0
66 :3 0 15b7 15b8
0 65 :3 0 76
:3 0 15ba 15bb 0
18 :2 0 2 :4 0
167 :2 0 78 :2 0
27 :2 0 c2b 15c0
15c2 :3 0 c2e 15bc
15c4 15b9 15c6 15c5
:2 0 68 :3 0 79
:3 0 15c8 15c9 0
6a :4 0 168 :4 0
6d :2 0 6e :3 0
c32 15cd 15cf :3 0
6d :2 0 82 :4 0
c35 15d1 15d3 :3 0
6d :2 0 83 :4 0
c38 15d5 15d7 :3 0
6d :2 0 72 :3 0
73 :3 0 84 :3 0
154 :3 0 15dc 15dd
0 c3b 15db 15df
74 :4 0 c3d 15da
15e2 c40 15d9 15e4
:3 0 6d :2 0 e5
:4 0 c43 15e6 15e8
:3 0 6d :2 0 70
:4 0 c46 15ea 15ec
:3 0 6d :2 0 1d
:3 0 c49 15ee 15f0
:3 0 6d :2 0 70
:4 0 c4c 15f2 15f4
:3 0 c4f 15ca 15f6
:2 0 15f8 c52 15f9
15c7 15f8 0 15fa
c54 0 1624 65
:3 0 66 :3 0 15fb
15fc 0 65 :3 0
76 :3 0 15fe 15ff
0 27 :2 0 2
:4 0 169 :2 0 78
:2 0 27 :2 0 c56
1604 1606 :3 0 c59
1600 1608 15fd 160a
1609 :2 0 68 :3 0
79 :3 0 160c 160d
0 6a :4 0 16a
:4 0 6d :2 0 6e
:3 0 c5d 1611 1613
:3 0 c60 160e 1615
:2 0 1617 c63 1618
160b 1617 0 1619
c65 0 1624 88
:3 0 e8 :3 0 161a
161b 0 84 :3 0
154 :3 0 161d 161e
0 1d :3 0 8a
:3 0 c67 161c 1622
:2 0 1624 c6b 1625
15b6 1624 0 1627
13ae 159d 0 1627
c6f 0 1d3c a4
:3 0 26 :3 0 27
:2 0 27 :2 0 c72
1628 162c 8f :2 0
30 :4 0 c78 162e
1630 :3 0 2b :3 0
a4 :3 0 2b :3 0
6d :2 0 1d :3 0
c7b 1635 1637 :3 0
27 :2 0 2a :2 0
c7e 1633 163b 1632
163c 0 1827 16b
:3 0 97 :3 0 16c
:3 0 21 :3 0 16d
:3 0 72 :3 0 97
:3 0 16c :3 0 16e
:3 0 72 :3 0 97
:3 0 16c :3 0 16f
:3 0 2d :3 0 48
:3 0 4c :3 0 49
:3 0 4a :3 0 170
:3 0 12c :3 0 1d
:4 0 171 1 :8 0
1659 15 :3 0 9b
:3 0 1654 1655 0
9c :3 0 1656 1657
0 1659 c82 16ac
9d :3 0 15 :3 0
9b :3 0 165b 165c
0 9c :3 0 165d
165e 0 1660 c85
1662 c87 1661 1660
:2 0 16aa 9e :3 0
15 :3 0 9b :3 0
1665 1666 0 9c
:3 0 1667 1668 0
16a2 65 :3 0 66
:3 0 166a 166b 0
65 :3 0 76 :3 0
166d 166e 0 9f
:2 0 2 :4 0 172
:2 0 78 :2 0 27
:2 0 c89 1673 1675
:3 0 c8c 166f 1677
166c 1679 1678 :2 0
68 :3 0 79 :3 0
167b 167c 0 6a
:4 0 173 :4 0 6d
:2 0 6e :3 0 c90
1680 1682 :3 0 6d
:2 0 82 :4 0 c93
1684 1686 :3 0 6d
:2 0 a2 :4 0 c96
1688 168a :3 0 6d
:2 0 9c :3 0 c99
168c 168e :3 0 6d
:2 0 a3 :4 0 c9c
1690 1692 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 c9f 1695 1699
ca3 1694 169b :3 0
ca6 167d 169d :2 0
169f ca9 16a0 167a
169f 0 16a1 cab
0 16a2 cad 16a5
:3 0 16a5 0 16a5
16a4 16a2 16a3 :6 0
16a7 2c :3 0 cb0
16a9 cb2 16a8 16a7
:2 0 16aa cb4 :2 0
16ac 0 16ac 16ab
1659 16aa :6 0 1827
1 :3 0 15 :3 0
9b :3 0 16ae 16af
0 15 :3 0 8f
:2 0 d9 :3 0 16b1
16b3 0 cb9 16b2
16b5 :3 0 16b6 :2 0
65 :3 0 66 :3 0
16b8 16b9 0 65
:3 0 76 :3 0 16bb
16bc 0 18 :2 0
2 :4 0 174 :2 0
78 :2 0 27 :2 0
cbc 16c1 16c3 :3 0
cbf 16bd 16c5 16ba
16c7 16c6 :2 0 68
:3 0 79 :3 0 16c9
16ca 0 6a :4 0
175 :4 0 6d :2 0
6e :3 0 cc3 16ce
16d0 :3 0 6d :2 0
82 :4 0 cc6 16d2
16d4 :3 0 6d :2 0
83 :4 0 cc9 16d6
16d8 :3 0 6d :2 0
72 :3 0 73 :3 0
84 :3 0 e4 :3 0
16dd 16de 0 ccc
16dc 16e0 74 :4 0
cce 16db 16e3 cd1
16da 16e5 :3 0 6d
:2 0 e5 :4 0 cd4
16e7 16e9 :3 0 6d
:2 0 70 :4 0 cd7
16eb 16ed :3 0 6d
:2 0 1d :3 0 cda
16ef 16f1 :3 0 6d
:2 0 70 :4 0 cdd
16f3 16f5 :3 0 ce0
16cb 16f7 :2 0 16f9
ce3 16fa 16c8 16f9
0 16fb ce5 0
1725 65 :3 0 66
:3 0 16fc 16fd 0
65 :3 0 76 :3 0
16ff 1700 0 27
:2 0 2 :4 0 176
:2 0 78 :2 0 27
:2 0 ce7 1705 1707
:3 0 cea 1701 1709
16fe 170b 170a :2 0
68 :3 0 79 :3 0
170d 170e 0 6a
:4 0 177 :4 0 6d
:2 0 6e :3 0 cee
1712 1714 :3 0 cf1
170f 1716 :2 0 1718
cf4 1719 170c 1718
0 171a cf6 0
1725 88 :3 0 e8
:3 0 171b 171c 0
84 :3 0 e4 :3 0
171e 171f 0 1d
:3 0 8a :3 0 cf8
171d 1723 :2 0 1725
cfc 1726 16b7 1725
0 1727 d00 0
1827 a4 :3 0 4c
:3 0 27 :2 0 27
:2 0 d02 1728 172c
8f :2 0 30 :4 0
d08 172e 1730 :3 0
1731 :2 0 72 :3 0
4a :3 0 30 :2 0
d0b 1733 1736 b2
:2 0 30 :2 0 d10
1738 173a :3 0 173b
:2 0 72 :3 0 48
:3 0 30 :2 0 d13
173d 1740 72 :3 0
b2 :2 0 4a :3 0
30 :2 0 d16 1742
1746 d1b 1743 1748
:3 0 1749 :2 0 173c
174b 174a :2 0 174c
:2 0 1732 174e 174d
:2 0 65 :3 0 66
:3 0 1750 1751 0
65 :3 0 76 :3 0
1753 1754 0 18
:2 0 2 :4 0 178
:2 0 78 :2 0 27
:2 0 d1e 1759 175b
:3 0 d21 1755 175d
1752 175f 175e :2 0
68 :3 0 79 :3 0
1761 1762 0 6a
:4 0 179 :4 0 6d
:2 0 6e :3 0 d25
1766 1768 :3 0 6d
:2 0 82 :4 0 d28
176a 176c :3 0 6d
:2 0 83 :4 0 d2b
176e 1770 :3 0 6d
:2 0 72 :3 0 73
:3 0 84 :3 0 17a
:3 0 1775 1776 0
d2e 1774 1778 74
:4 0 d30 1773 177b
d33 1772 177d :3 0
6d :2 0 e5 :4 0
d36 177f 1781 :3 0
6d :2 0 70 :4 0
d39 1783 1785 :3 0
6d :2 0 1d :3 0
d3c 1787 1789 :3 0
6d :2 0 70 :4 0
d3f 178b 178d :3 0
d42 1763 178f :2 0
1791 d45 1792 1760
1791 0 1793 d47
0 17bd 65 :3 0
66 :3 0 1794 1795
0 65 :3 0 76
:3 0 1797 1798 0
27 :2 0 2 :4 0
17b :2 0 78 :2 0
27 :2 0 d49 179d
179f :3 0 d4c 1799
17a1 1796 17a3 17a2
:2 0 68 :3 0 79
:3 0 17a5 17a6 0
6a :4 0 17c :4 0
6d :2 0 6e :3 0
d50 17aa 17ac :3 0
d53 17a7 17ae :2 0
17b0 d56 17b1 17a4
17b0 0 17b2 d58
0 17bd 88 :3 0
e8 :3 0 17b3 17b4
0 84 :3 0 17a
:3 0 17b6 17b7 0
1d :3 0 8a :3 0
d5a 17b5 17bb :2 0
17bd d5e 17be 174f
17bd 0 17bf d62
0 1827 17d :3 0
17e :3 0 17f :3 0
28 :3 0 42 :3 0
1e :3 0 180 :3 0
bd :3 0 1a :3 0
12d :3 0 12c :3 0
1d :4 0 181 1
:8 0 17d2 15 :3 0
9b :3 0 17cd 17ce
0 9c :3 0 17cf
17d0 0 17d2 d64
1825 9d :3 0 15
:3 0 9b :3 0 17d4
17d5 0 9c :3 0
17d6 17d7 0 17d9
d67 17db d69 17da
17d9 :2 0 1823 9e
:3 0 15 :3 0 9b
:3 0 17de 17df 0
9c :3 0 17e0 17e1
0 181b 65 :3 0
66 :3 0 17e3 17e4
0 65 :3 0 76
:3 0 17e6 17e7 0
9f :2 0 2 :4 0
182 :2 0 78 :2 0
27 :2 0 d6b 17ec
17ee :3 0 d6e 17e8
17f0 17e5 17f2 17f1
:2 0 68 :3 0 79
:3 0 17f4 17f5 0
6a :4 0 183 :4 0
6d :2 0 6e :3 0
d72 17f9 17fb :3 0
6d :2 0 82 :4 0
d75 17fd 17ff :3 0
6d :2 0 a2 :4 0
d78 1801 1803 :3 0
6d :2 0 9c :3 0
d7b 1805 1807 :3 0
6d :2 0 a3 :4 0
d7e 1809 180b :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 d81 180e
1812 d85 180d 1814
:3 0 d88 17f6 1816
:2 0 1818 d8b 1819
17f3 1818 0 181a
d8d 0 181b d8f
181e :3 0 181e 0
181e 181d 181b 181c
:6 0 1820 2e :3 0
d92 1822 d94 1821
1820 :2 0 1823 d96
:2 0 1825 0 1825
1824 17d2 1823 :6 0
1827 1 :3 0 d99
1a6b 2c :3 0 a4
:3 0 2c :3 0 6d
:2 0 1d :3 0 d9f
182b 182d :3 0 27
:2 0 2a :2 0 da2
1829 1831 1828 1832
0 1a6a 184 :3 0
2d :3 0 185 :3 0
186 :3 0 1d :4 0
187 1 :8 0 183f
15 :3 0 9b :3 0
183a 183b 0 9c
:3 0 183c 183d 0
183f da6 1892 9d
:3 0 15 :3 0 9b
:3 0 1841 1842 0
9c :3 0 1843 1844
0 1846 da9 1848
dab 1847 1846 :2 0
1890 9e :3 0 15
:3 0 9b :3 0 184b
184c 0 9c :3 0
184d 184e 0 1888
65 :3 0 66 :3 0
1850 1851 0 65
:3 0 76 :3 0 1853
1854 0 9f :2 0
2 :4 0 188 :2 0
78 :2 0 27 :2 0
dad 1859 185b :3 0
db0 1855 185d 1852
185f 185e :2 0 68
:3 0 79 :3 0 1861
1862 0 6a :4 0
189 :4 0 6d :2 0
6e :3 0 db4 1866
1868 :3 0 6d :2 0
82 :4 0 db7 186a
186c :3 0 6d :2 0
a2 :4 0 dba 186e
1870 :3 0 6d :2 0
9c :3 0 dbd 1872
1874 :3 0 6d :2 0
a3 :4 0 dc0 1876
1878 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
dc3 187b 187f dc7
187a 1881 :3 0 dca
1863 1883 :2 0 1885
dcd 1886 1860 1885
0 1887 dcf 0
1888 dd1 188b :3 0
188b 0 188b 188a
1888 1889 :6 0 188d
30 :3 0 dd4 188f
dd6 188e 188d :2 0
1890 dd8 :2 0 1892
0 1892 1891 183f
1890 :6 0 1a6a 1
:3 0 15 :3 0 9b
:3 0 1894 1895 0
15 :3 0 8f :2 0
d9 :3 0 1897 1899
0 ddd 1898 189b
:3 0 189c :2 0 65
:3 0 66 :3 0 189e
189f 0 65 :3 0
76 :3 0 18a1 18a2
0 18 :2 0 2
:4 0 18a :2 0 78
:2 0 27 :2 0 de0
18a7 18a9 :3 0 de3
18a3 18ab 18a0 18ad
18ac :2 0 68 :3 0
79 :3 0 18af 18b0
0 6a :4 0 18b
:4 0 6d :2 0 6e
:3 0 de7 18b4 18b6
:3 0 6d :2 0 82
:4 0 dea 18b8 18ba
:3 0 6d :2 0 83
:4 0 ded 18bc 18be
:3 0 6d :2 0 72
:3 0 73 :3 0 84
:3 0 e4 :3 0 18c3
18c4 0 df0 18c2
18c6 74 :4 0 df2
18c1 18c9 df5 18c0
18cb :3 0 6d :2 0
e5 :4 0 df8 18cd
18cf :3 0 6d :2 0
70 :4 0 dfb 18d1
18d3 :3 0 6d :2 0
1d :3 0 dfe 18d5
18d7 :3 0 6d :2 0
70 :4 0 e01 18d9
18db :3 0 e04 18b1
18dd :2 0 18df e07
18e0 18ae 18df 0
18e1 e09 0 190b
65 :3 0 66 :3 0
18e2 18e3 0 65
:3 0 76 :3 0 18e5
18e6 0 27 :2 0
2 :4 0 18c :2 0
78 :2 0 27 :2 0
e0b 18eb 18ed :3 0
e0e 18e7 18ef 18e4
18f1 18f0 :2 0 68
:3 0 79 :3 0 18f3
18f4 0 6a :4 0
18d :4 0 6d :2 0
6e :3 0 e12 18f8
18fa :3 0 e15 18f5
18fc :2 0 18fe e18
18ff 18f2 18fe 0
1900 e1a 0 190b
88 :3 0 e8 :3 0
1901 1902 0 84
:3 0 e4 :3 0 1904
1905 0 1d :3 0
8a :3 0 e1c 1903
1909 :2 0 190b e20
190c 189d 190b 0
190d e24 0 1a6a
129 :3 0 133 :3 0
a4 :3 0 1f :3 0
133 :3 0 a4 :3 0
129 :3 0 133 :3 0
a4 :3 0 18e :3 0
18f :3 0 37 :3 0
21 :3 0 44 :3 0
12a :3 0 12b :3 0
17 :3 0 12c :3 0
1d :3 0 12d :4 0
190 1 :8 0 1928
15 :3 0 9b :3 0
1923 1924 0 9c
:3 0 1925 1926 0
1928 e26 197b 9d
:3 0 15 :3 0 9b
:3 0 192a 192b 0
9c :3 0 192c 192d
0 192f e29 1931
e2b 1930 192f :2 0
1979 9e :3 0 15
:3 0 9b :3 0 1934
1935 0 9c :3 0
1936 1937 0 1971
65 :3 0 66 :3 0
1939 193a 0 65
:3 0 76 :3 0 193c
193d 0 9f :2 0
2 :4 0 191 :2 0
78 :2 0 27 :2 0
e2d 1942 1944 :3 0
e30 193e 1946 193b
1948 1947 :2 0 68
:3 0 79 :3 0 194a
194b 0 6a :4 0
192 :4 0 6d :2 0
6e :3 0 e34 194f
1951 :3 0 6d :2 0
82 :4 0 e37 1953
1955 :3 0 6d :2 0
a2 :4 0 e3a 1957
1959 :3 0 6d :2 0
9c :3 0 e3d 195b
195d :3 0 6d :2 0
a3 :4 0 e40 195f
1961 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
e43 1964 1968 e47
1963 196a :3 0 e4a
194c 196c :2 0 196e
e4d 196f 1949 196e
0 1970 e4f 0
1971 e51 1974 :3 0
1974 0 1974 1973
1971 1972 :6 0 1976
32 :3 0 e54 1978
e56 1977 1976 :2 0
1979 e58 :2 0 197b
0 197b 197a 1928
1979 :6 0 1a6a 1
:3 0 15 :3 0 9b
:3 0 197d 197e 0
15 :3 0 8f :2 0
a7 :3 0 1980 1982
0 e5d 1981 1984
:3 0 1985 :2 0 72
:3 0 44 :3 0 30
:2 0 e60 1987 198a
8f :2 0 27 :2 0
e65 198c 198e :3 0
198f :2 0 1986 1991
1990 :2 0 65 :3 0
66 :3 0 1993 1994
0 65 :3 0 76
:3 0 1996 1997 0
18 :2 0 2 :4 0
193 :2 0 78 :2 0
27 :2 0 e68 199c
199e :3 0 e6b 1998
19a0 1995 19a2 19a1
:2 0 68 :3 0 79
:3 0 19a4 19a5 0
6a :4 0 194 :4 0
6d :2 0 6e :3 0
e6f 19a9 19ab :3 0
6d :2 0 82 :4 0
e72 19ad 19af :3 0
6d :2 0 83 :4 0
e75 19b1 19b3 :3 0
6d :2 0 72 :3 0
73 :3 0 84 :3 0
154 :3 0 19b8 19b9
0 e78 19b7 19bb
74 :4 0 e7a 19b6
19be e7d 19b5 19c0
:3 0 6d :2 0 e5
:4 0 e80 19c2 19c4
:3 0 6d :2 0 70
:4 0 e83 19c6 19c8
:3 0 6d :2 0 1d
:3 0 e86 19ca 19cc
:3 0 6d :2 0 70
:4 0 e89 19ce 19d0
:3 0 e8c 19a6 19d2
:2 0 19d4 e8f 19d5
19a3 19d4 0 19d6
e91 0 1a00 65
:3 0 66 :3 0 19d7
19d8 0 65 :3 0
76 :3 0 19da 19db
0 27 :2 0 2
:4 0 195 :2 0 78
:2 0 27 :2 0 e93
19e0 19e2 :3 0 e96
19dc 19e4 19d9 19e6
19e5 :2 0 68 :3 0
79 :3 0 19e8 19e9
0 6a :4 0 196
:4 0 6d :2 0 6e
:3 0 e9a 19ed 19ef
:3 0 e9d 19ea 19f1
:2 0 19f3 ea0 19f4
19e7 19f3 0 19f5
ea2 0 1a00 88
:3 0 e8 :3 0 19f6
19f7 0 84 :3 0
154 :3 0 19f9 19fa
0 1d :3 0 8a
:3 0 ea4 19f8 19fe
:2 0 1a00 ea8 1a01
1992 1a00 0 1a02
eac 0 1a6a 17d
:3 0 17e :3 0 17f
:3 0 28 :3 0 42
:3 0 1e :3 0 180
:3 0 bd :3 0 1a
:3 0 12d :3 0 12c
:3 0 1d :4 0 197
1 :8 0 1a15 15
:3 0 9b :3 0 1a10
1a11 0 9c :3 0
1a12 1a13 0 1a15
eae 1a68 9d :3 0
15 :3 0 9b :3 0
1a17 1a18 0 9c
:3 0 1a19 1a1a 0
1a1c eb1 1a1e eb3
1a1d 1a1c :2 0 1a66
9e :3 0 15 :3 0
9b :3 0 1a21 1a22
0 9c :3 0 1a23
1a24 0 1a5e 65
:3 0 66 :3 0 1a26
1a27 0 65 :3 0
76 :3 0 1a29 1a2a
0 9f :2 0 2
:4 0 198 :2 0 78
:2 0 27 :2 0 eb5
1a2f 1a31 :3 0 eb8
1a2b 1a33 1a28 1a35
1a34 :2 0 68 :3 0
79 :3 0 1a37 1a38
0 6a :4 0 199
:4 0 6d :2 0 6e
:3 0 ebc 1a3c 1a3e
:3 0 6d :2 0 82
:4 0 ebf 1a40 1a42
:3 0 6d :2 0 a2
:4 0 ec2 1a44 1a46
:3 0 6d :2 0 9c
:3 0 ec5 1a48 1a4a
:3 0 6d :2 0 a3
:4 0 ec8 1a4c 1a4e
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 ecb
1a51 1a55 ecf 1a50
1a57 :3 0 ed2 1a39
1a59 :2 0 1a5b ed5
1a5c 1a36 1a5b 0
1a5d ed7 0 1a5e
ed9 1a61 :3 0 1a61
0 1a61 1a60 1a5e
1a5f :6 0 1a63 34
:3 0 edc 1a65 ede
1a64 1a63 :2 0 1a66
ee0 :2 0 1a68 0
1a68 1a67 1a15 1a66
:6 0 1a6a 1 :3 0
ee3 1a6c 1631 1827
0 1a6d 0 1a6a
0 1a6d eea 0
1d3c 21 :3 0 21
:3 0 1a6e 1a6f 0
1d3c 72 :3 0 46
:3 0 30 :2 0 eed
1a71 1a74 8f :2 0
27 :2 0 ef2 1a76
1a78 :3 0 97 :3 0
19a :3 0 133 :3 0
a4 :3 0 21 :3 0
97 :3 0 19b :3 0
1f :3 0 21 :3 0
99 :4 0 19c 1
:8 0 1a8a 15 :3 0
9b :3 0 1a85 1a86
0 9c :3 0 1a87
1a88 0 1a8a ef5
1add 9d :3 0 15
:3 0 9b :3 0 1a8c
1a8d 0 9c :3 0
1a8e 1a8f 0 1a91
ef8 1a93 efa 1a92
1a91 :2 0 1adb 9e
:3 0 15 :3 0 9b
:3 0 1a96 1a97 0
9c :3 0 1a98 1a99
0 1ad3 65 :3 0
66 :3 0 1a9b 1a9c
0 65 :3 0 76
:3 0 1a9e 1a9f 0
9f :2 0 2 :4 0
19d :2 0 78 :2 0
27 :2 0 efc 1aa4
1aa6 :3 0 eff 1aa0
1aa8 1a9d 1aaa 1aa9
:2 0 68 :3 0 79
:3 0 1aac 1aad 0
6a :4 0 19e :4 0
6d :2 0 6e :3 0
f03 1ab1 1ab3 :3 0
6d :2 0 82 :4 0
f06 1ab5 1ab7 :3 0
6d :2 0 a2 :4 0
f09 1ab9 1abb :3 0
6d :2 0 9c :3 0
f0c 1abd 1abf :3 0
6d :2 0 a3 :4 0
f0f 1ac1 1ac3 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 f12 1ac6
1aca f16 1ac5 1acc
:3 0 f19 1aae 1ace
:2 0 1ad0 f1c 1ad1
1aab 1ad0 0 1ad2
f1e 0 1ad3 f20
1ad6 :3 0 1ad6 0
1ad6 1ad5 1ad3 1ad4
:6 0 1ad8 36 :3 0
f23 1ada f25 1ad9
1ad8 :2 0 1adb f27
:2 0 1add 0 1add
1adc 1a8a 1adb :6 0
1c73 1 :3 0 133
:3 0 a4 :3 0 1f
:3 0 133 :3 0 a4
:3 0 21 :3 0 1f
:3 0 21 :3 0 21
:3 0 99 :4 0 19f
1 :8 0 1aef 15
:3 0 9b :3 0 1aea
1aeb 0 9c :3 0
1aec 1aed 0 1aef
f2a 1b42 9d :3 0
15 :3 0 9b :3 0
1af1 1af2 0 9c
:3 0 1af3 1af4 0
1af6 f2d 1af8 f2f
1af7 1af6 :2 0 1b40
9e :3 0 15 :3 0
9b :3 0 1afb 1afc
0 9c :3 0 1afd
1afe 0 1b38 65
:3 0 66 :3 0 1b00
1b01 0 65 :3 0
76 :3 0 1b03 1b04
0 9f :2 0 2
:4 0 1a0 :2 0 78
:2 0 27 :2 0 f31
1b09 1b0b :3 0 f34
1b05 1b0d 1b02 1b0f
1b0e :2 0 68 :3 0
79 :3 0 1b11 1b12
0 6a :4 0 1a1
:4 0 6d :2 0 6e
:3 0 f38 1b16 1b18
:3 0 6d :2 0 82
:4 0 f3b 1b1a 1b1c
:3 0 6d :2 0 a2
:4 0 f3e 1b1e 1b20
:3 0 6d :2 0 9c
:3 0 f41 1b22 1b24
:3 0 6d :2 0 a3
:4 0 f44 1b26 1b28
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 f47
1b2b 1b2f f4b 1b2a
1b31 :3 0 f4e 1b13
1b33 :2 0 1b35 f51
1b36 1b10 1b35 0
1b37 f53 0 1b38
f55 1b3b :3 0 1b3b
0 1b3b 1b3a 1b38
1b39 :6 0 1b3d 38
:3 0 f58 1b3f f5a
1b3e 1b3d :2 0 1b40
f5c :2 0 1b42 0
1b42 1b41 1aef 1b40
:6 0 1c73 1 :3 0
45 :3 0 1a2 :2 0
1b44 1b45 0 1c73
22 :3 0 6 :3 0
1b47 1b48 0 1c73
72 :3 0 33 :3 0
30 :2 0 f5f 1b4a
1b4d 8f :2 0 30
:2 0 f64 1b4f 1b51
:3 0 3f :3 0 114
:2 0 1b53 1b54 0
1b56 f67 1b57 1b52
1b56 0 1b58 f69
0 1c73 61 :3 0
1a3 :3 0 28 :3 0
17 :3 0 1a :3 0
1d :3 0 4e :3 0
32 :3 0 23 :3 0
23 :3 0 23 :3 0
23 :3 0 21 :3 0
22 :3 0 41 :3 0
37 :3 0 35 :3 0
38 :3 0 39 :3 0
34 :3 0 45 :3 0
26 :3 0 33 :3 0
31 :3 0 3b :3 0
36 :3 0 3f :3 0
3d :3 0 43 :3 0
1c :3 0 30 :2 0
30 :2 0 7d :2 0
7d :2 0 30 :2 0
f6b 1b5a 1b7c 1b59
1b7d 0 1c73 61
:3 0 8f :2 0 30
:2 0 f8f 1b80 1b82
:3 0 72 :3 0 33
:3 0 30 :2 0 f92
1b84 1b87 8f :2 0
30 :2 0 f97 1b89
1b8b :3 0 1a4 :3 0
1a5 :3 0 1a6 :3 0
1d :4 0 1a7 1
:8 0 1ba7 1a8 :4 0
1b92 :3 0 8a :3 0
8f :2 0 f9c 1b95
1b96 :3 0 15 :3 0
9b :3 0 1b98 1b99
0 30 :2 0 1b9a
1b9b 0 1b9d f9f
1ba4 15 :3 0 9b
:3 0 1b9e 1b9f 0
112 :2 0 1ba0 1ba1
0 1ba3 fa1 1ba5
1b97 1b9d 0 1ba6
0 1ba3 0 1ba6
fa3 0 1ba7 fa6
1bfa 9d :3 0 15
:3 0 9b :3 0 1ba9
1baa 0 9c :3 0
1bab 1bac 0 1bae
fa9 1bb0 fab 1baf
1bae :2 0 1bf8 9e
:3 0 15 :3 0 9b
:3 0 1bb3 1bb4 0
9c :3 0 1bb5 1bb6
0 1bf0 65 :3 0
66 :3 0 1bb8 1bb9
0 65 :3 0 76
:3 0 1bbb 1bbc 0
9f :2 0 2 :4 0
1a9 :2 0 78 :2 0
27 :2 0 fad 1bc1
1bc3 :3 0 fb0 1bbd
1bc5 1bba 1bc7 1bc6
:2 0 68 :3 0 79
:3 0 1bc9 1bca 0
6a :4 0 1aa :4 0
6d :2 0 6e :3 0
fb4 1bce 1bd0 :3 0
6d :2 0 82 :4 0
fb7 1bd2 1bd4 :3 0
6d :2 0 a2 :4 0
fba 1bd6 1bd8 :3 0
6d :2 0 9c :3 0
fbd 1bda 1bdc :3 0
6d :2 0 a3 :4 0
fc0 1bde 1be0 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 fc3 1be3
1be7 fc7 1be2 1be9
:3 0 fca 1bcb 1beb
:2 0 1bed fcd 1bee
1bc8 1bed 0 1bef
fcf 0 1bf0 fd1
1bf3 :3 0 1bf3 0
1bf3 1bf2 1bf0 1bf1
:6 0 1bf5 3a :3 0
fd4 1bf7 fd6 1bf6
1bf5 :2 0 1bf8 fd8
:2 0 1bfa 0 1bfa
1bf9 1ba7 1bf8 :6 0
1bfc 1 :3 0 fdb
1c6d 1a4 :3 0 1a5
:3 0 1a6 :3 0 1d
:4 0 1ab 1 :8 0
1c17 1a8 :4 0 1c02
:3 0 8a :3 0 8f
:2 0 fdf 1c05 1c06
:3 0 15 :3 0 9b
:3 0 1c08 1c09 0
30 :2 0 1c0a 1c0b
0 1c0d fe2 1c14
15 :3 0 9b :3 0
1c0e 1c0f 0 112
:2 0 1c10 1c11 0
1c13 fe4 1c15 1c07
1c0d 0 1c16 0
1c13 0 1c16 fe6
0 1c17 fe9 1c6a
9d :3 0 15 :3 0
9b :3 0 1c19 1c1a
0 9c :3 0 1c1b
1c1c 0 1c1e fec
1c20 fee 1c1f 1c1e
:2 0 1c68 9e :3 0
15 :3 0 9b :3 0
1c23 1c24 0 9c
:3 0 1c25 1c26 0
1c60 65 :3 0 66
:3 0 1c28 1c29 0
65 :3 0 76 :3 0
1c2b 1c2c 0 9f
:2 0 2 :4 0 1ac
:2 0 78 :2 0 27
:2 0 ff0 1c31 1c33
:3 0 ff3 1c2d 1c35
1c2a 1c37 1c36 :2 0
68 :3 0 79 :3 0
1c39 1c3a 0 6a
:4 0 1ad :4 0 6d
:2 0 6e :3 0 ff7
1c3e 1c40 :3 0 6d
:2 0 82 :4 0 ffa
1c42 1c44 :3 0 6d
:2 0 a2 :4 0 ffd
1c46 1c48 :3 0 6d
:2 0 9c :3 0 1000
1c4a 1c4c :3 0 6d
:2 0 a3 :4 0 1003
1c4e 1c50 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 1006 1c53 1c57
100a 1c52 1c59 :3 0
100d 1c3b 1c5b :2 0
1c5d 1010 1c5e 1c38
1c5d 0 1c5f 1012
0 1c60 1014 1c63
:3 0 1c63 0 1c63
1c62 1c60 1c61 :6 0
1c65 3c :3 0 1017
1c67 1019 1c66 1c65
:2 0 1c68 101b :2 0
1c6a 0 1c6a 1c69
1c17 1c68 :6 0 1c6c
1 :3 0 101e 1c6e
1b8c 1bfc 0 1c6f
0 1c6c 0 1c6f
1020 0 1c70 1023
1c71 1b83 1c70 0
1c72 1025 0 1c73
1027 1d39 21 :3 0
1f :3 0 1c74 1c75
0 1d38 22 :3 0
6 :3 0 1c77 1c78
0 1d38 a4 :3 0
26 :3 0 27 :2 0
27 :2 0 102f 1c7a
1c7e 8f :2 0 27
:4 0 1035 1c80 1c82
:3 0 45 :3 0 84
:3 0 106 :3 0 1c85
1c86 0 1c84 1c87
0 1c89 1038 1c98
45 :3 0 11a :3 0
72 :3 0 3a :3 0
30 :2 0 103a 1c8c
1c8f 84 :3 0 11d
:3 0 1c91 1c92 0
103d 1c8b 1c94 1c8a
1c95 0 1c97 1040
1c99 1c83 1c89 0
1c9a 0 1c97 0
1c9a 1042 0 1d38
61 :3 0 1a3 :3 0
28 :3 0 17 :3 0
1a :3 0 1d :3 0
4e :3 0 32 :3 0
23 :3 0 23 :3 0
23 :3 0 23 :3 0
21 :3 0 22 :3 0
41 :3 0 37 :3 0
35 :3 0 38 :3 0
39 :3 0 34 :3 0
45 :3 0 26 :3 0
33 :3 0 31 :3 0
3b :3 0 36 :3 0
3f :3 0 3d :3 0
43 :3 0 1c :3 0
30 :2 0 30 :2 0
7d :2 0 7d :2 0
30 :2 0 1045 1c9c
1cbe 1c9b 1cbf 0
1d38 61 :3 0 8f
:2 0 30 :2 0 1069
1cc2 1cc4 :3 0 1a4
:3 0 1a5 :3 0 1a6
:3 0 1d :4 0 1a7
1 :8 0 1ce0 1a8
:4 0 1ccb :3 0 8a
:3 0 8f :2 0 106e
1cce 1ccf :3 0 15
:3 0 9b :3 0 1cd1
1cd2 0 30 :2 0
1cd3 1cd4 0 1cd6
1071 1cdd 15 :3 0
9b :3 0 1cd7 1cd8
0 112 :2 0 1cd9
1cda 0 1cdc 1073
1cde 1cd0 1cd6 0
1cdf 0 1cdc 0
1cdf 1075 0 1ce0
1078 1d33 9d :3 0
15 :3 0 9b :3 0
1ce2 1ce3 0 9c
:3 0 1ce4 1ce5 0
1ce7 107b 1ce9 107d
1ce8 1ce7 :2 0 1d31
9e :3 0 15 :3 0
9b :3 0 1cec 1ced
0 9c :3 0 1cee
1cef 0 1d29 65
:3 0 66 :3 0 1cf1
1cf2 0 65 :3 0
76 :3 0 1cf4 1cf5
0 9f :2 0 2
:4 0 1ae :2 0 78
:2 0 27 :2 0 107f
1cfa 1cfc :3 0 1082
1cf6 1cfe 1cf3 1d00
1cff :2 0 68 :3 0
79 :3 0 1d02 1d03
0 6a :4 0 1af
:4 0 6d :2 0 6e
:3 0 1086 1d07 1d09
:3 0 6d :2 0 82
:4 0 1089 1d0b 1d0d
:3 0 6d :2 0 a2
:4 0 108c 1d0f 1d11
:3 0 6d :2 0 9c
:3 0 108f 1d13 1d15
:3 0 6d :2 0 a3
:4 0 1092 1d17 1d19
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 1095
1d1c 1d20 1099 1d1b
1d22 :3 0 109c 1d04
1d24 :2 0 1d26 109f
1d27 1d01 1d26 0
1d28 10a1 0 1d29
10a3 1d2c :3 0 1d2c
0 1d2c 1d2b 1d29
1d2a :6 0 1d2e 3e
:3 0 10a6 1d30 10a8
1d2f 1d2e :2 0 1d31
10aa :2 0 1d33 0
1d33 1d32 1ce0 1d31
:6 0 1d35 1 :3 0
10ad 1d36 1cc5 1d35
0 1d37 10af 0
1d38 10b1 1d3a 1a79
1c73 0 1d3b 0
1d38 0 1d3b 10b7
0 1d3c 10ba 2730
72 :3 0 1b0 :3 0
29 :3 0 10c8 1d3e
1d40 30 :2 0 10ca
1d3d 1d43 a8 :2 0
18 :2 0 10cf 1d45
1d47 :3 0 63 :3 0
30 :2 0 1d49 1d4a
0 1d4c 10d2 1d64
63 :3 0 1b1 :3 0
72 :3 0 1b0 :3 0
29 :3 0 10d4 1d50
1d52 30 :2 0 10d6
1d4f 1d55 78 :2 0
27 :2 0 10d9 1d57
1d59 :3 0 1d5a :2 0
1b2 :2 0 b5 :2 0
10dc 1d5c 1d5e :3 0
10df 1d4e 1d60 1d4d
1d61 0 1d63 10e1
1d65 1d48 1d4c 0
1d66 0 1d63 0
1d66 10e3 0 272f
63 :3 0 b2 :2 0
30 :2 0 10e8 1d68
1d6a :3 0 2f :3 0
30 :2 0 1d6c 1d6d
0 272c 1b3 :3 0
72 :3 0 2f :3 0
30 :2 0 10eb 1d70
1d73 63 :3 0 a8
:2 0 1b4 :3 0 10f0
1d76 1d78 :3 0 1d79
272b 46 :3 0 30
:2 0 1d7b 1d7c 0
2729 1d :3 0 b3
:3 0 b4 :3 0 1d7f
1d80 0 18 :2 0
18 :2 0 72 :3 0
2f :3 0 30 :2 0
10f3 1d84 1d87 116
:2 0 b5 :2 0 10f6
1d89 1d8b :3 0 78
:2 0 27 :2 0 10f9
1d8d 1d8f :3 0 29
:3 0 10fc 1d81 1d92
1d7e 1d93 0 2729
26 :3 0 b3 :3 0
b4 :3 0 1d96 1d97
0 27 :2 0 27
:2 0 72 :3 0 2f
:3 0 30 :2 0 1101
1d9b 1d9e 116 :2 0
b5 :2 0 1104 1da0
1da2 :3 0 78 :2 0
18 :2 0 1107 1da4
1da6 :3 0 78 :2 0
27 :2 0 110a 1da8
1daa :3 0 29 :3 0
110d 1d98 1dad 1d95
1dae 0 2729 1f
:3 0 5 :3 0 1db0
1db1 0 2729 46
:3 0 30 :2 0 1db3
1db4 0 2729 44
:3 0 30 :2 0 1db6
1db7 0 2729 21
:3 0 1f :3 0 1db9
1dba 0 2729 1b5
:3 0 128 :3 0 1b6
:3 0 44 :3 0 21
:3 0 12a :3 0 b8
:3 0 17 :3 0 12b
:3 0 17 :3 0 12c
:3 0 1d :3 0 12d
:3 0 26 :4 0 1b7
1 :8 0 1dd0 15
:3 0 9b :3 0 1dcb
1dcc 0 9c :3 0
1dcd 1dce 0 1dd0
1112 1e23 9d :3 0
15 :3 0 9b :3 0
1dd2 1dd3 0 9c
:3 0 1dd4 1dd5 0
1dd7 1115 1dd9 1117
1dd8 1dd7 :2 0 1e21
9e :3 0 15 :3 0
9b :3 0 1ddc 1ddd
0 9c :3 0 1dde
1ddf 0 1e19 65
:3 0 66 :3 0 1de1
1de2 0 65 :3 0
76 :3 0 1de4 1de5
0 9f :2 0 2
:4 0 1b8 :2 0 78
:2 0 27 :2 0 1119
1dea 1dec :3 0 111c
1de6 1dee 1de3 1df0
1def :2 0 68 :3 0
79 :3 0 1df2 1df3
0 6a :4 0 1b9
:4 0 6d :2 0 6e
:3 0 1120 1df7 1df9
:3 0 6d :2 0 82
:4 0 1123 1dfb 1dfd
:3 0 6d :2 0 a2
:4 0 1126 1dff 1e01
:3 0 6d :2 0 9c
:3 0 1129 1e03 1e05
:3 0 6d :2 0 a3
:4 0 112c 1e07 1e09
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 112f
1e0c 1e10 1133 1e0b
1e12 :3 0 1136 1df4
1e14 :2 0 1e16 1139
1e17 1df1 1e16 0
1e18 113b 0 1e19
113d 1e1c :3 0 1e1c
0 1e1c 1e1b 1e19
1e1a :6 0 1e1e 41
:3 0 1140 1e20 1142
1e1f 1e1e :2 0 1e21
1144 :2 0 1e23 0
1e23 1e22 1dd0 1e21
:6 0 2729 40 :3 0
72 :3 0 44 :3 0
30 :2 0 1147 1e25
1e28 b2 :2 0 30
:2 0 114c 1e2a 1e2c
:3 0 1e2d :2 0 21
:3 0 96 :2 0 114f
1e30 1e31 :3 0 1e32
:2 0 1e33 :2 0 1e2e
1e35 1e34 :2 0 46
:3 0 27 :2 0 1e37
1e38 0 1e4b 97
:3 0 f2 :3 0 1e3a
1e3b 0 1f :3 0
21 :3 0 1151 1e3c
1e3f a8 :2 0 30
:2 0 1156 1e41 1e43
:3 0 1f :3 0 21
:3 0 1e45 1e46 0
1e48 1159 1e49 1e44
1e48 0 1e4a 115b
0 1e4b 115d 1e4c
1e36 1e4b 0 1e4d
1160 0 2729 a4
:3 0 26 :3 0 27
:2 0 27 :2 0 1162
1e4e 1e52 8f :2 0
27 :4 0 1168 1e54
1e56 :3 0 3a :3 0
84 :3 0 106 :3 0
1e59 1e5a 0 1e58
1e5b 0 1e89 72
:3 0 1b0 :3 0 2c
:3 0 116b 1e5e 1e60
30 :2 0 116d 1e5d
1e63 8f :2 0 30
:2 0 1172 1e65 1e67
:3 0 2c :3 0 1d
:3 0 1e69 1e6a 0
1e6c 1175 1e86 2c
:3 0 a4 :3 0 2c
:3 0 6d :2 0 1ba
:4 0 1177 1e70 1e72
:3 0 27 :2 0 2a
:2 0 117a 1e6e 1e76
1e6d 1e77 0 1e85
2c :3 0 a4 :3 0
2c :3 0 6d :2 0
1d :3 0 117e 1e7c
1e7e :3 0 27 :2 0
2a :2 0 1181 1e7a
1e82 1e79 1e83 0
1e85 1185 1e87 1e68
1e6c 0 1e88 0
1e85 0 1e88 1188
0 1e89 118b 1eb7
72 :3 0 1b0 :3 0
2b :3 0 118e 1e8b
1e8d 30 :2 0 1190
1e8a 1e90 8f :2 0
30 :2 0 1195 1e92
1e94 :3 0 2b :3 0
1d :3 0 1e96 1e97
0 1e99 1198 1eb3
2b :3 0 a4 :3 0
2b :3 0 6d :2 0
1ba :4 0 119a 1e9d
1e9f :3 0 27 :2 0
2a :2 0 119d 1e9b
1ea3 1e9a 1ea4 0
1eb2 2b :3 0 a4
:3 0 2b :3 0 6d
:2 0 1d :3 0 11a1
1ea9 1eab :3 0 27
:2 0 2a :2 0 11a4
1ea7 1eaf 1ea6 1eb0
0 1eb2 11a8 1eb4
1e95 1e99 0 1eb5
0 1eb2 0 1eb5
11ab 0 1eb6 11ae
1eb8 1e57 1e89 0
1eb9 0 1eb6 0
1eb9 11b0 0 2729
33 :3 0 30 :2 0
1eba 1ebb 0 2729
44 :3 0 30 :2 0
1ebd 1ebe 0 2729
72 :3 0 46 :3 0
30 :2 0 11b3 1ec0
1ec3 8f :2 0 27
:2 0 11b8 1ec5 1ec7
:3 0 62 :3 0 8f
:2 0 27 :2 0 11bd
1eca 1ecc :3 0 a4
:3 0 26 :3 0 27
:2 0 27 :2 0 11c0
1ece 1ed2 8f :2 0
30 :4 0 11c6 1ed4
1ed6 :3 0 131 :3 0
132 :3 0 133 :3 0
a4 :3 0 1f :3 0
133 :3 0 a4 :3 0
132 :3 0 133 :3 0
a4 :3 0 22 :3 0
133 :3 0 a4 :3 0
134 :3 0 135 :3 0
37 :3 0 135 :3 0
19 :3 0 21 :3 0
44 :3 0 47 :3 0
12a :3 0 12b :3 0
17 :3 0 12c :3 0
1d :3 0 12d :3 0
136 :4 0 1bb 1
:8 0 1efa 15 :3 0
9b :3 0 1ef5 1ef6
0 9c :3 0 1ef7
1ef8 0 1efa 11c9
1f4d 9d :3 0 15
:3 0 9b :3 0 1efc
1efd 0 9c :3 0
1efe 1eff 0 1f01
11cc 1f03 11ce 1f02
1f01 :2 0 1f4b 9e
:3 0 15 :3 0 9b
:3 0 1f06 1f07 0
9c :3 0 1f08 1f09
0 1f43 65 :3 0
66 :3 0 1f0b 1f0c
0 65 :3 0 76
:3 0 1f0e 1f0f 0
9f :2 0 2 :4 0
1bc :2 0 78 :2 0
27 :2 0 11d0 1f14
1f16 :3 0 11d3 1f10
1f18 1f0d 1f1a 1f19
:2 0 68 :3 0 79
:3 0 1f1c 1f1d 0
6a :4 0 1bd :4 0
6d :2 0 6e :3 0
11d7 1f21 1f23 :3 0
6d :2 0 82 :4 0
11da 1f25 1f27 :3 0
6d :2 0 a2 :4 0
11dd 1f29 1f2b :3 0
6d :2 0 9c :3 0
11e0 1f2d 1f2f :3 0
6d :2 0 a3 :4 0
11e3 1f31 1f33 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 11e6 1f36
1f3a 11ea 1f35 1f3c
:3 0 11ed 1f1e 1f3e
:2 0 1f40 11f0 1f41
1f1b 1f40 0 1f42
11f2 0 1f43 11f4
1f46 :3 0 1f46 0
1f46 1f45 1f43 1f44
:6 0 1f48 43 :3 0
11f7 1f4a 11f9 1f49
1f48 :2 0 1f4b 11fb
:2 0 1f4d 0 1f4d
1f4c 1efa 1f4b :6 0
2080 40 :3 0 15
:3 0 9b :3 0 1f4f
1f50 0 15 :3 0
8f :2 0 a7 :3 0
1f52 1f54 0 1200
1f53 1f56 :3 0 1f57
:2 0 46 :3 0 27
:2 0 1f59 1f5a 0
1ff0 72 :3 0 47
:3 0 30 :2 0 1203
1f5c 1f5f 8f :2 0
30 :2 0 1208 1f61
1f63 :3 0 1f64 :2 0
72 :3 0 44 :3 0
30 :2 0 120b 1f66
1f69 8f :2 0 27
:2 0 1210 1f6b 1f6d
:3 0 1f6e :2 0 1f65
1f70 1f6f :2 0 131
:3 0 13a :3 0 133
:3 0 a4 :3 0 1f
:3 0 133 :3 0 a4
:3 0 13a :3 0 133
:3 0 a4 :3 0 22
:3 0 133 :3 0 a4
:3 0 13b :3 0 13c
:3 0 37 :3 0 19
:3 0 21 :3 0 44
:3 0 12a :3 0 12b
:3 0 17 :3 0 12c
:3 0 1d :3 0 12d
:3 0 136 :4 0 1be
1 :8 0 1f92 15
:3 0 9b :3 0 1f8d
1f8e 0 9c :3 0
1f8f 1f90 0 1f92
1213 1fe5 9d :3 0
15 :3 0 9b :3 0
1f94 1f95 0 9c
:3 0 1f96 1f97 0
1f99 1216 1f9b 1218
1f9a 1f99 :2 0 1fe3
9e :3 0 15 :3 0
9b :3 0 1f9e 1f9f
0 9c :3 0 1fa0
1fa1 0 1fdb 65
:3 0 66 :3 0 1fa3
1fa4 0 65 :3 0
76 :3 0 1fa6 1fa7
0 9f :2 0 2
:4 0 1bf :2 0 78
:2 0 27 :2 0 121a
1fac 1fae :3 0 121d
1fa8 1fb0 1fa5 1fb2
1fb1 :2 0 68 :3 0
79 :3 0 1fb4 1fb5
0 6a :4 0 1c0
:4 0 6d :2 0 6e
:3 0 1221 1fb9 1fbb
:3 0 6d :2 0 82
:4 0 1224 1fbd 1fbf
:3 0 6d :2 0 a2
:4 0 1227 1fc1 1fc3
:3 0 6d :2 0 9c
:3 0 122a 1fc5 1fc7
:3 0 6d :2 0 a3
:4 0 122d 1fc9 1fcb
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 1230
1fce 1fd2 1234 1fcd
1fd4 :3 0 1237 1fb6
1fd6 :2 0 1fd8 123a
1fd9 1fb3 1fd8 0
1fda 123c 0 1fdb
123e 1fde :3 0 1fde
0 1fde 1fdd 1fdb
1fdc :6 0 1fe0 45
:3 0 1241 1fe2 1243
1fe1 1fe0 :2 0 1fe3
1245 :2 0 1fe5 0
1fe5 1fe4 1f92 1fe3
:6 0 1fe7 40 :3 0
1248 1fec 33 :3 0
113 :2 0 1fe8 1fe9
0 1feb 124a 1fed
1f71 1fe7 0 1fee
0 1feb 0 1fee
124c 0 1ff0 ae
:3 0 124f 207e 15
:3 0 9b :3 0 1ff1
1ff2 0 15 :3 0
8f :2 0 d9 :3 0
1ff4 1ff6 0 1254
1ff5 1ff8 :3 0 1ff9
:2 0 72 :3 0 44
:3 0 30 :2 0 1257
1ffb 1ffe 8f :2 0
27 :2 0 125c 2000
2002 :3 0 2003 :2 0
1ffa 2005 2004 :2 0
131 :3 0 13a :3 0
133 :3 0 a4 :3 0
1f :3 0 133 :3 0
a4 :3 0 13a :3 0
133 :3 0 a4 :3 0
22 :3 0 133 :3 0
a4 :3 0 13b :3 0
13c :3 0 37 :3 0
19 :3 0 21 :3 0
44 :3 0 12a :3 0
12b :3 0 17 :3 0
12c :3 0 1d :3 0
12d :3 0 136 :4 0
1c1 1 :8 0 2027
15 :3 0 9b :3 0
2022 2023 0 9c
:3 0 2024 2025 0
2027 125f 207a 9d
:3 0 15 :3 0 9b
:3 0 2029 202a 0
9c :3 0 202b 202c
0 202e 1262 2030
1264 202f 202e :2 0
2078 9e :3 0 15
:3 0 9b :3 0 2033
2034 0 9c :3 0
2035 2036 0 2070
65 :3 0 66 :3 0
2038 2039 0 65
:3 0 76 :3 0 203b
203c 0 9f :2 0
2 :4 0 1c2 :2 0
78 :2 0 27 :2 0
1266 2041 2043 :3 0
1269 203d 2045 203a
2047 2046 :2 0 68
:3 0 79 :3 0 2049
204a 0 6a :4 0
1c3 :4 0 6d :2 0
6e :3 0 126d 204e
2050 :3 0 6d :2 0
82 :4 0 1270 2052
2054 :3 0 6d :2 0
a2 :4 0 1273 2056
2058 :3 0 6d :2 0
9c :3 0 1276 205a
205c :3 0 6d :2 0
a3 :4 0 1279 205e
2060 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
127c 2063 2067 1280
2062 2069 :3 0 1283
204b 206b :2 0 206d
1286 206e 2048 206d
0 206f 1288 0
2070 128a 2073 :3 0
2073 0 2073 2072
2070 2071 :6 0 2075
47 :3 0 128d 2077
128f 2076 2075 :2 0
2078 1291 :2 0 207a
0 207a 2079 2027
2078 :6 0 207c 40
:3 0 1294 207d 2006
207c 0 207f 1f58
1ff0 0 207f 1296
0 2080 1299 20f9
131 :3 0 13a :3 0
133 :3 0 a4 :3 0
1f :3 0 133 :3 0
a4 :3 0 13a :3 0
133 :3 0 a4 :3 0
22 :3 0 133 :3 0
a4 :3 0 13b :3 0
13c :3 0 37 :3 0
19 :3 0 21 :3 0
44 :3 0 12a :3 0
b8 :3 0 17 :3 0
12b :3 0 17 :3 0
12c :3 0 1d :3 0
12d :3 0 136 :4 0
1c4 1 :8 0 20a3
15 :3 0 9b :3 0
209e 209f 0 9c
:3 0 20a0 20a1 0
20a3 129c 20f6 9d
:3 0 15 :3 0 9b
:3 0 20a5 20a6 0
9c :3 0 20a7 20a8
0 20aa 129f 20ac
12a1 20ab 20aa :2 0
20f4 9e :3 0 15
:3 0 9b :3 0 20af
20b0 0 9c :3 0
20b1 20b2 0 20ec
65 :3 0 66 :3 0
20b4 20b5 0 65
:3 0 76 :3 0 20b7
20b8 0 9f :2 0
2 :4 0 1c5 :2 0
78 :2 0 27 :2 0
12a3 20bd 20bf :3 0
12a6 20b9 20c1 20b6
20c3 20c2 :2 0 68
:3 0 79 :3 0 20c5
20c6 0 6a :4 0
1c6 :4 0 6d :2 0
6e :3 0 12aa 20ca
20cc :3 0 6d :2 0
82 :4 0 12ad 20ce
20d0 :3 0 6d :2 0
a2 :4 0 12b0 20d2
20d4 :3 0 6d :2 0
9c :3 0 12b3 20d6
20d8 :3 0 6d :2 0
a3 :4 0 12b6 20da
20dc :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
12b9 20df 20e3 12bd
20de 20e5 :3 0 12c0
20c7 20e7 :2 0 20e9
12c3 20ea 20c4 20e9
0 20eb 12c5 0
20ec 12c7 20ef :3 0
20ef 0 20ef 20ee
20ec 20ed :6 0 20f1
49 :3 0 12ca 20f3
12cc 20f2 20f1 :2 0
20f4 12ce :2 0 20f6
0 20f6 20f5 20a3
20f4 :6 0 20f8 40
:3 0 12d1 20fa 1ed7
2080 0 20fb 0
20f8 0 20fb 12d3
0 20fc 12d6 2315
a4 :3 0 26 :3 0
27 :2 0 27 :2 0
12d8 20fd 2101 8f
:2 0 30 :4 0 12de
2103 2105 :3 0 131
:3 0 132 :3 0 133
:3 0 a4 :3 0 1f
:3 0 133 :3 0 a4
:3 0 132 :3 0 133
:3 0 a4 :3 0 134
:3 0 37 :3 0 135
:3 0 135 :3 0 19
:3 0 21 :3 0 44
:3 0 47 :3 0 12a
:3 0 b8 :3 0 17
:3 0 12b :3 0 17
:3 0 12c :3 0 1d
:3 0 12d :3 0 136
:4 0 1c7 1 :8 0
2128 15 :3 0 9b
:3 0 2123 2124 0
9c :3 0 2125 2126
0 2128 12e1 217b
9d :3 0 15 :3 0
9b :3 0 212a 212b
0 9c :3 0 212c
212d 0 212f 12e4
2131 12e6 2130 212f
:2 0 2179 9e :3 0
15 :3 0 9b :3 0
2134 2135 0 9c
:3 0 2136 2137 0
2171 65 :3 0 66
:3 0 2139 213a 0
65 :3 0 76 :3 0
213c 213d 0 9f
:2 0 2 :4 0 1c8
:2 0 78 :2 0 27
:2 0 12e8 2142 2144
:3 0 12eb 213e 2146
213b 2148 2147 :2 0
68 :3 0 79 :3 0
214a 214b 0 6a
:4 0 1c9 :4 0 6d
:2 0 6e :3 0 12ef
214f 2151 :3 0 6d
:2 0 82 :4 0 12f2
2153 2155 :3 0 6d
:2 0 a2 :4 0 12f5
2157 2159 :3 0 6d
:2 0 9c :3 0 12f8
215b 215d :3 0 6d
:2 0 a3 :4 0 12fb
215f 2161 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 12fe 2164 2168
1302 2163 216a :3 0
1305 214c 216c :2 0
216e 1308 216f 2149
216e 0 2170 130a
0 2171 130c 2174
:3 0 2174 0 2174
2173 2171 2172 :6 0
2176 4b :3 0 130f
2178 1311 2177 2176
:2 0 2179 1313 :2 0
217b 0 217b 217a
2128 2179 :6 0 229b
40 :3 0 15 :3 0
9b :3 0 217d 217e
0 15 :3 0 8f
:2 0 a7 :3 0 2180
2182 0 1318 2181
2184 :3 0 2185 :2 0
72 :3 0 47 :3 0
30 :2 0 131b 2187
218a 8f :2 0 30
:2 0 1320 218c 218e
:3 0 218f :2 0 72
:3 0 44 :3 0 30
:2 0 1323 2191 2194
8f :2 0 27 :2 0
1328 2196 2198 :3 0
2199 :2 0 2190 219b
219a :2 0 131 :3 0
13a :3 0 133 :3 0
a4 :3 0 1f :3 0
133 :3 0 a4 :3 0
13b :3 0 37 :3 0
13c :3 0 19 :3 0
21 :3 0 44 :3 0
12a :3 0 b8 :3 0
17 :3 0 12b :3 0
17 :3 0 12c :3 0
1d :3 0 12d :3 0
136 :4 0 1ca 1
:8 0 21b9 15 :3 0
9b :3 0 21b4 21b5
0 9c :3 0 21b6
21b7 0 21b9 132b
220c 9d :3 0 15
:3 0 9b :3 0 21bb
21bc 0 9c :3 0
21bd 21be 0 21c0
132e 21c2 1330 21c1
21c0 :2 0 220a 9e
:3 0 15 :3 0 9b
:3 0 21c5 21c6 0
9c :3 0 21c7 21c8
0 2202 65 :3 0
66 :3 0 21ca 21cb
0 65 :3 0 76
:3 0 21cd 21ce 0
9f :2 0 2 :4 0
1cb :2 0 78 :2 0
27 :2 0 1332 21d3
21d5 :3 0 1335 21cf
21d7 21cc 21d9 21d8
:2 0 68 :3 0 79
:3 0 21db 21dc 0
6a :4 0 1cc :4 0
6d :2 0 6e :3 0
1339 21e0 21e2 :3 0
6d :2 0 82 :4 0
133c 21e4 21e6 :3 0
6d :2 0 a2 :4 0
133f 21e8 21ea :3 0
6d :2 0 9c :3 0
1342 21ec 21ee :3 0
6d :2 0 a3 :4 0
1345 21f0 21f2 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 1348 21f5
21f9 134c 21f4 21fb
:3 0 134f 21dd 21fd
:2 0 21ff 1352 2200
21da 21ff 0 2201
1354 0 2202 1356
2205 :3 0 2205 0
2205 2204 2202 2203
:6 0 2207 4d :3 0
1359 2209 135b 2208
2207 :2 0 220a 135d
:2 0 220c 0 220c
220b 21b9 220a :6 0
220e 40 :3 0 1360
2214 33 :3 0 113
:2 0 220f 2210 0
2213 0 2213 1362
2215 219c 220e 0
2216 0 2213 0
2216 1365 0 2218
ae :3 0 1368 2299
15 :3 0 9b :3 0
2219 221a 0 15
:3 0 8f :2 0 d9
:3 0 221c 221e 0
136c 221d 2220 :3 0
2221 :2 0 131 :3 0
13a :3 0 133 :3 0
a4 :3 0 1f :3 0
133 :3 0 a4 :3 0
13a :3 0 133 :3 0
a4 :3 0 13b :3 0
37 :3 0 13c :3 0
19 :3 0 21 :3 0
44 :3 0 12a :3 0
b8 :3 0 17 :3 0
12b :3 0 17 :3 0
12c :3 0 1d :3 0
12d :3 0 136 :4 0
1cd 1 :8 0 2242
15 :3 0 9b :3 0
223d 223e 0 9c
:3 0 223f 2240 0
2242 136f 2295 9d
:3 0 15 :3 0 9b
:3 0 2244 2245 0
9c :3 0 2246 2247
0 2249 1372 224b
1374 224a 2249 :2 0
2293 9e :3 0 15
:3 0 9b :3 0 224e
224f 0 9c :3 0
2250 2251 0 228b
65 :3 0 66 :3 0
2253 2254 0 65
:3 0 76 :3 0 2256
2257 0 9f :2 0
2 :4 0 1ce :2 0
78 :2 0 27 :2 0
1376 225c 225e :3 0
1379 2258 2260 2255
2262 2261 :2 0 68
:3 0 79 :3 0 2264
2265 0 6a :4 0
1cf :4 0 6d :2 0
6e :3 0 137d 2269
226b :3 0 6d :2 0
82 :4 0 1380 226d
226f :3 0 6d :2 0
a2 :4 0 1383 2271
2273 :3 0 6d :2 0
9c :3 0 1386 2275
2277 :3 0 6d :2 0
a3 :4 0 1389 2279
227b :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
138c 227e 2282 1390
227d 2284 :3 0 1393
2266 2286 :2 0 2288
1396 2289 2263 2288
0 228a 1398 0
228b 139a 228e :3 0
228e 0 228e 228d
228b 228c :6 0 2290
4f :3 0 139d 2292
139f 2291 2290 :2 0
2293 13a1 :2 0 2295
0 2295 2294 2242
2293 :6 0 2297 40
:3 0 13a4 2298 2222
2297 0 229a 2186
2218 0 229a 13a6
0 229b 13a9 2311
131 :3 0 13a :3 0
133 :3 0 a4 :3 0
1f :3 0 133 :3 0
a4 :3 0 13a :3 0
133 :3 0 a4 :3 0
13b :3 0 37 :3 0
13c :3 0 19 :3 0
21 :3 0 44 :3 0
12a :3 0 b8 :3 0
17 :3 0 12b :3 0
17 :3 0 12c :3 0
1d :3 0 12d :3 0
136 :4 0 1d0 1
:8 0 22bb 15 :3 0
9b :3 0 22b6 22b7
0 9c :3 0 22b8
22b9 0 22bb 13ac
230e 9d :3 0 15
:3 0 9b :3 0 22bd
22be 0 9c :3 0
22bf 22c0 0 22c2
13af 22c4 13b1 22c3
22c2 :2 0 230c 9e
:3 0 15 :3 0 9b
:3 0 22c7 22c8 0
9c :3 0 22c9 22ca
0 2304 65 :3 0
66 :3 0 22cc 22cd
0 65 :3 0 76
:3 0 22cf 22d0 0
9f :2 0 2 :4 0
1d1 :2 0 78 :2 0
27 :2 0 13b3 22d5
22d7 :3 0 13b6 22d1
22d9 22ce 22db 22da
:2 0 68 :3 0 79
:3 0 22dd 22de 0
6a :4 0 1d2 :4 0
6d :2 0 6e :3 0
13ba 22e2 22e4 :3 0
6d :2 0 82 :4 0
13bd 22e6 22e8 :3 0
6d :2 0 a2 :4 0
13c0 22ea 22ec :3 0
6d :2 0 9c :3 0
13c3 22ee 22f0 :3 0
6d :2 0 a3 :4 0
13c6 22f2 22f4 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 13c9 22f7
22fb 13cd 22f6 22fd
:3 0 13d0 22df 22ff
:2 0 2301 13d3 2302
22dc 2301 0 2303
13d5 0 2304 13d7
2307 :3 0 2307 0
2307 2306 2304 2305
:6 0 2309 51 :3 0
13da 230b 13dc 230a
2309 :2 0 230c 13de
:2 0 230e 0 230e
230d 22bb 230c :6 0
2310 40 :3 0 13e1
2312 2106 229b 0
2313 0 2310 0
2313 13e3 0 2314
13e6 2316 1ecd 20fc
0 2317 0 2314
0 2317 13e8 0
264e 15 :3 0 9b
:3 0 2318 2319 0
15 :3 0 8f :2 0
a7 :3 0 231b 231d
0 13ed 231c 231f
:3 0 2320 :2 0 72
:3 0 44 :3 0 30
:2 0 13f0 2322 2325
8f :2 0 27 :2 0
13f5 2327 2329 :3 0
46 :3 0 113 :2 0
232b 232c 0 232e
13f8 2439 19 :3 0
96 :2 0 13fa 2330
2331 :3 0 2332 :2 0
62 :3 0 8f :2 0
27 :2 0 13fe 2335
2337 :3 0 47 :3 0
30 :2 0 2339 233a
0 23a6 157 :3 0
158 :3 0 47 :3 0
159 :3 0 b8 :3 0
17 :3 0 15a :3 0
19 :3 0 15b :3 0
133 :3 0 a4 :3 0
1f :3 0 133 :3 0
a4 :3 0 22 :4 0
1d3 1 :8 0 2351
15 :3 0 9b :3 0
234c 234d 0 9c
:3 0 234e 234f 0
2351 1401 23a4 9d
:3 0 15 :3 0 9b
:3 0 2353 2354 0
9c :3 0 2355 2356
0 2358 1404 235a
1406 2359 2358 :2 0
23a2 9e :3 0 15
:3 0 9b :3 0 235d
235e 0 9c :3 0
235f 2360 0 239a
65 :3 0 66 :3 0
2362 2363 0 65
:3 0 76 :3 0 2365
2366 0 9f :2 0
2 :4 0 1d4 :2 0
78 :2 0 27 :2 0
1408 236b 236d :3 0
140b 2367 236f 2364
2371 2370 :2 0 68
:3 0 79 :3 0 2373
2374 0 6a :4 0
1d5 :4 0 6d :2 0
6e :3 0 140f 2378
237a :3 0 6d :2 0
82 :4 0 1412 237c
237e :3 0 6d :2 0
a2 :4 0 1415 2380
2382 :3 0 6d :2 0
9c :3 0 1418 2384
2386 :3 0 6d :2 0
a3 :4 0 141b 2388
238a :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
141e 238d 2391 1422
238c 2393 :3 0 1425
2375 2395 :2 0 2397
1428 2398 2372 2397
0 2399 142a 0
239a 142c 239d :3 0
239d 0 239d 239c
239a 239b :6 0 239f
53 :3 0 142f 23a1
1431 23a0 239f :2 0
23a2 1433 :2 0 23a4
0 23a4 23a3 2351
23a2 :6 0 23a6 40
:3 0 1436 2412 47
:3 0 30 :2 0 23a7
23a8 0 2411 157
:3 0 158 :3 0 47
:3 0 159 :3 0 b8
:3 0 17 :3 0 15a
:3 0 19 :3 0 15b
:3 0 133 :3 0 a4
:3 0 1f :4 0 1d6
1 :8 0 23bc 15
:3 0 9b :3 0 23b7
23b8 0 9c :3 0
23b9 23ba 0 23bc
1439 240f 9d :3 0
15 :3 0 9b :3 0
23be 23bf 0 9c
:3 0 23c0 23c1 0
23c3 143c 23c5 143e
23c4 23c3 :2 0 240d
9e :3 0 15 :3 0
9b :3 0 23c8 23c9
0 9c :3 0 23ca
23cb 0 2405 65
:3 0 66 :3 0 23cd
23ce 0 65 :3 0
76 :3 0 23d0 23d1
0 9f :2 0 2
:4 0 1d7 :2 0 78
:2 0 27 :2 0 1440
23d6 23d8 :3 0 1443
23d2 23da 23cf 23dc
23db :2 0 68 :3 0
79 :3 0 23de 23df
0 6a :4 0 1d8
:4 0 6d :2 0 6e
:3 0 1447 23e3 23e5
:3 0 6d :2 0 82
:4 0 144a 23e7 23e9
:3 0 6d :2 0 a2
:4 0 144d 23eb 23ed
:3 0 6d :2 0 9c
:3 0 1450 23ef 23f1
:3 0 6d :2 0 a3
:4 0 1453 23f3 23f5
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 1456
23f8 23fc 145a 23f7
23fe :3 0 145d 23e0
2400 :2 0 2402 1460
2403 23dd 2402 0
2404 1462 0 2405
1464 2408 :3 0 2408
0 2408 2407 2405
2406 :6 0 240a 55
:3 0 1467 240c 1469
240b 240a :2 0 240d
146b :2 0 240f 0
240f 240e 23bc 240d
:6 0 2411 40 :3 0
146e 2413 2338 23a6
0 2414 0 2411
0 2414 1471 0
2432 72 :3 0 47
:3 0 30 :2 0 1474
2415 2418 72 :3 0
a8 :2 0 37 :3 0
30 :2 0 1477 241a
241e 147c 241b 2420
:3 0 2f :3 0 72
:3 0 2f :3 0 30
:2 0 147f 2423 2426
78 :2 0 27 :2 0
1482 2428 242a :3 0
2422 242b 0 242f
1d9 :3 0 242d :4 0
242f 1485 2430 2421
242f 0 2431 1488
0 2432 148a 2433
2333 2432 0 2434
148d 0 2438 46
:3 0 27 :2 0 2435
2436 0 2438 148f
243a 232a 232e 0
243b 0 2438 0
243b 1492 0 243c
1495 244b 2f :3 0
72 :3 0 2f :3 0
30 :2 0 1497 243e
2441 78 :2 0 27
:2 0 149a 2443 2445
:3 0 243d 2446 0
244a 1d9 :3 0 2448
:4 0 244a 149d 244c
2321 243c 0 244d
0 244a 0 244d
14a0 0 264e 21
:3 0 21 :3 0 244e
244f 0 264e 3f
:3 0 30 :2 0 2451
2452 0 264e 97
:3 0 19a :3 0 133
:3 0 a4 :3 0 21
:3 0 97 :3 0 19b
:3 0 1f :3 0 21
:3 0 99 :4 0 1da
1 :8 0 2464 15
:3 0 9b :3 0 245f
2460 0 9c :3 0
2461 2462 0 2464
14a3 24b7 9d :3 0
15 :3 0 9b :3 0
2466 2467 0 9c
:3 0 2468 2469 0
246b 14a6 246d 14a8
246c 246b :2 0 24b5
9e :3 0 15 :3 0
9b :3 0 2470 2471
0 9c :3 0 2472
2473 0 24ad 65
:3 0 66 :3 0 2475
2476 0 65 :3 0
76 :3 0 2478 2479
0 9f :2 0 2
:4 0 1db :2 0 78
:2 0 27 :2 0 14aa
247e 2480 :3 0 14ad
247a 2482 2477 2484
2483 :2 0 68 :3 0
79 :3 0 2486 2487
0 6a :4 0 1dc
:4 0 6d :2 0 6e
:3 0 14b1 248b 248d
:3 0 6d :2 0 82
:4 0 14b4 248f 2491
:3 0 6d :2 0 a2
:4 0 14b7 2493 2495
:3 0 6d :2 0 9c
:3 0 14ba 2497 2499
:3 0 6d :2 0 a3
:4 0 14bd 249b 249d
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 14c0
24a0 24a4 14c4 249f
24a6 :3 0 14c7 2488
24a8 :2 0 24aa 14ca
24ab 2485 24aa 0
24ac 14cc 0 24ad
14ce 24b0 :3 0 24b0
0 24b0 24af 24ad
24ae :6 0 24b2 57
:3 0 14d1 24b4 14d3
24b3 24b2 :2 0 24b5
14d5 :2 0 24b7 0
24b7 24b6 2464 24b5
:6 0 264e 40 :3 0
133 :3 0 a4 :3 0
1f :3 0 133 :3 0
a4 :3 0 21 :3 0
1f :3 0 21 :3 0
21 :3 0 99 :4 0
1dd 1 :8 0 24c9
15 :3 0 9b :3 0
24c4 24c5 0 9c
:3 0 24c6 24c7 0
24c9 14d8 251c 9d
:3 0 15 :3 0 9b
:3 0 24cb 24cc 0
9c :3 0 24cd 24ce
0 24d0 14db 24d2
14dd 24d1 24d0 :2 0
251a 9e :3 0 15
:3 0 9b :3 0 24d5
24d6 0 9c :3 0
24d7 24d8 0 2512
65 :3 0 66 :3 0
24da 24db 0 65
:3 0 76 :3 0 24dd
24de 0 9f :2 0
2 :4 0 1de :2 0
78 :2 0 27 :2 0
14df 24e3 24e5 :3 0
14e2 24df 24e7 24dc
24e9 24e8 :2 0 68
:3 0 79 :3 0 24eb
24ec 0 6a :4 0
1df :4 0 6d :2 0
6e :3 0 14e6 24f0
24f2 :3 0 6d :2 0
82 :4 0 14e9 24f4
24f6 :3 0 6d :2 0
a2 :4 0 14ec 24f8
24fa :3 0 6d :2 0
9c :3 0 14ef 24fc
24fe :3 0 6d :2 0
a3 :4 0 14f2 2500
2502 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
14f5 2505 2509 14f9
2504 250b :3 0 14fc
24ed 250d :2 0 250f
14ff 2510 24ea 250f
0 2511 1501 0
2512 1503 2515 :3 0
2515 0 2515 2514
2512 2513 :6 0 2517
59 :3 0 1506 2519
1508 2518 2517 :2 0
251a 150a :2 0 251c
0 251c 251b 24c9
251a :6 0 264e 40
:3 0 45 :3 0 1a2
:2 0 251e 251f 0
264e 22 :3 0 6
:3 0 2521 2522 0
264e 72 :3 0 33
:3 0 30 :2 0 150d
2524 2527 8f :2 0
30 :2 0 1512 2529
252b :3 0 3f :3 0
114 :2 0 252d 252e
0 2530 1515 2531
252c 2530 0 2532
1517 0 264e 61
:3 0 1a3 :3 0 19
:3 0 17 :3 0 1a
:3 0 1d :3 0 4e
:3 0 32 :3 0 23
:3 0 23 :3 0 23
:3 0 23 :3 0 21
:3 0 22 :3 0 41
:3 0 37 :3 0 35
:3 0 38 :3 0 39
:3 0 34 :3 0 45
:3 0 26 :3 0 33
:3 0 31 :3 0 3b
:3 0 36 :3 0 3f
:3 0 3d :3 0 43
:3 0 1c :3 0 30
:2 0 30 :2 0 7d
:2 0 7d :2 0 30
:2 0 1519 2534 2556
2533 2557 0 264e
61 :3 0 8f :2 0
30 :2 0 153d 255a
255c :3 0 72 :3 0
33 :3 0 30 :2 0
1540 255e 2561 8f
:2 0 30 :2 0 1545
2563 2565 :3 0 1a4
:3 0 1a5 :3 0 1a6
:3 0 1d :4 0 1a7
1 :8 0 2581 1a8
:4 0 256c :3 0 8a
:3 0 8f :2 0 154a
256f 2570 :3 0 15
:3 0 9b :3 0 2572
2573 0 30 :2 0
2574 2575 0 2577
154d 257e 15 :3 0
9b :3 0 2578 2579
0 112 :2 0 257a
257b 0 257d 154f
257f 2571 2577 0
2580 0 257d 0
2580 1551 0 2581
1554 25d4 9d :3 0
15 :3 0 9b :3 0
2583 2584 0 9c
:3 0 2585 2586 0
2588 1557 258a 1559
2589 2588 :2 0 25d2
9e :3 0 15 :3 0
9b :3 0 258d 258e
0 9c :3 0 258f
2590 0 25ca 65
:3 0 66 :3 0 2592
2593 0 65 :3 0
76 :3 0 2595 2596
0 9f :2 0 2
:4 0 1e0 :2 0 78
:2 0 27 :2 0 155b
259b 259d :3 0 155e
2597 259f 2594 25a1
25a0 :2 0 68 :3 0
79 :3 0 25a3 25a4
0 6a :4 0 1e1
:4 0 6d :2 0 6e
:3 0 1562 25a8 25aa
:3 0 6d :2 0 82
:4 0 1565 25ac 25ae
:3 0 6d :2 0 a2
:4 0 1568 25b0 25b2
:3 0 6d :2 0 9c
:3 0 156b 25b4 25b6
:3 0 6d :2 0 a3
:4 0 156e 25b8 25ba
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 1571
25bd 25c1 1575 25bc
25c3 :3 0 1578 25a5
25c5 :2 0 25c7 157b
25c8 25a2 25c7 0
25c9 157d 0 25ca
157f 25cd :3 0 25cd
0 25cd 25cc 25ca
25cb :6 0 25cf 5b
:3 0 1582 25d1 1584
25d0 25cf :2 0 25d2
1586 :2 0 25d4 0
25d4 25d3 2581 25d2
:6 0 25d6 40 :3 0
1589 2647 1a4 :3 0
1a5 :3 0 1a6 :3 0
1d :4 0 1ab 1
:8 0 25f1 1a8 :4 0
25dc :3 0 8a :3 0
8f :2 0 158d 25df
25e0 :3 0 15 :3 0
9b :3 0 25e2 25e3
0 30 :2 0 25e4
25e5 0 25e7 1590
25ee 15 :3 0 9b
:3 0 25e8 25e9 0
112 :2 0 25ea 25eb
0 25ed 1592 25ef
25e1 25e7 0 25f0
0 25ed 0 25f0
1594 0 25f1 1597
2644 9d :3 0 15
:3 0 9b :3 0 25f3
25f4 0 9c :3 0
25f5 25f6 0 25f8
159a 25fa 159c 25f9
25f8 :2 0 2642 9e
:3 0 15 :3 0 9b
:3 0 25fd 25fe 0
9c :3 0 25ff 2600
0 263a 65 :3 0
66 :3 0 2602 2603
0 65 :3 0 76
:3 0 2605 2606 0
9f :2 0 2 :4 0
1e2 :2 0 78 :2 0
27 :2 0 159e 260b
260d :3 0 15a1 2607
260f 2604 2611 2610
:2 0 68 :3 0 79
:3 0 2613 2614 0
6a :4 0 1e3 :4 0
6d :2 0 6e :3 0
15a5 2618 261a :3 0
6d :2 0 82 :4 0
15a8 261c 261e :3 0
6d :2 0 a2 :4 0
15ab 2620 2622 :3 0
6d :2 0 9c :3 0
15ae 2624 2626 :3 0
6d :2 0 a3 :4 0
15b1 2628 262a :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 15b4 262d
2631 15b8 262c 2633
:3 0 15bb 2615 2635
:2 0 2637 15be 2638
2612 2637 0 2639
15c0 0 263a 15c2
263d :3 0 263d 0
263d 263c 263a 263b
:6 0 263f 5d :3 0
15c5 2641 15c7 2640
263f :2 0 2642 15c9
:2 0 2644 0 2644
2643 25f1 2642 :6 0
2646 40 :3 0 15cc
2648 2566 25d6 0
2649 0 2646 0
2649 15ce 0 264a
15d1 264b 255d 264a
0 264c 15d3 0
264e ae :3 0 15d5
2718 72 :3 0 46
:3 0 30 :2 0 15e1
264f 2652 8f :2 0
30 :2 0 15e6 2654
2656 :3 0 21 :3 0
1f :3 0 2658 2659
0 2716 22 :3 0
6 :3 0 265b 265c
0 2716 a4 :3 0
26 :3 0 27 :2 0
27 :2 0 15e9 265e
2662 8f :2 0 27
:4 0 15ef 2664 2666
:3 0 45 :3 0 84
:3 0 106 :3 0 2669
266a 0 2668 266b
0 266d 15f2 2676
45 :3 0 72 :3 0
3a :3 0 30 :2 0
15f4 266f 2672 266e
2673 0 2675 15f7
2677 2667 266d 0
2678 0 2675 0
2678 15f9 0 2716
61 :3 0 1a3 :3 0
28 :3 0 17 :3 0
1a :3 0 1d :3 0
4e :3 0 32 :3 0
23 :3 0 23 :3 0
23 :3 0 23 :3 0
21 :3 0 22 :3 0
41 :3 0 37 :3 0
35 :3 0 38 :3 0
39 :3 0 34 :3 0
45 :3 0 26 :3 0
33 :3 0 31 :3 0
3b :3 0 36 :3 0
3f :3 0 3d :3 0
43 :3 0 1c :3 0
30 :2 0 30 :2 0
7d :2 0 7d :2 0
30 :2 0 15fc 267a
269c 2679 269d 0
2716 61 :3 0 8f
:2 0 30 :2 0 1620
26a0 26a2 :3 0 1a4
:3 0 1a5 :3 0 1a6
:3 0 1d :4 0 1a7
1 :8 0 26be 1a8
:4 0 26a9 :3 0 8a
:3 0 8f :2 0 1625
26ac 26ad :3 0 15
:3 0 9b :3 0 26af
26b0 0 30 :2 0
26b1 26b2 0 26b4
1628 26bb 15 :3 0
9b :3 0 26b5 26b6
0 112 :2 0 26b7
26b8 0 26ba 162a
26bc 26ae 26b4 0
26bd 0 26ba 0
26bd 162c 0 26be
162f 2711 9d :3 0
15 :3 0 9b :3 0
26c0 26c1 0 9c
:3 0 26c2 26c3 0
26c5 1632 26c7 1634
26c6 26c5 :2 0 270f
9e :3 0 15 :3 0
9b :3 0 26ca 26cb
0 9c :3 0 26cc
26cd 0 2707 65
:3 0 66 :3 0 26cf
26d0 0 65 :3 0
76 :3 0 26d2 26d3
0 9f :2 0 2
:4 0 1e4 :2 0 78
:2 0 27 :2 0 1636
26d8 26da :3 0 1639
26d4 26dc 26d1 26de
26dd :2 0 68 :3 0
79 :3 0 26e0 26e1
0 6a :4 0 1e5
:4 0 6d :2 0 6e
:3 0 163d 26e5 26e7
:3 0 6d :2 0 82
:4 0 1640 26e9 26eb
:3 0 6d :2 0 a2
:4 0 1643 26ed 26ef
:3 0 6d :2 0 9c
:3 0 1646 26f1 26f3
:3 0 6d :2 0 a3
:4 0 1649 26f5 26f7
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 164c
26fa 26fe 1650 26f9
2700 :3 0 1653 26e2
2702 :2 0 2704 1656
2705 26df 2704 0
2706 1658 0 2707
165a 270a :3 0 270a
0 270a 2709 2707
2708 :6 0 270c 5f
:3 0 165d 270e 165f
270d 270c :2 0 270f
1661 :2 0 2711 0
2711 2710 26be 270f
:6 0 2713 40 :3 0
1664 2714 26a3 2713
0 2715 1666 0
2716 1668 2717 2657
2716 0 2719 1ec8
264e 0 2719 166e
0 2729 2f :3 0
72 :3 0 2f :3 0
30 :2 0 1671 271b
271e 78 :2 0 27
:2 0 1674 2720 2722
:3 0 271a 2723 0
2729 1d9 :5 0 2727
61 0 2728 1677
2727 2726 2729 1679
272b 1b4 :3 0 1d7a
2729 :4 0 272c 1689
272d 1d6b 272c 0
272e 168c 0 272f
168e 2731 d8a 1d3c
0 2732 0 272f
0 2732 1691 0
3255 61 :3 0 b7
:2 0 30 :2 0 1696
2734 2736 :3 0 2737
:2 0 72 :3 0 32
:3 0 30 :2 0 1699
2739 273c b2 :2 0
30 :2 0 169e 273e
2740 :3 0 2741 :2 0
2738 2743 2742 :2 0
72 :3 0 42 :3 0
30 :2 0 16a1 2745
2748 8f :2 0 30
:2 0 16a6 274a 274c
:3 0 180 :3 0 17d
:3 0 28 :4 0 1e6
1 :8 0 2767 1a8
:4 0 2752 :3 0 8a
:3 0 8f :2 0 16ab
2755 2756 :3 0 15
:3 0 9b :3 0 2758
2759 0 30 :2 0
275a 275b 0 275d
16ae 2764 15 :3 0
9b :3 0 275e 275f
0 112 :2 0 2760
2761 0 2763 16b0
2765 2757 275d 0
2766 0 2763 0
2766 16b2 0 2767
16b5 27ba 9d :3 0
15 :3 0 9b :3 0
2769 276a 0 9c
:3 0 276b 276c 0
276e 16b8 2770 16ba
276f 276e :2 0 27b8
9e :3 0 15 :3 0
9b :3 0 2773 2774
0 9c :3 0 2775
2776 0 27b0 65
:3 0 66 :3 0 2778
2779 0 65 :3 0
76 :3 0 277b 277c
0 9f :2 0 2
:4 0 1e7 :2 0 78
:2 0 27 :2 0 16bc
2781 2783 :3 0 16bf
277d 2785 277a 2787
2786 :2 0 68 :3 0
79 :3 0 2789 278a
0 6a :4 0 1e8
:4 0 6d :2 0 6e
:3 0 16c3 278e 2790
:3 0 6d :2 0 82
:4 0 16c6 2792 2794
:3 0 6d :2 0 a2
:4 0 16c9 2796 2798
:3 0 6d :2 0 9c
:3 0 16cc 279a 279c
:3 0 6d :2 0 a3
:4 0 16cf 279e 27a0
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 16d2
27a3 27a7 16d6 27a2
27a9 :3 0 16d9 278b
27ab :2 0 27ad 16dc
27ae 2788 27ad 0
27af 16de 0 27b0
16e0 27b3 :3 0 27b3
0 27b3 27b2 27b0
27b1 :6 0 27b5 61
:3 0 16e3 27b7 16e5
27b6 27b5 :2 0 27b8
16e7 :2 0 27ba 0
27ba 27b9 2767 27b8
:6 0 27bc 1 :3 0
16ea 2830 180 :3 0
17f :3 0 1e :3 0
17e :3 0 42 :3 0
17d :3 0 28 :4 0
1e9 1 :8 0 27da
1a8 :4 0 27c5 :3 0
8a :3 0 8f :2 0
16ee 27c8 27c9 :3 0
15 :3 0 9b :3 0
27cb 27cc 0 30
:2 0 27cd 27ce 0
27d0 16f1 27d7 15
:3 0 9b :3 0 27d1
27d2 0 112 :2 0
27d3 27d4 0 27d6
16f3 27d8 27ca 27d0
0 27d9 0 27d6
0 27d9 16f5 0
27da 16f8 282d 9d
:3 0 15 :3 0 9b
:3 0 27dc 27dd 0
9c :3 0 27de 27df
0 27e1 16fb 27e3
16fd 27e2 27e1 :2 0
282b 9e :3 0 15
:3 0 9b :3 0 27e6
27e7 0 9c :3 0
27e8 27e9 0 2823
65 :3 0 66 :3 0
27eb 27ec 0 65
:3 0 76 :3 0 27ee
27ef 0 9f :2 0
2 :4 0 1ea :2 0
78 :2 0 27 :2 0
16ff 27f4 27f6 :3 0
1702 27f0 27f8 27ed
27fa 27f9 :2 0 68
:3 0 79 :3 0 27fc
27fd 0 6a :4 0
1eb :4 0 6d :2 0
6e :3 0 1706 2801
2803 :3 0 6d :2 0
82 :4 0 1709 2805
2807 :3 0 6d :2 0
a2 :4 0 170c 2809
280b :3 0 6d :2 0
9c :3 0 170f 280d
280f :3 0 6d :2 0
a3 :4 0 1712 2811
2813 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
1715 2816 281a 1719
2815 281c :3 0 171c
27fe 281e :2 0 2820
171f 2821 27fb 2820
0 2822 1721 0
2823 1723 2826 :3 0
2826 0 2826 2825
2823 2824 :6 0 2828
63 :3 0 1726 282a
1728 2829 2828 :2 0
282b 172a :2 0 282d
0 282d 282c 27da
282b :6 0 282f 1
:3 0 172d 2831 274d
27bc 0 2832 0
282f 0 2832 172f
0 2a05 61 :3 0
8f :2 0 112 :2 0
1734 2834 2836 :3 0
65 :3 0 66 :3 0
2838 2839 0 65
:3 0 76 :3 0 283b
283c 0 18 :2 0
2 :4 0 1ec :2 0
78 :2 0 27 :2 0
1737 2841 2843 :3 0
173a 283d 2845 283a
2847 2846 :2 0 68
:3 0 79 :3 0 2849
284a 0 6a :4 0
1ed :4 0 6d :2 0
6e :3 0 173e 284e
2850 :3 0 6d :2 0
82 :4 0 1741 2852
2854 :3 0 6d :2 0
83 :4 0 1744 2856
2858 :3 0 6d :2 0
72 :3 0 73 :3 0
84 :3 0 17a :3 0
285d 285e 0 1747
285c 2860 74 :4 0
1749 285b 2863 174c
285a 2865 :3 0 6d
:2 0 e5 :4 0 174f
2867 2869 :3 0 6d
:2 0 70 :4 0 1752
286b 286d :3 0 6d
:2 0 1d :3 0 1755
286f 2871 :3 0 6d
:2 0 70 :4 0 1758
2873 2875 :3 0 175b
284b 2877 :2 0 2879
175e 287a 2848 2879
0 287b 1760 0
28a6 65 :3 0 66
:3 0 287c 287d 0
65 :3 0 76 :3 0
287f 2880 0 27
:2 0 2 :4 0 1ee
:2 0 78 :2 0 27
:2 0 1762 2885 2887
:3 0 1765 2881 2889
287e 288b 288a :2 0
68 :3 0 79 :3 0
288d 288e 0 6a
:4 0 1ef :4 0 6d
:2 0 6e :3 0 1769
2892 2894 :3 0 176c
288f 2896 :2 0 2898
176f 2899 288c 2898
0 289a 1771 0
28a6 88 :3 0 e8
:3 0 289b 289c 0
84 :3 0 17a :3 0
289e 289f 0 1d
:3 0 8a :3 0 1773
289d 28a3 :2 0 28a6
ae :3 0 1777 2a02
61 :3 0 84 :3 0
8f :2 0 1f0 :3 0
28a8 28aa 0 177d
28a9 28ac :3 0 65
:3 0 66 :3 0 28ae
28af 0 65 :3 0
76 :3 0 28b1 28b2
0 18 :2 0 2
:4 0 1f1 :2 0 78
:2 0 27 :2 0 1780
28b7 28b9 :3 0 1783
28b3 28bb 28b0 28bd
28bc :2 0 68 :3 0
79 :3 0 28bf 28c0
0 6a :4 0 1f2
:4 0 6d :2 0 6e
:3 0 1787 28c4 28c6
:3 0 6d :2 0 82
:4 0 178a 28c8 28ca
:3 0 6d :2 0 83
:4 0 178d 28cc 28ce
:3 0 6d :2 0 72
:3 0 73 :3 0 84
:3 0 1f0 :3 0 28d3
28d4 0 1790 28d2
28d6 74 :4 0 1792
28d1 28d9 1795 28d0
28db :3 0 6d :2 0
e5 :4 0 1798 28dd
28df :3 0 6d :2 0
70 :4 0 179b 28e1
28e3 :3 0 6d :2 0
1d :3 0 179e 28e5
28e7 :3 0 6d :2 0
70 :4 0 17a1 28e9
28eb :3 0 17a4 28c1
28ed :2 0 28ef 17a7
28f0 28be 28ef 0
28f1 17a9 0 291c
65 :3 0 66 :3 0
28f2 28f3 0 65
:3 0 76 :3 0 28f5
28f6 0 27 :2 0
2 :4 0 1f3 :2 0
78 :2 0 27 :2 0
17ab 28fb 28fd :3 0
17ae 28f7 28ff 28f4
2901 2900 :2 0 68
:3 0 79 :3 0 2903
2904 0 6a :4 0
1f4 :4 0 6d :2 0
6e :3 0 17b2 2908
290a :3 0 17b5 2905
290c :2 0 290e 17b8
290f 2902 290e 0
2910 17ba 0 291c
88 :3 0 e8 :3 0
2911 2912 0 84
:3 0 1f0 :3 0 2914
2915 0 1d :3 0
8a :3 0 17bc 2913
2919 :2 0 291c ae
:3 0 17c0 291d 28ad
291c 0 2a04 61
:3 0 84 :3 0 8f
:2 0 1f5 :3 0 291f
2921 0 17c6 2920
2923 :3 0 65 :3 0
66 :3 0 2925 2926
0 65 :3 0 76
:3 0 2928 2929 0
18 :2 0 2 :4 0
1f6 :2 0 78 :2 0
27 :2 0 17c9 292e
2930 :3 0 17cc 292a
2932 2927 2934 2933
:2 0 68 :3 0 79
:3 0 2936 2937 0
6a :4 0 1f7 :4 0
6d :2 0 6e :3 0
17d0 293b 293d :3 0
6d :2 0 82 :4 0
17d3 293f 2941 :3 0
6d :2 0 83 :4 0
17d6 2943 2945 :3 0
6d :2 0 72 :3 0
73 :3 0 84 :3 0
1f5 :3 0 294a 294b
0 17d9 2949 294d
74 :4 0 17db 2948
2950 17de 2947 2952
:3 0 6d :2 0 e5
:4 0 17e1 2954 2956
:3 0 6d :2 0 70
:4 0 17e4 2958 295a
:3 0 6d :2 0 1d
:3 0 17e7 295c 295e
:3 0 6d :2 0 70
:4 0 17ea 2960 2962
:3 0 17ed 2938 2964
:2 0 2966 17f0 2967
2935 2966 0 2968
17f2 0 2992 65
:3 0 66 :3 0 2969
296a 0 65 :3 0
76 :3 0 296c 296d
0 27 :2 0 2
:4 0 1f8 :2 0 78
:2 0 27 :2 0 17f4
2972 2974 :3 0 17f7
296e 2976 296b 2978
2977 :2 0 68 :3 0
79 :3 0 297a 297b
0 6a :4 0 1f9
:4 0 6d :2 0 6e
:3 0 17fb 297f 2981
:3 0 17fe 297c 2983
:2 0 2985 1801 2986
2979 2985 0 2987
1803 0 2992 88
:3 0 e8 :3 0 2988
2989 0 84 :3 0
1f5 :3 0 298b 298c
0 1d :3 0 8a
:3 0 1805 298a 2990
:2 0 2992 1809 2993
2924 2992 0 2a04
65 :3 0 66 :3 0
2994 2995 0 65
:3 0 76 :3 0 2997
2998 0 18 :2 0
2 :4 0 1fa :2 0
78 :2 0 27 :2 0
180d 299d 299f :3 0
1810 2999 29a1 2996
29a3 29a2 :2 0 68
:3 0 79 :3 0 29a5
29a6 0 6a :4 0
1fb :4 0 6d :2 0
6e :3 0 1814 29aa
29ac :3 0 6d :2 0
82 :4 0 1817 29ae
29b0 :3 0 6d :2 0
83 :4 0 181a 29b2
29b4 :3 0 6d :2 0
72 :3 0 73 :3 0
84 :3 0 154 :3 0
29b9 29ba 0 181d
29b8 29bc 74 :4 0
181f 29b7 29bf 1822
29b6 29c1 :3 0 6d
:2 0 e5 :4 0 1825
29c3 29c5 :3 0 6d
:2 0 70 :4 0 1828
29c7 29c9 :3 0 6d
:2 0 28 :3 0 182b
29cb 29cd :3 0 6d
:2 0 70 :4 0 182e
29cf 29d1 :3 0 1831
29a7 29d3 :2 0 29d5
1834 29d6 29a4 29d5
0 29d7 1836 0
2a01 65 :3 0 66
:3 0 29d8 29d9 0
65 :3 0 76 :3 0
29db 29dc 0 27
:2 0 2 :4 0 1fc
:2 0 78 :2 0 27
:2 0 1838 29e1 29e3
:3 0 183b 29dd 29e5
29da 29e7 29e6 :2 0
68 :3 0 79 :3 0
29e9 29ea 0 6a
:4 0 1fd :4 0 6d
:2 0 6e :3 0 183f
29ee 29f0 :3 0 1842
29eb 29f2 :2 0 29f4
1845 29f5 29e8 29f4
0 29f6 1847 0
2a01 88 :3 0 e8
:3 0 29f7 29f8 0
84 :3 0 154 :3 0
29fa 29fb 0 28
:3 0 8a :3 0 1849
29f9 29ff :2 0 2a01
184d 2a03 2837 28a6
0 2a04 0 2a01
0 2a04 1851 0
2a05 1856 2a06 2744
2a05 0 2a07 1859
0 3255 72 :3 0
1b0 :3 0 2b :3 0
185b 2a09 2a0b 30
:2 0 185d 2a08 2a0e
b2 :2 0 30 :2 0
1862 2a10 2a12 :3 0
2a13 :2 0 72 :3 0
1b0 :3 0 2c :3 0
1865 2a16 2a18 30
:2 0 1867 2a15 2a1b
b2 :2 0 30 :2 0
186c 2a1d 2a1f :3 0
2a20 :2 0 2a14 2a22
2a21 :2 0 1fe :3 0
1ff :3 0 200 :4 0
2a26 :4 0 2a27 :2 0
2d32 15 :3 0 9b
:3 0 2a29 2a2a 0
30 :2 0 2a2b 2a2c
0 2d32 50 :3 0
201 :4 0 6d :2 0
202 :4 0 186f 2a30
2a32 :3 0 6d :2 0
203 :4 0 1872 2a34
2a36 :3 0 6d :2 0
204 :4 0 1875 2a38
2a3a :3 0 6d :2 0
205 :4 0 1878 2a3c
2a3e :3 0 6d :2 0
206 :4 0 187b 2a40
2a42 :3 0 6d :2 0
17 :3 0 187e 2a44
2a46 :3 0 6d :2 0
207 :4 0 1881 2a48
2a4a :3 0 6d :2 0
208 :4 0 1884 2a4c
2a4e :3 0 6d :2 0
2b :3 0 1887 2a50
2a52 :3 0 6d :2 0
209 :4 0 188a 2a54
2a56 :3 0 6d :2 0
2c :3 0 188d 2a58
2a5a :3 0 6d :2 0
20a :4 0 1890 2a5c
2a5e :3 0 2a2e 2a5f
0 2d32 1fe :3 0
1ff :3 0 50 :3 0
2a63 :4 0 2a64 :2 0
2a7b 1a8 :4 0 2a66
:3 0 8a :3 0 8f
:2 0 1895 2a69 2a6a
:3 0 15 :3 0 9b
:3 0 2a6c 2a6d 0
30 :2 0 2a6e 2a6f
0 2a71 1898 2a78
15 :3 0 9b :3 0
2a72 2a73 0 112
:2 0 2a74 2a75 0
2a77 189a 2a79 2a6b
2a71 0 2a7a 0
2a77 0 2a7a 189c
0 2a7b 189f 2ad9
9d :3 0 15 :3 0
9b :3 0 2a7d 2a7e
0 9c :3 0 2a7f
2a80 0 2a82 18a2
2a84 18a4 2a83 2a82
:2 0 2ad7 9e :3 0
15 :3 0 9b :3 0
2a87 2a88 0 9c
:3 0 2a89 2a8a 0
2acf 65 :3 0 66
:3 0 2a8c 2a8d 0
65 :3 0 76 :3 0
2a8f 2a90 0 9f
:2 0 2 :4 0 20b
:2 0 78 :2 0 27
:2 0 18a6 2a95 2a97
:3 0 18a9 2a91 2a99
2a8e 2a9b 2a9a :2 0
68 :3 0 79 :3 0
2a9d 2a9e 0 6a
:4 0 20c :4 0 6d
:2 0 6e :3 0 18ad
2aa2 2aa4 :3 0 6d
:2 0 82 :4 0 18b0
2aa6 2aa8 :3 0 6d
:2 0 a2 :4 0 18b3
2aaa 2aac :3 0 6d
:2 0 9c :3 0 18b6
2aae 2ab0 :3 0 6d
:2 0 a3 :4 0 18b9
2ab2 2ab4 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 18bc 2ab7 2abb
18c0 2ab6 2abd :3 0
18c3 2a9f 2abf :2 0
2acc 68 :3 0 79
:3 0 2ac1 2ac2 0
6a :4 0 20d :4 0
6d :2 0 50 :3 0
18c6 2ac6 2ac8 :3 0
18c9 2ac3 2aca :2 0
2acc 18cc 2acd 2a9c
2acc 0 2ace 18cf
0 2acf 18d1 2ad2
:3 0 2ad2 0 2ad2
2ad1 2acf 2ad0 :6 0
2ad4 65 :3 0 18d4
2ad6 18d6 2ad5 2ad4
:2 0 2ad7 18d8 :2 0
2ad9 0 2ad9 2ad8
2a7b 2ad7 :6 0 2d32
1 :3 0 1fe :3 0
1ff :3 0 20e :4 0
2add :4 0 2ade :2 0
2d32 15 :3 0 9b
:3 0 2ae0 2ae1 0
30 :2 0 2ae2 2ae3
0 2d32 50 :3 0
20f :4 0 6d :2 0
210 :4 0 18db 2ae7
2ae9 :3 0 6d :2 0
211 :4 0 18de 2aeb
2aed :3 0 6d :2 0
212 :4 0 18e1 2aef
2af1 :3 0 6d :2 0
213 :4 0 18e4 2af3
2af5 :3 0 6d :2 0
214 :4 0 18e7 2af7
2af9 :3 0 6d :2 0
17 :3 0 18ea 2afb
2afd :3 0 6d :2 0
207 :4 0 18ed 2aff
2b01 :3 0 6d :2 0
215 :4 0 18f0 2b03
2b05 :3 0 6d :2 0
2b :3 0 18f3 2b07
2b09 :3 0 6d :2 0
209 :4 0 18f6 2b0b
2b0d :3 0 6d :2 0
2c :3 0 18f9 2b0f
2b11 :3 0 6d :2 0
216 :4 0 18fc 2b13
2b15 :3 0 2ae5 2b16
0 2d32 1fe :3 0
1ff :3 0 50 :3 0
2b1a :4 0 2b1b :2 0
2b32 1a8 :4 0 2b1d
:3 0 8a :3 0 8f
:2 0 1901 2b20 2b21
:3 0 15 :3 0 9b
:3 0 2b23 2b24 0
30 :2 0 2b25 2b26
0 2b28 1904 2b2f
15 :3 0 9b :3 0
2b29 2b2a 0 112
:2 0 2b2b 2b2c 0
2b2e 1906 2b30 2b22
2b28 0 2b31 0
2b2e 0 2b31 1908
0 2b32 190b 2b90
9d :3 0 15 :3 0
9b :3 0 2b34 2b35
0 9c :3 0 2b36
2b37 0 2b39 190e
2b3b 1910 2b3a 2b39
:2 0 2b8e 9e :3 0
15 :3 0 9b :3 0
2b3e 2b3f 0 9c
:3 0 2b40 2b41 0
2b86 65 :3 0 66
:3 0 2b43 2b44 0
65 :3 0 76 :3 0
2b46 2b47 0 9f
:2 0 2 :4 0 217
:2 0 78 :2 0 27
:2 0 1912 2b4c 2b4e
:3 0 1915 2b48 2b50
2b45 2b52 2b51 :2 0
68 :3 0 79 :3 0
2b54 2b55 0 6a
:4 0 218 :4 0 6d
:2 0 6e :3 0 1919
2b59 2b5b :3 0 6d
:2 0 82 :4 0 191c
2b5d 2b5f :3 0 6d
:2 0 a2 :4 0 191f
2b61 2b63 :3 0 6d
:2 0 9c :3 0 1922
2b65 2b67 :3 0 6d
:2 0 a3 :4 0 1925
2b69 2b6b :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 1928 2b6e 2b72
192c 2b6d 2b74 :3 0
192f 2b56 2b76 :2 0
2b83 68 :3 0 79
:3 0 2b78 2b79 0
6a :4 0 20d :4 0
6d :2 0 50 :3 0
1932 2b7d 2b7f :3 0
1935 2b7a 2b81 :2 0
2b83 1938 2b84 2b53
2b83 0 2b85 193b
0 2b86 193d 2b89
:3 0 2b89 0 2b89
2b88 2b86 2b87 :6 0
2b8b 67 :3 0 1940
2b8d 1942 2b8c 2b8b
:2 0 2b8e 1944 :2 0
2b90 0 2b90 2b8f
2b32 2b8e :6 0 2d32
1 :3 0 15 :3 0
9b :3 0 2b92 2b93
0 219 :4 0 2b95
2b96 :3 0 2b94 2b97
0 2d32 50 :3 0
21a :4 0 6d :2 0
21b :4 0 1947 2b9b
2b9d :3 0 6d :2 0
21c :4 0 194a 2b9f
2ba1 :3 0 6d :2 0
21d :4 0 194d 2ba3
2ba5 :3 0 6d :2 0
21e :4 0 1950 2ba7
2ba9 :3 0 6d :2 0
21f :4 0 1953 2bab
2bad :3 0 6d :2 0
220 :4 0 1956 2baf
2bb1 :3 0 6d :2 0
221 :4 0 1959 2bb3
2bb5 :3 0 6d :2 0
222 :4 0 195c 2bb7
2bb9 :3 0 6d :2 0
223 :4 0 195f 2bbb
2bbd :3 0 6d :2 0
224 :4 0 1962 2bbf
2bc1 :3 0 6d :2 0
225 :4 0 1965 2bc3
2bc5 :3 0 6d :2 0
226 :4 0 1968 2bc7
2bc9 :3 0 6d :2 0
17 :3 0 196b 2bcb
2bcd :3 0 6d :2 0
227 :4 0 196e 2bcf
2bd1 :3 0 6d :2 0
228 :4 0 1971 2bd3
2bd5 :3 0 6d :2 0
17 :3 0 1974 2bd7
2bd9 :3 0 6d :2 0
229 :4 0 1977 2bdb
2bdd :3 0 6d :2 0
22a :4 0 197a 2bdf
2be1 :3 0 6d :2 0
22b :4 0 197d 2be3
2be5 :3 0 6d :2 0
2b :3 0 1980 2be7
2be9 :3 0 6d :2 0
22c :4 0 1983 2beb
2bed :3 0 6d :2 0
22d :4 0 1986 2bef
2bf1 :3 0 6d :2 0
22e :4 0 1989 2bf3
2bf5 :3 0 6d :2 0
22f :4 0 198c 2bf7
2bf9 :3 0 6d :2 0
230 :4 0 198f 2bfb
2bfd :3 0 6d :2 0
223 :4 0 1992 2bff
2c01 :3 0 6d :2 0
231 :4 0 1995 2c03
2c05 :3 0 6d :2 0
232 :4 0 1998 2c07
2c09 :3 0 6d :2 0
233 :4 0 199b 2c0b
2c0d :3 0 6d :2 0
17 :3 0 199e 2c0f
2c11 :3 0 6d :2 0
234 :4 0 19a1 2c13
2c15 :3 0 6d :2 0
235 :4 0 19a4 2c17
2c19 :3 0 6d :2 0
236 :4 0 19a7 2c1b
2c1d :3 0 6d :2 0
237 :4 0 19aa 2c1f
2c21 :3 0 6d :2 0
238 :4 0 19ad 2c23
2c25 :3 0 6d :2 0
2c :3 0 19b0 2c27
2c29 :3 0 6d :2 0
22c :4 0 19b3 2c2b
2c2d :3 0 6d :2 0
239 :4 0 19b6 2c2f
2c31 :3 0 2b99 2c32
0 2d32 1fe :3 0
1ff :3 0 50 :3 0
2c36 :4 0 2c37 :2 0
2c4e 1a8 :4 0 2c39
:3 0 8a :3 0 8f
:2 0 19bb 2c3c 2c3d
:3 0 15 :3 0 9b
:3 0 2c3f 2c40 0
30 :2 0 2c41 2c42
0 2c44 19be 2c4b
15 :3 0 9b :3 0
2c45 2c46 0 112
:2 0 2c47 2c48 0
2c4a 19c0 2c4c 2c3e
2c44 0 2c4d 0
2c4a 0 2c4d 19c2
0 2c4e 19c5 2cac
9d :3 0 15 :3 0
9b :3 0 2c50 2c51
0 9c :3 0 2c52
2c53 0 2c55 19c8
2c57 19ca 2c56 2c55
:2 0 2caa 9e :3 0
15 :3 0 9b :3 0
2c5a 2c5b 0 9c
:3 0 2c5c 2c5d 0
2ca2 65 :3 0 66
:3 0 2c5f 2c60 0
65 :3 0 76 :3 0
2c62 2c63 0 9f
:2 0 2 :4 0 23a
:2 0 78 :2 0 27
:2 0 19cc 2c68 2c6a
:3 0 19cf 2c64 2c6c
2c61 2c6e 2c6d :2 0
68 :3 0 79 :3 0
2c70 2c71 0 6a
:4 0 23b :4 0 6d
:2 0 6e :3 0 19d3
2c75 2c77 :3 0 6d
:2 0 82 :4 0 19d6
2c79 2c7b :3 0 6d
:2 0 a2 :4 0 19d9
2c7d 2c7f :3 0 6d
:2 0 9c :3 0 19dc
2c81 2c83 :3 0 6d
:2 0 a3 :4 0 19df
2c85 2c87 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 19e2 2c8a 2c8e
19e6 2c89 2c90 :3 0
19e9 2c72 2c92 :2 0
2c9f 68 :3 0 79
:3 0 2c94 2c95 0
6a :4 0 20d :4 0
6d :2 0 50 :3 0
19ec 2c99 2c9b :3 0
19ef 2c96 2c9d :2 0
2c9f 19f2 2ca0 2c6f
2c9f 0 2ca1 19f5
0 2ca2 19f7 2ca5
:3 0 2ca5 0 2ca5
2ca4 2ca2 2ca3 :6 0
2ca7 69 :3 0 19fa
2ca9 19fc 2ca8 2ca7
:2 0 2caa 19fe :2 0
2cac 0 2cac 2cab
2c4e 2caa :6 0 2d32
1 :3 0 50 :3 0
23c :4 0 6d :2 0
23d :4 0 1a01 2cb0
2cb2 :3 0 6d :2 0
23e :4 0 1a04 2cb4
2cb6 :3 0 6d :2 0
23f :4 0 1a07 2cb8
2cba :3 0 6d :2 0
73 :3 0 72 :3 0
38 :3 0 30 :2 0
1a0a 2cbe 2cc1 1a0d
2cbd 2cc3 1a0f 2cbc
2cc5 :3 0 6d :2 0
240 :4 0 1a12 2cc7
2cc9 :3 0 6d :2 0
82 :4 0 1a15 2ccb
2ccd :3 0 6d :2 0
73 :3 0 72 :3 0
3d :3 0 30 :2 0
1a18 2cd1 2cd4 1a1b
2cd0 2cd6 1a1d 2ccf
2cd8 :3 0 6d :2 0
241 :4 0 1a20 2cda
2cdc :3 0 6d :2 0
242 :4 0 1a23 2cde
2ce0 :3 0 6d :2 0
243 :4 0 1a26 2ce2
2ce4 :3 0 6d :2 0
244 :4 0 1a29 2ce6
2ce8 :3 0 6d :2 0
245 :4 0 1a2c 2cea
2cec :3 0 6d :2 0
246 :4 0 1a2f 2cee
2cf0 :3 0 6d :2 0
247 :4 0 1a32 2cf2
2cf4 :3 0 6d :2 0
248 :4 0 1a35 2cf6
2cf8 :3 0 6d :2 0
249 :4 0 1a38 2cfa
2cfc :3 0 6d :2 0
73 :3 0 72 :3 0
38 :3 0 30 :2 0
1a3b 2d00 2d03 1a3e
2cff 2d05 1a40 2cfe
2d07 :3 0 6d :2 0
24a :4 0 1a43 2d09
2d0b :3 0 6d :2 0
24b :4 0 1a46 2d0d
2d0f :3 0 6d :2 0
73 :3 0 72 :3 0
3d :3 0 30 :2 0
1a49 2d13 2d16 1a4c
2d12 2d18 1a4e 2d11
2d1a :3 0 6d :2 0
24c :4 0 1a51 2d1c
2d1e :3 0 6d :2 0
24d :4 0 1a54 2d20
2d22 :3 0 6d :2 0
24e :4 0 1a57 2d24
2d26 :3 0 6d :2 0
24f :4 0 1a5a 2d28
2d2a :3 0 6d :2 0
250 :4 0 1a5d 2d2c
2d2e :3 0 2cae 2d2f
0 2d32 ae :3 0
1a60 320c 72 :3 0
1b0 :3 0 2c :3 0
1a6d 2d34 2d36 30
:2 0 1a6f 2d33 2d39
8f :2 0 30 :2 0
1a74 2d3b 2d3d :3 0
1fe :3 0 1ff :3 0
251 :4 0 2d41 :4 0
2d42 :2 0 2fa2 15
:3 0 9b :3 0 2d44
2d45 0 30 :2 0
2d46 2d47 0 2fa2
50 :3 0 252 :4 0
6d :2 0 253 :4 0
1a77 2d4b 2d4d :3 0
6d :2 0 254 :4 0
1a7a 2d4f 2d51 :3 0
6d :2 0 255 :4 0
1a7d 2d53 2d55 :3 0
6d :2 0 256 :4 0
1a80 2d57 2d59 :3 0
6d :2 0 206 :4 0
1a83 2d5b 2d5d :3 0
6d :2 0 17 :3 0
1a86 2d5f 2d61 :3 0
6d :2 0 207 :4 0
1a89 2d63 2d65 :3 0
6d :2 0 257 :4 0
1a8c 2d67 2d69 :3 0
6d :2 0 2b :3 0
1a8f 2d6b 2d6d :3 0
6d :2 0 258 :4 0
1a92 2d6f 2d71 :3 0
2d49 2d72 0 2fa2
1fe :3 0 1ff :3 0
50 :3 0 2d76 :4 0
2d77 :2 0 2d8e 1a8
:4 0 2d79 :3 0 8a
:3 0 8f :2 0 1a97
2d7c 2d7d :3 0 15
:3 0 9b :3 0 2d7f
2d80 0 30 :2 0
2d81 2d82 0 2d84
1a9a 2d8b 15 :3 0
9b :3 0 2d85 2d86
0 112 :2 0 2d87
2d88 0 2d8a 1a9c
2d8c 2d7e 2d84 0
2d8d 0 2d8a 0
2d8d 1a9e 0 2d8e
1aa1 2dec 9d :3 0
15 :3 0 9b :3 0
2d90 2d91 0 9c
:3 0 2d92 2d93 0
2d95 1aa4 2d97 1aa6
2d96 2d95 :2 0 2dea
9e :3 0 15 :3 0
9b :3 0 2d9a 2d9b
0 9c :3 0 2d9c
2d9d 0 2de2 65
:3 0 66 :3 0 2d9f
2da0 0 65 :3 0
76 :3 0 2da2 2da3
0 9f :2 0 2
:4 0 259 :2 0 78
:2 0 27 :2 0 1aa8
2da8 2daa :3 0 1aab
2da4 2dac 2da1 2dae
2dad :2 0 68 :3 0
79 :3 0 2db0 2db1
0 6a :4 0 25a
:4 0 6d :2 0 6e
:3 0 1aaf 2db5 2db7
:3 0 6d :2 0 82
:4 0 1ab2 2db9 2dbb
:3 0 6d :2 0 a2
:4 0 1ab5 2dbd 2dbf
:3 0 6d :2 0 9c
:3 0 1ab8 2dc1 2dc3
:3 0 6d :2 0 a3
:4 0 1abb 2dc5 2dc7
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 1abe
2dca 2dce 1ac2 2dc9
2dd0 :3 0 1ac5 2db2
2dd2 :2 0 2ddf 68
:3 0 79 :3 0 2dd4
2dd5 0 6a :4 0
20d :4 0 6d :2 0
50 :3 0 1ac8 2dd9
2ddb :3 0 1acb 2dd6
2ddd :2 0 2ddf 1ace
2de0 2daf 2ddf 0
2de1 1ad1 0 2de2
1ad3 2de5 :3 0 2de5
0 2de5 2de4 2de2
2de3 :6 0 2de7 6b
:3 0 1ad6 2de9 1ad8
2de8 2de7 :2 0 2dea
1ada :2 0 2dec 0
2dec 2deb 2d8e 2dea
:6 0 2fa2 1 :3 0
1fe :3 0 1ff :3 0
20e :4 0 2df0 :4 0
2df1 :2 0 2fa2 15
:3 0 9b :3 0 2df3
2df4 0 30 :2 0
2df5 2df6 0 2fa2
50 :3 0 25b :4 0
6d :2 0 25c :4 0
1add 2dfa 2dfc :3 0
6d :2 0 25d :4 0
1ae0 2dfe 2e00 :3 0
6d :2 0 25e :4 0
1ae3 2e02 2e04 :3 0
6d :2 0 25f :4 0
1ae6 2e06 2e08 :3 0
6d :2 0 260 :4 0
1ae9 2e0a 2e0c :3 0
6d :2 0 17 :3 0
1aec 2e0e 2e10 :3 0
6d :2 0 261 :4 0
1aef 2e12 2e14 :3 0
6d :2 0 2b :3 0
1af2 2e16 2e18 :3 0
6d :2 0 262 :4 0
1af5 2e1a 2e1c :3 0
2df8 2e1d 0 2fa2
1fe :3 0 1ff :3 0
50 :3 0 2e21 :4 0
2e22 :2 0 2e39 1a8
:4 0 2e24 :3 0 8a
:3 0 8f :2 0 1afa
2e27 2e28 :3 0 15
:3 0 9b :3 0 2e2a
2e2b 0 30 :2 0
2e2c 2e2d 0 2e2f
1afd 2e36 15 :3 0
9b :3 0 2e30 2e31
0 112 :2 0 2e32
2e33 0 2e35 1aff
2e37 2e29 2e2f 0
2e38 0 2e35 0
2e38 1b01 0 2e39
1b04 2e97 9d :3 0
15 :3 0 9b :3 0
2e3b 2e3c 0 9c
:3 0 2e3d 2e3e 0
2e40 1b07 2e42 1b09
2e41 2e40 :2 0 2e95
9e :3 0 15 :3 0
9b :3 0 2e45 2e46
0 9c :3 0 2e47
2e48 0 2e8d 65
:3 0 66 :3 0 2e4a
2e4b 0 65 :3 0
76 :3 0 2e4d 2e4e
0 9f :2 0 2
:4 0 263 :2 0 78
:2 0 27 :2 0 1b0b
2e53 2e55 :3 0 1b0e
2e4f 2e57 2e4c 2e59
2e58 :2 0 68 :3 0
79 :3 0 2e5b 2e5c
0 6a :4 0 264
:4 0 6d :2 0 6e
:3 0 1b12 2e60 2e62
:3 0 6d :2 0 82
:4 0 1b15 2e64 2e66
:3 0 6d :2 0 a2
:4 0 1b18 2e68 2e6a
:3 0 6d :2 0 9c
:3 0 1b1b 2e6c 2e6e
:3 0 6d :2 0 a3
:4 0 1b1e 2e70 2e72
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 1b21
2e75 2e79 1b25 2e74
2e7b :3 0 1b28 2e5d
2e7d :2 0 2e8a 68
:3 0 79 :3 0 2e7f
2e80 0 6a :4 0
20d :4 0 6d :2 0
50 :3 0 1b2b 2e84
2e86 :3 0 1b2e 2e81
2e88 :2 0 2e8a 1b31
2e8b 2e5a 2e8a 0
2e8c 1b34 0 2e8d
1b36 2e90 :3 0 2e90
0 2e90 2e8f 2e8d
2e8e :6 0 2e92 6d
:3 0 1b39 2e94 1b3b
2e93 2e92 :2 0 2e95
1b3d :2 0 2e97 0
2e97 2e96 2e39 2e95
:6 0 2fa2 1 :3 0
15 :3 0 9b :3 0
2e99 2e9a 0 219
:4 0 2e9c 2e9d :3 0
2e9b 2e9e 0 2fa2
50 :3 0 21a :4 0
6d :2 0 265 :4 0
1b40 2ea2 2ea4 :3 0
6d :2 0 21d :4 0
1b43 2ea6 2ea8 :3 0
6d :2 0 266 :4 0
1b46 2eaa 2eac :3 0
6d :2 0 267 :4 0
1b49 2eae 2eb0 :3 0
6d :2 0 221 :4 0
1b4c 2eb2 2eb4 :3 0
6d :2 0 268 :4 0
1b4f 2eb6 2eb8 :3 0
6d :2 0 224 :4 0
1b52 2eba 2ebc :3 0
6d :2 0 269 :4 0
1b55 2ebe 2ec0 :3 0
6d :2 0 226 :4 0
1b58 2ec2 2ec4 :3 0
6d :2 0 17 :3 0
1b5b 2ec6 2ec8 :3 0
6d :2 0 227 :4 0
1b5e 2eca 2ecc :3 0
6d :2 0 228 :4 0
1b61 2ece 2ed0 :3 0
6d :2 0 17 :3 0
1b64 2ed2 2ed4 :3 0
6d :2 0 229 :4 0
1b67 2ed6 2ed8 :3 0
6d :2 0 22a :4 0
1b6a 2eda 2edc :3 0
6d :2 0 26a :4 0
1b6d 2ede 2ee0 :3 0
6d :2 0 2b :3 0
1b70 2ee2 2ee4 :3 0
6d :2 0 26b :4 0
1b73 2ee6 2ee8 :3 0
2ea0 2ee9 0 2fa2
1fe :3 0 1ff :3 0
50 :3 0 2eed :4 0
2eee :2 0 2f05 1a8
:4 0 2ef0 :3 0 8a
:3 0 8f :2 0 1b78
2ef3 2ef4 :3 0 15
:3 0 9b :3 0 2ef6
2ef7 0 30 :2 0
2ef8 2ef9 0 2efb
1b7b 2f02 15 :3 0
9b :3 0 2efc 2efd
0 112 :2 0 2efe
2eff 0 2f01 1b7d
2f03 2ef5 2efb 0
2f04 0 2f01 0
2f04 1b7f 0 2f05
1b82 2f63 9d :3 0
15 :3 0 9b :3 0
2f07 2f08 0 9c
:3 0 2f09 2f0a 0
2f0c 1b85 2f0e 1b87
2f0d 2f0c :2 0 2f61
9e :3 0 15 :3 0
9b :3 0 2f11 2f12
0 9c :3 0 2f13
2f14 0 2f59 65
:3 0 66 :3 0 2f16
2f17 0 65 :3 0
76 :3 0 2f19 2f1a
0 9f :2 0 2
:4 0 26c :2 0 78
:2 0 27 :2 0 1b89
2f1f 2f21 :3 0 1b8c
2f1b 2f23 2f18 2f25
2f24 :2 0 68 :3 0
79 :3 0 2f27 2f28
0 6a :4 0 26d
:4 0 6d :2 0 6e
:3 0 1b90 2f2c 2f2e
:3 0 6d :2 0 82
:4 0 1b93 2f30 2f32
:3 0 6d :2 0 a2
:4 0 1b96 2f34 2f36
:3 0 6d :2 0 9c
:3 0 1b99 2f38 2f3a
:3 0 6d :2 0 a3
:4 0 1b9c 2f3c 2f3e
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 1b9f
2f41 2f45 1ba3 2f40
2f47 :3 0 1ba6 2f29
2f49 :2 0 2f56 68
:3 0 79 :3 0 2f4b
2f4c 0 6a :4 0
20d :4 0 6d :2 0
50 :3 0 1ba9 2f50
2f52 :3 0 1bac 2f4d
2f54 :2 0 2f56 1baf
2f57 2f26 2f56 0
2f58 1bb2 0 2f59
1bb4 2f5c :3 0 2f5c
0 2f5c 2f5b 2f59
2f5a :6 0 2f5e 6f
:3 0 1bb7 2f60 1bb9
2f5f 2f5e :2 0 2f61
1bbb :2 0 2f63 0
2f63 2f62 2f05 2f61
:6 0 2fa2 1 :3 0
50 :3 0 26e :4 0
6d :2 0 26f :4 0
1bbe 2f67 2f69 :3 0
6d :2 0 270 :4 0
1bc1 2f6b 2f6d :3 0
6d :2 0 271 :4 0
1bc4 2f6f 2f71 :3 0
6d :2 0 73 :3 0
72 :3 0 38 :3 0
30 :2 0 1bc7 2f75
2f78 1bca 2f74 2f7a
1bcc 2f73 2f7c :3 0
6d :2 0 272 :4 0
1bcf 2f7e 2f80 :3 0
6d :2 0 73 :3 0
72 :3 0 3d :3 0
30 :2 0 1bd2 2f84
2f87 1bd5 2f83 2f89
1bd7 2f82 2f8b :3 0
6d :2 0 273 :4 0
1bda 2f8d 2f8f :3 0
6d :2 0 242 :4 0
1bdd 2f91 2f93 :3 0
6d :2 0 274 :4 0
1be0 2f95 2f97 :3 0
6d :2 0 275 :4 0
1be3 2f99 2f9b :3 0
6d :2 0 276 :4 0
1be6 2f9d 2f9f :3 0
2f65 2fa0 0 2fa2
1be9 2fa3 2d3e 2fa2
0 320e 1fe :3 0
1ff :3 0 251 :4 0
2fa6 :4 0 2fa7 :2 0
320b 15 :3 0 9b
:3 0 2fa9 2faa 0
30 :2 0 2fab 2fac
0 320b 50 :3 0
252 :4 0 6d :2 0
277 :4 0 1bf6 2fb0
2fb2 :3 0 6d :2 0
278 :4 0 1bf9 2fb4
2fb6 :3 0 6d :2 0
279 :4 0 1bfc 2fb8
2fba :3 0 6d :2 0
27a :4 0 1bff 2fbc
2fbe :3 0 6d :2 0
213 :4 0 1c02 2fc0
2fc2 :3 0 6d :2 0
27b :4 0 1c05 2fc4
2fc6 :3 0 6d :2 0
17 :3 0 1c08 2fc8
2fca :3 0 6d :2 0
27c :4 0 1c0b 2fcc
2fce :3 0 6d :2 0
27d :4 0 1c0e 2fd0
2fd2 :3 0 6d :2 0
2c :3 0 1c11 2fd4
2fd6 :3 0 6d :2 0
27e :4 0 1c14 2fd8
2fda :3 0 6d :2 0
27f :4 0 1c17 2fdc
2fde :3 0 2fae 2fdf
0 320b 1fe :3 0
1ff :3 0 50 :3 0
2fe3 :4 0 2fe4 :2 0
2ffb 1a8 :4 0 2fe6
:3 0 8a :3 0 8f
:2 0 1c1c 2fe9 2fea
:3 0 15 :3 0 9b
:3 0 2fec 2fed 0
30 :2 0 2fee 2fef
0 2ff1 1c1f 2ff8
15 :3 0 9b :3 0
2ff2 2ff3 0 112
:2 0 2ff4 2ff5 0
2ff7 1c21 2ff9 2feb
2ff1 0 2ffa 0
2ff7 0 2ffa 1c23
0 2ffb 1c26 3059
9d :3 0 15 :3 0
9b :3 0 2ffd 2ffe
0 9c :3 0 2fff
3000 0 3002 1c29
3004 1c2b 3003 3002
:2 0 3057 9e :3 0
15 :3 0 9b :3 0
3007 3008 0 9c
:3 0 3009 300a 0
304f 65 :3 0 66
:3 0 300c 300d 0
65 :3 0 76 :3 0
300f 3010 0 9f
:2 0 2 :4 0 280
:2 0 78 :2 0 27
:2 0 1c2d 3015 3017
:3 0 1c30 3011 3019
300e 301b 301a :2 0
68 :3 0 79 :3 0
301d 301e 0 6a
:4 0 281 :4 0 6d
:2 0 6e :3 0 1c34
3022 3024 :3 0 6d
:2 0 82 :4 0 1c37
3026 3028 :3 0 6d
:2 0 a2 :4 0 1c3a
302a 302c :3 0 6d
:2 0 9c :3 0 1c3d
302e 3030 :3 0 6d
:2 0 a3 :4 0 1c40
3032 3034 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 1c43 3037 303b
1c47 3036 303d :3 0
1c4a 301f 303f :2 0
304c 68 :3 0 79
:3 0 3041 3042 0
6a :4 0 20d :4 0
6d :2 0 50 :3 0
1c4d 3046 3048 :3 0
1c50 3043 304a :2 0
304c 1c53 304d 301c
304c 0 304e 1c56
0 304f 1c58 3052
:3 0 3052 0 3052
3051 304f 3050 :6 0
3054 71 :3 0 1c5b
3056 1c5d 3055 3054
:2 0 3057 1c5f :2 0
3059 0 3059 3058
2ffb 3057 :6 0 320b
1 :3 0 1fe :3 0
1ff :3 0 20e :4 0
305d :4 0 305e :2 0
320b 15 :3 0 9b
:3 0 3060 3061 0
30 :2 0 3062 3063
0 320b 50 :3 0
25b :4 0 6d :2 0
282 :4 0 1c62 3067
3069 :3 0 6d :2 0
283 :4 0 1c65 306b
306d :3 0 6d :2 0
284 :4 0 1c68 306f
3071 :3 0 6d :2 0
285 :4 0 1c6b 3073
3075 :3 0 6d :2 0
260 :4 0 1c6e 3077
3079 :3 0 6d :2 0
17 :3 0 1c71 307b
307d :3 0 6d :2 0
261 :4 0 1c74 307f
3081 :3 0 6d :2 0
2c :3 0 1c77 3083
3085 :3 0 6d :2 0
286 :4 0 1c7a 3087
3089 :3 0 3065 308a
0 320b 1fe :3 0
1ff :3 0 50 :3 0
308e :4 0 308f :2 0
30a6 1a8 :4 0 3091
:3 0 8a :3 0 8f
:2 0 1c7f 3094 3095
:3 0 15 :3 0 9b
:3 0 3097 3098 0
30 :2 0 3099 309a
0 309c 1c82 30a3
15 :3 0 9b :3 0
309d 309e 0 112
:2 0 309f 30a0 0
30a2 1c84 30a4 3096
309c 0 30a5 0
30a2 0 30a5 1c86
0 30a6 1c89 3104
9d :3 0 15 :3 0
9b :3 0 30a8 30a9
0 9c :3 0 30aa
30ab 0 30ad 1c8c
30af 1c8e 30ae 30ad
:2 0 3102 9e :3 0
15 :3 0 9b :3 0
30b2 30b3 0 9c
:3 0 30b4 30b5 0
30fa 65 :3 0 66
:3 0 30b7 30b8 0
65 :3 0 76 :3 0
30ba 30bb 0 9f
:2 0 2 :4 0 287
:2 0 78 :2 0 27
:2 0 1c90 30c0 30c2
:3 0 1c93 30bc 30c4
30b9 30c6 30c5 :2 0
68 :3 0 79 :3 0
30c8 30c9 0 6a
:4 0 288 :4 0 6d
:2 0 6e :3 0 1c97
30cd 30cf :3 0 6d
:2 0 82 :4 0 1c9a
30d1 30d3 :3 0 6d
:2 0 a2 :4 0 1c9d
30d5 30d7 :3 0 6d
:2 0 9c :3 0 1ca0
30d9 30db :3 0 6d
:2 0 a3 :4 0 1ca3
30dd 30df :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 1ca6 30e2 30e6
1caa 30e1 30e8 :3 0
1cad 30ca 30ea :2 0
30f7 68 :3 0 79
:3 0 30ec 30ed 0
6a :4 0 20d :4 0
6d :2 0 50 :3 0
1cb0 30f1 30f3 :3 0
1cb3 30ee 30f5 :2 0
30f7 1cb6 30f8 30c7
30f7 0 30f9 1cb9
0 30fa 1cbb 30fd
:3 0 30fd 0 30fd
30fc 30fa 30fb :6 0
30ff 73 :3 0 1cbe
3101 1cc0 3100 30ff
:2 0 3102 1cc2 :2 0
3104 0 3104 3103
30a6 3102 :6 0 320b
1 :3 0 15 :3 0
9b :3 0 3106 3107
0 219 :4 0 3109
310a :3 0 3108 310b
0 320b 50 :3 0
21a :4 0 6d :2 0
265 :4 0 1cc5 310f
3111 :3 0 6d :2 0
21d :4 0 1cc8 3113
3115 :3 0 6d :2 0
289 :4 0 1ccb 3117
3119 :3 0 6d :2 0
28a :4 0 1cce 311b
311d :3 0 6d :2 0
28b :4 0 1cd1 311f
3121 :3 0 6d :2 0
223 :4 0 1cd4 3123
3125 :3 0 6d :2 0
28c :4 0 1cd7 3127
3129 :3 0 6d :2 0
28d :4 0 1cda 312b
312d :3 0 6d :2 0
226 :4 0 1cdd 312f
3131 :3 0 6d :2 0
17 :3 0 1ce0 3133
3135 :3 0 6d :2 0
234 :4 0 1ce3 3137
3139 :3 0 6d :2 0
28e :4 0 1ce6 313b
313d :3 0 6d :2 0
237 :4 0 1ce9 313f
3141 :3 0 6d :2 0
238 :4 0 1cec 3143
3145 :3 0 6d :2 0
2c :3 0 1cef 3147
3149 :3 0 6d :2 0
26b :4 0 1cf2 314b
314d :3 0 310d 314e
0 320b 1fe :3 0
1ff :3 0 50 :3 0
3152 :4 0 3153 :2 0
316a 1a8 :4 0 3155
:3 0 8a :3 0 8f
:2 0 1cf7 3158 3159
:3 0 15 :3 0 9b
:3 0 315b 315c 0
30 :2 0 315d 315e
0 3160 1cfa 3167
15 :3 0 9b :3 0
3161 3162 0 112
:2 0 3163 3164 0
3166 1cfc 3168 315a
3160 0 3169 0
3166 0 3169 1cfe
0 316a 1d01 31c8
9d :3 0 15 :3 0
9b :3 0 316c 316d
0 9c :3 0 316e
316f 0 3171 1d04
3173 1d06 3172 3171
:2 0 31c6 9e :3 0
15 :3 0 9b :3 0
3176 3177 0 9c
:3 0 3178 3179 0
31be 65 :3 0 66
:3 0 317b 317c 0
65 :3 0 76 :3 0
317e 317f 0 9f
:2 0 2 :4 0 28f
:2 0 78 :2 0 27
:2 0 1d08 3184 3186
:3 0 1d0b 3180 3188
317d 318a 3189 :2 0
68 :3 0 79 :3 0
318c 318d 0 6a
:4 0 290 :4 0 6d
:2 0 6e :3 0 1d0f
3191 3193 :3 0 6d
:2 0 82 :4 0 1d12
3195 3197 :3 0 6d
:2 0 a2 :4 0 1d15
3199 319b :3 0 6d
:2 0 9c :3 0 1d18
319d 319f :3 0 6d
:2 0 a3 :4 0 1d1b
31a1 31a3 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 1d1e 31a6 31aa
1d22 31a5 31ac :3 0
1d25 318e 31ae :2 0
31bb 68 :3 0 79
:3 0 31b0 31b1 0
6a :4 0 20d :4 0
6d :2 0 50 :3 0
1d28 31b5 31b7 :3 0
1d2b 31b2 31b9 :2 0
31bb 1d2e 31bc 318b
31bb 0 31bd 1d31
0 31be 1d33 31c1
:3 0 31c1 0 31c1
31c0 31be 31bf :6 0
31c3 75 :3 0 1d36
31c5 1d38 31c4 31c3
:2 0 31c6 1d3a :2 0
31c8 0 31c8 31c7
316a 31c6 :6 0 320b
1 :3 0 50 :3 0
291 :4 0 6d :2 0
26f :4 0 1d3d 31cc
31ce :3 0 6d :2 0
292 :4 0 1d40 31d0
31d2 :3 0 6d :2 0
293 :4 0 1d43 31d4
31d6 :3 0 6d :2 0
73 :3 0 72 :3 0
38 :3 0 30 :2 0
1d46 31da 31dd 1d49
31d9 31df 1d4b 31d8
31e1 :3 0 6d :2 0
24a :4 0 1d4e 31e3
31e5 :3 0 6d :2 0
294 :4 0 1d51 31e7
31e9 :3 0 6d :2 0
73 :3 0 72 :3 0
3d :3 0 30 :2 0
1d54 31ed 31f0 1d57
31ec 31f2 1d59 31eb
31f4 :3 0 6d :2 0
295 :4 0 1d5c 31f6
31f8 :3 0 6d :2 0
296 :4 0 1d5f 31fa
31fc :3 0 6d :2 0
242 :4 0 1d62 31fe
3200 :3 0 6d :2 0
297 :4 0 1d65 3202
3204 :3 0 6d :2 0
276 :4 0 1d68 3206
3208 :3 0 31ca 3209
0 320b 1d6b 320d
2a23 2d32 0 320e
0 320b 0 320e
1d78 0 3255 65
:3 0 66 :3 0 320f
3210 0 65 :3 0
76 :3 0 3212 3213
0 27 :2 0 2
:4 0 298 :2 0 78
:2 0 27 :2 0 1d7c
3218 321a :3 0 1d7f
3214 321c 3211 321e
321d :2 0 68 :3 0
79 :3 0 3220 3221
0 6a :4 0 299
:4 0 6d :2 0 6e
:3 0 1d83 3225 3227
:3 0 1d86 3222 3229
:2 0 322b 1d89 322c
321f 322b 0 322d
1d8b 0 3255 65
:3 0 66 :3 0 322e
322f 0 65 :3 0
76 :3 0 3231 3232
0 27 :2 0 2
:4 0 29a :2 0 78
:2 0 27 :2 0 1d8d
3237 3239 :3 0 1d90
3233 323b 3230 323d
323c :2 0 68 :3 0
79 :3 0 323f 3240
0 6a :4 0 29b
:4 0 6d :2 0 6e
:3 0 1d94 3244 3246
:3 0 1d97 3241 3248
:2 0 324a 1d9a 324b
323e 324a 0 324c
1d9c 0 3255 14
:3 0 88 :3 0 29c
:3 0 324e 324f 0
50 :3 0 1d9e 3250
3252 3253 :2 0 3255
1da0 32f6 15 :3 0
29d :2 0 4 3256
3257 0 65 :3 0
66 :3 0 3259 325a
0 65 :3 0 76
:3 0 325c 325d 0
9f :2 0 2 :4 0
29e :2 0 78 :2 0
27 :2 0 1dce 3262
3264 :3 0 1dd1 325e
3266 325b 3268 3267
:2 0 68 :3 0 79
:3 0 326a 326b 0
6a :4 0 29f :4 0
6d :2 0 6e :3 0
1dd5 326f 3271 :3 0
1dd8 326c 3273 :2 0
328c 68 :3 0 79
:3 0 3275 3276 0
6a :4 0 2a0 :4 0
6d :2 0 15 :3 0
2a1 :3 0 327b 327c
0 1ddb 327a 327e
:3 0 6d :2 0 e5
:4 0 1dde 3280 3282
:3 0 6d :2 0 15
:3 0 2a2 :3 0 3285
3286 0 1de1 3284
3288 :3 0 1de4 3277
328a :2 0 328c 1de7
328d 3269 328c 0
328e 1dea 0 329e
2a3 :3 0 64 :3 0
15 :3 0 2a1 :3 0
2a4 :3 0 15 :3 0
2a2 :3 0 5e :3 0
99 :4 0 2a5 1
:a 0 329a :2 0 329e
3290 3298 :2 0 14
:3 0 64 :3 0 329c
:2 0 329e 1dec 32a0
1df0 329f 329e :2 0
32f4 9e :3 0 15
:3 0 9b :3 0 32a3
32a4 0 9c :3 0
32a5 32a6 0 32ec
65 :3 0 66 :3 0
32a8 32a9 0 65
:3 0 76 :3 0 32ab
32ac 0 9f :2 0
2 :4 0 2a6 :2 0
78 :2 0 27 :2 0
1df2 32b1 32b3 :3 0
1df5 32ad 32b5 32aa
32b7 32b6 :2 0 68
:3 0 79 :3 0 32b9
32ba 0 6a :4 0
2a7 :4 0 6d :2 0
6e :3 0 1df9 32be
32c0 :3 0 1dfc 32bb
32c2 :2 0 32dc 68
:3 0 79 :3 0 32c4
32c5 0 6a :4 0
a2 :4 0 6d :2 0
9c :3 0 1dff 32c9
32cb :3 0 6d :2 0
a3 :4 0 1e02 32cd
32cf :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
1e05 32d2 32d6 1e09
32d1 32d8 :3 0 1e0c
32c6 32da :2 0 32dc
1e0f 32dd 32b8 32dc
0 32de 1e12 0
32ec 2a3 :3 0 64
:3 0 2a4 :3 0 15
:3 0 2a2 :3 0 5e
:3 0 99 :4 0 2a8
1 :a 0 32e8 :2 0
32ec 32e0 32e6 :2 0
14 :3 0 64 :3 0
32ea :2 0 32ec 1e14
32ef :3 0 32ef 0
32ef 32ee 32ec 32ed
:6 0 32f1 1 :3 0
1e19 32f3 1e1b 32f2
32f1 :2 0 32f4 1e1d
:2 0 32f6 1e20 32f6
32f5 3255 32f4 :6 0
32f7 :2 0 2 44
32f6 32fa :3 0 32f9
32f7 32fb :8 0 
1e65
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
4f 1 4d 1
56 1 54 1
5d 1 5b 1
64 1 62 1
6b 1 69 1
72 1 70 1
79 1 77 1
80 1 7e 1
87 1 85 1
8c 1 91 1
98 1 96 1
9f 1 9d 1
a6 1 a4 1
ad 1 ab 1
b4 1 b2 1
bb 1 b9 1
c0 1 c6 1
cc 1 d2 1
d8 1 de 1
e4 1 ea 1
f0 1 f6 1
fc 1 102 1
108 1 10e 1
114 1 11a 1
120 1 126 1
12c 1 132 1
138 1 13e 1
144 1 14a 1
150 1 156 1
15c 1 162 1
16a 1 168 1
171 1 16f 1
176 1 17e 1
17c 1 183 1
18b 1 189 1
192 1 190 1
199 1 197 1
19e 1 1a4 1
1aa 1 1b2 1
1b0 1 1b9 1
1b7 1 1be 1
1c4 1 1cc 1
1ca 1 1d1 1
1d7 1 1dd 1
1e3 1 1e9 1
1ee 1 1fb 1
207 2 20a 20c
2 20f 211 2
213 215 2 217
219 2 21b 21d
2 21f 221 2
223 225 2 227
229 2 22b 22d
2 22f 231 2
233 235 2 237
239 2 23b 23d
1 243 2 245
246 2 23f 248
2 24a 24c 1
252 2 254 255
2 24e 257 2
259 25b 1 261
2 263 264 2
25d 266 2 268
26a 1 270 2
272 273 2 26c
275 2 277 279
1 27f 2 281
282 2 27b 284
2 286 288 1
28e 2 290 291
2 28a 293 2
295 297 1 29d
2 29f 2a0 2
299 2a2 2 2a4
2a6 1 2ac 2
2ae 2af 2 2a8
2b1 2 2b3 2b5
1 2bb 2 2bd
2be 2 2b7 2c0
2 2c2 2c4 1
2ca 2 2cc 2cd
2 2c6 2cf 2
2d1 2d3 2 2d5
2d7 2 2d9 2db
2 2dd 2df 2
2e1 2e3 2 2e5
2e7 2 2e9 2eb
2 2ed 2ef 2
2f1 2f3 4 203
209 20e 2f5 1
2f7 1 2f9 2
303 305 3 301
302 307 2 310
312 2 30f 314
1 316 1 318
2 350 351 1
353 1 360 2
36d 36f 3 36b
36c 371 2 37a
37c 2 37e 380
2 382 384 1
38c 2 38e 38f
2 386 391 2
379 393 1 395
1 397 2 3a1
3a3 3 39f 3a0
3a5 2 3ae 3b0
2 3ad 3b2 1
3b4 1 3b6 2
3bd 3be 3 398
3b7 3c0 1 3c2
1 3c4 2 3d1
3d3 3 3cf 3d0
3d5 2 3de 3e0
2 3e2 3e4 2
3e6 3e8 1 3f0
2 3f2 3f3 2
3ea 3f5 2 3dd
3f7 1 3f9 1
3fb 2 405 407
3 403 404 409
2 412 414 2
411 416 1 418
1 41a 2 421
422 3 3fc 41b
424 1 426 2
429 42a 1 42e
2 42c 42e 2
432 433 1 437
2 435 437 2
43d 43e 1 442
2 440 442 2
44f 451 3 44d
44e 453 2 45c
45e 2 460 462
2 464 466 1
46e 2 470 471
2 468 473 2
45b 475 1 477
1 479 2 483
485 3 481 482
487 2 490 492
2 48f 494 1
496 1 498 2
49f 4a0 3 47a
499 4a2 1 4a4
1 4a6 1 4ac
2 4bc 4c1 1
4c8 1 4c3 2
4db 4dd 3 4d9
4da 4df 2 4e8
4ea 2 4ec 4ee
2 4f0 4f2 2
4f4 4f6 2 4f8
4fa 3 4ff 500
501 2 4fc 503
2 4e7 505 1
507 1 509 2
4d2 50a 1 50e
1 4cd 2 4cb
512 1 51d 2
519 51d 2 522
523 1 527 2
525 527 2 535
537 3 533 534
539 2 542 544
2 546 548 2
54a 54c 1 554
2 556 557 2
54e 559 2 541
55b 1 55d 1
55f 2 569 56b
3 567 568 56d
2 576 578 2
575 57a 1 57c
1 57e 2 585
586 3 560 57f
588 1 58a 3
515 58b 58e 1
591 1 597 2
5a2 5a7 1 5ae
1 5a9 2 5c1
5c3 3 5bf 5c0
5c5 2 5ce 5d0
2 5d2 5d4 2
5d6 5d8 2 5da
5dc 2 5de 5e0
3 5e5 5e6 5e7
2 5e2 5e9 2
5cd 5eb 1 5ed
1 5ef 2 5b8
5f0 1 5f4 1
5b3 2 5b1 5f8
1 5fb 2 5ff
5fe 1 604 1
60b 1 60d 3
611 612 613 3
619 61a 61b 2
623 624 1 628
2 626 628 3
62e 62f 630 3
632 633 634 4
63c 63d 63e 63f
2 645 646 1
648 1 64c 2
64a 64c 2 65c
661 1 668 1
663 2 67b 67d
3 679 67a 67f
2 688 68a 2
68c 68e 2 690
692 2 694 696
2 698 69a 3
69f 6a0 6a1 2
69c 6a3 2 687
6a5 1 6a7 1
6a9 2 672 6aa
1 6ae 1 66d
2 66b 6b2 1
6b5 2 6fd 702
1 709 1 704
2 71c 71e 3
71a 71b 720 2
729 72b 2 72d
72f 2 731 733
2 735 737 2
739 73b 3 740
741 742 2 73d
744 2 728 746
1 748 1 74a
2 713 74b 1
74f 1 70e 2
70c 753 1 756
2 759 75a 1
762 2 75e 762
2 76d 772 1
779 1 774 2
78c 78e 3 78a
78b 790 2 799
79b 2 79d 79f
2 7a1 7a3 2
7a5 7a7 2 7a9
7ab 3 7b0 7b1
7b2 2 7ad 7b4
2 798 7b6 1
7b8 1 7ba 2
783 7bb 1 7bf
1 77e 2 77c
7c3 1 7ce 2
7ca 7ce 1 7d2
1 7d9 1 7db
2 7e8 7ed 1
7f4 1 7ef 2
807 809 3 805
806 80b 2 814
816 2 818 81a
2 81c 81e 2
820 822 2 824
826 3 82b 82c
82d 2 828 82f
2 813 831 1
833 1 835 2
7fe 836 1 83a
1 7f9 2 7f7
83e 2 7dc 841
2 84c 84e 3
84a 84b 850 2
859 85b 2 85d
85f 2 861 863
1 86b 2 86d
86e 2 865 870
2 872 874 2
876 878 2 87a
87c 2 87e 880
2 858 882 1
884 1 886 2
890 892 3 88e
88f 894 2 89d
89f 2 89c 8a1
1 8a3 1 8a5
3 8ac 8ad 8ae
3 887 8a6 8b0
2 8b2 8b3 2
7c6 8b4 1 8b8
2 8ba 8bb 2
8c5 8ca 1 8d1
1 8cc 2 8e4
8e6 3 8e2 8e3
8e8 2 8f1 8f3
2 8f5 8f7 2
8f9 8fb 2 8fd
8ff 2 901 903
3 908 909 90a
2 905 90c 2
8f0 90e 1 910
1 912 2 8db
913 1 917 1
8d6 2 8d4 91b
2 921 922 1
926 2 924 926
2 92e 933 1
93a 1 935 2
94d 94f 3 94b
94c 951 2 95a
95c 2 95e 960
2 962 964 2
966 968 2 96a
96c 3 971 972
973 2 96e 975
2 959 977 1
979 1 97b 2
944 97c 1 980
1 93f 2 93d
984 2 98c 98d
1 991 2 98f
991 2 99c 99e
3 99a 99b 9a0
2 9a9 9ab 2
9ad 9af 2 9b1
9b3 1 9bb 2
9bd 9be 2 9b5
9c0 2 9c2 9c4
2 9c6 9c8 2
9ca 9cc 2 9ce
9d0 2 9a8 9d2
1 9d4 1 9d6
2 9e0 9e2 3
9de 9df 9e4 2
9ed 9ef 2 9ec
9f1 1 9f3 1
9f5 3 9fc 9fd
9fe 3 9d7 9f6
a00 1 a02 2
987 a03 1 a05
7 637 642 75b
8bc 8bf 91e a06
2 a13 a18 1
a1f 1 a1a 2
a32 a34 3 a30
a31 a36 2 a3f
a41 2 a43 a45
2 a47 a49 2
a4b a4d 2 a4f
a51 3 a56 a57
a58 2 a53 a5a
2 a3e a5c 1
a5e 1 a60 2
a29 a61 1 a65
1 a24 2 a22
a69 1 a74 2
a70 a74 2 a7d
a82 1 a89 1
a84 2 a9c a9e
3 a9a a9b aa0
2 aa9 aab 2
aad aaf 2 ab1
ab3 2 ab5 ab7
2 ab9 abb 3
ac0 ac1 ac2 2
abd ac4 2 aa8
ac6 1 ac8 1
aca 2 a93 acb
1 acf 1 a8e
2 a8c ad3 1
ade 2 ada ade
2 aea aec 3
ae8 ae9 aee 2
af7 af9 2 afb
afd 2 aff b01
1 b09 2 b0b
b0c 2 b03 b0e
2 b10 b12 2
b14 b16 2 b18
b1a 2 b1c b1e
2 af6 b20 1
b22 1 b24 2
b2e b30 3 b2c
b2d b32 2 b3b
b3d 2 b3a b3f
1 b41 1 b43
3 b4a b4b b4c
3 b25 b44 b4e
1 b50 2 ad6
b51 1 b53 2
a6c b54 2 b56
b57 2 b5a b5b
1 b61 2 b5d
b61 2 b65 b66
1 b6c 2 b68
b6c 2 b73 b74
1 b78 2 b76
b78 2 b7f b80
1 b86 2 b82
b86 2 b8a b8b
1 b91 2 b8d
b91 1 b98 1
b9a 3 b9b b9e
ba1 1 ba5 2
ba3 ba5 2 bb3
bb4 2 bb8 bb9
2 bbd bbe 2
bc2 bc3 2 bc7
bc8 2 bcc bcd
2 bd1 bd2 2
bd6 bd7 d bb0
bb1 bb6 bbb bc0
bc5 bca bcf bd4
bd9 bda bdb bdc
2 be1 be2 1
be8 2 be4 be8
2 bf3 bf5 3
bf1 bf2 bf7 2
c00 c02 2 c04
c06 2 c08 c0a
1 c12 2 c14
c15 2 c0c c17
2 bff c19 1
c1b 1 c1d 2
c27 c29 3 c25
c26 c2b 2 c34
c36 2 c33 c38
1 c3a 1 c3c
2 c43 c44 3
c1e c3d c46 2
c4a c4b 1 c4f
2 c4d c4f 2
c5a c5c 3 c58
c59 c5e 2 c67
c69 2 c6b c6d
2 c6f c71 1
c77 2 c79 c7a
2 c73 c7c 2
c7e c80 2 c82
c84 2 c86 c88
2 c8a c8c 2
c66 c8e 1 c90
1 c92 2 c9c
c9e 3 c9a c9b
ca0 2 ca9 cab
2 ca8 cad 1
caf 1 cb1 2
cb7 cb8 3 cba
cbb cbc 3 c93
cb2 cbe 2 cc1
cc0 1 cc6 1
ccd 1 ccf 6
baa bad bdf cc2
cc5 cd0 2 cd4
cd5 1 cd9 2
cd7 cd9 2 cde
cdf 1 ce3 2
ce1 ce3 2 cea
ceb 1 cef 2
ced cef 2 cf4
cf5 1 cf9 2
cf7 cf9 1 d01
2 d05 d06 1
d0a 2 d08 d0a
1 d0f 2 d14
d15 1 d19 2
d17 d19 2 d1e
d1f 1 d23 2
d21 d23 1 d2b
2 d30 d31 1
d35 2 d33 d35
2 d3a d3b 2
d40 d41 2 d3d
d43 2 d46 d49
4 d4c d12 d2e
d4b 1 d4d 2
d50 d4f 1 d51
2 d53 d54 2
d67 d68 2 d6a
d6d 2 d70 d71
2 d78 d79 2
d7b d7e 2 d83
d84 1 d88 2
d86 d88 6 d8d
d8e d8f d90 d91
d92 2 d97 d98
1 d9e 2 d9a
d9e 2 da2 da3
1 da7 2 da5
da7 1 dae 1
db0 2 dba dbc
3 db8 db9 dbe
2 dc7 dc9 2
dcb dcd 2 dcf
dd1 1 dd7 2
dd9 dda 2 dd3
ddc 2 dde de0
2 de2 de4 2
de6 de8 2 dea
dec 2 dc6 dee
1 df0 1 df2
2 dfc dfe 3
dfa dfb e00 2
e09 e0b 2 e08
e0d 1 e0f 1
e11 2 e17 e18
3 e1a e1b e1c
4 db1 df3 e12
e1e 1 e20 2
e23 e24 1 e28
2 e26 e28 2
e2c e2d 1 e31
2 e2f e31 2
e3e e40 3 e3c
e3d e42 2 e4b
e4d 2 e4f e51
2 e53 e55 1
e5b 2 e5d e5e
2 e57 e60 2
e62 e64 2 e66
e68 2 e6a e6c
2 e6e e70 2
e4a e72 1 e74
1 e76 2 e80
e82 3 e7e e7f
e84 2 e8d e8f
2 e8c e91 1
e93 1 e95 2
e9b e9c 3 e9e
e9f ea0 3 e77
e96 ea2 1 ea4
2 ebd ec2 1
ec9 1 ec4 2
edc ede 3 eda
edb ee0 2 ee9
eeb 2 eed eef
2 ef1 ef3 2
ef5 ef7 2 ef9
efb 3 f00 f01
f02 2 efd f04
2 ee8 f06 1
f08 1 f0a 2
ed3 f0b 1 f0f
1 ece 2 ecc
f13 1 f1e 2
f1a f1e 1 f22
2 f2e f2f 1
f33 2 f31 f33
1 f38 1 f3a
2 f2c f3b 1
f3d 1 f47 2
f45 f47 3 f4b
f4c f4d 1 f51
2 f4f f51 2
f76 f7b 1 f82
1 f7d 2 f95
f97 3 f93 f94
f99 2 fa2 fa4
2 fa6 fa8 2
faa fac 2 fae
fb0 2 fb2 fb4
3 fb9 fba fbb
2 fb6 fbd 2
fa1 fbf 1 fc1
1 fc3 2 f8c
fc4 1 fc8 1
f87 2 f85 fcc
1 fd7 2 fd3
fd7 2 fdf fe0
1 fe4 2 fe2
fe4 2 fe9 fea
1 fee 2 fec
fee 2 1014 1019
1 1020 1 101b
2 1033 1035 3
1031 1032 1037 2
1040 1042 2 1044
1046 2 1048 104a
2 104c 104e 2
1050 1052 3 1057
1058 1059 2 1054
105b 2 103f 105d
1 105f 1 1061
2 102a 1062 1
1066 1 1025 2
1023 106a 1 106d
1 1072 2 1074
1075 2 fdd 1076
1 107f 2 107b
107f 2 1084 1085
1 1089 2 1087
1089 2 10af 10b4
1 10bb 1 10b6
2 10ce 10d0 3
10cc 10cd 10d2 2
10db 10dd 2 10df
10e1 2 10e3 10e5
2 10e7 10e9 2
10eb 10ed 3 10f2
10f3 10f4 2 10ef
10f6 2 10da 10f8
1 10fa 1 10fc
2 10c5 10fd 1
1101 1 10c0 2
10be 1105 1 1108
2 110c 110b 2
fcf 110d 2 112f
1134 1 113b 1
1136 2 114e 1150
3 114c 114d 1152
2 115b 115d 2
115f 1161 2 1163
1165 2 1167 1169
2 116b 116d 3
1172 1173 1174 2
116f 1176 2 115a
1178 1 117a 1
117c 2 1145 117d
1 1181 1 1140
2 113e 1185 1
1188 2 118b 118c
1 118d 3 1190
1191 1192 1 1196
2 1194 1196 2
11b2 11b7 1 11be
1 11b9 2 11d1
11d3 3 11cf 11d0
11d5 2 11de 11e0
2 11e2 11e4 2
11e6 11e8 2 11ea
11ec 2 11ee 11f0
3 11f5 11f6 11f7
2 11f2 11f9 2
11dd 11fb 1 11fd
1 11ff 2 11c8
1200 1 1204 1
11c3 2 11c1 1208
1 1213 2 120f
1213 2 121b 121c
1 1220 2 121e
1220 2 1225 1226
1 122a 2 1228
122a 2 1244 1249
1 1250 1 124b
2 1263 1265 3
1261 1262 1267 2
1270 1272 2 1274
1276 2 1278 127a
2 127c 127e 2
1280 1282 3 1287
1288 1289 2 1284
128b 2 126f 128d
1 128f 1 1291
2 125a 1292 1
1296 1 1255 2
1253 129a 1 129d
2 12a2 12a3 2
12a5 12a6 2 1219
12a7 1 12b0 2
12ac 12b0 2 12cb
12d0 1 12d7 1
12d2 2 12ea 12ec
3 12e8 12e9 12ee
2 12f7 12f9 2
12fb 12fd 2 12ff
1301 2 1303 1305
2 1307 1309 3
130e 130f 1310 2
130b 1312 2 12f6
1314 1 1316 1
1318 2 12e1 1319
1 131d 1 12dc
2 12da 1321 1
1324 2 1328 1327
2 120b 1329 2
1342 1347 1 134e
1 1349 2 1361
1363 3 135f 1360
1365 2 136e 1370
2 1372 1374 2
1376 1378 2 137a
137c 2 137e 1380
3 1385 1386 1387
2 1382 1389 2
136d 138b 1 138d
1 138f 2 1358
1390 1 1394 1
1353 2 1351 1398
1 139b 2 139e
139f 1 13a0 2
13a2 13a3 1 13ab
2 13a7 13ab 2
13b0 13b1 1 13b5
2 13b3 13b5 2
13c0 13c2 3 13be
13bf 13c4 2 13cd
13cf 2 13d1 13d3
2 13d5 13d7 1
13df 2 13e1 13e2
2 13d9 13e4 2
13e6 13e8 2 13ea
13ec 2 13ee 13f0
2 13f2 13f4 2
13cc 13f6 1 13f8
1 13fa 2 1404
1406 3 1402 1403
1408 2 1411 1413
2 1410 1415 1
1417 1 1419 3
1420 1421 1422 3
13fb 141a 1424 1
1427 2 142d 142e
1 1432 2 1430
1432 1 1439 2
1437 1439 2 144e
1453 1 145a 1
1455 2 146d 146f
3 146b 146c 1471
2 147a 147c 2
147e 1480 2 1482
1484 2 1486 1488
2 148a 148c 3
1491 1492 1493 2
148e 1495 2 1479
1497 1 1499 1
149b 2 1464 149c
1 14a0 1 145f
2 145d 14a4 2
143e 14a7 2 14b9
14be 1 14c5 1
14c0 2 14d8 14da
3 14d6 14d7 14dc
2 14e5 14e7 2
14e9 14eb 2 14ed
14ef 2 14f1 14f3
2 14f5 14f7 3
14fc 14fd 14fe 2
14f9 1500 2 14e4
1502 1 1504 1
1506 2 14cf 1507
1 150b 1 14ca
2 14c8 150f 2
14ac 1512 2 1515
1516 2 1519 151a
2 151f 1520 1
1522 2 151c 1522
2 152d 152f 3
152b 152c 1531 2
153a 153c 2 153e
1540 2 1542 1544
1 154c 2 154e
154f 2 1546 1551
2 1553 1555 2
1557 1559 2 155b
155d 2 155f 1561
2 1539 1563 1
1565 1 1567 2
1571 1573 3 156f
1570 1575 2 157e
1580 2 157d 1582
1 1584 1 1586
3 158d 158e 158f
3 1568 1587 1591
1 1593 2 1517
1594 2 1597 1596
2 1598 159b 2
159f 15a0 1 15a4
2 15a2 15a4 2
15aa 15ab 1 15ad
1 15b2 2 15b0
15b2 2 15bf 15c1
3 15bd 15be 15c3
2 15cc 15ce 2
15d0 15d2 2 15d4
15d6 1 15de 2
15e0 15e1 2 15d8
15e3 2 15e5 15e7
2 15e9 15eb 2
15ed 15ef 2 15f1
15f3 2 15cb 15f5
1 15f7 1 15f9
2 1603 1605 3
1601 1602 1607 2
1610 1612 2 160f
1614 1 1616 1
1618 3 161f 1620
1621 3 15fa 1619
1623 2 1626 1625
3 1629 162a 162b
1 162f 2 162d
162f 2 1634 1636
3 1638 1639 163a
2 1653 1658 1
165f 1 165a 2
1672 1674 3 1670
1671 1676 2 167f
1681 2 1683 1685
2 1687 1689 2
168b 168d 2 168f
1691 3 1696 1697
1698 2 1693 169a
2 167e 169c 1
169e 1 16a0 2
1669 16a1 1 16a5
1 1664 2 1662
16a9 1 16b4 2
16b0 16b4 2 16c0
16c2 3 16be 16bf
16c4 2 16cd 16cf
2 16d1 16d3 2
16d5 16d7 1 16df
2 16e1 16e2 2
16d9 16e4 2 16e6
16e8 2 16ea 16ec
2 16ee 16f0 2
16f2 16f4 2 16cc
16f6 1 16f8 1
16fa 2 1704 1706
3 1702 1703 1708
2 1711 1713 2
1710 1715 1 1717
1 1719 3 1720
1721 1722 3 16fb
171a 1724 1 1726
3 1729 172a 172b
1 172f 2 172d
172f 2 1734 1735
1 1739 2 1737
1739 2 173e 173f
2 1744 1745 1
1747 2 1741 1747
2 1758 175a 3
1756 1757 175c 2
1765 1767 2 1769
176b 2 176d 176f
1 1777 2 1779
177a 2 1771 177c
2 177e 1780 2
1782 1784 2 1786
1788 2 178a 178c
2 1764 178e 1
1790 1 1792 2
179c 179e 3 179a
179b 17a0 2 17a9
17ab 2 17a8 17ad
1 17af 1 17b1
3 17b8 17b9 17ba
3 1793 17b2 17bc
1 17be 2 17cc
17d1 1 17d8 1
17d3 2 17eb 17ed
3 17e9 17ea 17ef
2 17f8 17fa 2
17fc 17fe 2 1800
1802 2 1804 1806
2 1808 180a 3
180f 1810 1811 2
180c 1813 2 17f7
1815 1 1817 1
1819 2 17e2 181a
1 181e 1 17dd
2 17db 1822 5
163d 16ac 1727 17bf
1825 2 182a 182c
3 182e 182f 1830
2 1839 183e 1
1845 1 1840 2
1858 185a 3 1856
1857 185c 2 1865
1867 2 1869 186b
2 186d 186f 2
1871 1873 2 1875
1877 3 187c 187d
187e 2 1879 1880
2 1864 1882 1
1884 1 1886 2
184f 1887 1 188b
1 184a 2 1848
188f 1 189a 2
1896 189a 2 18a6
18a8 3 18a4 18a5
18aa 2 18b3 18b5
2 18b7 18b9 2
18bb 18bd 1 18c5
2 18c7 18c8 2
18bf 18ca 2 18cc
18ce 2 18d0 18d2
2 18d4 18d6 2
18d8 18da 2 18b2
18dc 1 18de 1
18e0 2 18ea 18ec
3 18e8 18e9 18ee
2 18f7 18f9 2
18f6 18fb 1 18fd
1 18ff 3 1906
1907 1908 3 18e1
1900 190a 1 190c
2 1922 1927 1
192e 1 1929 2
1941 1943 3 193f
1940 1945 2 194e
1950 2 1952 1954
2 1956 1958 2
195a 195c 2 195e
1960 3 1965 1966
1967 2 1962 1969
2 194d 196b 1
196d 1 196f 2
1938 1970 1 1974
1 1933 2 1931
1978 1 1983 2
197f 1983 2 1988
1989 1 198d 2
198b 198d 2 199b
199d 3 1999 199a
199f 2 19a8 19aa
2 19ac 19ae 2
19b0 19b2 1 19ba
2 19bc 19bd 2
19b4 19bf 2 19c1
19c3 2 19c5 19c7
2 19c9 19cb 2
19cd 19cf 2 19a7
19d1 1 19d3 1
19d5 2 19df 19e1
3 19dd 19de 19e3
2 19ec 19ee 2
19eb 19f0 1 19f2
1 19f4 3 19fb
19fc 19fd 3 19d6
19f5 19ff 1 1a01
2 1a0f 1a14 1
1a1b 1 1a16 2
1a2e 1a30 3 1a2c
1a2d 1a32 2 1a3b
1a3d 2 1a3f 1a41
2 1a43 1a45 2
1a47 1a49 2 1a4b
1a4d 3 1a52 1a53
1a54 2 1a4f 1a56
2 1a3a 1a58 1
1a5a 1 1a5c 2
1a25 1a5d 1 1a61
1 1a20 2 1a1e
1a65 6 1833 1892
190d 197b 1a02 1a68
2 1a6b 1a6c 2
1a72 1a73 1 1a77
2 1a75 1a77 2
1a84 1a89 1 1a90
1 1a8b 2 1aa3
1aa5 3 1aa1 1aa2
1aa7 2 1ab0 1ab2
2 1ab4 1ab6 2
1ab8 1aba 2 1abc
1abe 2 1ac0 1ac2
3 1ac7 1ac8 1ac9
2 1ac4 1acb 2
1aaf 1acd 1 1acf
1 1ad1 2 1a9a
1ad2 1 1ad6 1
1a95 2 1a93 1ada
2 1ae9 1aee 1
1af5 1 1af0 2
1b08 1b0a 3 1b06
1b07 1b0c 2 1b15
1b17 2 1b19 1b1b
2 1b1d 1b1f 2
1b21 1b23 2 1b25
1b27 3 1b2c 1b2d
1b2e 2 1b29 1b30
2 1b14 1b32 1
1b34 1 1b36 2
1aff 1b37 1 1b3b
1 1afa 2 1af8
1b3f 2 1b4b 1b4c
1 1b50 2 1b4e
1b50 1 1b55 1
1b57 21 1b5b 1b5c
1b5d 1b5e 1b5f 1b60
1b61 1b62 1b63 1b64
1b65 1b66 1b67 1b68
1b69 1b6a 1b6b 1b6c
1b6d 1b6e 1b6f 1b70
1b71 1b72 1b73 1b74
1b75 1b76 1b77 1b78
1b79 1b7a 1b7b 1
1b81 2 1b7f 1b81
2 1b85 1b86 1
1b8a 2 1b88 1b8a
1 1b94 2 1b93
1b94 1 1b9c 1
1ba2 2 1ba4 1ba5
2 1b91 1ba6 1
1bad 1 1ba8 2
1bc0 1bc2 3 1bbe
1bbf 1bc4 2 1bcd
1bcf 2 1bd1 1bd3
2 1bd5 1bd7 2
1bd9 1bdb 2 1bdd
1bdf 3 1be4 1be5
1be6 2 1be1 1be8
2 1bcc 1bea 1
1bec 1 1bee 2
1bb7 1bef 1 1bf3
1 1bb2 2 1bb0
1bf7 1 1bfa 1
1c04 2 1c03 1c04
1 1c0c 1 1c12
2 1c14 1c15 2
1c01 1c16 1 1c1d
1 1c18 2 1c30
1c32 3 1c2e 1c2f
1c34 2 1c3d 1c3f
2 1c41 1c43 2
1c45 1c47 2 1c49
1c4b 2 1c4d 1c4f
3 1c54 1c55 1c56
2 1c51 1c58 2
1c3c 1c5a 1 1c5c
1 1c5e 2 1c27
1c5f 1 1c63 1
1c22 2 1c20 1c67
1 1c6a 2 1c6d
1c6e 1 1c6f 1
1c71 7 1add 1b42
1b46 1b49 1b58 1b7e
1c72 3 1c7b 1c7c
1c7d 1 1c81 2
1c7f 1c81 1 1c88
2 1c8d 1c8e 2
1c90 1c93 1 1c96
2 1c98 1c99 21
1c9d 1c9e 1c9f 1ca0
1ca1 1ca2 1ca3 1ca4
1ca5 1ca6 1ca7 1ca8
1ca9 1caa 1cab 1cac
1cad 1cae 1caf 1cb0
1cb1 1cb2 1cb3 1cb4
1cb5 1cb6 1cb7 1cb8
1cb9 1cba 1cbb 1cbc
1cbd 1 1cc3 2
1cc1 1cc3 1 1ccd
2 1ccc 1ccd 1
1cd5 1 1cdb 2
1cdd 1cde 2 1cca
1cdf 1 1ce6 1
1ce1 2 1cf9 1cfb
3 1cf7 1cf8 1cfd
2 1d06 1d08 2
1d0a 1d0c 2 1d0e
1d10 2 1d12 1d14
2 1d16 1d18 3
1d1d 1d1e 1d1f 2
1d1a 1d21 2 1d05
1d23 1 1d25 1
1d27 2 1cf0 1d28
1 1d2c 1 1ceb
2 1ce9 1d30 1
1d33 1 1d36 5
1c76 1c79 1c9a 1cc0
1d37 2 1d39 1d3a
d d95 e21 ea5
ea8 f16 f3e f41
f44 13a4 1627 1a6d
1a70 1d3b 1 1d3f
2 1d41 1d42 1
1d46 2 1d44 1d46
1 1d4b 1 1d51
2 1d53 1d54 2
1d56 1d58 2 1d5b
1d5d 1 1d5f 1
1d62 2 1d64 1d65
1 1d69 2 1d67
1d69 2 1d71 1d72
1 1d75 2 1d74
1d75 2 1d85 1d86
2 1d88 1d8a 2
1d8c 1d8e 4 1d82
1d83 1d90 1d91 2
1d9c 1d9d 2 1d9f
1da1 2 1da3 1da5
2 1da7 1da9 4
1d99 1d9a 1dab 1dac
2 1dca 1dcf 1
1dd6 1 1dd1 2
1de9 1deb 3 1de7
1de8 1ded 2 1df6
1df8 2 1dfa 1dfc
2 1dfe 1e00 2
1e02 1e04 2 1e06
1e08 3 1e0d 1e0e
1e0f 2 1e0a 1e11
2 1df5 1e13 1
1e15 1 1e17 2
1de0 1e18 1 1e1c
1 1ddb 2 1dd9
1e20 2 1e26 1e27
1 1e2b 2 1e29
1e2b 1 1e2f 2
1e3d 1e3e 1 1e42
2 1e40 1e42 1
1e47 1 1e49 2
1e39 1e4a 1 1e4c
3 1e4f 1e50 1e51
1 1e55 2 1e53
1e55 1 1e5f 2
1e61 1e62 1 1e66
2 1e64 1e66 1
1e6b 2 1e6f 1e71
3 1e73 1e74 1e75
2 1e7b 1e7d 3
1e7f 1e80 1e81 2
1e78 1e84 2 1e86
1e87 2 1e5c 1e88
1 1e8c 2 1e8e
1e8f 1 1e93 2
1e91 1e93 1 1e98
2 1e9c 1e9e 3
1ea0 1ea1 1ea2 2
1ea8 1eaa 3 1eac
1ead 1eae 2 1ea5
1eb1 2 1eb3 1eb4
1 1eb5 2 1eb7
1eb8 2 1ec1 1ec2
1 1ec6 2 1ec4
1ec6 1 1ecb 2
1ec9 1ecb 3 1ecf
1ed0 1ed1 1 1ed5
2 1ed3 1ed5 2
1ef4 1ef9 1 1f00
1 1efb 2 1f13
1f15 3 1f11 1f12
1f17 2 1f20 1f22
2 1f24 1f26 2
1f28 1f2a 2 1f2c
1f2e 2 1f30 1f32
3 1f37 1f38 1f39
2 1f34 1f3b 2
1f1f 1f3d 1 1f3f
1 1f41 2 1f0a
1f42 1 1f46 1
1f05 2 1f03 1f4a
1 1f55 2 1f51
1f55 2 1f5d 1f5e
1 1f62 2 1f60
1f62 2 1f67 1f68
1 1f6c 2 1f6a
1f6c 2 1f8c 1f91
1 1f98 1 1f93
2 1fab 1fad 3
1fa9 1faa 1faf 2
1fb8 1fba 2 1fbc
1fbe 2 1fc0 1fc2
2 1fc4 1fc6 2
1fc8 1fca 3 1fcf
1fd0 1fd1 2 1fcc
1fd3 2 1fb7 1fd5
1 1fd7 1 1fd9
2 1fa2 1fda 1
1fde 1 1f9d 2
1f9b 1fe2 1 1fe5
1 1fea 2 1fec
1fed 2 1f5b 1fee
1 1ff7 2 1ff3
1ff7 2 1ffc 1ffd
1 2001 2 1fff
2001 2 2021 2026
1 202d 1 2028
2 2040 2042 3
203e 203f 2044 2
204d 204f 2 2051
2053 2 2055 2057
2 2059 205b 2
205d 205f 3 2064
2065 2066 2 2061
2068 2 204c 206a
1 206c 1 206e
2 2037 206f 1
2073 1 2032 2
2030 2077 1 207a
2 207e 207d 2
1f4d 207f 2 209d
20a2 1 20a9 1
20a4 2 20bc 20be
3 20ba 20bb 20c0
2 20c9 20cb 2
20cd 20cf 2 20d1
20d3 2 20d5 20d7
2 20d9 20db 3
20e0 20e1 20e2 2
20dd 20e4 2 20c8
20e6 1 20e8 1
20ea 2 20b3 20eb
1 20ef 1 20ae
2 20ac 20f3 1
20f6 2 20f9 20fa
1 20fb 3 20fe
20ff 2100 1 2104
2 2102 2104 2
2122 2127 1 212e
1 2129 2 2141
2143 3 213f 2140
2145 2 214e 2150
2 2152 2154 2
2156 2158 2 215a
215c 2 215e 2160
3 2165 2166 2167
2 2162 2169 2
214d 216b 1 216d
1 216f 2 2138
2170 1 2174 1
2133 2 2131 2178
1 2183 2 217f
2183 2 2188 2189
1 218d 2 218b
218d 2 2192 2193
1 2197 2 2195
2197 2 21b3 21b8
1 21bf 1 21ba
2 21d2 21d4 3
21d0 21d1 21d6 2
21df 21e1 2 21e3
21e5 2 21e7 21e9
2 21eb 21ed 2
21ef 21f1 3 21f6
21f7 21f8 2 21f3
21fa 2 21de 21fc
1 21fe 1 2200
2 21c9 2201 1
2205 1 21c4 2
21c2 2209 1 220c
2 2211 2212 2
2214 2215 1 2216
1 221f 2 221b
221f 2 223c 2241
1 2248 1 2243
2 225b 225d 3
2259 225a 225f 2
2268 226a 2 226c
226e 2 2270 2272
2 2274 2276 2
2278 227a 3 227f
2280 2281 2 227c
2283 2 2267 2285
1 2287 1 2289
2 2252 228a 1
228e 1 224d 2
224b 2292 1 2295
2 2299 2298 2
217b 229a 2 22b5
22ba 1 22c1 1
22bc 2 22d4 22d6
3 22d2 22d3 22d8
2 22e1 22e3 2
22e5 22e7 2 22e9
22eb 2 22ed 22ef
2 22f1 22f3 3
22f8 22f9 22fa 2
22f5 22fc 2 22e0
22fe 1 2300 1
2302 2 22cb 2303
1 2307 1 22c6
2 22c4 230b 1
230e 2 2311 2312
1 2313 2 2315
2316 1 231e 2
231a 231e 2 2323
2324 1 2328 2
2326 2328 1 232d
1 232f 1 2336
2 2334 2336 2
234b 2350 1 2357
1 2352 2 236a
236c 3 2368 2369
236e 2 2377 2379
2 237b 237d 2
237f 2381 2 2383
2385 2 2387 2389
3 238e 238f 2390
2 238b 2392 2
2376 2394 1 2396
1 2398 2 2361
2399 1 239d 1
235c 2 235a 23a1
2 233b 23a4 2
23b6 23bb 1 23c2
1 23bd 2 23d5
23d7 3 23d3 23d4
23d9 2 23e2 23e4
2 23e6 23e8 2
23ea 23ec 2 23ee
23f0 2 23f2 23f4
3 23f9 23fa 23fb
2 23f6 23fd 2
23e1 23ff 1 2401
1 2403 2 23cc
2404 1 2408 1
23c7 2 23c5 240c
2 23a9 240f 2
2412 2413 2 2416
2417 2 241c 241d
1 241f 2 2419
241f 2 2424 2425
2 2427 2429 2
242c 242e 1 2430
2 2414 2431 1
2433 2 2434 2437
2 2439 243a 1
243b 2 243f 2440
2 2442 2444 2
2447 2449 2 244b
244c 2 245e 2463
1 246a 1 2465
2 247d 247f 3
247b 247c 2481 2
248a 248c 2 248e
2490 2 2492 2494
2 2496 2498 2
249a 249c 3 24a1
24a2 24a3 2 249e
24a5 2 2489 24a7
1 24a9 1 24ab
2 2474 24ac 1
24b0 1 246f 2
246d 24b4 2 24c3
24c8 1 24cf 1
24ca 2 24e2 24e4
3 24e0 24e1 24e6
2 24ef 24f1 2
24f3 24f5 2 24f7
24f9 2 24fb 24fd
2 24ff 2501 3
2506 2507 2508 2
2503 250a 2 24ee
250c 1 250e 1
2510 2 24d9 2511
1 2515 1 24d4
2 24d2 2519 2
2525 2526 1 252a
2 2528 252a 1
252f 1 2531 21
2535 2536 2537 2538
2539 253a 253b 253c
253d 253e 253f 2540
2541 2542 2543 2544
2545 2546 2547 2548
2549 254a 254b 254c
254d 254e 254f 2550
2551 2552 2553 2554
2555 1 255b 2
2559 255b 2 255f
2560 1 2564 2
2562 2564 1 256e
2 256d 256e 1
2576 1 257c 2
257e 257f 2 256b
2580 1 2587 1
2582 2 259a 259c
3 2598 2599 259e
2 25a7 25a9 2
25ab 25ad 2 25af
25b1 2 25b3 25b5
2 25b7 25b9 3
25be 25bf 25c0 2
25bb 25c2 2 25a6
25c4 1 25c6 1
25c8 2 2591 25c9
1 25cd 1 258c
2 258a 25d1 1
25d4 1 25de 2
25dd 25de 1 25e6
1 25ec 2 25ee
25ef 2 25db 25f0
1 25f7 1 25f2
2 260a 260c 3
2608 2609 260e 2
2617 2619 2 261b
261d 2 261f 2621
2 2623 2625 2
2627 2629 3 262e
262f 2630 2 262b
2632 2 2616 2634
1 2636 1 2638
2 2601 2639 1
263d 1 25fc 2
25fa 2641 1 2644
2 2647 2648 1
2649 1 264b b
2317 244d 2450 2453
24b7 251c 2520 2523
2532 2558 264c 2
2650 2651 1 2655
2 2653 2655 3
265f 2660 2661 1
2665 2 2663 2665
1 266c 2 2670
2671 1 2674 2
2676 2677 21 267b
267c 267d 267e 267f
2680 2681 2682 2683
2684 2685 2686 2687
2688 2689 268a 268b
268c 268d 268e 268f
2690 2691 2692 2693
2694 2695 2696 2697
2698 2699 269a 269b
1 26a1 2 269f
26a1 1 26ab 2
26aa 26ab 1 26b3
1 26b9 2 26bb
26bc 2 26a8 26bd
1 26c4 1 26bf
2 26d7 26d9 3
26d5 26d6 26db 2
26e4 26e6 2 26e8
26ea 2 26ec 26ee
2 26f0 26f2 2
26f4 26f6 3 26fb
26fc 26fd 2 26f8
26ff 2 26e3 2701
1 2703 1 2705
2 26ce 2706 1
270a 1 26c9 2
26c7 270e 1 2711
1 2714 5 265a
265d 2678 269e 2715
2 2718 2717 2
271c 271d 2 271f
2721 1 2725 f
1d7d 1d94 1daf 1db2
1db5 1db8 1dbb 1e23
1e4d 1eb9 1ebc 1ebf
2719 2724 2728 2
1d6e 272b 1 272d
2 1d66 272e 2
2730 2731 1 2735
2 2733 2735 2
273a 273b 1 273f
2 273d 273f 2
2746 2747 1 274b
2 2749 274b 1
2754 2 2753 2754
1 275c 1 2762
2 2764 2765 2
2751 2766 1 276d
1 2768 2 2780
2782 3 277e 277f
2784 2 278d 278f
2 2791 2793 2
2795 2797 2 2799
279b 2 279d 279f
3 27a4 27a5 27a6
2 27a1 27a8 2
278c 27aa 1 27ac
1 27ae 2 2777
27af 1 27b3 1
2772 2 2770 27b7
1 27ba 1 27c7
2 27c6 27c7 1
27cf 1 27d5 2
27d7 27d8 2 27c4
27d9 1 27e0 1
27db 2 27f3 27f5
3 27f1 27f2 27f7
2 2800 2802 2
2804 2806 2 2808
280a 2 280c 280e
2 2810 2812 3
2817 2818 2819 2
2814 281b 2 27ff
281d 1 281f 1
2821 2 27ea 2822
1 2826 1 27e5
2 27e3 282a 1
282d 2 2830 2831
1 2835 2 2833
2835 2 2840 2842
3 283e 283f 2844
2 284d 284f 2
2851 2853 2 2855
2857 1 285f 2
2861 2862 2 2859
2864 2 2866 2868
2 286a 286c 2
286e 2870 2 2872
2874 2 284c 2876
1 2878 1 287a
2 2884 2886 3
2882 2883 2888 2
2891 2893 2 2890
2895 1 2897 1
2899 3 28a0 28a1
28a2 3 287b 289a
28a4 1 28ab 2
28a7 28ab 2 28b6
28b8 3 28b4 28b5
28ba 2 28c3 28c5
2 28c7 28c9 2
28cb 28cd 1 28d5
2 28d7 28d8 2
28cf 28da 2 28dc
28de 2 28e0 28e2
2 28e4 28e6 2
28e8 28ea 2 28c2
28ec 1 28ee 1
28f0 2 28fa 28fc
3 28f8 28f9 28fe
2 2907 2909 2
2906 290b 1 290d
1 290f 3 2916
2917 2918 3 28f1
2910 291a 1 2922
2 291e 2922 2
292d 292f 3 292b
292c 2931 2 293a
293c 2 293e 2940
2 2942 2944 1
294c 2 294e 294f
2 2946 2951 2
2953 2955 2 2957
2959 2 295b 295d
2 295f 2961 2
2939 2963 1 2965
1 2967 2 2971
2973 3 296f 2970
2975 2 297e 2980
2 297d 2982 1
2984 1 2986 3
298d 298e 298f 3
2968 2987 2991 2
299c 299e 3 299a
299b 29a0 2 29a9
29ab 2 29ad 29af
2 29b1 29b3 1
29bb 2 29bd 29be
2 29b5 29c0 2
29c2 29c4 2 29c6
29c8 2 29ca 29cc
2 29ce 29d0 2
29a8 29d2 1 29d4
1 29d6 2 29e0
29e2 3 29de 29df
29e4 2 29ed 29ef
2 29ec 29f1 1
29f3 1 29f5 3
29fc 29fd 29fe 3
29d7 29f6 2a00 4
2a02 291d 2993 2a03
2 2832 2a04 1
2a06 1 2a0a 2
2a0c 2a0d 1 2a11
2 2a0f 2a11 1
2a17 2 2a19 2a1a
1 2a1e 2 2a1c
2a1e 2 2a2f 2a31
2 2a33 2a35 2
2a37 2a39 2 2a3b
2a3d 2 2a3f 2a41
2 2a43 2a45 2
2a47 2a49 2 2a4b
2a4d 2 2a4f 2a51
2 2a53 2a55 2
2a57 2a59 2 2a5b
2a5d 1 2a68 2
2a67 2a68 1 2a70
1 2a76 2 2a78
2a79 2 2a65 2a7a
1 2a81 1 2a7c
2 2a94 2a96 3
2a92 2a93 2a98 2
2aa1 2aa3 2 2aa5
2aa7 2 2aa9 2aab
2 2aad 2aaf 2
2ab1 2ab3 3 2ab8
2ab9 2aba 2 2ab5
2abc 2 2aa0 2abe
2 2ac5 2ac7 2
2ac4 2ac9 2 2ac0
2acb 1 2acd 2
2a8b 2ace 1 2ad2
1 2a86 2 2a84
2ad6 2 2ae6 2ae8
2 2aea 2aec 2
2aee 2af0 2 2af2
2af4 2 2af6 2af8
2 2afa 2afc 2
2afe 2b00 2 2b02
2b04 2 2b06 2b08
2 2b0a 2b0c 2
2b0e 2b10 2 2b12
2b14 1 2b1f 2
2b1e 2b1f 1 2b27
1 2b2d 2 2b2f
2b30 2 2b1c 2b31
1 2b38 1 2b33
2 2b4b 2b4d 3
2b49 2b4a 2b4f 2
2b58 2b5a 2 2b5c
2b5e 2 2b60 2b62
2 2b64 2b66 2
2b68 2b6a 3 2b6f
2b70 2b71 2 2b6c
2b73 2 2b57 2b75
2 2b7c 2b7e 2
2b7b 2b80 2 2b77
2b82 1 2b84 2
2b42 2b85 1 2b89
1 2b3d 2 2b3b
2b8d 2 2b9a 2b9c
2 2b9e 2ba0 2
2ba2 2ba4 2 2ba6
2ba8 2 2baa 2bac
2 2bae 2bb0 2
2bb2 2bb4 2 2bb6
2bb8 2 2bba 2bbc
2 2bbe 2bc0 2
2bc2 2bc4 2 2bc6
2bc8 2 2bca 2bcc
2 2bce 2bd0 2
2bd2 2bd4 2 2bd6
2bd8 2 2bda 2bdc
2 2bde 2be0 2
2be2 2be4 2 2be6
2be8 2 2bea 2bec
2 2bee 2bf0 2
2bf2 2bf4 2 2bf6
2bf8 2 2bfa 2bfc
2 2bfe 2c00 2
2c02 2c04 2 2c06
2c08 2 2c0a 2c0c
2 2c0e 2c10 2
2c12 2c14 2 2c16
2c18 2 2c1a 2c1c
2 2c1e 2c20 2
2c22 2c24 2 2c26
2c28 2 2c2a 2c2c
2 2c2e 2c30 1
2c3b 2 2c3a 2c3b
1 2c43 1 2c49
2 2c4b 2c4c 2
2c38 2c4d 1 2c54
1 2c4f 2 2c67
2c69 3 2c65 2c66
2c6b 2 2c74 2c76
2 2c78 2c7a 2
2c7c 2c7e 2 2c80
2c82 2 2c84 2c86
3 2c8b 2c8c 2c8d
2 2c88 2c8f 2
2c73 2c91 2 2c98
2c9a 2 2c97 2c9c
2 2c93 2c9e 1
2ca0 2 2c5e 2ca1
1 2ca5 1 2c59
2 2c57 2ca9 2
2caf 2cb1 2 2cb3
2cb5 2 2cb7 2cb9
2 2cbf 2cc0 1
2cc2 2 2cbb 2cc4
2 2cc6 2cc8 2
2cca 2ccc 2 2cd2
2cd3 1 2cd5 2
2cce 2cd7 2 2cd9
2cdb 2 2cdd 2cdf
2 2ce1 2ce3 2
2ce5 2ce7 2 2ce9
2ceb 2 2ced 2cef
2 2cf1 2cf3 2
2cf5 2cf7 2 2cf9
2cfb 2 2d01 2d02
1 2d04 2 2cfd
2d06 2 2d08 2d0a
2 2d0c 2d0e 2
2d14 2d15 1 2d17
2 2d10 2d19 2
2d1b 2d1d 2 2d1f
2d21 2 2d23 2d25
2 2d27 2d29 2
2d2b 2d2d c 2a28
2a2d 2a60 2ad9 2adf
2ae4 2b17 2b90 2b98
2c33 2cac 2d30 1
2d35 2 2d37 2d38
1 2d3c 2 2d3a
2d3c 2 2d4a 2d4c
2 2d4e 2d50 2
2d52 2d54 2 2d56
2d58 2 2d5a 2d5c
2 2d5e 2d60 2
2d62 2d64 2 2d66
2d68 2 2d6a 2d6c
2 2d6e 2d70 1
2d7b 2 2d7a 2d7b
1 2d83 1 2d89
2 2d8b 2d8c 2
2d78 2d8d 1 2d94
1 2d8f 2 2da7
2da9 3 2da5 2da6
2dab 2 2db4 2db6
2 2db8 2dba 2
2dbc 2dbe 2 2dc0
2dc2 2 2dc4 2dc6
3 2dcb 2dcc 2dcd
2 2dc8 2dcf 2
2db3 2dd1 2 2dd8
2dda 2 2dd7 2ddc
2 2dd3 2dde 1
2de0 2 2d9e 2de1
1 2de5 1 2d99
2 2d97 2de9 2
2df9 2dfb 2 2dfd
2dff 2 2e01 2e03
2 2e05 2e07 2
2e09 2e0b 2 2e0d
2e0f 2 2e11 2e13
2 2e15 2e17 2
2e19 2e1b 1 2e26
2 2e25 2e26 1
2e2e 1 2e34 2
2e36 2e37 2 2e23
2e38 1 2e3f 1
2e3a 2 2e52 2e54
3 2e50 2e51 2e56
2 2e5f 2e61 2
2e63 2e65 2 2e67
2e69 2 2e6b 2e6d
2 2e6f 2e71 3
2e76 2e77 2e78 2
2e73 2e7a 2 2e5e
2e7c 2 2e83 2e85
2 2e82 2e87 2
2e7e 2e89 1 2e8b
2 2e49 2e8c 1
2e90 1 2e44 2
2e42 2e94 2 2ea1
2ea3 2 2ea5 2ea7
2 2ea9 2eab 2
2ead 2eaf 2 2eb1
2eb3 2 2eb5 2eb7
2 2eb9 2ebb 2
2ebd 2ebf 2 2ec1
2ec3 2 2ec5 2ec7
2 2ec9 2ecb 2
2ecd 2ecf 2 2ed1
2ed3 2 2ed5 2ed7
2 2ed9 2edb 2
2edd 2edf 2 2ee1
2ee3 2 2ee5 2ee7
1 2ef2 2 2ef1
2ef2 1 2efa 1
2f00 2 2f02 2f03
2 2eef 2f04 1
2f0b 1 2f06 2
2f1e 2f20 3 2f1c
2f1d 2f22 2 2f2b
2f2d 2 2f2f 2f31
2 2f33 2f35 2
2f37 2f39 2 2f3b
2f3d 3 2f42 2f43
2f44 2 2f3f 2f46
2 2f2a 2f48 2
2f4f 2f51 2 2f4e
2f53 2 2f4a 2f55
1 2f57 2 2f15
2f58 1 2f5c 1
2f10 2 2f0e 2f60
2 2f66 2f68 2
2f6a 2f6c 2 2f6e
2f70 2 2f76 2f77
1 2f79 2 2f72
2f7b 2 2f7d 2f7f
2 2f85 2f86 1
2f88 2 2f81 2f8a
2 2f8c 2f8e 2
2f90 2f92 2 2f94
2f96 2 2f98 2f9a
2 2f9c 2f9e c
2d43 2d48 2d73 2dec
2df2 2df7 2e1e 2e97
2e9f 2eea 2f63 2fa1
2 2faf 2fb1 2
2fb3 2fb5 2 2fb7
2fb9 2 2fbb 2fbd
2 2fbf 2fc1 2
2fc3 2fc5 2 2fc7
2fc9 2 2fcb 2fcd
2 2fcf 2fd1 2
2fd3 2fd5 2 2fd7
2fd9 2 2fdb 2fdd
1 2fe8 2 2fe7
2fe8 1 2ff0 1
2ff6 2 2ff8 2ff9
2 2fe5 2ffa 1
3001 1 2ffc 2
3014 3016 3 3012
3013 3018 2 3021
3023 2 3025 3027
2 3029 302b 2
302d 302f 2 3031
3033 3 3038 3039
303a 2 3035 303c
2 3020 303e 2
3045 3047 2 3044
3049 2 3040 304b
1 304d 2 300b
304e 1 3052 1
3006 2 3004 3056
2 3066 3068 2
306a 306c 2 306e
3070 2 3072 3074
2 3076 3078 2
307a 307c 2 307e
3080 2 3082 3084
2 3086 3088 1
3093 2 3092 3093
1 309b 1 30a1
2 30a3 30a4 2
3090 30a5 1 30ac
1 30a7 2 30bf
30c1 3 30bd 30be
30c3 2 30cc 30ce
2 30d0 30d2 2
30d4 30d6 2 30d8
30da 2 30dc 30de
3 30e3 30e4 30e5
2 30e0 30e7 2
30cb 30e9 2 30f0
30f2 2 30ef 30f4
2 30eb 30f6 1
30f8 2 30b6 30f9
1 30fd 1 30b1
2 30af 3101 2
310e 3110 2 3112
3114 2 3116 3118
2 311a 311c 2
311e 3120 2 3122
3124 2 3126 3128
2 312a 312c 2
312e 3130 2 3132
3134 2 3136 3138
2 313a 313c 2
313e 3140 2 3142
3144 2 3146 3148
2 314a 314c 1
3157 2 3156 3157
1 315f 1 3165
2 3167 3168 2
3154 3169 1 3170
1 316b 2 3183
3185 3 3181 3182
3187 2 3190 3192
2 3194 3196 2
3198 319a 2 319c
319e 2 31a0 31a2
3 31a7 31a8 31a9
2 31a4 31ab 2
318f 31ad 2 31b4
31b6 2 31b3 31b8
2 31af 31ba 1
31bc 2 317a 31bd
1 31c1 1 3175
2 3173 31c5 2
31cb 31cd 2 31cf
31d1 2 31d3 31d5
2 31db 31dc 1
31de 2 31d7 31e0
2 31e2 31e4 2
31e6 31e8 2 31ee
31ef 1 31f1 2
31ea 31f3 2 31f5
31f7 2 31f9 31fb
2 31fd 31ff 2
3201 3203 2 3205
3207 c 2fa8 2fad
2fe0 3059 305f 3064
308b 3104 310c 314f
31c8 320a 3 320c
2fa3 320d 2 3217
3219 3 3215 3216
321b 2 3224 3226
2 3223 3228 1
322a 1 322c 2
3236 3238 3 3234
3235 323a 2 3243
3245 2 3242 3247
1 3249 1 324b
1 3251 2d 2fa
319 31c 31f 322
325 328 32b 32e
331 334 337 33a
33d 340 343 346
349 34c 356 359
35c 35f 3c3 427
4a5 600 603 60e
616 61e 621 b58
d55 d5a d5d d60
d74 d81 2732 2a07
320e 322d 324c 3254
2 3261 3263 3
325f 3260 3265 2
326e 3270 2 326d
3272 2 3279 327d
2 327f 3281 2
3283 3287 2 3278
3289 2 3274 328b
1 328d 3 328e
3299 329d 1 3258
2 32b0 32b2 3
32ae 32af 32b4 2
32bd 32bf 2 32bc
32c1 2 32c8 32ca
2 32cc 32ce 3
32d3 32d4 32d5 2
32d0 32d7 2 32c7
32d9 2 32c3 32db
1 32dd 4 32a7
32de 32e7 32eb 1
32ef 1 32a2 2
32a0 32f3 44 4b
52 59 60 67
6e 75 7c 83
8a 8f 94 9b
a2 a9 b0 b7
be c4 ca d0
d6 dc e2 e8
ee f4 fa 100
106 10c 112 118
11e 124 12a 130
136 13c 142 148
14e 154 15a 160
166 16d 174 17a
181 187 18e 195
19c 1a2 1a8 1ae
1b5 1bc 1c2 1c8
1cf 1d5 1db 1e1
1e7 1ec 1f3 
1
4
0 
32fa
0
1
a0
77
55
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 1 36 1
38 1 3a 1 3c 1 3e 1
40 41 40 43 40 45 40 47
40 49 40 4b 40 4d 40 4f
40 51 40 53 40 55 40 57
40 59 40 5b 40 5d 40 5f
1 61 1 63 1 65 1 67
1 69 1 6b 1 6d 1 6f
1 71 1 73 1 75 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3b 1 0
13e 1 0
2b 1 0
183 1 0
1dd 1 0
162 1 0
2f 1 0
1c4 1 0
ab 1 0
1ca 1 0
fc 1 0
15c 1 0
d8 1 0
1d7 1 0
27 1 0
189 1 0
1f 1 0
1b 1 0
1e3 1 0
96 1 0
2725 40 61
c0 1 0
9d 1 0
11a 1 0
17c 1 0
12c 1 0
8c 1 0
1e9 1 0
1a4 1 0
13 1 0
f6 1 0
1b0 1 0
ea 1 0
7e 1 0
16f 1 0
168 1 0
a4 1 0
77 1 0
f 1 0
e4 1 0
70 1 0
5b 1 0
3 1 0
c6 1 0
150 1 0
14a 1 0
1b7 1 0
85 1 0
19e 1 0
138 1 0
2 0 1
114 1 0
108 1 0
23 1 0
144 1 0
54 1 0
1d1 1 0
156 1 0
7 1 0
176 1 0
f0 1 0
de 1 0
132 1 0
d2 1 0
197 1 0
1be 1 0
1aa 1 0
cc 1 0
69 1 0
46 1 0
10e 1 0
37 1 0
4d 1 0
b2 1 0
120 1 0
17 1 0
91 1 0
b9 1 0
126 1 0
62 1 0
33 1 0
102 1 0
b 1 0
1ee 1 0
190 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_1;
ALTER FUNCTION SP_SEARCH_1 COMPILE DEBUG;
/*######################################################################################*/
/*######################################################################################*/
/*
#Stored Procedure  :SP_SEARCH_3
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_SEARCH_3 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_3 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1e8
2 :e:
1FUNCTION:
1SP_SEARCH_3:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1TYPE001:
1AND_ROLES:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PROJECT_ID:
132:
1H_TASK_ID:
1H_REC_USER:
1H_RES_ID:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_REC_STATUS:
11:
1H_RES_TYPE:
1H_PA_TIMEPHASE:
1H_ASSIGN_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_AND_ROLES:
18000:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_SD:
1H_FD:
1H_FULL_NAME:
1255:
1H_COUNT:
10:
1H_BITFLAG:
1H_TYPE:
1H_UPDATE:
1H_WORK_TYPE:
1H_CRI:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_FROM_PRJ:
1H_DAYS:
1H_DURATION:
1H_NUMBER:
1H_TOTAL:
1H_TOTPR:
1H_PRIORITY:
1H_WEEK:
1H_RES_COST:
1NUMBER:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_AVAILABLE:
1H_ASSIGNED_WORK:
1H_REG_COST:
10.00:
1H_REG_SALE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1STMT:
17999:
1H_TABLE_TYPE:
1H_TEMP_VAR:
1I:
1II:
1I_PA_SCHED:
1I_RETURN:
1ISF:
1NUMITEMS:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_3(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1107:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_3(108) :: cplan.sql(4629) :: :
1GETTABLE:
1IS NULL:
18:
1143:
1      RETURN_INVALID:: SP_SEARCH_3(144) :: cplan.sql(4665) :: :
1 :
1STATE:: :
1PMO_CNST:
1ELEMENT_ID_REQUIRED:
1146:
1                EXIT:: SP_SEARCH_3(147) :: cplan.sql(4668) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1=:
15:
1153:
1      RETURN_INVALID:: SP_SEARCH_3(154) :: cplan.sql(4675) :: :
1INVALID_PARAMS:
1156:
1                EXIT:: SP_SEARCH_3(157) :: cplan.sql(4678) :: :
1!=:
1SC_SRCH_PARTICIPANT:
1IS NOT NULL:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1175:
1           EXCEPTION:: SP_SEARCH_3(176) :: cplan.sql(4697) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1<:
1182:
1      RETURN_INVALID:: SP_SEARCH_3(183) :: cplan.sql(4704) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1185:
1                EXIT:: SP_SEARCH_3(186) :: cplan.sql(4707) :: :
1ELSIF:
1SELECT SYSTIMESTAMP INTO h_start_date:n         FROM DUAL:
1203:
1           EXCEPTION:: SP_SEARCH_3(204) :: cplan.sql(4725) :: :
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1SC_SRCH_OVERALLOCATE:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n         INTO h_per_day, h_per_week, h_priority:n         FROM TMT_WBS WH+
1ERE ELEMENT_ID = h_project_id:
1233:
1           EXCEPTION:: SP_SEARCH_3(234) :: cplan.sql(4755) :: :
1SC_SQL_NO_DATA:
1TMT_POOLS:
1SELECT 480, 2400, 0 INTO h_per_day, h_per_week, h_priority FROM TMT_POOLS WHE+
1RE ELEMENT_ID = h_project_id:
1249:
1           EXCEPTION:: SP_SEARCH_3(250) :: cplan.sql(4771) :: :
1        RETURN_ERROR:: SP_SEARCH_3(256) :: cplan.sql(4777) :: :
1 ID:: :
1258:
1                EXIT:: SP_SEARCH_3(259) :: cplan.sql(4780) :: :
1PMO_RETURN_ERROR_SP:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1PROJECT_ID:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1277:
1           EXCEPTION:: SP_SEARCH_3(278) :: cplan.sql(4799) :: :
1>:
1REC_STATUS:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1295:
1           EXCEPTION:: SP_SEARCH_3(296) :: cplan.sql(4817) :: :
1STRCMP:
1L:
1302:
1        RETURN_ERROR:: SP_SEARCH_3(303) :: cplan.sql(4824) :: :
1LEV_LOCKED_BY_COPY:
1305:
1                EXIT:: SP_SEARCH_3(306) :: cplan.sql(4827) :: :
1313:
1      RETURN_INVALID:: SP_SEARCH_3(314) :: cplan.sql(4835) :: :
1316:
1                EXIT:: SP_SEARCH_3(317) :: cplan.sql(4838) :: :
1PMO_STPU:
1STRNPCPY:
133:
1ISPROJECTTYPE:
1TYPE_ID:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1SELECT PROJECT_ID, COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2+
1400), PRIORITY:n            INTO h_project_id, h_per_day, h_per_week, h_prior+
1ity:n            FROM TMT_WBS WHERE ELEMENT_ID = h_task_id AND TYPE_ID IN (pm+
1o_cnst.SC_PROJECT,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PRO+
1J_TYPE2,pmo_cnst.SC_PROJ_TYPE3):
1344:
1           EXCEPTION:: SP_SEARCH_3(345) :: cplan.sql(4866) :: :
1351:
1        RETURN_ERROR:: SP_SEARCH_3(352) :: cplan.sql(4873) :: :
1RECORD_NOT_FOUND:
1354:
1                EXIT:: SP_SEARCH_3(355) :: cplan.sql(4876) :: :
1360:
1        RETURN_ERROR:: SP_SEARCH_3(361) :: cplan.sql(4882) :: :
1363:
1                EXIT:: SP_SEARCH_3(364) :: cplan.sql(4885) :: :
1100:
1:
1FC_CALC_DURATION:
1386:
1      RETURN_INVALID:: SP_SEARCH_3(387) :: cplan.sql(4908) :: :
1389:
1                EXIT:: SP_SEARCH_3(390) :: cplan.sql(4911) :: :
1394:
1        RETURN_ERROR:: SP_SEARCH_3(395) :: cplan.sql(4916) :: :
1397:
1                EXIT:: SP_SEARCH_3(398) :: cplan.sql(4919) :: :
12000:
1404:
1        RETURN_ERROR:: SP_SEARCH_3(405) :: cplan.sql(4926) :: :
1CANNOT_SEARCH_ASSIGN:
1407:
1                EXIT:: SP_SEARCH_3(408) :: cplan.sql(4929) :: :
150:
1TRUNC:
1TO_NUMBER:
1*:
11.5:
12:
13:
14:
1FC_DECLARE_PMO_TMP_SEARCH:
1TSK_ASSIGNMENT_ID:
1TO_DATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n            REG+
1ULAR_COST, REGULAR_RATE:n            INTO h_prj_assignment_id, h_SD, h_FD, h_+
1billable, h_capital_expense,:n            h_reg_cost, h_reg_sale:n           +
1 FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project_id AND RESOURCE_I+
1D=h_res_id AND RESOURCE_TYPE='1' AND BIT_FLAG='0':
1464:
1           EXCEPTION:: SP_SEARCH_3(465) :: cplan.sql(4986) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME INTO h_full_name FROM PROFILES WHERE PROFILE_ID = h_res_i+
1d:
1479:
1           EXCEPTION:: SP_SEARCH_3(480) :: cplan.sql(5001) :: :
1486:
1        RETURN_ERROR:: SP_SEARCH_3(487) :: cplan.sql(5008) :: :
1489:
1                EXIT:: SP_SEARCH_3(490) :: cplan.sql(5011) :: :
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1RESOURCE_ASSIGNMENTS:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_assign_id, h_number:n           +
1 FROM RESOURCE_ASSIGNMENTS:n            WHERE ELEMENT_ID = h_task_id AND RESO+
1URCE_TYPE = '1' AND RESOURCE_ID = h_res_id:
1508:
1           EXCEPTION:: SP_SEARCH_3(509) :: cplan.sql(5030) :: :
1NICK_NAME:
1RESOURCES:
1SELECT NICK_NAME INTO h_full_name FROM RESOURCES WHERE RESOURCE_ID = h_res_id:
1523:
1           EXCEPTION:: SP_SEARCH_3(524) :: cplan.sql(5045) :: :
1530:
1        RETURN_ERROR:: SP_SEARCH_3(531) :: cplan.sql(5052) :: :
1533:
1                EXIT:: SP_SEARCH_3(534) :: cplan.sql(5055) :: :
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n            REG+
1ULAR_COST, REGULAR_RATE:n            INTO h_prj_assignment_id, h_SD, h_FD, h_+
1billable, h_capital_expense,:n            h_reg_cost, h_reg_sale:n           +
1 FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project_id AND RESOURCE_I+
1D=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='0':
1555:
1           EXCEPTION:: SP_SEARCH_3(556) :: cplan.sql(5077) :: :
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n               +
1REGULAR_COST, REGULAR_RATE :n               INTO h_prj_assignment_id, h_SD, h+
1_FD, h_billable, h_capital_expense,:n               h_reg_cost, h_reg_sale:n +
1              FROM TASK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_i+
1d AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
1578:
1           EXCEPTION:: SP_SEARCH_3(579) :: cplan.sql(5100) :: :
1-:
1COUNT:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (SELECT 'X' FROM TAS+
1K_ASSIGNMENTS  :n                     WHERE PROJECT_ID = h_project_id AND TAS+
1K_ID <> PROJECT_ID AND RESOURCE_ID = h_res_id):
1599:
1           EXCEPTION:: SP_SEARCH_3(600) :: cplan.sql(5121) :: :
1605:
1        RETURN_ERROR:: SP_SEARCH_3(606) :: cplan.sql(5127) :: :
1CHILD_TASK_ASSIGNMENT_ALREADY_:
1608:
1                EXIT:: SP_SEARCH_3(609) :: cplan.sql(5130) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_assign_id, h_number:n           +
1 FROM RESOURCE_ASSIGNMENTS:n            WHERE ELEMENT_ID = h_task_id AND RESO+
1URCE_TYPE = '0' AND RESOURCE_ID = h_res_id:
1629:
1           EXCEPTION:: SP_SEARCH_3(630) :: cplan.sql(5151) :: :
1635:
1      RETURN_INVALID:: SP_SEARCH_3(636) :: cplan.sql(5157) :: :
1638:
1                EXIT:: SP_SEARCH_3(639) :: cplan.sql(5160) :: :
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1SC_PARTICIPANT_GROUP:
1SECURITY_ID:
1ELEMENT_TYPE:
1SC_AFFECTED:
1SC_TEAMMEMBER:
1BIT_OR:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT =:n            CASE:n            +
1WHEN SECURITY_ID = h_temp2_security_id AND ELEMENT_TYPE IN (pmo_cnst.SC_PROJE+
1CT,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PROJ_TYPE2,pmo_cns+
1t.SC_PROJ_TYPE3) THEN pmo_cnst.SC_AFFECTED:n            WHEN SECURITY_ID = h_+
1temp2_security_id THEN pmo_cnst.SC_TEAMMEMBER:n            WHEN SECURITY_ID =+
1 h_temp_security_id THEN pmo_cnst.SC_AFFECTED:n            ELSE PMO_STPU.BIT_+
1OR( PARTICIPANT, pmo_cnst.SC_TEAMMEMBER):n            END, SECURITY_ID =:n   +
1         CASE:n            WHEN SECURITY_ID = h_temp2_security_id THEN  h_tem+
1p_security_id:n            ELSE SECURITY_ID:n            END:n            WHE+
1RE RES_ASSIGNMENT_ID = h_assign_id:
1FOUND:
1675:
1           EXCEPTION:: SP_SEARCH_3(676) :: cplan.sql(5197) :: :
1FC_AFTER_U_RES_ASSIGN:
1SYS_GUID:
1FC_BEFORE_I_RES_ASSIGN:
1TABLE_TYPE:
1REC_USER:
1REC_DATETIME:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE, TABLE_TYPE,:n            RESOURCE_TYPE, RESOURCE_ID, PARTICIPANT+
1, SECURITY_ID, REC_USER, REC_DATETIME):n            VALUES (h_assign_id, h_pr+
1oject_id, h_task_id, h_type, h_table_type,:n            h_res_type, h_res_id,+
1 pmo_cnst.SC_AFFECTED, h_temp_security_id, rec_user001, SYSTIMESTAMP):
1711:
1           EXCEPTION:: SP_SEARCH_3(712) :: cplan.sql(5233) :: :
1/:
110000.0:
10.5:
1MIN:
1TDY:
1DAY_YEAR:
1CALENDAR_DAY_OF_YEAR:
1CDY:
1TASK_DAY_OF_YEAR:
1ACTUAL_FLAG:
1AVAILABLE_MIN:
1SCHED_MIN:
1SELECT MIN(tdy.DAY_YEAR) INTO h_SD :n               FROM CALENDAR_DAY_OF_YEAR+
1 cdy, TASK_DAY_OF_YEAR tdy :n               WHERE tdy.PROJECT_ID = h_project_+
1id :n               AND tdy.TSK_ASSIGNMENT_ID = h_prj_assignment_id:n        +
1       AND tdy.DAY_YEAR >= TO_DATE(SubStr(h_start_DT, 1, 10)) :n             +
1  AND tdy.ACTUAL_FLAG = 0:n               AND cdy.ELEMENT_ID = h_res_id :n   +
1            AND cdy.DAY_YEAR = tdy.DAY_YEAR:n               AND (cdy.AVAILABL+
1E_MIN - tdy.SCHED_MIN) >= h_temp_var:
1745:
1           EXCEPTION:: SP_SEARCH_3(746) :: cplan.sql(5267) :: :
1DB2TIMESTAMP:
1TIME:
1SELECT  PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_FD, 1, 10)) + 1     , PMO_OR+
1ASTD.TIME('00::00'))  INTO  h_start_DT FROM DUAL:
1761:
1           EXCEPTION:: SP_SEARCH_3(762) :: cplan.sql(5283) :: :
1LAST_AVAIL_TIME:
1BIT_SCHED:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_STPU.LAST_AVAIL_TIME(BIT_SCHED))+
1 INTO h_start_DT:n                  FROM TASK_DAY_OF_YEAR :n                 +
1 WHERE PROJECT_ID = h_project_id :n                  AND TSK_ASSIGNMENT_ID = +
1h_prj_assignment_id :n                  AND DAY_YEAR = h_SD:
1780:
1           EXCEPTION:: SP_SEARCH_3(781) :: cplan.sql(5302) :: :
1STRNCMP:
110:
1788:
1        RETURN_ERROR:: SP_SEARCH_3(789) :: cplan.sql(5310) :: :
1TASK_ASSIGNMENT_ERROR:
1791:
1                EXIT:: SP_SEARCH_3(792) :: cplan.sql(5313) :: :
1SUM:
1SELECT SUM(SCHED_MIN) INTO h_assigned_work:n               FROM TASK_DAY_OF_Y+
1EAR:n               WHERE PROJECT_ID = h_project_id :n               AND TSK_+
1ASSIGNMENT_ID = h_prj_assignment_id :n               AND DAY_YEAR BETWEEN TO_+
1DATE(SubStr(h_start_DT, 1, 10)) AND TO_DATE(SubStr(h_finish_DT, 1, 10)):
1811:
1           EXCEPTION:: SP_SEARCH_3(812) :: cplan.sql(5333) :: :
1SELECT SUM(AVAILABLE_MIN) INTO h_available:n               FROM CALENDAR_DAY_+
1OF_YEAR:n               WHERE ELEMENT_ID = h_res_id AND DAY_YEAR BETWEEN TO_D+
1ATE(SubStr(h_start_DT, 1, 10)) AND TO_DATE(SubStr(h_finish_DT, 1, 10)):
1829:
1           EXCEPTION:: SP_SEARCH_3(830) :: cplan.sql(5351) :: :
1836:
1        RETURN_ERROR:: SP_SEARCH_3(837) :: cplan.sql(5358) :: :
1839:
1                EXIT:: SP_SEARCH_3(840) :: cplan.sql(5361) :: :
1TIMEPHASE_PROJECT_ASSIGNMENT:
1SELECT TIMEPHASE_PROJECT_ASSIGNMENT INTO h_pa_timephase FROM PROJECT_DETAILS +
1WHERE PROJECT_ID = h_project_id:
1855:
1           EXCEPTION:: SP_SEARCH_3(856) :: cplan.sql(5377) :: :
1Y:
1FC_TPHASE_SCHED_ASSIGN:
1SC_SRCH_PROFILE:
1FC_SEARCH_2:
1PMO_TMP_SEARCH:
1PLANNED_SCHED_FLAG:
1RES_ID:
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='0' WHERE RES_ID=h_res_id:
1902:
1           EXCEPTION:: SP_SEARCH_3(903) :: cplan.sql(5424) :: :
1LENGTH:
1WHILE:
1LOOP:
1',':
1START_DT:
1FINISH_DT:
1SELECT TSK_ASSIGNMENT_ID, START_DT, FINISH_DT :n               INTO h_prj_ass+
1ignment_id, h_start_DT, h_finish_DT :n               FROM TASK_ASSIGNMENTS :n+
1               WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND BIT_FL+
1AG='0':
1968:
1           EXCEPTION:: SP_SEARCH_3(969) :: cplan.sql(5490) :: :
1SELECT TSK_ASSIGNMENT_ID, START_DT, FINISH_DT :n                  INTO h_prj_+
1assignment_id, h_start_DT, h_finish_DT :n                  FROM TASK_ASSIGNME+
1NTS :n                  WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id A+
1ND BIT_FLAG='2':
1987:
1           EXCEPTION:: SP_SEARCH_3(988) :: cplan.sql(5509) :: :
1SELECT MIN(tdy.DAY_YEAR) INTO h_SD :n                     FROM CALENDAR_DAY_O+
1F_YEAR cdy, TASK_DAY_OF_YEAR tdy :n                     WHERE tdy.PROJECT_ID +
1= h_project_id :n                     AND tdy.TSK_ASSIGNMENT_ID = h_prj_assig+
1nment_id:n                     AND tdy.DAY_YEAR >= TO_DATE(SubStr(h_start_dat+
1e, 1, 10)) :n                     AND tdy.ACTUAL_FLAG = 0:n                  +
1   AND cdy.ELEMENT_ID = h_res_id :n                     AND cdy.DAY_YEAR = td+
1y.DAY_YEAR:n                     AND (cdy.AVAILABLE_MIN - tdy.SCHED_MIN) >= h+
1_temp_var:
11025:
1           EXCEPTION:: SP_SEARCH_3(1026) :: cplan.sql(5547) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_STPU.LAST_AVAIL_TIME(BIT_SCHED))+
1 INTO h_start_DT:n                        FROM TASK_DAY_OF_YEAR :n           +
1             WHERE PROJECT_ID = h_project_id :n                        AND TS+
1K_ASSIGNMENT_ID = h_prj_assignment_id :n                        AND DAY_YEAR +
1= h_SD:
11045:
1           EXCEPTION:: SP_SEARCH_3(1046) :: cplan.sql(5567) :: :
1<=:
1>=:
1SELECT  (PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_DT, 1, 10)) + 1     ,+
1 PMO_ORASTD.TIME('00::00'))) :n                      INTO  h_start_DT FROM DU+
1AL:
11063:
1           EXCEPTION:: SP_SEARCH_3(1064) :: cplan.sql(5585) :: :
11109:
1           EXCEPTION:: SP_SEARCH_3(1110) :: cplan.sql(5631) :: :
11123:
1        RETURN_ERROR:: SP_SEARCH_3(1124) :: cplan.sql(5645) :: :
1CANNOT_ASSIGN_FROM_PROJECT_AFF:
11126:
1                EXIT:: SP_SEARCH_3(1127) :: cplan.sql(5648) :: :
1SELECT t.RESOURCE_ID AS ELEMENT_ID, t.RES_ASSIGNMENT_ID, p.FULL_NAME AS ELEME+
1NT_NAME, 13 AS TYPE_ID, :
1p.E_MAIL_ADDRESS,b.PLANNED_START,b.PLANNED_FINISH,b.BEST AS PLANNED_EFFORT, :
1a.SCHED_START AS START_DATE, a.SCHED_FINISH AS FINISH_DATE, a.BEST AS WORK, a+
1.SCHED_WORK AS REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR,rs.PLANNED AS PLANNED_WORK,:
1rs.SCHED AS SCHED_WORK, :
1 AS WORK_EFFORT, :
1 AS UNIT_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILIT+
1Y,:
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, rs.PLANNED_SCHED_FLAG, '' AS+
1 OBJECTIVES,'' AS RANK, p.EXTERNAL_ID :
1FROM RESOURCE_ASSIGNMENTS t LEFT JOIN TASK_ASSIGNMENTS a ON a.RES_ASSIGNMENT_+
1ID=t.RES_ASSIGNMENT_ID AND a.BIT_FLAG='2' :
1LEFT JOIN TASK_ASSIGNMENTS b ON b.RES_ASSIGNMENT_ID=t.RES_ASSIGNMENT_ID AND b+
1.BIT_FLAG='0' :
1JOIN RESOURCES p ON t.RESOURCE_ID=p.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON t.RESOURCE_ID=rs.RES_ID :
1WHERE t.ELEMENT_ID=':
1' AND t.RESOURCE_TYPE='0' AND t.RESOURCE_ID IN (':
1') AND BITAND(t.PARTICIPANT, 4112) > 0 :
1UNION ALL :
1SELECT r.PROFILE_ID AS ELEMENT_ID, ta.RES_ASSIGNMENT_ID, r.PROFILE_NAME AS EL+
1EMENT_NAME, 41 AS TYPE_ID, :
1'' AS E_MAIL_ADDRESS,ta.PLANNED_START,ta.PLANNED_FINISH,ta.BEST AS PLANNED_EF+
1FORT,:
1STR_1899_12_31_00_00_00:
1 AS START_DATE, :
1 AS FINISH_DATE, 0 AS WORK, 0 AS REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR, :
1rs.PLANNED AS PLANNED_WORK,rs.SCHED AS SCHED_WORK, :
1 AS UNIT_EFFORT,:
1(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY , rs.CONTOUR AS ASSIGN_STRING, rs.PLANNED_SCHED_FLAG, '' A+
1S OBJECTIVES,'' AS RANK, '' AS EXTERNAL_ID :
1FROM TASK_ASSIGNMENTS ta JOIN PROFILES r ON ta.TASK_ID=':
1' AND ta.RESOURCE_TYPE='1' AND ta.RESOURCE_ID IN (':
1') AND r.PROFILE_ID=ta.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON ta.RESOURCE_ID=rs.RES_ID :
1ORDER BY TYPE_ID:
11212:
1                EXIT:: SP_SEARCH_3(1213) :: cplan.sql(5734) :: :
11215:
1                EXIT:: SP_SEARCH_3(1216) :: cplan.sql(5737) :: :
1PMO_SELECT_READ:
1RETURN_ERROR_EXCEPTION:
11223:
1           EXCEPTION:: SP_SEARCH_3(1224) :: cplan.sql(5745) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11235:
1           EXCEPTION:: SP_SEARCH_3(1236) :: cplan.sql(5757) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
20a9
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 :2 a0 6b 1c 81 b0 :2 a0
6b :2 a0 6b 6e a5 b a 10
:2 a0 6b 6e :2 a0 6b 6e a5 b
6e 7e a0 b4 2e 6e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :4 a0 51
a5 b a5 b d a0 51 d
a0 51 d a0 7e b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e a 10 :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a0 7e b4 2e :2 5a
a 10 a0 7e b4 2e :2 5a a
10 :8 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c a0 51 d a0 b7 a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
a 10 :3 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :3 a0
6b :3 a0 51 a5 b :2 a0 6b a5
b 5a 51 a5 b d :4 a0 51
a5 b :2 a0 6b a5 b 5a d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e a0 51 d b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:b a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :6 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 19 3c a0 51 d :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 6e a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c b7 19
3c b7 a0 7e b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :2 a0 d :4 a0 :2 51 a5 b :2 51
a5 b d :3 a0 6b :3 51 a0 a5
b d :3 a0 51 a5 b a5 b
7e 51 b4 2e :18 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 19 3c b7 :2 19 3c :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 a0 51 d b7 19
3c a0 7e 51 b4 2e :2 a0 d
a0 6e d :6 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :3 a0 a5 b d :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 51 a5 b :2 a0
a5 57 b7 :2 19 3c a0 b7 :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 :5 a0 51 a5
b a5 b 7e 51 b4 2e a5
b d b7 :2 19 3c b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a 52 10
a0 51 d a0 b7 :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 a0
51 d a0 b7 19 :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d a0 51 d b7 :2 19 3c b7
19 3c :2 a0 b4 2e d a0 6e
d a0 6e d a0 6e d a0
6e d :3 a0 :2 51 a5 b d :3 a0
:2 51 a5 b d :2 a0 51 a5 b
7e 51 b4 2e a0 4d d :2 a0
d :2 a0 :2 51 a5 b 7e 6e b4
2e :19 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:2 a0 d :a a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 b7 :2 a0 :2 51
a5 b 7e 6e b4 2e :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :2 a0 d :19 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 51 d :19 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a a0 7e
51 b4 2e d :3 a0 51 a5 b
a5 b 7e 51 b4 2e a0 51
d :a a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 19 3c
b7 19 3c b7 19 3c :a a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 :2 a0
51 a5 b :2 a0 6b a0 a5 b
d :2 a0 51 :2 a0 51 a5 b :2 a0
6b a0 a5 b d :25 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 a5 b
d b7 :2 a0 b4 2e d :2 a0 51
:2 a0 51 a5 b :2 a0 6b a0 a5
b d :3 a0 6b d a0 51 d
:9 a0 a5 b d :18 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
51 a5 b 7e 51 b4 2e 5a
a0 7e b4 2e 5a a 10 a0
7e 51 b4 2e 5a a 10 :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b d b7 :5 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
5a a5 b 7e 51 b4 2e 7e
51 b4 2e a5 b d b7 :2 19
3c a0 4d d :21 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 7e
b4 2e 5a :9 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :e a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c a0 7e 51 b4 2e
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e a 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c a0 b7
a0 7e 51 b4 2e a0 51 d
:f a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 51 d :d a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e :2 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e 5a
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 :2 19 3c :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 :2 51 a5 b 7e 6e b4
2e a0 7e 51 b4 2e d :2 a0
6b :b a0 a5 b d b7 19 3c
b7 19 3c :2 a0 :2 51 a5 b 7e
6e b4 2e :3 a0 6b d b7 :3 a0
51 a5 b d b7 :2 19 3c :1e a0
:5 51 a5 b d a0 7e 51 b4
2e :4 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 a0 6e d
a0 6e d :2 a0 d :3 a0 a5 b
51 a5 b 7e 51 b4 2e a0
51 d b7 :5 a0 a5 b 51 a5
b 7e 51 b4 2e 5a 7e 51
b4 2e a5 b d b7 :2 19 3c
a0 7e 51 b4 2e a0 51 d
:3 a0 51 a5 b a0 7e a0 b4
2e 82 :3 a0 6b :2 51 :2 a0 51 a5
b 7e 51 b4 2e 7e 51 b4
2e a0 a5 b d :3 a0 6b :2 51
:2 a0 51 a5 b 7e 51 b4 2e
7e 51 b4 2e 7e 51 b4 2e
a0 a5 b d :2 a0 :2 51 a5 b
7e 6e b4 2e :3 a0 6b d :3 a0
a5 b 51 a5 b 7e 51 b4
2e :2 a0 d b7 :3 a0 7e 6e b4
2e :2 51 a5 b d :3 a0 7e a0
b4 2e :2 51 a5 b d b7 :2 19
3c b7 :3 a0 51 a5 b d :3 a0
a5 b 51 a5 b 7e 51 b4
2e :2 a0 d b7 :3 a0 7e 6e b4
2e :2 51 a5 b d :3 a0 7e a0
b4 2e :2 51 a5 b d b7 :2 19
3c b7 :2 19 3c :2 a0 :2 51 a5 b
7e 6e b4 2e a0 51 d b7
19 3c a0 51 d a0 51 d
:c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :c a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a a0 51
d b7 :2 a0 d b7 :2 19 3c b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :3 a0 51 a5 b d b7
:5 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e 5a a5 b 7e 51
b4 2e 7e 51 b4 2e a5 b
d b7 :2 19 3c a0 4d d :21 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 7e b4 2e 5a :e a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c a0 b7 :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e a 10 :9 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 :2 a0
d :2 a0 d b7 :2 19 3c b7 :2 a0
d :2 a0 d b7 :2 19 3c :2 a0 51
a5 b 7e 51 b4 2e :2 a0 :2 51
a5 b 7e 6e b4 2e a0 51
d b7 19 3c a0 b7 :2 a0 :2 51
a5 b 7e 6e b4 2e :3 a0 6b
d b7 19 :3 a0 51 a5 b d
b7 :2 19 3c :1e a0 :5 51 a5 b d
a0 7e 51 b4 2e :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
:3 a0 51 a5 b 7e 51 b4 2e
d b7 a0 47 b7 19 3c b7
:2 19 3c a0 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d b7
19 3c :3 a0 a5 b 51 a5 b
7e 51 b4 2e 5a :3 a0 a5 b
51 a5 b 7e 51 b4 2e 5a
a 10 a0 6e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e :3 a0 51 a5 b a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 51 a5 b a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e d a0 b7 :3 a0
a5 b 51 a5 b 7e 51 b4
2e a0 6e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 51 a5 b a5 b b4
2e 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e d a0 b7 19 :3 a0 a5
b 51 a5 b 7e 51 b4 2e
a0 6e 7e 6e b4 2e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 51 a5 b a5 b b4
2e 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e d
b7 :2 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b a0 a5 b 65 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
20a9
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 16a 155
159 15c 15d 165 154 187 175 151
179 17a 182 174 1a4 192 171 196
197 19f 191 1c1 1af 18e 1b3 1b4
1bc 1ae 1de 1cc 1ab 1d0 1d1 1d9
1cb 1fb 1e9 1c8 1ed 1ee 1f6 1e8
218 206 1e5 20a 20b 213 205 234
223 227 22f 202 250 23b 23f 242
243 24b 222 26d 25b 21f 25f 260
268 25a 28a 278 257 27c 27d 285
277 2a7 295 274 299 29a 2a2 294
2c4 2b2 291 2b6 2b7 2bf 2b1 2e1
2cf 2ae 2d3 2d4 2dc 2ce 2fe 2ec
2cb 2f0 2f1 2f9 2eb 31b 309 2e8
30d 30e 316 308 337 326 32a 332
305 34f 33e 342 34a 325 36c 35a
322 35e 35f 367 359 388 377 37b
356 383 376 3a4 393 397 373 39f
392 3c0 3af 3b3 38f 3bb 3ae 3dc
3cb 3cf 3ab 3d7 3ca 3f8 3e7 3eb
3c7 3f3 3e6 414 403 407 3e3 40f
402 430 41f 423 3ff 42b 41e 44c
43b 43f 41b 447 43a 468 457 45b
437 463 456 484 473 477 453 47f
472 4a0 48f 493 46f 49b 48e 4bc
4ab 4af 48b 4b7 4aa 4d8 4c7 4cb
4a7 4d3 4c6 4f4 4e3 4e7 4c3 4ef
4e2 510 4ff 503 4df 50b 4fe 52c
51b 51f 4fb 527 51a 548 537 53b
517 543 536 564 553 557 533 55f
552 580 56f 573 54f 57b 56e 59c
58b 58f 56b 597 58a 5b8 5a7 5ab
587 5b3 5a6 5d4 5c3 5c7 5a3 5cf
5c2 5f0 5df 5e3 5bf 5eb 5de 60c
5fb 5ff 5db 607 5fa 628 617 61b
5f7 623 616 644 633 637 613 63f
632 660 64f 653 62f 65b 64e 67c
66b 66f 64b 677 66a 698 687 68b
667 693 686 6b4 6a3 6a7 683 6af
6a2 6d0 6bf 6c3 69f 6cb 6be 6ec
6db 6df 6bb 6e7 6da 708 6f7 6fb
6d7 703 6f6 725 713 6f3 717 718
720 712 742 730 70f 734 735 73d
72f 75e 74d 751 72c 759 74c 77a
769 76d 749 775 768 797 785 765
789 78a 792 784 7b3 7a2 7a6 781
7ae 7a1 7cf 7be 7c2 79e 7ca 7bd
7eb 7da 7de 7ba 7e6 7d9 807 7f6
7fa 7d6 802 7f5 823 812 816 7f2
81e 811 83f 82e 832 80e 83a 82d
85b 84a 84e 82a 856 849 877 866
86a 872 846 896 87e 882 886 889
891 865 89d 8a1 862 8a5 8a9 8ad
8b0 8b5 8b6 1 8b8 8bd 8c1 8c5
8c8 8cd 8d1 8d5 8d8 8dd 8de 8e0
8e5 8e8 8ec 8ed 8f2 8f7 8fa 8ff
900 905 908 90c 90d 912 915 91a
91b 920 923 928 929 92e 931 936
937 93c 93f 943 944 949 94c 951
952 957 95a 95f 960 965 968 96d
96e 973 976 97a 97b 980 983 988
989 98e 991 996 997 99c 99f 9a3
9a7 9ab 9ac 9ae 9b3 9b4 9b6 9b7
9bc 9bf 9c4 9c5 9ca 9cd 9d1 9d5
9d9 9da 9dc 9e1 9e2 9e4 9e5 9ea
9ed 9f2 9f3 9f8 9fb 9ff a03 a07
a08 a0a a0f a10 a12 a13 a18 a1b
a20 a21 a26 a29 a2d a31 a35 a36
a38 a3d a3e a40 a41 a46 a49 a4e
a4f a54 a57 a5b a5f a63 a64 a66
a6b a6c a6e a6f a74 a77 a7c a7d
a82 a85 a89 a8d a91 a92 a94 a99
a9a a9c a9d aa2 aa5 aaa aab ab0
ab3 ab7 abb abf ac0 ac2 ac7 ac8
aca acb ad0 ad3 ad8 ad9 ade ae1
ae5 ae9 aed aee af0 af5 af6 af8
af9 afe b01 b06 b07 b0c b0f b13
b17 b1b b1c b1e b23 b24 b26 b27
b2c b2f b34 b35 b3a b3d b41 b45
b49 b4a b4c b51 b52 b54 b55 b5a
b5d b62 b63 b68 b6b b70 b71 b76
b79 b7d b7e b83 b86 b8b b8c b91
b94 b99 b9a b9f ba2 ba7 ba8 bad
bb0 bb4 bb5 bba bbd bc2 bc3 bc8
bcb bd0 bd1 bd6 bd7 bdc bde be2
be5 be9 bed bf0 bf4 bf8 bfb bfe
c03 c06 c09 c0c c0d c12 c13 1
c15 c1a c1e c22 c25 c2a c2f c32
c36 c37 c3c c3d c42 c44 c48 c4b
c4f c53 c57 c5b c5f c63 c67 c6b
c6f c73 c77 c7b c7f c83 c87 c8b
c8f c93 c97 c9b c9f ca3 ca7 cab
caf cb3 cb7 cbb cbf cc3 cc7 ccb
ccf cd3 cd7 cdb cdf ce3 ce7 ceb
cef cf3 cf7 cfb cff d03 d07 d0b
d0f d12 d13 d15 d16 d18 d1c d20
d23 d27 d2b d2e d32 d36 d39 d3a
d3f d42 d46 d4a d4d d51 d55 d58
d5b d60 d63 d66 d69 d6a d6f d70
1 d72 d77 d7b d7f d82 d87 d8c
d8f d93 d94 d99 d9c da1 da2 da7
daa daf db0 db5 db8 dbc dc0 dc4
dc8 dcb dcc dce dd3 dd4 dd6 dd7
ddc ddd de2 de4 de8 deb def df3
df6 dfa dfe e01 e04 e09 e0c e0f
e12 e13 e18 e19 1 e1b e20 e24
e28 e2b e30 e35 e38 e3c e3d e42
e43 e48 e4a e4e e51 e55 e59 e5c
e60 e64 e67 e6b e6c e71 e73 e77
e7a e7e e82 e85 e86 e88 e8b e8e
e8f e94 e98 e9c e9f ea0 ea2 ea5
ea8 ea9 1 eae eb3 eb7 ebb ebe
ebf ec1 ec4 ec7 ec8 1 ecd ed2
ed6 eda edd ee1 ee5 ee8 eeb ef0
ef3 ef6 ef9 efa eff f00 1 f02
f07 f0b f0f f12 f17 f1c f1f f23
f24 f29 f2c f31 f32 f37 f3a f3f
f40 f45 f48 f4c f50 f54 f58 f5b
f5c f5e f63 f64 f66 f67 f6c f6d
f72 f74 f78 f7b f7f f83 f86 f8a
f8e f91 f94 f99 f9c f9f fa2 fa3
fa8 fa9 1 fab fb0 fb4 fb8 fbb
fc0 fc5 fc8 fcc fcd fd2 fd3 fd8
fda fde fe1 fe5 fe9 fec ff0 ff4
ff7 ffb ffc 1001 1003 1007 100a 100e
1012 1015 1016 1018 101c 101f 1023 1026
1027 102c 102f 1033 1036 1037 103c 103f
1 1042 1047 104b 104e 104f 1054 1057
1 105a 105f 1063 1067 106b 106f 1073
1077 107b 107f 108b 108f 1093 1096 109a
109e 10a0 10a4 10a8 10ac 10af 10b3 10b7
10b9 10ba 10bf 1 10c3 10c7 10cb 10ce
10d2 10d6 10da 10de 10e1 10e5 10e9 10ec
10ef 10f4 10f7 10fa 10fd 10fe 1103 1104
1 1106 110b 110f 1113 1116 111b 1120
1123 1127 1128 112d 1130 1135 1136 113b
113e 1143 1144 1149 114c 1150 1151 1156
1159 115e 115f 1164 1167 116b 116f 1172
1175 1176 1178 1179 117e 117f 1184 1186
118a 118d 118f 1193 1195 11a1 11a3 11a5
11a6 11ab 11af 11b1 11bd 11bf 11c3 11c7
11ca 11ce 11d1 11d5 11d8 11d9 11de 11e1
11e5 11e9 11ec 11ed 11ef 11f2 11f5 11f6
11fb 1 11fe 1203 1207 120b 120e 1212
1216 1219 121c 1221 1224 1227 122a 122b
1230 1231 1 1233 1238 123c 1240 1243
1248 124d 1250 1254 1255 125a 125d 1262
1263 1268 126b 1270 1271 1276 1279 127d
1281 1285 1289 128c 128d 128f 1294 1295
1297 1298 129d 129e 12a3 12a5 12a9 12ac
12b0 12b4 12b7 12bb 12bf 12c2 12c5 12ca
12cd 12d0 12d3 12d4 12d9 12da 1 12dc
12e1 12e5 12e9 12ec 12f1 12f6 12f9 12fd
12fe 1303 1304 1309 130b 130f 1312 1316
131a 131d 1321 1325 1328 132c 132d 1332
1334 1338 133b 133f 1342 1346 134a 134c
1350 1353 1354 1359 135c 135f 1363 1366
1367 136c 136f 1 1372 1377 137b 137f
1383 138f 1393 1397 139a 139e 13a2 13a4
13a8 13ac 13b0 13b3 13b7 13bb 13bd 13be
13c3 1 13c7 13cb 13cf 13d2 13d6 13da
13de 13e2 13e5 13e9 13ed 13f0 13f3 13f8
13fb 13fe 1401 1402 1407 1408 1 140a
140f 1413 1417 141a 141f 1424 1427 142b
142c 1431 1434 1439 143a 143f 1442 1447
1448 144d 1450 1454 1455 145a 145d 1462
1463 1468 146b 146f 1473 1476 1479 147a
147c 147d 1482 1483 1488 148a 148e 1491
1493 1497 1499 14a5 14a7 14a9 14aa 14af
14b3 14b5 14c1 14c3 14c5 14c9 14cd 14d0
14d4 14d8 14dc 14df 14e3 14e7 14eb 14ee
14ef 14f1 14f5 14f9 14fc 14fd 14ff 1502
1505 1506 1508 150c 1510 1514 1518 151c
151f 1520 1522 1526 152a 152d 152e 1530
1533 1537 153b 153f 1542 1543 1545 1549
154c 1550 1553 1554 1559 155d 1560 1564
1566 156a 156d 1571 1575 1578 1579 157b
157e 1581 1582 1587 158b 158f 1593 1597
159b 159f 15a3 15a7 15ab 15af 15b3 15bf
15c3 15c7 15ca 15ce 15d2 15d4 15d8 15dc
15e0 15e3 15e7 15eb 15ed 15ee 15f3 1
15f7 15fb 15ff 1602 1606 160a 160e 1612
1615 1619 161d 1620 1623 1628 162b 162e
1631 1632 1637 1638 1 163a 163f 1643
1647 164a 164f 1654 1657 165b 165c 1661
1664 1669 166a 166f 1672 1677 1678 167d
1680 1684 1685 168a 168d 1692 1693 1698
169b 169f 16a3 16a6 16a9 16aa 16ac 16ad
16b2 16b3 16b8 16ba 16be 16c1 16c3 16c7
16c9 16d5 16d7 16d9 16da 16df 16e3 16e5
16f1 16f3 16f7 16fb 16fe 1702 1705 1709
170c 170d 1712 1715 1719 171d 1721 1725
1729 172d 1739 173d 1741 1744 1748 174c
174e 1752 1756 175a 175d 1761 1765 1767
1768 176d 1 1771 1775 1779 177c 1780
1784 1788 178c 178f 1793 1797 179a 179d
17a2 17a5 17a8 17ab 17ac 17b1 17b2 1
17b4 17b9 17bd 17c1 17c4 17c9 17ce 17d1
17d5 17d6 17db 17de 17e3 17e4 17e9 17ec
17f1 17f2 17f7 17fa 17fe 17ff 1804 1807
180c 180d 1812 1815 1819 181d 1820 1823
1824 1826 1827 182c 182d 1832 1834 1838
183b 183d 1841 1843 184f 1851 1853 1854
1859 185d 185f 186b 186d 1871 1875 1878
187c 187f 1883 1886 1887 188c 188f 1893
1897 189a 189e 18a2 18a5 18a8 18ad 18b0
18b3 18b6 18b7 18bc 18bd 1 18bf 18c4
18c8 18cc 18cf 18d4 18d9 18dc 18e0 18e1
18e6 18e9 18ee 18ef 18f4 18f7 18fc 18fd
1902 1905 1909 190d 1911 1915 1918 1919
191b 1920 1921 1923 1924 1929 192c 1931
1932 1937 193a 193f 1940 1945 1948 194c
194d 1952 1955 195a 195b 1960 1961 1966
1968 196c 196f 1973 1977 197a 197e 1982
1985 1988 198d 1990 1993 1996 1997 199c
199d 1 199f 19a4 19a8 19ac 19af 19b4
19b9 19bc 19c0 19c1 19c6 19c7 19cc 19ce
19d2 19d5 19d9 19dd 19e0 19e4 19e8 19eb
19ef 19f3 19f4 19f9 19fb 19ff 1a02 1a04
1a08 1a0b 1a0f 1a12 1a16 1a1a 1a1e 1a22
1a26 1a2a 1a36 1a3a 1a3e 1a41 1a45 1a49
1a4b 1a4f 1a53 1a57 1a5a 1a5e 1a62 1a64
1a65 1a6a 1 1a6e 1a72 1a76 1a79 1a7d
1a81 1a85 1a89 1a8c 1a90 1a94 1a97 1a9a
1a9f 1aa2 1aa5 1aa8 1aa9 1aae 1aaf 1
1ab1 1ab6 1aba 1abe 1ac1 1ac6 1acb 1ace
1ad2 1ad3 1ad8 1adb 1ae0 1ae1 1ae6 1ae9
1aee 1aef 1af4 1af7 1afb 1afc 1b01 1b04
1b09 1b0a 1b0f 1b12 1b16 1b1a 1b1d 1b20
1b21 1b23 1b24 1b29 1b2a 1b2f 1b31 1b35
1b38 1b3a 1b3e 1b40 1b4c 1b4e 1b50 1b51
1b56 1b5a 1b5c 1b68 1b6a 1b6e 1b72 1b75
1b76 1b78 1b7b 1b7e 1b7f 1b84 1b88 1b8c
1b90 1b94 1b98 1ba4 1ba8 1bac 1baf 1bb3
1bb7 1bb9 1bbd 1bc1 1bc5 1bc8 1bcc 1bd0
1bd2 1bd3 1bd8 1 1bdc 1be0 1be4 1be7
1beb 1bef 1bf3 1bf7 1bfa 1bfe 1c02 1c05
1c08 1c0d 1c10 1c13 1c16 1c17 1c1c 1c1d
1 1c1f 1c24 1c28 1c2c 1c2f 1c34 1c39
1c3c 1c40 1c41 1c46 1c49 1c4e 1c4f 1c54
1c57 1c5c 1c5d 1c62 1c65 1c69 1c6a 1c6f
1c72 1c77 1c78 1c7d 1c80 1c84 1c88 1c8b
1c8e 1c8f 1c91 1c92 1c97 1c98 1c9d 1c9f
1ca3 1ca6 1ca8 1cac 1cae 1cba 1cbc 1cbe
1cbf 1cc4 1cc8 1cca 1cd6 1cd8 1cdc 1ce0
1ce3 1ce7 1cec 1ced 1cef 1cf2 1cf5 1cf6
1cfb 1cff 1d03 1d06 1d0a 1d0e 1d11 1d14
1d19 1d1c 1d1f 1d22 1d23 1d28 1d29 1
1d2b 1d30 1d34 1d38 1d3b 1d40 1d45 1d48
1d4c 1d4d 1d52 1d55 1d5a 1d5b 1d60 1d63
1d68 1d69 1d6e 1d71 1d75 1d79 1d7d 1d81
1d84 1d85 1d87 1d8c 1d8d 1d8f 1d90 1d95
1d98 1d9d 1d9e 1da3 1da6 1dab 1dac 1db1
1db4 1db8 1db9 1dbe 1dc1 1dc6 1dc7 1dcc
1dcd 1dd2 1dd4 1dd8 1ddb 1ddf 1de3 1de6
1dea 1dee 1df1 1df4 1df9 1dfc 1dff 1e02
1e03 1e08 1e09 1 1e0b 1e10 1e14 1e18
1e1b 1e20 1e25 1e28 1e2c 1e2d 1e32 1e33
1e38 1e3a 1e3e 1e41 1e45 1e49 1e4c 1e50
1e54 1e57 1e5b 1e5f 1e60 1e65 1e67 1e6b
1e6e 1e70 1e74 1e77 1e79 1e7d 1e80 1e81
1e86 1e89 1e8d 1e91 1e94 1e98 1e9c 1e9f
1ea2 1ea7 1eaa 1ead 1eb0 1eb1 1eb6 1eb7
1 1eb9 1ebe 1ec2 1ec6 1ec9 1ece 1ed3
1ed6 1eda 1edb 1ee0 1ee3 1ee8 1ee9 1eee
1ef1 1ef6 1ef7 1efc 1eff 1f03 1f07 1f0b
1f0f 1f12 1f13 1f15 1f1a 1f1b 1f1d 1f1e
1f23 1f24 1f29 1f2b 1f2f 1f32 1f36 1f3a
1f3d 1f41 1f45 1f48 1f4b 1f50 1f53 1f56
1f59 1f5a 1f5f 1f60 1 1f62 1f67 1f6b
1f6f 1f72 1f77 1f7c 1f7f 1f83 1f84 1f89
1f8a 1f8f 1f91 1f95 1f98 1f9c 1fa0 1fa3
1fa7 1fab 1fae 1fb2 1fb3 1fb8 1fba 1fbe
1fc1 1fc5 1fc9 1fcd 1fd1 1fd5 1fd9 1fdd
1fe0 1fe3 1fe4 1fe6 1fe9 1fec 1fed 1fef
1ff3 1ff7 1ffb 1fff 2002 2005 2008 200b
200f 2010 2012 2016 201a 201e 2022 2025
2026 2028 2029 202b 202e 2031 2032 2037
203b 203f 2043 2047 204b 204f 2053 2057
205b 205f 2063 2067 206b 206f 2073 2077
207b 207f 2083 2087 208b 208f 2093 2097
20a3 20a7 20ab 20ae 20b2 20b6 20b8 20bc
20c0 20c4 20c7 20cb 20cf 20d1 20d2 20d7
1 20db 20df 20e3 20e6 20ea 20ee 20f2
20f6 20f9 20fd 2101 2104 2107 210c 210f
2112 2115 2116 211b 211c 1 211e 2123
2127 212b 212e 2133 2138 213b 213f 2140
2145 2148 214d 214e 2153 2156 215b 215c
2161 2164 2168 2169 216e 2171 2176 2177
217c 217f 2183 2187 218a 218d 218e 2190
2191 2196 2197 219c 219e 21a2 21a5 21a7
21ab 21ad 21b9 21bb 21bd 21be 21c3 21c7
21c9 21d5 21d7 21db 21df 21e2 21e6 21e9
21ed 21f0 21f1 21f6 21f9 21fd 2201 2204
2208 220c 220f 2212 2217 221a 221d 2220
2221 2226 2227 1 2229 222e 2232 2236
2239 223e 2243 2246 224a 224b 2250 2253
2258 2259 225e 2261 2266 2267 226c 226f
2273 2277 227b 227f 2282 2283 2285 228a
228b 228d 228e 2293 2296 229b 229c 22a1
22a4 22a9 22aa 22af 22b2 22b6 22b7 22bc
22bf 22c4 22c5 22ca 22cb 22d0 22d2 22d6
22d9 22dd 22e1 22e4 22e8 22ec 22ef 22f2
22f7 22fa 22fd 2300 2301 2306 2307 1
2309 230e 2312 2316 2319 231e 2323 2326
232a 232b 2330 2331 2336 2338 233c 233f
2343 2347 234a 234e 2352 2355 2359 235d
235e 2363 2365 2369 236c 236e 2372 2376
2379 237d 2381 2384 2387 238c 238f 2392
2395 2396 239b 239c 1 239e 23a3 23a7
23ab 23ae 23b3 23b8 23bb 23bf 23c0 23c5
23c8 23cd 23ce 23d3 23d6 23db 23dc 23e1
23e4 23e8 23ec 23f0 23f4 23f7 23f8 23fa
23ff 2400 2402 2403 2408 240b 2410 2411
2416 2419 241e 241f 2424 2427 242b 242c
2431 2434 2439 243a 243f 2440 2445 2447
244b 244e 2452 2456 2459 245d 2461 2464
2467 246c 246f 2472 2475 2476 247b 247c
1 247e 2483 2487 248b 248e 2493 2498
249b 249f 24a0 24a5 24a6 24ab 24ad 24b1
24b4 24b8 24bc 24bf 24c3 24c7 24ca 24ce
24d2 24d3 24d8 24da 24de 24e2 24e5 24e7
24eb 24ef 24f2 24f6 24fa 24fd 24fe 2500
2503 2506 2507 250c 250f 2513 2517 251a
251b 251d 2520 2523 2524 2529 1 252c
2531 2535 2538 253c 253e 2542 2545 2549
254c 254f 2550 2555 2559 255d 2561 2565
256a 256e 2572 2576 257a 257e 2582 2586
2589 258a 258c 2590 2594 2597 2598 259a
259e 25a2 25a5 25a6 25a8 25ac 25b0 25b3
25b4 25b6 25ba 25be 25c1 25c2 25c4 25c8
25cc 25cf 25d0 25d2 25d6 25da 25dd 25de
25e0 25e4 25e8 25eb 25ec 25ee 25f2 25f6
25fa 25fb 25fd 2601 2605 2609 260c 260d
260f 2613 2616 261a 261d 261e 2623 2627
262b 262e 2632 2636 2639 263c 2641 2644
2647 264a 264b 2650 2651 1 2653 2658
265c 2660 2663 2668 266d 2670 2674 2675
267a 267d 2682 2683 2688 268b 2690 2691
2696 2699 269d 26a1 26a5 26a9 26ac 26ad
26af 26b4 26b5 26b7 26b8 26bd 26be 26c3
26c5 26c9 26cc 26d0 26d4 26d7 26db 26df
26e2 26e5 26ea 26ed 26f0 26f3 26f4 26f9
26fa 1 26fc 2701 2705 2709 270c 2711
2716 2719 271d 271e 2723 2724 2729 272b
272f 2732 2736 273a 273d 2741 2745 2748
274c 274d 2752 2756 2758 275c 2760 2763
2764 2766 2769 276c 276d 2772 2776 277a
277d 2781 2785 2788 278b 2790 2793 2796
2799 279a 279f 27a0 1 27a2 27a7 27ab
27af 27b2 27b7 27bc 27bf 27c3 27c4 27c9
27cc 27d1 27d2 27d7 27da 27df 27e0 27e5
27e8 27ec 27f0 27f4 27f5 27f7 27fc 27fd
27ff 2800 2805 2808 280d 280e 2813 2816
281b 281c 2821 2824 2828 2829 282e 2831
2836 2837 283c 283d 2842 2844 2848 284b
284f 2853 2856 285a 285e 2861 2864 2869
286c 286f 2872 2873 2878 2879 1 287b
2880 2884 2888 288b 2890 2895 2898 289c
289d 28a2 28a3 28a8 28aa 28ae 28b1 28b5
28b9 28bc 28c0 28c4 28c7 28c8 28ca 28ce
28d2 28d3 28d8 28da 28de 28e2 28e5 28e9
28eb 28ef 28f3 28f6 28f7 28f9 28fc 28ff
2900 2905 2909 290d 2910 2911 2913 2916
2919 291a 291f 2923 2927 292a 292e 2932
2935 2938 293d 2940 2943 2946 2947 294c
294d 1 294f 2954 2958 295c 295f 2964
2969 296c 2970 2971 2976 2979 297e 297f
2984 2987 298c 298d 2992 2995 2999 299d
29a1 29a5 29a8 29a9 29ab 29b0 29b1 29b3
29b4 29b9 29bc 29c1 29c2 29c7 29ca 29cf
29d0 29d5 29d8 29dc 29dd 29e2 29e5 29ea
29eb 29f0 29f1 29f6 29f8 29fc 29ff 2a03
2a07 2a0a 2a0e 2a12 2a15 2a18 2a1d 2a20
2a23 2a26 2a27 2a2c 2a2d 1 2a2f 2a34
2a38 2a3c 2a3f 2a44 2a49 2a4c 2a50 2a51
2a56 2a57 2a5c 2a5e 2a62 2a65 2a69 2a6d
2a70 2a74 2a78 2a7b 2a7f 2a83 2a84 2a89
2a8b 2a8f 2a92 2a96 2a9a 2a9d 2a9e 2aa0
2aa3 2aa6 2aa7 2aac 2ab0 2ab3 2ab7 2ab9
2abd 2ac1 2ac5 2ac9 2acd 2ad0 2ad1 2ad3
2ad4 2ad6 2ad9 2adc 2add 2ae2 2ae3 2ae5
2ae9 2aeb 2aef 2af3 2af6 2af8 2afc 2b00
2b03 2b07 2b0b 2b0e 2b0f 2b11 2b14 2b17
2b18 2b1d 2b20 2b24 2b28 2b2b 2b2c 2b2e
2b31 2b34 2b35 2b3a 1 2b3d 2b42 2b46
2b4a 2b4d 2b4e 2b50 2b53 2b56 2b57 2b5c
2b5f 2b63 2b67 2b6a 2b6b 2b6d 2b70 2b73
2b74 2b79 1 2b7c 2b81 2b85 2b88 2b8c
2b90 2b92 2b96 2b9a 2b9d 2b9e 2ba0 2ba3
2ba6 2ba7 2bac 2bb0 2bb3 2bb7 2bbb 2bbd
2bc1 2bc5 2bc9 2bcc 2bcd 2bcf 2bd2 2bd5
2bd6 2bdb 2bde 2be2 2be6 2be9 2bea 2bec
2bef 2bf2 2bf3 2bf8 1 2bfb 2c00 2c04
2c07 2c0b 2c0f 2c11 2c15 2c19 2c1d 2c20
2c21 2c23 2c26 2c29 2c2a 2c2f 2c33 2c37
2c3b 2c3e 2c3f 2c41 2c44 2c48 2c4c 2c4f
2c50 2c52 2c53 2c58 2c5c 2c60 2c63 2c67
2c69 2c6d 2c71 2c74 2c76 2c7a 2c7d 2c81
2c85 2c86 2c8b 2c8f 2c93 2c98 2c9c 2ca0
2ca5 2ca9 2cad 2cb2 2cb6 2cba 2cbf 2cc3
2cc7 2ccb 2ccf 2cd2 2cd5 2cd6 2cd8 2cdc
2ce0 2ce4 2ce8 2ceb 2cee 2cef 2cf1 2cf5
2cf9 2cfd 2d00 2d01 2d03 2d06 2d09 2d0a
2d0f 2d13 2d14 2d18 2d1c 2d20 2d24 2d28
2d2c 2d2f 2d32 2d33 2d35 2d38 2d3d 2d3e
2d43 2d47 2d4b 2d4f 2d53 2d57 2d5b 2d5f
2d63 2d67 2d6b 2d6f 2d73 2d77 2d7b 2d7f
2d83 2d87 2d8b 2d8f 2d93 2d97 2d9b 2d9f
2da3 2da7 2db3 2db7 2dbb 2dbe 2dc2 2dc6
2dc8 2dcc 2dd0 2dd4 2dd7 2ddb 2ddf 2de1
2de2 2de7 1 2deb 2def 2df3 2df6 2dfa
2dfe 2e02 2e06 2e09 2e0d 2e11 2e14 2e17
2e1c 2e1f 2e22 2e25 2e26 2e2b 2e2c 1
2e2e 2e33 2e37 2e3b 2e3e 2e43 2e48 2e4b
2e4f 2e50 2e55 2e58 2e5d 2e5e 2e63 2e66
2e6b 2e6c 2e71 2e74 2e78 2e79 2e7e 2e81
2e86 2e87 2e8c 2e8f 2e93 2e97 2e9a 2e9d
2e9e 2ea0 2ea1 2ea6 2ea7 2eac 2eae 2eb2
2eb5 2eb7 2ebb 2ebd 2ec9 2ecb 2ecd 2ece
2ed3 2ed7 2ed9 2ee5 2ee7 2eeb 2eef 2ef3
2ef7 2efb 2f07 2f0b 2f0f 2f12 2f16 2f1a
2f1c 2f20 2f24 2f28 2f2b 2f2f 2f33 2f35
2f36 2f3b 1 2f3f 2f43 2f47 2f4a 2f4e
2f52 2f56 2f5a 2f5d 2f61 2f65 2f68 2f6b
2f70 2f73 2f76 2f79 2f7a 2f7f 2f80 1
2f82 2f87 2f8b 2f8f 2f92 2f97 2f9c 2f9f
2fa3 2fa4 2fa9 2fac 2fb1 2fb2 2fb7 2fba
2fbf 2fc0 2fc5 2fc8 2fcc 2fcd 2fd2 2fd5
2fda 2fdb 2fe0 2fe3 2fe7 2feb 2fee 2ff1
2ff2 2ff4 2ff5 2ffa 2ffb 3000 3002 3006
3009 300b 300f 3011 301d 301f 3021 3022
3027 302b 302d 3039 303b 303f 3043 3046
304a 304d 3051 3054 3055 305a 305d 3061
3065 3068 306c 3070 3073 3076 307b 307e
3081 3084 3085 308a 308b 1 308d 3092
3096 309a 309d 30a2 30a7 30aa 30ae 30af
30b4 30b7 30bc 30bd 30c2 30c5 30ca 30cb
30d0 30d3 30d7 30db 30df 30e3 30e6 30e7
30e9 30ee 30ef 30f1 30f2 30f7 30fa 30ff
3100 3105 3108 310d 310e 3113 3116 311a
311b 3120 3123 3128 3129 312e 312f 3134
3136 313a 313d 3141 3145 3148 314c 3150
3153 3156 315b 315e 3161 3164 3165 316a
316b 1 316d 3172 3176 317a 317d 3182
3187 318a 318e 318f 3194 3195 319a 319c
31a0 31a3 31a7 31ab 31ae 31b2 31b6 31b9
31bd 31c1 31c2 31c7 31c9 31cd 31d0 31d4
31d8 31dc 31e0 31e4 31e8 31ec 31f0 31f4
31f8 31fc 3200 3204 3210 3214 3218 321b
321f 3223 3225 3229 322d 3231 3234 3238
323c 323e 323f 3244 1 3248 324c 3250
3253 3257 325b 325f 3263 3266 326a 326e
3271 3274 3279 327c 327f 3282 3283 3288
3289 1 328b 3290 3294 3298 329b 32a0
32a5 32a8 32ac 32ad 32b2 32b5 32ba 32bb
32c0 32c3 32c8 32c9 32ce 32d1 32d5 32d6
32db 32de 32e3 32e4 32e9 32ec 32f0 32f4
32f7 32fa 32fb 32fd 32fe 3303 3304 3309
330b 330f 3312 3314 3318 331a 3326 3328
332a 332b 3330 3334 3336 3342 3344 3348
334a 334e 3352 3355 3358 3359 335b 335e
3363 3364 3369 336d 3371 3375 3379 337d
3389 338d 3391 3394 3398 339c 339e 33a2
33a6 33aa 33ad 33b1 33b5 33b7 33b8 33bd
1 33c1 33c5 33c9 33cc 33d0 33d4 33d8
33dc 33df 33e3 33e7 33ea 33ed 33f2 33f5
33f8 33fb 33fc 3401 3402 1 3404 3409
340d 3411 3414 3419 341e 3421 3425 3426
342b 342e 3433 3434 3439 343c 3441 3442
3447 344a 344e 344f 3454 3457 345c 345d
3462 3465 3469 346d 3470 3473 3474 3476
3477 347c 347d 3482 3484 3488 348b 348d
3491 3493 349f 34a1 34a3 34a4 34a9 34ad
34af 34bb 34bd 34c1 34c5 34c8 34cc 34cf
34d3 34d6 34d7 34dc 34df 34e3 34e7 34ea
34ee 34f2 34f5 34f8 34fd 3500 3503 3506
3507 350c 350d 1 350f 3514 3518 351c
351f 3524 3529 352c 3530 3531 3536 3539
353e 353f 3544 3547 354c 354d 3552 3555
3559 355d 3561 3565 3568 3569 356b 3570
3571 3573 3574 3579 357c 3581 3582 3587
358a 358f 3590 3595 3598 359c 359d 35a2
35a5 35aa 35ab 35b0 35b1 35b6 35b8 35bc
35bf 35c3 35c7 35ca 35ce 35d2 35d5 35d8
35dd 35e0 35e3 35e6 35e7 35ec 35ed 1
35ef 35f4 35f8 35fc 35ff 3604 3609 360c
3610 3611 3616 3617 361c 361e 3622 3625
3629 362d 3630 3634 3638 363b 363f 3643
3644 3649 364b 364f 3652 3656 365a 365e
3662 3666 366a 366e 3672 3676 367a 367e
3682 3686 368a 368e 3692 3696 369a 369e
36a2 36a6 36aa 36ae 36b2 36b6 36ba 36be
36c2 36ce 36d2 36d6 36d9 36dd 36e1 36e3
36e7 36eb 36ef 36f2 36f6 36fa 36fc 36fd
3702 1 3706 370a 370e 3711 3715 3719
371d 3721 3724 3728 372c 372f 3732 3737
373a 373d 3740 3741 3746 3747 1 3749
374e 3752 3756 3759 375e 3763 3766 376a
376b 3770 3773 3778 3779 377e 3781 3786
3787 378c 378f 3793 3794 3799 379c 37a1
37a2 37a7 37aa 37ae 37b2 37b5 37b8 37b9
37bb 37bc 37c1 37c2 37c7 37c9 37cd 37d0
37d2 37d6 37d8 37e4 37e6 37e8 37e9 37ee
37f2 37f4 3800 3802 3806 380a 380d 3811
3814 3818 381b 381c 3821 3824 3828 382b
382f 3833 3837 383b 383f 3843 3847 384b
384f 3853 3857 385b 385f 3863 3867 386b
386f 3873 3877 387b 387f 3883 3887 388b
388f 3893 389f 38a3 38a7 38aa 38ae 38b2
38b4 38b8 38bc 38c0 38c3 38c7 38cb 38cd
38ce 38d3 1 38d7 38db 38df 38e2 38e6
38ea 38ee 38f2 38f5 38f9 38fd 3900 3903
3908 390b 390e 3911 3912 3917 3918 1
391a 391f 3923 3927 392a 392f 3934 3937
393b 393c 3941 3944 3949 394a 394f 3952
3957 3958 395d 3960 3964 3965 396a 396d
3972 3973 3978 397b 397f 3983 3986 3989
398a 398c 398d 3992 3993 3998 399a 399e
39a1 39a3 39a7 39a9 39b5 39b7 39b9 39ba
39bf 39c3 39c5 39d1 39d3 39d7 39db 39de
39e2 39e5 39e9 39ec 39ed 39f2 39f5 39f9
39fc 39ff 3a00 3a05 3a09 3a0d 3a11 3a15
3a18 3a19 3a1b 3a1c 3a1e 3a21 3a24 3a25
3a2a 3a2e 3a31 3a35 3a39 3a3d 3a41 3a45
3a49 3a4d 3a51 3a55 3a59 3a5d 3a69 3a6d
3a71 3a74 3a78 3a7c 3a7e 3a82 3a86 3a8a
3a8d 3a91 3a95 3a97 3a98 3a9d 1 3aa1
3aa5 3aa9 3aac 3ab0 3ab4 3ab8 3abc 3abf
3ac3 3ac7 3aca 3acd 3ad2 3ad5 3ad8 3adb
3adc 3ae1 3ae2 1 3ae4 3ae9 3aed 3af1
3af4 3af9 3afe 3b01 3b05 3b06 3b0b 3b0e
3b13 3b14 3b19 3b1c 3b21 3b22 3b27 3b2a
3b2e 3b2f 3b34 3b37 3b3c 3b3d 3b42 3b45
3b49 3b4d 3b50 3b53 3b54 3b56 3b57 3b5c
3b5d 3b62 3b64 3b68 3b6b 3b6d 3b71 3b73
3b7f 3b81 3b83 3b84 3b89 3b8d 3b8f 3b9b
3b9d 3ba1 3ba5 3ba8 3ba9 3bab 3bae 3bb1
3bb2 3bb7 3bbb 3bbf 3bc2 3bc6 3bca 3bcd
3bd0 3bd5 3bd8 3bdb 3bde 3bdf 3be4 3be5
1 3be7 3bec 3bf0 3bf4 3bf7 3bfc 3c01
3c04 3c08 3c09 3c0e 3c11 3c16 3c17 3c1c
3c1f 3c24 3c25 3c2a 3c2d 3c31 3c35 3c39
3c3d 3c40 3c41 3c43 3c48 3c49 3c4b 3c4c
3c51 3c54 3c59 3c5a 3c5f 3c62 3c67 3c68
3c6d 3c70 3c74 3c75 3c7a 3c7d 3c82 3c83
3c88 3c89 3c8e 3c90 3c94 3c97 3c9b 3c9f
3ca2 3ca6 3caa 3cad 3cb0 3cb5 3cb8 3cbb
3cbe 3cbf 3cc4 3cc5 1 3cc7 3ccc 3cd0
3cd4 3cd7 3cdc 3ce1 3ce4 3ce8 3ce9 3cee
3cef 3cf4 3cf6 3cfa 3cfd 3d01 3d05 3d08
3d0c 3d10 3d13 3d17 3d1b 3d1c 3d21 3d23
3d27 3d2a 3d2c 3d30 3d33 3d35 3d39 3d3c
3d3e 3d42 3d45 3d49 3d4d 3d51 3d55 3d59
3d5d 3d61 3d65 3d69 3d6d 3d79 3d7d 3d81
3d84 3d88 3d8c 3d8e 3d92 3d96 3d9a 3d9d
3da1 3da5 3da7 3da8 3dad 1 3db1 3db5
3db9 3dbc 3dc0 3dc4 3dc8 3dcc 3dcf 3dd3
3dd7 3dda 3ddd 3de2 3de5 3de8 3deb 3dec
3df1 3df2 1 3df4 3df9 3dfd 3e01 3e04
3e09 3e0e 3e11 3e15 3e16 3e1b 3e1e 3e23
3e24 3e29 3e2c 3e31 3e32 3e37 3e3a 3e3e
3e3f 3e44 3e47 3e4c 3e4d 3e52 3e55 3e59
3e5d 3e60 3e63 3e64 3e66 3e67 3e6c 3e6d
3e72 3e74 3e78 3e7b 3e7d 3e81 3e83 3e8f
3e91 3e93 3e94 3e99 3e9d 3e9f 3eab 3ead
3eaf 3eb3 3eb7 3ebb 3ebe 3ec2 3ec6 3ec9
3ecc 3ed1 3ed4 3ed7 3eda 3edb 3ee0 3ee1
1 3ee3 3ee8 3eec 3ef0 3ef3 3ef8 3efd
3f00 3f04 3f05 3f0a 3f0d 3f12 3f13 3f18
3f1b 3f20 3f21 3f26 3f29 3f2d 3f31 3f35
3f39 3f3c 3f3d 3f3f 3f44 3f45 3f47 3f48
3f4d 3f4e 3f53 3f55 3f59 3f5c 3f60 3f64
3f67 3f6b 3f6f 3f72 3f75 3f7a 3f7d 3f80
3f83 3f84 3f89 3f8a 1 3f8c 3f91 3f95
3f99 3f9c 3fa1 3fa6 3fa9 3fad 3fae 3fb3
3fb4 3fb9 3fbb 3fbf 3fc2 3fc6 3fca 3fcd
3fd1 3fd5 3fd8 3fdc 3fdd 3fe2 3fe4 3fe8
3fec 3fef 3ff3 3ff7 3ffa 3ffe 4001 4005
4008 4009 400e 4011 4015 4019 401c 4020
4024 4027 4028 402a 402e 4032 4035 4039
403a 403c 4040 4044 4048 404b 404f 4053
4056 4057 4059 405d 4061 4064 4068 4069
406b 406f 4073 4077 407b 407f 4083 4087
408b 408f 4093 4097 409b 409f 40a3 40a7
40ab 40af 40b3 40b7 40bb 40bf 40c3 40c7
40cb 40cf 40d3 40d7 40db 40df 40e3 40e7
40eb 40ef 40f3 40f7 40fb 40ff 4103 410f
4113 4118 411c 411f 4120 4125 4129 412d
4130 4133 4137 4139 413d 4141 4144 4147
414b 414d 4151 4155 4158 415a 415e 4162
4166 4169 416d 4171 4173 4174 4179 1
417d 4181 4185 4188 418c 4190 4194 4198
419b 419f 41a3 41a6 41a9 41ae 41b1 41b4
41b7 41b8 41bd 41be 1 41c0 41c5 41c9
41cd 41d0 41d5 41da 41dd 41e1 41e2 41e7
41ea 41ef 41f0 41f5 41f8 41fd 41fe 4203
4206 420a 420b 4210 4213 4218 4219 421e
4221 4225 4229 422c 422f 4230 4232 4233
4238 4239 423e 4240 4244 4247 4249 424d
424f 425b 425d 425f 4260 4265 4269 426b
4277 4279 427d 4281 4285 4286 4288 428c
428e 4292 4296 4297 429c 42a0 42a4 42a8
42ab 42af 42b3 42b6 42b7 42b9 42bd 42c1
42c4 42c8 42c9 42cb 42cf 42d3 42d7 42db
42de 42e2 42e6 42e9 42ed 42f1 42f5 42f9
42fd 4301 4305 4309 430d 4311 4312 4314
4318 431c 4320 4324 4328 432c 4330 4334
4338 433c 4340 4344 4348 434c 4350 4354
4358 435c 4360 4364 4368 436c 4370 4374
4378 4384 4388 438d 4391 4394 4395 439a
439e 43a2 43a5 43a8 43ac 43ae 43b2 43b6
43b9 43bc 43c0 43c2 43c6 43ca 43cd 43cf
43d3 43d7 43db 43de 43e2 43e6 43e8 43e9
43ee 1 43f2 43f6 43fa 43fd 4401 4405
4409 440d 4410 4414 4418 441b 441e 4423
4426 4429 442c 442d 4432 4433 1 4435
443a 443e 4442 4445 444a 444f 4452 4456
4457 445c 445f 4464 4465 446a 446d 4472
4473 4478 447b 447f 4480 4485 4488 448d
448e 4493 4496 449a 449e 44a1 44a4 44a5
44a7 44a8 44ad 44ae 44b3 44b5 44b9 44bc
44be 44c2 44c4 44d0 44d2 44d4 44d5 44da
44de 44e0 44ec 44ee 44f0 44f4 44f8 44fb
44ff 4503 4506 4507 4509 450c 450f 4510
4515 4518 451c 451f 4520 4525 1 4528
452d 4531 4534 4537 4538 453d 1 4540
4545 4549 454d 4550 4551 4553 4556 4559
455a 455f 4563 4567 456a 456b 456d 4570
4573 4574 4579 457d 4581 4585 4588 4589
458b 458f 4591 4595 4599 459d 45a1 45a5
45a8 45a9 45ab 45ae 45b2 45b6 45b9 45ba
45bc 45bd 45c2 45c5 45c6 45c8 45cb 45ce
45cf 45d4 45d7 45da 45db 45e0 45e1 45e3
45e7 45e9 45ed 45f1 45f4 45f8 45f9 45fd
4601 4605 4609 460d 4611 4615 4619 461d
4621 4625 4629 462d 4631 4635 4639 463d
4641 4645 4649 464d 4651 4655 4659 465d
4661 4665 4669 466d 4671 4675 4679 467d
4681 468d 4691 4695 4698 469c 46a0 46a2
46a6 46aa 46ae 46b1 46b5 46b9 46bb 46bc
46c1 1 46c5 46c9 46cd 46d0 46d4 46d8
46dc 46e0 46e3 46e7 46eb 46ee 46f1 46f6
46f9 46fc 46ff 4700 4705 4706 1 4708
470d 4711 4715 4718 471d 4722 4725 4729
472a 472f 4732 4737 4738 473d 4740 4745
4746 474b 474e 4752 4753 4758 475b 4760
4761 4766 4769 476d 4771 4774 4777 4778
477a 477b 4780 4781 4786 4788 478c 478f
4791 4795 4797 47a3 47a5 47a7 47a8 47ad
47b1 47b3 47bf 47c1 47c5 47c8 47c9 47ce
47d1 47d5 47d9 47dd 47e1 47e5 47e9 47ed
47f1 47f5 4801 4805 4809 480c 4810 4814
4816 481a 481e 4822 4825 4829 482d 482f
4830 4835 1 4839 483d 4841 4844 4848
484c 4850 4854 4857 485b 485f 4862 4865
486a 486d 4870 4873 4874 4879 487a 1
487c 4881 4885 4889 488c 4891 4896 4899
489d 489e 48a3 48a6 48ab 48ac 48b1 48b4
48b9 48ba 48bf 48c2 48c6 48c7 48cc 48cf
48d4 48d5 48da 48dd 48e1 48e5 48e8 48eb
48ec 48ee 48ef 48f4 48f5 48fa 48fc 4900
4903 4905 4909 490b 4917 4919 491b 491c
4921 4925 4927 4933 4935 4937 493b 493f
4943 4947 494b 494f 4953 4957 495b 495f
4963 4967 496b 496f 497b 497f 4983 4986
498a 498e 4990 4994 4998 499c 499f 49a3
49a7 49a9 49aa 49af 1 49b3 49b7 49bb
49be 49c2 49c6 49ca 49ce 49d1 49d5 49d9
49dc 49df 49e4 49e7 49ea 49ed 49ee 49f3
49f4 1 49f6 49fb 49ff 4a03 4a06 4a0b
4a10 4a13 4a17 4a18 4a1d 4a20 4a25 4a26
4a2b 4a2e 4a33 4a34 4a39 4a3c 4a40 4a41
4a46 4a49 4a4e 4a4f 4a54 4a57 4a5b 4a5f
4a62 4a65 4a66 4a68 4a69 4a6e 4a6f 4a74
4a76 4a7a 4a7d 4a7f 4a83 4a85 4a91 4a93
4a95 4a96 4a9b 4a9f 4aa1 4aad 4aaf 4ab1
4ab5 4ab9 4abc 4ac0 4ac3 4ac6 4ac7 4acc
4ad0 4ad4 4ad7 4adb 4adf 4ae2 4ae3 4ae5
4ae8 4aeb 4aec 1 4af1 4af6 4afa 4afe
4b01 4b05 4b09 4b0c 4b0f 4b14 4b17 4b1a
4b1d 4b1e 4b23 4b24 1 4b26 4b2b 4b2f
4b33 4b36 4b3b 4b40 4b43 4b47 4b48 4b4d
4b50 4b55 4b56 4b5b 4b5e 4b63 4b64 4b69
4b6c 4b70 4b74 4b78 4b7c 4b7f 4b80 4b82
4b87 4b88 4b8a 4b8b 4b90 4b93 4b98 4b99
4b9e 4ba1 4ba6 4ba7 4bac 4baf 4bb3 4bb4
4bb9 4bbc 4bc1 4bc2 4bc7 4bc8 4bcd 4bcf
4bd3 4bd6 4bda 4bde 4be1 4be5 4be9 4bec
4bef 4bf4 4bf7 4bfa 4bfd 4bfe 4c03 4c04
1 4c06 4c0b 4c0f 4c13 4c16 4c1b 4c20
4c23 4c27 4c28 4c2d 4c2e 4c33 4c35 4c39
4c3c 4c40 4c44 4c47 4c4b 4c4f 4c52 4c56
4c5a 4c5b 4c60 4c62 4c66 4c69 4c6d 4c6f
4c73 4c76 4c79 4c7a 4c7f 4c83 4c86 4c8a
4c8e 4c92 4c96 4c9a 4c9e 4ca2 4ca6 4caa
4cae 4cb2 4cb6 4cba 4cbe 4cc2 4cc6 4cd2
4cd6 4cda 4cdd 4ce1 4ce5 4ce7 4ceb 4cef
4cf3 4cf6 4cfa 4cfe 4d00 4d01 4d06 1
4d0a 4d0e 4d12 4d15 4d19 4d1d 4d21 4d25
4d28 4d2c 4d30 4d33 4d36 4d3b 4d3e 4d41
4d44 4d45 4d4a 4d4b 1 4d4d 4d52 4d56
4d5a 4d5d 4d62 4d67 4d6a 4d6e 4d6f 4d74
4d77 4d7c 4d7d 4d82 4d85 4d8a 4d8b 4d90
4d93 4d97 4d98 4d9d 4da0 4da5 4da6 4dab
4dae 4db2 4db6 4db9 4dbc 4dbd 4dbf 4dc0
4dc5 4dc6 4dcb 4dcd 4dd1 4dd4 4dd6 4dda
4ddc 4de8 4dea 4dec 4ded 4df2 4df6 4df8
4e04 4e06 4e0a 4e0d 4e11 4e15 4e19 4e1d
4e21 4e25 4e29 4e2d 4e31 4e35 4e39 4e3d
4e41 4e45 4e51 4e55 4e59 4e5c 4e60 4e64
4e66 4e6a 4e6e 4e72 4e75 4e79 4e7d 4e7f
4e80 4e85 1 4e89 4e8d 4e91 4e94 4e98
4e9c 4ea0 4ea4 4ea7 4eab 4eaf 4eb2 4eb5
4eba 4ebd 4ec0 4ec3 4ec4 4ec9 4eca 1
4ecc 4ed1 4ed5 4ed9 4edc 4ee1 4ee6 4ee9
4eed 4eee 4ef3 4ef6 4efb 4efc 4f01 4f04
4f09 4f0a 4f0f 4f12 4f16 4f17 4f1c 4f1f
4f24 4f25 4f2a 4f2d 4f31 4f35 4f38 4f3b
4f3c 4f3e 4f3f 4f44 4f45 4f4a 4f4c 4f50
4f53 4f55 4f59 4f5b 4f67 4f69 4f6b 4f6c
4f71 4f75 4f77 4f83 4f85 4f89 4f8d 4f90
4f91 4f93 4f96 4f9a 4f9e 4fa1 4fa2 4fa4
4fa7 4fab 4faf 4fb2 4fb3 4fb5 4fb6 4fbb
4fbe 4fbf 4fc4 4fc8 4fcc 4fcf 4fd3 4fd7
4fda 4fdd 4fe2 4fe5 4fe8 4feb 4fec 4ff1
4ff2 1 4ff4 4ff9 4ffd 5001 5004 5009
500e 5011 5015 5016 501b 501e 5023 5024
5029 502c 5031 5032 5037 503a 503e 5042
5046 504a 504d 504e 5050 5055 5056 5058
5059 505e 5061 5066 5067 506c 506f 5074
5075 507a 507d 5081 5082 5087 508a 508f
5090 5095 5096 509b 509d 50a1 50a4 50a8
50ac 50af 50b3 50b7 50ba 50bd 50c2 50c5
50c8 50cb 50cc 50d1 50d2 1 50d4 50d9
50dd 50e1 50e4 50e9 50ee 50f1 50f5 50f6
50fb 50fc 5101 5103 5107 510a 510e 5112
5115 5119 511d 5120 5124 5128 5129 512e
5130 5134 5137 5139 513d 5141 5144 5148
514c 5150 5154 5158 5164 5168 516c 516f
5173 5177 5179 517d 5181 5185 5188 518c
5190 5192 5193 5198 1 519c 51a0 51a4
51a7 51ab 51af 51b3 51b7 51ba 51be 51c2
51c5 51c8 51cd 51d0 51d3 51d6 51d7 51dc
51dd 1 51df 51e4 51e8 51ec 51ef 51f4
51f9 51fc 5200 5201 5206 5209 520e 520f
5214 5217 521c 521d 5222 5225 5229 522a
522f 5232 5237 5238 523d 5240 5244 5248
524b 524e 524f 5251 5252 5257 5258 525d
525f 5263 5266 5268 526c 526e 527a 527c
527e 527f 5284 5288 528a 5296 5298 529c
52a0 52a3 52a6 52a7 52a9 52ac 52b1 52b2
52b7 52bb 52be 52c1 52c2 52c7 52cb 52cf
52d3 52d6 52da 52de 52e2 52e6 52ea 52ee
52f2 52f6 52fa 52fe 5302 5303 5305 5309
530b 530f 5312 5314 5318 531b 531f 5323
5326 5329 532a 532c 532f 5334 5335 533a
533e 5342 5346 5349 534d 534f 5353 5357
535b 535e 535f 5361 5365 5367 536b 536f
5372 5376 537a 537e 5382 5386 538a 538e
5392 5396 539a 539e 53a2 53a6 53aa 53ae
53b2 53b6 53ba 53be 53c2 53c6 53ca 53ce
53d2 53d6 53da 53de 53e2 53e6 53ea 53ed
53f0 53f3 53f6 53f9 53fa 53fc 5400 5404
5407 540a 540b 5410 5414 5418 541c 5420
542c 5430 5435 5439 543c 543d 5442 5446
544a 544d 5450 5454 5456 545a 545e 5461
5464 5468 546a 546e 5472 5475 5477 547b
547f 5483 5486 548a 548e 5490 5491 5496
1 549a 549e 54a2 54a5 54a9 54ad 54b1
54b5 54b8 54bc 54c0 54c3 54c6 54cb 54ce
54d1 54d4 54d5 54da 54db 1 54dd 54e2
54e6 54ea 54ed 54f2 54f7 54fa 54fe 54ff
5504 5507 550c 550d 5512 5515 551a 551b
5520 5523 5527 5528 552d 5530 5535 5536
553b 553e 5542 5546 5549 554c 554d 554f
5550 5555 5556 555b 555d 5561 5564 5566
556a 556c 5578 557a 557c 557d 5582 5586
5588 5594 5596 5598 559c 559f 55a1 55a5
55aa 55ae 55b2 55b7 55bb 55bf 55c3 55c7
55cb 55cf 55d3 55d4 55d6 55d9 55da 55dc
55df 55e2 55e3 55e8 55ec 55ef 55f3 55f5
55f9 55fd 5601 5605 5609 560a 560c 560f
5610 5612 5615 5618 5619 561e 5621 5624
5627 5628 562d 562e 5630 5634 5636 563a
563e 5641 5645 5648 564b 564c 5651 5655
5658 565c 5660 5664 5668 566b 566c 566e
5672 5675 5679 567a 567f 5681 5685 5689
568d 5690 5693 5696 569a 569e 56a1 56a2
56a4 56a7 56aa 56ab 56b0 56b3 56b6 56b7
56bc 56c0 56c1 56c3 56c7 56cb 56cf 56d3
56d6 56d9 56dc 56e0 56e4 56e7 56e8 56ea
56ed 56f0 56f1 56f6 56f9 56fc 56fd 5702
5705 5708 5709 570e 5712 5713 5715 5719
571d 5721 5724 5727 5728 572a 572d 5732
5733 5738 573c 5740 5744 5747 574b 574f
5753 5757 5758 575a 575d 575e 5760 5763
5766 5767 576c 5770 5774 5778 577a 577e
5782 5786 5789 578e 578f 5794 5797 579a
579b 579d 57a1 57a5 57a9 57ad 57b0 57b4
57b5 57ba 57bd 57c0 57c1 57c3 57c7 57c9
57cd 57d1 57d4 57d6 57da 57de 57e2 57e5
57e6 57e8 57ec 57f0 57f4 57f8 57f9 57fb
57fe 57ff 5801 5804 5807 5808 580d 5811
5815 5819 581b 581f 5823 5827 582a 582f
5830 5835 5838 583b 583c 583e 5842 5846
584a 584e 5851 5855 5856 585b 585e 5861
5862 5864 5868 586a 586e 5872 5875 5877
587b 587f 5882 5886 588a 588d 5890 5891
5893 5896 589b 589c 58a1 58a5 58a8 58ac
58ae 58b2 58b5 58b9 58bc 58c0 58c4 58c7
58cb 58cf 58d3 58d7 58db 58df 58e3 58e7
58eb 58ef 58f3 58f7 58fb 5907 590b 590f
5912 5916 591a 591c 5920 5924 5928 592b
592f 5933 5935 5936 593b 1 593f 5943
5947 594a 594e 5952 5956 595a 595d 5961
5965 5968 596b 5970 5973 5976 5979 597a
597f 5980 1 5982 5987 598b 598f 5992
5997 599c 599f 59a3 59a4 59a9 59ac 59b1
59b2 59b7 59ba 59bf 59c0 59c5 59c8 59cc
59cd 59d2 59d5 59da 59db 59e0 59e3 59e7
59eb 59ee 59f1 59f2 59f4 59f5 59fa 59fb
5a00 5a02 5a06 5a09 5a0b 5a0f 5a11 5a1d
5a1f 5a21 5a22 5a27 5a2b 5a2d 5a39 5a3b
5a3f 5a43 5a46 5a4a 5a4d 5a51 5a54 5a55
5a5a 5a5d 5a61 5a65 5a69 5a6d 5a71 5a75
5a79 5a7d 5a81 5a85 5a89 5a8d 5a99 5a9d
5aa1 5aa4 5aa8 5aac 5aae 5ab2 5ab6 5aba
5abd 5ac1 5ac5 5ac7 5ac8 5acd 1 5ad1
5ad5 5ad9 5adc 5ae0 5ae4 5ae8 5aec 5aef
5af3 5af7 5afa 5afd 5b02 5b05 5b08 5b0b
5b0c 5b11 5b12 1 5b14 5b19 5b1d 5b21
5b24 5b29 5b2e 5b31 5b35 5b36 5b3b 5b3e
5b43 5b44 5b49 5b4c 5b51 5b52 5b57 5b5a
5b5e 5b5f 5b64 5b67 5b6c 5b6d 5b72 5b75
5b79 5b7d 5b80 5b83 5b84 5b86 5b87 5b8c
5b8d 5b92 5b94 5b98 5b9b 5b9d 5ba1 5ba3
5baf 5bb1 5bb3 5bb4 5bb9 5bbd 5bbf 5bcb
5bcd 5bd1 5bd5 5bd8 5bdc 5bdf 5be3 5be6
5be7 5bec 5bef 5bf3 5bf6 5bfa 5bfc 5c00
5c04 5c08 5c0a 5c0e 5c12 5c15 5c17 5c1b
5c1e 5c22 5c26 5c29 5c2a 5c2c 5c2f 5c32
5c33 5c38 5c3c 5c40 5c43 5c44 5c46 5c49
5c4c 5c4d 5c52 5c56 5c5a 5c5d 5c5e 5c60
5c63 5c66 5c67 5c6c 5c70 5c74 5c78 5c7b
5c7c 5c7e 5c82 5c84 5c88 5c8c 5c90 5c94
5c98 5c9b 5c9c 5c9e 5ca1 5ca5 5ca9 5cac
5cad 5caf 5cb0 5cb5 5cb8 5cb9 5cbb 5cbe
5cc1 5cc2 5cc7 5cca 5ccd 5cce 5cd3 5cd4
5cd6 5cda 5cdc 5ce0 5ce4 5ce7 5ceb 5cec
5cf0 5cf4 5cf8 5cfc 5d00 5d04 5d08 5d0c
5d10 5d14 5d18 5d1c 5d20 5d24 5d28 5d2c
5d30 5d34 5d38 5d3c 5d40 5d44 5d48 5d4c
5d50 5d54 5d58 5d5c 5d60 5d64 5d68 5d6c
5d70 5d74 5d80 5d84 5d88 5d8b 5d8f 5d93
5d95 5d99 5d9d 5da1 5da4 5da8 5dac 5dae
5daf 5db4 1 5db8 5dbc 5dc0 5dc3 5dc7
5dcb 5dcf 5dd3 5dd6 5dda 5dde 5de1 5de4
5de9 5dec 5def 5df2 5df3 5df8 5df9 1
5dfb 5e00 5e04 5e08 5e0b 5e10 5e15 5e18
5e1c 5e1d 5e22 5e25 5e2a 5e2b 5e30 5e33
5e38 5e39 5e3e 5e41 5e45 5e46 5e4b 5e4e
5e53 5e54 5e59 5e5c 5e60 5e64 5e67 5e6a
5e6b 5e6d 5e6e 5e73 5e74 5e79 5e7b 5e7f
5e82 5e84 5e88 5e8a 5e96 5e98 5e9a 5e9b
5ea0 5ea4 5ea6 5eb2 5eb4 5eb8 5ebb 5ebc
5ec1 5ec4 5ec8 5ecc 5ed0 5ed4 5ed8 5edc
5ee0 5ee4 5ee8 5eec 5ef0 5ef4 5ef8 5efc
5f08 5f0c 5f10 5f13 5f17 5f1b 5f1d 5f21
5f25 5f29 5f2c 5f30 5f34 5f36 5f37 5f3c
1 5f40 5f44 5f48 5f4b 5f4f 5f53 5f57
5f5b 5f5e 5f62 5f66 5f69 5f6c 5f71 5f74
5f77 5f7a 5f7b 5f80 5f81 1 5f83 5f88
5f8c 5f90 5f93 5f98 5f9d 5fa0 5fa4 5fa5
5faa 5fad 5fb2 5fb3 5fb8 5fbb 5fc0 5fc1
5fc6 5fc9 5fcd 5fce 5fd3 5fd6 5fdb 5fdc
5fe1 5fe4 5fe8 5fec 5fef 5ff2 5ff3 5ff5
5ff6 5ffb 5ffc 6001 6003 6007 600a 600c
6010 6012 601e 6020 6022 6023 6028 602c
602e 603a 603c 603e 6042 6045 6049 604b
604f 6053 6056 605a 605e 6061 6062 6064
6067 606a 606b 6070 6074 6078 607b 607f
6083 6086 6087 6089 608c 608f 6090 1
6095 609a 609e 60a2 60a6 60aa 60ae 60b2
60b6 60ba 60be 60ca 60ce 60d2 60d5 60d9
60dd 60df 60e3 60e7 60eb 60ee 60f2 60f6
60f8 60f9 60fe 1 6102 6106 610a 610d
6111 6115 6119 611d 6120 6124 6128 612b
612e 6133 6136 6139 613c 613d 6142 6143
1 6145 614a 614e 6152 6155 615a 615f
6162 6166 6167 616c 616f 6174 6175 617a
617d 6182 6183 6188 618b 618f 6190 6195
6198 619d 619e 61a3 61a6 61aa 61ae 61b1
61b4 61b5 61b7 61b8 61bd 61be 61c3 61c5
61c9 61cc 61ce 61d2 61d4 61e0 61e2 61e4
61e5 61ea 61ee 61f0 61fc 61fe 6200 6204
6208 620c 6210 6214 6218 621c 621e 6222
6226 6229 622b 622f 6233 6237 623b 623f
6243 6245 6249 624d 6250 6254 6258 625b
625c 625e 6261 6264 6265 626a 626e 6272
6275 6278 6279 627b 627e 6283 6284 6289
628d 6290 6294 6296 629a 629d 62a1 62a3
62a7 62ab 62ae 62b1 62b2 62b4 62b7 62bc
62bd 62c2 62c6 62ca 62ce 62d1 62d5 62d7
62db 62df 62e3 62e7 62ea 62eb 62ed 62f1
62f3 62f7 62fb 62fe 6302 6306 630a 630e
6312 6316 631a 631e 6322 6326 632a 632e
6332 6336 633a 633e 6342 6346 634a 634e
6352 6356 635a 635e 6362 6366 636a 636e
6372 6376 6379 637c 637f 6382 6385 6386
6388 638c 6390 6393 6396 6397 639c 63a0
63a4 63a8 63ac 63b8 63bc 63c1 63c5 63c8
63c9 63ce 63d2 63d6 63d9 63dc 63e0 63e2
63e6 63ea 63ed 63f0 63f4 63f6 63fa 63fe
6401 6403 6407 640b 640f 6412 6416 641a
641c 641d 6422 1 6426 642a 642e 6431
6435 6439 643d 6441 6444 6448 644c 644f
6452 6457 645a 645d 6460 6461 6466 6467
1 6469 646e 6472 6476 6479 647e 6483
6486 648a 648b 6490 6493 6498 6499 649e
64a1 64a6 64a7 64ac 64af 64b3 64b4 64b9
64bc 64c1 64c2 64c7 64ca 64ce 64d2 64d5
64d8 64d9 64db 64dc 64e1 64e2 64e7 64e9
64ed 64f0 64f2 64f6 64f8 6504 6506 6508
6509 650e 6512 6514 6520 6522 6524 6528
652b 652f 6533 6537 653a 653b 653d 6540
6543 6544 6549 654d 654f 6553 655a 655c
6560 6563 6565 6569 656d 6570 6574 6577
657a 657b 6580 6583 6587 658b 658e 658f
6591 6594 6597 6598 659d 1 65a0 65a5
65a9 65ad 65b0 65b4 65b8 65bb 65be 65c3
65c6 65c9 65cc 65cd 65d2 65d3 1 65d5
65da 65de 65e2 65e5 65ea 65ef 65f2 65f6
65f7 65fc 65ff 6604 6605 660a 660d 6612
6613 6618 661b 661f 6623 6627 662b 662e
662f 6631 6636 6637 6639 663a 663f 6642
6647 6648 664d 6650 6655 6656 665b 665e
6662 6663 6668 666b 6670 6671 6676 6677
667c 667e 6682 6685 6689 668d 6690 6694
6698 669b 669e 66a3 66a6 66a9 66ac 66ad
66b2 66b3 1 66b5 66ba 66be 66c2 66c5
66ca 66cf 66d2 66d6 66d7 66dc 66dd 66e2
66e4 66e8 66eb 66ef 66f3 66f6 66fa 66fe
6701 6705 6709 670a 670f 6711 6715 6718
671c 6720 6723 6724 6726 6729 672c 672d
6732 6736 673a 673e 6740 6744 6747 674b
674f 6753 6754 6756 6759 675a 675c 675f
6762 6763 6768 676b 676f 6773 6777 6778
677a 677d 677e 6780 6783 6786 6787 678c
1 678f 6794 6798 679d 67a0 67a5 67a6
67ab 67ae 67b3 67b4 67b9 67bc 67c1 67c2
67c7 67ca 67cf 67d0 67d5 67d8 67dc 67e0
67e4 67e7 67e8 67ea 67eb 67ed 67ee 67f3
67f6 67fb 67fc 6801 6804 6808 680c 6810
6813 6814 6816 6817 6819 681a 681f 6822
6827 6828 682d 6830 6834 6838 683c 683f
6840 6842 6843 6845 6846 684b 684e 6853
6854 6859 685c 6861 6862 6867 686a 686f
6870 6875 6878 687d 687e 6883 6886 688b
688c 6891 6894 6899 689a 689f 68a2 68a6
68a7 68ac 68af 68b4 68b5 68ba 68bd 68c1
68c2 68c7 68ca 68cf 68d0 68d5 68d8 68dd
68de 68e3 68e6 68eb 68ec 68f1 68f4 68f9
68fa 68ff 6902 6906 690a 690d 690e 6913
6916 691b 691c 6921 6924 6928 692c 692f
6930 6935 6938 693d 693e 6943 6946 694b
694c 6951 6954 6959 695a 695f 6962 6966
696a 696e 6971 6972 6974 6975 6977 6978
697d 6980 6985 6986 698b 698e 6992 6996
699a 699d 699e 69a0 69a1 69a3 69a4 69a9
69ac 69b1 69b2 69b7 69ba 69bf 69c0 69c5
69c8 69cc 69d0 69d4 69d7 69d8 69da 69db
69dd 69de 69e3 69e6 69eb 69ec 69f1 69f4
69f9 69fa 69ff 6a02 6a06 6a07 6a0c 6a0f
6a14 6a15 6a1a 6a1d 6a21 6a22 6a27 6a2a
6a2f 6a30 6a35 6a38 6a3d 6a3e 6a43 6a46
6a4b 6a4c 6a51 6a55 6a59 6a5b 6a5f 6a63
6a67 6a68 6a6a 6a6d 6a6e 6a70 6a73 6a76
6a77 6a7c 6a80 6a85 6a88 6a8d 6a8e 6a93
6a96 6a9b 6a9c 6aa1 6aa4 6aa9 6aaa 6aaf
6ab2 6ab7 6ab8 6abd 6ac0 6ac4 6ac8 6acc
6acf 6ad0 6ad2 6ad3 6ad5 6ad6 6adb 6ade
6ae3 6ae4 6ae9 6aec 6af0 6af4 6af8 6afb
6afc 6afe 6aff 6b01 6b02 6b07 6b0a 6b0f
6b10 6b15 6b18 6b1c 6b20 6b24 6b27 6b28
6b2a 6b2b 6b2d 6b2e 6b33 6b36 6b3b 6b3c
6b41 6b44 6b49 6b4a 6b4f 6b52 6b57 6b58
6b5d 6b60 6b65 6b66 6b6b 6b6e 6b73 6b74
6b79 6b7c 6b81 6b82 6b87 6b8a 6b8e 6b8f
6b94 6b97 6b9c 6b9d 6ba2 6ba5 6ba9 6baa
6baf 6bb2 6bb7 6bb8 6bbd 6bc0 6bc5 6bc6
6bcb 6bcf 6bd3 6bd5 6bd9 6bdd 6be1 6be5
6be6 6be8 6beb 6bec 6bee 6bf1 6bf4 6bf5
6bfa 6bfe 6c03 6c06 6c0b 6c0c 6c11 6c14
6c18 6c1c 6c1f 6c20 6c25 6c28 6c2d 6c2e
6c33 6c36 6c3a 6c3e 6c41 6c42 6c47 6c4a
6c4f 6c50 6c55 6c58 6c5d 6c5e 6c63 6c66
6c6b 6c6c 6c71 6c74 6c78 6c7c 6c80 6c83
6c84 6c86 6c87 6c89 6c8a 6c8f 6c92 6c97
6c98 6c9d 6ca0 6ca4 6ca8 6cac 6caf 6cb0
6cb2 6cb3 6cb5 6cb6 6cbb 6cbe 6cc3 6cc4
6cc9 6ccc 6cd1 6cd2 6cd7 6cda 6cde 6ce2
6ce6 6ce9 6cea 6cec 6ced 6cef 6cf0 6cf5
6cf8 6cfd 6cfe 6d03 6d06 6d0b 6d0c 6d11
6d14 6d18 6d19 6d1e 6d21 6d26 6d27 6d2c
6d2f 6d33 6d34 6d39 6d3c 6d41 6d42 6d47
6d4a 6d4f 6d50 6d55 6d58 6d5d 6d5e 6d63
6d67 6d69 6d6d 6d71 6d74 6d78 6d7c 6d7f
6d83 6d87 6d8a 6d8d 6d92 6d95 6d98 6d9b
6d9c 6da1 6da2 1 6da4 6da9 6dad 6db1
6db4 6db9 6dbe 6dc1 6dc5 6dc6 6dcb 6dcc
6dd1 6dd3 6dd7 6dda 6dde 6de2 6de5 6de9
6ded 6df0 6df3 6df8 6dfb 6dfe 6e01 6e02
6e07 6e08 1 6e0a 6e0f 6e13 6e17 6e1a
6e1f 6e24 6e27 6e2b 6e2c 6e31 6e32 6e37
6e39 6e3d 6e40 6e44 6e48 6e4c 6e4f 6e53
6e54 6e56 6e5a 6e5c 6e60 6e64 6e67 6e6b
6e6f 6e72 6e76 6e7a 6e7d 6e80 6e85 6e88
6e8b 6e8e 6e8f 6e94 6e95 1 6e97 6e9c
6ea0 6ea4 6ea7 6eac 6eb1 6eb4 6eb8 6eb9
6ebe 6ebf 6ec4 6ec8 6ecc 6ecf 6ed4 6ed9
6edc 6ee0 6ee4 6ee7 6ee8 6eed 6ef0 6ef5
6ef6 6efb 6efe 6f02 6f06 6f09 6f0a 6f0f
6f10 6f15 6f17 6f1b 6f1e 6f22 6f26 6f2a
6f2e 6f32 6f36 6f3a 6f3e 6f42 6f4e 6f53
6f57 6f5b 6f5f 6f63 6f65 6f66 6f6b 1
6f6f 6f73 6f77 6f7a 6f7e 6f82 6f86 6f8a
6f8d 6f91 6f95 6f98 6f9b 6fa0 6fa3 6fa6
6fa9 6faa 6faf 6fb0 1 6fb2 6fb7 6fbb
6fbf 6fc2 6fc7 6fcc 6fcf 6fd3 6fd4 6fd9
6fda 6fdf 6fe3 6fe7 6fea 6fef 6ff4 6ff7
6ffb 6ffc 7001 7004 7009 700a 700f 7012
7016 701a 701d 7020 7021 7023 7024 7029
702a 702f 7031 7035 7038 703c 7040 7044
7048 704c 7050 7054 7060 7065 7069 706d
7071 7075 7077 707b 707d 7089 708b 708d
708e 7093 7097 7099 70a5 70a9 70ab 70ac
70b5 
20a9
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 10 :3 6 e :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 e 17
16 :2 e :2 4 f 18 17 :2 f :2 4
d 16 15 :2 d :2 4 11 1a 19
:2 11 :2 4 f 18 17 :2 f :2 4 10
19 18 :2 10 :2 4 :3 10 :2 4 11 1a
19 :2 11 :2 4 f 18 17 :2 f :2 4
13 1c 1b :2 13 :2 4 10 19 18
:2 10 :2 4 18 21 20 :2 18 :2 4 10
19 18 :2 10 :2 4 f 18 17 :2 f
:2 4 10 19 18 :2 10 :2 4 :3 9 :2 4
:3 9 :2 4 10 19 18 :2 10 :2 4 :2 c
1b c :2 4 :2 e 1d e :2 4 :2 b
1a b :2 4 :2 d 1c d :2 4 :2 10
1f 10 :2 4 :2 a 19 a :2 4 :2 b
1a b :2 4 :2 11 20 11 :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 :2 b
1a b :2 4 :2 f 1e f :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 f 1e f :2 4 :2 f
1e f :2 4 :2 b 1a b :2 4 :2 f
1e f :2 4 :2 d 1c d :2 4 :2 c
1b c :2 4 :2 c 1b c :2 4 :2 f
1e f :2 4 :2 b 1a b :2 4 :2 f
19 f :2 4 :2 f 1e f :2 4 :2 16
25 16 :2 4 :2 11 20 11 :2 4 :2 10
1f 10 :2 4 :2 14 23 14 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 :2 17
26 17 :2 4 17 1c 1b :2 17 :2 4
18 1d 1c :2 18 :2 4 :2 13 22 13
:2 4 :2 14 23 14 :2 4 9 12 11
:2 9 :2 4 :2 11 20 11 :2 4 :2 f 1e
f :2 4 :2 6 1e 6 :2 4 :2 7 1f
7 :2 4 :2 f 27 f :2 4 :2 d 25
d :2 4 :2 8 20 8 :2 4 :3 d :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 53 59 5c :2 53 6a 7f 8
:2 6a d 10 :2 6a 17 1a :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
2c 2f :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 2d 30 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 34 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
2f :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 2e :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 34 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 34 :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 40 :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4e 4f :2 4b :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e :2 7 52 :3 4
14 :2 4 14 :2 4 13 :2 4 12 :2 4
10 :2 4 e :2 4 14 :2 4 f :2 4
12 :2 4 e :2 4 e :2 4 11 :2 4
11 :2 4 13 :2 4 11 :2 4 14 1d
26 2e :2 1d :2 14 :2 4 12 :2 4 10
4 :4 8 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b6 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 46
:2 7 18 :2 4 7 10 1b :2 7 1e
20 :2 1e 26 2f 37 :2 26 3a 3c
:2 3a :2 7 42 4b 53 :2 42 56 58
:2 56 :2 7 a :2 14 26 :2 30 3c 3f
4e 51 52 :2 4e :2 26 :3 a :2 10 15
21 5f 62 :2 21 6f 72 :2 21 76
79 :2 21 83 86 8f 97 :2 a0 :2 8f
b1 :2 86 :2 21 :2 a 55 :2 7 a :2 14
26 :2 30 3c 3f 4e 51 52 :2 4e
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:2 a 55 :3 7 :2 12 28 :2 31 41 :2 7
5a :2 4 8 11 1c :2 8 22 1f
:2 2b :2 1f 7 :4 46 45 44 :2 7 :4 14
13 12 :2 7 11 1c 21 33 3e
43 :2 f :2 a :2 13 1f a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 8b 8e :2 27 96 99
:2 27 a5 a8 af b8 bb :2 a8 :2 27
:2 10 5c :2 d :2 a :4 16 :2 a 7 :3 31
b :2 14 1f 1d :2 28 :2 1d a 3d
46 4f :2 3d 52 54 :2 52 3c :2 a
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 62
65 :2 24 72 75 :2 24 79 7c :2 24
86 89 92 9a :2 a3 :2 92 c0 :2 89
:2 24 :2 d 58 :2 a d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 62 65 :2 24 :2 d 58
:3 a :2 15 2b :2 34 50 :2 a 57 :3 7
e 7 4 31 :4 c b a :4 2a
29 28 :2 a 11 23 f :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 8b
8e :2 27 96 99 :2 27 a5 a8 af
b8 bb :2 a8 :2 27 :2 10 5c :2 d :2 a
:4 16 :2 a 7 :4 43 31 :3 4 d :2 16
22 29 32 3e :2 29 42 :2 4b :2 22
21 5a :2 d :2 4 13 1a 23 2f
:2 1a 33 :2 3c :2 13 12 4 7 10
1c :2 7 21 1f :2 2a :2 1f 7 15
7 3f :2 4 7 10 18 :2 7 1b
1d :2 1b 11 1a 30 39 51 f
1a 26 f 1d 2a :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 1f b :2 14 1f 1d :2 28
:2 1d a 26 31 3d 4d 5d 6a
:2 d :2 16 22 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :3 38 e :2 17
22 20 :2 2b :2 20 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 b7 :2 8c :2 27 bf c2
:2 27 ca cd :2 27 d2 d5 :2 27 e2
e5 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 45 53 :2 d
3b :2 a 38 :3 7 15 7 11 21
f 10 1d :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 8b 8e :2 27 96
99 :2 27 a5 a8 af b8 bb :2 a8
:2 27 :2 10 5c :2 d :2 a :4 16 :2 a 7
:3 1f a 13 1f :2 a 22 24 :2 22
14 24 12 13 20 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 26 d :2 18 1f 2d :2 d
32 34 :2 32 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 89 8c 95 9d :2 a6
:2 95 bb :2 8c :2 27 c3 c6 :2 27 ce
d1 :2 27 d6 d9 :2 27 e6 e9 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 49 57 :2 d 36 :2 a
26 :2 7 1f :4 b a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 86 89 92
9a :2 a3 :2 92 b9 :2 89 :2 24 :2 d 58
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
62 65 :2 24 :2 d 58 :3 a :2 15 2b
:2 34 49 :2 a 1e :3 7 16 :2 7 13
1a 21 2e 31 :2 1a 36 39 :2 13
:2 7 15 :2 1e 27 2a 2d 31 :2 15
7 a 18 21 29 :2 18 :2 a 2d
30 :2 2d 14 20 29 3f 48 60
12 20 2b 37 12 20 2d 3b
47 50 5b 64 70 79 87 90
9e a7 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 32
e :2 17 22 20 :2 2b :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 89
8c 95 9d :2 a6 :2 95 b9 :2 8c :2 27
c1 c4 :2 27 cc cf :2 27 d4 d7
:2 27 e1 e4 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 :2 10 5b :3 d :2 18 2c :2 35 47
52 :2 d 3b :2 a 32 d :2 17 29
:2 33 3f 43 52 55 56 :2 52 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 86 89 92
9a :2 a3 :2 92 b6 :2 89 :2 24 be c1
:2 24 c9 cc :2 24 d1 d4 :2 24 de
e1 :2 24 :2 d 59 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 :2 d
58 :3 a :2 15 29 :2 32 44 4f :2 a
:4 7 :4 4 8 11 1d :2 8 20 22
:2 20 7 2a 33 3b :2 2a 3e 41
:2 3e 29 :3 7 11 7 46 :2 4 7
b d :2 b 7 15 :2 7 16 :2 7
15 26 32 3f 48 51 :2 3f 55
5e 66 :2 55 22 2b 37 :2 22 3b
44 4f :2 3b 53 20 2b :2 53 2f
38 46 :2 2f 4a 53 5e :2 4a 22
2b 37 :2 22 3b 43 4d :2 15 7
a 13 1f :2 a 24 22 :2 2d :2 22
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 62
65 :2 24 72 75 :2 24 79 7c :2 24
86 89 92 9a :2 a3 :2 92 b4 :2 89
:2 24 :2 d 58 :2 a d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 62 65 :2 24 :2 d 58
:3 a :2 15 2b :2 34 44 :2 a 7 3c
d 16 22 :2 d 25 28 :2 25 d
:2 17 29 :2 33 3f 43 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 62 65
:2 24 72 75 :2 24 79 7c :2 24 86
89 92 9a :2 92 a7 :2 89 :2 24 af
b2 :2 24 ba bd :2 24 c2 c5 :2 24
d2 d5 :2 24 :2 d 59 :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 62 65 :2 24
:2 d 58 :3 a :2 15 29 32 3e :2 29
42 50 :2 a 2a 3c :2 7 4 f
a 13 1f :2 a 22 24 :2 22 a
13 1f :2 a 22 24 :2 22 d :2 17
29 :2 33 3f 43 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 62 65 :2 24
72 75 :2 24 79 7c :2 24 86 89
92 9a :2 a3 :2 92 ba :2 89 :2 24 c2
c5 :2 24 cd d0 :2 24 d5 d8 :2 24
e5 e8 :2 24 :2 d 59 :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 62 65 :2 24
:2 d 58 :3 a :2 15 29 :2 32 48 56
:2 a 29 :2 7 a 13 1f :2 a 22
24 :2 22 a 18 a 27 a 18
1e 28 31 3d :2 28 :2 1e 41 43
:2 1e :2 18 a :4 7 26 f :2 4 8
11 19 :2 8 1c 1e :2 1c 7 26
2f 37 :2 26 3a 3d :2 3a 25 :2 7
b 14 1c :2 b 1f 21 :2 1f a
28 31 39 :2 28 3c 3e :2 3c 27
:3 a 15 a 7 41 d 16 1e
:2 d 21 23 :2 21 a 15 a 7
25 41 e 17 1f :2 e 22 24
:2 22 d 2b 34 3c :2 2b 3f 41
:2 3f 2a :2 d a 15 a 7 44
41 d 16 1e :2 d 21 23 :2 21
a 14 1d 29 :2 14 2c 2e 37
3f :2 2e :2 14 :2 a 15 a 25 41
:2 7 42 :3 4 :3 17 :2 4 12 :2 4 13
:2 4 13 :2 4 13 :2 4 10 17 21
24 :2 10 :2 4 12 19 25 28 :2 12
4 7 10 18 :2 7 1b 1d :2 1b
7 f :2 7 15 7 a 11 1d
20 :2 a 23 25 :2 23 14 27 2f
36 51 59 60 7c 86 d 1b
12 27 2d 33 3f d 19 12
13 1b 2c 38 45 5b :2 d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 29 14 26 37 46
53 :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 29 e
:2 17 22 20 :2 2b :2 20 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 89 8c
95 9d :2 a6 :2 95 b9 :2 8c :2 27 c1
c4 :2 27 cc cf :2 27 d4 d7 :2 27
e0 e3 :2 27 :2 10 5c :2 d 10 :2 1a
2c :2 36 42 45 54 57 58 :2 54
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
:2 10 5b :3 d :2 18 2c :2 35 47 51
:2 d 3b :3 a 19 a 14 27 38
45 12 13 20 2e 46 54 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 29 7 29 d
14 20 23 :2 d 26 28 :2 26 14
23 34 44 52 :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 2c e :2 17 22 20 :2 2b :2 20
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 89 8c 95 9d :2 a6 :2 95 b9
:2 8c :2 27 c1 c4 :2 27 cc cf :2 27
d4 d7 :2 27 e0 e3 :2 27 :2 10 5c
:2 d 10 :2 1a 2c :2 36 42 45 54
57 58 :2 54 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 :2 10 5b :3 d :2 18 2c
:2 35 47 51 :2 d 3b :3 a 18 a
14 27 2f 36 51 59 60 7c
86 d 1b 12 27 2d 33 3f
d 19 12 13 1b 2c 38 45
5b :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 2c e
:2 17 22 20 :2 2b :2 20 :2 d 1b d
17 2a 32 39 54 5c 63 7f
89 10 1e 15 2a 30 36 42
10 1c 15 16 1e 2f 3b 48
5e :2 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5b 5e 5f :2 5b :2 32 :3 16 :2 1c 21
2d 6b 6e :2 2d 7b 7e :2 2d 82
85 :2 2d 91 94 :2 2d 9c 9f :2 2d
ab ae b5 be c1 :2 ae :2 2d :2 16
62 :2 13 :2 10 :4 1c :2 10 d :3 3b 11
:2 1a 25 23 :2 2e :2 23 :2 10 1e 1f
:2 1e 10 13 21 2a 32 :2 21 :2 13
36 39 :2 36 13 21 13 1d 2d
3d 60 1c 29 3a 45 54 62
:2 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 61
64 65 :2 61 :2 38 :3 1c :2 22 27 33
71 74 :2 33 81 84 :2 33 88 8b
:2 33 97 9a :2 33 a2 a5 :2 33 b1
b4 bb c4 c7 :2 b4 :2 33 :2 1c 68
:2 19 :2 16 :4 22 :2 16 13 :3 3b 16 1f
2b :2 16 2e 31 :2 2e 19 :2 23 35
:2 3f 4b 4f 5e 61 62 :2 5e :2 35
:3 19 :2 1f 24 30 6e 71 :2 30 7e
81 :2 30 85 88 :2 30 92 95 9e
a6 :2 af :2 9e d0 :2 95 :2 30 d8 db
:2 30 e3 e6 :2 30 eb ee :2 30 f7
fa :2 30 :2 19 65 :2 16 19 :2 23 35
:2 3f 4b 4e 5d 60 61 :2 5d :2 35
:3 19 :2 1f 24 30 6e 71 :2 30 :2 19
64 :3 16 :2 21 35 :2 3e 5e 1e :2 16
33 :2 13 3b :2 10 3e :2 d 3b :2 a
14 27 38 45 12 13 20 2e
46 54 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :4 2c
29 d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 86 89 92 9a :2 a3 :2 92 b4
:2 89 :2 24 :2 d 58 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 :2 d
58 :3 a :2 15 2b :2 34 44 :2 a :4 7
b :2 14 1f 1d :2 28 :2 1d :2 a 1d
2b 2e 37 3f :2 2e 43 :2 4c 24
:2 1d :2 a 1d 2b 2e 37 3f :2 2e
43 :2 4c 24 :2 1d a 14 2d 12
20 38 49 52 5d 66 72 7b
89 92 a0 a9 bd c6 12 20
39 42 12 20 38 41 12 1b
23 30 39 :2 12 20 3a 12 13
27 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 38 a 1d 33 :2 1d a 38
a :3 19 :2 a 1d 2b 2e 37 3f
:2 2e 43 :2 4c 24 :2 1d :2 a 20 :2 29
:2 a 1c :2 a 1d 34 42 4c 54
2d 41 4d :2 1d a 19 2e 41
4d 59 67 d 1c 29 36 43
4d 15 22 30 3b 43 d 19
23 2c 39 4d 5a d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :7 7 b 14
21 :2 b 24 26 :2 24 a :4 2e 2d
:2 a 45 50 52 :2 50 44 :2 a d
16 1e :2 d 21 23 :2 21 10 19
21 :2 10 24 27 :2 24 10 1e 27
2f :2 1e 10 2b 10 1e 24 2f
38 40 :2 2f 43 45 4e 59 :2 45
:2 2f 2e :2 24 5e 60 :2 24 68 6a
:2 24 :2 1e 10 :5 d 15 d 17 1b
1f 2e 15 2a 2f 40 16 1a
27 14 18 2c 14 18 24 2c
33 14 18 14 18 25 14 18
23 27 15 19 29 2d 3b :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5e
5f :2 5b :2 32 :3 16 :2 1c 21 2d 6b
6e :2 2d 7b 7e :2 2d 82 85 :2 2d
91 94 :2 2d 9c 9f :2 2d ab ae
b5 be c1 :2 ae :2 2d :2 16 62 :2 13
:2 10 :4 1c :2 10 d :3 25 :4 11 10 1b
26 33 3b 42 5a 65 7b 8b
:2 13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 5e
61 62 :2 5e :2 35 :3 19 :2 1f 24 30
6e 71 :2 30 7e 81 :2 30 85 88
:2 30 94 97 :2 30 9f a2 :2 30 ae
b1 b8 c1 c4 :2 b1 :2 30 :2 19 65
:2 16 :2 13 :4 1f :2 13 10 :4 1f 1a 25
32 3c 45 55 66 18 19 26
17 2b 17 22 :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 5e 61 62 :2 5e :2 35
:3 19 :2 1f 24 30 6e 71 :2 30 7e
81 :2 30 85 88 :2 30 94 97 :2 30
9f a2 :2 30 ae b1 b8 c1 c4
:2 b1 :2 30 :2 19 65 :2 16 :2 13 :4 1f :2 13
10 :7 d 10 14 16 :2 14 1c :2 27
2f 3b 48 :2 1c 4c 4e :2 4c :2 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8c 8f 98 a0 :2 a9 :2 98 c1 :2 8f
:2 2a c9 cc :2 2a d4 d7 :2 2a dc
df :2 2a e8 eb :2 2a :2 13 5f :2 10
13 :2 1d 2f :2 39 45 48 57 5a
5b :2 57 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a :2 13 5e :3 10 :2 1b 2f :2 38
4f 59 :2 10 50 :2 d a 25 10
14 16 :2 14 d 20 d 17 1b
2b 15 16 23 14 28 14 25
2d 34 4c 54 5b :2 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5e 5f :2 5b
:2 32 :3 16 :2 1c 21 2d 6b 6e :2 2d
7b 7e :2 2d 82 85 :2 2d 91 94
:2 2d 9c 9f :2 2d ab ae b5 be
c1 :2 ae :2 2d :2 16 62 :2 13 :2 10 :4 1c
:2 10 d :3 18 d 1c d 17 1b
2f 15 16 23 30 41 49 50
68 70 77 :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5e 5f :2 5b :2 32 :3 16
:2 1c 21 2d 6b 6e :2 2d 7b 7e
:2 2d 82 85 :2 2d 91 94 :2 2d 9c
9f :2 2d ab ae b5 be c1 :2 ae
:2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10 d
:3 18 10 19 26 :2 10 29 2c 35
46 :2 2c 49 4b 54 5e :2 4b :2 2c
2b :2 29 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8c 8f 98 a0 :2 a9 :2 98
c1 :2 8f :2 2a c9 cc :2 2a d4 d7
:2 2a dc df :2 2a e8 eb :2 2a :2 13
5f :2 10 13 :2 1d 2f :2 39 45 48
57 5a 5b :2 57 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a :2 13 5e :3 10 :2 1b
2f :2 38 4f 59 :2 10 62 :2 d 18
25 :2 a 14 36 4a 60 6d :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 55 d 14 24
27 :2 d 2a 2c :2 2a d 1d 1e
:2 1d :2 d :2 16 22 39 47 55 6a
2f 35 41 4d 2f 42 :2 22 d
30 :2 a 55 :2 7 a 11 1d 20
:2 a 23 25 :2 23 a 15 :2 1e a
29 a 15 1e 2a :2 15 a :5 7
13 1f 2c 3a 45 4f 5b 1b
28 35 42 4f 1b 28 34 3e
46 4f 57 5e 1b 27 34 3f
4a 58 1b 26 32 3e 41 44
4a 50 :2 13 7 a 13 15 :2 13
14 27 44 4b d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :4 17 :2 7 1f 7
15 :2 7 16 :2 7 16 7 a 13
1a :2 13 28 :2 a 2b 2d :2 2b a
16 a 30 a 16 1d 26 2d
:2 26 3b :2 1d 3e 40 :2 1d 1c 43
45 :2 1c :2 16 a :4 7 a 13 15
:2 13 a 15 :2 a 10 19 22 :2 10
27 25 30 :2 25 a d 19 :2 22
2b 2f 33 3c 45 :2 33 48 4a
:2 33 4c 4d :2 33 50 :2 19 :2 d 1b
:2 24 2d 30 33 3c 45 :2 33 48
4a :2 33 4d 4f :2 33 51 52 :2 33
55 :2 1b d 10 17 23 26 :2 10
29 2b :2 29 10 1b :2 24 10 13
1c 23 :2 1c 31 :2 13 34 36 :2 34
13 22 13 38 13 22 29 35
38 :2 29 41 44 :2 22 :2 13 22 29
35 38 :2 29 42 45 :2 22 13 :4 10
2f 10 1b 24 30 :2 1b 10 13
1c 23 :2 1c 30 :2 13 33 35 :2 33
13 21 13 37 13 21 28 33
36 :2 28 3f 42 :2 21 :2 13 21 28
33 36 :2 28 40 43 :2 21 13 :4 10
:4 d 10 17 23 26 :2 10 29 2b
:2 29 10 1f 10 2f :3 d 1b :2 d
1c d 17 2a 34 15 2a 36
15 16 1e 2f 3b 48 :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5e 5f
:2 5b :2 32 :3 16 :2 1c 21 2d 6b 6e
:2 2d 7b 7e :2 2d 82 85 :2 2d 91
94 :2 2d 9c 9f :2 2d ab ae b5
be c1 :2 ae :2 2d :2 16 62 :2 13 :2 10
:4 1c :2 10 d :3 30 11 :2 1a 25 23
:2 2e :2 23 10 1a 2d 37 18 2d
39 18 19 21 32 3e 4b :2 13
:2 1c 28 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5e 61
62 :2 5e :2 35 :3 19 :2 1f 24 30 6e
71 :2 30 7e 81 :2 30 85 88 :2 30
94 97 :2 30 9f a2 :2 30 ae b1
b8 c1 c4 :2 b1 :2 30 :2 19 65 :2 16
:2 13 :4 1f :2 13 10 :3 3e 14 :2 1d 28
26 :2 31 :2 26 :2 13 22 13 41 13
21 13 :4 10 3e :2 d 10 19 26
:2 10 29 2b :2 29 13 1c 24 :2 13
27 29 :2 27 16 1f 27 :2 16 2a
2d :2 2a 16 24 2d 35 :2 24 16
31 16 24 2a 35 3e 46 :2 35
49 4b 54 5f :2 4b :2 35 34 :2 2a
64 66 :2 2a 6e 70 :2 2a :2 24 16
:5 13 1b 13 1d 21 25 34 1b
30 35 46 1c 20 2d 1a 1e
32 1a 1e 2a 32 39 1a 1e
1a 1e 2b 1a 1e 29 2d 1b
1f 2f 33 41 :2 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 61 65 66 :2 61 :2 38
:3 1c :2 22 27 33 72 75 :2 33 82
85 :2 33 89 8c :2 33 98 9b :2 33
a3 a6 :2 33 b2 b5 bc c5 c8
:2 b5 :2 33 :2 1c 69 :2 19 :2 16 :4 22 :2 16
13 :3 2b :4 17 16 20 2b 38 42
4b 5b 6c 1e 1f 2c 1d 31
1d 28 :2 19 :2 22 2e 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 64 68 69 :2 64 :2 3b :3 1f :2 25
2a 36 75 78 :2 36 85 88 :2 36
8c 8f :2 36 9b 9e :2 36 a6 a9
:2 36 b5 b8 bf c8 cb :2 b8 :2 36
:2 1f 6c :2 1c :2 19 :4 25 :2 19 16 :4 29
:2 13 10 2b 16 :2 21 29 37 43
:2 16 47 4a :2 47 50 :2 5b 63 18
25 :2 50 29 2c :2 29 :2 16 1f 2a
37 3f 46 64 6f 1d 2d :2 16
:2 1f 2b 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 61 65
66 :2 61 :2 38 :3 1c :2 22 27 33 72
75 :2 33 82 85 :2 33 89 8c :2 33
98 9b :2 33 a3 a6 :2 33 b2 b5
bc c5 c8 :2 b5 :2 33 :2 1c 69 :2 19
:2 16 :4 22 :2 16 13 :4 2e 2b 13 21
:2 13 22 13 :4 10 2d 10 1e :2 10
1f 10 :4 d 10 19 25 :2 10 28
2a :2 28 13 1a 26 29 :2 13 2c
2e :2 2c 13 1f 13 32 :2 10 d
2c 13 1a 26 29 :2 13 2c 2e
:2 2c 10 1b :2 24 10 32 2c 10
1b 24 30 :2 1b 10 :5 d 19 25
32 40 4b 55 61 1b 28 35
42 4f 1b 28 34 3e 46 4f
57 5e 1b 27 34 3f 4a 58
1b 26 32 3e 41 44 4a 50
:2 19 d 10 19 1b :2 19 1a 2d
4a 51 13 1a 16 22 :3 20 16
:2 1f 2b 16 27 16 :2 1f 2b 16
:4 13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 5e 62 63 :2 5e
:2 35 :3 19 :2 1f 24 30 6f 72 :2 30
7f 82 :2 30 86 89 :2 30 95 98
:2 30 a0 a3 :2 30 af b2 b9 c2
c5 :2 b2 :2 30 :2 19 66 :2 16 :2 13 :4 1f
:2 13 10 :4 1d :3 d 18 21 2a :2 18
2d 2f :2 18 d 30 e a 17
:2 7 :4 4 8 11 14 :2 11 7 1c
25 2d :2 1c 30 32 :2 30 1b :2 7
a :2 14 26 :2 30 3c 40 4f 53
54 :2 4f :2 26 :3 a :2 10 15 21 60
63 :2 21 70 73 :2 21 77 7a :2 21
84 87 90 98 :2 a1 :2 90 c2 :2 87
:2 21 ca cd :2 21 d5 d8 :2 21 dd
e0 :2 21 ec ef :2 21 :2 a 57 :2 7
a :2 14 26 :2 30 3c 3f 4e 52
53 :2 4e :2 26 :3 a :2 10 15 21 60
63 :2 21 :2 a 56 :3 7 :2 12 26 :2 2f
4f f :2 7 35 :2 4 7 10 18
:2 7 1b 1d :2 1b 7 17 7 1f
:2 4 8 11 18 :2 11 25 :2 8 28
2a :2 28 7 32 3b 42 :2 3b 50
:2 32 53 55 :2 53 31 :3 7 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d 2c 2f 37 40 4a
:2 37 :2 2f :2 d 4e 51 :2 d 13 16
1e 27 30 :2 1e :2 16 :2 d 13 16
:2 d e 11 19 22 2d :2 19 :2 11
:2 d 13 16 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d 29 2c :2 d 13 16
:2 d 4e 51 :2 d 13 16 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 1a :2 d 32 35 :2 d 48
4b :2 54 :2 d 13 16 :2 d e 11
:2 d e 11 :2 d 47 4a 52 5b
65 :2 52 :2 4a :2 d 13 16 :2 d 2a
2d 35 3e 47 :2 35 :2 2d :2 d 4b
4e :2 d e 11 :2 d 54 57 5f
13 1e :2 5f :2 57 :2 d 13 16 :2 d
e 11 :2 d 4d 50 :2 d 13 16
:2 d 50 53 :2 d 13 16 :2 d e
11 :2 d e 11 :2 d 7 4 58
a 13 1a :2 13 27 :2 a 2a 2c
:2 2a 7 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d 2c
2f 37 40 4a :2 37 :2 2f :2 d 4e
51 :2 d 13 16 1e 27 30 :2 1e
:2 16 :2 d 13 16 :2 d e 11 19
22 2d :2 19 :2 11 :2 d 13 16 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d 29
2c :2 d 13 16 :2 d 4e 51 :2 d
13 16 :2 d e 11 :2 d 7 4
2e 58 a 13 1a :2 13 28 :2 a
2b 2d :2 2b 7 d e 11 :2 d
e 11 :2 1a :2 d 32 35 :2 d 48
4b :2 54 :2 d 13 16 :2 d e 11
:2 d e 11 :2 d 47 4a 52 5b
65 :2 52 :2 4a :2 d 13 16 :2 d 2a
2d 35 3e 47 :2 35 :2 2d :2 d 4b
4e :2 d e 11 :2 d 54 57 5f
13 1e :2 5f :2 57 :2 d 13 16 :2 d
e 11 :2 d 4d 50 :2 d 13 16
:2 d 50 53 :2 d 13 16 :2 d e
11 :2 d e 11 :2 d 7 2f 58
:2 4 7 :2 11 23 :2 2d 39 3c 4b
4f 50 :2 4b :2 23 :3 7 :2 d 12 1e
5d 60 :2 1e :2 7 53 :2 4 7 :2 11
23 :2 2d 39 3c 4b 4f 50 :2 4b
:2 23 :3 7 :2 d 12 1e 5d 60 :2 1e
:2 7 53 :3 4 b :2 16 26 :2 b 4
1 9 12 9 a :2 14 26 :2 30
3c 40 4f 53 54 :2 4f :2 26 :3 a
:2 10 15 21 60 63 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 57 :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 4c 50 51 :2 4c :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
54 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
20a9
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :5 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :7 21 :7 22 :7 23
:5 24 :5 25 :7 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:7 48 :7 49 :6 4a :6 4b
:7 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:5 54 :7 56 :b 58 :11 59
5a :2 59 :2 5a :2 59
:2 5a :2 59 :2 5b :2 59
:2 5b :2 59 :2 5b :2 59
:2 5b :2 59 :2 5c :2 59
:2 5c :2 59 :2 5c :2 59
:2 5c :2 59 :2 5d :2 59
:9 5d :2 59 :2 5e :2 59
:9 5e :2 59 :2 5f :2 59
:9 5f :2 59 :2 60 :2 59
:9 60 :2 59 :2 61 :2 59
:9 61 :2 59 :2 62 :2 59
:9 62 :2 59 :2 63 :2 59
:9 63 :2 59 :2 64 :2 59
:9 64 :2 59 :2 65 :2 59
:9 65 :2 59 :2 66 :2 59
:9 66 :2 59 :2 67 :2 59
:2 67 :2 59 :2 67 :2 59
:2 67 :2 59 :2 68 :2 59
:2 68 :2 59 :2 68 :2 59
:2 68 :2 59 :2 68 :4 59
:3 58 :11 6b :b 6c :3 6b
:3 73 :3 74 :3 75 :3 76
:3 78 :3 7a :3 7c :3 7e
:3 7f :3 80 :3 81 :3 82
:3 83 :3 84 :3 86 :a 87
:3 8b :3 8c :5 8e :11 8f
:20 90 :3 8f :11 92 :b 93
:3 92 :9 95 :3 8e :1f 98
:11 99 :20 9a :3 99 :11 9c
:b 9d :3 9c :9 9f :3 98
:14 a2 :6 a3 :2 a2 :6 a5
a6 a7 a5 :5 a8
a4 aa :5 ab :3 aa
:2 ac :5 ae :11 af :24 b0
:3 af :2 ad :6 ac a9
:3 a3 :16 b5 :11 b6 :20 b7
:3 b6 :11 b9 :b ba :3 b9
:9 bc :3 b5 :3 bf c0
a3 :e c0 :2 c2 c3
c2 :5 c4 c1 c6
:5 c7 :3 c6 :2 c8 :5 ca
:11 cb :24 cc :3 cb :2 c9
:6 c8 c5 :4 c0 a3
:2 a2 :14 d4 :e d6 :b d9
:3 da :3 d9 :9 dd :5 df
:3 e0 :3 e1 df :5 e2
de e4 :5 e5 :3 e4
:2 e6 :5 e8 :11 e9 :24 ea
:3 e9 :2 e7 :6 e6 e3
:3 dd :a ef :7 f1 :5 f2
f0 f4 :5 f5 :3 f4
:2 f6 :5 f8 :11 f9 :24 fa
:3 f9 :2 f7 :6 f6 f3
:3 ef :a fe :11 ff :30 100
:3 ff :11 102 :b 103 :3 102
:a 105 :3 fe :3 ef :3 109
:2 10b 10c :2 10d 10b
:5 10e 10a 110 :5 111
:3 110 :2 112 :5 114 :11 115
:24 116 :3 115 :2 113 :6 112
10f :3 dd :9 11b :2 11d
11e :2 11f 11d :5 120
11c 122 :5 123 :3 122
:2 124 :5 126 :11 127 :24 128
:3 127 :2 125 :6 124 121
:3 11b :b 12d :11 12e :30 12f
:3 12e :11 131 :b 132 :3 131
:a 134 :3 12d :3 11b dd
:5 138 :11 139 :20 13a :3 139
:11 13c :b 13d :3 13c :9 13f
:3 138 :3 142 :d 146 :b 14a
:c 14c :6 14e :4 14f :e 150
14e :5 151 14d 153
:5 154 :3 153 :2 155 :5 157
:11 158 :24 159 :3 158 :2 156
:6 155 152 :3 14c :a 15e
:11 15f :30 160 :3 15f :11 162
:b 163 :3 162 :a 165 :3 15e
14c :11 168 :30 169 :3 168
:11 16b :b 16c :3 16b :a 16e
167 :3 14c 137 :3 dd
:16 173 :3 174 :3 173 :5 177
:3 179 :3 17a :e 17c :b 17d
:2 17e :2 17d :a 17e :8 17f
:3 17c :b 181 :11 182 :20 183
:3 182 :11 185 :b 186 :3 185
:9 188 189 181 :9 189
:11 18a :2e 18b :3 18a :11 18d
:b 18e :3 18d :c 190 189
:3 181 192 177 :9 192
:9 193 :11 194 :30 195 :3 194
:11 197 :b 198 :3 197 :a 19a
:3 193 :9 19c :3 19d 19c
:11 19f 19e :3 19c 192
:3 177 :16 1a2 :16 1a3 :3 1a4
1a5 1a3 :9 1a5 :3 1a6
1a7 1a5 1a3 :16 1a7
:3 1a8 1a9 1a7 1a3
:9 1a9 :f 1aa :3 1ab 1a9
:3 1a3 :3 1a2 :5 1af :3 1b2
:3 1b3 :3 1b4 :3 1b5 :8 1b7
:8 1b9 :9 1be :3 1bf :3 1c0
:a 1c1 :9 1c3 :2 1c4 :5 1c5
:2 1c6 1c7 :6 1c8 1c3
:5 1c9 1c2 1cb :5 1cc
:3 1cb :2 1cd :5 1cf :11 1d0
:24 1d1 :3 1d0 :2 1ce :6 1cd
1ca :3 1c1 :6 1d7 :5 1d8
1d6 1da :5 1db :3 1da
:2 1dc :5 1de :11 1df :24 1e0
:3 1df :2 1dd :6 1dc 1d9
:3 1c1 :a 1e5 :11 1e6 :30 1e7
:3 1e6 :11 1e9 :b 1ea :3 1e9
:a 1ec :3 1e5 :3 1ef :4 1f2
1f3 :5 1f4 1f2 :5 1f5
1f1 1f7 :5 1f8 :3 1f7
:2 1f9 :5 1fb :11 1fc :24 1fd
:3 1fc :2 1fa :6 1f9 1f6
:3 1c1 201 1c1 :a 201
:6 203 :5 204 202 206
:5 207 :3 206 :2 208 :5 20a
:11 20b :24 20c :3 20b :2 209
:6 208 205 :3 201 :a 211
:11 212 :30 213 :3 212 :11 215
:b 216 :3 215 :a 218 :3 211
:3 21b :9 21e :2 21f :5 220
:2 221 222 :6 223 21e
:5 224 21d 226 :5 227
:3 226 :2 228 :5 22a :11 22b
:24 22c :3 22b :2 229 :6 228
225 :3 201 :a 232 :3 233
:9 235 :2 236 :5 237 :2 238
239 :6 23a 235 :5 23b
234 23d :5 23e :3 23d
:2 23f :5 241 :11 242 :24 243
:3 242 :2 240 :6 23f 23c
:3 232 :a 248 :6 249 :c 24b
:3 24c :4 24e :6 24f 24e
:5 250 24d 252 :5 253
:3 252 :2 254 :5 256 :11 257
:24 258 :3 257 :2 255 :6 254
251 :3 24b :9 25c :11 25d
:30 25e :3 25d :11 260 :b 261
:3 260 :7 263 264 :2 263
:3 25c :3 24b :3 248 :3 232
:4 26b 26c :5 26d 26b
:5 26e 26a 270 :5 271
:3 270 :2 272 :5 274 :11 275
:24 276 :3 275 :2 273 :6 272
26f :4 201 1c1 :11 27b
:20 27c :3 27b :11 27e :b 27f
:3 27e :9 281 27a :3 1c1
:a 285 :b 286 287 :3 286
:b 288 289 :3 288 :2 28c
:f 28e :4 28f :4 290 :5 291
292 :3 294 295 :2 297
28c :6 298 :5 299 298
:5 29b 29a :3 298 28b
29e :5 29f :3 29e :2 2a0
:5 2a2 :11 2a3 :24 2a4 :3 2a3
:2 2a1 :6 2a0 29d :3 285
:6 2a9 285 :5 2ac :b 2ae
2af :3 2ae :5 2b1 :3 2b2
:6 2b4 :3 2b5 :3 2b4 :6 2b8
:6 2b9 :5 2ba :7 2bb 2b8
:6 2bc :5 2bd 2bc :5 2bf
2be :3 2bc 2b7 2c2
:5 2c3 :3 2c2 :2 2c4 :5 2c6
:11 2c7 :24 2c8 :3 2c7 :2 2c5
:6 2c4 2c1 :4 2aa :3 285
:19 2cf :9 2d0 :9 2d1 :7 2d2
2d1 :1e 2d4 2d3 :3 2d1
:3 2d7 :4 2d9 :4 2da :3 2db
:3 2dc :5 2dd :2 2de :3 2df
:4 2e0 :5 2e1 2d9 :5 2e2
2d8 2e4 :5 2e5 :3 2e4
:2 2e6 :5 2e8 :11 2e9 :24 2ea
:3 2e9 :2 2e7 :6 2e6 2e3
:3 2d0 :5 2ef :a 2f1 :5 2f2
2f0 2f4 :5 2f5 :3 2f4
:2 2f6 :5 2f8 :11 2f9 :24 2fa
:3 2f9 :2 2f7 :6 2f6 2f3
:4 2ef :7 300 301 :2 302
:2 303 :2 304 300 :5 305
2ff 307 :5 308 :3 307
:2 309 :5 30b :11 30c :24 30d
:3 30c :2 30a :6 309 306
:4 2fe :3 2ef :13 313 :11 314
:30 315 :3 314 :11 317 :b 318
:3 317 :a 31a :3 313 31c
2d0 :5 31c :3 31d :3 31f
320 :2 321 :2 322 :7 323
31f :5 324 31e 326
:5 327 :3 326 :2 328 :5 32a
:11 32b :24 32c :3 32b :2 329
:6 328 325 :3 31c :3 331
:3 333 334 :9 335 333
:5 336 332 338 :5 339
:3 338 :2 33a :5 33c :11 33d
:24 33e :3 33d :2 33b :6 33a
337 :3 31c :16 343 :11 344
:30 345 :3 344 :11 347 :b 348
:3 347 :a 34a :3 343 31c
:3 2d0 :6 34f :5 350 34e
352 :5 353 :3 352 :2 354
:5 356 :11 357 :24 358 :3 357
:2 355 :6 354 351 :3 2cf
:a 35e :6 35f :8 360 :4 361
:2 362 :3 360 :3 35e :3 2cf
:a 369 :5 36a 369 :7 36d
36b :3 369 :8 371 :5 372
:8 373 :6 374 :8 375 :3 371
:5 378 :5 37a :6 37b :5 37c
37b :5 37e 37d :3 37b
379 381 :5 382 :3 381
:2 383 :5 385 :11 386 :24 387
:3 386 :2 384 :6 383 380
:6 378 1be :3 38d :3 38e
:3 390 :c 392 :3 393 392
:16 395 394 :3 392 :5 398
:3 399 :c 39a :17 39d :1b 39f
:a 3a1 :5 3a2 :c 3a4 :3 3a5
3a4 :c 3a7 :c 3a8 3a6
:3 3a4 3a1 :7 3ab :c 3ad
:3 3ae 3ad :c 3b0 :c 3b1
3af :3 3ad 3aa :3 3a1
:a 3b5 :3 3b6 :3 3b5 :3 3b9
:3 3ba :3 3bd :3 3be 3bf
:5 3c0 3bd :5 3c1 3bc
3c3 :5 3c4 :3 3c3 :2 3c5
:5 3c7 :11 3c8 :24 3c9 :3 3c8
:2 3c6 :6 3c5 3c2 :3 39a
:a 3ce :3 3d0 :3 3d1 3d2
:5 3d3 3d0 :5 3d4 3cf
3d6 :5 3d7 :3 3d6 :2 3d8
:5 3da :11 3db :24 3dc :3 3db
:2 3d9 :6 3d8 3d5 :3 3ce
:a 3e0 :3 3e1 3e0 :3 3e3
3e2 :3 3e0 :3 3ce :9 3e7
:9 3e8 :9 3e9 :7 3ea 3e9
:1e 3ec 3eb :3 3e9 :3 3ef
:4 3f1 :4 3f2 :3 3f3 :3 3f4
:5 3f5 :2 3f6 :3 3f7 :4 3f8
:5 3f9 3f1 :5 3fa 3f0
3fc :5 3fd :3 3fc :2 3fe
:5 400 :11 401 :24 402 :3 401
:2 3ff :6 3fe 3fb :3 3e8
:5 407 :7 409 40a :2 40b
:2 40c :2 40d 409 :5 40e
408 410 :5 411 :3 410
:2 412 :5 414 :11 415 :24 416
:3 415 :2 413 :6 412 40f
:6 407 41b 3e8 :10 41b
:2 41c :2 41b :4 41c :2 41b
:7 41e :2 41f 41e :5 420
41d 422 :5 423 :3 422
:2 424 :5 426 :11 427 :24 428
:3 427 :2 425 :6 424 421
:4 41c 3e8 :3 42d :3 42e
42c :3 3e8 3e7 :3 431
:3 432 430 :3 3e7 :9 435
:a 437 :3 438 :3 437 43a
435 :a 43a :5 43b 43a
435 :7 43d 43c :3 435
:8 440 :5 441 :8 442 :6 443
:8 444 :3 440 :5 447 :5 449
:6 44a :5 44b 44a :5 44d
44c :3 44a 448 450
:5 451 :3 450 :2 452 :5 454
:11 455 :24 456 :3 455 :2 453
:6 452 44f :6 447 :b 45c
39a 45d 39a :3 398
38c :3 1be :12 462 :11 463
:30 464 :3 463 :11 466 :b 467
:3 466 :7 469 46a :2 469
:3 462 :9 46d :3 46e :3 46d
:1c 473 474 475 :2 476
:2 475 :2 477 :2 475 :2 478
:2 475 :2 479 :2 475 :9 479
:2 475 :2 479 :2 475 :9 47a
:2 475 :2 47b :2 475 :9 47c
:2 475 :2 47d :2 475 :2 47e
:2 475 :2 47f :2 475 :2 480
:2 475 :2 481 :2 475 :2 482
:2 475 :2 482 :2 475 :2 483
:2 475 :2 483 :2 475 :2 484
:2 475 :2 485 :2 475 :2 486
:2 475 :2 487 :2 475 :4 488
:2 475 :2 488 :2 475 :4 488
:2 475 :2 489 :2 475 :2 48a
:2 475 :2 48b :2 475 :9 48b
:2 475 :2 48c :2 475 :9 48c
:2 475 :2 48c :2 475 :2 48d
:2 475 :3 48d :2 48e :4 48d
:2 475 :2 48f :2 475 :2 490
:2 475 :2 490 :2 475 :2 491
:2 475 :2 491 :2 475 :2 492
:2 475 :2 493 :2 475 :2 494
:2 475 474 495 473
:c 495 496 497 :2 498
:2 497 :2 499 :2 497 :2 49a
:2 497 :2 49b :2 497 :9 49b
:2 497 :2 49b :2 497 :9 49c
:2 497 :2 49d :2 497 :9 49e
:2 497 :2 49f :2 497 :2 4a0
:2 497 :2 4a1 :2 497 :2 4a2
:2 497 :2 4a3 :2 497 :2 4a4
:2 497 :2 4a4 :2 497 :2 4a5
:2 497 :2 4a5 :2 497 :2 4a6
:2 497 :2 4a7 :2 497 496
4a8 495 473 :c 4a8
4a9 4aa :2 4ab :2 4aa
:4 4ac :2 4aa :2 4ac :2 4aa
:4 4ac :2 4aa :2 4ad :2 4aa
:2 4ae :2 4aa :2 4af :2 4aa
:9 4af :2 4aa :2 4b0 :2 4aa
:9 4b0 :2 4aa :2 4b0 :2 4aa
:2 4b1 :2 4aa :3 4b1 :2 4b2
:4 4b1 :2 4aa :2 4b3 :2 4aa
:2 4b4 :2 4aa :2 4b4 :2 4aa
:2 4b5 :2 4aa :2 4b5 :2 4aa
:2 4b6 :2 4aa :2 4b7 :2 4aa
:2 4b8 :2 4aa 4a9 4a8
:3 473 :11 4bc :b 4bd :3 4bc
:11 4bf :b 4c0 :3 4bf :8 4c2
57 :3 4c6 :11 4c7 :b 4c8
:17 4c9 :3 4c7 :2 4cb :3 4cc
:3 4cd 4ce 4cc 4cb
4cc :3 4cf :3 4c6 :2 4d0
:5 4d2 :11 4d3 :b 4d4 :18 4d5
:3 4d3 :2 4d7 4d8 :3 4d9
4da 4d8 4d7 4d8
:3 4db :2 4d1 :6 4d0 4c5
:7 1 
70b7
4
:3 0 1 :3 0 2
:a 0 20a4 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f 4 :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 20a4 2 44
:2 0 18 :2 0 33
4 :3 0 18 :2 0
31 47 49 :6 0
4c 4a 0 20a2
0 17 :6 0 18
:2 0 37 4 :3 0
35 4e 50 :6 0
53 51 0 20a2
0 19 :6 0 18
:2 0 3b 4 :3 0
39 55 57 :6 0
5a 58 0 20a2
0 1a :6 0 1d
:2 0 3f 4 :3 0
3d 5c 5e :6 0
61 5f 0 20a2
0 1b :6 0 1d
:2 0 43 4 :3 0
41 63 65 :6 0
68 66 0 20a2
0 1c :6 0 1d
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 20a2
0 1e :6 0 4d
21f 0 4b 4
:3 0 49 71 73
:6 0 76 74 0
20a2 0 1f :6 0
23 :2 0 51 21
:3 0 78 :7 0 7b
79 0 20a2 0
20 :6 0 4 :3 0
23 :2 0 4f 7d
7f :6 0 82 80
0 20a2 0 22
:6 0 23 :2 0 55
4 :3 0 53 84
86 :6 0 89 87
0 20a2 0 24
:6 0 18 :2 0 59
4 :3 0 57 8b
8d :6 0 90 8e
0 20a2 0 25
:6 0 18 :2 0 5d
4 :3 0 5b 92
94 :6 0 97 95
0 20a2 0 26
:6 0 29 :2 0 61
4 :3 0 5f 99
9b :6 0 9e 9c
0 20a2 0 27
:6 0 29 :2 0 65
4 :3 0 63 a0
a2 :6 0 a5 a3
0 20a2 0 28
:6 0 29 :2 0 69
4 :3 0 67 a7
a9 :6 0 ac aa
0 20a2 0 2a
:6 0 6f 322 0
6d 4 :3 0 6b
ae b0 :6 0 b3
b1 0 20a2 0
2b :6 0 2f :2 0
71 21 :3 0 b5
:7 0 b8 b6 0
20a2 0 2c :6 0
21 :3 0 ba :7 0
bd bb 0 20a2
0 2d :6 0 31
:2 0 75 4 :3 0
73 bf c1 :6 0
c4 c2 0 20a2
0 2e :6 0 31
:2 0 77 8 :3 0
c6 :7 0 ca c7
c8 20a2 0 30
:6 0 31 :2 0 79
8 :3 0 cc :7 0
d0 cd ce 20a2
0 32 :6 0 31
:2 0 7b 8 :3 0
d2 :7 0 d6 d3
d4 20a2 0 33
:6 0 31 :2 0 7d
8 :3 0 d8 :7 0
dc d9 da 20a2
0 34 :6 0 31
:2 0 7f 8 :3 0
de :7 0 e2 df
e0 20a2 0 35
:6 0 31 :2 0 81
8 :3 0 e4 :7 0
e8 e5 e6 20a2
0 36 :6 0 31
:2 0 83 8 :3 0
ea :7 0 ee eb
ec 20a2 0 37
:6 0 31 :2 0 85
8 :3 0 f0 :7 0
f4 f1 f2 20a2
0 38 :6 0 31
:2 0 87 8 :3 0
f6 :7 0 fa f7
f8 20a2 0 39
:6 0 31 :2 0 89
8 :3 0 fc :7 0
100 fd fe 20a2
0 3a :6 0 31
:2 0 8b 8 :3 0
102 :7 0 106 103
104 20a2 0 3b
:6 0 31 :2 0 8d
8 :3 0 108 :7 0
10c 109 10a 20a2
0 3c :6 0 31
:2 0 8f 8 :3 0
10e :7 0 112 10f
110 20a2 0 3d
:6 0 31 :2 0 91
8 :3 0 114 :7 0
118 115 116 20a2
0 3e :6 0 31
:2 0 93 8 :3 0
11a :7 0 11e 11b
11c 20a2 0 3f
:6 0 31 :2 0 95
8 :3 0 120 :7 0
124 121 122 20a2
0 40 :6 0 31
:2 0 97 8 :3 0
126 :7 0 12a 127
128 20a2 0 41
:6 0 31 :2 0 99
8 :3 0 12c :7 0
130 12d 12e 20a2
0 42 :6 0 31
:2 0 9b 8 :3 0
132 :7 0 136 133
134 20a2 0 43
:6 0 31 :2 0 9d
8 :3 0 138 :7 0
13c 139 13a 20a2
0 44 :6 0 31
:2 0 9f 8 :3 0
13e :7 0 142 13f
140 20a2 0 45
:6 0 31 :2 0 a1
8 :3 0 144 :7 0
148 145 146 20a2
0 46 :6 0 31
:2 0 a3 8 :3 0
14a :7 0 14e 14b
14c 20a2 0 47
:6 0 31 :2 0 a5
8 :3 0 150 :7 0
154 151 152 20a2
0 48 :6 0 31
:2 0 a7 4a :3 0
156 :7 0 15a 157
158 20a2 0 49
:6 0 31 :2 0 a9
8 :3 0 15c :7 0
160 15d 15e 20a2
0 4b :6 0 31
:2 0 ab 8 :3 0
162 :7 0 166 163
164 20a2 0 4c
:6 0 31 :2 0 ad
8 :3 0 168 :7 0
16c 169 16a 20a2
0 4d :6 0 31
:2 0 af 8 :3 0
16e :7 0 172 16f
170 20a2 0 4e
:6 0 51 :2 0 b1
8 :3 0 174 :7 0
178 175 176 20a2
0 4f :6 0 51
:2 0 b3 4a :3 0
17a :7 0 17e 17b
17c 20a2 0 50
:6 0 31 :2 0 b5
4a :3 0 180 :7 0
184 181 182 20a2
0 52 :6 0 18
:2 0 b7 8 :3 0
186 :7 0 18a 187
188 20a2 0 53
:6 0 18 :2 0 bb
55 :3 0 b9 18c
18e :6 0 191 18f
0 20a2 0 54
:6 0 31 :2 0 bf
55 :3 0 bd 193
195 :6 0 198 196
0 20a2 0 56
:6 0 31 :2 0 c1
8 :3 0 19a :7 0
19e 19b 19c 20a2
0 57 :6 0 5a
:2 0 c3 8 :3 0
1a0 :7 0 1a4 1a1
1a2 20a2 0 58
:6 0 31 :2 0 c7
4 :3 0 c5 1a6
1a8 :6 0 1ab 1a9
0 20a2 0 59
:6 0 31 :2 0 c9
8 :3 0 1ad :7 0
1b1 1ae 1af 20a2
0 5b :6 0 23
:2 0 cb 8 :3 0
1b3 :7 0 1b7 1b4
1b5 20a2 0 5c
:6 0 23 :2 0 cd
8 :3 0 1b9 0
2 :5 0 1bd 1ba
1bb 20a2 0 5d
:6 0 31 :2 0 cf
8 :3 0 1bf 0
2 :5 0 1c3 1c0
1c1 20a2 0 5e
:6 0 31 :2 0 d1
8 :3 0 1c5 0
2 :5 0 1c9 1c6
1c7 20a2 0 5f
:6 0 31 :2 0 d3
8 :3 0 1cb 0
2 :5 0 1cf 1cc
1cd 20a2 0 60
:6 0 d7 862 0
d5 8 :3 0 1d1
0 2 :5 0 1d5
1d2 1d3 20a2 0
61 :6 0 1e2 1e3
0 d9 8 :3 0
1d7 :7 0 1da 1d8
0 20a2 0 62
:6 0 15 :3 0 16
:2 0 4 1dc 1dd
0 1de :7 0 1e1
1df 0 20a2 0
63 :6 0 64 :3 0
65 :3 0 64 :3 0
66 :3 0 1e5 1e6
0 2 :4 0 db
1e7 1e9 1e4 1eb
1ea :2 0 67 :3 0
68 :3 0 1ed 1ee
0 69 :4 0 64
:3 0 6a :3 0 1f1
1f2 0 2 :4 0
dd 1f3 1f5 6b
:4 0 6c :2 0 6d
:3 0 df 1f8 1fa
:3 0 6e :4 0 6c
:2 0 6f :4 0 e2
1fd 1ff :3 0 6c
:2 0 3 :3 0 e5
201 203 :3 0 6c
:2 0 6f :4 0 e8
205 207 :3 0 6c
:2 0 70 :4 0 eb
209 20b :3 0 6c
:2 0 6f :4 0 ee
20d 20f :3 0 6c
:2 0 5 :3 0 f1
211 213 :3 0 6c
:2 0 6f :4 0 f4
215 217 :3 0 6c
:2 0 70 :4 0 f7
219 21b :3 0 6c
:2 0 6f :4 0 fa
21d 21f :3 0 6c
:2 0 6 :3 0 fd
221 223 :3 0 6c
:2 0 6f :4 0 100
225 227 :3 0 6c
:2 0 70 :4 0 103
229 22b :3 0 6c
:2 0 71 :3 0 72
:3 0 7 :3 0 106
22f 231 73 :4 0
108 22e 234 10b
22d 236 :3 0 6c
:2 0 70 :4 0 10e
238 23a :3 0 6c
:2 0 71 :3 0 72
:3 0 9 :3 0 111
23e 240 73 :4 0
113 23d 243 116
23c 245 :3 0 6c
:2 0 70 :4 0 119
247 249 :3 0 6c
:2 0 71 :3 0 72
:3 0 a :3 0 11c
24d 24f 73 :4 0
11e 24c 252 121
24b 254 :3 0 6c
:2 0 70 :4 0 124
256 258 :3 0 6c
:2 0 71 :3 0 72
:3 0 b :3 0 127
25c 25e 73 :4 0
129 25b 261 12c
25a 263 :3 0 6c
:2 0 70 :4 0 12f
265 267 :3 0 6c
:2 0 71 :3 0 72
:3 0 c :3 0 132
26b 26d 73 :4 0
134 26a 270 137
269 272 :3 0 6c
:2 0 70 :4 0 13a
274 276 :3 0 6c
:2 0 71 :3 0 72
:3 0 d :3 0 13d
27a 27c 73 :4 0
13f 279 27f 142
278 281 :3 0 6c
:2 0 70 :4 0 145
283 285 :3 0 6c
:2 0 71 :3 0 72
:3 0 e :3 0 148
289 28b 73 :4 0
14a 288 28e 14d
287 290 :3 0 6c
:2 0 70 :4 0 150
292 294 :3 0 6c
:2 0 71 :3 0 72
:3 0 f :3 0 153
298 29a 73 :4 0
155 297 29d 158
296 29f :3 0 6c
:2 0 70 :4 0 15b
2a1 2a3 :3 0 6c
:2 0 71 :3 0 72
:3 0 10 :3 0 15e
2a7 2a9 73 :4 0
160 2a6 2ac 163
2a5 2ae :3 0 6c
:2 0 70 :4 0 166
2b0 2b2 :3 0 6c
:2 0 71 :3 0 72
:3 0 11 :3 0 169
2b6 2b8 73 :4 0
16b 2b5 2bb 16e
2b4 2bd :3 0 6c
:2 0 70 :4 0 171
2bf 2c1 :3 0 6c
:2 0 6f :4 0 174
2c3 2c5 :3 0 6c
:2 0 12 :3 0 177
2c7 2c9 :3 0 6c
:2 0 6f :4 0 17a
2cb 2cd :3 0 6c
:2 0 70 :4 0 17d
2cf 2d1 :3 0 6c
:2 0 6f :4 0 180
2d3 2d5 :3 0 6c
:2 0 13 :3 0 183
2d7 2d9 :3 0 6c
:2 0 6f :4 0 186
2db 2dd :3 0 6c
:2 0 74 :4 0 189
2df 2e1 :3 0 18c
1ef 2e3 :2 0 2e5
191 2e6 1ec 2e5
0 2e7 193 0
2002 64 :3 0 65
:3 0 2e8 2e9 0
64 :3 0 75 :3 0
2eb 2ec 0 23
:2 0 2 :4 0 76
:2 0 77 :2 0 23
:2 0 195 2f1 2f3
:3 0 198 2ed 2f5
2ea 2f7 2f6 :2 0
67 :3 0 78 :3 0
2f9 2fa 0 69
:4 0 79 :4 0 6c
:2 0 6d :3 0 19c
2fe 300 :3 0 19f
2fb 302 :2 0 304
1a2 305 2f8 304
0 306 1a4 0
2002 17 :3 0 3
:3 0 307 308 0
2002 1c :3 0 5
:3 0 30a 30b 0
2002 1f :3 0 6
:3 0 30d 30e 0
2002 1a :3 0 13
:3 0 310 311 0
2002 39 :3 0 7
:3 0 313 314 0
2002 37 :3 0 9
:3 0 316 317 0
2002 38 :3 0 e
:3 0 319 31a 0
2002 3a :3 0 b
:3 0 31c 31d 0
2002 3c :3 0 f
:3 0 31f 320 0
2002 3b :3 0 c
:3 0 322 323 0
2002 33 :3 0 11
:3 0 325 326 0
2002 32 :3 0 a
:3 0 328 329 0
2002 3d :3 0 d
:3 0 32b 32c 0
2002 35 :3 0 10
:3 0 32e 32f 0
2002 19 :3 0 17
:3 0 331 332 0
2002 5b :3 0 7a
:3 0 71 :3 0 33
:3 0 31 :2 0 1a6
336 339 1a9 335
33b 334 33c 0
2002 49 :3 0 51
:2 0 33e 33f 0
2002 34 :3 0 31
:2 0 341 342 0
2002 3 :3 0 7b
:2 0 1ab 345 346
:3 0 347 :2 0 64
:3 0 65 :3 0 349
34a 0 64 :3 0
75 :3 0 34c 34d
0 7c :2 0 2
:4 0 7d :2 0 77
:2 0 23 :2 0 1ad
352 354 :3 0 1b0
34e 356 34b 358
357 :2 0 67 :3 0
78 :3 0 35a 35b
0 69 :4 0 7e
:4 0 6c :2 0 6d
:3 0 1b4 35f 361
:3 0 6c :2 0 7f
:4 0 1b7 363 365
:3 0 6c :2 0 80
:4 0 1ba 367 369
:3 0 6c :2 0 71
:3 0 72 :3 0 81
:3 0 82 :3 0 36e
36f 0 1bd 36d
371 73 :4 0 1bf
36c 374 1c2 36b
376 :3 0 1c5 35c
378 :2 0 37a 1c8
37b 359 37a 0
37c 1ca 0 3a5
64 :3 0 65 :3 0
37d 37e 0 64
:3 0 75 :3 0 380
381 0 23 :2 0
2 :4 0 83 :2 0
77 :2 0 23 :2 0
1cc 386 388 :3 0
1cf 382 38a 37f
38c 38b :2 0 67
:3 0 78 :3 0 38e
38f 0 69 :4 0
84 :4 0 6c :2 0
6d :3 0 1d3 393
395 :3 0 1d6 390
397 :2 0 399 1d9
39a 38d 399 0
39b 1db 0 3a5
85 :3 0 86 :3 0
39c 39d 0 81
:3 0 82 :3 0 39f
3a0 0 87 :3 0
1dd 39e 3a3 :2 0
3a5 1e0 3a6 348
3a5 0 3a7 1e4
0 2002 71 :3 0
32 :3 0 31 :2 0
1e6 3a8 3ab 88
:2 0 89 :2 0 1eb
3ad 3af :3 0 71
:3 0 3b :3 0 31
:2 0 1ee 3b1 3b4
88 :2 0 89 :2 0
1f3 3b6 3b8 :3 0
3b0 3ba 3b9 :2 0
71 :3 0 37 :3 0
31 :2 0 1f6 3bc
3bf 88 :2 0 89
:2 0 1fb 3c1 3c3
:3 0 3bb 3c5 3c4
:2 0 64 :3 0 65
:3 0 3c7 3c8 0
64 :3 0 75 :3 0
3ca 3cb 0 7c
:2 0 2 :4 0 8a
:2 0 77 :2 0 23
:2 0 1fe 3d0 3d2
:3 0 201 3cc 3d4
3c9 3d6 3d5 :2 0
67 :3 0 78 :3 0
3d8 3d9 0 69
:4 0 8b :4 0 6c
:2 0 6d :3 0 205
3dd 3df :3 0 6c
:2 0 7f :4 0 208
3e1 3e3 :3 0 6c
:2 0 80 :4 0 20b
3e5 3e7 :3 0 6c
:2 0 71 :3 0 72
:3 0 81 :3 0 8c
:3 0 3ec 3ed 0
20e 3eb 3ef 73
:4 0 210 3ea 3f2
213 3e9 3f4 :3 0
216 3da 3f6 :2 0
3f8 219 3f9 3d7
3f8 0 3fa 21b
0 423 64 :3 0
65 :3 0 3fb 3fc
0 64 :3 0 75
:3 0 3fe 3ff 0
23 :2 0 2 :4 0
8d :2 0 77 :2 0
23 :2 0 21d 404
406 :3 0 220 400
408 3fd 40a 409
:2 0 67 :3 0 78
:3 0 40c 40d 0
69 :4 0 8e :4 0
6c :2 0 6d :3 0
224 411 413 :3 0
227 40e 415 :2 0
417 22a 418 40b
417 0 419 22c
0 423 85 :3 0
86 :3 0 41a 41b
0 81 :3 0 8c
:3 0 41d 41e 0
87 :3 0 22e 41c
421 :2 0 423 231
424 3c6 423 0
425 235 0 2002
71 :3 0 32 :3 0
31 :2 0 237 426
429 81 :3 0 8f
:2 0 90 :3 0 42b
42d 0 23c 42c
42f :3 0 430 :2 0
5 :3 0 91 :2 0
23f 433 434 :3 0
435 :2 0 436 :2 0
431 438 437 :2 0
6 :3 0 91 :2 0
241 43b 43c :3 0
43d :2 0 43e :2 0
439 440 43f :2 0
92 :3 0 93 :3 0
6 :3 0 92 :3 0
93 :3 0 5 :3 0
45 :3 0 94 :4 0
95 1 :8 0 450
15 :3 0 96 :3 0
44b 44c 0 97
:3 0 44d 44e 0
450 243 4a3 98
:3 0 15 :3 0 96
:3 0 452 453 0
97 :3 0 454 455
0 457 246 459
248 458 457 :2 0
4a1 99 :3 0 15
:3 0 96 :3 0 45c
45d 0 97 :3 0
45e 45f 0 499
64 :3 0 65 :3 0
461 462 0 64
:3 0 75 :3 0 464
465 0 9a :2 0
2 :4 0 9b :2 0
77 :2 0 23 :2 0
24a 46a 46c :3 0
24d 466 46e 463
470 46f :2 0 67
:3 0 78 :3 0 472
473 0 69 :4 0
9c :4 0 6c :2 0
6d :3 0 251 477
479 :3 0 6c :2 0
7f :4 0 254 47b
47d :3 0 6c :2 0
9d :4 0 257 47f
481 :3 0 6c :2 0
97 :3 0 25a 483
485 :3 0 6c :2 0
9e :4 0 25d 487
489 :3 0 6c :2 0
9f :3 0 a0 :3 0
23 :2 0 a1 :2 0
260 48c 490 264
48b 492 :3 0 267
474 494 :2 0 496
26a 497 471 496
0 498 26c 0
499 26e 49c :3 0
49c 0 49c 49b
499 49a :6 0 49e
2 :3 0 271 4a0
273 49f 49e :2 0
4a1 275 :2 0 4a3
0 4a3 4a2 450
4a1 :6 0 51e 1
:3 0 15 :3 0 96
:3 0 4a5 4a6 0
15 :3 0 88 :2 0
a2 :3 0 4a8 4aa
0 27a 4a9 4ac
:3 0 4ad :2 0 71
:3 0 45 :3 0 31
:2 0 27d 4af 4b2
a3 :2 0 31 :2 0
282 4b4 4b6 :3 0
4b7 :2 0 4ae 4b9
4b8 :2 0 64 :3 0
65 :3 0 4bb 4bc
0 64 :3 0 75
:3 0 4be 4bf 0
7c :2 0 2 :4 0
a4 :2 0 77 :2 0
23 :2 0 285 4c4
4c6 :3 0 288 4c0
4c8 4bd 4ca 4c9
:2 0 67 :3 0 78
:3 0 4cc 4cd 0
69 :4 0 a5 :4 0
6c :2 0 6d :3 0
28c 4d1 4d3 :3 0
6c :2 0 7f :4 0
28f 4d5 4d7 :3 0
6c :2 0 80 :4 0
292 4d9 4db :3 0
6c :2 0 71 :3 0
72 :3 0 81 :3 0
a6 :3 0 4e0 4e1
0 295 4df 4e3
73 :4 0 297 4de
4e6 29a 4dd 4e8
:3 0 29d 4ce 4ea
:2 0 4ec 2a0 4ed
4cb 4ec 0 4ee
2a2 0 517 64
:3 0 65 :3 0 4ef
4f0 0 64 :3 0
75 :3 0 4f2 4f3
0 23 :2 0 2
:4 0 a7 :2 0 77
:2 0 23 :2 0 2a4
4f8 4fa :3 0 2a7
4f4 4fc 4f1 4fe
4fd :2 0 67 :3 0
78 :3 0 500 501
0 69 :4 0 a8
:4 0 6c :2 0 6d
:3 0 2ab 505 507
:3 0 2ae 502 509
:2 0 50b 2b1 50c
4ff 50b 0 50d
2b3 0 517 85
:3 0 86 :3 0 50e
50f 0 81 :3 0
a6 :3 0 511 512
0 87 :3 0 2b5
510 515 :2 0 517
2b8 518 4ba 517
0 519 2bc 0
51e 61 :3 0 23
:2 0 51a 51b 0
51e a9 :3 0 2be
58d 5 :3 0 7b
:2 0 2c2 520 521
:3 0 522 :2 0 523
:2 0 6 :3 0 7b
:2 0 2c4 526 527
:3 0 528 :2 0 529
:2 0 524 52b 52a
:2 0 6d :3 0 1c
:3 0 94 :4 0 aa
1 :8 0 536 15
:3 0 96 :3 0 531
532 0 97 :3 0
533 534 0 536
2c6 589 98 :3 0
15 :3 0 96 :3 0
538 539 0 97
:3 0 53a 53b 0
53d 2c9 53f 2cb
53e 53d :2 0 587
99 :3 0 15 :3 0
96 :3 0 542 543
0 97 :3 0 544
545 0 57f 64
:3 0 65 :3 0 547
548 0 64 :3 0
75 :3 0 54a 54b
0 9a :2 0 2
:4 0 ab :2 0 77
:2 0 23 :2 0 2cd
550 552 :3 0 2d0
54c 554 549 556
555 :2 0 67 :3 0
78 :3 0 558 559
0 69 :4 0 ac
:4 0 6c :2 0 6d
:3 0 2d4 55d 55f
:3 0 6c :2 0 7f
:4 0 2d7 561 563
:3 0 6c :2 0 9d
:4 0 2da 565 567
:3 0 6c :2 0 97
:3 0 2dd 569 56b
:3 0 6c :2 0 9e
:4 0 2e0 56d 56f
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 2e3
572 576 2e7 571
578 :3 0 2ea 55a
57a :2 0 57c 2ed
57d 557 57c 0
57e 2ef 0 57f
2f1 582 :3 0 582
0 582 581 57f
580 :6 0 584 4
:3 0 2f4 586 2f6
585 584 :2 0 587
2f8 :2 0 589 0
589 588 536 587
:6 0 58b 1 :3 0
2fb 58c 52c 58b
0 58e 441 51e
0 58e 2fd 0
2002 36 :3 0 ad
:3 0 ae :3 0 590
591 0 af :3 0
71 :3 0 3c :3 0
31 :2 0 300 594
597 81 :3 0 b0
:3 0 599 59a 0
303 593 59c 59d
:2 0 b1 :2 0 306
592 5a0 58f 5a1
0 2002 3c :3 0
af :3 0 71 :3 0
3c :3 0 31 :2 0
309 5a5 5a8 81
:3 0 b2 :3 0 5aa
5ab 0 30c 5a4
5ad 5ae :2 0 5a3
5af 0 2002 71
:3 0 3c :3 0 31
:2 0 30f 5b1 5b4
81 :3 0 88 :2 0
b3 :3 0 5b6 5b8
0 314 5b7 5ba
:3 0 3c :3 0 9a
:2 0 5bc 5bd 0
5bf 317 5c0 5bb
5bf 0 5c1 319
0 2002 71 :3 0
33 :3 0 31 :2 0
31b 5c2 5c5 88
:2 0 31 :2 0 320
5c7 5c9 :3 0 71
:3 0 b4 :3 0 71
:3 0 b5 :3 0 b6
:3 0 3f :3 0 40
:3 0 47 :3 0 b7
:3 0 b8 :3 0 17
:4 0 b9 1 :8 0
5dc 15 :3 0 96
:3 0 5d7 5d8 0
97 :3 0 5d9 5da
0 5dc 323 62f
98 :3 0 15 :3 0
96 :3 0 5de 5df
0 97 :3 0 5e0
5e1 0 5e3 326
5e5 328 5e4 5e3
:2 0 62d 99 :3 0
15 :3 0 96 :3 0
5e8 5e9 0 97
:3 0 5ea 5eb 0
625 64 :3 0 65
:3 0 5ed 5ee 0
64 :3 0 75 :3 0
5f0 5f1 0 9a
:2 0 2 :4 0 ba
:2 0 77 :2 0 23
:2 0 32a 5f6 5f8
:3 0 32d 5f2 5fa
5ef 5fc 5fb :2 0
67 :3 0 78 :3 0
5fe 5ff 0 69
:4 0 bb :4 0 6c
:2 0 6d :3 0 331
603 605 :3 0 6c
:2 0 7f :4 0 334
607 609 :3 0 6c
:2 0 9d :4 0 337
60b 60d :3 0 6c
:2 0 97 :3 0 33a
60f 611 :3 0 6c
:2 0 9e :4 0 33d
613 615 :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 340 618 61c
344 617 61e :3 0
347 600 620 :2 0
622 34a 623 5fd
622 0 624 34c
0 625 34e 628
:3 0 628 0 628
627 625 626 :6 0
62a 6 :3 0 351
62c 353 62b 62a
:2 0 62d 355 :2 0
62f 0 62f 62e
5dc 62d :6 0 863
1 :3 0 15 :3 0
96 :3 0 631 632
0 15 :3 0 88
:2 0 bc :3 0 634
636 0 35a 635
638 :3 0 639 :2 0
3f :3 0 40 :3 0
47 :3 0 bd :3 0
b8 :3 0 17 :4 0
be 1 :8 0 647
15 :3 0 96 :3 0
642 643 0 97
:3 0 644 645 0
647 35d 69a 98
:3 0 15 :3 0 96
:3 0 649 64a 0
97 :3 0 64b 64c
0 64e 360 650
362 64f 64e :2 0
698 99 :3 0 15
:3 0 96 :3 0 653
654 0 97 :3 0
655 656 0 690
64 :3 0 65 :3 0
658 659 0 64
:3 0 75 :3 0 65b
65c 0 9a :2 0
2 :4 0 bf :2 0
77 :2 0 23 :2 0
364 661 663 :3 0
367 65d 665 65a
667 666 :2 0 67
:3 0 78 :3 0 669
66a 0 69 :4 0
c0 :4 0 6c :2 0
6d :3 0 36b 66e
670 :3 0 6c :2 0
7f :4 0 36e 672
674 :3 0 6c :2 0
9d :4 0 371 676
678 :3 0 6c :2 0
97 :3 0 374 67a
67c :3 0 6c :2 0
9e :4 0 377 67e
680 :3 0 6c :2 0
9f :3 0 a0 :3 0
23 :2 0 a1 :2 0
37a 683 687 37e
682 689 :3 0 381
66b 68b :2 0 68d
384 68e 668 68d
0 68f 386 0
690 388 693 :3 0
693 0 693 692
690 691 :6 0 695
8 :3 0 38b 697
38d 696 695 :2 0
698 38f :2 0 69a
0 69a 699 647
698 :6 0 716 1
:3 0 15 :3 0 96
:3 0 69c 69d 0
15 :3 0 88 :2 0
bc :3 0 69f 6a1
0 394 6a0 6a3
:3 0 6a4 :2 0 64
:3 0 65 :3 0 6a6
6a7 0 64 :3 0
75 :3 0 6a9 6aa
0 18 :2 0 2
:4 0 2f :2 0 77
:2 0 23 :2 0 397
6af 6b1 :3 0 39a
6ab 6b3 6a8 6b5
6b4 :2 0 67 :3 0
78 :3 0 6b7 6b8
0 69 :4 0 c1
:4 0 6c :2 0 6d
:3 0 39e 6bc 6be
:3 0 6c :2 0 7f
:4 0 3a1 6c0 6c2
:3 0 6c :2 0 80
:4 0 3a4 6c4 6c6
:3 0 6c :2 0 71
:3 0 72 :3 0 81
:3 0 8c :3 0 6cb
6cc 0 3a7 6ca
6ce 73 :4 0 3a9
6c9 6d1 3ac 6c8
6d3 :3 0 6c :2 0
c2 :4 0 3af 6d5
6d7 :3 0 6c :2 0
6f :4 0 3b2 6d9
6db :3 0 6c :2 0
17 :3 0 3b5 6dd
6df :3 0 6c :2 0
6f :4 0 3b8 6e1
6e3 :3 0 3bb 6b9
6e5 :2 0 6e7 3be
6e8 6b6 6e7 0
6e9 3c0 0 713
64 :3 0 65 :3 0
6ea 6eb 0 64
:3 0 75 :3 0 6ed
6ee 0 23 :2 0
2 :4 0 c3 :2 0
77 :2 0 23 :2 0
3c2 6f3 6f5 :3 0
3c5 6ef 6f7 6ec
6f9 6f8 :2 0 67
:3 0 78 :3 0 6fb
6fc 0 69 :4 0
c4 :4 0 6c :2 0
6d :3 0 3c9 700
702 :3 0 3cc 6fd
704 :2 0 706 3cf
707 6fa 706 0
708 3d1 0 713
85 :3 0 c5 :3 0
709 70a 0 81
:3 0 8c :3 0 70c
70d 0 17 :3 0
87 :3 0 3d3 70b
711 :2 0 713 3d7
714 6a5 713 0
715 3db 0 716
3dd 717 63a 716
0 718 3e0 0
863 5c :3 0 31
:2 0 719 71a 0
863 c6 :3 0 5c
:3 0 c7 :3 0 c8
:3 0 17 :4 0 c9
1 :8 0 727 15
:3 0 96 :3 0 722
723 0 97 :3 0
724 725 0 727
3e2 77a 98 :3 0
15 :3 0 96 :3 0
729 72a 0 97
:3 0 72b 72c 0
72e 3e5 730 3e7
72f 72e :2 0 778
99 :3 0 15 :3 0
96 :3 0 733 734
0 97 :3 0 735
736 0 770 64
:3 0 65 :3 0 738
739 0 64 :3 0
75 :3 0 73b 73c
0 9a :2 0 2
:4 0 ca :2 0 77
:2 0 23 :2 0 3e9
741 743 :3 0 3ec
73d 745 73a 747
746 :2 0 67 :3 0
78 :3 0 749 74a
0 69 :4 0 cb
:4 0 6c :2 0 6d
:3 0 3f0 74e 750
:3 0 6c :2 0 7f
:4 0 3f3 752 754
:3 0 6c :2 0 9d
:4 0 3f6 756 758
:3 0 6c :2 0 97
:3 0 3f9 75a 75c
:3 0 6c :2 0 9e
:4 0 3fc 75e 760
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 3ff
763 767 403 762
769 :3 0 406 74b
76b :2 0 76d 409
76e 748 76d 0
76f 40b 0 770
40d 773 :3 0 773
0 773 772 770
771 :6 0 775 a
:3 0 410 777 412
776 775 :2 0 778
414 :2 0 77a 0
77a 779 727 778
:6 0 863 1 :3 0
71 :3 0 5c :3 0
31 :2 0 417 77c
77f cc :2 0 31
:2 0 41c 781 783
:3 0 cd :3 0 22
:3 0 b7 :3 0 b8
:3 0 17 :4 0 ce
1 :8 0 790 15
:3 0 96 :3 0 78b
78c 0 97 :3 0
78d 78e 0 790
41f 7e3 98 :3 0
15 :3 0 96 :3 0
792 793 0 97
:3 0 794 795 0
797 422 799 424
798 797 :2 0 7e1
99 :3 0 15 :3 0
96 :3 0 79c 79d
0 97 :3 0 79e
79f 0 7d9 64
:3 0 65 :3 0 7a1
7a2 0 64 :3 0
75 :3 0 7a4 7a5
0 9a :2 0 2
:4 0 cf :2 0 77
:2 0 23 :2 0 426
7aa 7ac :3 0 429
7a6 7ae 7a3 7b0
7af :2 0 67 :3 0
78 :3 0 7b2 7b3
0 69 :4 0 d0
:4 0 6c :2 0 6d
:3 0 42d 7b7 7b9
:3 0 6c :2 0 7f
:4 0 430 7bb 7bd
:3 0 6c :2 0 9d
:4 0 433 7bf 7c1
:3 0 6c :2 0 97
:3 0 436 7c3 7c5
:3 0 6c :2 0 9e
:4 0 439 7c7 7c9
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 43c
7cc 7d0 440 7cb
7d2 :3 0 443 7b4
7d4 :2 0 7d6 446
7d7 7b1 7d6 0
7d8 448 0 7d9
44a 7dc :3 0 7dc
0 7dc 7db 7d9
7da :6 0 7de c
:3 0 44d 7e0 44f
7df 7de :2 0 7e1
451 :2 0 7e3 0
7e3 7e2 790 7e1
:6 0 860 1 :3 0
92 :3 0 d1 :3 0
7e5 7e6 0 22
:3 0 d2 :4 0 454
7e7 7ea 88 :2 0
31 :2 0 459 7ec
7ee :3 0 64 :3 0
65 :3 0 7f0 7f1
0 64 :3 0 75
:3 0 7f3 7f4 0
18 :2 0 2 :4 0
d3 :2 0 77 :2 0
23 :2 0 45c 7f9
7fb :3 0 45f 7f5
7fd 7f2 7ff 7fe
:2 0 67 :3 0 78
:3 0 801 802 0
69 :4 0 d4 :4 0
6c :2 0 6d :3 0
463 806 808 :3 0
6c :2 0 7f :4 0
466 80a 80c :3 0
6c :2 0 80 :4 0
469 80e 810 :3 0
6c :2 0 71 :3 0
72 :3 0 81 :3 0
d5 :3 0 815 816
0 46c 814 818
73 :4 0 46e 813
81b 471 812 81d
:3 0 6c :2 0 c2
:4 0 474 81f 821
:3 0 6c :2 0 6f
:4 0 477 823 825
:3 0 6c :2 0 17
:3 0 47a 827 829
:3 0 6c :2 0 6f
:4 0 47d 82b 82d
:3 0 480 803 82f
:2 0 831 483 832
800 831 0 833
485 0 85d 64
:3 0 65 :3 0 834
835 0 64 :3 0
75 :3 0 837 838
0 23 :2 0 2
:4 0 d6 :2 0 77
:2 0 23 :2 0 487
83d 83f :3 0 48a
839 841 836 843
842 :2 0 67 :3 0
78 :3 0 845 846
0 69 :4 0 d7
:4 0 6c :2 0 6d
:3 0 48e 84a 84c
:3 0 491 847 84e
:2 0 850 494 851
844 850 0 852
496 0 85d 85
:3 0 c5 :3 0 853
854 0 81 :3 0
d5 :3 0 856 857
0 17 :3 0 87
:3 0 498 855 85b
:2 0 85d 49c 85e
7ef 85d 0 85f
4a0 0 860 4a2
861 784 860 0
862 4a5 0 863
4a7 a4f 12 :3 0
7b :2 0 4ad 865
866 :3 0 867 :2 0
64 :3 0 65 :3 0
869 86a 0 64
:3 0 75 :3 0 86c
86d 0 7c :2 0
2 :4 0 d8 :2 0
77 :2 0 23 :2 0
4af 872 874 :3 0
4b2 86e 876 86b
878 877 :2 0 67
:3 0 78 :3 0 87a
87b 0 69 :4 0
d9 :4 0 6c :2 0
6d :3 0 4b6 87f
881 :3 0 6c :2 0
7f :4 0 4b9 883
885 :3 0 6c :2 0
80 :4 0 4bc 887
889 :3 0 6c :2 0
71 :3 0 72 :3 0
81 :3 0 82 :3 0
88e 88f 0 4bf
88d 891 73 :4 0
4c1 88c 894 4c4
88b 896 :3 0 4c7
87c 898 :2 0 89a
4ca 89b 879 89a
0 89c 4cc 0
8c5 64 :3 0 65
:3 0 89d 89e 0
64 :3 0 75 :3 0
8a0 8a1 0 23
:2 0 2 :4 0 da
:2 0 77 :2 0 23
:2 0 4ce 8a6 8a8
:3 0 4d1 8a2 8aa
89f 8ac 8ab :2 0
67 :3 0 78 :3 0
8ae 8af 0 69
:4 0 db :4 0 6c
:2 0 6d :3 0 4d5
8b3 8b5 :3 0 4d8
8b0 8b7 :2 0 8b9
4db 8ba 8ad 8b9
0 8bb 4dd 0
8c5 85 :3 0 86
:3 0 8bc 8bd 0
81 :3 0 82 :3 0
8bf 8c0 0 87
:3 0 4df 8be 8c3
:2 0 8c5 4e2 8c6
868 8c5 0 8c7
4e6 0 a4e 28
:3 0 12 :3 0 8c8
8c9 0 a4e 1b
:3 0 9f :3 0 9f
:3 0 28 :3 0 23
:2 0 18 :2 0 4e8
8cd 8d1 23 :2 0
18 :2 0 4ec 8cc
8d5 8cb 8d6 0
a4e 24 :3 0 dc
:3 0 dd :3 0 8d9
8da 0 23 :2 0
23 :2 0 de :2 0
28 :3 0 4f0 8db
8e0 8d8 8e1 0
a4e df :3 0 71
:3 0 33 :3 0 31
:2 0 4f5 8e4 8e7
4f8 8e3 8e9 8f
:2 0 31 :2 0 4fc
8eb 8ed :3 0 c8
:3 0 71 :3 0 b4
:3 0 71 :3 0 b5
:3 0 b6 :3 0 17
:3 0 3f :3 0 40
:3 0 47 :3 0 b7
:3 0 b8 :3 0 19
:3 0 e0 :3 0 81
:3 0 e1 :3 0 81
:3 0 e2 :3 0 81
:3 0 e3 :3 0 81
:3 0 e4 :3 0 81
:3 0 e5 :4 0 e6
1 :8 0 90d 15
:3 0 96 :3 0 908
909 0 97 :3 0
90a 90b 0 90d
4ff 960 98 :3 0
15 :3 0 96 :3 0
90f 910 0 97
:3 0 911 912 0
914 502 916 504
915 914 :2 0 95e
99 :3 0 15 :3 0
96 :3 0 919 91a
0 97 :3 0 91b
91c 0 956 64
:3 0 65 :3 0 91e
91f 0 64 :3 0
75 :3 0 921 922
0 9a :2 0 2
:4 0 e7 :2 0 77
:2 0 23 :2 0 506
927 929 :3 0 509
923 92b 920 92d
92c :2 0 67 :3 0
78 :3 0 92f 930
0 69 :4 0 e8
:4 0 6c :2 0 6d
:3 0 50d 934 936
:3 0 6c :2 0 7f
:4 0 510 938 93a
:3 0 6c :2 0 9d
:4 0 513 93c 93e
:3 0 6c :2 0 97
:3 0 516 940 942
:3 0 6c :2 0 9e
:4 0 519 944 946
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 51c
949 94d 520 948
94f :3 0 523 931
951 :2 0 953 526
954 92e 953 0
955 528 0 956
52a 959 :3 0 959
0 959 958 956
957 :6 0 95b e
:3 0 52d 95d 52f
95c 95b :2 0 95e
531 :2 0 960 0
960 95f 90d 95e
:6 0 9dc 1 :3 0
15 :3 0 96 :3 0
962 963 0 15
:3 0 88 :2 0 bc
:3 0 965 967 0
536 966 969 :3 0
96a :2 0 64 :3 0
65 :3 0 96c 96d
0 64 :3 0 75
:3 0 96f 970 0
18 :2 0 2 :4 0
e9 :2 0 77 :2 0
23 :2 0 539 975
977 :3 0 53c 971
979 96e 97b 97a
:2 0 67 :3 0 78
:3 0 97d 97e 0
69 :4 0 ea :4 0
6c :2 0 6d :3 0
540 982 984 :3 0
6c :2 0 7f :4 0
543 986 988 :3 0
6c :2 0 80 :4 0
546 98a 98c :3 0
6c :2 0 71 :3 0
72 :3 0 81 :3 0
eb :3 0 991 992
0 549 990 994
73 :4 0 54b 98f
997 54e 98e 999
:3 0 6c :2 0 c2
:4 0 551 99b 99d
:3 0 6c :2 0 6f
:4 0 554 99f 9a1
:3 0 6c :2 0 19
:3 0 557 9a3 9a5
:3 0 6c :2 0 6f
:4 0 55a 9a7 9a9
:3 0 55d 97f 9ab
:2 0 9ad 560 9ae
97c 9ad 0 9af
562 0 9d9 64
:3 0 65 :3 0 9b0
9b1 0 64 :3 0
75 :3 0 9b3 9b4
0 23 :2 0 2
:4 0 ec :2 0 77
:2 0 23 :2 0 564
9b9 9bb :3 0 567
9b5 9bd 9b2 9bf
9be :2 0 67 :3 0
78 :3 0 9c1 9c2
0 69 :4 0 ed
:4 0 6c :2 0 6d
:3 0 56b 9c6 9c8
:3 0 56e 9c3 9ca
:2 0 9cc 571 9cd
9c0 9cc 0 9ce
573 0 9d9 85
:3 0 c5 :3 0 9cf
9d0 0 81 :3 0
eb :3 0 9d2 9d3
0 19 :3 0 87
:3 0 575 9d1 9d7
:2 0 9d9 579 9da
96b 9d9 0 9db
57d 0 9dc 57f
a4b 64 :3 0 65
:3 0 9dd 9de 0
64 :3 0 75 :3 0
9e0 9e1 0 18
:2 0 2 :4 0 ee
:2 0 77 :2 0 23
:2 0 582 9e6 9e8
:3 0 585 9e2 9ea
9df 9ec 9eb :2 0
67 :3 0 78 :3 0
9ee 9ef 0 69
:4 0 ef :4 0 6c
:2 0 6d :3 0 589
9f3 9f5 :3 0 6c
:2 0 7f :4 0 58c
9f7 9f9 :3 0 6c
:2 0 80 :4 0 58f
9fb 9fd :3 0 6c
:2 0 71 :3 0 72
:3 0 81 :3 0 eb
:3 0 a02 a03 0
592 a01 a05 73
:4 0 594 a00 a08
597 9ff a0a :3 0
6c :2 0 c2 :4 0
59a a0c a0e :3 0
6c :2 0 6f :4 0
59d a10 a12 :3 0
6c :2 0 19 :3 0
5a0 a14 a16 :3 0
6c :2 0 6f :4 0
5a3 a18 a1a :3 0
5a6 9f0 a1c :2 0
a1e 5a9 a1f 9ed
a1e 0 a20 5ab
0 a4a 64 :3 0
65 :3 0 a21 a22
0 64 :3 0 75
:3 0 a24 a25 0
23 :2 0 2 :4 0
f0 :2 0 77 :2 0
23 :2 0 5ad a2a
a2c :3 0 5b0 a26
a2e a23 a30 a2f
:2 0 67 :3 0 78
:3 0 a32 a33 0
69 :4 0 f1 :4 0
6c :2 0 6d :3 0
5b4 a37 a39 :3 0
5b7 a34 a3b :2 0
a3d 5ba a3e a31
a3d 0 a3f 5bc
0 a4a 85 :3 0
c5 :3 0 a40 a41
0 81 :3 0 eb
:3 0 a43 a44 0
19 :3 0 87 :3 0
5be a42 a48 :2 0
a4a 5c2 a4c 8ee
9dc 0 a4d 0
a4a 0 a4d 5c6
0 a4e 5c9 a50
5ca 863 0 a51
0 a4e 0 a51
5cf 0 2002 71
:3 0 d :3 0 31
:2 0 5d2 a52 a55
88 :2 0 31 :2 0
5d7 a57 a59 :3 0
a5a :2 0 71 :3 0
3b :3 0 31 :2 0
5da a5c a5f 8f
:2 0 f2 :2 0 5df
a61 a63 :3 0 a64
:2 0 a5b a66 a65
:2 0 37 :3 0 31
:2 0 a68 a69 0
a6b 5e2 a6c a67
a6b 0 a6d 5e4
0 2002 61 :3 0
88 :2 0 31 :2 0
5e8 a6f a71 :3 0
1e :3 0 5 :3 0
a73 a74 0 b8f
1f :3 0 f3 :4 0
a76 a77 0 b8f
5c :3 0 f4 :3 0
1e :3 0 1f :3 0
71 :3 0 3a :3 0
31 :2 0 5eb a7d
a80 71 :3 0 3b
:3 0 31 :2 0 5ee
a82 a85 71 :3 0
3c :3 0 31 :2 0
5f1 a87 a8a 71
:3 0 32 :3 0 31
:2 0 5f4 a8c a8f
71 :3 0 3d :3 0
31 :2 0 5f7 a91
a94 71 :3 0 38
:3 0 31 :2 0 5fa
a96 a99 71 :3 0
3f :3 0 31 :2 0
5fd a9b a9e 71
:3 0 40 :3 0 31
:2 0 600 aa0 aa3
37 :3 0 39 :3 0
43 :3 0 603 a7a
aa8 a79 aa9 0
b8f 71 :3 0 5c
:3 0 31 :2 0 611
aab aae 81 :3 0
88 :2 0 8c :3 0
ab0 ab2 0 616
ab1 ab4 :3 0 64
:3 0 65 :3 0 ab6
ab7 0 64 :3 0
75 :3 0 ab9 aba
0 7c :2 0 2
:4 0 f5 :2 0 77
:2 0 23 :2 0 619
abf ac1 :3 0 61c
abb ac3 ab8 ac5
ac4 :2 0 67 :3 0
78 :3 0 ac7 ac8
0 69 :4 0 f6
:4 0 6c :2 0 6d
:3 0 620 acc ace
:3 0 6c :2 0 7f
:4 0 623 ad0 ad2
:3 0 6c :2 0 80
:4 0 626 ad4 ad6
:3 0 6c :2 0 71
:3 0 72 :3 0 81
:3 0 8c :3 0 adb
adc 0 629 ada
ade 73 :4 0 62b
ad9 ae1 62e ad8
ae3 :3 0 631 ac9
ae5 :2 0 ae7 634
ae8 ac6 ae7 0
ae9 636 0 b13
64 :3 0 65 :3 0
aea aeb 0 64
:3 0 75 :3 0 aed
aee 0 23 :2 0
2 :4 0 f7 :2 0
77 :2 0 23 :2 0
638 af3 af5 :3 0
63b aef af7 aec
af9 af8 :2 0 67
:3 0 78 :3 0 afb
afc 0 69 :4 0
f8 :4 0 6c :2 0
6d :3 0 63f b00
b02 :3 0 642 afd
b04 :2 0 b06 645
b07 afa b06 0
b08 647 0 b13
85 :3 0 86 :3 0
b09 b0a 0 81
:3 0 8c :3 0 b0c
b0d 0 87 :3 0
649 b0b b10 :2 0
b13 a9 :3 0 64c
b8c 71 :3 0 5c
:3 0 31 :2 0 650
b14 b17 8f :2 0
31 :2 0 655 b19
b1b :3 0 64 :3 0
65 :3 0 b1d b1e
0 64 :3 0 75
:3 0 b20 b21 0
18 :2 0 2 :4 0
f9 :2 0 77 :2 0
23 :2 0 658 b26
b28 :3 0 65b b22
b2a b1f b2c b2b
:2 0 67 :3 0 78
:3 0 b2e b2f 0
69 :4 0 fa :4 0
6c :2 0 6d :3 0
65f b33 b35 :3 0
6c :2 0 7f :4 0
662 b37 b39 :3 0
6c :2 0 80 :4 0
665 b3b b3d :3 0
6c :2 0 71 :3 0
72 :3 0 5c :3 0
668 b41 b43 73
:4 0 66a b40 b46
66d b3f b48 :3 0
6c :2 0 c2 :4 0
670 b4a b4c :3 0
6c :2 0 6f :4 0
673 b4e b50 :3 0
6c :2 0 17 :3 0
676 b52 b54 :3 0
6c :2 0 6f :4 0
679 b56 b58 :3 0
67c b30 b5a :2 0
b5c 67f b5d b2d
b5c 0 b5e 681
0 b8a 64 :3 0
65 :3 0 b5f b60
0 64 :3 0 75
:3 0 b62 b63 0
23 :2 0 2 :4 0
fb :2 0 77 :2 0
23 :2 0 683 b68
b6a :3 0 686 b64
b6c b61 b6e b6d
:2 0 67 :3 0 78
:3 0 b70 b71 0
69 :4 0 fc :4 0
6c :2 0 6d :3 0
68a b75 b77 :3 0
68d b72 b79 :2 0
b7b 690 b7c b6f
b7b 0 b7d 692
0 b8a 85 :3 0
c5 :3 0 b7e b7f
0 71 :3 0 5c
:3 0 31 :2 0 694
b81 b84 17 :3 0
87 :3 0 697 b80
b88 :2 0 b8a 69b
b8b b1c b8a 0
b8d ab5 b13 0
b8d 69f 0 b8f
a9 :3 0 6a2 c36
71 :3 0 43 :3 0
31 :2 0 6a7 b90
b93 cc :2 0 31
:2 0 6ac b95 b97
:3 0 71 :3 0 43
:3 0 31 :2 0 6af
b99 b9c cc :2 0
fd :2 0 6b4 b9e
ba0 :3 0 64 :3 0
65 :3 0 ba2 ba3
0 64 :3 0 75
:3 0 ba5 ba6 0
18 :2 0 2 :4 0
fe :2 0 77 :2 0
23 :2 0 6b7 bab
bad :3 0 6ba ba7
baf ba4 bb1 bb0
:2 0 67 :3 0 78
:3 0 bb3 bb4 0
69 :4 0 ff :4 0
6c :2 0 6d :3 0
6be bb8 bba :3 0
6c :2 0 7f :4 0
6c1 bbc bbe :3 0
6c :2 0 80 :4 0
6c4 bc0 bc2 :3 0
6c :2 0 71 :3 0
72 :3 0 81 :3 0
100 :3 0 bc7 bc8
0 6c7 bc6 bca
73 :4 0 6c9 bc5
bcd 6cc bc4 bcf
:3 0 6c :2 0 c2
:4 0 6cf bd1 bd3
:3 0 6c :2 0 6f
:4 0 6d2 bd5 bd7
:3 0 6c :2 0 17
:3 0 6d5 bd9 bdb
:3 0 6c :2 0 6f
:4 0 6d8 bdd bdf
:3 0 6db bb5 be1
:2 0 be3 6de be4
bb2 be3 0 be5
6e0 0 c0f 64
:3 0 65 :3 0 be6
be7 0 64 :3 0
75 :3 0 be9 bea
0 23 :2 0 2
:4 0 101 :2 0 77
:2 0 23 :2 0 6e2
bef bf1 :3 0 6e5
beb bf3 be8 bf5
bf4 :2 0 67 :3 0
78 :3 0 bf7 bf8
0 69 :4 0 102
:4 0 6c :2 0 6d
:3 0 6e9 bfc bfe
:3 0 6ec bf9 c00
:2 0 c02 6ef c03
bf6 c02 0 c04
6f1 0 c0f 85
:3 0 c5 :3 0 c05
c06 0 81 :3 0
100 :3 0 c08 c09
0 17 :3 0 87
:3 0 6f3 c07 c0d
:2 0 c0f 6f7 c10
ba1 c0f 0 c11
6fb 0 c34 71
:3 0 43 :3 0 31
:2 0 6fd c12 c15
a3 :2 0 b1 :2 0
702 c17 c19 :3 0
43 :3 0 103 :2 0
c1b c1c 0 c1e
705 c31 43 :3 0
104 :3 0 105 :3 0
71 :3 0 43 :3 0
31 :2 0 707 c22
c25 70a c21 c27
106 :2 0 107 :2 0
70c c29 c2b :3 0
70f c20 c2d c1f
c2e 0 c30 711
c32 c1a c1e 0
c33 0 c30 0
c33 713 0 c34
716 c35 b98 c34
0 c37 a72 b8f
0 c37 719 0
2002 71 :3 0 37
:3 0 31 :2 0 71c
c38 c3b cc :2 0
31 :2 0 721 c3d
c3f :3 0 c40 :2 0
71 :3 0 3b :3 0
31 :2 0 724 c42
c45 8f :2 0 f2
:2 0 729 c47 c49
:3 0 c4a :2 0 c41
c4c c4b :2 0 71
:3 0 3b :3 0 31
:2 0 72c c4e c51
88 :2 0 23 :2 0
731 c53 c55 :3 0
c56 :2 0 71 :3 0
3b :3 0 31 :2 0
734 c58 c5b 88
:2 0 108 :2 0 739
c5d c5f :3 0 c60
:2 0 c57 c62 c61
:2 0 3a :3 0 108
:2 0 c64 c65 0
c68 a9 :3 0 73c
cb1 71 :3 0 3b
:3 0 31 :2 0 73e
c69 c6c 88 :2 0
31 :2 0 743 c6e
c70 :3 0 3a :3 0
23 :2 0 c72 c73
0 c76 a9 :3 0
746 c77 c71 c76
0 cb2 71 :3 0
3b :3 0 31 :2 0
748 c78 c7b 88
:2 0 109 :2 0 74d
c7d c7f :3 0 c80
:2 0 71 :3 0 3b
:3 0 31 :2 0 750
c82 c85 88 :2 0
10a :2 0 755 c87
c89 :3 0 c8a :2 0
c81 c8c c8b :2 0
3a :3 0 23 :2 0
c8e c8f 0 c92
a9 :3 0 758 c93
c8d c92 0 cb2
71 :3 0 3b :3 0
31 :2 0 75a c94
c97 88 :2 0 89
:2 0 75f c99 c9b
:3 0 37 :3 0 71
:3 0 40 :3 0 31
:2 0 762 c9e ca1
106 :2 0 71 :3 0
37 :3 0 31 :2 0
765 ca4 ca7 768
ca3 ca9 :3 0 c9d
caa 0 caf 3a
:3 0 109 :2 0 cac
cad 0 caf 76b
cb0 c9c caf 0
cb2 c63 c68 0
cb2 76e 0 cb3
773 cb4 c4d cb3
0 cb5 775 0
2002 58 :3 0 10b
:4 0 cb7 cb8 :3 0
cb6 cb9 0 2002
2a :3 0 f3 :4 0
cbb cbc 0 2002
2b :3 0 f3 :4 0
cbe cbf 0 2002
20 :3 0 f3 :4 0
cc1 cc2 0 2002
26 :3 0 f3 :4 0
cc4 cc5 0 2002
1b :3 0 9f :3 0
1b :3 0 23 :2 0
18 :2 0 777 cc8
ccc cc7 ccd 0
2002 24 :3 0 9f
:3 0 24 :3 0 23
:2 0 23 :2 0 77b
cd0 cd4 ccf cd5
0 2002 71 :3 0
33 :3 0 31 :2 0
77f cd7 cda cc
:2 0 31 :2 0 784
cdc cde :3 0 2c
:4 0 ce0 ce1 0
1895 1e :3 0 1c
:3 0 ce3 ce4 0
1895 9f :3 0 24
:3 0 23 :2 0 23
:2 0 787 ce6 cea
88 :2 0 23 :4 0
78d cec cee :3 0
10c :3 0 10d :3 0
9f :3 0 10e :3 0
10d :3 0 9f :3 0
10f :3 0 110 :3 0
111 :3 0 112 :3 0
113 :3 0 27 :3 0
2c :3 0 2d :3 0
4b :3 0 4c :3 0
50 :3 0 52 :3 0
114 :3 0 115 :3 0
17 :3 0 116 :3 0
1b :3 0 117 :3 0
118 :4 0 119 1
:8 0 d0f 15 :3 0
96 :3 0 d0a d0b
0 97 :3 0 d0c
d0d 0 d0f 790
d62 98 :3 0 15
:3 0 96 :3 0 d11
d12 0 97 :3 0
d13 d14 0 d16
793 d18 795 d17
d16 :2 0 d60 99
:3 0 15 :3 0 96
:3 0 d1b d1c 0
97 :3 0 d1d d1e
0 d58 64 :3 0
65 :3 0 d20 d21
0 64 :3 0 75
:3 0 d23 d24 0
9a :2 0 2 :4 0
11a :2 0 77 :2 0
23 :2 0 797 d29
d2b :3 0 79a d25
d2d d22 d2f d2e
:2 0 67 :3 0 78
:3 0 d31 d32 0
69 :4 0 11b :4 0
6c :2 0 6d :3 0
79e d36 d38 :3 0
6c :2 0 7f :4 0
7a1 d3a d3c :3 0
6c :2 0 9d :4 0
7a4 d3e d40 :3 0
6c :2 0 97 :3 0
7a7 d42 d44 :3 0
6c :2 0 9e :4 0
7aa d46 d48 :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 7ad d4b
d4f 7b1 d4a d51
:3 0 7b4 d33 d53
:2 0 d55 7b7 d56
d30 d55 0 d57
7b9 0 d58 7bb
d5b :3 0 d5b 0
d5b d5a d58 d59
:6 0 d5d 10 :3 0
7be d5f 7c0 d5e
d5d :2 0 d60 7c2
:2 0 d62 0 d62
d61 d0f d60 :6 0
ea7 1 :3 0 11c
:3 0 2e :3 0 11d
:3 0 11e :3 0 1b
:4 0 11f 1 :8 0
d6f 15 :3 0 96
:3 0 d6a d6b 0
97 :3 0 d6c d6d
0 d6f 7c5 dc2
98 :3 0 15 :3 0
96 :3 0 d71 d72
0 97 :3 0 d73
d74 0 d76 7c8
d78 7ca d77 d76
:2 0 dc0 99 :3 0
15 :3 0 96 :3 0
d7b d7c 0 97
:3 0 d7d d7e 0
db8 64 :3 0 65
:3 0 d80 d81 0
64 :3 0 75 :3 0
d83 d84 0 9a
:2 0 2 :4 0 120
:2 0 77 :2 0 23
:2 0 7cc d89 d8b
:3 0 7cf d85 d8d
d82 d8f d8e :2 0
67 :3 0 78 :3 0
d91 d92 0 69
:4 0 121 :4 0 6c
:2 0 6d :3 0 7d3
d96 d98 :3 0 6c
:2 0 7f :4 0 7d6
d9a d9c :3 0 6c
:2 0 9d :4 0 7d9
d9e da0 :3 0 6c
:2 0 97 :3 0 7dc
da2 da4 :3 0 6c
:2 0 9e :4 0 7df
da6 da8 :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 7e2 dab daf
7e6 daa db1 :3 0
7e9 d93 db3 :2 0
db5 7ec db6 d90
db5 0 db7 7ee
0 db8 7f0 dbb
:3 0 dbb 0 dbb
dba db8 db9 :6 0
dbd 12 :3 0 7f3
dbf 7f5 dbe dbd
:2 0 dc0 7f7 :2 0
dc2 0 dc2 dc1
d6f dc0 :6 0 ea7
1 :3 0 15 :3 0
96 :3 0 dc4 dc5
0 15 :3 0 88
:2 0 bc :3 0 dc7
dc9 0 7fc dc8
dcb :3 0 dcc :2 0
64 :3 0 65 :3 0
dce dcf 0 64
:3 0 75 :3 0 dd1
dd2 0 18 :2 0
2 :4 0 122 :2 0
77 :2 0 23 :2 0
7ff dd7 dd9 :3 0
802 dd3 ddb dd0
ddd ddc :2 0 67
:3 0 78 :3 0 ddf
de0 0 69 :4 0
123 :4 0 6c :2 0
6d :3 0 806 de4
de6 :3 0 6c :2 0
7f :4 0 809 de8
dea :3 0 6c :2 0
80 :4 0 80c dec
dee :3 0 6c :2 0
71 :3 0 72 :3 0
81 :3 0 eb :3 0
df3 df4 0 80f
df2 df6 73 :4 0
811 df1 df9 814
df0 dfb :3 0 6c
:2 0 c2 :4 0 817
dfd dff :3 0 6c
:2 0 6f :4 0 81a
e01 e03 :3 0 6c
:2 0 1b :3 0 81d
e05 e07 :3 0 6c
:2 0 6f :4 0 820
e09 e0b :3 0 823
de1 e0d :2 0 e0f
826 e10 dde e0f
0 e11 828 0
e3b 64 :3 0 65
:3 0 e12 e13 0
64 :3 0 75 :3 0
e15 e16 0 23
:2 0 2 :4 0 124
:2 0 77 :2 0 23
:2 0 82a e1b e1d
:3 0 82d e17 e1f
e14 e21 e20 :2 0
67 :3 0 78 :3 0
e23 e24 0 69
:4 0 125 :4 0 6c
:2 0 6d :3 0 831
e28 e2a :3 0 834
e25 e2c :2 0 e2e
837 e2f e22 e2e
0 e30 839 0
e3b 85 :3 0 c5
:3 0 e31 e32 0
81 :3 0 eb :3 0
e34 e35 0 1b
:3 0 87 :3 0 83b
e33 e39 :2 0 e3b
83f e3c dcd e3b
0 e3d 843 0
ea7 2b :3 0 1b
:3 0 e3e e3f 0
ea7 126 :3 0 127
:3 0 26 :3 0 44
:3 0 128 :3 0 b8
:3 0 19 :3 0 117
:3 0 116 :3 0 1b
:4 0 129 1 :8 0
e51 15 :3 0 96
:3 0 e4c e4d 0
97 :3 0 e4e e4f
0 e51 845 ea4
98 :3 0 15 :3 0
96 :3 0 e53 e54
0 97 :3 0 e55
e56 0 e58 848
e5a 84a e59 e58
:2 0 ea2 99 :3 0
15 :3 0 96 :3 0
e5d e5e 0 97
:3 0 e5f e60 0
e9a 64 :3 0 65
:3 0 e62 e63 0
64 :3 0 75 :3 0
e65 e66 0 9a
:2 0 2 :4 0 12a
:2 0 77 :2 0 23
:2 0 84c e6b e6d
:3 0 84f e67 e6f
e64 e71 e70 :2 0
67 :3 0 78 :3 0
e73 e74 0 69
:4 0 12b :4 0 6c
:2 0 6d :3 0 853
e78 e7a :3 0 6c
:2 0 7f :4 0 856
e7c e7e :3 0 6c
:2 0 9d :4 0 859
e80 e82 :3 0 6c
:2 0 97 :3 0 85c
e84 e86 :3 0 6c
:2 0 9e :4 0 85f
e88 e8a :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 862 e8d e91
866 e8c e93 :3 0
869 e75 e95 :2 0
e97 86c e98 e72
e97 0 e99 86e
0 e9a 870 e9d
:3 0 e9d 0 e9d
e9c e9a e9b :6 0
e9f 14 :3 0 873
ea1 875 ea0 e9f
:2 0 ea2 877 :2 0
ea4 0 ea4 ea3
e51 ea2 :6 0 ea7
1 :3 0 a9 :3 0
87a 124e 9f :3 0
24 :3 0 23 :2 0
23 :2 0 880 ea8
eac 88 :2 0 31
:4 0 886 eae eb0
:3 0 12c :3 0 2e
:3 0 12d :3 0 116
:3 0 1b :4 0 12e
1 :8 0 ebd 15
:3 0 96 :3 0 eb8
eb9 0 97 :3 0
eba ebb 0 ebd
889 f10 98 :3 0
15 :3 0 96 :3 0
ebf ec0 0 97
:3 0 ec1 ec2 0
ec4 88c ec6 88e
ec5 ec4 :2 0 f0e
99 :3 0 15 :3 0
96 :3 0 ec9 eca
0 97 :3 0 ecb
ecc 0 f06 64
:3 0 65 :3 0 ece
ecf 0 64 :3 0
75 :3 0 ed1 ed2
0 9a :2 0 2
:4 0 12f :2 0 77
:2 0 23 :2 0 890
ed7 ed9 :3 0 893
ed3 edb ed0 edd
edc :2 0 67 :3 0
78 :3 0 edf ee0
0 69 :4 0 130
:4 0 6c :2 0 6d
:3 0 897 ee4 ee6
:3 0 6c :2 0 7f
:4 0 89a ee8 eea
:3 0 6c :2 0 9d
:4 0 89d eec eee
:3 0 6c :2 0 97
:3 0 8a0 ef0 ef2
:3 0 6c :2 0 9e
:4 0 8a3 ef4 ef6
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 8a6
ef9 efd 8aa ef8
eff :3 0 8ad ee1
f01 :2 0 f03 8b0
f04 ede f03 0
f05 8b2 0 f06
8b4 f09 :3 0 f09
0 f09 f08 f06
f07 :6 0 f0b 16
:3 0 8b7 f0d 8b9
f0c f0b :2 0 f0e
8bb :2 0 f10 0
f10 f0f ebd f0e
:6 0 11ef 1 :3 0
15 :3 0 96 :3 0
f12 f13 0 15
:3 0 88 :2 0 bc
:3 0 f15 f17 0
8c0 f16 f19 :3 0
f1a :2 0 64 :3 0
65 :3 0 f1c f1d
0 64 :3 0 75
:3 0 f1f f20 0
18 :2 0 2 :4 0
131 :2 0 77 :2 0
23 :2 0 8c3 f25
f27 :3 0 8c6 f21
f29 f1e f2b f2a
:2 0 67 :3 0 78
:3 0 f2d f2e 0
69 :4 0 132 :4 0
6c :2 0 6d :3 0
8ca f32 f34 :3 0
6c :2 0 7f :4 0
8cd f36 f38 :3 0
6c :2 0 80 :4 0
8d0 f3a f3c :3 0
6c :2 0 71 :3 0
72 :3 0 81 :3 0
eb :3 0 f41 f42
0 8d3 f40 f44
73 :4 0 8d5 f3f
f47 8d8 f3e f49
:3 0 6c :2 0 c2
:4 0 8db f4b f4d
:3 0 6c :2 0 6f
:4 0 8de f4f f51
:3 0 6c :2 0 1b
:3 0 8e1 f53 f55
:3 0 6c :2 0 6f
:4 0 8e4 f57 f59
:3 0 8e7 f2f f5b
:2 0 f5d 8ea f5e
f2c f5d 0 f5f
8ec 0 f89 64
:3 0 65 :3 0 f60
f61 0 64 :3 0
75 :3 0 f63 f64
0 23 :2 0 2
:4 0 133 :2 0 77
:2 0 23 :2 0 8ee
f69 f6b :3 0 8f1
f65 f6d f62 f6f
f6e :2 0 67 :3 0
78 :3 0 f71 f72
0 69 :4 0 134
:4 0 6c :2 0 6d
:3 0 8f5 f76 f78
:3 0 8f8 f73 f7a
:2 0 f7c 8fb f7d
f70 f7c 0 f7e
8fd 0 f89 85
:3 0 c5 :3 0 f7f
f80 0 81 :3 0
eb :3 0 f82 f83
0 1b :3 0 87
:3 0 8ff f81 f87
:2 0 f89 903 f8a
f1b f89 0 f8b
907 0 11ef 2a
:3 0 1b :3 0 f8c
f8d 0 11ef 10c
:3 0 10d :3 0 9f
:3 0 10e :3 0 10d
:3 0 9f :3 0 10f
:3 0 110 :3 0 111
:3 0 112 :3 0 113
:3 0 27 :3 0 2c
:3 0 2d :3 0 4b
:3 0 4c :3 0 50
:3 0 52 :3 0 114
:3 0 115 :3 0 17
:3 0 116 :3 0 1b
:3 0 117 :3 0 118
:4 0 135 1 :8 0
fae 15 :3 0 96
:3 0 fa9 faa 0
97 :3 0 fab fac
0 fae 909 1001
98 :3 0 15 :3 0
96 :3 0 fb0 fb1
0 97 :3 0 fb2
fb3 0 fb5 90c
fb7 90e fb6 fb5
:2 0 fff 99 :3 0
15 :3 0 96 :3 0
fba fbb 0 97
:3 0 fbc fbd 0
ff7 64 :3 0 65
:3 0 fbf fc0 0
64 :3 0 75 :3 0
fc2 fc3 0 9a
:2 0 2 :4 0 136
:2 0 77 :2 0 23
:2 0 910 fc8 fca
:3 0 913 fc4 fcc
fc1 fce fcd :2 0
67 :3 0 78 :3 0
fd0 fd1 0 69
:4 0 137 :4 0 6c
:2 0 6d :3 0 917
fd5 fd7 :3 0 6c
:2 0 7f :4 0 91a
fd9 fdb :3 0 6c
:2 0 9d :4 0 91d
fdd fdf :3 0 6c
:2 0 97 :3 0 920
fe1 fe3 :3 0 6c
:2 0 9e :4 0 923
fe5 fe7 :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 926 fea fee
92a fe9 ff0 :3 0
92d fd2 ff2 :2 0
ff4 930 ff5 fcf
ff4 0 ff6 932
0 ff7 934 ffa
:3 0 ffa 0 ffa
ff9 ff7 ff8 :6 0
ffc 18 :3 0 937
ffe 939 ffd ffc
:2 0 fff 93b :2 0
1001 0 1001 1000
fae fff :6 0 11ef
1 :3 0 15 :3 0
96 :3 0 1003 1004
0 15 :3 0 88
:2 0 bc :3 0 1006
1008 0 940 1007
100a :3 0 100b :2 0
5f :3 0 23 :2 0
100d 100e 0 1187
10c :3 0 10d :3 0
9f :3 0 10e :3 0
10d :3 0 9f :3 0
10f :3 0 110 :3 0
111 :3 0 112 :3 0
113 :3 0 27 :3 0
2c :3 0 2d :3 0
4b :3 0 4c :3 0
50 :3 0 52 :3 0
114 :3 0 115 :3 0
17 :3 0 116 :3 0
1b :3 0 117 :3 0
118 :4 0 138 1
:8 0 102f 15 :3 0
96 :3 0 102a 102b
0 97 :3 0 102c
102d 0 102f 943
1082 98 :3 0 15
:3 0 96 :3 0 1031
1032 0 97 :3 0
1033 1034 0 1036
946 1038 948 1037
1036 :2 0 1080 99
:3 0 15 :3 0 96
:3 0 103b 103c 0
97 :3 0 103d 103e
0 1078 64 :3 0
65 :3 0 1040 1041
0 64 :3 0 75
:3 0 1043 1044 0
9a :2 0 2 :4 0
139 :2 0 77 :2 0
23 :2 0 94a 1049
104b :3 0 94d 1045
104d 1042 104f 104e
:2 0 67 :3 0 78
:3 0 1051 1052 0
69 :4 0 13a :4 0
6c :2 0 6d :3 0
951 1056 1058 :3 0
6c :2 0 7f :4 0
954 105a 105c :3 0
6c :2 0 9d :4 0
957 105e 1060 :3 0
6c :2 0 97 :3 0
95a 1062 1064 :3 0
6c :2 0 9e :4 0
95d 1066 1068 :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 960 106b
106f 964 106a 1071
:3 0 967 1053 1073
:2 0 1075 96a 1076
1050 1075 0 1077
96c 0 1078 96e
107b :3 0 107b 0
107b 107a 1078 1079
:6 0 107d 1a :3 0
971 107f 973 107e
107d :2 0 1080 975
:2 0 1082 0 1082
1081 102f 1080 :6 0
1187 1 :3 0 15
:3 0 96 :3 0 1084
1085 0 15 :3 0
88 :2 0 bc :3 0
1087 1089 0 97a
1088 108b :3 0 108c
:2 0 5f :3 0 13b
:2 0 23 :2 0 97d
108f 1091 :3 0 108e
1092 0 1184 df
:3 0 71 :3 0 33
:3 0 31 :2 0 97f
1095 1098 982 1094
109a 8f :2 0 31
:2 0 986 109c 109e
:3 0 5c :3 0 31
:2 0 10a0 10a1 0
1181 13c :3 0 5c
:3 0 94 :3 0 114
:3 0 c8 :3 0 17
:3 0 115 :3 0 c8
:3 0 116 :3 0 1b
:4 0 13d 1 :8 0
10b3 15 :3 0 96
:3 0 10ae 10af 0
97 :3 0 10b0 10b1
0 10b3 989 1106
98 :3 0 15 :3 0
96 :3 0 10b5 10b6
0 97 :3 0 10b7
10b8 0 10ba 98c
10bc 98e 10bb 10ba
:2 0 1104 99 :3 0
15 :3 0 96 :3 0
10bf 10c0 0 97
:3 0 10c1 10c2 0
10fc 64 :3 0 65
:3 0 10c4 10c5 0
64 :3 0 75 :3 0
10c7 10c8 0 9a
:2 0 2 :4 0 13e
:2 0 77 :2 0 23
:2 0 990 10cd 10cf
:3 0 993 10c9 10d1
10c6 10d3 10d2 :2 0
67 :3 0 78 :3 0
10d5 10d6 0 69
:4 0 13f :4 0 6c
:2 0 6d :3 0 997
10da 10dc :3 0 6c
:2 0 7f :4 0 99a
10de 10e0 :3 0 6c
:2 0 9d :4 0 99d
10e2 10e4 :3 0 6c
:2 0 97 :3 0 9a0
10e6 10e8 :3 0 6c
:2 0 9e :4 0 9a3
10ea 10ec :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 9a6 10ef 10f3
9aa 10ee 10f5 :3 0
9ad 10d7 10f7 :2 0
10f9 9b0 10fa 10d4
10f9 0 10fb 9b2
0 10fc 9b4 10ff
:3 0 10ff 0 10ff
10fe 10fc 10fd :6 0
1101 1c :3 0 9b7
1103 9b9 1102 1101
:2 0 1104 9bb :2 0
1106 0 1106 1105
10b3 1104 :6 0 1181
1 :3 0 71 :3 0
5c :3 0 31 :2 0
9be 1108 110b 8f
:2 0 31 :2 0 9c3
110d 110f :3 0 64
:3 0 65 :3 0 1111
1112 0 64 :3 0
75 :3 0 1114 1115
0 18 :2 0 2
:4 0 140 :2 0 77
:2 0 23 :2 0 9c6
111a 111c :3 0 9c9
1116 111e 1113 1120
111f :2 0 67 :3 0
78 :3 0 1122 1123
0 69 :4 0 141
:4 0 6c :2 0 6d
:3 0 9cd 1127 1129
:3 0 6c :2 0 7f
:4 0 9d0 112b 112d
:3 0 6c :2 0 80
:4 0 9d3 112f 1131
:3 0 6c :2 0 71
:3 0 72 :3 0 81
:3 0 142 :3 0 1136
1137 0 9d6 1135
1139 73 :4 0 9d8
1134 113c 9db 1133
113e :3 0 6c :2 0
c2 :4 0 9de 1140
1142 :3 0 6c :2 0
6f :4 0 9e1 1144
1146 :3 0 6c :2 0
1b :3 0 9e4 1148
114a :3 0 6c :2 0
6f :4 0 9e7 114c
114e :3 0 9ea 1124
1150 :2 0 1152 9ed
1153 1121 1152 0
1154 9ef 0 117e
64 :3 0 65 :3 0
1155 1156 0 64
:3 0 75 :3 0 1158
1159 0 23 :2 0
2 :4 0 143 :2 0
77 :2 0 23 :2 0
9f1 115e 1160 :3 0
9f4 115a 1162 1157
1164 1163 :2 0 67
:3 0 78 :3 0 1166
1167 0 69 :4 0
144 :4 0 6c :2 0
6d :3 0 9f8 116b
116d :3 0 9fb 1168
116f :2 0 1171 9fe
1172 1165 1171 0
1173 a00 0 117e
85 :3 0 c5 :3 0
1174 1175 0 81
:3 0 142 :3 0 1177
1178 0 1b :3 0
87 :3 0 a02 1176
117c :2 0 117e a06
117f 1110 117e 0
1180 a0a 0 1181
a0c 1182 109f 1181
0 1183 a10 0
1184 a12 1185 108d
1184 0 1186 a15
0 1187 a17 1188
100c 1187 0 1189
a1b 0 11ef 126
:3 0 127 :3 0 26
:3 0 44 :3 0 128
:3 0 b8 :3 0 19
:3 0 117 :3 0 116
:3 0 1b :4 0 145
1 :8 0 119a 15
:3 0 96 :3 0 1195
1196 0 97 :3 0
1197 1198 0 119a
a1d 11ed 98 :3 0
15 :3 0 96 :3 0
119c 119d 0 97
:3 0 119e 119f 0
11a1 a20 11a3 a22
11a2 11a1 :2 0 11eb
99 :3 0 15 :3 0
96 :3 0 11a6 11a7
0 97 :3 0 11a8
11a9 0 11e3 64
:3 0 65 :3 0 11ab
11ac 0 64 :3 0
75 :3 0 11ae 11af
0 9a :2 0 2
:4 0 146 :2 0 77
:2 0 23 :2 0 a24
11b4 11b6 :3 0 a27
11b0 11b8 11ad 11ba
11b9 :2 0 67 :3 0
78 :3 0 11bc 11bd
0 69 :4 0 147
:4 0 6c :2 0 6d
:3 0 a2b 11c1 11c3
:3 0 6c :2 0 7f
:4 0 a2e 11c5 11c7
:3 0 6c :2 0 9d
:4 0 a31 11c9 11cb
:3 0 6c :2 0 97
:3 0 a34 11cd 11cf
:3 0 6c :2 0 9e
:4 0 a37 11d1 11d3
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 a3a
11d6 11da a3e 11d5
11dc :3 0 a41 11be
11de :2 0 11e0 a44
11e1 11bb 11e0 0
11e2 a46 0 11e3
a48 11e6 :3 0 11e6
0 11e6 11e5 11e3
11e4 :6 0 11e8 1e
:3 0 a4b 11ea a4d
11e9 11e8 :2 0 11eb
a4f :2 0 11ed 0
11ed 11ec 119a 11eb
:6 0 11ef 1 :3 0
a52 11f0 eb1 11ef
0 1250 64 :3 0
65 :3 0 11f1 11f2
0 64 :3 0 75
:3 0 11f4 11f5 0
7c :2 0 2 :4 0
148 :2 0 77 :2 0
23 :2 0 a59 11fa
11fc :3 0 a5c 11f6
11fe 11f3 1200 11ff
:2 0 67 :3 0 78
:3 0 1202 1203 0
69 :4 0 149 :4 0
6c :2 0 6d :3 0
a60 1207 1209 :3 0
6c :2 0 7f :4 0
a63 120b 120d :3 0
6c :2 0 80 :4 0
a66 120f 1211 :3 0
6c :2 0 71 :3 0
72 :3 0 81 :3 0
8c :3 0 1216 1217
0 a69 1215 1219
73 :4 0 a6b 1214
121c a6e 1213 121e
:3 0 a71 1204 1220
:2 0 1222 a74 1223
1201 1222 0 1224
a76 0 124d 64
:3 0 65 :3 0 1225
1226 0 64 :3 0
75 :3 0 1228 1229
0 23 :2 0 2
:4 0 14a :2 0 77
:2 0 23 :2 0 a78
122e 1230 :3 0 a7b
122a 1232 1227 1234
1233 :2 0 67 :3 0
78 :3 0 1236 1237
0 69 :4 0 14b
:4 0 6c :2 0 6d
:3 0 a7f 123b 123d
:3 0 a82 1238 123f
:2 0 1241 a85 1242
1235 1241 0 1243
a87 0 124d 85
:3 0 86 :3 0 1244
1245 0 81 :3 0
8c :3 0 1247 1248
0 87 :3 0 a89
1246 124b :2 0 124d
a8c 124f cef ea7
0 1250 0 124d
0 1250 a90 0
1895 15 :3 0 96
:3 0 1251 1252 0
15 :3 0 88 :2 0
a2 :3 0 1254 1256
0 a96 1255 1258
:3 0 1259 :2 0 58
:3 0 14c :3 0 31
:2 0 71 :3 0 33
:3 0 31 :2 0 a99
125e 1261 81 :3 0
14d :3 0 1263 1264
0 54 :3 0 a9c
125c 1267 125b 1268
0 130f 58 :3 0
14c :3 0 31 :2 0
71 :3 0 33 :3 0
31 :2 0 aa1 126d
1270 81 :3 0 14e
:3 0 1272 1273 0
56 :3 0 aa4 126b
1276 126a 1277 0
130f 128 :3 0 127
:3 0 14f :3 0 56
:3 0 150 :3 0 81
:3 0 e1 :3 0 81
:3 0 e2 :3 0 81
:3 0 e3 :3 0 81
:3 0 e4 :3 0 81
:3 0 e5 :3 0 81
:3 0 151 :3 0 14f
:3 0 56 :3 0 81
:3 0 152 :3 0 14f
:3 0 54 :3 0 81
:3 0 151 :3 0 dc
:3 0 153 :3 0 127
:3 0 81 :3 0 152
:3 0 14f :3 0 14f
:3 0 56 :3 0 54
:3 0 14f :3 0 126
:3 0 26 :4 0 154
1 :8 0 12b4 155
:4 0 129f :3 0 87
:3 0 88 :2 0 aab
12a2 12a3 :3 0 15
:3 0 96 :3 0 12a5
12a6 0 31 :2 0
12a7 12a8 0 12aa
aae 12b1 15 :3 0
96 :3 0 12ab 12ac
0 f2 :2 0 12ad
12ae 0 12b0 ab0
12b2 12a4 12aa 0
12b3 0 12b0 0
12b3 ab2 0 12b4
ab5 1307 98 :3 0
15 :3 0 96 :3 0
12b6 12b7 0 97
:3 0 12b8 12b9 0
12bb ab8 12bd aba
12bc 12bb :2 0 1305
99 :3 0 15 :3 0
96 :3 0 12c0 12c1
0 97 :3 0 12c2
12c3 0 12fd 64
:3 0 65 :3 0 12c5
12c6 0 64 :3 0
75 :3 0 12c8 12c9
0 9a :2 0 2
:4 0 156 :2 0 77
:2 0 23 :2 0 abc
12ce 12d0 :3 0 abf
12ca 12d2 12c7 12d4
12d3 :2 0 67 :3 0
78 :3 0 12d6 12d7
0 69 :4 0 157
:4 0 6c :2 0 6d
:3 0 ac3 12db 12dd
:3 0 6c :2 0 7f
:4 0 ac6 12df 12e1
:3 0 6c :2 0 9d
:4 0 ac9 12e3 12e5
:3 0 6c :2 0 97
:3 0 acc 12e7 12e9
:3 0 6c :2 0 9e
:4 0 acf 12eb 12ed
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 ad2
12f0 12f4 ad6 12ef
12f6 :3 0 ad9 12d8
12f8 :2 0 12fa adc
12fb 12d5 12fa 0
12fc ade 0 12fd
ae0 1300 :3 0 1300
0 1300 12ff 12fd
12fe :6 0 1302 20
:3 0 ae3 1304 ae5
1303 1302 :2 0 1305
ae7 :2 0 1307 0
1307 1306 12b4 1305
:6 0 130f 1 :3 0
58 :3 0 158 :3 0
26 :3 0 aea 130a
130c 1309 130d 0
130f aec 13bc 26
:3 0 159 :4 0 1311
1312 :3 0 1310 1313
0 13bb 58 :3 0
14c :3 0 31 :2 0
71 :3 0 33 :3 0
31 :2 0 af1 1318
131b 81 :3 0 14d
:3 0 131d 131e 0
54 :3 0 af4 1316
1321 1315 1322 0
13bb 53 :3 0 81
:3 0 151 :3 0 1325
1326 0 1324 1327
0 13bb 57 :3 0
23 :2 0 1329 132a
0 13bb 58 :3 0
15a :3 0 17 :3 0
1b :3 0 33 :3 0
53 :3 0 54 :3 0
24 :3 0 57 :3 0
af9 132d 1335 132c
1336 0 13bb 128
:3 0 126 :3 0 c8
:3 0 b8 :3 0 150
:3 0 15b :3 0 117
:3 0 116 :3 0 127
:3 0 14f :3 0 15c
:3 0 15d :3 0 26
:3 0 17 :3 0 19
:3 0 33 :3 0 5b
:3 0 24 :3 0 1b
:3 0 81 :3 0 151
:3 0 54 :3 0 13
:3 0 6d :4 0 15e
1 :8 0 1366 155
:4 0 1351 :3 0 87
:3 0 88 :2 0 b03
1354 1355 :3 0 15
:3 0 96 :3 0 1357
1358 0 31 :2 0
1359 135a 0 135c
b06 1363 15 :3 0
96 :3 0 135d 135e
0 f2 :2 0 135f
1360 0 1362 b08
1364 1356 135c 0
1365 0 1362 0
1365 b0a 0 1366
b0d 13b9 98 :3 0
15 :3 0 96 :3 0
1368 1369 0 97
:3 0 136a 136b 0
136d b10 136f b12
136e 136d :2 0 13b7
99 :3 0 15 :3 0
96 :3 0 1372 1373
0 97 :3 0 1374
1375 0 13af 64
:3 0 65 :3 0 1377
1378 0 64 :3 0
75 :3 0 137a 137b
0 9a :2 0 2
:4 0 15f :2 0 77
:2 0 23 :2 0 b14
1380 1382 :3 0 b17
137c 1384 1379 1386
1385 :2 0 67 :3 0
78 :3 0 1388 1389
0 69 :4 0 160
:4 0 6c :2 0 6d
:3 0 b1b 138d 138f
:3 0 6c :2 0 7f
:4 0 b1e 1391 1393
:3 0 6c :2 0 9d
:4 0 b21 1395 1397
:3 0 6c :2 0 97
:3 0 b24 1399 139b
:3 0 6c :2 0 9e
:4 0 b27 139d 139f
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 b2a
13a2 13a6 b2e 13a1
13a8 :3 0 b31 138a
13aa :2 0 13ac b34
13ad 1387 13ac 0
13ae b36 0 13af
b38 13b2 :3 0 13b2
0 13b2 13b1 13af
13b0 :6 0 13b4 22
:3 0 b3b 13b6 b3d
13b5 13b4 :2 0 13b7
b3f :2 0 13b9 0
13b9 13b8 1366 13b7
:6 0 13bb 1 :3 0
b42 13bd 125a 130f
0 13be 0 13bb
0 13be b49 0
1895 71 :3 0 35
:3 0 31 :2 0 b4c
13bf 13c2 88 :2 0
31 :2 0 b51 13c4
13c6 :3 0 13c7 :2 0
2c :3 0 91 :2 0
b54 13ca 13cb :3 0
13cc :2 0 13c8 13ce
13cd :2 0 5f :3 0
88 :2 0 31 :2 0
b58 13d1 13d3 :3 0
13d4 :2 0 13cf 13d6
13d5 :2 0 71 :3 0
37 :3 0 31 :2 0
b5b 13d8 13db cc
:2 0 31 :2 0 b60
13dd 13df :3 0 71
:3 0 3b :3 0 31
:2 0 b63 13e1 13e4
8f :2 0 f2 :2 0
b68 13e6 13e8 :3 0
5c :3 0 71 :3 0
37 :3 0 31 :2 0
b6b 13eb 13ee 13ea
13ef 0 13f1 b6e
1411 5c :3 0 104
:3 0 105 :3 0 71
:3 0 37 :3 0 31
:2 0 b70 13f5 13f8
106 :2 0 71 :3 0
3f :3 0 31 :2 0
b73 13fb 13fe b76
13fa 1400 :3 0 1401
:2 0 b79 13f4 1403
161 :2 0 162 :2 0
b7b 1405 1407 :3 0
77 :2 0 163 :2 0
b7e 1409 140b :3 0
b81 13f3 140d 13f2
140e 0 1410 b83
1412 13e9 13f1 0
1413 0 1410 0
1413 b85 0 15ee
2c :4 0 1414 1415
0 15ee 164 :3 0
165 :3 0 166 :3 0
2c :3 0 167 :3 0
168 :3 0 169 :3 0
165 :3 0 165 :3 0
c8 :3 0 17 :3 0
165 :3 0 10c :3 0
27 :3 0 165 :3 0
166 :3 0 10d :3 0
9f :3 0 1e :3 0
165 :3 0 16a :3 0
168 :3 0 b8 :3 0
1b :3 0 168 :3 0
166 :3 0 165 :3 0
166 :3 0 168 :3 0
16b :3 0 165 :3 0
16c :3 0 5c :4 0
16d 1 :8 0 143e
15 :3 0 96 :3 0
1439 143a 0 97
:3 0 143b 143c 0
143e b88 1491 98
:3 0 15 :3 0 96
:3 0 1440 1441 0
97 :3 0 1442 1443
0 1445 b8b 1447
b8d 1446 1445 :2 0
148f 99 :3 0 15
:3 0 96 :3 0 144a
144b 0 97 :3 0
144c 144d 0 1487
64 :3 0 65 :3 0
144f 1450 0 64
:3 0 75 :3 0 1452
1453 0 9a :2 0
2 :4 0 16e :2 0
77 :2 0 23 :2 0
b8f 1458 145a :3 0
b92 1454 145c 1451
145e 145d :2 0 67
:3 0 78 :3 0 1460
1461 0 69 :4 0
16f :4 0 6c :2 0
6d :3 0 b96 1465
1467 :3 0 6c :2 0
7f :4 0 b99 1469
146b :3 0 6c :2 0
9d :4 0 b9c 146d
146f :3 0 6c :2 0
97 :3 0 b9f 1471
1473 :3 0 6c :2 0
9e :4 0 ba2 1475
1477 :3 0 6c :2 0
9f :3 0 a0 :3 0
23 :2 0 a1 :2 0
ba5 147a 147e ba9
1479 1480 :3 0 bac
1462 1482 :2 0 1484
baf 1485 145f 1484
0 1486 bb1 0
1487 bb3 148a :3 0
148a 0 148a 1489
1487 1488 :6 0 148c
24 :3 0 bb6 148e
bb8 148d 148c :2 0
148f bba :2 0 1491
0 1491 1490 143e
148f :6 0 15ee 1
:3 0 2c :3 0 7b
:2 0 bbd 1494 1495
:3 0 1496 :2 0 92
:3 0 170 :3 0 10d
:3 0 9f :3 0 2d
:3 0 92 :3 0 171
:3 0 1e :3 0 94
:4 0 172 1 :8 0
14a7 15 :3 0 96
:3 0 14a2 14a3 0
97 :3 0 14a4 14a5
0 14a7 bbf 14fa
98 :3 0 15 :3 0
96 :3 0 14a9 14aa
0 97 :3 0 14ab
14ac 0 14ae bc2
14b0 bc4 14af 14ae
:2 0 14f8 99 :3 0
15 :3 0 96 :3 0
14b3 14b4 0 97
:3 0 14b5 14b6 0
14f0 64 :3 0 65
:3 0 14b8 14b9 0
64 :3 0 75 :3 0
14bb 14bc 0 9a
:2 0 2 :4 0 173
:2 0 77 :2 0 23
:2 0 bc6 14c1 14c3
:3 0 bc9 14bd 14c5
14ba 14c7 14c6 :2 0
67 :3 0 78 :3 0
14c9 14ca 0 69
:4 0 174 :4 0 6c
:2 0 6d :3 0 bcd
14ce 14d0 :3 0 6c
:2 0 7f :4 0 bd0
14d2 14d4 :3 0 6c
:2 0 9d :4 0 bd3
14d6 14d8 :3 0 6c
:2 0 97 :3 0 bd6
14da 14dc :3 0 6c
:2 0 9e :4 0 bd9
14de 14e0 :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 bdc 14e3 14e7
be0 14e2 14e9 :3 0
be3 14cb 14eb :2 0
14ed be6 14ee 14c8
14ed 0 14ef be8
0 14f0 bea 14f3
:3 0 14f3 0 14f3
14f2 14f0 14f1 :6 0
14f5 26 :3 0 bed
14f7 bef 14f6 14f5
:2 0 14f8 bf1 :2 0
14fa 0 14fa 14f9
14a7 14f8 :6 0 14fc
1 :3 0 bf4 1567
92 :3 0 170 :3 0
166 :3 0 dc :3 0
175 :3 0 176 :3 0
1e :3 0 169 :3 0
c8 :3 0 17 :3 0
10c :3 0 27 :3 0
166 :3 0 2c :4 0
177 1 :8 0 1511
15 :3 0 96 :3 0
150c 150d 0 97
:3 0 150e 150f 0
1511 bf6 1564 98
:3 0 15 :3 0 96
:3 0 1513 1514 0
97 :3 0 1515 1516
0 1518 bf9 151a
bfb 1519 1518 :2 0
1562 99 :3 0 15
:3 0 96 :3 0 151d
151e 0 97 :3 0
151f 1520 0 155a
64 :3 0 65 :3 0
1522 1523 0 64
:3 0 75 :3 0 1525
1526 0 9a :2 0
2 :4 0 178 :2 0
77 :2 0 23 :2 0
bfd 152b 152d :3 0
c00 1527 152f 1524
1531 1530 :2 0 67
:3 0 78 :3 0 1533
1534 0 69 :4 0
179 :4 0 6c :2 0
6d :3 0 c04 1538
153a :3 0 6c :2 0
7f :4 0 c07 153c
153e :3 0 6c :2 0
9d :4 0 c0a 1540
1542 :3 0 6c :2 0
97 :3 0 c0d 1544
1546 :3 0 6c :2 0
9e :4 0 c10 1548
154a :3 0 6c :2 0
9f :3 0 a0 :3 0
23 :2 0 a1 :2 0
c13 154d 1551 c17
154c 1553 :3 0 c1a
1535 1555 :2 0 1557
c1d 1558 1532 1557
0 1559 c1f 0
155a c21 155d :3 0
155d 0 155d 155c
155a 155b :6 0 155f
28 :3 0 c24 1561
c26 1560 155f :2 0
1562 c28 :2 0 1564
0 1564 1563 1511
1562 :6 0 1566 1
:3 0 c2b 1568 1497
14fc 0 1569 0
1566 0 1569 c2d
0 15ee 61 :3 0
88 :2 0 23 :2 0
c32 156b 156d :3 0
92 :3 0 17a :3 0
156f 1570 0 1e
:3 0 1f :3 0 17b
:2 0 c35 1571 1575
cc :2 0 31 :2 0
c3b 1577 1579 :3 0
156e 157b 157a :2 0
64 :3 0 65 :3 0
157d 157e 0 64
:3 0 75 :3 0 1580
1581 0 18 :2 0
2 :4 0 17c :2 0
77 :2 0 23 :2 0
c3e 1586 1588 :3 0
c41 1582 158a 157f
158c 158b :2 0 67
:3 0 78 :3 0 158e
158f 0 69 :4 0
17d :4 0 6c :2 0
6d :3 0 c45 1593
1595 :3 0 6c :2 0
7f :4 0 c48 1597
1599 :3 0 6c :2 0
80 :4 0 c4b 159b
159d :3 0 6c :2 0
71 :3 0 72 :3 0
81 :3 0 17e :3 0
15a2 15a3 0 c4e
15a1 15a5 73 :4 0
c50 15a0 15a8 c53
159f 15aa :3 0 6c
:2 0 c2 :4 0 c56
15ac 15ae :3 0 6c
:2 0 6f :4 0 c59
15b0 15b2 :3 0 6c
:2 0 1b :3 0 c5c
15b4 15b6 :3 0 6c
:2 0 6f :4 0 c5f
15b8 15ba :3 0 c62
1590 15bc :2 0 15be
c65 15bf 158d 15be
0 15c0 c67 0
15ea 64 :3 0 65
:3 0 15c1 15c2 0
64 :3 0 75 :3 0
15c4 15c5 0 23
:2 0 2 :4 0 17f
:2 0 77 :2 0 23
:2 0 c69 15ca 15cc
:3 0 c6c 15c6 15ce
15c3 15d0 15cf :2 0
67 :3 0 78 :3 0
15d2 15d3 0 69
:4 0 180 :4 0 6c
:2 0 6d :3 0 c70
15d7 15d9 :3 0 c73
15d4 15db :2 0 15dd
c76 15de 15d1 15dd
0 15df c78 0
15ea 85 :3 0 c5
:3 0 15e0 15e1 0
81 :3 0 17e :3 0
15e3 15e4 0 1b
:3 0 87 :3 0 c7a
15e2 15e8 :2 0 15ea
c7e 15eb 157c 15ea
0 15ec c82 0
15ee a9 :3 0 c84
1754 61 :3 0 88
:2 0 23 :2 0 c8c
15f0 15f2 :3 0 4f
:3 0 31 :2 0 15f4
15f5 0 1752 181
:3 0 16c :3 0 4f
:3 0 169 :3 0 c8
:3 0 17 :3 0 10c
:3 0 27 :3 0 166
:3 0 10d :3 0 9f
:3 0 1e :3 0 10d
:3 0 9f :3 0 1f
:4 0 182 1 :8 0
160c 15 :3 0 96
:3 0 1607 1608 0
97 :3 0 1609 160a
0 160c c8f 165f
98 :3 0 15 :3 0
96 :3 0 160e 160f
0 97 :3 0 1610
1611 0 1613 c92
1615 c94 1614 1613
:2 0 165d 99 :3 0
15 :3 0 96 :3 0
1618 1619 0 97
:3 0 161a 161b 0
1655 64 :3 0 65
:3 0 161d 161e 0
64 :3 0 75 :3 0
1620 1621 0 9a
:2 0 2 :4 0 183
:2 0 77 :2 0 23
:2 0 c96 1626 1628
:3 0 c99 1622 162a
161f 162c 162b :2 0
67 :3 0 78 :3 0
162e 162f 0 69
:4 0 184 :4 0 6c
:2 0 6d :3 0 c9d
1633 1635 :3 0 6c
:2 0 7f :4 0 ca0
1637 1639 :3 0 6c
:2 0 9d :4 0 ca3
163b 163d :3 0 6c
:2 0 97 :3 0 ca6
163f 1641 :3 0 6c
:2 0 9e :4 0 ca9
1643 1645 :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 cac 1648 164c
cb0 1647 164e :3 0
cb3 1630 1650 :2 0
1652 cb6 1653 162d
1652 0 1654 cb8
0 1655 cba 1658
:3 0 1658 0 1658
1657 1655 1656 :6 0
165a 2a :3 0 cbd
165c cbf 165b 165a
:2 0 165d cc1 :2 0
165f 0 165f 165e
160c 165d :6 0 1752
1 :3 0 4e :3 0
31 :2 0 1661 1662
0 1752 181 :3 0
16b :3 0 4e :3 0
167 :3 0 b8 :3 0
1b :3 0 166 :3 0
10d :3 0 9f :3 0
1e :3 0 10d :3 0
9f :3 0 1f :4 0
185 1 :8 0 1677
15 :3 0 96 :3 0
1672 1673 0 97
:3 0 1674 1675 0
1677 cc4 16ca 98
:3 0 15 :3 0 96
:3 0 1679 167a 0
97 :3 0 167b 167c
0 167e cc7 1680
cc9 167f 167e :2 0
16c8 99 :3 0 15
:3 0 96 :3 0 1683
1684 0 97 :3 0
1685 1686 0 16c0
64 :3 0 65 :3 0
1688 1689 0 64
:3 0 75 :3 0 168b
168c 0 9a :2 0
2 :4 0 186 :2 0
77 :2 0 23 :2 0
ccb 1691 1693 :3 0
cce 168d 1695 168a
1697 1696 :2 0 67
:3 0 78 :3 0 1699
169a 0 69 :4 0
187 :4 0 6c :2 0
6d :3 0 cd2 169e
16a0 :3 0 6c :2 0
7f :4 0 cd5 16a2
16a4 :3 0 6c :2 0
9d :4 0 cd8 16a6
16a8 :3 0 6c :2 0
97 :3 0 cdb 16aa
16ac :3 0 6c :2 0
9e :4 0 cde 16ae
16b0 :3 0 6c :2 0
9f :3 0 a0 :3 0
23 :2 0 a1 :2 0
ce1 16b3 16b7 ce5
16b2 16b9 :3 0 ce8
169b 16bb :2 0 16bd
ceb 16be 1698 16bd
0 16bf ced 0
16c0 cef 16c3 :3 0
16c3 0 16c3 16c2
16c0 16c1 :6 0 16c5
2c :3 0 cf2 16c7
cf4 16c6 16c5 :2 0
16c8 cf6 :2 0 16ca
0 16ca 16c9 1677
16c8 :6 0 1752 1
:3 0 71 :3 0 4e
:3 0 31 :2 0 cf9
16cc 16cf a3 :2 0
71 :3 0 4f :3 0
31 :2 0 cfc 16d2
16d5 77 :2 0 71
:3 0 39 :3 0 31
:2 0 cff 16d8 16db
d02 16d7 16dd :3 0
16de :2 0 d07 16d1
16e0 :3 0 64 :3 0
65 :3 0 16e2 16e3
0 64 :3 0 75
:3 0 16e5 16e6 0
18 :2 0 2 :4 0
188 :2 0 77 :2 0
23 :2 0 d0a 16eb
16ed :3 0 d0d 16e7
16ef 16e4 16f1 16f0
:2 0 67 :3 0 78
:3 0 16f3 16f4 0
69 :4 0 189 :4 0
6c :2 0 6d :3 0
d11 16f8 16fa :3 0
6c :2 0 7f :4 0
d14 16fc 16fe :3 0
6c :2 0 80 :4 0
d17 1700 1702 :3 0
6c :2 0 71 :3 0
72 :3 0 81 :3 0
17e :3 0 1707 1708
0 d1a 1706 170a
73 :4 0 d1c 1705
170d d1f 1704 170f
:3 0 6c :2 0 c2
:4 0 d22 1711 1713
:3 0 6c :2 0 6f
:4 0 d25 1715 1717
:3 0 6c :2 0 1b
:3 0 d28 1719 171b
:3 0 6c :2 0 6f
:4 0 d2b 171d 171f
:3 0 d2e 16f5 1721
:2 0 1723 d31 1724
16f2 1723 0 1725
d33 0 174f 64
:3 0 65 :3 0 1726
1727 0 64 :3 0
75 :3 0 1729 172a
0 23 :2 0 2
:4 0 18a :2 0 77
:2 0 23 :2 0 d35
172f 1731 :3 0 d38
172b 1733 1728 1735
1734 :2 0 67 :3 0
78 :3 0 1737 1738
0 69 :4 0 18b
:4 0 6c :2 0 6d
:3 0 d3c 173c 173e
:3 0 d3f 1739 1740
:2 0 1742 d42 1743
1736 1742 0 1744
d44 0 174f 85
:3 0 c5 :3 0 1745
1746 0 81 :3 0
17e :3 0 1748 1749
0 1b :3 0 87
:3 0 d46 1747 174d
:2 0 174f d4a 1750
16e1 174f 0 1751
d4e 0 1752 d50
1753 15f3 1752 0
1755 13e0 15ee 0
1755 d56 0 17da
18c :3 0 25 :3 0
c7 :3 0 c8 :3 0
17 :4 0 18d 1
:8 0 1761 15 :3 0
96 :3 0 175c 175d
0 97 :3 0 175e
175f 0 1761 d59
17b4 98 :3 0 15
:3 0 96 :3 0 1763
1764 0 97 :3 0
1765 1766 0 1768
d5c 176a d5e 1769
1768 :2 0 17b2 99
:3 0 15 :3 0 96
:3 0 176d 176e 0
97 :3 0 176f 1770
0 17aa 64 :3 0
65 :3 0 1772 1773
0 64 :3 0 75
:3 0 1775 1776 0
9a :2 0 2 :4 0
18e :2 0 77 :2 0
23 :2 0 d60 177b
177d :3 0 d63 1777
177f 1774 1781 1780
:2 0 67 :3 0 78
:3 0 1783 1784 0
69 :4 0 18f :4 0
6c :2 0 6d :3 0
d67 1788 178a :3 0
6c :2 0 7f :4 0
d6a 178c 178e :3 0
6c :2 0 9d :4 0
d6d 1790 1792 :3 0
6c :2 0 97 :3 0
d70 1794 1796 :3 0
6c :2 0 9e :4 0
d73 1798 179a :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 d76 179d
17a1 d7a 179c 17a3
:3 0 d7d 1785 17a5
:2 0 17a7 d80 17a8
1782 17a7 0 17a9
d82 0 17aa d84
17ad :3 0 17ad 0
17ad 17ac 17aa 17ab
:6 0 17af 2e :3 0
d87 17b1 d89 17b0
17af :2 0 17b2 d8b
:2 0 17b4 0 17b4
17b3 1761 17b2 :6 0
17da 1 :3 0 9f
:3 0 25 :3 0 23
:2 0 23 :2 0 d8e
17b6 17ba 88 :2 0
190 :4 0 d94 17bc
17be :3 0 4d :3 0
13b :2 0 23 :2 0
d97 17c1 17c3 :3 0
17c0 17c4 0 17d7
15 :3 0 96 :3 0
17c6 17c7 0 191
:3 0 17 :3 0 17
:3 0 27 :3 0 2c
:3 0 2d :3 0 50
:3 0 52 :3 0 4d
:3 0 4c :3 0 4b
:3 0 d99 17c9 17d4
17c8 17d5 0 17d7
da4 17d8 17bf 17d7
0 17d9 da7 0
17da da9 17db 13d7
17da 0 17dc dad
0 1895 9f :3 0
24 :3 0 23 :2 0
23 :2 0 daf 17dd
17e1 88 :2 0 23
:4 0 db5 17e3 17e5
:3 0 46 :3 0 81
:3 0 192 :3 0 17e8
17e9 0 17e7 17ea
0 17ec db8 17f5
46 :3 0 71 :3 0
3c :3 0 31 :2 0
dba 17ee 17f1 17ed
17f2 0 17f4 dbd
17f6 17e6 17ec 0
17f7 0 17f4 0
17f7 dbf 0 1895
60 :3 0 193 :3 0
26 :3 0 17 :3 0
19 :3 0 1b :3 0
49 :3 0 33 :3 0
20 :3 0 20 :3 0
20 :3 0 20 :3 0
1e :3 0 1f :3 0
43 :3 0 39 :3 0
37 :3 0 3a :3 0
3b :3 0 36 :3 0
46 :3 0 24 :3 0
35 :3 0 32 :3 0
3d :3 0 38 :3 0
34 :3 0 3f :3 0
47 :3 0 1a :3 0
31 :2 0 31 :2 0
51 :2 0 51 :2 0
31 :2 0 dc2 17f9
181b 17f8 181c 0
1895 60 :3 0 88
:2 0 31 :2 0 de6
181f 1821 :3 0 194
:3 0 195 :3 0 196
:3 0 1b :4 0 197
1 :8 0 183d 155
:4 0 1828 :3 0 87
:3 0 88 :2 0 deb
182b 182c :3 0 15
:3 0 96 :3 0 182e
182f 0 31 :2 0
1830 1831 0 1833
dee 183a 15 :3 0
96 :3 0 1834 1835
0 f2 :2 0 1836
1837 0 1839 df0
183b 182d 1833 0
183c 0 1839 0
183c df2 0 183d
df5 1890 98 :3 0
15 :3 0 96 :3 0
183f 1840 0 97
:3 0 1841 1842 0
1844 df8 1846 dfa
1845 1844 :2 0 188e
99 :3 0 15 :3 0
96 :3 0 1849 184a
0 97 :3 0 184b
184c 0 1886 64
:3 0 65 :3 0 184e
184f 0 64 :3 0
75 :3 0 1851 1852
0 9a :2 0 2
:4 0 198 :2 0 77
:2 0 23 :2 0 dfc
1857 1859 :3 0 dff
1853 185b 1850 185d
185c :2 0 67 :3 0
78 :3 0 185f 1860
0 69 :4 0 199
:4 0 6c :2 0 6d
:3 0 e03 1864 1866
:3 0 6c :2 0 7f
:4 0 e06 1868 186a
:3 0 6c :2 0 9d
:4 0 e09 186c 186e
:3 0 6c :2 0 97
:3 0 e0c 1870 1872
:3 0 6c :2 0 9e
:4 0 e0f 1874 1876
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 e12
1879 187d e16 1878
187f :3 0 e19 1861
1881 :2 0 1883 e1c
1884 185e 1883 0
1885 e1e 0 1886
e20 1889 :3 0 1889
0 1889 1888 1886
1887 :6 0 188b 30
:3 0 e23 188d e25
188c 188b :2 0 188e
e27 :2 0 1890 0
1890 188f 183d 188e
:6 0 1892 1 :3 0
e2a 1893 1822 1892
0 1894 e2c 0
1895 e2e 1d3a 2a
:3 0 f3 :4 0 1896
1897 0 1d39 2b
:3 0 f3 :4 0 1899
189a 0 1d39 28
:3 0 12 :3 0 189c
189d 0 1d39 71
:3 0 19a :3 0 28
:3 0 e37 18a0 18a2
31 :2 0 e39 189f
18a5 a3 :2 0 18
:2 0 e3e 18a7 18a9
:3 0 62 :3 0 31
:2 0 18ab 18ac 0
18ae e41 18c6 62
:3 0 104 :3 0 71
:3 0 19a :3 0 28
:3 0 e43 18b2 18b4
31 :2 0 e45 18b1
18b7 77 :2 0 23
:2 0 e48 18b9 18bb
:3 0 18bc :2 0 161
:2 0 de :2 0 e4b
18be 18c0 :3 0 e4e
18b0 18c2 18af 18c3
0 18c5 e50 18c7
18aa 18ae 0 18c8
0 18c5 0 18c8
e52 0 1d39 62
:3 0 cc :2 0 31
:2 0 e57 18ca 18cc
:3 0 30 :3 0 31
:2 0 18ce 18cf 0
1d36 19b :3 0 71
:3 0 30 :3 0 31
:2 0 e5a 18d2 18d5
62 :3 0 a3 :2 0
19c :3 0 e5f 18d8
18da :3 0 18db 1d35
1b :3 0 dc :3 0
dd :3 0 18de 18df
0 18 :2 0 18
:2 0 71 :3 0 30
:3 0 31 :2 0 e62
18e3 18e6 106 :2 0
de :2 0 e65 18e8
18ea :3 0 77 :2 0
23 :2 0 e68 18ec
18ee :3 0 28 :3 0
e6b 18e0 18f1 18dd
18f2 0 1d33 24
:3 0 dc :3 0 dd
:3 0 18f5 18f6 0
23 :2 0 23 :2 0
71 :3 0 30 :3 0
31 :2 0 e70 18fa
18fd 106 :2 0 de
:2 0 e73 18ff 1901
:3 0 77 :2 0 18
:2 0 e76 1903 1905
:3 0 77 :2 0 23
:2 0 e79 1907 1909
:3 0 28 :3 0 e7c
18f7 190c 18f4 190d
0 1d33 9f :3 0
24 :3 0 23 :2 0
23 :2 0 e81 190f
1913 88 :2 0 23
:4 0 e87 1915 1917
:3 0 46 :3 0 81
:3 0 192 :3 0 191a
191b 0 1919 191c
0 194a 71 :3 0
19a :3 0 2b :3 0
e8a 191f 1921 31
:2 0 e8c 191e 1924
88 :2 0 31 :2 0
e91 1926 1928 :3 0
2b :3 0 1b :3 0
192a 192b 0 192d
e94 1947 2b :3 0
9f :3 0 2b :3 0
6c :2 0 19d :4 0
e96 1931 1933 :3 0
23 :2 0 29 :2 0
e99 192f 1937 192e
1938 0 1946 2b
:3 0 9f :3 0 2b
:3 0 6c :2 0 1b
:3 0 e9d 193d 193f
:3 0 23 :2 0 29
:2 0 ea0 193b 1943
193a 1944 0 1946
ea4 1948 1929 192d
0 1949 0 1946
0 1949 ea7 0
194a eaa 197f 46
:3 0 71 :3 0 3c
:3 0 31 :2 0 ead
194c 194f 194b 1950
0 197e 71 :3 0
19a :3 0 2a :3 0
eb0 1953 1955 31
:2 0 eb2 1952 1958
88 :2 0 31 :2 0
eb7 195a 195c :3 0
2a :3 0 1b :3 0
195e 195f 0 1961
eba 197b 2a :3 0
9f :3 0 2a :3 0
6c :2 0 19d :4 0
ebc 1965 1967 :3 0
23 :2 0 29 :2 0
ebf 1963 196b 1962
196c 0 197a 2a
:3 0 9f :3 0 2a
:3 0 6c :2 0 1b
:3 0 ec3 1971 1973
:3 0 23 :2 0 29
:2 0 ec6 196f 1977
196e 1978 0 197a
eca 197c 195d 1961
0 197d 0 197a
0 197d ecd 0
197e ed0 1980 1918
194a 0 1981 0
197e 0 1981 ed3
0 1d33 9f :3 0
24 :3 0 23 :2 0
23 :2 0 ed6 1982
1986 88 :2 0 23
:4 0 edc 1988 198a
:3 0 35 :3 0 31
:2 0 198c 198d 0
198f edf 1990 198b
198f 0 1991 ee1
0 1d33 41 :3 0
31 :2 0 1992 1993
0 1d33 35 :3 0
31 :2 0 1995 1996
0 1d33 10c :3 0
19e :3 0 19f :3 0
27 :3 0 1e :3 0
1f :3 0 114 :3 0
115 :3 0 17 :3 0
116 :3 0 1b :3 0
118 :4 0 1a0 1
:8 0 19aa 15 :3 0
96 :3 0 19a5 19a6
0 97 :3 0 19a7
19a8 0 19aa ee3
19fd 98 :3 0 15
:3 0 96 :3 0 19ac
19ad 0 97 :3 0
19ae 19af 0 19b1
ee6 19b3 ee8 19b2
19b1 :2 0 19fb 99
:3 0 15 :3 0 96
:3 0 19b6 19b7 0
97 :3 0 19b8 19b9
0 19f3 64 :3 0
65 :3 0 19bb 19bc
0 64 :3 0 75
:3 0 19be 19bf 0
9a :2 0 2 :4 0
1a1 :2 0 77 :2 0
23 :2 0 eea 19c4
19c6 :3 0 eed 19c0
19c8 19bd 19ca 19c9
:2 0 67 :3 0 78
:3 0 19cc 19cd 0
69 :4 0 1a2 :4 0
6c :2 0 6d :3 0
ef1 19d1 19d3 :3 0
6c :2 0 7f :4 0
ef4 19d5 19d7 :3 0
6c :2 0 9d :4 0
ef7 19d9 19db :3 0
6c :2 0 97 :3 0
efa 19dd 19df :3 0
6c :2 0 9e :4 0
efd 19e1 19e3 :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 f00 19e6
19ea f04 19e5 19ec
:3 0 f07 19ce 19ee
:2 0 19f0 f0a 19f1
19cb 19f0 0 19f2
f0c 0 19f3 f0e
19f6 :3 0 19f6 0
19f6 19f5 19f3 19f4
:6 0 19f8 33 :3 0
f11 19fa f13 19f9
19f8 :2 0 19fb f15
:2 0 19fd 0 19fd
19fc 19aa 19fb :6 0
1d33 32 :3 0 15
:3 0 96 :3 0 19ff
1a00 0 15 :3 0
88 :2 0 bc :3 0
1a02 1a04 0 f1a
1a03 1a06 :3 0 1a07
:2 0 10c :3 0 19e
:3 0 19f :3 0 27
:3 0 1e :3 0 1f
:3 0 114 :3 0 115
:3 0 17 :3 0 116
:3 0 1b :3 0 118
:4 0 1a3 1 :8 0
1a1b 15 :3 0 96
:3 0 1a16 1a17 0
97 :3 0 1a18 1a19
0 1a1b f1d 1a6e
98 :3 0 15 :3 0
96 :3 0 1a1d 1a1e
0 97 :3 0 1a1f
1a20 0 1a22 f20
1a24 f22 1a23 1a22
:2 0 1a6c 99 :3 0
15 :3 0 96 :3 0
1a27 1a28 0 97
:3 0 1a29 1a2a 0
1a64 64 :3 0 65
:3 0 1a2c 1a2d 0
64 :3 0 75 :3 0
1a2f 1a30 0 9a
:2 0 2 :4 0 1a4
:2 0 77 :2 0 23
:2 0 f24 1a35 1a37
:3 0 f27 1a31 1a39
1a2e 1a3b 1a3a :2 0
67 :3 0 78 :3 0
1a3d 1a3e 0 69
:4 0 1a5 :4 0 6c
:2 0 6d :3 0 f2b
1a42 1a44 :3 0 6c
:2 0 7f :4 0 f2e
1a46 1a48 :3 0 6c
:2 0 9d :4 0 f31
1a4a 1a4c :3 0 6c
:2 0 97 :3 0 f34
1a4e 1a50 :3 0 6c
:2 0 9e :4 0 f37
1a52 1a54 :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 f3a 1a57 1a5b
f3e 1a56 1a5d :3 0
f41 1a3f 1a5f :2 0
1a61 f44 1a62 1a3c
1a61 0 1a63 f46
0 1a64 f48 1a67
:3 0 1a67 0 1a67
1a66 1a64 1a65 :6 0
1a69 35 :3 0 f4b
1a6b f4d 1a6a 1a69
:2 0 1a6c f4f :2 0
1a6e 0 1a6e 1a6d
1a1b 1a6c :6 0 1a85
32 :3 0 15 :3 0
96 :3 0 1a70 1a71
0 15 :3 0 88
:2 0 a2 :3 0 1a73
1a75 0 f54 1a74
1a77 :3 0 1a78 :2 0
35 :3 0 108 :2 0
1a7a 1a7b 0 1a7d
f57 1a82 1e :3 0
1c :3 0 1a7e 1a7f
0 1a81 f59 1a83
1a79 1a7d 0 1a84
0 1a81 0 1a84
f5b 0 1a85 f5e
1a86 1a08 1a85 0
1a87 f61 0 1d33
71 :3 0 35 :3 0
31 :2 0 f63 1a88
1a8b 88 :2 0 31
:2 0 f68 1a8d 1a8f
:3 0 71 :3 0 37
:3 0 31 :2 0 f6b
1a91 1a94 cc :2 0
31 :2 0 f70 1a96
1a98 :3 0 71 :3 0
3b :3 0 31 :2 0
f73 1a9a 1a9d 8f
:2 0 f2 :2 0 f78
1a9f 1aa1 :3 0 5c
:3 0 71 :3 0 37
:3 0 31 :2 0 f7b
1aa4 1aa7 1aa3 1aa8
0 1aaa f7e 1aca
5c :3 0 104 :3 0
105 :3 0 71 :3 0
37 :3 0 31 :2 0
f80 1aae 1ab1 106
:2 0 71 :3 0 3f
:3 0 31 :2 0 f83
1ab4 1ab7 f86 1ab3
1ab9 :3 0 1aba :2 0
f89 1aad 1abc 161
:2 0 162 :2 0 f8b
1abe 1ac0 :3 0 77
:2 0 163 :2 0 f8e
1ac2 1ac4 :3 0 f91
1aac 1ac6 1aab 1ac7
0 1ac9 f93 1acb
1aa2 1aaa 0 1acc
0 1ac9 0 1acc
f95 0 1bbe 2c
:4 0 1acd 1ace 0
1bbe 164 :3 0 165
:3 0 166 :3 0 2c
:3 0 167 :3 0 168
:3 0 169 :3 0 165
:3 0 165 :3 0 c8
:3 0 17 :3 0 165
:3 0 10c :3 0 27
:3 0 165 :3 0 166
:3 0 10d :3 0 9f
:3 0 1c :3 0 165
:3 0 16a :3 0 168
:3 0 b8 :3 0 1b
:3 0 168 :3 0 166
:3 0 165 :3 0 166
:3 0 168 :3 0 16b
:3 0 165 :3 0 16c
:3 0 5c :4 0 1a6
1 :8 0 1af7 15
:3 0 96 :3 0 1af2
1af3 0 97 :3 0
1af4 1af5 0 1af7
f98 1b4a 98 :3 0
15 :3 0 96 :3 0
1af9 1afa 0 97
:3 0 1afb 1afc 0
1afe f9b 1b00 f9d
1aff 1afe :2 0 1b48
99 :3 0 15 :3 0
96 :3 0 1b03 1b04
0 97 :3 0 1b05
1b06 0 1b40 64
:3 0 65 :3 0 1b08
1b09 0 64 :3 0
75 :3 0 1b0b 1b0c
0 9a :2 0 2
:4 0 1a7 :2 0 77
:2 0 23 :2 0 f9f
1b11 1b13 :3 0 fa2
1b0d 1b15 1b0a 1b17
1b16 :2 0 67 :3 0
78 :3 0 1b19 1b1a
0 69 :4 0 1a8
:4 0 6c :2 0 6d
:3 0 fa6 1b1e 1b20
:3 0 6c :2 0 7f
:4 0 fa9 1b22 1b24
:3 0 6c :2 0 9d
:4 0 fac 1b26 1b28
:3 0 6c :2 0 97
:3 0 faf 1b2a 1b2c
:3 0 6c :2 0 9e
:4 0 fb2 1b2e 1b30
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 fb5
1b33 1b37 fb9 1b32
1b39 :3 0 fbc 1b1b
1b3b :2 0 1b3d fbf
1b3e 1b18 1b3d 0
1b3f fc1 0 1b40
fc3 1b43 :3 0 1b43
0 1b43 1b42 1b40
1b41 :6 0 1b45 37
:3 0 fc6 1b47 fc8
1b46 1b45 :2 0 1b48
fca :2 0 1b4a 0
1b4a 1b49 1af7 1b48
:6 0 1bbe 32 :3 0
2c :3 0 91 :2 0
fcd 1b4d 1b4e :3 0
1b4f :2 0 92 :3 0
170 :3 0 166 :3 0
dc :3 0 175 :3 0
176 :3 0 1e :3 0
169 :3 0 c8 :3 0
17 :3 0 10c :3 0
27 :3 0 166 :3 0
2c :4 0 1a9 1
:8 0 1b65 15 :3 0
96 :3 0 1b60 1b61
0 97 :3 0 1b62
1b63 0 1b65 fcf
1bb8 98 :3 0 15
:3 0 96 :3 0 1b67
1b68 0 97 :3 0
1b69 1b6a 0 1b6c
fd2 1b6e fd4 1b6d
1b6c :2 0 1bb6 99
:3 0 15 :3 0 96
:3 0 1b71 1b72 0
97 :3 0 1b73 1b74
0 1bae 64 :3 0
65 :3 0 1b76 1b77
0 64 :3 0 75
:3 0 1b79 1b7a 0
9a :2 0 2 :4 0
1aa :2 0 77 :2 0
23 :2 0 fd6 1b7f
1b81 :3 0 fd9 1b7b
1b83 1b78 1b85 1b84
:2 0 67 :3 0 78
:3 0 1b87 1b88 0
69 :4 0 1ab :4 0
6c :2 0 6d :3 0
fdd 1b8c 1b8e :3 0
6c :2 0 7f :4 0
fe0 1b90 1b92 :3 0
6c :2 0 9d :4 0
fe3 1b94 1b96 :3 0
6c :2 0 97 :3 0
fe6 1b98 1b9a :3 0
6c :2 0 9e :4 0
fe9 1b9c 1b9e :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 fec 1ba1
1ba5 ff0 1ba0 1ba7
:3 0 ff3 1b89 1ba9
:2 0 1bab ff6 1bac
1b86 1bab 0 1bad
ff8 0 1bae ffa
1bb1 :3 0 1bb1 0
1bb1 1bb0 1bae 1baf
:6 0 1bb3 39 :3 0
ffd 1bb5 fff 1bb4
1bb3 :2 0 1bb6 1001
:2 0 1bb8 0 1bb8
1bb7 1b65 1bb6 :6 0
1bba 32 :3 0 1004
1bbb 1b50 1bba 0
1bbc 1006 0 1bbe
a9 :3 0 1008 1c46
92 :3 0 17a :3 0
1bbf 1bc0 0 1c
:3 0 1e :3 0 9a
:2 0 100d 1bc1 1bc5
1ac :2 0 31 :2 0
1013 1bc7 1bc9 :3 0
92 :3 0 17a :3 0
1bcb 1bcc 0 1c
:3 0 1f :3 0 9a
:2 0 1016 1bcd 1bd1
1ad :2 0 31 :2 0
101c 1bd3 1bd5 :3 0
1bca 1bd7 1bd6 :2 0
92 :3 0 170 :3 0
10d :3 0 9f :3 0
1e :3 0 92 :3 0
171 :3 0 1e :3 0
94 :4 0 1ae 1
:8 0 1be8 15 :3 0
96 :3 0 1be3 1be4
0 97 :3 0 1be5
1be6 0 1be8 101f
1c3b 98 :3 0 15
:3 0 96 :3 0 1bea
1beb 0 97 :3 0
1bec 1bed 0 1bef
1022 1bf1 1024 1bf0
1bef :2 0 1c39 99
:3 0 15 :3 0 96
:3 0 1bf4 1bf5 0
97 :3 0 1bf6 1bf7
0 1c31 64 :3 0
65 :3 0 1bf9 1bfa
0 64 :3 0 75
:3 0 1bfc 1bfd 0
9a :2 0 2 :4 0
1af :2 0 77 :2 0
23 :2 0 1026 1c02
1c04 :3 0 1029 1bfe
1c06 1bfb 1c08 1c07
:2 0 67 :3 0 78
:3 0 1c0a 1c0b 0
69 :4 0 1b0 :4 0
6c :2 0 6d :3 0
102d 1c0f 1c11 :3 0
6c :2 0 7f :4 0
1030 1c13 1c15 :3 0
6c :2 0 9d :4 0
1033 1c17 1c19 :3 0
6c :2 0 97 :3 0
1036 1c1b 1c1d :3 0
6c :2 0 9e :4 0
1039 1c1f 1c21 :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 103c 1c24
1c28 1040 1c23 1c2a
:3 0 1043 1c0c 1c2c
:2 0 1c2e 1046 1c2f
1c09 1c2e 0 1c30
1048 0 1c31 104a
1c34 :3 0 1c34 0
1c34 1c33 1c31 1c32
:6 0 1c36 3b :3 0
104d 1c38 104f 1c37
1c36 :2 0 1c39 1051
:2 0 1c3b 0 1c3b
1c3a 1be8 1c39 :6 0
1c3d 32 :3 0 1054
1c3e 1bd8 1c3d 0
1c48 1e :3 0 1c
:3 0 1c3f 1c40 0
1c45 1f :3 0 6
:3 0 1c42 1c43 0
1c45 1056 1c47 1a99
1bbe 0 1c48 0
1c45 0 1c48 1059
0 1c49 105d 1c51
1e :3 0 1c :3 0
1c4a 1c4b 0 1c50
1f :3 0 6 :3 0
1c4d 1c4e 0 1c50
105f 1c52 1a90 1c49
0 1c53 0 1c50
0 1c53 1062 0
1d33 71 :3 0 41
:3 0 31 :2 0 1065
1c54 1c57 cc :2 0
31 :2 0 106a 1c59
1c5b :3 0 9f :3 0
24 :3 0 23 :2 0
23 :2 0 106d 1c5d
1c61 88 :2 0 23
:4 0 1073 1c63 1c65
:3 0 34 :3 0 109
:2 0 1c67 1c68 0
1c6a 1076 1c6b 1c66
1c6a 0 1c6c 1078
0 1c6e a9 :3 0
107a 1c88 9f :3 0
24 :3 0 23 :2 0
23 :2 0 107c 1c6f
1c73 88 :2 0 23
:4 0 1082 1c75 1c77
:3 0 46 :3 0 81
:3 0 192 :3 0 1c7a
1c7b 0 1c79 1c7c
0 1c7e 1085 1c7f
1c78 1c7e 0 1c8a
46 :3 0 71 :3 0
3c :3 0 31 :2 0
1087 1c81 1c84 1c80
1c85 0 1c87 108a
1c89 1c5c 1c6e 0
1c8a 0 1c87 0
1c8a 108c 0 1d33
60 :3 0 193 :3 0
26 :3 0 17 :3 0
19 :3 0 1b :3 0
49 :3 0 33 :3 0
20 :3 0 20 :3 0
20 :3 0 20 :3 0
1e :3 0 1f :3 0
43 :3 0 39 :3 0
37 :3 0 3a :3 0
3b :3 0 36 :3 0
46 :3 0 24 :3 0
35 :3 0 32 :3 0
3d :3 0 38 :3 0
34 :3 0 3f :3 0
47 :3 0 1a :3 0
31 :2 0 31 :2 0
51 :2 0 51 :2 0
31 :2 0 1090 1c8c
1cae 1c8b 1caf 0
1d33 60 :3 0 88
:2 0 31 :2 0 10b4
1cb2 1cb4 :3 0 194
:3 0 195 :3 0 196
:3 0 1b :4 0 197
1 :8 0 1cd0 155
:4 0 1cbb :3 0 87
:3 0 88 :2 0 10b9
1cbe 1cbf :3 0 15
:3 0 96 :3 0 1cc1
1cc2 0 31 :2 0
1cc3 1cc4 0 1cc6
10bc 1ccd 15 :3 0
96 :3 0 1cc7 1cc8
0 f2 :2 0 1cc9
1cca 0 1ccc 10be
1cce 1cc0 1cc6 0
1ccf 0 1ccc 0
1ccf 10c0 0 1cd0
10c3 1d23 98 :3 0
15 :3 0 96 :3 0
1cd2 1cd3 0 97
:3 0 1cd4 1cd5 0
1cd7 10c6 1cd9 10c8
1cd8 1cd7 :2 0 1d21
99 :3 0 15 :3 0
96 :3 0 1cdc 1cdd
0 97 :3 0 1cde
1cdf 0 1d19 64
:3 0 65 :3 0 1ce1
1ce2 0 64 :3 0
75 :3 0 1ce4 1ce5
0 9a :2 0 2
:4 0 1b1 :2 0 77
:2 0 23 :2 0 10ca
1cea 1cec :3 0 10cd
1ce6 1cee 1ce3 1cf0
1cef :2 0 67 :3 0
78 :3 0 1cf2 1cf3
0 69 :4 0 1b2
:4 0 6c :2 0 6d
:3 0 10d1 1cf7 1cf9
:3 0 6c :2 0 7f
:4 0 10d4 1cfb 1cfd
:3 0 6c :2 0 9d
:4 0 10d7 1cff 1d01
:3 0 6c :2 0 97
:3 0 10da 1d03 1d05
:3 0 6c :2 0 9e
:4 0 10dd 1d07 1d09
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 10e0
1d0c 1d10 10e4 1d0b
1d12 :3 0 10e7 1cf4
1d14 :2 0 1d16 10ea
1d17 1cf1 1d16 0
1d18 10ec 0 1d19
10ee 1d1c :3 0 1d1c
0 1d1c 1d1b 1d19
1d1a :6 0 1d1e 3d
:3 0 10f1 1d20 10f3
1d1f 1d1e :2 0 1d21
10f5 :2 0 1d23 0
1d23 1d22 1cd0 1d21
:6 0 1d25 32 :3 0
10f8 1d26 1cb5 1d25
0 1d27 10fa 0
1d33 30 :3 0 71
:3 0 30 :3 0 31
:2 0 10fc 1d29 1d2c
77 :2 0 23 :2 0
10ff 1d2e 1d30 :3 0
1d28 1d31 0 1d33
1102 1d35 19c :3 0
18dc 1d33 :4 0 1d36
1110 1d37 18cd 1d36
0 1d38 1113 0
1d39 1115 1d3b cdf
1895 0 1d3c 0
1d39 0 1d3c 111b
0 2002 60 :3 0
8f :2 0 31 :2 0
1120 1d3e 1d40 :3 0
1d41 :2 0 71 :3 0
33 :3 0 31 :2 0
1123 1d43 1d46 cc
:2 0 31 :2 0 1128
1d48 1d4a :3 0 1d4b
:2 0 1d42 1d4d 1d4c
:2 0 64 :3 0 65
:3 0 1d4f 1d50 0
64 :3 0 75 :3 0
1d52 1d53 0 18
:2 0 2 :4 0 1b3
:2 0 77 :2 0 23
:2 0 112b 1d58 1d5a
:3 0 112e 1d54 1d5c
1d51 1d5e 1d5d :2 0
67 :3 0 78 :3 0
1d60 1d61 0 69
:4 0 1b4 :4 0 6c
:2 0 6d :3 0 1132
1d65 1d67 :3 0 6c
:2 0 7f :4 0 1135
1d69 1d6b :3 0 6c
:2 0 80 :4 0 1138
1d6d 1d6f :3 0 6c
:2 0 71 :3 0 72
:3 0 81 :3 0 1b5
:3 0 1d74 1d75 0
113b 1d73 1d77 73
:4 0 113d 1d72 1d7a
1140 1d71 1d7c :3 0
6c :2 0 c2 :4 0
1143 1d7e 1d80 :3 0
6c :2 0 6f :4 0
1146 1d82 1d84 :3 0
6c :2 0 26 :3 0
1149 1d86 1d88 :3 0
6c :2 0 6f :4 0
114c 1d8a 1d8c :3 0
114f 1d62 1d8e :2 0
1d90 1152 1d91 1d5f
1d90 0 1d92 1154
0 1dbc 64 :3 0
65 :3 0 1d93 1d94
0 64 :3 0 75
:3 0 1d96 1d97 0
23 :2 0 2 :4 0
1b6 :2 0 77 :2 0
23 :2 0 1156 1d9c
1d9e :3 0 1159 1d98
1da0 1d95 1da2 1da1
:2 0 67 :3 0 78
:3 0 1da4 1da5 0
69 :4 0 1b7 :4 0
6c :2 0 6d :3 0
115d 1da9 1dab :3 0
1160 1da6 1dad :2 0
1daf 1163 1db0 1da3
1daf 0 1db1 1165
0 1dbc 85 :3 0
c5 :3 0 1db2 1db3
0 81 :3 0 1b5
:3 0 1db5 1db6 0
26 :3 0 87 :3 0
1167 1db4 1dba :2 0
1dbc 116b 1dbd 1d4e
1dbc 0 1dbe 116f
0 2002 71 :3 0
33 :3 0 31 :2 0
1171 1dbf 1dc2 cc
:2 0 31 :2 0 1176
1dc4 1dc6 :3 0 17
:3 0 19 :3 0 1dc8
1dc9 0 1dcb 1179
1dcc 1dc7 1dcb 0
1dcd 117b 0 2002
71 :3 0 19a :3 0
2a :3 0 117d 1dcf
1dd1 31 :2 0 117f
1dce 1dd4 cc :2 0
31 :2 0 1184 1dd6
1dd8 :3 0 1dd9 :2 0
71 :3 0 19a :3 0
2b :3 0 1187 1ddc
1dde 31 :2 0 1189
1ddb 1de1 cc :2 0
31 :2 0 118e 1de3
1de5 :3 0 1de6 :2 0
1dda 1de8 1de7 :2 0
59 :3 0 1b8 :4 0
6c :2 0 1b9 :4 0
1191 1dec 1dee :3 0
6c :2 0 1ba :4 0
1194 1df0 1df2 :3 0
6c :2 0 1bb :4 0
1197 1df4 1df6 :3 0
6c :2 0 1bc :4 0
119a 1df8 1dfa :3 0
6c :2 0 72 :3 0
71 :3 0 39 :3 0
31 :2 0 119d 1dfe
1e01 11a0 1dfd 1e03
11a2 1dfc 1e05 :3 0
6c :2 0 1bd :4 0
11a5 1e07 1e09 :3 0
6c :2 0 72 :3 0
71 :3 0 3a :3 0
31 :2 0 11a8 1e0d
1e10 11ab 1e0c 1e12
11ad 1e0b 1e14 :3 0
6c :2 0 1be :4 0
11b0 1e16 1e18 :3 0
6c :2 0 72 :3 0
71 :3 0 3f :3 0
31 :2 0 11b3 1e1c
1e1f 11b6 1e1b 1e21
11b8 1e1a 1e23 :3 0
6c :2 0 1bf :4 0
11bb 1e25 1e27 :3 0
6c :2 0 1c0 :4 0
11be 1e29 1e2b :3 0
6c :2 0 1c1 :4 0
11c1 1e2d 1e2f :3 0
6c :2 0 1c2 :4 0
11c4 1e31 1e33 :3 0
6c :2 0 1c3 :4 0
11c7 1e35 1e37 :3 0
6c :2 0 1c4 :4 0
11ca 1e39 1e3b :3 0
6c :2 0 17 :3 0
11cd 1e3d 1e3f :3 0
6c :2 0 1c5 :4 0
11d0 1e41 1e43 :3 0
6c :2 0 2a :3 0
11d3 1e45 1e47 :3 0
6c :2 0 1c6 :4 0
11d6 1e49 1e4b :3 0
6c :2 0 1c7 :4 0
11d9 1e4d 1e4f :3 0
6c :2 0 1c8 :4 0
11dc 1e51 1e53 :3 0
6c :2 0 1c9 :4 0
11df 1e55 1e57 :3 0
6c :2 0 81 :3 0
1ca :3 0 1e5a 1e5b
0 11e2 1e59 1e5d
:3 0 6c :2 0 1cb
:4 0 11e5 1e5f 1e61
:3 0 6c :2 0 81
:3 0 1ca :3 0 1e64
1e65 0 11e8 1e63
1e67 :3 0 6c :2 0
1cc :4 0 11eb 1e69
1e6b :3 0 6c :2 0
1cd :4 0 11ee 1e6d
1e6f :3 0 6c :2 0
1ce :4 0 11f1 1e71
1e73 :3 0 6c :2 0
72 :3 0 71 :3 0
39 :3 0 31 :2 0
11f4 1e77 1e7a 11f7
1e76 1e7c 11f9 1e75
1e7e :3 0 6c :2 0
1bd :4 0 11fc 1e80
1e82 :3 0 6c :2 0
72 :3 0 71 :3 0
3a :3 0 31 :2 0
11ff 1e86 1e89 1202
1e85 1e8b 1204 1e84
1e8d :3 0 6c :2 0
1cf :4 0 1207 1e8f
1e91 :3 0 6c :2 0
1d0 :4 0 120a 1e93
1e95 :3 0 6c :2 0
72 :3 0 71 :3 0
3f :3 0 31 :2 0
120d 1e99 1e9c 1210
1e98 1e9e 1212 1e97
1ea0 :3 0 6c :2 0
1d1 :4 0 1215 1ea2
1ea4 :3 0 6c :2 0
1d2 :4 0 1218 1ea6
1ea8 :3 0 6c :2 0
17 :3 0 121b 1eaa
1eac :3 0 6c :2 0
1d3 :4 0 121e 1eae
1eb0 :3 0 6c :2 0
2b :3 0 1221 1eb2
1eb4 :3 0 6c :2 0
1d4 :4 0 1224 1eb6
1eb8 :3 0 6c :2 0
1d5 :4 0 1227 1eba
1ebc :3 0 6c :2 0
1d6 :4 0 122a 1ebe
1ec0 :3 0 1dea 1ec1
0 1ec4 a9 :3 0
122d 1fba 71 :3 0
19a :3 0 2a :3 0
122f 1ec6 1ec8 31
:2 0 1231 1ec5 1ecb
cc :2 0 31 :2 0
1236 1ecd 1ecf :3 0
59 :3 0 1b8 :4 0
6c :2 0 1b9 :4 0
1239 1ed3 1ed5 :3 0
6c :2 0 1ba :4 0
123c 1ed7 1ed9 :3 0
6c :2 0 1bb :4 0
123f 1edb 1edd :3 0
6c :2 0 1bc :4 0
1242 1edf 1ee1 :3 0
6c :2 0 72 :3 0
71 :3 0 39 :3 0
31 :2 0 1245 1ee5
1ee8 1248 1ee4 1eea
124a 1ee3 1eec :3 0
6c :2 0 1bd :4 0
124d 1eee 1ef0 :3 0
6c :2 0 72 :3 0
71 :3 0 3a :3 0
31 :2 0 1250 1ef4
1ef7 1253 1ef3 1ef9
1255 1ef2 1efb :3 0
6c :2 0 1be :4 0
1258 1efd 1eff :3 0
6c :2 0 72 :3 0
71 :3 0 3f :3 0
31 :2 0 125b 1f03
1f06 125e 1f02 1f08
1260 1f01 1f0a :3 0
6c :2 0 1bf :4 0
1263 1f0c 1f0e :3 0
6c :2 0 1c0 :4 0
1266 1f10 1f12 :3 0
6c :2 0 1c1 :4 0
1269 1f14 1f16 :3 0
6c :2 0 1c2 :4 0
126c 1f18 1f1a :3 0
6c :2 0 1c3 :4 0
126f 1f1c 1f1e :3 0
6c :2 0 1c4 :4 0
1272 1f20 1f22 :3 0
6c :2 0 17 :3 0
1275 1f24 1f26 :3 0
6c :2 0 1c5 :4 0
1278 1f28 1f2a :3 0
6c :2 0 2a :3 0
127b 1f2c 1f2e :3 0
6c :2 0 1c6 :4 0
127e 1f30 1f32 :3 0
6c :2 0 1d6 :4 0
1281 1f34 1f36 :3 0
1ed1 1f37 0 1f3a
a9 :3 0 1284 1f3b
1ed0 1f3a 0 1fbb
71 :3 0 19a :3 0
2b :3 0 1286 1f3d
1f3f 31 :2 0 1288
1f3c 1f42 cc :2 0
31 :2 0 128d 1f44
1f46 :3 0 59 :3 0
1c8 :4 0 6c :2 0
1c9 :4 0 1290 1f4a
1f4c :3 0 6c :2 0
81 :3 0 1ca :3 0
1f4f 1f50 0 1293
1f4e 1f52 :3 0 6c
:2 0 1cb :4 0 1296
1f54 1f56 :3 0 6c
:2 0 81 :3 0 1ca
:3 0 1f59 1f5a 0
1299 1f58 1f5c :3 0
6c :2 0 1cc :4 0
129c 1f5e 1f60 :3 0
6c :2 0 1cd :4 0
129f 1f62 1f64 :3 0
6c :2 0 1ce :4 0
12a2 1f66 1f68 :3 0
6c :2 0 72 :3 0
71 :3 0 39 :3 0
31 :2 0 12a5 1f6c
1f6f 12a8 1f6b 1f71
12aa 1f6a 1f73 :3 0
6c :2 0 1bd :4 0
12ad 1f75 1f77 :3 0
6c :2 0 72 :3 0
71 :3 0 3a :3 0
31 :2 0 12b0 1f7b
1f7e 12b3 1f7a 1f80
12b5 1f79 1f82 :3 0
6c :2 0 1cf :4 0
12b8 1f84 1f86 :3 0
6c :2 0 1d0 :4 0
12bb 1f88 1f8a :3 0
6c :2 0 72 :3 0
71 :3 0 3f :3 0
31 :2 0 12be 1f8e
1f91 12c1 1f8d 1f93
12c3 1f8c 1f95 :3 0
6c :2 0 1d1 :4 0
12c6 1f97 1f99 :3 0
6c :2 0 1d2 :4 0
12c9 1f9b 1f9d :3 0
6c :2 0 17 :3 0
12cc 1f9f 1fa1 :3 0
6c :2 0 1d3 :4 0
12cf 1fa3 1fa5 :3 0
6c :2 0 2b :3 0
12d2 1fa7 1fa9 :3 0
6c :2 0 1d4 :4 0
12d5 1fab 1fad :3 0
6c :2 0 1d5 :4 0
12d8 1faf 1fb1 :3 0
6c :2 0 1d6 :4 0
12db 1fb3 1fb5 :3 0
1f48 1fb6 0 1fb8
12de 1fb9 1f47 1fb8
0 1fbb 1de9 1ec4
0 1fbb 12e0 0
2002 64 :3 0 65
:3 0 1fbc 1fbd 0
64 :3 0 75 :3 0
1fbf 1fc0 0 23
:2 0 2 :4 0 1d7
:2 0 77 :2 0 23
:2 0 12e4 1fc5 1fc7
:3 0 12e7 1fc1 1fc9
1fbe 1fcb 1fca :2 0
67 :3 0 78 :3 0
1fcd 1fce 0 69
:4 0 1d8 :4 0 6c
:2 0 6d :3 0 12eb
1fd2 1fd4 :3 0 12ee
1fcf 1fd6 :2 0 1fd8
12f1 1fd9 1fcc 1fd8
0 1fda 12f3 0
2002 64 :3 0 65
:3 0 1fdb 1fdc 0
64 :3 0 75 :3 0
1fde 1fdf 0 23
:2 0 2 :4 0 1d9
:2 0 77 :2 0 23
:2 0 12f5 1fe4 1fe6
:3 0 12f8 1fe0 1fe8
1fdd 1fea 1fe9 :2 0
67 :3 0 78 :3 0
1fec 1fed 0 69
:4 0 1da :4 0 6c
:2 0 6d :3 0 12fc
1ff1 1ff3 :3 0 12ff
1fee 1ff5 :2 0 1ff7
1302 1ff8 1feb 1ff7
0 1ff9 1304 0
2002 14 :3 0 85
:3 0 1db :3 0 1ffb
1ffc 0 59 :3 0
1306 1ffd 1fff 2000
:2 0 2002 1308 20a3
15 :3 0 1dc :2 0
4 2003 2004 0
64 :3 0 65 :3 0
2006 2007 0 64
:3 0 75 :3 0 2009
200a 0 9a :2 0
2 :4 0 1dd :2 0
77 :2 0 23 :2 0
1335 200f 2011 :3 0
1338 200b 2013 2008
2015 2014 :2 0 67
:3 0 78 :3 0 2017
2018 0 69 :4 0
1de :4 0 6c :2 0
6d :3 0 133c 201c
201e :3 0 133f 2019
2020 :2 0 2039 67
:3 0 78 :3 0 2022
2023 0 69 :4 0
1df :4 0 6c :2 0
15 :3 0 1e0 :3 0
2028 2029 0 1342
2027 202b :3 0 6c
:2 0 c2 :4 0 1345
202d 202f :3 0 6c
:2 0 15 :3 0 1e1
:3 0 2032 2033 0
1348 2031 2035 :3 0
134b 2024 2037 :2 0
2039 134e 203a 2016
2039 0 203b 1351
0 204b 1e2 :3 0
63 :3 0 15 :3 0
1e0 :3 0 1e3 :3 0
15 :3 0 1e1 :3 0
1e4 :3 0 94 :4 0
1e5 1 :a 0 2047
:2 0 204b 203d 2045
:2 0 14 :3 0 63
:3 0 2049 :2 0 204b
1353 204d 1357 204c
204b :2 0 20a1 99
:3 0 15 :3 0 96
:3 0 2050 2051 0
97 :3 0 2052 2053
0 2099 64 :3 0
65 :3 0 2055 2056
0 64 :3 0 75
:3 0 2058 2059 0
9a :2 0 2 :4 0
1e6 :2 0 77 :2 0
23 :2 0 1359 205e
2060 :3 0 135c 205a
2062 2057 2064 2063
:2 0 67 :3 0 78
:3 0 2066 2067 0
69 :4 0 1e7 :4 0
6c :2 0 6d :3 0
1360 206b 206d :3 0
1363 2068 206f :2 0
2089 67 :3 0 78
:3 0 2071 2072 0
69 :4 0 9d :4 0
6c :2 0 97 :3 0
1366 2076 2078 :3 0
6c :2 0 9e :4 0
1369 207a 207c :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 136c 207f
2083 1370 207e 2085
:3 0 1373 2073 2087
:2 0 2089 1376 208a
2065 2089 0 208b
1379 0 2099 1e2
:3 0 63 :3 0 1e3
:3 0 15 :3 0 1e1
:3 0 1e4 :3 0 94
:4 0 1e8 1 :a 0
2095 :2 0 2099 208d
2093 :2 0 14 :3 0
63 :3 0 2097 :2 0
2099 137b 209c :3 0
209c 0 209c 209b
2099 209a :6 0 209e
1 :3 0 1380 20a0
1382 209f 209e :2 0
20a1 1384 :2 0 20a3
1387 20a3 20a2 2002
20a1 :6 0 20a4 :2 0
2 44 20a3 20a7
:3 0 20a6 20a4 20a8
:8 0 
13ca
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
4f 1 4d 1
56 1 54 1
5d 1 5b 1
64 1 62 1
6b 1 69 1
72 1 70 1
77 1 7e 1
7c 1 85 1
83 1 8c 1
8a 1 93 1
91 1 9a 1
98 1 a1 1
9f 1 a8 1
a6 1 af 1
ad 1 b4 1
b9 1 c0 1
be 1 c5 1
cb 1 d1 1
d7 1 dd 1
e3 1 e9 1
ef 1 f5 1
fb 1 101 1
107 1 10d 1
113 1 119 1
11f 1 125 1
12b 1 131 1
137 1 13d 1
143 1 149 1
14f 1 155 1
15b 1 161 1
167 1 16d 1
173 1 179 1
17f 1 185 1
18d 1 18b 1
194 1 192 1
199 1 19f 1
1a7 1 1a5 1
1ac 1 1b2 1
1b8 1 1be 1
1c4 1 1ca 1
1d0 1 1d6 1
1db 1 1e8 1
1f4 2 1f7 1f9
2 1fc 1fe 2
200 202 2 204
206 2 208 20a
2 20c 20e 2
210 212 2 214
216 2 218 21a
2 21c 21e 2
220 222 2 224
226 2 228 22a
1 230 2 232
233 2 22c 235
2 237 239 1
23f 2 241 242
2 23b 244 2
246 248 1 24e
2 250 251 2
24a 253 2 255
257 1 25d 2
25f 260 2 259
262 2 264 266
1 26c 2 26e
26f 2 268 271
2 273 275 1
27b 2 27d 27e
2 277 280 2
282 284 1 28a
2 28c 28d 2
286 28f 2 291
293 1 299 2
29b 29c 2 295
29e 2 2a0 2a2
1 2a8 2 2aa
2ab 2 2a4 2ad
2 2af 2b1 1
2b7 2 2b9 2ba
2 2b3 2bc 2
2be 2c0 2 2c2
2c4 2 2c6 2c8
2 2ca 2cc 2
2ce 2d0 2 2d2
2d4 2 2d6 2d8
2 2da 2dc 2
2de 2e0 4 1f0
1f6 1fb 2e2 1
2e4 1 2e6 2
2f0 2f2 3 2ee
2ef 2f4 2 2fd
2ff 2 2fc 301
1 303 1 305
2 337 338 1
33a 1 344 2
351 353 3 34f
350 355 2 35e
360 2 362 364
2 366 368 1
370 2 372 373
2 36a 375 2
35d 377 1 379
1 37b 2 385
387 3 383 384
389 2 392 394
2 391 396 1
398 1 39a 2
3a1 3a2 3 37c
39b 3a4 1 3a6
2 3a9 3aa 1
3ae 2 3ac 3ae
2 3b2 3b3 1
3b7 2 3b5 3b7
2 3bd 3be 1
3c2 2 3c0 3c2
2 3cf 3d1 3
3cd 3ce 3d3 2
3dc 3de 2 3e0
3e2 2 3e4 3e6
1 3ee 2 3f0
3f1 2 3e8 3f3
2 3db 3f5 1
3f7 1 3f9 2
403 405 3 401
402 407 2 410
412 2 40f 414
1 416 1 418
2 41f 420 3
3fa 419 422 1
424 2 427 428
1 42e 2 42a
42e 1 432 1
43a 2 44a 44f
1 456 1 451
2 469 46b 3
467 468 46d 2
476 478 2 47a
47c 2 47e 480
2 482 484 2
486 488 3 48d
48e 48f 2 48a
491 2 475 493
1 495 1 497
2 460 498 1
49c 1 45b 2
459 4a0 1 4ab
2 4a7 4ab 2
4b0 4b1 1 4b5
2 4b3 4b5 2
4c3 4c5 3 4c1
4c2 4c7 2 4d0
4d2 2 4d4 4d6
2 4d8 4da 1
4e2 2 4e4 4e5
2 4dc 4e7 2
4cf 4e9 1 4eb
1 4ed 2 4f7
4f9 3 4f5 4f6
4fb 2 504 506
2 503 508 1
50a 1 50c 2
513 514 3 4ee
50d 516 1 518
3 4a3 519 51c
1 51f 1 525
2 530 535 1
53c 1 537 2
54f 551 3 54d
54e 553 2 55c
55e 2 560 562
2 564 566 2
568 56a 2 56c
56e 3 573 574
575 2 570 577
2 55b 579 1
57b 1 57d 2
546 57e 1 582
1 541 2 53f
586 1 589 2
58d 58c 2 595
596 2 598 59b
2 59e 59f 2
5a6 5a7 2 5a9
5ac 2 5b2 5b3
1 5b9 2 5b5
5b9 1 5be 1
5c0 2 5c3 5c4
1 5c8 2 5c6
5c8 2 5d6 5db
1 5e2 1 5dd
2 5f5 5f7 3
5f3 5f4 5f9 2
602 604 2 606
608 2 60a 60c
2 60e 610 2
612 614 3 619
61a 61b 2 616
61d 2 601 61f
1 621 1 623
2 5ec 624 1
628 1 5e7 2
5e5 62c 1 637
2 633 637 2
641 646 1 64d
1 648 2 660
662 3 65e 65f
664 2 66d 66f
2 671 673 2
675 677 2 679
67b 2 67d 67f
3 684 685 686
2 681 688 2
66c 68a 1 68c
1 68e 2 657
68f 1 693 1
652 2 650 697
1 6a2 2 69e
6a2 2 6ae 6b0
3 6ac 6ad 6b2
2 6bb 6bd 2
6bf 6c1 2 6c3
6c5 1 6cd 2
6cf 6d0 2 6c7
6d2 2 6d4 6d6
2 6d8 6da 2
6dc 6de 2 6e0
6e2 2 6ba 6e4
1 6e6 1 6e8
2 6f2 6f4 3
6f0 6f1 6f6 2
6ff 701 2 6fe
703 1 705 1
707 3 70e 70f
710 3 6e9 708
712 1 714 2
69a 715 1 717
2 721 726 1
72d 1 728 2
740 742 3 73e
73f 744 2 74d
74f 2 751 753
2 755 757 2
759 75b 2 75d
75f 3 764 765
766 2 761 768
2 74c 76a 1
76c 1 76e 2
737 76f 1 773
1 732 2 730
777 2 77d 77e
1 782 2 780
782 2 78a 78f
1 796 1 791
2 7a9 7ab 3
7a7 7a8 7ad 2
7b6 7b8 2 7ba
7bc 2 7be 7c0
2 7c2 7c4 2
7c6 7c8 3 7cd
7ce 7cf 2 7ca
7d1 2 7b5 7d3
1 7d5 1 7d7
2 7a0 7d8 1
7dc 1 79b 2
799 7e0 2 7e8
7e9 1 7ed 2
7eb 7ed 2 7f8
7fa 3 7f6 7f7
7fc 2 805 807
2 809 80b 2
80d 80f 1 817
2 819 81a 2
811 81c 2 81e
820 2 822 824
2 826 828 2
82a 82c 2 804
82e 1 830 1
832 2 83c 83e
3 83a 83b 840
2 849 84b 2
848 84d 1 84f
1 851 3 858
859 85a 3 833
852 85c 1 85e
2 7e3 85f 1
861 5 62f 718
71b 77a 862 1
864 2 871 873
3 86f 870 875
2 87e 880 2
882 884 2 886
888 1 890 2
892 893 2 88a
895 2 87d 897
1 899 1 89b
2 8a5 8a7 3
8a3 8a4 8a9 2
8b2 8b4 2 8b1
8b6 1 8b8 1
8ba 2 8c1 8c2
3 89c 8bb 8c4
1 8c6 3 8ce
8cf 8d0 3 8d2
8d3 8d4 4 8dc
8dd 8de 8df 2
8e5 8e6 1 8e8
1 8ec 2 8ea
8ec 2 907 90c
1 913 1 90e
2 926 928 3
924 925 92a 2
933 935 2 937
939 2 93b 93d
2 93f 941 2
943 945 3 94a
94b 94c 2 947
94e 2 932 950
1 952 1 954
2 91d 955 1
959 1 918 2
916 95d 1 968
2 964 968 2
974 976 3 972
973 978 2 981
983 2 985 987
2 989 98b 1
993 2 995 996
2 98d 998 2
99a 99c 2 99e
9a0 2 9a2 9a4
2 9a6 9a8 2
980 9aa 1 9ac
1 9ae 2 9b8
9ba 3 9b6 9b7
9bc 2 9c5 9c7
2 9c4 9c9 1
9cb 1 9cd 3
9d4 9d5 9d6 3
9af 9ce 9d8 1
9da 2 960 9db
2 9e5 9e7 3
9e3 9e4 9e9 2
9f2 9f4 2 9f6
9f8 2 9fa 9fc
1 a04 2 a06
a07 2 9fe a09
2 a0b a0d 2
a0f a11 2 a13
a15 2 a17 a19
2 9f1 a1b 1
a1d 1 a1f 2
a29 a2b 3 a27
a28 a2d 2 a36
a38 2 a35 a3a
1 a3c 1 a3e
3 a45 a46 a47
3 a20 a3f a49
2 a4b a4c 5
8c7 8ca 8d7 8e2
a4d 2 a4f a50
2 a53 a54 1
a58 2 a56 a58
2 a5d a5e 1
a62 2 a60 a62
1 a6a 1 a6c
1 a70 2 a6e
a70 2 a7e a7f
2 a83 a84 2
a88 a89 2 a8d
a8e 2 a92 a93
2 a97 a98 2
a9c a9d 2 aa1
aa2 d a7b a7c
a81 a86 a8b a90
a95 a9a a9f aa4
aa5 aa6 aa7 2
aac aad 1 ab3
2 aaf ab3 2
abe ac0 3 abc
abd ac2 2 acb
acd 2 acf ad1
2 ad3 ad5 1
add 2 adf ae0
2 ad7 ae2 2
aca ae4 1 ae6
1 ae8 2 af2
af4 3 af0 af1
af6 2 aff b01
2 afe b03 1
b05 1 b07 2
b0e b0f 3 ae9
b08 b11 2 b15
b16 1 b1a 2
b18 b1a 2 b25
b27 3 b23 b24
b29 2 b32 b34
2 b36 b38 2
b3a b3c 1 b42
2 b44 b45 2
b3e b47 2 b49
b4b 2 b4d b4f
2 b51 b53 2
b55 b57 2 b31
b59 1 b5b 1
b5d 2 b67 b69
3 b65 b66 b6b
2 b74 b76 2
b73 b78 1 b7a
1 b7c 2 b82
b83 3 b85 b86
b87 3 b5e b7d
b89 2 b8c b8b
4 a75 a78 aaa
b8d 2 b91 b92
1 b96 2 b94
b96 2 b9a b9b
1 b9f 2 b9d
b9f 2 baa bac
3 ba8 ba9 bae
2 bb7 bb9 2
bbb bbd 2 bbf
bc1 1 bc9 2
bcb bcc 2 bc3
bce 2 bd0 bd2
2 bd4 bd6 2
bd8 bda 2 bdc
bde 2 bb6 be0
1 be2 1 be4
2 bee bf0 3
bec bed bf2 2
bfb bfd 2 bfa
bff 1 c01 1
c03 3 c0a c0b
c0c 3 be5 c04
c0e 1 c10 2
c13 c14 1 c18
2 c16 c18 1
c1d 2 c23 c24
1 c26 2 c28
c2a 1 c2c 1
c2f 2 c31 c32
2 c11 c33 2
c36 c35 2 c39
c3a 1 c3e 2
c3c c3e 2 c43
c44 1 c48 2
c46 c48 2 c4f
c50 1 c54 2
c52 c54 2 c59
c5a 1 c5e 2
c5c c5e 1 c66
2 c6a c6b 1
c6f 2 c6d c6f
1 c74 2 c79
c7a 1 c7e 2
c7c c7e 2 c83
c84 1 c88 2
c86 c88 1 c90
2 c95 c96 1
c9a 2 c98 c9a
2 c9f ca0 2
ca5 ca6 2 ca2
ca8 2 cab cae
4 cb1 c77 c93
cb0 1 cb2 1
cb4 3 cc9 cca
ccb 3 cd1 cd2
cd3 2 cd8 cd9
1 cdd 2 cdb
cdd 3 ce7 ce8
ce9 1 ced 2
ceb ced 2 d09
d0e 1 d15 1
d10 2 d28 d2a
3 d26 d27 d2c
2 d35 d37 2
d39 d3b 2 d3d
d3f 2 d41 d43
2 d45 d47 3
d4c d4d d4e 2
d49 d50 2 d34
d52 1 d54 1
d56 2 d1f d57
1 d5b 1 d1a
2 d18 d5f 2
d69 d6e 1 d75
1 d70 2 d88
d8a 3 d86 d87
d8c 2 d95 d97
2 d99 d9b 2
d9d d9f 2 da1
da3 2 da5 da7
3 dac dad dae
2 da9 db0 2
d94 db2 1 db4
1 db6 2 d7f
db7 1 dbb 1
d7a 2 d78 dbf
1 dca 2 dc6
dca 2 dd6 dd8
3 dd4 dd5 dda
2 de3 de5 2
de7 de9 2 deb
ded 1 df5 2
df7 df8 2 def
dfa 2 dfc dfe
2 e00 e02 2
e04 e06 2 e08
e0a 2 de2 e0c
1 e0e 1 e10
2 e1a e1c 3
e18 e19 e1e 2
e27 e29 2 e26
e2b 1 e2d 1
e2f 3 e36 e37
e38 3 e11 e30
e3a 1 e3c 2
e4b e50 1 e57
1 e52 2 e6a
e6c 3 e68 e69
e6e 2 e77 e79
2 e7b e7d 2
e7f e81 2 e83
e85 2 e87 e89
3 e8e e8f e90
2 e8b e92 2
e76 e94 1 e96
1 e98 2 e61
e99 1 e9d 1
e5c 2 e5a ea1
5 d62 dc2 e3d
e40 ea4 3 ea9
eaa eab 1 eaf
2 ead eaf 2
eb7 ebc 1 ec3
1 ebe 2 ed6
ed8 3 ed4 ed5
eda 2 ee3 ee5
2 ee7 ee9 2
eeb eed 2 eef
ef1 2 ef3 ef5
3 efa efb efc
2 ef7 efe 2
ee2 f00 1 f02
1 f04 2 ecd
f05 1 f09 1
ec8 2 ec6 f0d
1 f18 2 f14
f18 2 f24 f26
3 f22 f23 f28
2 f31 f33 2
f35 f37 2 f39
f3b 1 f43 2
f45 f46 2 f3d
f48 2 f4a f4c
2 f4e f50 2
f52 f54 2 f56
f58 2 f30 f5a
1 f5c 1 f5e
2 f68 f6a 3
f66 f67 f6c 2
f75 f77 2 f74
f79 1 f7b 1
f7d 3 f84 f85
f86 3 f5f f7e
f88 1 f8a 2
fa8 fad 1 fb4
1 faf 2 fc7
fc9 3 fc5 fc6
fcb 2 fd4 fd6
2 fd8 fda 2
fdc fde 2 fe0
fe2 2 fe4 fe6
3 feb fec fed
2 fe8 fef 2
fd3 ff1 1 ff3
1 ff5 2 fbe
ff6 1 ffa 1
fb9 2 fb7 ffe
1 1009 2 1005
1009 2 1029 102e
1 1035 1 1030
2 1048 104a 3
1046 1047 104c 2
1055 1057 2 1059
105b 2 105d 105f
2 1061 1063 2
1065 1067 3 106c
106d 106e 2 1069
1070 2 1054 1072
1 1074 1 1076
2 103f 1077 1
107b 1 103a 2
1038 107f 1 108a
2 1086 108a 1
1090 2 1096 1097
1 1099 1 109d
2 109b 109d 2
10ad 10b2 1 10b9
1 10b4 2 10cc
10ce 3 10ca 10cb
10d0 2 10d9 10db
2 10dd 10df 2
10e1 10e3 2 10e5
10e7 2 10e9 10eb
3 10f0 10f1 10f2
2 10ed 10f4 2
10d8 10f6 1 10f8
1 10fa 2 10c3
10fb 1 10ff 1
10be 2 10bc 1103
2 1109 110a 1
110e 2 110c 110e
2 1119 111b 3
1117 1118 111d 2
1126 1128 2 112a
112c 2 112e 1130
1 1138 2 113a
113b 2 1132 113d
2 113f 1141 2
1143 1145 2 1147
1149 2 114b 114d
2 1125 114f 1
1151 1 1153 2
115d 115f 3 115b
115c 1161 2 116a
116c 2 1169 116e
1 1170 1 1172
3 1179 117a 117b
3 1154 1173 117d
1 117f 3 10a2
1106 1180 1 1182
2 1093 1183 1
1185 3 100f 1082
1186 1 1188 2
1194 1199 1 11a0
1 119b 2 11b3
11b5 3 11b1 11b2
11b7 2 11c0 11c2
2 11c4 11c6 2
11c8 11ca 2 11cc
11ce 2 11d0 11d2
3 11d7 11d8 11d9
2 11d4 11db 2
11bf 11dd 1 11df
1 11e1 2 11aa
11e2 1 11e6 1
11a5 2 11a3 11ea
6 f10 f8b f8e
1001 1189 11ed 2
11f9 11fb 3 11f7
11f8 11fd 2 1206
1208 2 120a 120c
2 120e 1210 1
1218 2 121a 121b
2 1212 121d 2
1205 121f 1 1221
1 1223 2 122d
122f 3 122b 122c
1231 2 123a 123c
2 1239 123e 1
1240 1 1242 2
1249 124a 3 1224
1243 124c 3 124e
11f0 124f 1 1257
2 1253 1257 2
125f 1260 4 125d
1262 1265 1266 2
126e 126f 4 126c
1271 1274 1275 1
12a1 2 12a0 12a1
1 12a9 1 12af
2 12b1 12b2 2
129e 12b3 1 12ba
1 12b5 2 12cd
12cf 3 12cb 12cc
12d1 2 12da 12dc
2 12de 12e0 2
12e2 12e4 2 12e6
12e8 2 12ea 12ec
3 12f1 12f2 12f3
2 12ee 12f5 2
12d9 12f7 1 12f9
1 12fb 2 12c4
12fc 1 1300 1
12bf 2 12bd 1304
1 130b 4 1269
1278 1307 130e 2
1319 131a 4 1317
131c 131f 1320 7
132e 132f 1330 1331
1332 1333 1334 1
1353 2 1352 1353
1 135b 1 1361
2 1363 1364 2
1350 1365 1 136c
1 1367 2 137f
1381 3 137d 137e
1383 2 138c 138e
2 1390 1392 2
1394 1396 2 1398
139a 2 139c 139e
3 13a3 13a4 13a5
2 13a0 13a7 2
138b 13a9 1 13ab
1 13ad 2 1376
13ae 1 13b2 1
1371 2 136f 13b6
6 1314 1323 1328
132b 1337 13b9 2
13bc 13bd 2 13c0
13c1 1 13c5 2
13c3 13c5 1 13c9
1 13d2 2 13d0
13d2 2 13d9 13da
1 13de 2 13dc
13de 2 13e2 13e3
1 13e7 2 13e5
13e7 2 13ec 13ed
1 13f0 2 13f6
13f7 2 13fc 13fd
2 13f9 13ff 1
1402 2 1404 1406
2 1408 140a 1
140c 1 140f 2
1411 1412 2 1438
143d 1 1444 1
143f 2 1457 1459
3 1455 1456 145b
2 1464 1466 2
1468 146a 2 146c
146e 2 1470 1472
2 1474 1476 3
147b 147c 147d 2
1478 147f 2 1463
1481 1 1483 1
1485 2 144e 1486
1 148a 1 1449
2 1447 148e 1
1493 2 14a1 14a6
1 14ad 1 14a8
2 14c0 14c2 3
14be 14bf 14c4 2
14cd 14cf 2 14d1
14d3 2 14d5 14d7
2 14d9 14db 2
14dd 14df 3 14e4
14e5 14e6 2 14e1
14e8 2 14cc 14ea
1 14ec 1 14ee
2 14b7 14ef 1
14f3 1 14b2 2
14b0 14f7 1 14fa
2 150b 1510 1
1517 1 1512 2
152a 152c 3 1528
1529 152e 2 1537
1539 2 153b 153d
2 153f 1541 2
1543 1545 2 1547
1549 3 154e 154f
1550 2 154b 1552
2 1536 1554 1
1556 1 1558 2
1521 1559 1 155d
1 151c 2 151a
1561 1 1564 2
1567 1568 1 156c
2 156a 156c 3
1572 1573 1574 1
1578 2 1576 1578
2 1585 1587 3
1583 1584 1589 2
1592 1594 2 1596
1598 2 159a 159c
1 15a4 2 15a6
15a7 2 159e 15a9
2 15ab 15ad 2
15af 15b1 2 15b3
15b5 2 15b7 15b9
2 1591 15bb 1
15bd 1 15bf 2
15c9 15cb 3 15c7
15c8 15cd 2 15d6
15d8 2 15d5 15da
1 15dc 1 15de
3 15e5 15e6 15e7
3 15c0 15df 15e9
1 15eb 5 1413
1416 1491 1569 15ec
1 15f1 2 15ef
15f1 2 1606 160b
1 1612 1 160d
2 1625 1627 3
1623 1624 1629 2
1632 1634 2 1636
1638 2 163a 163c
2 163e 1640 2
1642 1644 3 1649
164a 164b 2 1646
164d 2 1631 164f
1 1651 1 1653
2 161c 1654 1
1658 1 1617 2
1615 165c 2 1671
1676 1 167d 1
1678 2 1690 1692
3 168e 168f 1694
2 169d 169f 2
16a1 16a3 2 16a5
16a7 2 16a9 16ab
2 16ad 16af 3
16b4 16b5 16b6 2
16b1 16b8 2 169c
16ba 1 16bc 1
16be 2 1687 16bf
1 16c3 1 1682
2 1680 16c7 2
16cd 16ce 2 16d3
16d4 2 16d9 16da
2 16d6 16dc 1
16df 2 16d0 16df
2 16ea 16ec 3
16e8 16e9 16ee 2
16f7 16f9 2 16fb
16fd 2 16ff 1701
1 1709 2 170b
170c 2 1703 170e
2 1710 1712 2
1714 1716 2 1718
171a 2 171c 171e
2 16f6 1720 1
1722 1 1724 2
172e 1730 3 172c
172d 1732 2 173b
173d 2 173a 173f
1 1741 1 1743
3 174a 174b 174c
3 1725 1744 174e
1 1750 5 15f6
165f 1663 16ca 1751
2 1754 1753 2
175b 1760 1 1767
1 1762 2 177a
177c 3 1778 1779
177e 2 1787 1789
2 178b 178d 2
178f 1791 2 1793
1795 2 1797 1799
3 179e 179f 17a0
2 179b 17a2 2
1786 17a4 1 17a6
1 17a8 2 1771
17a9 1 17ad 1
176c 2 176a 17b1
3 17b7 17b8 17b9
1 17bd 2 17bb
17bd 1 17c2 a
17ca 17cb 17cc 17cd
17ce 17cf 17d0 17d1
17d2 17d3 2 17c5
17d6 1 17d8 3
1755 17b4 17d9 1
17db 3 17de 17df
17e0 1 17e4 2
17e2 17e4 1 17eb
2 17ef 17f0 1
17f3 2 17f5 17f6
21 17fa 17fb 17fc
17fd 17fe 17ff 1800
1801 1802 1803 1804
1805 1806 1807 1808
1809 180a 180b 180c
180d 180e 180f 1810
1811 1812 1813 1814
1815 1816 1817 1818
1819 181a 1 1820
2 181e 1820 1
182a 2 1829 182a
1 1832 1 1838
2 183a 183b 2
1827 183c 1 1843
1 183e 2 1856
1858 3 1854 1855
185a 2 1863 1865
2 1867 1869 2
186b 186d 2 186f
1871 2 1873 1875
3 187a 187b 187c
2 1877 187e 2
1862 1880 1 1882
1 1884 2 184d
1885 1 1889 1
1848 2 1846 188d
1 1890 1 1893
8 ce2 ce5 1250
13be 17dc 17f7 181d
1894 1 18a1 2
18a3 18a4 1 18a8
2 18a6 18a8 1
18ad 1 18b3 2
18b5 18b6 2 18b8
18ba 2 18bd 18bf
1 18c1 1 18c4
2 18c6 18c7 1
18cb 2 18c9 18cb
2 18d3 18d4 1
18d7 2 18d6 18d7
2 18e4 18e5 2
18e7 18e9 2 18eb
18ed 4 18e1 18e2
18ef 18f0 2 18fb
18fc 2 18fe 1900
2 1902 1904 2
1906 1908 4 18f8
18f9 190a 190b 3
1910 1911 1912 1
1916 2 1914 1916
1 1920 2 1922
1923 1 1927 2
1925 1927 1 192c
2 1930 1932 3
1934 1935 1936 2
193c 193e 3 1940
1941 1942 2 1939
1945 2 1947 1948
2 191d 1949 2
194d 194e 1 1954
2 1956 1957 1
195b 2 1959 195b
1 1960 2 1964
1966 3 1968 1969
196a 2 1970 1972
3 1974 1975 1976
2 196d 1979 2
197b 197c 2 1951
197d 2 197f 1980
3 1983 1984 1985
1 1989 2 1987
1989 1 198e 1
1990 2 19a4 19a9
1 19b0 1 19ab
2 19c3 19c5 3
19c1 19c2 19c7 2
19d0 19d2 2 19d4
19d6 2 19d8 19da
2 19dc 19de 2
19e0 19e2 3 19e7
19e8 19e9 2 19e4
19eb 2 19cf 19ed
1 19ef 1 19f1
2 19ba 19f2 1
19f6 1 19b5 2
19b3 19fa 1 1a05
2 1a01 1a05 2
1a15 1a1a 1 1a21
1 1a1c 2 1a34
1a36 3 1a32 1a33
1a38 2 1a41 1a43
2 1a45 1a47 2
1a49 1a4b 2 1a4d
1a4f 2 1a51 1a53
3 1a58 1a59 1a5a
2 1a55 1a5c 2
1a40 1a5e 1 1a60
1 1a62 2 1a2b
1a63 1 1a67 1
1a26 2 1a24 1a6b
1 1a76 2 1a72
1a76 1 1a7c 1
1a80 2 1a82 1a83
2 1a6e 1a84 1
1a86 2 1a89 1a8a
1 1a8e 2 1a8c
1a8e 2 1a92 1a93
1 1a97 2 1a95
1a97 2 1a9b 1a9c
1 1aa0 2 1a9e
1aa0 2 1aa5 1aa6
1 1aa9 2 1aaf
1ab0 2 1ab5 1ab6
2 1ab2 1ab8 1
1abb 2 1abd 1abf
2 1ac1 1ac3 1
1ac5 1 1ac8 2
1aca 1acb 2 1af1
1af6 1 1afd 1
1af8 2 1b10 1b12
3 1b0e 1b0f 1b14
2 1b1d 1b1f 2
1b21 1b23 2 1b25
1b27 2 1b29 1b2b
2 1b2d 1b2f 3
1b34 1b35 1b36 2
1b31 1b38 2 1b1c
1b3a 1 1b3c 1
1b3e 2 1b07 1b3f
1 1b43 1 1b02
2 1b00 1b47 1
1b4c 2 1b5f 1b64
1 1b6b 1 1b66
2 1b7e 1b80 3
1b7c 1b7d 1b82 2
1b8b 1b8d 2 1b8f
1b91 2 1b93 1b95
2 1b97 1b99 2
1b9b 1b9d 3 1ba2
1ba3 1ba4 2 1b9f
1ba6 2 1b8a 1ba8
1 1baa 1 1bac
2 1b75 1bad 1
1bb1 1 1b70 2
1b6e 1bb5 1 1bb8
1 1bbb 4 1acc
1acf 1b4a 1bbc 3
1bc2 1bc3 1bc4 1
1bc8 2 1bc6 1bc8
3 1bce 1bcf 1bd0
1 1bd4 2 1bd2
1bd4 2 1be2 1be7
1 1bee 1 1be9
2 1c01 1c03 3
1bff 1c00 1c05 2
1c0e 1c10 2 1c12
1c14 2 1c16 1c18
2 1c1a 1c1c 2
1c1e 1c20 3 1c25
1c26 1c27 2 1c22
1c29 2 1c0d 1c2b
1 1c2d 1 1c2f
2 1bf8 1c30 1
1c34 1 1bf3 2
1bf1 1c38 1 1c3b
2 1c41 1c44 3
1c46 1c3e 1c47 1
1c48 2 1c4c 1c4f
2 1c51 1c52 2
1c55 1c56 1 1c5a
2 1c58 1c5a 3
1c5e 1c5f 1c60 1
1c64 2 1c62 1c64
1 1c69 1 1c6b
1 1c6c 3 1c70
1c71 1c72 1 1c76
2 1c74 1c76 1
1c7d 2 1c82 1c83
1 1c86 3 1c88
1c7f 1c89 21 1c8d
1c8e 1c8f 1c90 1c91
1c92 1c93 1c94 1c95
1c96 1c97 1c98 1c99
1c9a 1c9b 1c9c 1c9d
1c9e 1c9f 1ca0 1ca1
1ca2 1ca3 1ca4 1ca5
1ca6 1ca7 1ca8 1ca9
1caa 1cab 1cac 1cad
1 1cb3 2 1cb1
1cb3 1 1cbd 2
1cbc 1cbd 1 1cc5
1 1ccb 2 1ccd
1cce 2 1cba 1ccf
1 1cd6 1 1cd1
2 1ce9 1ceb 3
1ce7 1ce8 1ced 2
1cf6 1cf8 2 1cfa
1cfc 2 1cfe 1d00
2 1d02 1d04 2
1d06 1d08 3 1d0d
1d0e 1d0f 2 1d0a
1d11 2 1cf5 1d13
1 1d15 1 1d17
2 1ce0 1d18 1
1d1c 1 1cdb 2
1cd9 1d20 1 1d23
1 1d26 2 1d2a
1d2b 2 1d2d 1d2f
d 18f3 190e 1981
1991 1994 1997 19fd
1a87 1c53 1c8a 1cb0
1d27 1d32 2 18d0
1d35 1 1d37 5
1898 189b 189e 18c8
1d38 2 1d3a 1d3b
1 1d3f 2 1d3d
1d3f 2 1d44 1d45
1 1d49 2 1d47
1d49 2 1d57 1d59
3 1d55 1d56 1d5b
2 1d64 1d66 2
1d68 1d6a 2 1d6c
1d6e 1 1d76 2
1d78 1d79 2 1d70
1d7b 2 1d7d 1d7f
2 1d81 1d83 2
1d85 1d87 2 1d89
1d8b 2 1d63 1d8d
1 1d8f 1 1d91
2 1d9b 1d9d 3
1d99 1d9a 1d9f 2
1da8 1daa 2 1da7
1dac 1 1dae 1
1db0 3 1db7 1db8
1db9 3 1d92 1db1
1dbb 1 1dbd 2
1dc0 1dc1 1 1dc5
2 1dc3 1dc5 1
1dca 1 1dcc 1
1dd0 2 1dd2 1dd3
1 1dd7 2 1dd5
1dd7 1 1ddd 2
1ddf 1de0 1 1de4
2 1de2 1de4 2
1deb 1ded 2 1def
1df1 2 1df3 1df5
2 1df7 1df9 2
1dff 1e00 1 1e02
2 1dfb 1e04 2
1e06 1e08 2 1e0e
1e0f 1 1e11 2
1e0a 1e13 2 1e15
1e17 2 1e1d 1e1e
1 1e20 2 1e19
1e22 2 1e24 1e26
2 1e28 1e2a 2
1e2c 1e2e 2 1e30
1e32 2 1e34 1e36
2 1e38 1e3a 2
1e3c 1e3e 2 1e40
1e42 2 1e44 1e46
2 1e48 1e4a 2
1e4c 1e4e 2 1e50
1e52 2 1e54 1e56
2 1e58 1e5c 2
1e5e 1e60 2 1e62
1e66 2 1e68 1e6a
2 1e6c 1e6e 2
1e70 1e72 2 1e78
1e79 1 1e7b 2
1e74 1e7d 2 1e7f
1e81 2 1e87 1e88
1 1e8a 2 1e83
1e8c 2 1e8e 1e90
2 1e92 1e94 2
1e9a 1e9b 1 1e9d
2 1e96 1e9f 2
1ea1 1ea3 2 1ea5
1ea7 2 1ea9 1eab
2 1ead 1eaf 2
1eb1 1eb3 2 1eb5
1eb7 2 1eb9 1ebb
2 1ebd 1ebf 1
1ec2 1 1ec7 2
1ec9 1eca 1 1ece
2 1ecc 1ece 2
1ed2 1ed4 2 1ed6
1ed8 2 1eda 1edc
2 1ede 1ee0 2
1ee6 1ee7 1 1ee9
2 1ee2 1eeb 2
1eed 1eef 2 1ef5
1ef6 1 1ef8 2
1ef1 1efa 2 1efc
1efe 2 1f04 1f05
1 1f07 2 1f00
1f09 2 1f0b 1f0d
2 1f0f 1f11 2
1f13 1f15 2 1f17
1f19 2 1f1b 1f1d
2 1f1f 1f21 2
1f23 1f25 2 1f27
1f29 2 1f2b 1f2d
2 1f2f 1f31 2
1f33 1f35 1 1f38
1 1f3e 2 1f40
1f41 1 1f45 2
1f43 1f45 2 1f49
1f4b 2 1f4d 1f51
2 1f53 1f55 2
1f57 1f5b 2 1f5d
1f5f 2 1f61 1f63
2 1f65 1f67 2
1f6d 1f6e 1 1f70
2 1f69 1f72 2
1f74 1f76 2 1f7c
1f7d 1 1f7f 2
1f78 1f81 2 1f83
1f85 2 1f87 1f89
2 1f8f 1f90 1
1f92 2 1f8b 1f94
2 1f96 1f98 2
1f9a 1f9c 2 1f9e
1fa0 2 1fa2 1fa4
2 1fa6 1fa8 2
1faa 1fac 2 1fae
1fb0 2 1fb2 1fb4
1 1fb7 3 1fba
1f3b 1fb9 2 1fc4
1fc6 3 1fc2 1fc3
1fc8 2 1fd1 1fd3
2 1fd0 1fd5 1
1fd7 1 1fd9 2
1fe3 1fe5 3 1fe1
1fe2 1fe7 2 1ff0
1ff2 2 1fef 1ff4
1 1ff6 1 1ff8
1 1ffe 2c 2e7
306 309 30c 30f
312 315 318 31b
31e 321 324 327
32a 32d 330 333
33d 340 343 3a7
425 58e 5a2 5b0
5c1 a51 a6d c37
cb5 cba cbd cc0
cc3 cc6 cce cd6
1d3c 1dbe 1dcd 1fbb
1fda 1ff9 2001 2
200e 2010 3 200c
200d 2012 2 201b
201d 2 201a 201f
2 2026 202a 2
202c 202e 2 2030
2034 2 2025 2036
2 2021 2038 1
203a 3 203b 2046
204a 1 2005 2
205d 205f 3 205b
205c 2061 2 206a
206c 2 2069 206e
2 2075 2077 2
2079 207b 3 2080
2081 2082 2 207d
2084 2 2074 2086
2 2070 2088 1
208a 4 2054 208b
2094 2098 1 209c
1 204f 2 204d
20a0 42 4b 52
59 60 67 6e
75 7a 81 88
8f 96 9d a4
ab b2 b7 bc
c3 c9 cf d5
db e1 e7 ed
f3 f9 ff 105
10b 111 117 11d
123 129 12f 135
13b 141 147 14d
153 159 15f 165
16b 171 177 17d
183 189 190 197
19d 1a3 1aa 1b0
1b6 1bc 1c2 1c8
1ce 1d4 1d9 1e0

1
4
0 
20a7
0
1
50
3f
52
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 33 32 35 32 37
32 39 32 3b 32 3d 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3b 1 0
143 1 0
2b 1 0
173 1 0
185 1 0
1ca 1 0
14f 1 0
2f 1 0
1b2 1 0
a6 1 0
107 1 0
e3 1 0
1be 1 0
8a 1 0
27 1 0
167 1 0
18b 1 0
98 1 0
1f 1 0
1b 1 0
1d0 1 0
83 1 0
c5 1 0
17f 1 0
16d 1 0
91 1 0
d7 1 0
1a5 1 0
77 1 0
1d6 1 0
19f 1 0
13 1 0
101 1 0
f5 1 0
69 1 0
7c 1 0
137 1 0
9f 1 0
62 1 0
f 1 0
ef 1 0
15b 1 0
3 1 0
cb 1 0
b9 1 0
70 1 0
199 1 0
13d 1 0
161 1 0
11f 1 0
113 1 0
23 1 0
2 0 1
125 1 0
4d 1 0
1b8 1 0
7 1 0
155 1 0
fb 1 0
e9 1 0
149 1 0
dd 1 0
1ac 1 0
d1 1 0
5b 1 0
46 1 0
119 1 0
37 1 0
ad 1 0
12b 1 0
17 1 0
179 1 0
b4 1 0
be 1 0
131 1 0
54 1 0
33 1 0
1c4 1 0
10d 1 0
b 1 0
1db 1 0
192 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_3;
ALTER FUNCTION SP_SEARCH_3 COMPILE DEBUG;
/*
#Stored Procedure  :SP_I_PROFILE
#Short Description :Assign a profile to a task or project
#Description       :used tables: RESOURCE_ASSIGNMENTS, PROFILES
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_I_PROFILE ==
CREATE OR REPLACE FUNCTION SP_I_PROFILE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
bb
2 :e:
1FUNCTION:
1SP_I_PROFILE:
1PRJ_ID:
1VARCHAR2:
1AND_ROLES:
1AND_SKILLS:
1ORG_ID001:
1GEO_ID001:
1POOL_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_UNIQUEID:
132:
1H_AND_ROLES:
18000:
1H_ROLE_ID:
1H_FULL_NAME:
1255:
1H_COUNT:
1PLS_INTEGER:
10:
1H_NUMBER:
1H_TYPE_ID:
1NUMITEMS:
1NUMITEMS001:
1CURSOR:
1CEXISTS:
1PROFILE_ID:
1PROFILES:
1ROWNUM:
1PROJECT_ID:
1ROLE_ID:
1SELECT PROFILE_ID FROM PROFILES:n         WHERE  ROWNUM <= 1 AND  PROJECT_ID=+
1prj_id AND ROLE_ID=h_role_id:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_I_PROFILE(:
1':
1, :
1);:
1CHECK_TRACE:
11:
139:
1+:
1FPUT:
1               ENTER:: SP_I_PROFILE(40) :: cplan.sql(5821) :: :
1IS NULL:
18:
146:
1      RETURN_INVALID:: SP_I_PROFILE(47) :: cplan.sql(5828) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
149:
1                EXIT:: SP_I_PROFILE(50) :: cplan.sql(5831) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SUBSTR:
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
1TNGROLE:
17:
1=:
1SELECT PROFILE_ID INTO h_uniqueID:n            FROM PROFILES:n            WHE+
1RE PROJECT_ID=prj_id AND ROLE_ID=h_role_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
176:
1           EXCEPTION:: SP_I_PROFILE(77) :: cplan.sql(5858) :: :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1OPEN:
1FOUND:
1100:
1SC_SQL_SUCCESS:
1CLOSE:
1101:
1           EXCEPTION:: SP_I_PROFILE(102) :: cplan.sql(5883) :: :
1106:
1        RETURN_ERROR:: SP_I_PROFILE(107) :: cplan.sql(5888) :: :
1 ID:: :
1109:
1                EXIT:: SP_I_PROFILE(110) :: cplan.sql(5891) :: :
1PMO_RETURN_ERROR_SP:
1123:
1           EXCEPTION:: SP_I_PROFILE(124) :: cplan.sql(5905) :: :
1MAX:
1PROF_NUMBER:
1SELECT COALESCE(MAX(PROF_NUMBER),0)+1 INTO h_number:n      FROM PROFILES:n   +
1   WHERE PROJECT_ID=prj_id/**prj_id*/ AND ROLE_ID=h_role_id:
1143:
1           EXCEPTION:: SP_I_PROFILE(144) :: cplan.sql(5925) :: :
1STRINGCONCAT:
1RTRIM:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1ELEMENT_ID:
1PARENT_ID:
1SELECT PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConca+
1t(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEMENT_NAME), ',+
1 '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(h_number))), ')'):n      IN+
1TO h_full_name FROM TMT_COMPETENCIES TC, TMT_COMPETENCIES TCP:n      WHERE TC+
1.ELEMENT_ID = h_role_id AND TCP.ELEMENT_ID = TC.PARENT_ID:
1160:
1           EXCEPTION:: SP_I_PROFILE(161) :: cplan.sql(5942) :: :
1SC_SQL_NO_DATA:
1167:
1        RETURN_ERROR:: SP_I_PROFILE(168) :: cplan.sql(5949) :: :
1RECORD_NOT_FOUND:
1170:
1                EXIT:: SP_I_PROFILE(171) :: cplan.sql(5952) :: :
1TYPE_ID:
1TMT_WBS:
1SELECT TYPE_ID INTO h_type_id:n      FROM TMT_WBS:n      WHERE ELEMENT_ID=prj+
1_id:
1187:
1           EXCEPTION:: SP_I_PROFILE(188) :: cplan.sql(5969) :: :
1!=:
1ISPROJECTTYPE:
1NOT:
1195:
1        RETURN_ERROR:: SP_I_PROFILE(196) :: cplan.sql(5977) :: :
1198:
1                EXIT:: SP_I_PROFILE(199) :: cplan.sql(5980) :: :
1SYS_GUID:
1PROFILE_NAME:
1POOL_ID:
1GEO_ID:
1ORG_ID:
1INSERT INTO PROFILES(PROFILE_ID,PROJECT_ID,ROLE_ID,PROF_NUMBER, PROFILE_NAME,+
1 POOL_ID, GEO_ID, ORG_ID):n      VALUES(h_uniqueID, prj_id, h_role_id, h_numb+
1er, h_full_name, pool_id001, geo_id001, org_id001):
1221:
1           EXCEPTION:: SP_I_PROFILE(222) :: cplan.sql(6003) :: :
1TRUNC:
1LENGTH:
1/:
1>:
1WHILE:
1<:
1LOOP:
1PMO_STPU:
1STRNPCPY:
1*:
1RESOURCE_ASSIGN_ROLES:
1PROFICIENCY_LEVEL_ID:
1PREFERENCE_LEVEL_ID:
1EXPERIENCE_ID:
1LAST_USED_DATETIME:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n               SELECT h_uniqueID, ELEMENT_+
1ID, PROFICIENCY_LEVEL_ID, PREFERENCE_LEVEL_ID,:n               EXPERIENCE_ID,+
1 LAST_USED_DATETIME, TO_CHAR(h_count):n               FROM TMT_COMPETENCIES W+
1HERE ELEMENT_ID = h_role_id:
1254:
1           EXCEPTION:: SP_I_PROFILE(255) :: cplan.sql(6036) :: :
1RESOURCE_ASSIGN_SKILLS:
1INSERT INTO RESOURCE_ASSIGN_SKILLS:n                  SELECT h_uniqueID, h_ro+
1le_id, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID,:n                  PREFERENCE_LEV+
1EL_ID, LAST_USED_DATETIME, TO_CHAR(h_count):n                  FROM TMT_COMPE+
1TENCIES WHERE ELEMENT_ID = h_role_id:
1293:
1           EXCEPTION:: SP_I_PROFILE(294) :: cplan.sql(6075) :: :
14:
1305:
1       RETURN_STATUS:: SP_I_PROFILE(306) :: cplan.sql(6087) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1312:
1           EXCEPTION:: SP_I_PROFILE(313) :: cplan.sql(6094) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1324:
1           EXCEPTION:: SP_I_PROFILE(325) :: cplan.sql(6106) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
8d6
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a0 f4 b4 bf
c8 :7 a0 12a bd b7 11 a4 b1
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c a0 7e b4
2e :2 5a a0 7e b4 2e :2 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :2 a0 d :4 a0 :2 51 a5
b :2 51 a5 b d a0 7e b4
2e 5a :2 a0 d :2 a0 6b a0 6e
51 a5 b 7e 51 b4 2e :7 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 e9 dd b3 :2 a0 e9 d3
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
e9 c1 :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 e9 c1 :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 19 3c b7 19 3c :9 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:1f a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:3 a0 51 a5 b a5 b 5a 7e
51 b4 2e 7e b4 2e 52 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :2 a0 b4 2e d :11 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :5 a0
a5 b 51 a5 b 7e 51 b4
2e 5a 7e 51 b4 2e a5 b
d a0 7e 51 b4 2e a0 51
d :3 a0 51 a5 b a0 7e a0
b4 2e 82 :3 a0 6b :2 51 :2 a0 51
a5 b 7e 51 b4 2e 7e 51
b4 2e a0 a5 b d :c a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 51
a5 b 7e 51 b4 2e d b7
a0 47 b7 19 3c a0 7e b4
2e 5a :2 a0 d :5 a0 a5 b 51
a5 b 7e 51 b4 2e 5a 7e
51 b4 2e a5 b d a0 7e
51 b4 2e a0 51 d :3 a0 51
a5 b a0 7e a0 b4 2e 82
:3 a0 6b :2 51 :2 a0 51 a5 b 7e
51 b4 2e 7e 51 b4 2e a0
a5 b d :c a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 51 a5 b 7e
51 b4 2e d b7 a0 47 b7
19 3c b7 19 3c b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
8d6
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d 7c
a2 a6 aa ae b1 b5 d2 bd
c1 c4 c5 cd bc ef dd b9
e1 e2 ea dc 10c fa d9 fe
ff 107 f9 129 117 f6 11b 11c
124 116 145 134 138 113 140 133
161 150 154 130 15c 14f 17d 16c
170 14c 178 16b 199 188 18c 194
168 1b1 1a0 1a4 1ac 187 1b8 1bc
184 1cd 1d0 1d4 1d8 1dc 1e0 1e4
1e8 1ec 1f0 1fc 201 203 20f 213
231 219 21d 221 224 22c 218 238
23c 215 240 244 248 24b 250 251
1 253 258 25c 260 263 268 26c
270 273 278 279 27b 280 283 287
288 28d 292 295 29a 29b 2a0 2a3
2a7 2a8 2ad 2b0 2b5 2b6 2bb 2be
2c3 2c4 2c9 2cc 2d1 2d2 2d7 2da
2de 2df 2e4 2e7 2ec 2ed 2f2 2f5
2fa 2fb 300 303 308 309 30e 311
315 316 31b 31e 323 324 329 32c
331 332 337 33a 33f 340 345 348
34c 34d 352 355 35a 35b 360 363
368 369 36e 371 376 377 37c 37f
383 384 389 38c 391 392 397 39a
39f 3a0 3a5 3a8 3ad 3ae 3b3 3b6
3ba 3bb 3c0 3c3 3c8 3c9 3ce 3d1
3d6 3d7 3dc 3df 3e4 3e5 3ea 3ed
3f1 3f2 3f7 3fa 3ff 400 405 408
40d 40e 413 414 419 41b 41f 422
426 42a 42d 431 435 438 43b 440
443 446 449 44a 44f 450 1 452
457 45b 45f 462 467 46c 46f 473
474 479 47a 47f 481 485 488 48c
48f 490 495 498 49b 49f 4a2 4a3
4a8 4ab 1 4ae 4b3 4b7 4bb 4be
4c2 4c6 4c9 4cc 4d1 4d4 4d7 4da
4db 4e0 4e1 1 4e3 4e8 4ec 4f0
4f3 4f8 4fd 500 504 505 50a 50d
512 513 518 51b 520 521 526 529
52d 531 535 539 53c 53d 53f 544
545 547 548 54d 54e 553 555 559
55c 560 564 567 56b 56f 572 575
57a 57d 580 583 584 589 58a 1
58c 591 595 599 59c 5a1 5a6 5a9
5ad 5ae 5b3 5b4 5b9 5bb 5bf 5c2
5c6 5ca 5cd 5d1 5d5 5d8 5dc 5dd
5e2 5e4 5e8 5eb 5ef 5f3 5f7 5fb
5ff 603 607 60a 60d 60e 610 613
616 617 619 61d 621 624 625 62a
62d 631 635 639 63d 641 644 648
64d 650 651 653 656 659 65a 65f
663 667 66b 66f 673 677 67b 687
68b 68f 692 696 69a 69c 6a0 6a4
6a8 6ab 6af 6b3 6b5 6b6 6bb 1
6bf 6c3 6c7 6ca 6ce 6d2 6d6 6da
6dd 6e1 6e5 6e8 6eb 6f0 6f3 6f6
6f9 6fa 6ff 700 1 702 707 70b
70f 712 717 71c 71f 723 724 729
72c 731 732 737 73a 73f 740 745
748 74c 74d 752 755 75a 75b 760
763 767 76b 76e 771 772 774 775
77a 77b 780 782 786 789 78b 78f
791 79d 79f 7a1 7a2 7a7 7ab 7ad
7b9 7bb 7bf 7c3 7c8 7cc 7cd 7d1
7d5 7da 7df 7e3 7e7 7ec 7f0 7f4
7f7 7fa 7fe 800 804 808 80b 80e
812 814 818 81c 81f 823 827 82a
82e 831 835 838 839 83e 841 845
849 84e 850 854 858 85b 85f 863
865 869 86d 871 874 878 87c 87e
87f 884 1 888 88c 890 893 897
89b 89f 8a3 8a6 8aa 8ae 8b1 8b4
8b9 8bc 8bf 8c2 8c3 8c8 8c9 1
8cb 8d0 8d4 8d8 8db 8e0 8e5 8e8
8ec 8ed 8f2 8f5 8fa 8fb 900 903
908 909 90e 911 915 916 91b 91e
923 924 929 92c 930 934 937 93a
93b 93d 93e 943 944 949 94b 94f
952 954 958 95a 966 968 96a 96b
970 974 976 982 984 988 98c 98f
993 997 99a 99d 9a2 9a5 9a8 9ab
9ac 9b1 9b2 1 9b4 9b9 9bd 9c1
9c4 9c9 9ce 9d1 9d5 9d6 9db 9de
9e3 9e4 9e9 9ec 9f1 9f2 9f7 9fa
9fe a02 a06 a0a a0d a0e a10 a15
a16 a18 a19 a1e a21 a26 a27 a2c
a2f a34 a35 a3a a3d a41 a42 a47
a4a a4f a50 a55 a56 a5b a5d a61
a64 a68 a6c a6f a73 a77 a7a a7d
a82 a85 a88 a8b a8c a91 a92 1
a94 a99 a9d aa1 aa4 aa9 aae ab1
ab5 ab6 abb abc ac1 ac3 ac7 aca
ace ad2 ad5 ad9 add ae0 ae4 ae8
ae9 aee af0 af4 af8 afd aff b03
b07 b0a b0e b12 b14 b18 b1c b20
b23 b27 b2b b2d b2e b33 1 b37
b3b b3f b42 b46 b4a b4e b52 b55
b59 b5d b60 b63 b68 b6b b6e b71
b72 b77 b78 1 b7a b7f b83 b87
b8a b8f b94 b97 b9b b9c ba1 ba4
ba9 baa baf bb2 bb7 bb8 bbd bc0
bc4 bc5 bca bcd bd2 bd3 bd8 bdb
bdf be3 be6 be9 bea bec bed bf2
bf3 bf8 bfa bfe c01 c03 c07 c09
c15 c17 c19 c1a c1f c23 c25 c31
c33 c35 c39 c3d c40 c42 c46 c49
c4b c4f c52 c56 c5a c5e c62 c66
c6a c6e c72 c76 c82 c86 c8a c8d
c91 c95 c97 c9b c9f ca3 ca6 caa
cae cb0 cb1 cb6 1 cba cbe cc2
cc5 cc9 ccd cd1 cd5 cd8 cdc ce0
ce3 ce6 ceb cee cf1 cf4 cf5 cfa
cfb 1 cfd d02 d06 d0a d0d d12
d17 d1a d1e d1f d24 d27 d2c d2d
d32 d35 d3a d3b d40 d43 d47 d48
d4d d50 d55 d56 d5b d5e d62 d66
d69 d6c d6d d6f d70 d75 d76 d7b
d7d d81 d84 d86 d8a d8c d98 d9a
d9c d9d da2 da6 da8 db4 db6 dba
dbe dc2 dc6 dca dce dd2 dd6 dda
dde de2 de6 dea dee df2 df6 dfa
dfe e02 e06 e0a e0e e12 e16 e1a
e1e e22 e26 e2a e2e e32 e3e e42
e46 e49 e4d e51 e53 e57 e5b e5f
e62 e66 e6a e6c e6d e72 1 e76
e7a e7e e81 e85 e89 e8d e91 e94
e98 e9c e9f ea2 ea7 eaa ead eb0
eb1 eb6 eb7 1 eb9 ebe ec2 ec6
ec9 ece ed3 ed6 eda edb ee0 ee3
ee8 ee9 eee ef1 ef6 ef7 efc eff
f03 f04 f09 f0c f11 f12 f17 f1a
f1e f22 f25 f28 f29 f2b f2c f31
f32 f37 f39 f3d f40 f42 f46 f48
f54 f56 f58 f59 f5e f62 f64 f70
f72 f76 f7a f7d f81 f84 f88 f8b
f8c f91 f94 f98 f9c f9f fa3 fa7
faa fad fb2 fb5 fb8 fbb fbc fc1
fc2 1 fc4 fc9 fcd fd1 fd4 fd9
fde fe1 fe5 fe6 feb fee ff3 ff4
ff9 ffc 1001 1002 1007 100a 100e 1012
1016 101a 101d 101e 1020 1025 1026 1028
1029 102e 1031 1036 1037 103c 103f 1044
1045 104a 104d 1051 1052 1057 105a 105f
1060 1065 1066 106b 106d 1071 1074 1078
107c 107f 1083 1087 108a 108d 1092 1095
1098 109b 109c 10a1 10a2 1 10a4 10a9
10ad 10b1 10b4 10b9 10be 10c1 10c5 10c6
10cb 10cc 10d1 10d3 10d7 10da 10de 10e2
10e5 10e9 10ed 10f0 10f4 10f8 10f9 10fe
1100 1104 1107 110b 110f 1113 1117 111b
1127 112b 112f 1132 1136 113a 113c 1140
1144 1148 114b 114f 1153 1155 1156 115b
1 115f 1163 1167 116a 116e 1172 1176
117a 117d 1181 1185 1188 118b 1190 1193
1196 1199 119a 119f 11a0 1 11a2 11a7
11ab 11af 11b2 11b7 11bc 11bf 11c3 11c4
11c9 11cc 11d1 11d2 11d7 11da 11df 11e0
11e5 11e8 11ec 11ed 11f2 11f5 11fa 11fb
1200 1203 1207 120b 120e 1211 1212 1214
1215 121a 121b 1220 1222 1226 1229 122b
122f 1231 123d 123f 1241 1242 1247 124b
124d 1259 125b 125f 1263 1266 126a 126d
1271 1274 1275 127a 127d 1281 1285 1289
128c 128d 128f 1290 1292 1295 1298 129b
129c 12a1 12a4 12a5 1 12aa 12af 12b3
12b7 12ba 12be 12c2 12c5 12c8 12cd 12d0
12d3 12d6 12d7 12dc 12dd 1 12df 12e4
12e8 12ec 12ef 12f4 12f9 12fc 1300 1301
1306 1309 130e 130f 1314 1317 131c 131d
1322 1325 1329 132d 1331 1335 1338 1339
133b 1340 1341 1343 1344 1349 134c 1351
1352 1357 135a 135f 1360 1365 1368 136c
136d 1372 1375 137a 137b 1380 1381 1386
1388 138c 138f 1393 1397 139a 139e 13a2
13a5 13a8 13ad 13b0 13b3 13b6 13b7 13bc
13bd 1 13bf 13c4 13c8 13cc 13cf 13d4
13d9 13dc 13e0 13e1 13e6 13e7 13ec 13ee
13f2 13f5 13f9 13fd 1400 1404 1408 140b
140f 1413 1414 1419 141b 141f 1422 1426
142a 142b 1430 1434 1438 143c 1440 1444
1448 144c 1450 1454 1458 145c 1460 1464
1468 146c 1470 1474 1478 1484 1488 148d
1491 1494 1495 149a 149e 14a2 14a5 14a8
14ac 14ae 14b2 14b6 14b9 14bc 14c0 14c2
14c6 14ca 14cd 14cf 14d3 14d7 14db 14de
14e2 14e6 14e8 14e9 14ee 1 14f2 14f6
14fa 14fd 1501 1505 1509 150d 1510 1514
1518 151b 151e 1523 1526 1529 152c 152d
1532 1533 1 1535 153a 153e 1542 1545
154a 154f 1552 1556 1557 155c 155f 1564
1565 156a 156d 1572 1573 1578 157b 157f
1580 1585 1588 158d 158e 1593 1596 159a
159e 15a1 15a4 15a5 15a7 15a8 15ad 15ae
15b3 15b5 15b9 15bc 15be 15c2 15c4 15d0
15d2 15d4 15d5 15da 15de 15e0 15ec 15ee
15f2 15f6 15f9 15fd 1600 1604 1607 1608
160d 1610 1614 1618 161c 1620 1624 1625
1627 162a 162b 162d 1630 1633 1634 1639
163c 163f 1642 1643 1648 1649 164b 164f
1653 1656 1659 165a 165f 1663 1666 166a
166e 1672 1676 1679 167a 167c 1680 1683
1687 1688 168d 168f 1693 1697 169b 169e
16a1 16a4 16a8 16ac 16af 16b0 16b2 16b5
16b8 16b9 16be 16c1 16c4 16c5 16ca 16ce
16cf 16d1 16d5 16d9 16dd 16e1 16e5 16e9
16ed 16f1 16f5 16f9 16fd 1701 1705 1711
1715 171a 171e 1721 1722 1727 172b 172f
1732 1735 1739 173b 173f 1743 1746 1749
174d 174f 1753 1757 175a 175c 1760 1764
1768 176b 176f 1773 1775 1776 177b 1
177f 1783 1787 178a 178e 1792 1796 179a
179d 17a1 17a5 17a8 17ab 17b0 17b3 17b6
17b9 17ba 17bf 17c0 1 17c2 17c7 17cb
17cf 17d2 17d7 17dc 17df 17e3 17e4 17e9
17ec 17f1 17f2 17f7 17fa 17ff 1800 1805
1808 180c 180d 1812 1815 181a 181b 1820
1823 1827 182b 182e 1831 1832 1834 1835
183a 183b 1840 1842 1846 1849 184b 184f
1851 185d 185f 1861 1862 1867 186b 186d
1879 187b 187f 1883 1887 188a 188b 188d
1890 1893 1894 1899 189d 189f 18a3 18aa
18ac 18b0 18b3 18b7 18ba 18bb 18c0 18c3
18c7 18cb 18cf 18d3 18d7 18db 18df 18e3
18e4 18e6 18e9 18ea 18ec 18ef 18f2 18f3
18f8 18fb 18fe 1901 1902 1907 1908 190a
190e 1912 1915 1918 1919 191e 1922 1925
1929 192d 1931 1935 1938 1939 193b 193f
1942 1946 1947 194c 194e 1952 1956 195a
195d 1960 1963 1967 196b 196e 196f 1971
1974 1977 1978 197d 1980 1983 1984 1989
198d 198e 1990 1994 1998 199c 19a0 19a4
19a8 19ac 19b0 19b4 19b8 19bc 19c0 19c4
19d0 19d4 19d9 19dd 19e0 19e1 19e6 19ea
19ee 19f1 19f4 19f8 19fa 19fe 1a02 1a05
1a08 1a0c 1a0e 1a12 1a16 1a19 1a1b 1a1f
1a23 1a27 1a2a 1a2e 1a32 1a34 1a35 1a3a
1 1a3e 1a42 1a46 1a49 1a4d 1a51 1a55
1a59 1a5c 1a60 1a64 1a67 1a6a 1a6f 1a72
1a75 1a78 1a79 1a7e 1a7f 1 1a81 1a86
1a8a 1a8e 1a91 1a96 1a9b 1a9e 1aa2 1aa3
1aa8 1aab 1ab0 1ab1 1ab6 1ab9 1abe 1abf
1ac4 1ac7 1acb 1acc 1ad1 1ad4 1ad9 1ada
1adf 1ae2 1ae6 1aea 1aed 1af0 1af1 1af3
1af4 1af9 1afa 1aff 1b01 1b05 1b08 1b0a
1b0e 1b10 1b1c 1b1e 1b20 1b21 1b26 1b2a
1b2c 1b38 1b3a 1b3e 1b42 1b46 1b49 1b4a
1b4c 1b4f 1b52 1b53 1b58 1b5c 1b5e 1b62
1b69 1b6b 1b6f 1b72 1b74 1b78 1b7b 1b7d
1b81 1b84 1b88 1b8c 1b8f 1b93 1b97 1b9a
1b9d 1ba2 1ba5 1ba8 1bab 1bac 1bb1 1bb2
1 1bb4 1bb9 1bbd 1bc1 1bc4 1bc9 1bce
1bd1 1bd5 1bd6 1bdb 1bde 1be3 1be4 1be9
1bec 1bf1 1bf2 1bf7 1bfa 1bfe 1c02 1c06
1c0a 1c0d 1c0e 1c10 1c15 1c16 1c18 1c19
1c1e 1c21 1c26 1c27 1c2c 1c2f 1c34 1c35
1c3a 1c3d 1c41 1c42 1c47 1c4a 1c4f 1c50
1c55 1c56 1c5b 1c5d 1c61 1c64 1c68 1c6c
1c6f 1c73 1c77 1c7a 1c7e 1c82 1c83 1c88
1c8a 1c8e 1c92 1c95 1c99 1c9d 1ca0 1ca4
1ca8 1cab 1cae 1cb3 1cb6 1cb9 1cbc 1cbd
1cc2 1cc3 1 1cc5 1cca 1cce 1cd2 1cd5
1cda 1cdf 1ce2 1ce6 1ce7 1cec 1ced 1cf2
1cf6 1cfa 1cfd 1d02 1d07 1d0a 1d0e 1d12
1d15 1d16 1d1b 1d1e 1d23 1d24 1d29 1d2c
1d30 1d34 1d37 1d38 1d3d 1d3e 1d43 1d45
1d49 1d4c 1d50 1d54 1d58 1d5c 1d60 1d64
1d68 1d6c 1d70 1d7c 1d81 1d85 1d89 1d8d
1d91 1d93 1d94 1d99 1 1d9d 1da1 1da5
1da8 1dac 1db0 1db4 1db8 1dbb 1dbf 1dc3
1dc6 1dc9 1dce 1dd1 1dd4 1dd7 1dd8 1ddd
1dde 1 1de0 1de5 1de9 1ded 1df0 1df5
1dfa 1dfd 1e01 1e02 1e07 1e08 1e0d 1e11
1e15 1e18 1e1d 1e22 1e25 1e29 1e2a 1e2f
1e32 1e37 1e38 1e3d 1e40 1e44 1e48 1e4b
1e4e 1e4f 1e51 1e52 1e57 1e58 1e5d 1e5f
1e63 1e66 1e6a 1e6e 1e72 1e76 1e7a 1e7e
1e82 1e8e 1e93 1e97 1e9b 1e9f 1ea3 1ea5
1ea9 1eab 1eb7 1eb9 1ebb 1ebc 1ec1 1ec5
1ec7 1ed3 1ed7 1ed9 1eda 1ee3 
8d6
2
0 1 a 6 d :3 6 10 :3 6
11 :3 6 10 :3 6 10 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 e 17 16 :2 e :2 4
10 19 18 :2 10 :2 4 :2 c 1b c
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :3 d :2 4 :3 10 4 7 e 0
:2 7 11 21 11 22 2d 38 40
a :5 7 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 54 5a 5d :2 54
6b 81 8 :2 6b d 10 :2 6b 17
1a :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 28 2b :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 29
2c :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 28 2b :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 28
2b :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 29 2c :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 2a
2d :2 6b 32 35 :2 6b :2 7 4a :2 4
7 :2 11 23 :2 2d 39 3c 4c 4e
4f :2 4c :2 23 :3 7 :2 d 12 1e 5c
5f :2 1e :2 7 52 :2 4 :4 9 8 7
:4 1f 1e 1d :2 7 a :2 14 26 :2 30
3c 3f 4f 51 52 :2 4f :2 26 :3 a
:2 10 15 21 5f 62 :2 21 6f 72
:2 21 76 79 :2 21 83 86 8f 97
:2 a0 :2 8f b1 :2 86 :2 21 :2 a 55 :2 7
a :2 14 26 :2 30 3c 3f 4f 51
52 :2 4f :2 26 :3 a :2 10 15 21 5f
62 :2 21 :2 a 55 :3 7 :2 12 28 :2 31
41 :2 7 33 :3 4 13 :2 4 11 18
1f 2c 2f :2 18 34 37 :2 11 4
:4 8 :2 7 15 7 a :2 15 1d 29
34 :2 a 37 39 :2 37 14 24 12
13 1e 29 31 :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5b 5c :2 59 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 3b a f :3 a 10 1d :2 a
d 15 :2 d :2 16 22 d 1b d
:2 16 22 d :4 a e :2 17 22 20
:2 2b :2 20 d 10 16 :3 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5c 5f 60 :2 5c
:2 32 :3 16 :2 1c 21 2d 6c 6f :2 2d
7c 7f :2 2d 83 86 :2 2d 92 95
:2 2d 9d a0 :2 2d ac af b6 bf
c2 :2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c
:2 10 d :3 3b 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8a 8d 96 9e :2 a7
:2 96 b2 :2 8d :2 27 ba bd :2 27 c5
c8 :2 27 cd d0 :2 27 db de :2 27
:2 10 5d :2 d 10 :2 1a 2c :2 36 42
45 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 :2 10 5c :3 d
:2 18 2c :2 35 3f 4b :2 d 3b 10
16 :3 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5c 5f 60 :2 5c :2 32 :3 16 :2 1c 21
2d 6c 6f :2 2d 7c 7f :2 2d 83
86 :2 2d 92 95 :2 2d 9d a0 :2 2d
ac af b6 bf c2 :2 af :2 2d :2 16
63 :2 13 :2 10 :4 1c :2 10 d :7 a 3b
:2 7 20 :2 4 e 17 1b 32 c
d 18 2e 36 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 53 56 57 :2 53 :2 29
:3 d :2 13 18 24 63 66 :2 24 73
76 :2 24 7a 7d :2 24 89 8c :2 24
94 97 :2 24 a3 a6 ad b6 b9
:2 a6 :2 24 :2 d 5a :2 a :2 7 :4 13 :2 7
4 :3 1 e 19 26 31 3e 49
56 61 6e 79 86 8c 90 a6
ac af c5 cb d3 c 1d 2e
32 43 d 10 1d 2b 2f 3c
3f :2 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
53 56 57 :2 53 :2 29 :3 d :2 13 18
24 63 66 :2 24 73 76 :2 24 7a
7d :2 24 89 8c :2 24 94 97 :2 24
a3 a6 ad b6 b9 :2 a6 :2 24 :2 d
5a :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a 7 a :2 14
26 :2 30 3c 40 50 53 54 :2 50
:2 26 :3 a :2 10 15 21 60 63 :2 21
70 73 :2 21 77 7a :2 21 84 87
90 98 :2 a1 :2 90 b4 :2 87 :2 21 bc
bf :2 21 c7 ca :2 21 cf d2 :2 21
dc df :2 21 :2 a 57 :2 7 a :2 14
26 :2 30 3c 3f 4f 52 53 :2 4f
:2 26 :3 a :2 10 15 21 60 63 :2 21
:2 a 56 :3 7 :2 12 26 :2 2f 41 4c
:2 7 35 :2 4 e 1b c d 18
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 53
56 57 :2 53 :2 29 :3 d :2 13 18 24
63 66 :2 24 73 76 :2 24 7a 7d
:2 24 89 8c :2 24 94 97 :2 24 a3
a6 ad b6 b9 :2 a6 :2 24 :2 d 5a
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1d 1a :2 26 :2 1a 7 3e 4c a
15 :2 4c :2 3e 3d 1a 1d :2 1a :3 39
:2 7 a :2 14 26 :2 30 3c 40 50
53 54 :2 50 :2 26 :3 a :2 10 15 21
60 63 :2 21 70 73 :2 21 77 7a
:2 21 84 87 90 98 :2 a1 :2 90 ac
:2 87 :2 21 b4 b7 :2 21 bf c2 :2 21
c7 ca :2 21 d1 d4 :2 21 :2 a 57
:2 7 a :2 14 26 :2 30 3c 3f 4f
52 53 :2 4f :2 26 :3 a :2 10 15 21
60 63 :2 21 :2 a 56 :3 7 :2 12 26
:2 2f 39 41 :2 7 1f :3 4 :3 12 4
13 1c 27 32 3a 47 55 5e
66 e 1a 22 2d 37 44 50
5b 7 e a 16 :3 14 a :2 13
1f a 1b a :2 13 1f a :4 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 53 56 57 :2 53 :2 29
:3 d :2 13 18 24 63 66 :2 24 73
76 :2 24 7a 7d :2 24 89 8c :2 24
94 97 :2 24 a3 a6 ad b6 b9
:2 a6 :2 24 :2 d 5a :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
:2 7 13 1a 23 2a :2 23 38 :2 1a
3b 3d :2 1a 19 40 42 :2 19 :2 13
7 a 13 15 :2 13 a 15 :2 a
10 19 22 :2 10 27 25 30 :2 25
a d 1a :2 23 2c 30 34 3d
46 :2 34 49 4b :2 34 4d 4e :2 34
51 :2 1a d 1c 17 23 2f 45
10 1f 33 3b 15 2c 39 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5c 5f 60 :2 5c :2 32 :3 16 :2 1c
21 2d 6c 6f :2 2d 7c 7f :2 2d
83 86 :2 2d 92 95 :2 2d 9d a0
:2 2d ac af b6 bf c2 :2 af :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :3 30
d 18 21 2a :2 18 2d 2f :2 18
d 30 e a 17 :2 7 :4 b :2 a
19 :2 a 19 20 29 30 :2 29 3e
:2 20 41 43 :2 20 1f 46 48 :2 1f
:2 19 a d 19 1b :2 19 d 18
:2 d 13 1c 25 :2 13 2a 28 36
:2 28 d 10 1d :2 26 2f 33 37
40 49 :2 37 4c 4e :2 37 50 51
:2 37 54 :2 1d 10 1f 1a 26 31
47 13 28 3c 44 18 2f 3c
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5f 62 63 :2 5f :2 35 :3 19
:2 1f 24 30 6f 72 :2 30 7f 82
:2 30 86 89 :2 30 95 98 :2 30 a0
a3 :2 30 af b2 b9 c2 c5 :2 b2
:2 30 :2 19 66 :2 16 :2 13 :4 1f :2 13 10
:3 36 10 1b 24 2d :2 1b 30 32
:2 1b 10 36 11 d 1d :2 a 23
:2 7 35 :2 4 7 :2 11 23 :2 2d 39
3c 4c 4f 50 :2 4c :2 23 :3 7 :2 d
12 1e 5d 60 :2 1e 6d 70 :2 1e
74 77 :2 1e 81 84 8d 95 :2 9e
:2 8d a9 :2 84 :2 1e b1 b4 :2 1e bc
bf :2 1e c4 c7 :2 1e d2 d5 :2 1e
:2 7 53 :3 4 :2 f 21 :2 2a 34 40
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 50 53 54 :2 50 :2 26
:3 a :2 10 15 21 60 63 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 57
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 4d 50 51 :2 4d :2 23
:3 7 :2 d 12 1e 5d 60 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 54 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
8d6
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 2 :4 a :2 1
:7 c :7 d :7 e :7 f
:6 10 :6 11 :6 12 :5 13
:5 14 :2 16 0 :2 16
:2 17 :5 18 17 :5 16
:7 1a :b 1c :11 1d 1e
:2 1d :2 1e :2 1d :2 1e
:2 1d :2 1f :2 1d :2 1f
:2 1d :2 1f :2 1d :2 1f
:2 1d :2 20 :2 1d :2 20
:2 1d :2 20 :2 1d :2 20
:2 1d :2 21 :2 1d :2 21
:2 1d :2 21 :2 1d :2 21
:2 1d :2 22 :2 1d :2 22
:2 1d :2 22 :2 1d :2 22
:2 1d :2 23 :2 1d :2 23
:2 1d :2 23 :2 1d :2 23
:2 1d :2 24 :2 1d :2 24
:2 1d :2 24 :2 1d :2 24
:2 1d :2 24 :4 1d :3 1c
:11 27 :b 28 :3 27 :e 2d
:11 2e :20 2f :3 2e :11 31
:b 32 :3 31 :9 34 :3 2d
:3 38 :d 3b :5 3d :3 3e
:c 40 :2 42 43 :4 44
42 :5 45 41 47
:5 48 :3 47 :2 49 :5 4b
:11 4c :24 4d :3 4c :2 4a
:6 49 46 :3 40 :5 52
:4 54 :3 55 :5 56 55
:5 58 57 :3 55 :a 5b
:4 5d :5 5e 5c 60
:5 61 :3 60 :2 62 :5 64
:11 65 :24 66 :3 65 :2 63
:6 62 5f :3 5b :11 6a
:30 6b :3 6a :11 6d :b 6e
:3 6d :a 70 5b :4 73
:5 74 72 76 :5 77
:3 76 :2 78 :5 7a :11 7b
:24 7c :3 7b :2 79 :6 78
75 :4 71 :3 5b :3 40
:3 3d :4 85 86 :4 87
85 :5 88 84 8a
:5 8b :3 8a :2 8c :5 8e
:11 8f :24 90 :3 8f :2 8d
:6 8c 89 :3 1b :13 96
:5 97 :7 98 96 :5 99
95 9b :5 9c :3 9b
:2 9d :5 9f :11 a0 :24 a1
:3 a0 :2 9e :6 9d 9a
:3 1b :a a6 :11 a7 :30 a8
:3 a7 :11 aa :b ab :3 aa
:a ad :3 a6 :2 b1 b2
:2 b3 b1 :5 b4 b0
b6 :5 b7 :3 b6 :2 b8
:5 ba :11 bb :24 bc :3 bb
:2 b9 :6 b8 b5 :3 1b
:c c1 :2 c2 :5 c1 :4 c2
:5 c1 :11 c3 :30 c4 :3 c3
:11 c6 :b c7 :3 c6 :a c9
c2 :2 c1 :5 cd :9 d0
:8 d1 d0 :6 d2 :5 d3
d2 :5 d5 d4 :3 d2
cf d8 :5 d9 :3 d8
:2 da :5 dc :11 dd :24 de
:3 dd :2 db :6 da d7
:3 1b :a e3 :16 e5 :5 e6
:3 e7 :c e8 :17 ec ef
:4 f0 :4 f1 :3 f2 ef
:6 f3 :5 f4 f3 :5 f6
f5 :3 f3 ee f9
:5 fa :3 f9 :2 fb :5 fd
:11 fe :24 ff :3 fe :2 fc
:6 fb f8 :3 e8 :b 103
e8 104 e8 :3 e6
:5 108 :3 10a :16 10b :5 10d
:3 10e :c 10f :17 113 116
:4 117 :4 118 :3 119 116
:6 11a :5 11b 11a :5 11d
11c :3 11a 115 120
:5 121 :3 120 :2 122 :5 124
:11 125 :24 126 :3 125 :2 123
:6 122 11f :3 10f :b 12b
10f 12c 10f :3 10d
:3 108 :3 e3 :11 131 :30 132
:3 131 :a 134 1b :3 137
:11 138 :b 139 :17 13a :3 138
:2 13c :3 13d :3 13e 13f
13d 13c 13d :3 140
:3 137 :2 141 :5 143 :11 144
:b 145 :18 146 :3 144 :2 148
149 :3 14a 14b 149
148 149 :3 14c :2 142
:6 141 136 :7 1 
1ee5
4
:3 0 1 :3 0 2
:a 0 8d1 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 7
:7 0 11 10 :3 0
4 :3 0 8 :7 0
15 14 :3 0 11
:2 0 f 4 :3 0
9 :7 0 19 18
:3 0 4 :3 0 a
:7 0 1d 1c :3 0
b :3 0 c :3 0
d :2 0 4 21
22 0 1f 23
0 8d1 2 24
:2 0 11 :2 0 1b
4 :3 0 f :2 0
19 27 29 :6 0
2c 2a 0 8cf
0 e :6 0 f
:2 0 1f 4 :3 0
1d 2e 30 :6 0
33 31 0 8cf
0 10 :6 0 14
:2 0 23 4 :3 0
21 35 37 :6 0
3a 38 0 8cf
0 12 :6 0 17
:2 0 27 4 :3 0
25 3c 3e :6 0
41 3f 0 8cf
0 13 :6 0 17
:2 0 29 16 :3 0
43 :7 0 47 44
45 8cf 0 15
:6 0 17 :2 0 2b
16 :3 0 49 :7 0
4d 4a 4b 8cf
0 18 :6 0 2f
184 0 2d 16
:3 0 4f :7 0 53
50 51 8cf 0
19 :9 0 31 16
:3 0 55 :7 0 58
56 0 8cf 0
1a :6 0 16 :3 0
5a :7 0 5d 5b
0 8cf 0 1b
:6 0 1c :3 0 1d
:a 0 2 6b :4 0
5f 62 0 60
:3 0 1e :3 0 1f
:3 0 20 :3 0 21
:3 0 3 :3 0 22
:3 0 12 :4 0 23
1 :8 0 6c 5f
62 6d 0 8cf
33 6d 6f 6c
6e :6 0 6b :7 0
6d 77 78 0
35 c :3 0 d
:2 0 4 71 72
0 73 :7 0 76
74 0 8cf 0
24 :6 0 25 :3 0
26 :3 0 25 :3 0
27 :3 0 7a 7b
0 2 :4 0 37
7c 7e 79 80
7f :2 0 28 :3 0
29 :3 0 82 83
0 2a :4 0 25
:3 0 2b :3 0 86
87 0 2 :4 0
39 88 8a 2c
:4 0 2d :2 0 2e
:3 0 3b 8d 8f
:3 0 2f :4 0 2d
:2 0 30 :4 0 3e
92 94 :3 0 2d
:2 0 3 :3 0 41
96 98 :3 0 2d
:2 0 30 :4 0 44
9a 9c :3 0 2d
:2 0 31 :4 0 47
9e a0 :3 0 2d
:2 0 30 :4 0 4a
a2 a4 :3 0 2d
:2 0 5 :3 0 4d
a6 a8 :3 0 2d
:2 0 30 :4 0 50
aa ac :3 0 2d
:2 0 31 :4 0 53
ae b0 :3 0 2d
:2 0 30 :4 0 56
b2 b4 :3 0 2d
:2 0 6 :3 0 59
b6 b8 :3 0 2d
:2 0 30 :4 0 5c
ba bc :3 0 2d
:2 0 31 :4 0 5f
be c0 :3 0 2d
:2 0 30 :4 0 62
c2 c4 :3 0 2d
:2 0 7 :3 0 65
c6 c8 :3 0 2d
:2 0 30 :4 0 68
ca cc :3 0 2d
:2 0 31 :4 0 6b
ce d0 :3 0 2d
:2 0 30 :4 0 6e
d2 d4 :3 0 2d
:2 0 8 :3 0 71
d6 d8 :3 0 2d
:2 0 30 :4 0 74
da dc :3 0 2d
:2 0 31 :4 0 77
de e0 :3 0 2d
:2 0 30 :4 0 7a
e2 e4 :3 0 2d
:2 0 9 :3 0 7d
e6 e8 :3 0 2d
:2 0 30 :4 0 80
ea ec :3 0 2d
:2 0 31 :4 0 83
ee f0 :3 0 2d
:2 0 30 :4 0 86
f2 f4 :3 0 2d
:2 0 a :3 0 89
f6 f8 :3 0 2d
:2 0 30 :4 0 8c
fa fc :3 0 2d
:2 0 32 :4 0 8f
fe 100 :3 0 92
84 102 :2 0 104
97 105 81 104
0 106 99 0
82f 25 :3 0 26
:3 0 107 108 0
25 :3 0 33 :3 0
10a 10b 0 34
:2 0 2 :4 0 35
:2 0 36 :2 0 34
:2 0 9b 110 112
:3 0 9e 10c 114
109 116 115 :2 0
28 :3 0 37 :3 0
118 119 0 2a
:4 0 38 :4 0 2d
:2 0 2e :3 0 a2
11d 11f :3 0 a5
11a 121 :2 0 123
a8 124 117 123
0 125 aa 0
82f 3 :3 0 39
:2 0 ac 127 128
:3 0 129 :2 0 12a
:2 0 5 :3 0 39
:2 0 ae 12d 12e
:3 0 12f :2 0 130
:2 0 12b 132 131
:2 0 25 :3 0 26
:3 0 134 135 0
25 :3 0 33 :3 0
137 138 0 3a
:2 0 2 :4 0 3b
:2 0 36 :2 0 34
:2 0 b0 13d 13f
:3 0 b3 139 141
136 143 142 :2 0
28 :3 0 37 :3 0
145 146 0 2a
:4 0 3c :4 0 2d
:2 0 2e :3 0 b7
14a 14c :3 0 2d
:2 0 3d :4 0 ba
14e 150 :3 0 2d
:2 0 3e :4 0 bd
152 154 :3 0 2d
:2 0 3f :3 0 40
:3 0 41 :3 0 42
:3 0 159 15a 0
c0 158 15c 43
:4 0 c2 157 15f
c5 156 161 :3 0
c8 147 163 :2 0
165 cb 166 144
165 0 167 cd
0 190 25 :3 0
26 :3 0 168 169
0 25 :3 0 33
:3 0 16b 16c 0
34 :2 0 2 :4 0
44 :2 0 36 :2 0
34 :2 0 cf 171
173 :3 0 d2 16d
175 16a 177 176
:2 0 28 :3 0 37
:3 0 179 17a 0
2a :4 0 45 :4 0
2d :2 0 2e :3 0
d6 17e 180 :3 0
d9 17b 182 :2 0
184 dc 185 178
184 0 186 de
0 190 46 :3 0
47 :3 0 187 188
0 41 :3 0 42
:3 0 18a 18b 0
48 :3 0 e0 189
18e :2 0 190 e3
191 133 190 0
192 e7 0 82f
10 :3 0 5 :3 0
193 194 0 82f
12 :3 0 49 :3 0
49 :3 0 10 :3 0
34 :2 0 f :2 0
e9 198 19c 34
:2 0 f :2 0 ed
197 1a0 196 1a1
0 82f 9 :3 0
4a :2 0 f1 1a4
1a5 :3 0 1a6 :2 0
e :3 0 9 :3 0
1a8 1a9 0 36f
4b :3 0 4c :3 0
1ab 1ac 0 e
:3 0 4d :4 0 4e
:2 0 f3 1ad 1b1
4f :2 0 17 :2 0
f9 1b3 1b5 :3 0
1e :3 0 e :3 0
1f :3 0 21 :3 0
3 :3 0 22 :3 0
12 :4 0 50 1
:8 0 1c4 c :3 0
51 :3 0 1bf 1c0
0 52 :3 0 1c1
1c2 0 1c4 fc
217 53 :3 0 c
:3 0 51 :3 0 1c6
1c7 0 52 :3 0
1c8 1c9 0 1cb
ff 1cd 101 1cc
1cb :2 0 215 54
:3 0 c :3 0 51
:3 0 1d0 1d1 0
52 :3 0 1d2 1d3
0 20d 25 :3 0
26 :3 0 1d5 1d6
0 25 :3 0 33
:3 0 1d8 1d9 0
55 :2 0 2 :4 0
56 :2 0 36 :2 0
34 :2 0 103 1de
1e0 :3 0 106 1da
1e2 1d7 1e4 1e3
:2 0 28 :3 0 37
:3 0 1e6 1e7 0
2a :4 0 57 :4 0
2d :2 0 2e :3 0
10a 1eb 1ed :3 0
2d :2 0 3d :4 0
10d 1ef 1f1 :3 0
2d :2 0 58 :4 0
110 1f3 1f5 :3 0
2d :2 0 52 :3 0
113 1f7 1f9 :3 0
2d :2 0 59 :4 0
116 1fb 1fd :3 0
2d :2 0 49 :3 0
5a :3 0 34 :2 0
5b :2 0 119 200
204 11d 1ff 206
:3 0 120 1e8 208
:2 0 20a 123 20b
1e5 20a 0 20c
125 0 20d 127
210 :3 0 210 0
210 20f 20d 20e
:6 0 212 3 :3 0
12a 214 12c 213
212 :2 0 215 12e
:2 0 217 0 217
216 1c4 215 :6 0
36c 1 :3 0 5c
:3 0 1d :4 0 21c
:2 0 36c 21a 21d
:3 0 1d :3 0 e
:4 0 221 :2 0 36c
21e 21f :3 0 1d
:3 0 5d :3 0 222
223 :3 0 c :3 0
51 :3 0 225 226
0 17 :2 0 227
228 0 22a 131
231 c :3 0 51
:3 0 22b 22c 0
5e :2 0 22d 22e
0 230 133 232
224 22a 0 233
0 230 0 233
135 0 36c c
:3 0 51 :3 0 234
235 0 c :3 0
4f :2 0 5f :3 0
237 239 0 13a
238 23b :3 0 23c
:2 0 60 :3 0 1d
:4 0 241 :2 0 247
23f 0 c :3 0
51 :3 0 242 243
0 52 :3 0 244
245 0 247 13d
29a 53 :3 0 c
:3 0 51 :3 0 249
24a 0 52 :3 0
24b 24c 0 24e
140 250 142 24f
24e :2 0 298 54
:3 0 c :3 0 51
:3 0 253 254 0
52 :3 0 255 256
0 290 25 :3 0
26 :3 0 258 259
0 25 :3 0 33
:3 0 25b 25c 0
55 :2 0 2 :4 0
61 :2 0 36 :2 0
34 :2 0 144 261
263 :3 0 147 25d
265 25a 267 266
:2 0 28 :3 0 37
:3 0 269 26a 0
2a :4 0 62 :4 0
2d :2 0 2e :3 0
14b 26e 270 :3 0
2d :2 0 3d :4 0
14e 272 274 :3 0
2d :2 0 58 :4 0
151 276 278 :3 0
2d :2 0 52 :3 0
154 27a 27c :3 0
2d :2 0 59 :4 0
157 27e 280 :3 0
2d :2 0 49 :3 0
5a :3 0 34 :2 0
5b :2 0 15a 283
287 15e 282 289
:3 0 161 26b 28b
:2 0 28d 164 28e
268 28d 0 28f
166 0 290 168
293 :3 0 293 0
293 292 290 291
:6 0 295 5 :3 0
16b 297 16d 296
295 :2 0 298 16f
:2 0 29a 0 29a
299 247 298 :6 0
309 1 :3 0 25
:3 0 26 :3 0 29c
29d 0 25 :3 0
33 :3 0 29f 2a0
0 f :2 0 2
:4 0 63 :2 0 36
:2 0 34 :2 0 172
2a5 2a7 :3 0 175
2a1 2a9 29e 2ab
2aa :2 0 28 :3 0
37 :3 0 2ad 2ae
0 2a :4 0 64
:4 0 2d :2 0 2e
:3 0 179 2b2 2b4
:3 0 2d :2 0 3d
:4 0 17c 2b6 2b8
:3 0 2d :2 0 3e
:4 0 17f 2ba 2bc
:3 0 2d :2 0 3f
:3 0 40 :3 0 c
:3 0 51 :3 0 2c1
2c2 0 182 2c0
2c4 43 :4 0 184
2bf 2c7 187 2be
2c9 :3 0 2d :2 0
65 :4 0 18a 2cb
2cd :3 0 2d :2 0
30 :4 0 18d 2cf
2d1 :3 0 2d :2 0
e :3 0 190 2d3
2d5 :3 0 2d :2 0
30 :4 0 193 2d7
2d9 :3 0 196 2af
2db :2 0 2dd 199
2de 2ac 2dd 0
2df 19b 0 309
25 :3 0 26 :3 0
2e0 2e1 0 25
:3 0 33 :3 0 2e3
2e4 0 34 :2 0
2 :4 0 66 :2 0
36 :2 0 34 :2 0
19d 2e9 2eb :3 0
1a0 2e5 2ed 2e2
2ef 2ee :2 0 28
:3 0 37 :3 0 2f1
2f2 0 2a :4 0
67 :4 0 2d :2 0
2e :3 0 1a4 2f6
2f8 :3 0 1a7 2f3
2fa :2 0 2fc 1aa
2fd 2f0 2fc 0
2fe 1ac 0 309
46 :3 0 68 :3 0
2ff 300 0 c
:3 0 51 :3 0 302
303 0 e :3 0
48 :3 0 1ae 301
307 :2 0 309 1b2
369 60 :3 0 1d
:4 0 30d :2 0 313
30b 0 c :3 0
51 :3 0 30e 30f
0 52 :3 0 310
311 0 313 1b7
366 53 :3 0 c
:3 0 51 :3 0 315
316 0 52 :3 0
317 318 0 31a
1ba 31c 1bc 31b
31a :2 0 364 54
:3 0 c :3 0 51
:3 0 31f 320 0
52 :3 0 321 322
0 35c 25 :3 0
26 :3 0 324 325
0 25 :3 0 33
:3 0 327 328 0
55 :2 0 2 :4 0
69 :2 0 36 :2 0
34 :2 0 1be 32d
32f :3 0 1c1 329
331 326 333 332
:2 0 28 :3 0 37
:3 0 335 336 0
2a :4 0 6a :4 0
2d :2 0 2e :3 0
1c5 33a 33c :3 0
2d :2 0 3d :4 0
1c8 33e 340 :3 0
2d :2 0 58 :4 0
1cb 342 344 :3 0
2d :2 0 52 :3 0
1ce 346 348 :3 0
2d :2 0 59 :4 0
1d1 34a 34c :3 0
2d :2 0 49 :3 0
5a :3 0 34 :2 0
5b :2 0 1d4 34f
353 1d8 34e 355
:3 0 1db 337 357
:2 0 359 1de 35a
334 359 0 35b
1e0 0 35c 1e2
35f :3 0 35f 0
35f 35e 35c 35d
:6 0 361 7 :3 0
1e5 363 1e7 362
361 :2 0 364 1e9
:2 0 366 0 366
365 313 364 :6 0
368 1 :3 0 1ec
36a 23d 309 0
36b 0 368 0
36b 1ee 0 36c
1f1 36d 1b6 36c
0 36e 1f7 0
36f 1f9 370 1a7
36f 0 371 1fc
0 82f 3f :3 0
6b :3 0 6c :3 0
18 :3 0 1f :3 0
21 :3 0 3 :3 0
22 :3 0 12 :4 0
6d 1 :8 0 381
c :3 0 51 :3 0
37c 37d 0 52
:3 0 37e 37f 0
381 1fe 3d4 53
:3 0 c :3 0 51
:3 0 383 384 0
52 :3 0 385 386
0 388 201 38a
203 389 388 :2 0
3d2 54 :3 0 c
:3 0 51 :3 0 38d
38e 0 52 :3 0
38f 390 0 3ca
25 :3 0 26 :3 0
392 393 0 25
:3 0 33 :3 0 395
396 0 55 :2 0
2 :4 0 6e :2 0
36 :2 0 34 :2 0
205 39b 39d :3 0
208 397 39f 394
3a1 3a0 :2 0 28
:3 0 37 :3 0 3a3
3a4 0 2a :4 0
6f :4 0 2d :2 0
2e :3 0 20c 3a8
3aa :3 0 2d :2 0
3d :4 0 20f 3ac
3ae :3 0 2d :2 0
58 :4 0 212 3b0
3b2 :3 0 2d :2 0
52 :3 0 215 3b4
3b6 :3 0 2d :2 0
59 :4 0 218 3b8
3ba :3 0 2d :2 0
49 :3 0 5a :3 0
34 :2 0 5b :2 0
21b 3bd 3c1 21f
3bc 3c3 :3 0 222
3a5 3c5 :2 0 3c7
225 3c8 3a2 3c7
0 3c9 227 0
3ca 229 3cd :3 0
3cd 0 3cd 3cc
3ca 3cb :6 0 3cf
9 :3 0 22c 3d1
22e 3d0 3cf :2 0
3d2 230 :2 0 3d4
0 3d4 3d3 381
3d2 :6 0 82f 1
:3 0 4b :3 0 70
:3 0 4b :3 0 70
:3 0 4b :3 0 70
:3 0 4b :3 0 70
:3 0 4b :3 0 70
:3 0 71 :3 0 72
:3 0 73 :3 0 71
:3 0 74 :3 0 73
:3 0 71 :3 0 40
:3 0 18 :3 0 13
:3 0 75 :3 0 74
:3 0 75 :3 0 72
:3 0 74 :3 0 76
:3 0 12 :3 0 72
:3 0 76 :3 0 74
:3 0 77 :4 0 78
1 :8 0 3fb c
:3 0 51 :3 0 3f6
3f7 0 52 :3 0
3f8 3f9 0 3fb
233 44e 53 :3 0
c :3 0 51 :3 0
3fd 3fe 0 52
:3 0 3ff 400 0
402 236 404 238
403 402 :2 0 44c
54 :3 0 c :3 0
51 :3 0 407 408
0 52 :3 0 409
40a 0 444 25
:3 0 26 :3 0 40c
40d 0 25 :3 0
33 :3 0 40f 410
0 55 :2 0 2
:4 0 79 :2 0 36
:2 0 34 :2 0 23a
415 417 :3 0 23d
411 419 40e 41b
41a :2 0 28 :3 0
37 :3 0 41d 41e
0 2a :4 0 7a
:4 0 2d :2 0 2e
:3 0 241 422 424
:3 0 2d :2 0 3d
:4 0 244 426 428
:3 0 2d :2 0 58
:4 0 247 42a 42c
:3 0 2d :2 0 52
:3 0 24a 42e 430
:3 0 2d :2 0 59
:4 0 24d 432 434
:3 0 2d :2 0 49
:3 0 5a :3 0 34
:2 0 5b :2 0 250
437 43b 254 436
43d :3 0 257 41f
43f :2 0 441 25a
442 41c 441 0
443 25c 0 444
25e 447 :3 0 447
0 447 446 444
445 :6 0 449 b
:3 0 261 44b 263
44a 449 :2 0 44c
265 :2 0 44e 0
44e 44d 3fb 44c
:6 0 82f 1 :3 0
c :3 0 51 :3 0
450 451 0 c
:3 0 4f :2 0 7b
:3 0 453 455 0
26a 454 457 :3 0
458 :2 0 25 :3 0
26 :3 0 45a 45b
0 25 :3 0 33
:3 0 45d 45e 0
f :2 0 2 :4 0
7c :2 0 36 :2 0
34 :2 0 26d 463
465 :3 0 270 45f
467 45c 469 468
:2 0 28 :3 0 37
:3 0 46b 46c 0
2a :4 0 7d :4 0
2d :2 0 2e :3 0
274 470 472 :3 0
2d :2 0 3d :4 0
277 474 476 :3 0
2d :2 0 3e :4 0
27a 478 47a :3 0
2d :2 0 3f :3 0
40 :3 0 41 :3 0
7e :3 0 47f 480
0 27d 47e 482
43 :4 0 27f 47d
485 282 47c 487
:3 0 2d :2 0 65
:4 0 285 489 48b
:3 0 2d :2 0 30
:4 0 288 48d 48f
:3 0 2d :2 0 12
:3 0 28b 491 493
:3 0 2d :2 0 30
:4 0 28e 495 497
:3 0 291 46d 499
:2 0 49b 294 49c
46a 49b 0 49d
296 0 4c7 25
:3 0 26 :3 0 49e
49f 0 25 :3 0
33 :3 0 4a1 4a2
0 34 :2 0 2
:4 0 7f :2 0 36
:2 0 34 :2 0 298
4a7 4a9 :3 0 29b
4a3 4ab 4a0 4ad
4ac :2 0 28 :3 0
37 :3 0 4af 4b0
0 2a :4 0 80
:4 0 2d :2 0 2e
:3 0 29f 4b4 4b6
:3 0 2a2 4b1 4b8
:2 0 4ba 2a5 4bb
4ae 4ba 0 4bc
2a7 0 4c7 46
:3 0 68 :3 0 4bd
4be 0 41 :3 0
7e :3 0 4c0 4c1
0 12 :3 0 48
:3 0 2a9 4bf 4c5
:2 0 4c7 2ad 4c8
459 4c7 0 4c9
2b1 0 82f 81
:3 0 19 :3 0 82
:3 0 76 :3 0 3
:4 0 83 1 :8 0
4d5 c :3 0 51
:3 0 4d0 4d1 0
52 :3 0 4d2 4d3
0 4d5 2b3 528
53 :3 0 c :3 0
51 :3 0 4d7 4d8
0 52 :3 0 4d9
4da 0 4dc 2b6
4de 2b8 4dd 4dc
:2 0 526 54 :3 0
c :3 0 51 :3 0
4e1 4e2 0 52
:3 0 4e3 4e4 0
51e 25 :3 0 26
:3 0 4e6 4e7 0
25 :3 0 33 :3 0
4e9 4ea 0 55
:2 0 2 :4 0 84
:2 0 36 :2 0 34
:2 0 2ba 4ef 4f1
:3 0 2bd 4eb 4f3
4e8 4f5 4f4 :2 0
28 :3 0 37 :3 0
4f7 4f8 0 2a
:4 0 85 :4 0 2d
:2 0 2e :3 0 2c1
4fc 4fe :3 0 2d
:2 0 3d :4 0 2c4
500 502 :3 0 2d
:2 0 58 :4 0 2c7
504 506 :3 0 2d
:2 0 52 :3 0 2ca
508 50a :3 0 2d
:2 0 59 :4 0 2cd
50c 50e :3 0 2d
:2 0 49 :3 0 5a
:3 0 34 :2 0 5b
:2 0 2d0 511 515
2d4 510 517 :3 0
2d7 4f9 519 :2 0
51b 2da 51c 4f6
51b 0 51d 2dc
0 51e 2de 521
:3 0 521 0 521
520 51e 51f :6 0
523 d :3 0 2e1
525 2e3 524 523
:2 0 526 2e5 :2 0
528 0 528 527
4d5 526 :6 0 82f
1 :3 0 c :3 0
51 :3 0 52a 52b
0 c :3 0 86
:2 0 5f :3 0 52d
52f 0 2ea 52e
531 :3 0 532 :2 0
87 :3 0 3f :3 0
19 :3 0 17 :2 0
2ed 535 538 2f0
534 53a 53b :2 0
86 :2 0 17 :2 0
2f4 53d 53f :3 0
88 :2 0 2f7 541
542 :3 0 533 544
543 :2 0 25 :3 0
26 :3 0 546 547
0 25 :3 0 33
:3 0 549 54a 0
f :2 0 2 :4 0
89 :2 0 36 :2 0
34 :2 0 2f9 54f
551 :3 0 2fc 54b
553 548 555 554
:2 0 28 :3 0 37
:3 0 557 558 0
2a :4 0 8a :4 0
2d :2 0 2e :3 0
300 55c 55e :3 0
2d :2 0 3d :4 0
303 560 562 :3 0
2d :2 0 3e :4 0
306 564 566 :3 0
2d :2 0 3f :3 0
40 :3 0 c :3 0
51 :3 0 56b 56c
0 309 56a 56e
43 :4 0 30b 569
571 30e 568 573
:3 0 2d :2 0 65
:4 0 311 575 577
:3 0 2d :2 0 30
:4 0 314 579 57b
:3 0 2d :2 0 3
:3 0 317 57d 57f
:3 0 2d :2 0 30
:4 0 31a 581 583
:3 0 31d 559 585
:2 0 587 320 588
556 587 0 589
322 0 5b3 25
:3 0 26 :3 0 58a
58b 0 25 :3 0
33 :3 0 58d 58e
0 34 :2 0 2
:4 0 8b :2 0 36
:2 0 34 :2 0 324
593 595 :3 0 327
58f 597 58c 599
598 :2 0 28 :3 0
37 :3 0 59b 59c
0 2a :4 0 8c
:4 0 2d :2 0 2e
:3 0 32b 5a0 5a2
:3 0 32e 59d 5a4
:2 0 5a6 331 5a7
59a 5a6 0 5a8
333 0 5b3 46
:3 0 68 :3 0 5a9
5aa 0 c :3 0
51 :3 0 5ac 5ad
0 3 :3 0 48
:3 0 335 5ab 5b1
:2 0 5b3 339 5b4
545 5b3 0 5b5
33d 0 82f e
:3 0 8d :4 0 5b7
5b8 :3 0 5b6 5b9
0 82f 1f :3 0
1e :3 0 21 :3 0
22 :3 0 6c :3 0
8e :3 0 8f :3 0
90 :3 0 91 :3 0
e :3 0 3 :3 0
12 :3 0 18 :3 0
13 :3 0 9 :3 0
8 :3 0 7 :4 0
92 1 :8 0 5e2
5d :4 0 5cd :3 0
48 :3 0 4f :2 0
341 5d0 5d1 :3 0
c :3 0 51 :3 0
5d3 5d4 0 17
:2 0 5d5 5d6 0
5d8 344 5df c
:3 0 51 :3 0 5d9
5da 0 5e :2 0
5db 5dc 0 5de
346 5e0 5d2 5d8
0 5e1 0 5de
0 5e1 348 0
5e2 34b 635 53
:3 0 c :3 0 51
:3 0 5e4 5e5 0
52 :3 0 5e6 5e7
0 5e9 34e 5eb
350 5ea 5e9 :2 0
633 54 :3 0 c
:3 0 51 :3 0 5ee
5ef 0 52 :3 0
5f0 5f1 0 62b
25 :3 0 26 :3 0
5f3 5f4 0 25
:3 0 33 :3 0 5f6
5f7 0 55 :2 0
2 :4 0 93 :2 0
36 :2 0 34 :2 0
352 5fc 5fe :3 0
355 5f8 600 5f5
602 601 :2 0 28
:3 0 37 :3 0 604
605 0 2a :4 0
94 :4 0 2d :2 0
2e :3 0 359 609
60b :3 0 2d :2 0
3d :4 0 35c 60d
60f :3 0 2d :2 0
58 :4 0 35f 611
613 :3 0 2d :2 0
52 :3 0 362 615
617 :3 0 2d :2 0
59 :4 0 365 619
61b :3 0 2d :2 0
49 :3 0 5a :3 0
34 :2 0 5b :2 0
368 61e 622 36c
61d 624 :3 0 36f
606 626 :2 0 628
372 629 603 628
0 62a 374 0
62b 376 62e :3 0
62e 0 62e 62d
62b 62c :6 0 630
f :3 0 379 632
37b 631 630 :2 0
633 37d :2 0 635
0 635 634 5e2
633 :6 0 82f 1
:3 0 c :3 0 51
:3 0 637 638 0
c :3 0 4f :2 0
5f :3 0 63a 63c
0 382 63b 63e
:3 0 63f :2 0 1a
:3 0 95 :3 0 3f
:3 0 96 :3 0 10
:3 0 385 644 646
17 :2 0 387 643
649 36 :2 0 34
:2 0 38a 64b 64d
:3 0 64e :2 0 97
:2 0 f :2 0 38d
650 652 :3 0 390
642 654 641 655
0 7de 1a :3 0
98 :2 0 34 :2 0
394 658 65a :3 0
15 :3 0 34 :2 0
65c 65d 0 707
99 :3 0 3f :3 0
15 :3 0 17 :2 0
397 660 663 1a
:3 0 9a :2 0 9b
:3 0 39c 666 668
:3 0 669 706 12
:3 0 9c :3 0 9d
:3 0 66c 66d 0
f :2 0 f :2 0
3f :3 0 15 :3 0
17 :2 0 39f 671
674 9e :2 0 f
:2 0 3a2 676 678
:3 0 36 :2 0 34
:2 0 3a5 67a 67c
:3 0 10 :3 0 3a8
66e 67f 66b 680
0 704 9f :3 0
e :3 0 76 :3 0
a0 :3 0 a1 :3 0
a2 :3 0 a3 :3 0
40 :3 0 15 :3 0
75 :3 0 76 :3 0
12 :4 0 a4 1
:8 0 6a4 5d :4 0
68f :3 0 48 :3 0
4f :2 0 3af 692
693 :3 0 c :3 0
51 :3 0 695 696
0 17 :2 0 697
698 0 69a 3b2
6a1 c :3 0 51
:3 0 69b 69c 0
5e :2 0 69d 69e
0 6a0 3b4 6a2
694 69a 0 6a3
0 6a0 0 6a3
3b6 0 6a4 3b9
6f7 53 :3 0 c
:3 0 51 :3 0 6a6
6a7 0 52 :3 0
6a8 6a9 0 6ab
3bc 6ad 3be 6ac
6ab :2 0 6f5 54
:3 0 c :3 0 51
:3 0 6b0 6b1 0
52 :3 0 6b2 6b3
0 6ed 25 :3 0
26 :3 0 6b5 6b6
0 25 :3 0 33
:3 0 6b8 6b9 0
55 :2 0 2 :4 0
a5 :2 0 36 :2 0
34 :2 0 3c0 6be
6c0 :3 0 3c3 6ba
6c2 6b7 6c4 6c3
:2 0 28 :3 0 37
:3 0 6c6 6c7 0
2a :4 0 a6 :4 0
2d :2 0 2e :3 0
3c7 6cb 6cd :3 0
2d :2 0 3d :4 0
3ca 6cf 6d1 :3 0
2d :2 0 58 :4 0
3cd 6d3 6d5 :3 0
2d :2 0 52 :3 0
3d0 6d7 6d9 :3 0
2d :2 0 59 :4 0
3d3 6db 6dd :3 0
2d :2 0 49 :3 0
5a :3 0 34 :2 0
5b :2 0 3d6 6e0
6e4 3da 6df 6e6
:3 0 3dd 6c8 6e8
:2 0 6ea 3e0 6eb
6c5 6ea 0 6ec
3e2 0 6ed 3e4
6f0 :3 0 6f0 0
6f0 6ef 6ed 6ee
:6 0 6f2 12 :3 0
3e7 6f4 3e9 6f3
6f2 :2 0 6f5 3eb
:2 0 6f7 0 6f7
6f6 6a4 6f5 :6 0
704 11 :3 0 15
:3 0 3f :3 0 15
:3 0 17 :2 0 3ee
6fa 6fd 36 :2 0
34 :2 0 3f1 6ff
701 :3 0 6f9 702
0 704 3f4 706
9b :3 0 66a 704
:4 0 707 3f8 708
65b 707 0 709
3fb 0 7de 6
:3 0 4a :2 0 3fd
70b 70c :3 0 70d
:2 0 10 :3 0 6
:3 0 70f 710 0
7db 1b :3 0 95
:3 0 3f :3 0 96
:3 0 10 :3 0 3ff
715 717 17 :2 0
401 714 71a 36
:2 0 34 :2 0 404
71c 71e :3 0 71f
:2 0 97 :2 0 f
:2 0 407 721 723
:3 0 40a 713 725
712 726 0 7db
1b :3 0 98 :2 0
17 :2 0 40e 729
72b :3 0 15 :3 0
17 :2 0 72d 72e
0 7d8 99 :3 0
3f :3 0 15 :3 0
17 :2 0 411 731
734 1b :3 0 9a
:2 0 9b :3 0 416
737 739 :3 0 73a
7d7 12 :3 0 9c
:3 0 9d :3 0 73d
73e 0 f :2 0
f :2 0 3f :3 0
15 :3 0 17 :2 0
419 742 745 9e
:2 0 f :2 0 41c
747 749 :3 0 36
:2 0 34 :2 0 41f
74b 74d :3 0 10
:3 0 422 73f 750
73c 751 0 7d5
a7 :3 0 e :3 0
12 :3 0 a0 :3 0
a2 :3 0 a1 :3 0
a3 :3 0 40 :3 0
15 :3 0 75 :3 0
76 :3 0 12 :4 0
a8 1 :8 0 775
5d :4 0 760 :3 0
48 :3 0 4f :2 0
429 763 764 :3 0
c :3 0 51 :3 0
766 767 0 17
:2 0 768 769 0
76b 42c 772 c
:3 0 51 :3 0 76c
76d 0 5e :2 0
76e 76f 0 771
42e 773 765 76b
0 774 0 771
0 774 430 0
775 433 7c8 53
:3 0 c :3 0 51
:3 0 777 778 0
52 :3 0 779 77a
0 77c 436 77e
438 77d 77c :2 0
7c6 54 :3 0 c
:3 0 51 :3 0 781
782 0 52 :3 0
783 784 0 7be
25 :3 0 26 :3 0
786 787 0 25
:3 0 33 :3 0 789
78a 0 55 :2 0
2 :4 0 a9 :2 0
36 :2 0 34 :2 0
43a 78f 791 :3 0
43d 78b 793 788
795 794 :2 0 28
:3 0 37 :3 0 797
798 0 2a :4 0
aa :4 0 2d :2 0
2e :3 0 441 79c
79e :3 0 2d :2 0
3d :4 0 444 7a0
7a2 :3 0 2d :2 0
58 :4 0 447 7a4
7a6 :3 0 2d :2 0
52 :3 0 44a 7a8
7aa :3 0 2d :2 0
59 :4 0 44d 7ac
7ae :3 0 2d :2 0
49 :3 0 5a :3 0
34 :2 0 5b :2 0
450 7b1 7b5 454
7b0 7b7 :3 0 457
799 7b9 :2 0 7bb
45a 7bc 796 7bb
0 7bd 45c 0
7be 45e 7c1 :3 0
7c1 0 7c1 7c0
7be 7bf :6 0 7c3
15 :3 0 461 7c5
463 7c4 7c3 :2 0
7c6 465 :2 0 7c8
0 7c8 7c7 775
7c6 :6 0 7d5 14
:3 0 15 :3 0 3f
:3 0 15 :3 0 17
:2 0 468 7cb 7ce
36 :2 0 34 :2 0
46b 7d0 7d2 :3 0
7ca 7d3 0 7d5
46e 7d7 9b :3 0
73b 7d5 :4 0 7d8
472 7d9 72c 7d8
0 7da 475 0
7db 477 7dc 70e
7db 0 7dd 47b
0 7de 47d 7df
640 7de 0 7e0
481 0 82f 25
:3 0 26 :3 0 7e1
7e2 0 25 :3 0
33 :3 0 7e4 7e5
0 ab :2 0 2
:4 0 ac :2 0 36
:2 0 34 :2 0 483
7ea 7ec :3 0 486
7e6 7ee 7e3 7f0
7ef :2 0 28 :3 0
37 :3 0 7f2 7f3
0 2a :4 0 ad
:4 0 2d :2 0 2e
:3 0 48a 7f7 7f9
:3 0 2d :2 0 3d
:4 0 48d 7fb 7fd
:3 0 2d :2 0 3e
:4 0 490 7ff 801
:3 0 2d :2 0 3f
:3 0 40 :3 0 c
:3 0 51 :3 0 806
807 0 493 805
809 43 :4 0 495
804 80c 498 803
80e :3 0 2d :2 0
65 :4 0 49b 810
812 :3 0 2d :2 0
30 :4 0 49e 814
816 :3 0 2d :2 0
e :3 0 4a1 818
81a :3 0 2d :2 0
30 :4 0 4a4 81c
81e :3 0 4a7 7f4
820 :2 0 822 4aa
823 7f1 822 0
824 4ac 0 82f
46 :3 0 ae :3 0
825 826 0 c
:3 0 51 :3 0 828
829 0 e :3 0
48 :3 0 4ae 827
82d :2 0 82f 4b2
8d0 c :3 0 af
:2 0 4 830 831
0 25 :3 0 26
:3 0 833 834 0
25 :3 0 33 :3 0
836 837 0 55
:2 0 2 :4 0 b0
:2 0 36 :2 0 34
:2 0 4c3 83c 83e
:3 0 4c6 838 840
835 842 841 :2 0
28 :3 0 37 :3 0
844 845 0 2a
:4 0 b1 :4 0 2d
:2 0 2e :3 0 4ca
849 84b :3 0 4cd
846 84d :2 0 866
28 :3 0 37 :3 0
84f 850 0 2a
:4 0 b2 :4 0 2d
:2 0 c :3 0 b3
:3 0 855 856 0
4d0 854 858 :3 0
2d :2 0 65 :4 0
4d3 85a 85c :3 0
2d :2 0 c :3 0
b4 :3 0 85f 860
0 4d6 85e 862
:3 0 4d9 851 864
:2 0 866 4dc 867
843 866 0 868
4df 0 878 5c
:3 0 24 :3 0 c
:3 0 b3 :3 0 b5
:3 0 c :3 0 b4
:3 0 b6 :3 0 b7
:4 0 b8 1 :a 0
874 :2 0 878 86a
872 :2 0 b :3 0
24 :3 0 876 :2 0
878 4e1 87a 4e5
879 878 :2 0 8ce
54 :3 0 c :3 0
51 :3 0 87d 87e
0 52 :3 0 87f
880 0 8c6 25
:3 0 26 :3 0 882
883 0 25 :3 0
33 :3 0 885 886
0 55 :2 0 2
:4 0 b9 :2 0 36
:2 0 34 :2 0 4e7
88b 88d :3 0 4ea
887 88f 884 891
890 :2 0 28 :3 0
37 :3 0 893 894
0 2a :4 0 ba
:4 0 2d :2 0 2e
:3 0 4ee 898 89a
:3 0 4f1 895 89c
:2 0 8b6 28 :3 0
37 :3 0 89e 89f
0 2a :4 0 58
:4 0 2d :2 0 52
:3 0 4f4 8a3 8a5
:3 0 2d :2 0 59
:4 0 4f7 8a7 8a9
:3 0 2d :2 0 49
:3 0 5a :3 0 34
:2 0 5b :2 0 4fa
8ac 8b0 4fe 8ab
8b2 :3 0 501 8a0
8b4 :2 0 8b6 504
8b7 892 8b6 0
8b8 507 0 8c6
5c :3 0 24 :3 0
b5 :3 0 c :3 0
b4 :3 0 b6 :3 0
b7 :4 0 bb 1
:a 0 8c2 :2 0 8c6
8ba 8c0 :2 0 b
:3 0 24 :3 0 8c4
:2 0 8c6 509 8c9
:3 0 8c9 0 8c9
8c8 8c6 8c7 :6 0
8cb 1 :3 0 50e
8cd 510 8cc 8cb
:2 0 8ce 512 :2 0
8d0 515 8d0 8cf
82f 8ce :6 0 8d1
:2 0 2 24 8d0
8d4 :3 0 8d3 8d1
8d5 :8 0 
521
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 7
6 a e 12
16 1a 1e 1
28 1 26 1
2f 1 2d 1
36 1 34 1
3d 1 3b 1
42 1 48 1
4e 1 54 1
59 1 6a 1
70 1 7d 1
89 2 8c 8e
2 91 93 2
95 97 2 99
9b 2 9d 9f
2 a1 a3 2
a5 a7 2 a9
ab 2 ad af
2 b1 b3 2
b5 b7 2 b9
bb 2 bd bf
2 c1 c3 2
c5 c7 2 c9
cb 2 cd cf
2 d1 d3 2
d5 d7 2 d9
db 2 dd df
2 e1 e3 2
e5 e7 2 e9
eb 2 ed ef
2 f1 f3 2
f5 f7 2 f9
fb 2 fd ff
4 85 8b 90
101 1 103 1
105 2 10f 111
3 10d 10e 113
2 11c 11e 2
11b 120 1 122
1 124 1 126
1 12c 2 13c
13e 3 13a 13b
140 2 149 14b
2 14d 14f 2
151 153 1 15b
2 15d 15e 2
155 160 2 148
162 1 164 1
166 2 170 172
3 16e 16f 174
2 17d 17f 2
17c 181 1 183
1 185 2 18c
18d 3 167 186
18f 1 191 3
199 19a 19b 3
19d 19e 19f 1
1a3 3 1ae 1af
1b0 1 1b4 2
1b2 1b4 2 1be
1c3 1 1ca 1
1c5 2 1dd 1df
3 1db 1dc 1e1
2 1ea 1ec 2
1ee 1f0 2 1f2
1f4 2 1f6 1f8
2 1fa 1fc 3
201 202 203 2
1fe 205 2 1e9
207 1 209 1
20b 2 1d4 20c
1 210 1 1cf
2 1cd 214 1
229 1 22f 2
231 232 1 23a
2 236 23a 2
240 246 1 24d
1 248 2 260
262 3 25e 25f
264 2 26d 26f
2 271 273 2
275 277 2 279
27b 2 27d 27f
3 284 285 286
2 281 288 2
26c 28a 1 28c
1 28e 2 257
28f 1 293 1
252 2 250 297
2 2a4 2a6 3
2a2 2a3 2a8 2
2b1 2b3 2 2b5
2b7 2 2b9 2bb
1 2c3 2 2c5
2c6 2 2bd 2c8
2 2ca 2cc 2
2ce 2d0 2 2d2
2d4 2 2d6 2d8
2 2b0 2da 1
2dc 1 2de 2
2e8 2ea 3 2e6
2e7 2ec 2 2f5
2f7 2 2f4 2f9
1 2fb 1 2fd
3 304 305 306
4 29a 2df 2fe
308 2 30c 312
1 319 1 314
2 32c 32e 3
32a 32b 330 2
339 33b 2 33d
33f 2 341 343
2 345 347 2
349 34b 3 350
351 352 2 34d
354 2 338 356
1 358 1 35a
2 323 35b 1
35f 1 31e 2
31c 363 1 366
2 369 36a 5
217 21b 220 233
36b 1 36d 2
1aa 36e 1 370
2 37b 380 1
387 1 382 2
39a 39c 3 398
399 39e 2 3a7
3a9 2 3ab 3ad
2 3af 3b1 2
3b3 3b5 2 3b7
3b9 3 3be 3bf
3c0 2 3bb 3c2
2 3a6 3c4 1
3c6 1 3c8 2
391 3c9 1 3cd
1 38c 2 38a
3d1 2 3f5 3fa
1 401 1 3fc
2 414 416 3
412 413 418 2
421 423 2 425
427 2 429 42b
2 42d 42f 2
431 433 3 438
439 43a 2 435
43c 2 420 43e
1 440 1 442
2 40b 443 1
447 1 406 2
404 44b 1 456
2 452 456 2
462 464 3 460
461 466 2 46f
471 2 473 475
2 477 479 1
481 2 483 484
2 47b 486 2
488 48a 2 48c
48e 2 490 492
2 494 496 2
46e 498 1 49a
1 49c 2 4a6
4a8 3 4a4 4a5
4aa 2 4b3 4b5
2 4b2 4b7 1
4b9 1 4bb 3
4c2 4c3 4c4 3
49d 4bc 4c6 1
4c8 2 4cf 4d4
1 4db 1 4d6
2 4ee 4f0 3
4ec 4ed 4f2 2
4fb 4fd 2 4ff
501 2 503 505
2 507 509 2
50b 50d 3 512
513 514 2 50f
516 2 4fa 518
1 51a 1 51c
2 4e5 51d 1
521 1 4e0 2
4de 525 1 530
2 52c 530 2
536 537 1 539
1 53e 2 53c
53e 1 540 2
54e 550 3 54c
54d 552 2 55b
55d 2 55f 561
2 563 565 1
56d 2 56f 570
2 567 572 2
574 576 2 578
57a 2 57c 57e
2 580 582 2
55a 584 1 586
1 588 2 592
594 3 590 591
596 2 59f 5a1
2 59e 5a3 1
5a5 1 5a7 3
5ae 5af 5b0 3
589 5a8 5b2 1
5b4 1 5cf 2
5ce 5cf 1 5d7
1 5dd 2 5df
5e0 2 5cc 5e1
1 5e8 1 5e3
2 5fb 5fd 3
5f9 5fa 5ff 2
608 60a 2 60c
60e 2 610 612
2 614 616 2
618 61a 3 61f
620 621 2 61c
623 2 607 625
1 627 1 629
2 5f2 62a 1
62e 1 5ed 2
5eb 632 1 63d
2 639 63d 1
645 2 647 648
2 64a 64c 2
64f 651 1 653
1 659 2 657
659 2 661 662
1 665 2 664
665 2 672 673
2 675 677 2
679 67b 4 66f
670 67d 67e 1
691 2 690 691
1 699 1 69f
2 6a1 6a2 2
68e 6a3 1 6aa
1 6a5 2 6bd
6bf 3 6bb 6bc
6c1 2 6ca 6cc
2 6ce 6d0 2
6d2 6d4 2 6d6
6d8 2 6da 6dc
3 6e1 6e2 6e3
2 6de 6e5 2
6c9 6e7 1 6e9
1 6eb 2 6b4
6ec 1 6f0 1
6af 2 6ad 6f4
2 6fb 6fc 2
6fe 700 3 681
6f7 703 2 65e
706 1 708 1
70a 1 716 2
718 719 2 71b
71d 2 720 722
1 724 1 72a
2 728 72a 2
732 733 1 736
2 735 736 2
743 744 2 746
748 2 74a 74c
4 740 741 74e
74f 1 762 2
761 762 1 76a
1 770 2 772
773 2 75f 774
1 77b 1 776
2 78e 790 3
78c 78d 792 2
79b 79d 2 79f
7a1 2 7a3 7a5
2 7a7 7a9 2
7ab 7ad 3 7b2
7b3 7b4 2 7af
7b6 2 79a 7b8
1 7ba 1 7bc
2 785 7bd 1
7c1 1 780 2
77e 7c5 2 7cc
7cd 2 7cf 7d1
3 752 7c8 7d4
2 72f 7d7 1
7d9 3 711 727
7da 1 7dc 3
656 709 7dd 1
7df 2 7e9 7eb
3 7e7 7e8 7ed
2 7f6 7f8 2
7fa 7fc 2 7fe
800 1 808 2
80a 80b 2 802
80d 2 80f 811
2 813 815 2
817 819 2 81b
81d 2 7f5 81f
1 821 1 823
3 82a 82b 82c
10 106 125 192
195 1a2 371 3d4
44e 4c9 528 5b5
5ba 635 7e0 824
82e 2 83b 83d
3 839 83a 83f
2 848 84a 2
847 84c 2 853
857 2 859 85b
2 85d 861 2
852 863 2 84e
865 1 867 3
868 873 877 1
832 2 88a 88c
3 888 889 88e
2 897 899 2
896 89b 2 8a2
8a4 2 8a6 8a8
3 8ad 8ae 8af
2 8aa 8b1 2
8a1 8b3 2 89d
8b5 1 8b7 4
881 8b8 8c1 8c5
1 8c9 1 87c
2 87a 8cd b
2b 32 39 40
46 4c 52 57
5c 6b 75 
1
4
0 
8d4
0
1
28
17
13
0 1 1 3 1 5 1 7
1 9 1 b 1 d 1 f
1 11 12 1 14 15 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

1b 1 0
b 1 0
34 1 0
42 1 0
54 1 0
4e 1 0
17 1 0
48 1 0
2d 1 0
13 1 0
f 1 0
26 1 0
3 1 0
59 1 0
5f 1 2
2 0 1
7 1 0
3b 1 0
70 1 0
0

/
SHOW ERRORS FUNCTION SP_I_PROFILE;
ALTER FUNCTION SP_I_PROFILE COMPILE DEBUG;
/*######################################################################################*/
/* assign a profile to a task or project, used tables: RESOURCE_ASSIGNMENTS, PROFILES   */
/****************************************************************************************/
/*  RES_ID is profile_id, role_id is role_id in TMT_COMPETENCIES    */
/****************************************************************************************/
/*
#Stored Procedure  :SP_A_TSKPROF
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_TSKPROF ==
CREATE OR REPLACE FUNCTION SP_A_TSKPROF wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
d7
2 :e:
1FUNCTION:
1SP_A_TSKPROF:
1TASK_ID001:
1VARCHAR2:
1RES_ID001:
1ROLE_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_UNIQUEID:
132:
1H_PROJECT_ID:
1H_RES_ID:
1H_AND_ROLES:
18000:
1H_ROLE_ID:
1H_REC_STATUS:
11:
1H_FULL_NAME:
1255:
1H_TYPE:
1PLS_INTEGER:
10:
1H_CRI:
1H_BITFLAG:
1H_NUMBER:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_RES_TYPE:
1H_TEMP_SC_STATE:
1H_TABLE_TYPE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_TSKPROF(:
1':
1, :
1);:
1CHECK_TRACE:
137:
1+:
1FPUT:
1               ENTER:: SP_A_TSKPROF(38) :: cplan.sql(6178) :: :
1IS NULL:
18:
144:
1      RETURN_INVALID:: SP_A_TSKPROF(45) :: cplan.sql(6185) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
147:
1                EXIT:: SP_A_TSKPROF(48) :: cplan.sql(6188) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1PROJECT_ID:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type FROM TMT_WBS WHERE ELEME+
1NT_ID = task_id001:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
162:
1           EXCEPTION:: SP_A_TSKPROF(63) :: cplan.sql(6203) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type FROM TMT_CRI WHERE ELEME+
1NT_ID = task_id001:
178:
1           EXCEPTION:: SP_A_TSKPROF(79) :: cplan.sql(6219) :: :
185:
1        RETURN_ERROR:: SP_A_TSKPROF(86) :: cplan.sql(6226) :: :
1RECORD_NOT_FOUND:
1 ID:: :
188:
1                EXIT:: SP_A_TSKPROF(89) :: cplan.sql(6229) :: :
1PMO_RETURN_ERROR_SP:
1SC_TABLE_CRI:
1SC_TABLE_WBS:
1PROFILE_ID:
1PROFILE_NAME:
1REC_STATUS:
1PROFILES:
1SELECT PROFILE_ID, PROFILE_NAME, REC_STATUS INTO h_res_id, h_full_name, h_rec+
1_status:n      FROM PROFILES WHERE PROFILE_ID = h_res_id:
1113:
1           EXCEPTION:: SP_A_TSKPROF(114) :: cplan.sql(6254) :: :
1MAX:
1PROF_NUMBER:
1ROLE_ID:
1SELECT COALESCE(MAX(PROF_NUMBER),0)+1 INTO h_number:n         FROM PROFILES:n+
1         WHERE PROJECT_ID=h_project_id AND ROLE_ID=h_role_id:
1135:
1           EXCEPTION:: SP_A_TSKPROF(136) :: cplan.sql(6276) :: :
1PMO_ORASTD:
1STRINGCONCAT:
1RTRIM:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1PARENT_ID:
1SELECT PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConca+
1t(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEMENT_NAME), ',+
1 '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(h_number))), ')') INTO h_fu+
1ll_name:n         FROM TMT_COMPETENCIES TC, TMT_COMPETENCIES TCP:n         WH+
1ERE TC.ELEMENT_ID = h_role_id AND TCP.ELEMENT_ID = TC.PARENT_ID:
1152:
1           EXCEPTION:: SP_A_TSKPROF(153) :: cplan.sql(6293) :: :
1159:
1        RETURN_ERROR:: SP_A_TSKPROF(160) :: cplan.sql(6300) :: :
1162:
1                EXIT:: SP_A_TSKPROF(163) :: cplan.sql(6303) :: :
1INSERT INTO PROFILES(PROFILE_ID,PROJECT_ID,ROLE_ID,PROF_NUMBER, PROFILE_NAME)+
1:n         VALUES(h_res_id, h_project_id, h_role_id, h_number, h_full_name):
1FOUND:
1100:
1182:
1           EXCEPTION:: SP_A_TSKPROF(183) :: cplan.sql(6323) :: :
1!=:
1SC_SQL_SUCCESS:
1189:
1        RETURN_ERROR:: SP_A_TSKPROF(190) :: cplan.sql(6330) :: :
1192:
1                EXIT:: SP_A_TSKPROF(193) :: cplan.sql(6333) :: :
1ELSIF:
1ISNOTPROJECTTYPE:
1A:
1RES_ASSIGNMENT_ID:
1RESOURCE_ASSIGNMENTS:
1RESOURCE_ID:
1RESOURCE_TYPE:
1SELECT a.RES_ASSIGNMENT_ID INTO h_uniqueID :n            FROM RESOURCE_ASSIGN+
1MENTS a:n            WHERE a.ELEMENT_ID = task_id001  :n            AND a.RES+
1OURCE_ID = res_id001:n            AND a.RESOURCE_TYPE = '1':
1212:
1           EXCEPTION:: SP_A_TSKPROF(213) :: cplan.sql(6353) :: :
1219:
1        RETURN_ERROR:: SP_A_TSKPROF(220) :: cplan.sql(6360) :: :
1RECORD_ALREADY_ASSIGNED:
1222:
1                EXIT:: SP_A_TSKPROF(223) :: cplan.sql(6363) :: :
1D:
1UPDATE PROFILES SET REC_STATUS = 'U' WHERE PROFILE_ID = h_res_id:
1243:
1           EXCEPTION:: SP_A_TSKPROF(244) :: cplan.sql(6384) :: :
1250:
1        RETURN_ERROR:: SP_A_TSKPROF(251) :: cplan.sql(6391) :: :
1253:
1                EXIT:: SP_A_TSKPROF(254) :: cplan.sql(6394) :: :
1SELECT RES_ASSIGNMENT_ID INTO h_uniqueID :n      FROM RESOURCE_ASSIGNMENTS:n +
1     WHERE ELEMENT_ID = task_id001 :n      AND RESOURCE_ID = h_res_id :n     +
1 AND RESOURCE_TYPE = '1':
1273:
1           EXCEPTION:: SP_A_TSKPROF(274) :: cplan.sql(6414) :: :
1ASSIGN_NAMES:
1INSTR:
1LENGTH:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n            ELSE:n  +
1          CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) >+
1 2040 THEN ASSIGN_NAMES:n            ELSE ASSIGN_NAMES || h_full_name || ';'+
1:n            END:n            END:n            WHERE ELEMENT_ID = task_id001:
1304:
1           EXCEPTION:: SP_A_TSKPROF(305) :: cplan.sql(6445) :: :
1UPDATE TMT_CRI SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n            ELSE:n  +
1          CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) >+
1 2040 THEN ASSIGN_NAMES:n            ELSE ASSIGN_NAMES || h_full_name || ';'+
1:n            END:n            END:n            WHERE ELEMENT_ID = task_id001:
1332:
1           EXCEPTION:: SP_A_TSKPROF(333) :: cplan.sql(6473) :: :
1SYS_GUID:
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1ISPROJECTTYPE:
1SC_AFFECTED:
1SC_TEAMMEMBER:
1FC_BEFORE_I_RES_ASSIGN:
1ELEMENT_TYPE:
1PARTICIPANT:
1SECURITY_ID:
1REC_USER:
1REC_DATETIME:
1TABLE_TYPE:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE,:n         RESOURCE_TYPE, RESOURCE_ID, PARTICIPANT, SECURITY_ID, +
1REC_USER, REC_DATETIME,TABLE_TYPE) :n         VALUES (h_uniqueID, h_project_i+
1d,task_id001, h_type, :n         '1', h_res_id, h_temp_participant, h_temp_se+
1curity_id, rec_user001, SYSTIMESTAMP,h_table_type):
1372:
1           EXCEPTION:: SP_A_TSKPROF(373) :: cplan.sql(6513) :: :
1PMO_STPU:
1BIT_OR:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT = PMO_STPU.BIT_OR(PARTICIPANT, pm+
1o_cnst.SC_TEAMMEMBER):n         WHERE RES_ASSIGNMENT_ID = h_uniqueID:
1393:
1           EXCEPTION:: SP_A_TSKPROF(394) :: cplan.sql(6534) :: :
1FC_AFTER_U_RES_ASSIGN:
14:
1402:
1       RETURN_STATUS:: SP_A_TSKPROF(403) :: cplan.sql(6543) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1409:
1           EXCEPTION:: SP_A_TSKPROF(410) :: cplan.sql(6550) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1421:
1           EXCEPTION:: SP_A_TSKPROF(422) :: cplan.sql(6562) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
b52
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a 52 10
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :7 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :7 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c a0 51 d :3 a0 6b d b7
a0 51 d :3 a0 6b d b7 :2 19
3c :2 a0 d :9 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 d
:3 a0 :2 51 a5 b d :9 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :1f a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c a0
b7 :2 a0 6b a0 7e a0 6b b4
2e 5a :3 a0 51 a5 b a5 b
7e 51 b4 2e :d a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 19 3c :2 a0 :2 51 a5 b
7e 6e b4 2e :4 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
19 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c a0 51 d :8 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e :f a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :2 a0 b4
2e d :4 a0 51 a5 b :2 a0 51
a5 b :2 a0 6b a0 a5 b d
:3 a0 51 a5 b a5 b 7e 51
b4 2e :3 a0 6b d b7 :3 a0 6b
d b7 :2 19 3c a0 6e d a0
51 d :9 a0 a5 b d :16 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 b7
:2 a0 6b a0 7e a0 6b b4 2e
5a :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 a5 b d b7 :2 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
b52
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ef
dd bc e1 e2 ea dc 10c fa
d9 fe ff 107 f9 129 117 f6
11b 11c 124 116 146 134 113 138
139 141 133 162 151 155 130 15d
150 17e 16d 171 14d 179 16c 19a
189 18d 169 195 188 1b6 1a5 1a9
185 1b1 1a4 1d2 1c1 1c5 1a1 1cd
1c0 1ef 1dd 1bd 1e1 1e2 1ea 1dc
20b 1fa 1fe 1d9 206 1f9 228 216
1f6 21a 21b 223 215 244 233 237
212 23f 232 260 24f 253 22f 25b
24e 280 26b 26f 24b 273 27b 26a
287 28b 267 28f 293 297 29a 29f
2a0 1 2a2 2a7 2ab 2af 2b2 2b7
2bb 2bf 2c2 2c7 2c8 2ca 2cf 2d2
2d6 2d7 2dc 2e1 2e4 2e9 2ea 2ef
2f2 2f6 2f7 2fc 2ff 304 305 30a
30d 312 313 318 31b 320 321 326
329 32d 32e 333 336 33b 33c 341
344 349 34a 34f 352 357 358 35d
360 364 365 36a 36d 372 373 378
37b 380 381 386 389 38e 38f 394
397 39b 39c 3a1 3a4 3a9 3aa 3af
3b2 3b7 3b8 3bd 3be 3c3 3c5 3c9
3cc 3d0 3d4 3d7 3db 3df 3e2 3e5
3ea 3ed 3f0 3f3 3f4 3f9 3fa 1
3fc 401 405 409 40c 411 416 419
41d 41e 423 424 429 42b 42f 432
436 439 43a 43f 442 445 449 44c
44d 452 455 1 458 45d 461 464
465 46a 46d 1 470 475 479 47d
480 484 488 48b 48e 493 496 499
49c 49d 4a2 4a3 1 4a5 4aa 4ae
4b2 4b5 4ba 4bf 4c2 4c6 4c7 4cc
4cf 4d4 4d5 4da 4dd 4e2 4e3 4e8
4eb 4ef 4f3 4f7 4fb 4fe 4ff 501
506 507 509 50a 50f 510 515 517
51b 51e 522 526 529 52d 531 534
537 53c 53f 542 545 546 54b 54c
1 54e 553 557 55b 55e 563 568
56b 56f 570 575 576 57b 57d 581
584 588 58c 58f 593 597 59a 59e
59f 5a4 5a6 5aa 5ad 5b1 5b5 5b9
5bd 5c1 5c5 5c9 5d5 5d9 5dd 5e0
5e4 5e8 5ea 5ee 5f2 5f6 5f9 5fd
601 603 604 609 1 60d 611 615
618 61c 620 624 628 62b 62f 633
636 639 63e 641 644 647 648 64d
64e 1 650 655 659 65d 660 665
66a 66d 671 672 677 67a 67f 680
685 688 68d 68e 693 696 69a 69b
6a0 6a3 6a8 6a9 6ae 6b1 6b5 6b9
6bc 6bf 6c0 6c2 6c3 6c8 6c9 6ce
6d0 6d4 6d7 6d9 6dd 6df 6eb 6ed
6ef 6f0 6f5 6f9 6fb 707 709 70d
711 714 718 71b 71f 722 723 728
72b 72f 733 737 73b 73f 743 747
753 757 75b 75e 762 766 768 76c
770 774 777 77b 77f 781 782 787
1 78b 78f 793 796 79a 79e 7a2
7a6 7a9 7ad 7b1 7b4 7b7 7bc 7bf
7c2 7c5 7c6 7cb 7cc 1 7ce 7d3
7d7 7db 7de 7e3 7e8 7eb 7ef 7f0
7f5 7f8 7fd 7fe 803 806 80b 80c
811 814 818 819 81e 821 826 827
82c 82f 833 837 83a 83d 83e 840
841 846 847 84c 84e 852 855 857
85b 85d 869 86b 86d 86e 873 877
879 885 887 88b 88f 892 896 899
89d 8a0 8a1 8a6 8a9 8ad 8b1 8b4
8b8 8bc 8bf 8c2 8c7 8ca 8cd 8d0
8d1 8d6 8d7 1 8d9 8de 8e2 8e6
8e9 8ee 8f3 8f6 8fa 8fb 900 903
908 909 90e 911 916 917 91c 91f
923 927 92b 92f 932 933 935 93a
93b 93d 93e 943 946 94b 94c 951
954 959 95a 95f 962 966 967 96c
96f 974 975 97a 97b 980 982 986
989 98d 991 994 998 99c 99f 9a2
9a7 9aa 9ad 9b0 9b1 9b6 9b7 1
9b9 9be 9c2 9c6 9c9 9ce 9d3 9d6
9da 9db 9e0 9e1 9e6 9e8 9ec 9ef
9f3 9f7 9fa 9fe a02 a05 a09 a0d
a0e a13 a15 a19 a1c a20 a23 a27
a2b a2f a33 a36 a3a a3c a40 a43
a47 a4b a4f a53 a56 a5a a5c a60
a64 a67 a6b a6f a73 a77 a7b a7f
a83 a87 a8b a8f a93 a97 aa3 aa7
aab aae ab2 ab6 ab8 abc ac0 ac4
ac7 acb acf ad1 ad2 ad7 1 adb
adf ae3 ae6 aea aee af2 af6 af9
afd b01 b04 b07 b0c b0f b12 b15
b16 b1b b1c 1 b1e b23 b27 b2b
b2e b33 b38 b3b b3f b40 b45 b48
b4d b4e b53 b56 b5b b5c b61 b64
b68 b69 b6e b71 b76 b77 b7c b7f
b83 b87 b8a b8d b8e b90 b91 b96
b97 b9c b9e ba2 ba5 ba7 bab bad
bb9 bbb bbd bbe bc3 bc7 bc9 bd5
bd7 bdb bdf be2 be6 be9 bed bf0
bf1 bf6 bf9 bfd c01 c05 c09 c0d
c11 c14 c17 c18 c1a c1e c22 c26
c2a c2e c32 c36 c3a c3e c42 c4e
c52 c56 c59 c5d c61 c63 c67 c6b
c6f c72 c76 c7a c7c c7d c82 1
c86 c8a c8e c91 c95 c99 c9d ca1
ca4 ca8 cac caf cb2 cb7 cba cbd
cc0 cc1 cc6 cc7 1 cc9 cce cd2
cd6 cd9 cde ce3 ce6 cea ceb cf0
cf3 cf8 cf9 cfe d01 d06 d07 d0c
d0f d13 d14 d19 d1c d21 d22 d27
d2a d2e d32 d35 d38 d39 d3b d3c
d41 d42 d47 d49 d4d d50 d52 d56
d58 d64 d66 d68 d69 d6e d72 d74
d80 d82 d86 d8a d8e d92 d96 d9a
d9e da2 da6 daa dae db2 db6 dba
dbe dc2 dc6 dca dce dd2 dd6 dda
dde de2 de6 dea dee df2 df6 dfa
dfe e0a e0e e12 e15 e19 e1d e1f
e23 e27 e2b e2e e32 e36 e38 e39
e3e 1 e42 e46 e4a e4d e51 e55
e59 e5d e60 e64 e68 e6b e6e e73
e76 e79 e7c e7d e82 e83 1 e85
e8a e8e e92 e95 e9a e9f ea2 ea6
ea7 eac eaf eb4 eb5 eba ebd ec2
ec3 ec8 ecb ecf ed0 ed5 ed8 edd
ede ee3 ee6 eea eee ef1 ef4 ef5
ef7 ef8 efd efe f03 f05 f09 f0c
f0e f12 f14 f20 f22 f24 f25 f2a
f2e f30 f3c f3e f42 f46 f49 f4d
f50 f54 f57 f58 f5d f60 f64 f68
f6b f6f f73 f76 f79 f7e f81 f84
f87 f88 f8d f8e 1 f90 f95 f99
f9d fa0 fa5 faa fad fb1 fb2 fb7
fba fbf fc0 fc5 fc8 fcd fce fd3
fd6 fda fde fe2 fe6 fe9 fea fec
ff1 ff2 ff4 ff5 ffa ffd 1002 1003
1008 100b 1010 1011 1016 1019 101d 101e
1023 1026 102b 102c 1031 1032 1037 1039
103d 1040 1044 1048 104b 104f 1053 1056
1059 105e 1061 1064 1067 1068 106d 106e
1 1070 1075 1079 107d 1080 1085 108a
108d 1091 1092 1097 1098 109d 109f 10a3
10a6 10aa 10ae 10b1 10b5 10b9 10bc 10c0
10c4 10c5 10ca 10cc 10d0 10d3 10d7 10db
10df 10e3 10e7 10eb 10ef 10f3 10f7 10fb
10ff 110b 110f 1114 1118 111b 111c 1121
1125 1129 112c 112f 1133 1135 1139 113d
1140 1143 1147 1149 114d 1151 1154 1156
115a 115e 1162 1165 1169 116d 116f 1170
1175 1 1179 117d 1181 1184 1188 118c
1190 1194 1197 119b 119f 11a2 11a5 11aa
11ad 11b0 11b3 11b4 11b9 11ba 1 11bc
11c1 11c5 11c9 11cc 11d1 11d6 11d9 11dd
11de 11e3 11e6 11eb 11ec 11f1 11f4 11f9
11fa 11ff 1202 1206 1207 120c 120f 1214
1215 121a 121d 1221 1225 1228 122b 122c
122e 122f 1234 1235 123a 123c 1240 1243
1245 1249 124b 1257 1259 125b 125c 1261
1265 1267 1273 1275 1279 127d 1280 1284
1287 128b 128e 128f 1294 1297 129b 129f
12a2 12a6 12aa 12ad 12b0 12b5 12b8 12bb
12be 12bf 12c4 12c5 1 12c7 12cc 12d0
12d4 12d7 12dc 12e1 12e4 12e8 12e9 12ee
12f1 12f6 12f7 12fc 12ff 1304 1305 130a
130d 1311 1315 1319 131d 1320 1321 1323
1328 1329 132b 132c 1331 1334 1339 133a
133f 1342 1347 1348 134d 1350 1354 1355
135a 135d 1362 1363 1368 1369 136e 1370
1374 1377 137b 137f 1382 1386 138a 138d
1390 1395 1398 139b 139e 139f 13a4 13a5
1 13a7 13ac 13b0 13b4 13b7 13bc 13c1
13c4 13c8 13c9 13ce 13cf 13d4 13d6 13da
13dd 13e1 13e5 13e8 13ec 13f0 13f3 13f7
13fb 13fc 1401 1403 1407 140a 140e 1410
1414 1418 141b 141f 1422 1426 1429 142a
142f 1432 1436 143a 143e 1441 1442 1444
1445 1447 144a 144d 144e 1453 1457 145b
145f 1463 1467 146b 146f 1473 1477 147b
147f 1483 1487 1493 1497 149b 149e 14a2
14a6 14a8 14ac 14b0 14b4 14b7 14bb 14bf
14c1 14c2 14c7 1 14cb 14cf 14d3 14d6
14da 14de 14e2 14e6 14e9 14ed 14f1 14f4
14f7 14fc 14ff 1502 1505 1506 150b 150c
1 150e 1513 1517 151b 151e 1523 1528
152b 152f 1530 1535 1538 153d 153e 1543
1546 154b 154c 1551 1554 1558 1559 155e
1561 1566 1567 156c 156f 1573 1577 157a
157d 157e 1580 1581 1586 1587 158c 158e
1592 1595 1597 159b 159d 15a9 15ab 15ad
15ae 15b3 15b7 15b9 15c5 15c7 15cb 15cf
15d2 15d6 15d9 15dd 15e0 15e1 15e6 15e9
15ed 15f1 15f4 15f8 15fc 15ff 1602 1607
160a 160d 1610 1611 1616 1617 1 1619
161e 1622 1626 1629 162e 1633 1636 163a
163b 1640 1643 1648 1649 164e 1651 1656
1657 165c 165f 1663 1667 166b 166f 1672
1673 1675 167a 167b 167d 167e 1683 1686
168b 168c 1691 1694 1699 169a 169f 16a2
16a6 16a7 16ac 16af 16b4 16b5 16ba 16bb
16c0 16c2 16c6 16c9 16cd 16d1 16d4 16d8
16dc 16df 16e2 16e7 16ea 16ed 16f0 16f1
16f6 16f7 1 16f9 16fe 1702 1706 1709
170e 1713 1716 171a 171b 1720 1721 1726
1728 172c 172f 1733 1737 173a 173e 1742
1745 1749 174d 174e 1753 1755 1759 175c
175e 1762 1765 1769 176d 1770 1773 1774
1776 1779 177e 177f 1784 1788 178c 1790
1794 17a0 17a4 17a9 17ad 17b0 17b1 17b6
17ba 17be 17c1 17c4 17c8 17ca 17ce 17d2
17d5 17d8 17dc 17de 17e2 17e6 17e9 17eb
17ef 17f3 17f7 17fa 17fe 1802 1804 1805
180a 1 180e 1812 1816 1819 181d 1821
1825 1829 182c 1830 1834 1837 183a 183f
1842 1845 1848 1849 184e 184f 1 1851
1856 185a 185e 1861 1866 186b 186e 1872
1873 1878 187b 1880 1881 1886 1889 188e
188f 1894 1897 189b 189c 18a1 18a4 18a9
18aa 18af 18b2 18b6 18ba 18bd 18c0 18c1
18c3 18c4 18c9 18ca 18cf 18d1 18d5 18d8
18da 18de 18e0 18ec 18ee 18f0 18f1 18f6
18fa 18fc 1908 190a 190c 1910 1913 1915
1919 191d 1921 1924 1928 192c 192f 1932
1937 193a 193d 1940 1941 1946 1947 1
1949 194e 1952 1956 1959 195e 1963 1966
196a 196b 1970 1973 1978 1979 197e 1981
1986 1987 198c 198f 1993 1997 199b 199f
19a2 19a3 19a5 19aa 19ab 19ad 19ae 19b3
19b6 19bb 19bc 19c1 19c4 19c9 19ca 19cf
19d2 19d6 19d7 19dc 19df 19e4 19e5 19ea
19eb 19f0 19f2 19f6 19f9 19fd 1a01 1a04
1a08 1a0c 1a0f 1a12 1a17 1a1a 1a1d 1a20
1a21 1a26 1a27 1 1a29 1a2e 1a32 1a36
1a39 1a3e 1a43 1a46 1a4a 1a4b 1a50 1a51
1a56 1a58 1a5c 1a5f 1a63 1a67 1a6a 1a6e
1a72 1a75 1a79 1a7d 1a7e 1a83 1a85 1a89
1a8d 1a90 1a94 1a97 1a9b 1a9f 1aa3 1aa7
1aab 1aaf 1ab3 1ab7 1abb 1ac7 1acb 1acf
1ad2 1ad6 1ada 1adc 1ae0 1ae4 1ae8 1aeb
1aef 1af3 1af5 1af6 1afb 1 1aff 1b03
1b07 1b0a 1b0e 1b12 1b16 1b1a 1b1d 1b21
1b25 1b28 1b2b 1b30 1b33 1b36 1b39 1b3a
1b3f 1b40 1 1b42 1b47 1b4b 1b4f 1b52
1b57 1b5c 1b5f 1b63 1b64 1b69 1b6c 1b71
1b72 1b77 1b7a 1b7f 1b80 1b85 1b88 1b8c
1b8d 1b92 1b95 1b9a 1b9b 1ba0 1ba3 1ba7
1bab 1bae 1bb1 1bb2 1bb4 1bb5 1bba 1bbb
1bc0 1bc2 1bc6 1bc9 1bcb 1bcf 1bd1 1bdd
1bdf 1be1 1be2 1be7 1beb 1bed 1bf9 1bfb
1bff 1c03 1c06 1c0a 1c0d 1c11 1c14 1c15
1c1a 1c1d 1c21 1c25 1c28 1c29 1c2b 1c2e
1c31 1c32 1c37 1c3b 1c3f 1c43 1c47 1c4b
1c4f 1c53 1c57 1c5b 1c5f 1c63 1c67 1c6b
1c6f 1c73 1c7f 1c83 1c88 1c8c 1c8f 1c90
1c95 1c99 1c9d 1ca0 1ca3 1ca7 1ca9 1cad
1cb1 1cb4 1cb7 1cbb 1cbd 1cc1 1cc5 1cc8
1cca 1cce 1cd2 1cd6 1cd9 1cdd 1ce1 1ce3
1ce4 1ce9 1 1ced 1cf1 1cf5 1cf8 1cfc
1d00 1d04 1d08 1d0b 1d0f 1d13 1d16 1d19
1d1e 1d21 1d24 1d27 1d28 1d2d 1d2e 1
1d30 1d35 1d39 1d3d 1d40 1d45 1d4a 1d4d
1d51 1d52 1d57 1d5a 1d5f 1d60 1d65 1d68
1d6d 1d6e 1d73 1d76 1d7a 1d7b 1d80 1d83
1d88 1d89 1d8e 1d91 1d95 1d99 1d9c 1d9f
1da0 1da2 1da3 1da8 1da9 1dae 1db0 1db4
1db7 1db9 1dbd 1dbf 1dcb 1dcd 1dcf 1dd0
1dd5 1dd9 1ddb 1de7 1de9 1ded 1def 1df3
1df7 1dfa 1dfb 1dfd 1e00 1e03 1e04 1e09
1e0d 1e11 1e15 1e19 1e1d 1e21 1e25 1e29
1e2d 1e31 1e35 1e39 1e3d 1e41 1e45 1e51
1e55 1e5a 1e5e 1e61 1e62 1e67 1e6b 1e6f
1e72 1e75 1e79 1e7b 1e7f 1e83 1e86 1e89
1e8d 1e8f 1e93 1e97 1e9a 1e9c 1ea0 1ea4
1ea8 1eab 1eaf 1eb3 1eb5 1eb6 1ebb 1
1ebf 1ec3 1ec7 1eca 1ece 1ed2 1ed6 1eda
1edd 1ee1 1ee5 1ee8 1eeb 1ef0 1ef3 1ef6
1ef9 1efa 1eff 1f00 1 1f02 1f07 1f0b
1f0f 1f12 1f17 1f1c 1f1f 1f23 1f24 1f29
1f2c 1f31 1f32 1f37 1f3a 1f3f 1f40 1f45
1f48 1f4c 1f4d 1f52 1f55 1f5a 1f5b 1f60
1f63 1f67 1f6b 1f6e 1f71 1f72 1f74 1f75
1f7a 1f7b 1f80 1f82 1f86 1f89 1f8b 1f8f
1f91 1f9d 1f9f 1fa1 1fa2 1fa7 1fab 1fad
1fb9 1fbb 1fbd 1fc1 1fc5 1fc8 1fcc 1fd0
1fd1 1fd6 1fda 1fde 1fe2 1fe6 1fea 1fed
1fee 1ff0 1ff4 1ff8 1ffb 1ffc 1ffe 2002
2006 2009 200d 200e 2010 2014 2018 201c
2020 2023 2024 2026 2027 2029 202c 202f
2030 2035 2039 203d 2041 2044 2048 204a
204e 2052 2056 2059 205d 205f 2063 2067
206a 206e 2073 2077 207b 207e 2082 2086
208a 208e 2092 2096 209a 209e 20a2 20a6
20a7 20a9 20ad 20b1 20b5 20b9 20bd 20c1
20c5 20c9 20cd 20d1 20d5 20d9 20dd 20e1
20e5 20e9 20ed 20f1 20f5 20f9 20fd 2101
2105 2111 2115 211a 211e 2121 2122 2127
212b 212f 2132 2135 2139 213b 213f 2143
2146 2149 214d 214f 2153 2157 215a 215c
2160 2164 2168 216b 216f 2173 2175 2176
217b 1 217f 2183 2187 218a 218e 2192
2196 219a 219d 21a1 21a5 21a8 21ab 21b0
21b3 21b6 21b9 21ba 21bf 21c0 1 21c2
21c7 21cb 21cf 21d2 21d7 21dc 21df 21e3
21e4 21e9 21ec 21f1 21f2 21f7 21fa 21ff
2200 2205 2208 220c 220d 2212 2215 221a
221b 2220 2223 2227 222b 222e 2231 2232
2234 2235 223a 223b 2240 2242 2246 2249
224b 224f 2251 225d 225f 2261 2262 2267
226b 226d 2279 227b 227f 2281 2285 2289
228c 2290 2293 2297 229a 229b 22a0 22a3
22a7 22ab 22af 22b3 22b7 22bb 22bf 22c3
22c7 22d3 22d7 22dc 22e0 22e3 22e4 22e9
22ed 22f1 22f4 22f7 22fb 22fd 2301 2305
2308 230b 230f 2311 2315 2319 231c 231e
2322 2326 232a 232d 2331 2335 2337 2338
233d 1 2341 2345 2349 234c 2350 2354
2358 235c 235f 2363 2367 236a 236d 2372
2375 2378 237b 237c 2381 2382 1 2384
2389 238d 2391 2394 2399 239e 23a1 23a5
23a6 23ab 23ae 23b3 23b4 23b9 23bc 23c1
23c2 23c7 23ca 23ce 23cf 23d4 23d7 23dc
23dd 23e2 23e5 23e9 23ed 23f0 23f3 23f4
23f6 23f7 23fc 23fd 2402 2404 2408 240b
240d 2411 2413 241f 2421 2423 2424 2429
242d 242f 243b 243d 2441 2445 2449 244a
244c 2450 2452 2456 245a 245d 2461 2465
2468 246c 2470 2473 2476 247b 247e 2481
2484 2485 248a 248b 1 248d 2492 2496
249a 249d 24a2 24a7 24aa 24ae 24af 24b4
24b7 24bc 24bd 24c2 24c5 24ca 24cb 24d0
24d3 24d7 24db 24df 24e3 24e6 24e7 24e9
24ee 24ef 24f1 24f2 24f7 24fa 24ff 2500
2505 2508 250d 250e 2513 2516 251a 251b
2520 2523 2528 2529 252e 252f 2534 2536
253a 253d 2541 2545 2548 254c 2550 2553
2557 255b 255c 2561 2563 2567 256b 256e
2572 2576 2579 257d 2581 2584 2587 258c
258f 2592 2595 2596 259b 259c 1 259e
25a3 25a7 25ab 25ae 25b3 25b8 25bb 25bf
25c0 25c5 25c6 25cb 25cf 25d3 25d6 25db
25e0 25e3 25e7 25eb 25ee 25ef 25f4 25f7
25fc 25fd 2602 2605 2609 260d 2610 2611
2616 2617 261c 261e 2622 2625 2629 262d
2631 2635 2639 263d 2641 2645 2649 2655
265a 265e 2662 2666 266a 266c 266d 2672
1 2676 267a 267e 2681 2685 2689 268d
2691 2694 2698 269c 269f 26a2 26a7 26aa
26ad 26b0 26b1 26b6 26b7 1 26b9 26be
26c2 26c6 26c9 26ce 26d3 26d6 26da 26db
26e0 26e1 26e6 26ea 26ee 26f1 26f6 26fb
26fe 2702 2703 2708 270b 2710 2711 2716
2719 271d 2721 2724 2727 2728 272a 272b
2730 2731 2736 2738 273c 273f 2743 2747
274b 274f 2753 2757 275b 2767 276c 2770
2774 2778 277c 277e 2782 2784 2790 2792
2794 2795 279a 279e 27a0 27ac 27b0 27b2
27b3 27bc 
b52
2
0 1 a 6 11 :3 6 10 :3 6
11 :3 6 12 :2 6 1 3 a 13
a :2 1 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 d 16 15
:2 d :2 4 10 19 18 :2 10 :2 4 e
17 16 :2 e :2 4 11 1a 19 :2 11
:2 4 10 19 18 :2 10 :2 4 :2 b 1a
b :2 4 :2 a 19 a :2 4 :2 e 1d
e :2 4 :2 d 1c d :2 4 :2 17 26
17 :2 4 17 20 1f :2 17 :2 4 :2 13
22 13 :2 4 14 1d 1c :2 14 :2 4
:2 14 23 14 :2 4 :2 11 20 11 :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 54 5a 5d :2 54 6b 81 8
:2 6b d 10 :2 6b 1b 1e :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
28 2b :2 6b b e :2 6b 13 16
:2 6b 1b 1e :2 6b 29 2c :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
2a 2d :2 6b 32 35 :2 6b :2 7 4a
:2 4 7 :2 11 23 :2 2d 39 3c 4c
4e 4f :2 4c :2 23 :3 7 :2 d 12 1e
5c 5f :2 1e :2 7 52 :2 4 :4 9 8
7 :4 23 22 21 :2 7 :4 3c 3b 3a
:2 7 a :2 14 26 :2 30 3c 3f 4f
51 52 :2 4f :2 26 :3 a :2 10 15 21
5f 62 :2 21 6f 72 :2 21 76 79
:2 21 83 86 8f 97 :2 a0 :2 8f b1
:2 86 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4f 51 52 :2 4f :2 26
:3 a :2 10 15 21 5f 62 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 41 :2 7 51
:2 4 e 1a 27 35 41 4f 5c
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 53
55 56 :2 53 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 88 8b :2 24 93 96 :2 24 a2
a5 ac b5 b8 :2 a5 :2 24 :2 d 59
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1c 1a :2 25 :2 1a 7 11 1d 2a
38 44 52 5f :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 58 59 :2 56 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 8b 8e :2 27
96 99 :2 27 a5 a8 af b8 bb
:2 a8 :2 27 :2 10 5c :2 d :2 a :4 16 :2 a
7 :3 35 b :2 14 1f 1d :2 28 :2 1d
a d :2 17 29 :2 33 3f 43 53
55 56 :2 53 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 86 89 92 9a :2 a3 :2 92 b6
:2 89 :2 24 be c1 :2 24 c9 cc :2 24
d1 d4 :2 24 df e2 :2 24 :2 d 59
:2 a d :2 17 29 :2 33 3f 42 52
54 55 :2 52 :2 29 :3 d :2 13 18 24
62 65 :2 24 :2 d 58 :3 a :2 15 29
:2 32 44 50 :2 a 38 :3 7 10 :2 7
17 :2 20 7 35 7 10 :2 7 17
:2 20 7 :5 4 10 4 e 1a 28
38 42 4f c 1b 28 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 53 56 57
:2 53 :2 29 :3 d :2 13 18 24 63 66
:2 24 73 76 :2 24 7a 7d :2 24 89
8c :2 24 94 97 :2 24 a3 a6 ad
b6 b9 :2 a6 :2 24 :2 d 5a :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a :2 7 16 :2 7 14 1b 28
2b :2 14 7 11 1a 1e 35 f
10 1b 2c 34 :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 35 11 1c 29 34 41 4c
59 64 71 7c 89 8f 93 a9
af b2 c8 ce d6 ed f 20
24 35 10 13 20 2e 32 3f
42 :2 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 35 b
:2 14 1f 1d :2 28 :2 1d a d :2 17
29 :2 33 3f 43 53 56 57 :2 53
:2 29 :3 d :2 13 18 24 63 66 :2 24
73 76 :2 24 7a 7d :2 24 87 8a
93 9b :2 a4 :2 93 b7 :2 8a :2 24 bf
c2 :2 24 ca cd :2 24 d2 d5 :2 24
de e1 :2 24 :2 d 5a :2 a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 63 66 :2 24
:2 d 59 :3 a :2 15 29 :2 32 44 4e
:2 a 38 :2 7 16 1f 2a 35 3d
4a 11 1b 29 34 3e a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 35 b
:2 14 20 1d :2 29 :2 1d a d :2 17
29 :2 33 3f 43 53 56 57 :2 53
:2 29 :3 d :2 13 18 24 63 66 :2 24
73 76 :2 24 7a 7d :2 24 87 8a
93 9b :2 a4 :2 93 af :2 8a :2 24 b7
ba :2 24 c2 c5 :2 24 ca cd :2 24
d7 da :2 24 :2 d 5a :2 a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 63 66 :2 24
:2 d 59 :3 a :2 15 29 :2 32 3c 47
:2 a 39 :2 7 4 35 b :2 14 1f
1d :2 28 :2 1d :2 a 1b 24 2c :2 1b
:2 a 30 33 :2 30 14 16 2d 12
27 13 15 22 11 13 21 11
13 :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
59 5c 5d :2 59 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8f 92 :2 2a 9a 9d :2 2a
a9 ac b3 bc bf :2 ac :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :3 35 e
:2 17 22 20 :2 2b :2 20 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8a 8d
96 9e :2 a7 :2 96 c1 :2 8d :2 27 c9
cc :2 27 d4 d7 :2 27 dc df :2 27
e9 ec :2 27 :2 10 5d :2 d 10 :2 1a
2c :2 36 42 45 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
:2 10 5c :3 d :2 18 2c :2 35 4e 59
:2 d 3b :2 a 35 :2 7 a 11 1f
22 :2 a 25 27 :2 25 14 21 38
45 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5c 5d :2 59 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :4 2b :2 7 38 35 a :2 14 26
:2 30 3c 40 50 53 54 :2 50 :2 26
:3 a :2 10 15 21 60 63 :2 21 70
73 :2 21 77 7a :2 21 84 87 90
98 :2 a1 :2 90 b4 :2 87 :2 21 bc bf
:2 21 c7 ca :2 21 cf d2 :2 21 dc
df :2 21 :2 a 57 :2 7 a :2 14 26
:2 30 3c 3f 4f 52 53 :2 4f :2 26
:3 a :2 10 15 21 60 63 :2 21 :2 a
56 :3 7 :2 12 26 :2 2f 41 4c :2 7
:5 4 11 4 e 25 c d 1a
b 19 b :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 53 56 57 :2 53 :2 29 :3 d
:2 13 18 24 63 66 :2 24 73 76
:2 24 7a 7d :2 24 89 8c :2 24 94
97 :2 24 a3 a6 ad b6 b9 :2 a6
:2 24 :2 d 5a :2 a :2 7 :4 13 :2 7 4
:3 1 8 :2 11 1c 1a :2 25 :2 1a 7
a 13 1a :2 a 1d 1f :2 1d 14
20 12 19 27 44 12 19 28
2f 49 12 22 13 20 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
59 5c 5d :2 59 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8f 92 :2 2a 9a 9d :2 2a
a9 ac b3 bc bf :2 ac :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :3 21 7
21 d 16 1d :2 d 20 22 :2 20
14 20 12 19 27 44 12 19
28 2f 49 12 22 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 59 5c 5d :2 59 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8f 92 :2 2a 9a 9d
:2 2a a9 ac b3 bc bf :2 ac :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :4 24
21 :3 7 :3 15 :2 7 1a 28 31 3f
:2 28 43 4c 54 :2 43 24 :2 2d 42
:2 1a 7 a 18 21 29 :2 18 :2 a
2d 30 :2 2d a 20 :2 29 a 32
a 20 :2 29 a :5 7 1a :2 7 19
:2 7 1a 31 3f 49 51 2d 41
52 :2 1a 7 16 2b 3e 4a 56
a 19 26 33 40 4a 57 12
1e 2b 37 f 19 2d 41 4e
5b a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 35 4 35 b :2 14 1f 1d
:2 28 :2 1d a 11 2a 38 41 48
55 5e 10 24 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 38 7 1a 30
:2 1a 7 38 35 :2 4 7 :2 11 23
:2 2d 39 3c 4c 4f 50 :2 4c :2 23
:3 7 :2 d 12 1e 5d 60 :2 1e 6d
70 :2 1e 74 77 :2 1e 81 84 8d
95 :2 9e :2 8d a9 :2 84 :2 1e b1 b4
:2 1e bc bf :2 1e c4 c7 :2 1e d2
d5 :2 1e :2 7 53 :3 4 :2 f 21 :2 2a
34 40 :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 50 53 54
:2 50 :2 26 :3 a :2 10 15 21 60 63
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 57 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4d 50 51
:2 4d :2 23 :3 7 :2 d 12 1e 5d 60
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 54 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
b52
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:7 c :7 d :7 e :7 f
:6 10 :6 11 :6 12 :6 13
:6 14 :7 15 :6 16 :7 17
:6 18 :6 19 :7 1b :b 1d
:11 1e 1f :2 1e :2 1f
:2 1e :2 1f :2 1e :2 20
:2 1e :2 20 :2 1e :2 20
:2 1e :2 20 :2 1e :2 21
:2 1e :2 21 :2 1e :2 21
:2 1e :2 21 :2 1e :2 22
:2 1e :2 22 :2 1e :2 22
:2 1e :2 22 :2 1e :2 22
:4 1e :3 1d :11 25 :b 26
:3 25 :16 2b :11 2c :20 2d
:3 2c :11 2f :b 30 :3 2f
:9 32 :3 2b :8 36 :5 37
35 39 :5 3a :3 39
:2 3b :5 3d :11 3e :24 3f
:3 3e :2 3c :6 3b 38
:3 1c :a 44 :8 46 :5 47
45 49 :5 4a :3 49
:2 4b :5 4d :11 4e :24 4f
:3 4e :2 4c :6 4b 48
:3 44 :a 54 :11 55 :30 56
:3 55 :11 58 :b 59 :3 58
:a 5b :3 54 :3 5d :5 5e
44 :3 60 :5 61 5f
:3 44 :3 64 :6 68 :3 69
68 :5 6a 67 6c
:5 6d :3 6c :2 6e :5 70
:11 71 :24 72 :3 71 :2 6f
:6 6e 6b :3 1c :a 77
:3 78 :8 7a :4 7d 7e
:4 7f 7d :5 80 7c
82 :5 83 :3 82 :2 84
:5 86 :11 87 :24 88 :3 87
:2 85 :6 84 81 :3 77
:14 8e :4 8f :7 90 8e
:5 91 8d 93 :5 94
:3 93 :2 95 :5 97 :11 98
:24 99 :3 98 :2 96 :6 95
92 :3 77 :a 9e :11 9f
:30 a0 :3 9f :11 a2 :b a3
:3 a2 :a a5 :3 9e :6 a9
:5 aa a9 :6 ab :5 ac
ab :5 ae ad :3 ab
a8 b1 :5 b2 :3 b1
:2 b3 :5 b5 :11 b6 :24 b7
:3 b6 :2 b4 :6 b3 b0
:3 77 :a bc :11 bd :30 be
:3 bd :11 c0 :b c1 :3 c0
:a c3 :3 bc c5 77
:a c5 :c c6 :3 c8 :2 c9
:3 ca :3 cb :2 cc c8
:5 cd c7 cf :5 d0
:3 cf :2 d1 :5 d3 :11 d4
:24 d5 :3 d4 :2 d2 :6 d1
ce :3 c6 :a da :11 db
:30 dc :3 db :11 de :b df
:3 de :a e1 :3 da :3 c6
:a e5 :5 e7 :6 e8 :5 e9
e8 :5 eb ea :3 e8
e6 ee :5 ef :3 ee
:2 f0 :5 f2 :11 f3 :24 f4
:3 f3 :2 f1 :6 f0 ed
:6 e5 c5 77 :11 fa
:30 fb :3 fa :11 fd :b fe
:3 fd :a 100 f9 :3 77
:3 103 :2 105 106 :2 107
:2 108 109 105 :5 10a
104 10c :5 10d :3 10c
:2 10e :5 110 :11 111 :24 112
:3 111 :2 10f :6 10e 10b
:3 1c :a 118 :9 119 :2 11b
:4 11d :5 120 :2 121 :2 124
11b :6 125 :5 126 125
:5 128 127 :3 125 11a
12b :5 12c :3 12b :2 12d
:5 12f :11 130 :24 131 :3 130
:2 12e :6 12d 12a :3 119
135 119 :9 135 :2 137
:4 139 :5 13c :2 13d :2 140
137 :6 141 :5 142 141
:5 144 143 :3 141 136
147 :5 148 :3 147 :2 149
:5 14b :11 14c :24 14d :3 14c
:2 14a :6 149 146 :4 135
:3 119 :5 154 :c 155 :4 156
:3 155 :c 158 :5 159 158
:5 15b 15a :3 158 :3 15e
:3 15f :6 161 :3 162 :3 161
:5 165 :7 166 :4 167 :6 168
165 :6 169 :5 16a 169
:5 16c 16b :3 169 164
16f :5 170 :3 16f :2 171
:5 173 :11 174 :24 175 :3 174
:2 172 :6 171 16e :3 118
17a 118 :a 17a :7 17c
:2 17d 17c :6 17e :5 17f
17e :5 181 180 :3 17e
17b 184 :5 185 :3 184
:2 186 :5 188 :11 189 :24 18a
:3 189 :2 187 :6 186 183
:3 17a :6 18f 17a :3 118
:11 192 :30 193 :3 192 :a 195
1c :3 198 :11 199 :b 19a
:17 19b :3 199 :2 19d :3 19e
:3 19f 1a0 19e 19d
19e :3 1a1 :3 198 :2 1a2
:5 1a4 :11 1a5 :b 1a6 :18 1a7
:3 1a5 :2 1a9 1aa :3 1ab
1ac 1aa 1a9 1aa
:3 1ad :2 1a3 :6 1a2 197
:7 1 
27be
4
:3 0 1 :3 0 2
:a 0 b4d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 15 16 0
b 4 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :3 0
a :2 0 4 13
17 0 b4d 2
18 :2 0 c :2 0
12 4 :3 0 c
:2 0 10 1b 1d
:6 0 20 1e 0
b4b 0 b :6 0
c :2 0 16 4
:3 0 14 22 24
:6 0 27 25 0
b4b 0 d :6 0
10 :2 0 1a 4
:3 0 18 29 2b
:6 0 2e 2c 0
b4b 0 e :6 0
c :2 0 1e 4
:3 0 1c 30 32
:6 0 35 33 0
b4b 0 f :6 0
13 :2 0 22 4
:3 0 20 37 39
:6 0 3c 3a 0
b4b 0 11 :6 0
15 :2 0 26 4
:3 0 24 3e 40
:6 0 43 41 0
b4b 0 12 :6 0
18 :2 0 2a 4
:3 0 28 45 47
:6 0 4a 48 0
b4b 0 14 :6 0
18 :2 0 2c 17
:3 0 4c :7 0 50
4d 4e b4b 0
16 :6 0 18 :2 0
2e 17 :3 0 52
:7 0 56 53 54
b4b 0 19 :6 0
18 :2 0 30 17
:3 0 58 :7 0 5c
59 5a b4b 0
1a :6 0 18 :2 0
32 17 :3 0 5e
:7 0 62 5f 60
b4b 0 1b :6 0
c :2 0 34 17
:3 0 64 :7 0 68
65 66 b4b 0
1c :6 0 18 :2 0
38 4 :3 0 36
6a 6c :6 0 6f
6d 0 b4b 0
1d :6 0 13 :2 0
3a 17 :3 0 71
:7 0 75 72 73
b4b 0 1e :6 0
18 :2 0 3e 4
:3 0 3c 77 79
:6 0 7c 7a 0
b4b 0 1f :6 0
18 :2 0 40 17
:3 0 7e :7 0 82
7f 80 b4b 0
20 :6 0 8a 8b
0 42 17 :3 0
84 :7 0 88 85
86 b4b 0 21
:6 0 90 91 0
44 9 :3 0 a
:2 0 4 8c :7 0
8f 8d 0 b4b
0 22 :6 0 23
:3 0 24 :3 0 23
:3 0 25 :3 0 93
94 0 2 :4 0
46 95 97 92
99 98 :2 0 26
:3 0 27 :3 0 9b
9c 0 28 :4 0
23 :3 0 29 :3 0
9f a0 0 2
:4 0 48 a1 a3
2a :4 0 2b :2 0
2c :3 0 4a a6
a8 :3 0 2d :4 0
2b :2 0 2e :4 0
4d ab ad :3 0
2b :2 0 3 :3 0
50 af b1 :3 0
2b :2 0 2e :4 0
53 b3 b5 :3 0
2b :2 0 2f :4 0
56 b7 b9 :3 0
2b :2 0 2e :4 0
59 bb bd :3 0
2b :2 0 5 :3 0
5c bf c1 :3 0
2b :2 0 2e :4 0
5f c3 c5 :3 0
2b :2 0 2f :4 0
62 c7 c9 :3 0
2b :2 0 2e :4 0
65 cb cd :3 0
2b :2 0 6 :3 0
68 cf d1 :3 0
2b :2 0 2e :4 0
6b d3 d5 :3 0
2b :2 0 2f :4 0
6e d7 d9 :3 0
2b :2 0 2e :4 0
71 db dd :3 0
2b :2 0 7 :3 0
74 df e1 :3 0
2b :2 0 2e :4 0
77 e3 e5 :3 0
2b :2 0 30 :4 0
7a e7 e9 :3 0
7d 9d eb :2 0
ed 82 ee 9a
ed 0 ef 84
0 aab 23 :3 0
24 :3 0 f0 f1
0 23 :3 0 31
:3 0 f3 f4 0
13 :2 0 2 :4 0
32 :2 0 33 :2 0
13 :2 0 86 f9
fb :3 0 89 f5
fd f2 ff fe
:2 0 26 :3 0 34
:3 0 101 102 0
28 :4 0 35 :4 0
2b :2 0 2c :3 0
8d 106 108 :3 0
90 103 10a :2 0
10c 93 10d 100
10c 0 10e 95
0 aab 3 :3 0
36 :2 0 97 110
111 :3 0 112 :2 0
113 :2 0 5 :3 0
36 :2 0 99 116
117 :3 0 118 :2 0
119 :2 0 114 11b
11a :2 0 6 :3 0
36 :2 0 9b 11e
11f :3 0 120 :2 0
121 :2 0 11c 123
122 :2 0 23 :3 0
24 :3 0 125 126
0 23 :3 0 31
:3 0 128 129 0
37 :2 0 2 :4 0
38 :2 0 33 :2 0
13 :2 0 9d 12e
130 :3 0 a0 12a
132 127 134 133
:2 0 26 :3 0 34
:3 0 136 137 0
28 :4 0 39 :4 0
2b :2 0 2c :3 0
a4 13b 13d :3 0
2b :2 0 3a :4 0
a7 13f 141 :3 0
2b :2 0 3b :4 0
aa 143 145 :3 0
2b :2 0 3c :3 0
3d :3 0 3e :3 0
3f :3 0 14a 14b
0 ad 149 14d
40 :4 0 af 148
150 b2 147 152
:3 0 b5 138 154
:2 0 156 b8 157
135 156 0 158
ba 0 181 23
:3 0 24 :3 0 159
15a 0 23 :3 0
31 :3 0 15c 15d
0 13 :2 0 2
:4 0 41 :2 0 33
:2 0 13 :2 0 bc
162 164 :3 0 bf
15e 166 15b 168
167 :2 0 26 :3 0
34 :3 0 16a 16b
0 28 :4 0 42
:4 0 2b :2 0 2c
:3 0 c3 16f 171
:3 0 c6 16c 173
:2 0 175 c9 176
169 175 0 177
cb 0 181 43
:3 0 44 :3 0 178
179 0 3e :3 0
3f :3 0 17b 17c
0 45 :3 0 cd
17a 17f :2 0 181
d0 182 124 181
0 183 d4 0
aab 46 :3 0 47
:3 0 d :3 0 16
:3 0 48 :3 0 49
:3 0 3 :4 0 4a
1 :8 0 191 9
:3 0 4b :3 0 18c
18d 0 4c :3 0
18e 18f 0 191
d6 1e4 4d :3 0
9 :3 0 4b :3 0
193 194 0 4c
:3 0 195 196 0
198 d9 19a db
199 198 :2 0 1e2
4e :3 0 9 :3 0
4b :3 0 19d 19e
0 4c :3 0 19f
1a0 0 1da 23
:3 0 24 :3 0 1a2
1a3 0 23 :3 0
31 :3 0 1a5 1a6
0 4f :2 0 2
:4 0 50 :2 0 33
:2 0 13 :2 0 dd
1ab 1ad :3 0 e0
1a7 1af 1a4 1b1
1b0 :2 0 26 :3 0
34 :3 0 1b3 1b4
0 28 :4 0 51
:4 0 2b :2 0 2c
:3 0 e4 1b8 1ba
:3 0 2b :2 0 3a
:4 0 e7 1bc 1be
:3 0 2b :2 0 52
:4 0 ea 1c0 1c2
:3 0 2b :2 0 4c
:3 0 ed 1c4 1c6
:3 0 2b :2 0 53
:4 0 f0 1c8 1ca
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 f3
1cd 1d1 f7 1cc
1d3 :3 0 fa 1b5
1d5 :2 0 1d7 fd
1d8 1b2 1d7 0
1d9 ff 0 1da
101 1dd :3 0 1dd
0 1dd 1dc 1da
1db :6 0 1df 2
:3 0 104 1e1 106
1e0 1df :2 0 1e2
108 :2 0 1e4 0
1e4 1e3 191 1e2
:6 0 aab 1 :3 0
9 :3 0 4b :3 0
1e6 1e7 0 9
:3 0 57 :2 0 58
:3 0 1e9 1eb 0
10d 1ea 1ed :3 0
1ee :2 0 46 :3 0
47 :3 0 d :3 0
16 :3 0 59 :3 0
49 :3 0 3 :4 0
5a 1 :8 0 1fd
9 :3 0 4b :3 0
1f8 1f9 0 4c
:3 0 1fa 1fb 0
1fd 110 250 4d
:3 0 9 :3 0 4b
:3 0 1ff 200 0
4c :3 0 201 202
0 204 113 206
115 205 204 :2 0
24e 4e :3 0 9
:3 0 4b :3 0 209
20a 0 4c :3 0
20b 20c 0 246
23 :3 0 24 :3 0
20e 20f 0 23
:3 0 31 :3 0 211
212 0 4f :2 0
2 :4 0 5b :2 0
33 :2 0 13 :2 0
117 217 219 :3 0
11a 213 21b 210
21d 21c :2 0 26
:3 0 34 :3 0 21f
220 0 28 :4 0
5c :4 0 2b :2 0
2c :3 0 11e 224
226 :3 0 2b :2 0
3a :4 0 121 228
22a :3 0 2b :2 0
52 :4 0 124 22c
22e :3 0 2b :2 0
4c :3 0 127 230
232 :3 0 2b :2 0
53 :4 0 12a 234
236 :3 0 2b :2 0
54 :3 0 55 :3 0
13 :2 0 56 :2 0
12d 239 23d 131
238 23f :3 0 134
221 241 :2 0 243
137 244 21e 243
0 245 139 0
246 13b 249 :3 0
249 0 249 248
246 247 :6 0 24b
4 :3 0 13e 24d
140 24c 24b :2 0
24e 142 :2 0 250
0 250 24f 1fd
24e :6 0 2d4 1
:3 0 9 :3 0 4b
:3 0 252 253 0
9 :3 0 57 :2 0
58 :3 0 255 257
0 147 256 259
:3 0 25a :2 0 23
:3 0 24 :3 0 25c
25d 0 23 :3 0
31 :3 0 25f 260
0 c :2 0 2
:4 0 5d :2 0 33
:2 0 13 :2 0 14a
265 267 :3 0 14d
261 269 25e 26b
26a :2 0 26 :3 0
34 :3 0 26d 26e
0 28 :4 0 5e
:4 0 2b :2 0 2c
:3 0 151 272 274
:3 0 2b :2 0 3a
:4 0 154 276 278
:3 0 2b :2 0 3b
:4 0 157 27a 27c
:3 0 2b :2 0 3c
:3 0 3d :3 0 3e
:3 0 5f :3 0 281
282 0 15a 280
284 40 :4 0 15c
27f 287 15f 27e
289 :3 0 2b :2 0
60 :4 0 162 28b
28d :3 0 2b :2 0
2e :4 0 165 28f
291 :3 0 2b :2 0
3 :3 0 168 293
295 :3 0 2b :2 0
2e :4 0 16b 297
299 :3 0 16e 26f
29b :2 0 29d 171
29e 26c 29d 0
29f 173 0 2c9
23 :3 0 24 :3 0
2a0 2a1 0 23
:3 0 31 :3 0 2a3
2a4 0 13 :2 0
2 :4 0 61 :2 0
33 :2 0 13 :2 0
175 2a9 2ab :3 0
178 2a5 2ad 2a2
2af 2ae :2 0 26
:3 0 34 :3 0 2b1
2b2 0 28 :4 0
62 :4 0 2b :2 0
2c :3 0 17c 2b6
2b8 :3 0 17f 2b3
2ba :2 0 2bc 182
2bd 2b0 2bc 0
2be 184 0 2c9
43 :3 0 63 :3 0
2bf 2c0 0 3e
:3 0 5f :3 0 2c2
2c3 0 3 :3 0
45 :3 0 186 2c1
2c7 :2 0 2c9 18a
2ca 25b 2c9 0
2cb 18e 0 2d4
19 :3 0 13 :2 0
2cc 2cd 0 2d4
21 :3 0 3e :3 0
64 :3 0 2d0 2d1
0 2cf 2d2 0
2d4 190 2de 19
:3 0 18 :2 0 2d5
2d6 0 2dd 21
:3 0 3e :3 0 65
:3 0 2d9 2da 0
2d8 2db 0 2dd
195 2df 1ef 2d4
0 2e0 0 2dd
0 2e0 198 0
aab e :3 0 5
:3 0 2e1 2e2 0
aab 66 :3 0 67
:3 0 68 :3 0 e
:3 0 14 :3 0 12
:3 0 69 :3 0 66
:3 0 e :4 0 6a
1 :8 0 2f3 9
:3 0 4b :3 0 2ee
2ef 0 4c :3 0
2f0 2f1 0 2f3
19b 346 4d :3 0
9 :3 0 4b :3 0
2f5 2f6 0 4c
:3 0 2f7 2f8 0
2fa 19e 2fc 1a0
2fb 2fa :2 0 344
4e :3 0 9 :3 0
4b :3 0 2ff 300
0 4c :3 0 301
302 0 33c 23
:3 0 24 :3 0 304
305 0 23 :3 0
31 :3 0 307 308
0 4f :2 0 2
:4 0 6b :2 0 33
:2 0 13 :2 0 1a2
30d 30f :3 0 1a5
309 311 306 313
312 :2 0 26 :3 0
34 :3 0 315 316
0 28 :4 0 6c
:4 0 2b :2 0 2c
:3 0 1a9 31a 31c
:3 0 2b :2 0 3a
:4 0 1ac 31e 320
:3 0 2b :2 0 52
:4 0 1af 322 324
:3 0 2b :2 0 4c
:3 0 1b2 326 328
:3 0 2b :2 0 53
:4 0 1b5 32a 32c
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 1b8
32f 333 1bc 32e
335 :3 0 1bf 317
337 :2 0 339 1c2
33a 314 339 0
33b 1c4 0 33c
1c6 33f :3 0 33f
0 33f 33e 33c
33d :6 0 341 6
:3 0 1c9 343 1cb
342 341 :2 0 344
1cd :2 0 346 0
346 345 2f3 344
:6 0 aab 1 :3 0
9 :3 0 4b :3 0
348 349 0 9
:3 0 57 :2 0 58
:3 0 34b 34d 0
1d2 34c 34f :3 0
350 :2 0 f :3 0
6 :3 0 352 353
0 5a6 11 :3 0
54 :3 0 f :3 0
13 :2 0 c :2 0
1d5 356 35a 355
35b 0 5a6 3c
:3 0 6d :3 0 6e
:3 0 1b :3 0 69
:3 0 46 :3 0 d
:3 0 6f :3 0 11
:4 0 70 1 :8 0
36c 9 :3 0 4b
:3 0 367 368 0
4c :3 0 369 36a
0 36c 1d9 3bf
4d :3 0 9 :3 0
4b :3 0 36e 36f
0 4c :3 0 370
371 0 373 1dc
375 1de 374 373
:2 0 3bd 4e :3 0
9 :3 0 4b :3 0
378 379 0 4c
:3 0 37a 37b 0
3b5 23 :3 0 24
:3 0 37d 37e 0
23 :3 0 31 :3 0
380 381 0 4f
:2 0 2 :4 0 71
:2 0 33 :2 0 13
:2 0 1e0 386 388
:3 0 1e3 382 38a
37f 38c 38b :2 0
26 :3 0 34 :3 0
38e 38f 0 28
:4 0 72 :4 0 2b
:2 0 2c :3 0 1e7
393 395 :3 0 2b
:2 0 3a :4 0 1ea
397 399 :3 0 2b
:2 0 52 :4 0 1ed
39b 39d :3 0 2b
:2 0 4c :3 0 1f0
39f 3a1 :3 0 2b
:2 0 53 :4 0 1f3
3a3 3a5 :3 0 2b
:2 0 54 :3 0 55
:3 0 13 :2 0 56
:2 0 1f6 3a8 3ac
1fa 3a7 3ae :3 0
1fd 390 3b0 :2 0
3b2 200 3b3 38d
3b2 0 3b4 202
0 3b5 204 3b8
:3 0 3b8 0 3b8
3b7 3b5 3b6 :6 0
3ba 8 :3 0 207
3bc 209 3bb 3ba
:2 0 3bd 20b :2 0
3bf 0 3bf 3be
36c 3bd :6 0 5a6
1 :3 0 73 :3 0
74 :3 0 73 :3 0
74 :3 0 73 :3 0
74 :3 0 73 :3 0
74 :3 0 73 :3 0
74 :3 0 75 :3 0
76 :3 0 77 :3 0
75 :3 0 78 :3 0
77 :3 0 75 :3 0
3d :3 0 1b :3 0
14 :3 0 79 :3 0
78 :3 0 79 :3 0
76 :3 0 78 :3 0
49 :3 0 11 :3 0
76 :3 0 49 :3 0
78 :3 0 7a :4 0
7b 1 :8 0 3e6
9 :3 0 4b :3 0
3e1 3e2 0 4c
:3 0 3e3 3e4 0
3e6 20e 439 4d
:3 0 9 :3 0 4b
:3 0 3e8 3e9 0
4c :3 0 3ea 3eb
0 3ed 211 3ef
213 3ee 3ed :2 0
437 4e :3 0 9
:3 0 4b :3 0 3f2
3f3 0 4c :3 0
3f4 3f5 0 42f
23 :3 0 24 :3 0
3f7 3f8 0 23
:3 0 31 :3 0 3fa
3fb 0 4f :2 0
2 :4 0 7c :2 0
33 :2 0 13 :2 0
215 400 402 :3 0
218 3fc 404 3f9
406 405 :2 0 26
:3 0 34 :3 0 408
409 0 28 :4 0
7d :4 0 2b :2 0
2c :3 0 21c 40d
40f :3 0 2b :2 0
3a :4 0 21f 411
413 :3 0 2b :2 0
52 :4 0 222 415
417 :3 0 2b :2 0
4c :3 0 225 419
41b :3 0 2b :2 0
53 :4 0 228 41d
41f :3 0 2b :2 0
54 :3 0 55 :3 0
13 :2 0 56 :2 0
22b 422 426 22f
421 428 :3 0 232
40a 42a :2 0 42c
235 42d 407 42c
0 42e 237 0
42f 239 432 :3 0
432 0 432 431
42f 430 :6 0 434
a :3 0 23c 436
23e 435 434 :2 0
437 240 :2 0 439
0 439 438 3e6
437 :6 0 5a6 1
:3 0 9 :3 0 4b
:3 0 43b 43c 0
9 :3 0 57 :2 0
58 :3 0 43e 440
0 245 43f 442
:3 0 443 :2 0 23
:3 0 24 :3 0 445
446 0 23 :3 0
31 :3 0 448 449
0 c :2 0 2
:4 0 7e :2 0 33
:2 0 13 :2 0 248
44e 450 :3 0 24b
44a 452 447 454
453 :2 0 26 :3 0
34 :3 0 456 457
0 28 :4 0 7f
:4 0 2b :2 0 2c
:3 0 24f 45b 45d
:3 0 2b :2 0 3a
:4 0 252 45f 461
:3 0 2b :2 0 3b
:4 0 255 463 465
:3 0 2b :2 0 3c
:3 0 3d :3 0 3e
:3 0 5f :3 0 46a
46b 0 258 469
46d 40 :4 0 25a
468 470 25d 467
472 :3 0 2b :2 0
60 :4 0 260 474
476 :3 0 2b :2 0
2e :4 0 263 478
47a :3 0 2b :2 0
e :3 0 266 47c
47e :3 0 2b :2 0
2e :4 0 269 480
482 :3 0 26c 458
484 :2 0 486 26f
487 455 486 0
488 271 0 4b2
23 :3 0 24 :3 0
489 48a 0 23
:3 0 31 :3 0 48c
48d 0 13 :2 0
2 :4 0 80 :2 0
33 :2 0 13 :2 0
273 492 494 :3 0
276 48e 496 48b
498 497 :2 0 26
:3 0 34 :3 0 49a
49b 0 28 :4 0
81 :4 0 2b :2 0
2c :3 0 27a 49f
4a1 :3 0 27d 49c
4a3 :2 0 4a5 280
4a6 499 4a5 0
4a7 282 0 4b2
43 :3 0 63 :3 0
4a8 4a9 0 3e
:3 0 5f :3 0 4ab
4ac 0 e :3 0
45 :3 0 284 4aa
4b0 :2 0 4b2 288
4b3 444 4b2 0
4b4 28c 0 5a6
69 :3 0 66 :3 0
46 :3 0 6f :3 0
6e :3 0 67 :3 0
e :3 0 d :3 0
11 :3 0 1b :3 0
14 :4 0 82 1
:8 0 4d6 83 :4 0
4c1 :3 0 45 :3 0
57 :2 0 290 4c4
4c5 :3 0 9 :3 0
4b :3 0 4c7 4c8
0 18 :2 0 4c9
4ca 0 4cc 293
4d3 9 :3 0 4b
:3 0 4cd 4ce 0
84 :2 0 4cf 4d0
0 4d2 295 4d4
4c6 4cc 0 4d5
0 4d2 0 4d5
297 0 4d6 29a
529 4d :3 0 9
:3 0 4b :3 0 4d8
4d9 0 4c :3 0
4da 4db 0 4dd
29d 4df 29f 4de
4dd :2 0 527 4e
:3 0 9 :3 0 4b
:3 0 4e2 4e3 0
4c :3 0 4e4 4e5
0 51f 23 :3 0
24 :3 0 4e7 4e8
0 23 :3 0 31
:3 0 4ea 4eb 0
4f :2 0 2 :4 0
85 :2 0 33 :2 0
13 :2 0 2a1 4f0
4f2 :3 0 2a4 4ec
4f4 4e9 4f6 4f5
:2 0 26 :3 0 34
:3 0 4f8 4f9 0
28 :4 0 86 :4 0
2b :2 0 2c :3 0
2a8 4fd 4ff :3 0
2b :2 0 3a :4 0
2ab 501 503 :3 0
2b :2 0 52 :4 0
2ae 505 507 :3 0
2b :2 0 4c :3 0
2b1 509 50b :3 0
2b :2 0 53 :4 0
2b4 50d 50f :3 0
2b :2 0 54 :3 0
55 :3 0 13 :2 0
56 :2 0 2b7 512
516 2bb 511 518
:3 0 2be 4fa 51a
:2 0 51c 2c1 51d
4f7 51c 0 51e
2c3 0 51f 2c5
522 :3 0 522 0
522 521 51f 520
:6 0 524 c :3 0
2c8 526 2ca 525
524 :2 0 527 2cc
:2 0 529 0 529
528 4d6 527 :6 0
5a6 1 :3 0 9
:3 0 4b :3 0 52b
52c 0 9 :3 0
87 :2 0 88 :3 0
52e 530 0 2d1
52f 532 :3 0 533
:2 0 23 :3 0 24
:3 0 535 536 0
23 :3 0 31 :3 0
538 539 0 c
:2 0 2 :4 0 89
:2 0 33 :2 0 13
:2 0 2d4 53e 540
:3 0 2d7 53a 542
537 544 543 :2 0
26 :3 0 34 :3 0
546 547 0 28
:4 0 8a :4 0 2b
:2 0 2c :3 0 2db
54b 54d :3 0 2b
:2 0 3a :4 0 2de
54f 551 :3 0 2b
:2 0 3b :4 0 2e1
553 555 :3 0 2b
:2 0 3c :3 0 3d
:3 0 9 :3 0 4b
:3 0 55a 55b 0
2e4 559 55d 40
:4 0 2e6 558 560
2e9 557 562 :3 0
2b :2 0 60 :4 0
2ec 564 566 :3 0
2b :2 0 2e :4 0
2ef 568 56a :3 0
2b :2 0 5 :3 0
2f2 56c 56e :3 0
2b :2 0 2e :4 0
2f5 570 572 :3 0
2f8 548 574 :2 0
576 2fb 577 545
576 0 578 2fd
0 5a2 23 :3 0
24 :3 0 579 57a
0 23 :3 0 31
:3 0 57c 57d 0
13 :2 0 2 :4 0
8b :2 0 33 :2 0
13 :2 0 2ff 582
584 :3 0 302 57e
586 57b 588 587
:2 0 26 :3 0 34
:3 0 58a 58b 0
28 :4 0 8c :4 0
2b :2 0 2c :3 0
306 58f 591 :3 0
309 58c 593 :2 0
595 30c 596 589
595 0 597 30e
0 5a2 43 :3 0
63 :3 0 598 599
0 9 :3 0 4b
:3 0 59b 59c 0
5 :3 0 45 :3 0
310 59a 5a0 :2 0
5a2 314 5a3 534
5a2 0 5a4 318
0 5a6 8d :3 0
31a 78e 9 :3 0
4b :3 0 5a7 5a8
0 9 :3 0 57
:2 0 88 :3 0 5aa
5ac 0 324 5ab
5ae :3 0 5af :2 0
8e :3 0 3c :3 0
16 :3 0 18 :2 0
327 5b2 5b5 32a
5b1 5b7 87 :2 0
18 :2 0 32e 5b9
5bb :3 0 8f :3 0
90 :3 0 b :3 0
91 :3 0 8f :3 0
8f :3 0 49 :3 0
3 :3 0 8f :3 0
92 :3 0 5 :3 0
8f :3 0 93 :4 0
94 1 :8 0 5d0
9 :3 0 4b :3 0
5cb 5cc 0 4c
:3 0 5cd 5ce 0
5d0 331 623 4d
:3 0 9 :3 0 4b
:3 0 5d2 5d3 0
4c :3 0 5d4 5d5
0 5d7 334 5d9
336 5d8 5d7 :2 0
621 4e :3 0 9
:3 0 4b :3 0 5dc
5dd 0 4c :3 0
5de 5df 0 619
23 :3 0 24 :3 0
5e1 5e2 0 23
:3 0 31 :3 0 5e4
5e5 0 4f :2 0
2 :4 0 95 :2 0
33 :2 0 13 :2 0
338 5ea 5ec :3 0
33b 5e6 5ee 5e3
5f0 5ef :2 0 26
:3 0 34 :3 0 5f2
5f3 0 28 :4 0
96 :4 0 2b :2 0
2c :3 0 33f 5f7
5f9 :3 0 2b :2 0
3a :4 0 342 5fb
5fd :3 0 2b :2 0
52 :4 0 345 5ff
601 :3 0 2b :2 0
4c :3 0 348 603
605 :3 0 2b :2 0
53 :4 0 34b 607
609 :3 0 2b :2 0
54 :3 0 55 :3 0
13 :2 0 56 :2 0
34e 60c 610 352
60b 612 :3 0 355
5f4 614 :2 0 616
358 617 5f1 616
0 618 35a 0
619 35c 61c :3 0
61c 0 61c 61b
619 61a :6 0 61e
e :3 0 35f 620
361 61f 61e :2 0
621 363 :2 0 623
0 623 622 5d0
621 :6 0 69f 1
:3 0 9 :3 0 4b
:3 0 625 626 0
9 :3 0 57 :2 0
88 :3 0 628 62a
0 368 629 62c
:3 0 62d :2 0 23
:3 0 24 :3 0 62f
630 0 23 :3 0
31 :3 0 632 633
0 c :2 0 2
:4 0 97 :2 0 33
:2 0 13 :2 0 36b
638 63a :3 0 36e
634 63c 631 63e
63d :2 0 26 :3 0
34 :3 0 640 641
0 28 :4 0 98
:4 0 2b :2 0 2c
:3 0 372 645 647
:3 0 2b :2 0 3a
:4 0 375 649 64b
:3 0 2b :2 0 3b
:4 0 378 64d 64f
:3 0 2b :2 0 3c
:3 0 3d :3 0 3e
:3 0 99 :3 0 654
655 0 37b 653
657 40 :4 0 37d
652 65a 380 651
65c :3 0 2b :2 0
60 :4 0 383 65e
660 :3 0 2b :2 0
2e :4 0 386 662
664 :3 0 2b :2 0
5 :3 0 389 666
668 :3 0 2b :2 0
2e :4 0 38c 66a
66c :3 0 38f 642
66e :2 0 670 392
671 63f 670 0
672 394 0 69c
23 :3 0 24 :3 0
673 674 0 23
:3 0 31 :3 0 676
677 0 13 :2 0
2 :4 0 9a :2 0
33 :2 0 13 :2 0
396 67c 67e :3 0
399 678 680 675
682 681 :2 0 26
:3 0 34 :3 0 684
685 0 28 :4 0
9b :4 0 2b :2 0
2c :3 0 39d 689
68b :3 0 3a0 686
68d :2 0 68f 3a3
690 683 68f 0
691 3a5 0 69c
43 :3 0 63 :3 0
692 693 0 3e
:3 0 99 :3 0 695
696 0 5 :3 0
45 :3 0 3a7 694
69a :2 0 69c 3ab
69d 62e 69c 0
69e 3af 0 69f
3b1 6a0 5bc 69f
0 6a1 3b4 0
71e 54 :3 0 12
:3 0 13 :2 0 13
:2 0 3b6 6a2 6a6
57 :2 0 9c :4 0
3bc 6a8 6aa :3 0
69 :3 0 68 :3 0
66 :3 0 e :4 0
9d 1 :8 0 6c6
83 :4 0 6b1 :3 0
45 :3 0 57 :2 0
3c1 6b4 6b5 :3 0
9 :3 0 4b :3 0
6b7 6b8 0 18
:2 0 6b9 6ba 0
6bc 3c4 6c3 9
:3 0 4b :3 0 6bd
6be 0 84 :2 0
6bf 6c0 0 6c2
3c6 6c4 6b6 6bc
0 6c5 0 6c2
0 6c5 3c8 0
6c6 3cb 719 4d
:3 0 9 :3 0 4b
:3 0 6c8 6c9 0
4c :3 0 6ca 6cb
0 6cd 3ce 6cf
3d0 6ce 6cd :2 0
717 4e :3 0 9
:3 0 4b :3 0 6d2
6d3 0 4c :3 0
6d4 6d5 0 70f
23 :3 0 24 :3 0
6d7 6d8 0 23
:3 0 31 :3 0 6da
6db 0 4f :2 0
2 :4 0 9e :2 0
33 :2 0 13 :2 0
3d2 6e0 6e2 :3 0
3d5 6dc 6e4 6d9
6e6 6e5 :2 0 26
:3 0 34 :3 0 6e8
6e9 0 28 :4 0
9f :4 0 2b :2 0
2c :3 0 3d9 6ed
6ef :3 0 2b :2 0
3a :4 0 3dc 6f1
6f3 :3 0 2b :2 0
52 :4 0 3df 6f5
6f7 :3 0 2b :2 0
4c :3 0 3e2 6f9
6fb :3 0 2b :2 0
53 :4 0 3e5 6fd
6ff :3 0 2b :2 0
54 :3 0 55 :3 0
13 :2 0 56 :2 0
3e8 702 706 3ec
701 708 :3 0 3ef
6ea 70a :2 0 70c
3f2 70d 6e7 70c
0 70e 3f4 0
70f 3f6 712 :3 0
712 0 712 711
70f 710 :6 0 714
10 :3 0 3f9 716
3fb 715 714 :2 0
717 3fd :2 0 719
0 719 718 6c6
717 :6 0 71b 1
:3 0 400 71c 6ab
71b 0 71d 402
0 71e 404 71f
5b0 71e 0 790
23 :3 0 24 :3 0
720 721 0 23
:3 0 31 :3 0 723
724 0 c :2 0
2 :4 0 a0 :2 0
33 :2 0 13 :2 0
407 729 72b :3 0
40a 725 72d 722
72f 72e :2 0 26
:3 0 34 :3 0 731
732 0 28 :4 0
a1 :4 0 2b :2 0
2c :3 0 40e 736
738 :3 0 2b :2 0
3a :4 0 411 73a
73c :3 0 2b :2 0
3b :4 0 414 73e
740 :3 0 2b :2 0
3c :3 0 3d :3 0
3e :3 0 5f :3 0
745 746 0 417
744 748 40 :4 0
419 743 74b 41c
742 74d :3 0 2b
:2 0 60 :4 0 41f
74f 751 :3 0 2b
:2 0 2e :4 0 422
753 755 :3 0 2b
:2 0 5 :3 0 425
757 759 :3 0 2b
:2 0 2e :4 0 428
75b 75d :3 0 42b
733 75f :2 0 761
42e 762 730 761
0 763 430 0
78d 23 :3 0 24
:3 0 764 765 0
23 :3 0 31 :3 0
767 768 0 13
:2 0 2 :4 0 a2
:2 0 33 :2 0 13
:2 0 432 76d 76f
:3 0 435 769 771
766 773 772 :2 0
26 :3 0 34 :3 0
775 776 0 28
:4 0 a3 :4 0 2b
:2 0 2c :3 0 439
77a 77c :3 0 43c
777 77e :2 0 780
43f 781 774 780
0 782 441 0
78d 43 :3 0 63
:3 0 783 784 0
3e :3 0 5f :3 0
786 787 0 5
:3 0 45 :3 0 443
785 78b :2 0 78d
447 78f 351 5a6
0 790 0 78d
0 790 44b 0
aab 1a :3 0 18
:2 0 791 792 0
aab 90 :3 0 b
:3 0 91 :3 0 49
:3 0 3 :3 0 92
:3 0 e :3 0 93
:4 0 a4 1 :8 0
7a2 9 :3 0 4b
:3 0 79d 79e 0
4c :3 0 79f 7a0
0 7a2 44f 7f5
4d :3 0 9 :3 0
4b :3 0 7a4 7a5
0 4c :3 0 7a6
7a7 0 7a9 452
7ab 454 7aa 7a9
:2 0 7f3 4e :3 0
9 :3 0 4b :3 0
7ae 7af 0 4c
:3 0 7b0 7b1 0
7eb 23 :3 0 24
:3 0 7b3 7b4 0
23 :3 0 31 :3 0
7b6 7b7 0 4f
:2 0 2 :4 0 a5
:2 0 33 :2 0 13
:2 0 456 7bc 7be
:3 0 459 7b8 7c0
7b5 7c2 7c1 :2 0
26 :3 0 34 :3 0
7c4 7c5 0 28
:4 0 a6 :4 0 2b
:2 0 2c :3 0 45d
7c9 7cb :3 0 2b
:2 0 3a :4 0 460
7cd 7cf :3 0 2b
:2 0 52 :4 0 463
7d1 7d3 :3 0 2b
:2 0 4c :3 0 466
7d5 7d7 :3 0 2b
:2 0 53 :4 0 469
7d9 7db :3 0 2b
:2 0 54 :3 0 55
:3 0 13 :2 0 56
:2 0 46c 7de 7e2
470 7dd 7e4 :3 0
473 7c6 7e6 :2 0
7e8 476 7e9 7c3
7e8 0 7ea 478
0 7eb 47a 7ee
:3 0 7ee 0 7ee
7ed 7eb 7ec :6 0
7f0 12 :3 0 47d
7f2 47f 7f1 7f0
:2 0 7f3 481 :2 0
7f5 0 7f5 7f4
7a2 7f3 :6 0 aab
1 :3 0 9 :3 0
4b :3 0 7f7 7f8
0 9 :3 0 57
:2 0 58 :3 0 7fa
7fc 0 486 7fb
7fe :3 0 7ff :2 0
3c :3 0 19 :3 0
18 :2 0 489 801
804 57 :2 0 18
:2 0 48e 806 808
:3 0 48 :3 0 a7
:3 0 a8 :3 0 a7
:3 0 14 :3 0 a7
:3 0 a9 :3 0 14
:3 0 a9 :3 0 a7
:3 0 a7 :3 0 a7
:3 0 14 :3 0 49
:3 0 3 :4 0 aa
1 :8 0 82f 83
:4 0 81a :3 0 45
:3 0 57 :2 0 493
81d 81e :3 0 9
:3 0 4b :3 0 820
821 0 18 :2 0
822 823 0 825
496 82c 9 :3 0
4b :3 0 826 827
0 84 :2 0 828
829 0 82b 498
82d 81f 825 0
82e 0 82b 0
82e 49a 0 82f
49d 882 4d :3 0
9 :3 0 4b :3 0
831 832 0 4c
:3 0 833 834 0
836 4a0 838 4a2
837 836 :2 0 880
4e :3 0 9 :3 0
4b :3 0 83b 83c
0 4c :3 0 83d
83e 0 878 23
:3 0 24 :3 0 840
841 0 23 :3 0
31 :3 0 843 844
0 4f :2 0 2
:4 0 ab :2 0 33
:2 0 13 :2 0 4a4
849 84b :3 0 4a7
845 84d 842 84f
84e :2 0 26 :3 0
34 :3 0 851 852
0 28 :4 0 ac
:4 0 2b :2 0 2c
:3 0 4ab 856 858
:3 0 2b :2 0 3a
:4 0 4ae 85a 85c
:3 0 2b :2 0 52
:4 0 4b1 85e 860
:3 0 2b :2 0 4c
:3 0 4b4 862 864
:3 0 2b :2 0 53
:4 0 4b7 866 868
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 4ba
86b 86f 4be 86a
871 :3 0 4c1 853
873 :2 0 875 4c4
876 850 875 0
877 4c6 0 878
4c8 87b :3 0 87b
0 87b 87a 878
879 :6 0 87d 14
:3 0 4cb 87f 4cd
87e 87d :2 0 880
4cf :2 0 882 0
882 881 82f 880
:6 0 885 1 :3 0
8d :3 0 4d2 90b
3c :3 0 19 :3 0
18 :2 0 4d4 886
889 57 :2 0 13
:2 0 4d9 88b 88d
:3 0 59 :3 0 a7
:3 0 a8 :3 0 a7
:3 0 14 :3 0 a7
:3 0 a9 :3 0 14
:3 0 a9 :3 0 a7
:3 0 a7 :3 0 a7
:3 0 14 :3 0 49
:3 0 3 :4 0 ad
1 :8 0 8b4 83
:4 0 89f :3 0 45
:3 0 57 :2 0 4de
8a2 8a3 :3 0 9
:3 0 4b :3 0 8a5
8a6 0 18 :2 0
8a7 8a8 0 8aa
4e1 8b1 9 :3 0
4b :3 0 8ab 8ac
0 84 :2 0 8ad
8ae 0 8b0 4e3
8b2 8a4 8aa 0
8b3 0 8b0 0
8b3 4e5 0 8b4
4e8 907 4d :3 0
9 :3 0 4b :3 0
8b6 8b7 0 4c
:3 0 8b8 8b9 0
8bb 4eb 8bd 4ed
8bc 8bb :2 0 905
4e :3 0 9 :3 0
4b :3 0 8c0 8c1
0 4c :3 0 8c2
8c3 0 8fd 23
:3 0 24 :3 0 8c5
8c6 0 23 :3 0
31 :3 0 8c8 8c9
0 4f :2 0 2
:4 0 ae :2 0 33
:2 0 13 :2 0 4ef
8ce 8d0 :3 0 4f2
8ca 8d2 8c7 8d4
8d3 :2 0 26 :3 0
34 :3 0 8d6 8d7
0 28 :4 0 af
:4 0 2b :2 0 2c
:3 0 4f6 8db 8dd
:3 0 2b :2 0 3a
:4 0 4f9 8df 8e1
:3 0 2b :2 0 52
:4 0 4fc 8e3 8e5
:3 0 2b :2 0 4c
:3 0 4ff 8e7 8e9
:3 0 2b :2 0 53
:4 0 502 8eb 8ed
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 505
8f0 8f4 509 8ef
8f6 :3 0 50c 8d8
8f8 :2 0 8fa 50f
8fb 8d5 8fa 0
8fc 511 0 8fd
513 900 :3 0 900
0 900 8ff 8fd
8fe :6 0 902 16
:3 0 516 904 518
903 902 :2 0 905
51a :2 0 907 0
907 906 8b4 905
:6 0 909 1 :3 0
51d 90a 88e 909
0 90c 809 885
0 90c 51f 0
9d4 b :3 0 b0
:4 0 90e 90f :3 0
90d 910 0 9d4
20 :3 0 b1 :3 0
3c :3 0 21 :3 0
18 :2 0 522 914
917 3c :3 0 16
:3 0 18 :2 0 525
919 91c 3e :3 0
b2 :3 0 91e 91f
0 1d :3 0 528
913 922 912 923
0 9d4 b3 :3 0
3c :3 0 16 :3 0
18 :2 0 52d 926
929 530 925 92b
87 :2 0 18 :2 0
534 92d 92f :3 0
1c :3 0 3e :3 0
b4 :3 0 932 933
0 931 934 0
936 537 93d 1c
:3 0 3e :3 0 b5
:3 0 938 939 0
937 93a 0 93c
539 93e 930 936
0 93f 0 93c
0 93f 53b 0
9d4 1f :3 0 13
:4 0 940 941 0
9d4 1e :3 0 13
:2 0 943 944 0
9d4 20 :3 0 b6
:3 0 d :3 0 e
:3 0 16 :3 0 1c
:3 0 1d :3 0 1f
:3 0 1e :3 0 53e
947 94f 946 950
0 9d4 91 :3 0
90 :3 0 46 :3 0
49 :3 0 b7 :3 0
93 :3 0 92 :3 0
b8 :3 0 b9 :3 0
ba :3 0 bb :3 0
bc :3 0 b :3 0
d :3 0 3 :3 0
16 :3 0 e :3 0
1c :3 0 1d :3 0
7 :3 0 2c :3 0
21 :4 0 bd 1
:8 0 97e 83 :4 0
969 :3 0 45 :3 0
57 :2 0 548 96c
96d :3 0 9 :3 0
4b :3 0 96f 970
0 18 :2 0 971
972 0 974 54b
97b 9 :3 0 4b
:3 0 975 976 0
84 :2 0 977 978
0 97a 54d 97c
96e 974 0 97d
0 97a 0 97d
54f 0 97e 552
9d1 4d :3 0 9
:3 0 4b :3 0 980
981 0 4c :3 0
982 983 0 985
555 987 557 986
985 :2 0 9cf 4e
:3 0 9 :3 0 4b
:3 0 98a 98b 0
4c :3 0 98c 98d
0 9c7 23 :3 0
24 :3 0 98f 990
0 23 :3 0 31
:3 0 992 993 0
4f :2 0 2 :4 0
be :2 0 33 :2 0
13 :2 0 559 998
99a :3 0 55c 994
99c 991 99e 99d
:2 0 26 :3 0 34
:3 0 9a0 9a1 0
28 :4 0 bf :4 0
2b :2 0 2c :3 0
560 9a5 9a7 :3 0
2b :2 0 3a :4 0
563 9a9 9ab :3 0
2b :2 0 52 :4 0
566 9ad 9af :3 0
2b :2 0 4c :3 0
569 9b1 9b3 :3 0
2b :2 0 53 :4 0
56c 9b5 9b7 :3 0
2b :2 0 54 :3 0
55 :3 0 13 :2 0
56 :2 0 56f 9ba
9be 573 9b9 9c0
:3 0 576 9a2 9c2
:2 0 9c4 579 9c5
99f 9c4 0 9c6
57b 0 9c7 57d
9ca :3 0 9ca 0
9ca 9c9 9c7 9c8
:6 0 9cc 18 :3 0
580 9ce 582 9cd
9cc :2 0 9cf 584
:2 0 9d1 0 9d1
9d0 97e 9cf :6 0
9d4 1 :3 0 8d
:3 0 587 a5b 9
:3 0 4b :3 0 9d5
9d6 0 9 :3 0
57 :2 0 88 :3 0
9d8 9da 0 592
9d9 9dc :3 0 9dd
:2 0 91 :3 0 b8
:3 0 c0 :3 0 c1
:3 0 b8 :3 0 3e
:3 0 b5 :3 0 90
:3 0 b :4 0 c2
1 :8 0 9fe 83
:4 0 9e9 :3 0 45
:3 0 57 :2 0 597
9ec 9ed :3 0 9
:3 0 4b :3 0 9ef
9f0 0 18 :2 0
9f1 9f2 0 9f4
59a 9fb 9 :3 0
4b :3 0 9f5 9f6
0 84 :2 0 9f7
9f8 0 9fa 59c
9fc 9ee 9f4 0
9fd 0 9fa 0
9fd 59e 0 9fe
5a1 a51 4d :3 0
9 :3 0 4b :3 0
a00 a01 0 4c
:3 0 a02 a03 0
a05 5a4 a07 5a6
a06 a05 :2 0 a4f
4e :3 0 9 :3 0
4b :3 0 a0a a0b
0 4c :3 0 a0c
a0d 0 a47 23
:3 0 24 :3 0 a0f
a10 0 23 :3 0
31 :3 0 a12 a13
0 4f :2 0 2
:4 0 c3 :2 0 33
:2 0 13 :2 0 5a8
a18 a1a :3 0 5ab
a14 a1c a11 a1e
a1d :2 0 26 :3 0
34 :3 0 a20 a21
0 28 :4 0 c4
:4 0 2b :2 0 2c
:3 0 5af a25 a27
:3 0 2b :2 0 3a
:4 0 5b2 a29 a2b
:3 0 2b :2 0 52
:4 0 5b5 a2d a2f
:3 0 2b :2 0 4c
:3 0 5b8 a31 a33
:3 0 2b :2 0 53
:4 0 5bb a35 a37
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 5be
a3a a3e 5c2 a39
a40 :3 0 5c5 a22
a42 :2 0 a44 5c8
a45 a1f a44 0
a46 5ca 0 a47
5cc a4a :3 0 a4a
0 a4a a49 a47
a48 :6 0 a4c 1a
:3 0 5cf a4e 5d1
a4d a4c :2 0 a4f
5d3 :2 0 a51 0
a51 a50 9fe a4f
:6 0 a59 1 :3 0
20 :3 0 c5 :3 0
b :3 0 5d6 a54
a56 a53 a57 0
a59 5d8 a5a 9de
a59 0 a5c 800
9d4 0 a5c 5db
0 aab 23 :3 0
24 :3 0 a5d a5e
0 23 :3 0 31
:3 0 a60 a61 0
c6 :2 0 2 :4 0
c7 :2 0 33 :2 0
13 :2 0 5de a66
a68 :3 0 5e1 a62
a6a a5f a6c a6b
:2 0 26 :3 0 34
:3 0 a6e a6f 0
28 :4 0 c8 :4 0
2b :2 0 2c :3 0
5e5 a73 a75 :3 0
2b :2 0 3a :4 0
5e8 a77 a79 :3 0
2b :2 0 3b :4 0
5eb a7b a7d :3 0
2b :2 0 3c :3 0
3d :3 0 9 :3 0
4b :3 0 a82 a83
0 5ee a81 a85
40 :4 0 5f0 a80
a88 5f3 a7f a8a
:3 0 2b :2 0 60
:4 0 5f6 a8c a8e
:3 0 2b :2 0 2e
:4 0 5f9 a90 a92
:3 0 2b :2 0 b
:3 0 5fc a94 a96
:3 0 2b :2 0 2e
:4 0 5ff a98 a9a
:3 0 602 a70 a9c
:2 0 a9e 605 a9f
a6d a9e 0 aa0
607 0 aab 43
:3 0 c9 :3 0 aa1
aa2 0 9 :3 0
4b :3 0 aa4 aa5
0 b :3 0 45
:3 0 609 aa3 aa9
:2 0 aab 60d b4c
9 :3 0 ca :2 0
4 aac aad 0
23 :3 0 24 :3 0
aaf ab0 0 23
:3 0 31 :3 0 ab2
ab3 0 4f :2 0
2 :4 0 cb :2 0
33 :2 0 13 :2 0
61b ab8 aba :3 0
61e ab4 abc ab1
abe abd :2 0 26
:3 0 34 :3 0 ac0
ac1 0 28 :4 0
cc :4 0 2b :2 0
2c :3 0 622 ac5
ac7 :3 0 625 ac2
ac9 :2 0 ae2 26
:3 0 34 :3 0 acb
acc 0 28 :4 0
cd :4 0 2b :2 0
9 :3 0 ce :3 0
ad1 ad2 0 628
ad0 ad4 :3 0 2b
:2 0 60 :4 0 62b
ad6 ad8 :3 0 2b
:2 0 9 :3 0 cf
:3 0 adb adc 0
62e ada ade :3 0
631 acd ae0 :2 0
ae2 634 ae3 abf
ae2 0 ae4 637
0 af4 d0 :3 0
22 :3 0 9 :3 0
ce :3 0 d1 :3 0
9 :3 0 cf :3 0
d2 :3 0 d3 :4 0
d4 1 :a 0 af0
:2 0 af4 ae6 aee
:2 0 8 :3 0 22
:3 0 af2 :2 0 af4
639 af6 63d af5
af4 :2 0 b4a 4e
:3 0 9 :3 0 4b
:3 0 af9 afa 0
4c :3 0 afb afc
0 b42 23 :3 0
24 :3 0 afe aff
0 23 :3 0 31
:3 0 b01 b02 0
4f :2 0 2 :4 0
d5 :2 0 33 :2 0
13 :2 0 63f b07
b09 :3 0 642 b03
b0b b00 b0d b0c
:2 0 26 :3 0 34
:3 0 b0f b10 0
28 :4 0 d6 :4 0
2b :2 0 2c :3 0
646 b14 b16 :3 0
649 b11 b18 :2 0
b32 26 :3 0 34
:3 0 b1a b1b 0
28 :4 0 52 :4 0
2b :2 0 4c :3 0
64c b1f b21 :3 0
2b :2 0 53 :4 0
64f b23 b25 :3 0
2b :2 0 54 :3 0
55 :3 0 13 :2 0
56 :2 0 652 b28
b2c 656 b27 b2e
:3 0 659 b1c b30
:2 0 b32 65c b33
b0e b32 0 b34
65f 0 b42 d0
:3 0 22 :3 0 d1
:3 0 9 :3 0 cf
:3 0 d2 :3 0 d3
:4 0 d7 1 :a 0
b3e :2 0 b42 b36
b3c :2 0 8 :3 0
22 :3 0 b40 :2 0
b42 661 b45 :3 0
b45 0 b45 b44
b42 b43 :6 0 b47
1 :3 0 666 b49
668 b48 b47 :2 0
b4a 66a :2 0 b4c
66d b4c b4b aab
b4a :6 0 b4d :2 0
2 18 b4c b50
:3 0 b4f b4d b51
:8 0 
680
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 31
1 2f 1 38
1 36 1 3f
1 3d 1 46
1 44 1 4b
1 51 1 57
1 5d 1 63
1 6b 1 69
1 70 1 78
1 76 1 7d
1 83 1 89
1 96 1 a2
2 a5 a7 2
aa ac 2 ae
b0 2 b2 b4
2 b6 b8 2
ba bc 2 be
c0 2 c2 c4
2 c6 c8 2
ca cc 2 ce
d0 2 d2 d4
2 d6 d8 2
da dc 2 de
e0 2 e2 e4
2 e6 e8 4
9e a4 a9 ea
1 ec 1 ee
2 f8 fa 3
f6 f7 fc 2
105 107 2 104
109 1 10b 1
10d 1 10f 1
115 1 11d 2
12d 12f 3 12b
12c 131 2 13a
13c 2 13e 140
2 142 144 1
14c 2 14e 14f
2 146 151 2
139 153 1 155
1 157 2 161
163 3 15f 160
165 2 16e 170
2 16d 172 1
174 1 176 2
17d 17e 3 158
177 180 1 182
2 18b 190 1
197 1 192 2
1aa 1ac 3 1a8
1a9 1ae 2 1b7
1b9 2 1bb 1bd
2 1bf 1c1 2
1c3 1c5 2 1c7
1c9 3 1ce 1cf
1d0 2 1cb 1d2
2 1b6 1d4 1
1d6 1 1d8 2
1a1 1d9 1 1dd
1 19c 2 19a
1e1 1 1ec 2
1e8 1ec 2 1f7
1fc 1 203 1
1fe 2 216 218
3 214 215 21a
2 223 225 2
227 229 2 22b
22d 2 22f 231
2 233 235 3
23a 23b 23c 2
237 23e 2 222
240 1 242 1
244 2 20d 245
1 249 1 208
2 206 24d 1
258 2 254 258
2 264 266 3
262 263 268 2
271 273 2 275
277 2 279 27b
1 283 2 285
286 2 27d 288
2 28a 28c 2
28e 290 2 292
294 2 296 298
2 270 29a 1
29c 1 29e 2
2a8 2aa 3 2a6
2a7 2ac 2 2b5
2b7 2 2b4 2b9
1 2bb 1 2bd
3 2c4 2c5 2c6
3 29f 2be 2c8
1 2ca 4 250
2cb 2ce 2d3 2
2d7 2dc 2 2de
2df 2 2ed 2f2
1 2f9 1 2f4
2 30c 30e 3
30a 30b 310 2
319 31b 2 31d
31f 2 321 323
2 325 327 2
329 32b 3 330
331 332 2 32d
334 2 318 336
1 338 1 33a
2 303 33b 1
33f 1 2fe 2
2fc 343 1 34e
2 34a 34e 3
357 358 359 2
366 36b 1 372
1 36d 2 385
387 3 383 384
389 2 392 394
2 396 398 2
39a 39c 2 39e
3a0 2 3a2 3a4
3 3a9 3aa 3ab
2 3a6 3ad 2
391 3af 1 3b1
1 3b3 2 37c
3b4 1 3b8 1
377 2 375 3bc
2 3e0 3e5 1
3ec 1 3e7 2
3ff 401 3 3fd
3fe 403 2 40c
40e 2 410 412
2 414 416 2
418 41a 2 41c
41e 3 423 424
425 2 420 427
2 40b 429 1
42b 1 42d 2
3f6 42e 1 432
1 3f1 2 3ef
436 1 441 2
43d 441 2 44d
44f 3 44b 44c
451 2 45a 45c
2 45e 460 2
462 464 1 46c
2 46e 46f 2
466 471 2 473
475 2 477 479
2 47b 47d 2
47f 481 2 459
483 1 485 1
487 2 491 493
3 48f 490 495
2 49e 4a0 2
49d 4a2 1 4a4
1 4a6 3 4ad
4ae 4af 3 488
4a7 4b1 1 4b3
1 4c3 2 4c2
4c3 1 4cb 1
4d1 2 4d3 4d4
2 4c0 4d5 1
4dc 1 4d7 2
4ef 4f1 3 4ed
4ee 4f3 2 4fc
4fe 2 500 502
2 504 506 2
508 50a 2 50c
50e 3 513 514
515 2 510 517
2 4fb 519 1
51b 1 51d 2
4e6 51e 1 522
1 4e1 2 4df
526 1 531 2
52d 531 2 53d
53f 3 53b 53c
541 2 54a 54c
2 54e 550 2
552 554 1 55c
2 55e 55f 2
556 561 2 563
565 2 567 569
2 56b 56d 2
56f 571 2 549
573 1 575 1
577 2 581 583
3 57f 580 585
2 58e 590 2
58d 592 1 594
1 596 3 59d
59e 59f 3 578
597 5a1 1 5a3
7 354 35c 3bf
439 4b4 529 5a4
1 5ad 2 5a9
5ad 2 5b3 5b4
1 5b6 1 5ba
2 5b8 5ba 2
5ca 5cf 1 5d6
1 5d1 2 5e9
5eb 3 5e7 5e8
5ed 2 5f6 5f8
2 5fa 5fc 2
5fe 600 2 602
604 2 606 608
3 60d 60e 60f
2 60a 611 2
5f5 613 1 615
1 617 2 5e0
618 1 61c 1
5db 2 5d9 620
1 62b 2 627
62b 2 637 639
3 635 636 63b
2 644 646 2
648 64a 2 64c
64e 1 656 2
658 659 2 650
65b 2 65d 65f
2 661 663 2
665 667 2 669
66b 2 643 66d
1 66f 1 671
2 67b 67d 3
679 67a 67f 2
688 68a 2 687
68c 1 68e 1
690 3 697 698
699 3 672 691
69b 1 69d 2
623 69e 1 6a0
3 6a3 6a4 6a5
1 6a9 2 6a7
6a9 1 6b3 2
6b2 6b3 1 6bb
1 6c1 2 6c3
6c4 2 6b0 6c5
1 6cc 1 6c7
2 6df 6e1 3
6dd 6de 6e3 2
6ec 6ee 2 6f0
6f2 2 6f4 6f6
2 6f8 6fa 2
6fc 6fe 3 703
704 705 2 700
707 2 6eb 709
1 70b 1 70d
2 6d6 70e 1
712 1 6d1 2
6cf 716 1 719
1 71c 2 6a1
71d 2 728 72a
3 726 727 72c
2 735 737 2
739 73b 2 73d
73f 1 747 2
749 74a 2 741
74c 2 74e 750
2 752 754 2
756 758 2 75a
75c 2 734 75e
1 760 1 762
2 76c 76e 3
76a 76b 770 2
779 77b 2 778
77d 1 77f 1
781 3 788 789
78a 3 763 782
78c 3 78e 71f
78f 2 79c 7a1
1 7a8 1 7a3
2 7bb 7bd 3
7b9 7ba 7bf 2
7c8 7ca 2 7cc
7ce 2 7d0 7d2
2 7d4 7d6 2
7d8 7da 3 7df
7e0 7e1 2 7dc
7e3 2 7c7 7e5
1 7e7 1 7e9
2 7b2 7ea 1
7ee 1 7ad 2
7ab 7f2 1 7fd
2 7f9 7fd 2
802 803 1 807
2 805 807 1
81c 2 81b 81c
1 824 1 82a
2 82c 82d 2
819 82e 1 835
1 830 2 848
84a 3 846 847
84c 2 855 857
2 859 85b 2
85d 85f 2 861
863 2 865 867
3 86c 86d 86e
2 869 870 2
854 872 1 874
1 876 2 83f
877 1 87b 1
83a 2 838 87f
1 882 2 887
888 1 88c 2
88a 88c 1 8a1
2 8a0 8a1 1
8a9 1 8af 2
8b1 8b2 2 89e
8b3 1 8ba 1
8b5 2 8cd 8cf
3 8cb 8cc 8d1
2 8da 8dc 2
8de 8e0 2 8e2
8e4 2 8e6 8e8
2 8ea 8ec 3
8f1 8f2 8f3 2
8ee 8f5 2 8d9
8f7 1 8f9 1
8fb 2 8c4 8fc
1 900 1 8bf
2 8bd 904 1
907 2 90b 90a
2 915 916 2
91a 91b 4 918
91d 920 921 2
927 928 1 92a
1 92e 2 92c
92e 1 935 1
93b 2 93d 93e
7 948 949 94a
94b 94c 94d 94e
1 96b 2 96a
96b 1 973 1
979 2 97b 97c
2 968 97d 1
984 1 97f 2
997 999 3 995
996 99b 2 9a4
9a6 2 9a8 9aa
2 9ac 9ae 2
9b0 9b2 2 9b4
9b6 3 9bb 9bc
9bd 2 9b8 9bf
2 9a3 9c1 1
9c3 1 9c5 2
98e 9c6 1 9ca
1 989 2 987
9ce 8 90c 911
924 93f 942 945
951 9d1 1 9db
2 9d7 9db 1
9eb 2 9ea 9eb
1 9f3 1 9f9
2 9fb 9fc 2
9e8 9fd 1 a04
1 9ff 2 a17
a19 3 a15 a16
a1b 2 a24 a26
2 a28 a2a 2
a2c a2e 2 a30
a32 2 a34 a36
3 a3b a3c a3d
2 a38 a3f 2
a23 a41 1 a43
1 a45 2 a0e
a46 1 a4a 1
a09 2 a07 a4e
1 a55 2 a51
a58 2 a5b a5a
2 a65 a67 3
a63 a64 a69 2
a72 a74 2 a76
a78 2 a7a a7c
1 a84 2 a86
a87 2 a7e a89
2 a8b a8d 2
a8f a91 2 a93
a95 2 a97 a99
2 a71 a9b 1
a9d 1 a9f 3
aa6 aa7 aa8 d
ef 10e 183 1e4
2e0 2e3 346 790
793 7f5 a5c aa0
aaa 2 ab7 ab9
3 ab5 ab6 abb
2 ac4 ac6 2
ac3 ac8 2 acf
ad3 2 ad5 ad7
2 ad9 add 2
ace adf 2 aca
ae1 1 ae3 3
ae4 aef af3 1
aae 2 b06 b08
3 b04 b05 b0a
2 b13 b15 2
b12 b17 2 b1e
b20 2 b22 b24
3 b29 b2a b2b
2 b26 b2d 2
b1d b2f 2 b19
b31 1 b33 4
afd b34 b3d b41
1 b45 1 af8
2 af6 b49 12
1f 26 2d 34
3b 42 49 4f
55 5b 61 67
6e 74 7b 81
87 8e 
1
4
0 
b50
0
1
28
1c
17
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 0 0 0 0
0 0 0 0 0 0 0 0

f 1 0
63 1 0
51 1 0
69 1 0
7 1 0
36 1 0
76 1 0
7d 1 0
b 1 0
3d 1 0
5d 1 0
2f 1 0
1a 1 0
57 1 0
3 1 0
70 1 0
2 0 1
83 1 0
4b 1 0
28 1 0
21 1 0
44 1 0
89 1 0
0

/
SHOW ERRORS FUNCTION SP_A_TSKPROF;
ALTER FUNCTION SP_A_TSKPROF COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_TSKRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_TSKRES ==
CREATE OR REPLACE FUNCTION SP_A_TSKRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
61
2 :e:
1FUNCTION:
1SP_A_TSKRES:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_PROJECT_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_TSKRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
126:
1+:
1FPUT:
1               ENTER:: SP_A_TSKRES(27) :: cplan.sql(6615) :: :
1IS NULL:
18:
131:
1      RETURN_INVALID:: SP_A_TSKRES(32) :: cplan.sql(6620) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
134:
1                EXIT:: SP_A_TSKRES(35) :: cplan.sql(6623) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_TABLE_WBS:
1TYPE_ID:
1PROJECT_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID, PROJECT_ID INTO h_type_id, h_project_id:n      FROM TMT_WBS W+
1HERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
157:
1           EXCEPTION:: SP_A_TSKRES(58) :: cplan.sql(6646) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1ASSIGNRESOURCE:
1=:
1RECORD_ALREADY_ASSIGNED:
14:
172:
1       RETURN_STATUS:: SP_A_TSKRES(73) :: cplan.sql(6661) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
179:
1           EXCEPTION:: SP_A_TSKRES(80) :: cplan.sql(6668) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
191:
1           EXCEPTION:: SP_A_TSKRES(92) :: cplan.sql(6680) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2bc
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 :2 a0 6b 1c 81 b0 :2 a0
6b :2 a0 6b 6e a5 b a 10
:2 a0 6b 6e :2 a0 6b 6e a5 b
6e 7e a0 b4 2e 6e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
52 10 a0 7e b4 2e :2 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :2 a0 d :2 a0 d :2 a0
d :3 a0 6b d :7 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 b4
2e d :8 a0 a5 b d :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
d b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 51 a5 b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
2bc
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 116 105 109 e4 111 104 132
121 125 101 12d 120 14e 13d 141
11d 149 13c 16e 159 15d 139 161
169 158 175 179 155 17d 181 185
188 18d 18e 1 190 195 199 19d
1a0 1a5 1a9 1ad 1b0 1b5 1b6 1b8
1bd 1c0 1c4 1c5 1ca 1cf 1d2 1d7
1d8 1dd 1e0 1e4 1e5 1ea 1ed 1f2
1f3 1f8 1fb 200 201 206 209 20e
20f 214 217 21b 21c 221 224 229
22a 22f 232 237 238 23d 240 245
246 24b 24e 252 253 258 25b 260
261 266 269 26e 26f 274 275 27a
27c 280 283 287 28b 28e 292 296
299 29c 2a1 2a4 2a7 2aa 2ab 2b0
2b1 1 2b3 2b8 2bc 2c0 2c3 2c8
2cd 2d0 2d4 2d5 2da 2db 2e0 2e2
2e6 2e9 2ed 2f0 2f1 2f6 2f9 2fc
300 303 304 309 30c 1 30f 314
318 31b 31c 321 324 1 327 32c
330 334 337 33b 33f 342 345 34a
34d 350 353 354 359 35a 1 35c
361 365 369 36c 371 376 379 37d
37e 383 386 38b 38c 391 394 399
39a 39f 3a2 3a6 3aa 3ae 3b2 3b5
3b6 3b8 3bd 3be 3c0 3c1 3c6 3c7
3cc 3ce 3d2 3d5 3d9 3dd 3e0 3e4
3e8 3eb 3ee 3f3 3f6 3f9 3fc 3fd
402 403 1 405 40a 40e 412 415
41a 41f 422 426 427 42c 42d 432
434 438 43b 43f 443 446 44a 44e
451 455 456 45b 45d 461 464 468
46c 470 474 478 47c 480 484 488
48c 490 494 497 49b 49f 4a3 4a7
4ab 4af 4b3 4b7 4c3 4c7 4cb 4ce
4d2 4d6 4d8 4dc 4e0 4e4 4e7 4eb
4ef 4f1 4f2 4f7 1 4fb 4ff 503
506 50a 50e 512 516 519 51d 521
524 527 52c 52f 532 535 536 53b
53c 1 53e 543 547 54b 54e 553
558 55b 55f 560 565 568 56d 56e
573 576 57b 57c 581 584 588 589
58e 591 596 597 59c 59f 5a3 5a7
5aa 5ad 5ae 5b0 5b1 5b6 5b7 5bc
5be 5c2 5c5 5c7 5cb 5cd 5d9 5db
5dd 5de 5e3 5e7 5e9 5f5 5f7 5fb
5ff 600 605 609 60d 611 615 619
61d 621 625 629 62a 62c 630 634
638 63b 63c 63e 641 644 645 64a
64e 652 656 659 65d 65f 663 666
66a 66e 671 675 679 67c 67f 684
687 68a 68d 68e 693 694 1 696
69b 69f 6a3 6a6 6ab 6b0 6b3 6b7
6b8 6bd 6c0 6c5 6c6 6cb 6ce 6d3
6d4 6d9 6dc 6e0 6e4 6e8 6e9 6eb
6f0 6f1 6f3 6f4 6f9 6fc 701 702
707 70a 70f 710 715 718 71c 71d
722 725 72a 72b 730 731 736 738
73c 73f 743 747 74a 74e 752 755
756 758 75c 760 761 766 768 76c
770 773 777 77b 77e 782 786 789
78c 791 794 797 79a 79b 7a0 7a1
1 7a3 7a8 7ac 7b0 7b3 7b8 7bd
7c0 7c4 7c5 7ca 7cb 7d0 7d4 7d8
7db 7e0 7e5 7e8 7ec 7f0 7f3 7f4
7f9 7fc 801 802 807 80a 80e 812
815 816 81b 81c 821 823 827 82a
82e 832 836 83a 83e 842 846 84a
84e 85a 85f 863 867 86b 86f 871
872 877 1 87b 87f 883 886 88a
88e 892 896 899 89d 8a1 8a4 8a7
8ac 8af 8b2 8b5 8b6 8bb 8bc 1
8be 8c3 8c7 8cb 8ce 8d3 8d8 8db
8df 8e0 8e5 8e6 8eb 8ef 8f3 8f6
8fb 900 903 907 908 90d 910 915
916 91b 91e 922 926 929 92c 92d
92f 930 935 936 93b 93d 941 944
948 94c 950 954 958 95c 960 96c
971 975 979 97d 981 983 987 989
995 997 999 99a 99f 9a3 9a5 9b1
9b5 9b7 9b8 9c1 
2bc
2
0 1 a 6 9 :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 11 1a 19 :2 11 :2 4
f 18 17 :2 f :2 4 12 1b 1a
:2 12 :2 4 :2 11 20 11 :2 4 :2 e 1d
e :2 4 :2 14 23 14 :2 4 e 17
:3 e 4 7 :2 11 23 :2 2d 3a :2 23
:3 7 :2 d 19 25 :2 2f 43 :2 25 53
59 5c :2 53 6a 7f 8 :2 6a d
10 :2 6a 13 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4d 4e :2 4b :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 51 :2 4
:4 9 8 7 :4 1b 1a 19 :2 7 :4 34
33 32 :2 7 a :2 14 26 :2 30 3c
3f 4e 50 51 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 6e 71 :2 21
75 78 :2 21 82 85 8e 96 :2 9f
:2 8e b0 :2 85 :2 21 :2 a 54 :2 7 a
:2 14 26 :2 30 3c 3f 4e 50 51
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 :2 a 54 :3 7 :2 12 28 :2 31 41
:2 7 4a :3 4 14 :2 4 15 :2 4 12
:2 4 14 :2 1d 4 e 17 27 32
c 1a 27 :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 52 54 55 :2 52 :2 29 :3 d
:2 13 18 24 61 64 :2 24 71 74
:2 24 78 7b :2 24 87 8a :2 24 92
95 :2 24 a1 a4 ab b4 b7 :2 a4
:2 24 :2 d 58 :2 a :2 7 :4 13 :2 7 4
:3 1 4 :3 f :2 4 17 26 34 3f
4d 5c 25 :2 17 4 7 10 21
:2 7 24 26 :2 24 7 1a :2 23 7
28 :2 4 7 :2 11 23 :2 2d 39 3c
4b 4d 4e :2 4b :2 23 :3 7 :2 d 12
1e 5b 5e :2 1e 6b 6e :2 1e 72
75 :2 1e 7f 82 8b 93 :2 8b a5
:2 82 :2 1e ad b0 :2 1e b8 bb :2 1e
c0 c3 :2 1e cb ce :2 1e :2 7 51
:3 4 :2 f 21 2a 3b :2 21 3f 48
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 4f 51 52 :2 4f :2 26
:3 a :2 10 15 21 5e 61 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 55
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 4c 4e 4f :2 4c :2 23
:3 7 :2 d 12 1e 5b 5e :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 52 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
2bc
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :6 d :6 e :6 f
:7 11 :b 13 :11 14 15
:2 14 :2 15 :2 14 :2 15
:2 14 :2 16 :2 14 :2 16
:2 14 :2 16 :2 14 :2 16
:2 14 :2 17 :2 14 :2 17
:2 14 :2 17 :2 14 :2 17
:2 14 :2 17 :4 14 :3 13
:11 1a :b 1b :3 1a :16 1e
:11 1f :20 20 :3 1f :11 22
:b 23 :3 22 :9 25 :3 1e
:3 2a :3 2b :3 2c :5 2d
:4 30 :3 31 30 :5 32
2f 34 :5 35 :3 34
:2 36 :5 38 :11 39 :24 3a
:3 39 :2 37 :6 36 33
:3 12 :5 3f :7 41 42
:3 41 :9 44 :5 45 :3 44
:11 48 :2e 49 :3 48 :c 4b
12 :3 4e :11 4f :b 50
:17 51 :3 4f :2 53 :3 54
:3 55 56 54 53
54 :3 57 :3 4e :2 58
:5 5a :11 5b :b 5c :18 5d
:3 5b :2 5f 60 :3 61
62 60 5f 60
:3 63 :2 59 :6 58 4d
:7 1 
9c3
4
:3 0 1 :3 0 2
:a 0 2b7 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 2b7 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 2b5
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 2b5
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 2b5
0 d :6 0 b
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 2b5
0 e :6 0 12
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 2b5
0 f :6 0 12
:2 0 21 11 :3 0
3a :7 0 3e 3b
3c 2b5 0 10
:6 0 12 :2 0 23
11 :3 0 40 :7 0
44 41 42 2b5
0 13 :6 0 4c
4d 0 25 11
:3 0 46 :7 0 4a
47 48 2b5 0
14 :6 0 52 53
0 27 8 :3 0
9 :2 0 4 4e
:7 0 51 4f 0
2b5 0 15 :6 0
16 :3 0 17 :3 0
16 :3 0 18 :3 0
55 56 0 2
:4 0 29 57 59
54 5b 5a :2 0
19 :3 0 1a :3 0
5d 5e 0 1b
:4 0 16 :3 0 1c
:3 0 61 62 0
2 :4 0 2b 63
65 1d :4 0 1e
:2 0 1f :3 0 2d
68 6a :3 0 20
:4 0 1e :2 0 21
:4 0 30 6d 6f
:3 0 1e :2 0 3
:3 0 33 71 73
:3 0 1e :2 0 21
:4 0 36 75 77
:3 0 1e :2 0 22
:4 0 39 79 7b
:3 0 1e :2 0 21
:4 0 3c 7d 7f
:3 0 1e :2 0 5
:3 0 3f 81 83
:3 0 1e :2 0 21
:4 0 42 85 87
:3 0 1e :2 0 22
:4 0 45 89 8b
:3 0 1e :2 0 21
:4 0 48 8d 8f
:3 0 1e :2 0 6
:3 0 4b 91 93
:3 0 1e :2 0 21
:4 0 4e 95 97
:3 0 1e :2 0 23
:4 0 51 99 9b
:3 0 54 5f 9d
:2 0 9f 59 a0
5c 9f 0 a1
5b 0 215 16
:3 0 17 :3 0 a2
a3 0 16 :3 0
24 :3 0 a5 a6
0 25 :2 0 2
:4 0 26 :2 0 27
:2 0 25 :2 0 5d
ab ad :3 0 60
a7 af a4 b1
b0 :2 0 19 :3 0
28 :3 0 b3 b4
0 1b :4 0 29
:4 0 1e :2 0 1f
:3 0 64 b8 ba
:3 0 67 b5 bc
:2 0 be 6a bf
b2 be 0 c0
6c 0 215 3
:3 0 2a :2 0 6e
c2 c3 :3 0 c4
:2 0 c5 :2 0 5
:3 0 2a :2 0 70
c8 c9 :3 0 ca
:2 0 cb :2 0 c6
cd cc :2 0 6
:3 0 2a :2 0 72
d0 d1 :3 0 d2
:2 0 d3 :2 0 ce
d5 d4 :2 0 16
:3 0 17 :3 0 d7
d8 0 16 :3 0
24 :3 0 da db
0 2b :2 0 2
:4 0 2c :2 0 27
:2 0 25 :2 0 74
e0 e2 :3 0 77
dc e4 d9 e6
e5 :2 0 19 :3 0
28 :3 0 e8 e9
0 1b :4 0 2d
:4 0 1e :2 0 1f
:3 0 7b ed ef
:3 0 1e :2 0 2e
:4 0 7e f1 f3
:3 0 1e :2 0 2f
:4 0 81 f5 f7
:3 0 1e :2 0 30
:3 0 31 :3 0 32
:3 0 33 :3 0 fc
fd 0 84 fb
ff 34 :4 0 86
fa 102 89 f9
104 :3 0 8c ea
106 :2 0 108 8f
109 e7 108 0
10a 91 0 133
16 :3 0 17 :3 0
10b 10c 0 16
:3 0 24 :3 0 10e
10f 0 25 :2 0
2 :4 0 35 :2 0
27 :2 0 25 :2 0
93 114 116 :3 0
96 110 118 10d
11a 119 :2 0 19
:3 0 28 :3 0 11c
11d 0 1b :4 0
36 :4 0 1e :2 0
1f :3 0 9a 121
123 :3 0 9d 11e
125 :2 0 127 a0
128 11b 127 0
129 a2 0 133
37 :3 0 38 :3 0
12a 12b 0 32
:3 0 33 :3 0 12d
12e 0 39 :3 0
a4 12c 131 :2 0
133 a7 134 d6
133 0 135 ab
0 215 a :3 0
3 :3 0 136 137
0 215 f :3 0
5 :3 0 139 13a
0 215 e :3 0
6 :3 0 13c 13d
0 215 10 :3 0
32 :3 0 3a :3 0
140 141 0 13f
142 0 215 3b
:3 0 3c :3 0 13
:3 0 d :3 0 3d
:3 0 3e :3 0 a
:4 0 3f 1 :8 0
151 8 :3 0 40
:3 0 14c 14d 0
41 :3 0 14e 14f
0 151 ad 1a4
42 :3 0 8 :3 0
40 :3 0 153 154
0 41 :3 0 155
156 0 158 b0
15a b2 159 158
:2 0 1a2 43 :3 0
8 :3 0 40 :3 0
15d 15e 0 41
:3 0 15f 160 0
19a 16 :3 0 17
:3 0 162 163 0
16 :3 0 24 :3 0
165 166 0 44
:2 0 2 :4 0 45
:2 0 27 :2 0 25
:2 0 b4 16b 16d
:3 0 b7 167 16f
164 171 170 :2 0
19 :3 0 28 :3 0
173 174 0 1b
:4 0 46 :4 0 1e
:2 0 1f :3 0 bb
178 17a :3 0 1e
:2 0 2e :4 0 be
17c 17e :3 0 1e
:2 0 47 :4 0 c1
180 182 :3 0 1e
:2 0 41 :3 0 c4
184 186 :3 0 1e
:2 0 48 :4 0 c7
188 18a :3 0 1e
:2 0 49 :3 0 4a
:3 0 25 :2 0 4b
:2 0 ca 18d 191
ce 18c 193 :3 0
d1 175 195 :2 0
197 d4 198 172
197 0 199 d6
0 19a d8 19d
:3 0 19d 0 19d
19c 19a 19b :6 0
19f 2 :3 0 db
1a1 dd 1a0 19f
:2 0 1a2 df :2 0
1a4 0 1a4 1a3
151 1a2 :6 0 215
1 :3 0 c :3 0
4c :4 0 1a7 1a8
:3 0 1a6 1a9 0
215 14 :3 0 4d
:3 0 10 :3 0 13
:3 0 a :3 0 f
:3 0 e :3 0 c
:3 0 e2 1ac 1b3
1ab 1b4 0 215
30 :3 0 14 :3 0
12 :2 0 e9 1b6
1b9 4e :2 0 25
:2 0 ee 1bb 1bd
:3 0 14 :3 0 32
:3 0 4f :3 0 1c0
1c1 0 1bf 1c2
0 1c4 f1 1c5
1be 1c4 0 1c6
f3 0 215 16
:3 0 17 :3 0 1c7
1c8 0 16 :3 0
24 :3 0 1ca 1cb
0 50 :2 0 2
:4 0 51 :2 0 27
:2 0 25 :2 0 f5
1d0 1d2 :3 0 f8
1cc 1d4 1c9 1d6
1d5 :2 0 19 :3 0
28 :3 0 1d8 1d9
0 1b :4 0 52
:4 0 1e :2 0 1f
:3 0 fc 1dd 1df
:3 0 1e :2 0 2e
:4 0 ff 1e1 1e3
:3 0 1e :2 0 2f
:4 0 102 1e5 1e7
:3 0 1e :2 0 30
:3 0 31 :3 0 14
:3 0 105 1eb 1ed
34 :4 0 107 1ea
1f0 10a 1e9 1f2
:3 0 1e :2 0 53
:4 0 10d 1f4 1f6
:3 0 1e :2 0 21
:4 0 110 1f8 1fa
:3 0 1e :2 0 c
:3 0 113 1fc 1fe
:3 0 1e :2 0 21
:4 0 116 200 202
:3 0 119 1da 204
:2 0 206 11c 207
1d7 206 0 208
11e 0 215 37
:3 0 54 :3 0 209
20a 0 30 :3 0
14 :3 0 12 :2 0
120 20c 20f c
:3 0 39 :3 0 123
20b 213 :2 0 215
127 2b6 8 :3 0
55 :2 0 4 216
217 0 16 :3 0
17 :3 0 219 21a
0 16 :3 0 24
:3 0 21c 21d 0
44 :2 0 2 :4 0
56 :2 0 27 :2 0
25 :2 0 135 222
224 :3 0 138 21e
226 21b 228 227
:2 0 19 :3 0 28
:3 0 22a 22b 0
1b :4 0 57 :4 0
1e :2 0 1f :3 0
13c 22f 231 :3 0
13f 22c 233 :2 0
24c 19 :3 0 28
:3 0 235 236 0
1b :4 0 58 :4 0
1e :2 0 8 :3 0
59 :3 0 23b 23c
0 142 23a 23e
:3 0 1e :2 0 53
:4 0 145 240 242
:3 0 1e :2 0 8
:3 0 5a :3 0 245
246 0 148 244
248 :3 0 14b 237
24a :2 0 24c 14e
24d 229 24c 0
24e 151 0 25e
5b :3 0 15 :3 0
8 :3 0 59 :3 0
5c :3 0 8 :3 0
5a :3 0 3 :3 0
5d :4 0 5e 1
:a 0 25a :2 0 25e
250 258 :2 0 7
:3 0 15 :3 0 25c
:2 0 25e 153 260
157 25f 25e :2 0
2b4 43 :3 0 8
:3 0 40 :3 0 263
264 0 41 :3 0
265 266 0 2ac
16 :3 0 17 :3 0
268 269 0 16
:3 0 24 :3 0 26b
26c 0 44 :2 0
2 :4 0 5f :2 0
27 :2 0 25 :2 0
159 271 273 :3 0
15c 26d 275 26a
277 276 :2 0 19
:3 0 28 :3 0 279
27a 0 1b :4 0
60 :4 0 1e :2 0
1f :3 0 160 27e
280 :3 0 163 27b
282 :2 0 29c 19
:3 0 28 :3 0 284
285 0 1b :4 0
47 :4 0 1e :2 0
41 :3 0 166 289
28b :3 0 1e :2 0
48 :4 0 169 28d
28f :3 0 1e :2 0
49 :3 0 4a :3 0
25 :2 0 4b :2 0
16c 292 296 170
291 298 :3 0 173
286 29a :2 0 29c
176 29d 278 29c
0 29e 179 0
2ac 5b :3 0 15
:3 0 5c :3 0 8
:3 0 5a :3 0 3
:3 0 5d :4 0 61
1 :a 0 2a8 :2 0
2ac 2a0 2a6 :2 0
7 :3 0 15 :3 0
2aa :2 0 2ac 17b
2af :3 0 2af 0
2af 2ae 2ac 2ad
:6 0 2b1 1 :3 0
180 2b3 182 2b2
2b1 :2 0 2b4 184
:2 0 2b6 187 2b6
2b5 215 2b4 :6 0
2b7 :2 0 2 14
2b6 2ba :3 0 2b9
2b7 2bb :8 0 
191
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
39 1 3f 1
45 1 4b 1
58 1 64 2
67 69 2 6c
6e 2 70 72
2 74 76 2
78 7a 2 7c
7e 2 80 82
2 84 86 2
88 8a 2 8c
8e 2 90 92
2 94 96 2
98 9a 4 60
66 6b 9c 1
9e 1 a0 2
aa ac 3 a8
a9 ae 2 b7
b9 2 b6 bb
1 bd 1 bf
1 c1 1 c7
1 cf 2 df
e1 3 dd de
e3 2 ec ee
2 f0 f2 2
f4 f6 1 fe
2 100 101 2
f8 103 2 eb
105 1 107 1
109 2 113 115
3 111 112 117
2 120 122 2
11f 124 1 126
1 128 2 12f
130 3 10a 129
132 1 134 2
14b 150 1 157
1 152 2 16a
16c 3 168 169
16e 2 177 179
2 17b 17d 2
17f 181 2 183
185 2 187 189
3 18e 18f 190
2 18b 192 2
176 194 1 196
1 198 2 161
199 1 19d 1
15c 2 15a 1a1
6 1ad 1ae 1af
1b0 1b1 1b2 2
1b7 1b8 1 1bc
2 1ba 1bc 1
1c3 1 1c5 2
1cf 1d1 3 1cd
1ce 1d3 2 1dc
1de 2 1e0 1e2
2 1e4 1e6 1
1ec 2 1ee 1ef
2 1e8 1f1 2
1f3 1f5 2 1f7
1f9 2 1fb 1fd
2 1ff 201 2
1db 203 1 205
1 207 2 20d
20e 3 210 211
212 d a1 c0
135 138 13b 13e
143 1a4 1aa 1b5
1c6 208 214 2
221 223 3 21f
220 225 2 22e
230 2 22d 232
2 239 23d 2
23f 241 2 243
247 2 238 249
2 234 24b 1
24d 3 24e 259
25d 1 218 2
270 272 3 26e
26f 274 2 27d
27f 2 27c 281
2 288 28a 2
28c 28e 3 293
294 295 2 290
297 2 287 299
2 283 29b 1
29d 4 267 29e
2a7 2ab 1 2af
1 262 2 260
2b3 9 1b 22
29 30 37 3d
43 49 50 
1
4
0 
2ba
0
1
14
4
d
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
32 1 0
3 1 0
7 1 0
2 0 1
45 1 0
3f 1 0
1d 1 0
39 1 0
24 1 0
2b 1 0
4b 1 0
0

/
SHOW ERRORS FUNCTION SP_A_TSKRES;
ALTER FUNCTION SP_A_TSKRES COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_CRIRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_CRIRES ==
CREATE OR REPLACE FUNCTION SP_A_CRIRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
65
2 :e:
1FUNCTION:
1SP_A_CRIRES:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_CRIRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
125:
1+:
1FPUT:
1               ENTER:: SP_A_CRIRES(26) :: cplan.sql(6730) :: :
1IS NULL:
18:
130:
1      RETURN_INVALID:: SP_A_CRIRES(31) :: cplan.sql(6735) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
133:
1                EXIT:: SP_A_CRIRES(34) :: cplan.sql(6738) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_WBS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
154:
1           EXCEPTION:: SP_A_CRIRES(55) :: cplan.sql(6759) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT TYPE_ID INTO h_type_id FROM TMT_CRI WHERE ELEMENT_ID = h_element_id:
171:
1           EXCEPTION:: SP_A_CRIRES(72) :: cplan.sql(6776) :: :
1SC_TABLE_CRI:
1SC_TABLE_WBS:
1SYS_GUID:
1ASSIGNRESOURCE:
1RECORD_ALREADY_ASSIGNED:
14:
191:
1       RETURN_STATUS:: SP_A_CRIRES(92) :: cplan.sql(6796) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
198:
1           EXCEPTION:: SP_A_CRIRES(99) :: cplan.sql(6803) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1110:
1           EXCEPTION:: SP_A_CRIRES(111) :: cplan.sql(6815) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
327
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a 52 10 a0 7e b4 2e :2 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c :2 a0 d :2 a0 d
:2 a0 d :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
6b d b7 :3 a0 6b d b7 :2 19
3c :2 a0 b4 2e d :8 a0 a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :3 a0 6b d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
327
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
115 104 108 e4 110 103 131 120
124 100 12c 11f 151 13c 140 11c
144 14c 13b 158 15c 138 160 164
168 16b 170 171 1 173 178 17c
180 183 188 18c 190 193 198 199
19b 1a0 1a3 1a7 1a8 1ad 1b2 1b5
1ba 1bb 1c0 1c3 1c7 1c8 1cd 1d0
1d5 1d6 1db 1de 1e3 1e4 1e9 1ec
1f1 1f2 1f7 1fa 1fe 1ff 204 207
20c 20d 212 215 21a 21b 220 223
228 229 22e 231 235 236 23b 23e
243 244 249 24c 251 252 257 258
25d 25f 263 266 26a 26e 271 275
279 27c 27f 284 287 28a 28d 28e
293 294 1 296 29b 29f 2a3 2a6
2ab 2b0 2b3 2b7 2b8 2bd 2be 2c3
2c5 2c9 2cc 2d0 2d3 2d4 2d9 2dc
2df 2e3 2e6 2e7 2ec 2ef 1 2f2
2f7 2fb 2fe 2ff 304 307 1 30a
30f 313 317 31a 31e 322 325 328
32d 330 333 336 337 33c 33d 1
33f 344 348 34c 34f 354 359 35c
360 361 366 369 36e 36f 374 377
37c 37d 382 385 389 38d 391 395
398 399 39b 3a0 3a1 3a3 3a4 3a9
3aa 3af 3b1 3b5 3b8 3bc 3c0 3c3
3c7 3cb 3ce 3d1 3d6 3d9 3dc 3df
3e0 3e5 3e6 1 3e8 3ed 3f1 3f5
3f8 3fd 402 405 409 40a 40f 410
415 417 41b 41e 422 426 429 42d
431 434 438 439 43e 440 444 447
44b 44f 453 457 45b 45f 463 467
46b 46f 473 477 47b 47f 48b 48f
493 496 49a 49e 4a0 4a4 4a8 4ac
4af 4b3 4b7 4b9 4ba 4bf 1 4c3
4c7 4cb 4ce 4d2 4d6 4da 4de 4e1
4e5 4e9 4ec 4ef 4f4 4f7 4fa 4fd
4fe 503 504 1 506 50b 50f 513
516 51b 520 523 527 528 52d 530
535 536 53b 53e 543 544 549 54c
550 551 556 559 55e 55f 564 567
56b 56f 572 575 576 578 579 57e
57f 584 586 58a 58d 58f 593 595
5a1 5a3 5a5 5a6 5ab 5af 5b1 5bd
5bf 5c3 5c7 5ca 5ce 5d1 5d5 5d8
5d9 5de 5e1 5e5 5e9 5ed 5f1 5f5
601 605 609 60c 610 614 616 61a
61e 622 625 629 62d 62f 630 635
1 639 63d 641 644 648 64c 650
654 657 65b 65f 662 665 66a 66d
670 673 674 679 67a 1 67c 681
685 689 68c 691 696 699 69d 69e
6a3 6a6 6ab 6ac 6b1 6b4 6b9 6ba
6bf 6c2 6c6 6c7 6cc 6cf 6d4 6d5
6da 6dd 6e1 6e5 6e8 6eb 6ec 6ee
6ef 6f4 6f5 6fa 6fc 700 703 705
709 70b 717 719 71b 71c 721 725
727 733 735 739 73d 741 744 748
74a 74e 752 756 759 75d 75f 763
767 76a 76e 772 773 778 77c 780
784 788 78c 790 794 798 79c 79d
79f 7a3 7a7 7ab 7ae 7af 7b1 7b4
7b7 7b8 7bd 7c1 7c5 7c9 7cc 7d0
7d2 7d6 7d9 7dd 7e1 7e4 7e8 7ec
7ef 7f2 7f7 7fa 7fd 800 801 806
807 1 809 80e 812 816 819 81e
823 826 82a 82b 830 833 838 839
83e 841 846 847 84c 84f 853 857
85b 85c 85e 863 864 866 867 86c
86f 874 875 87a 87d 882 883 888
88b 88f 890 895 898 89d 89e 8a3
8a4 8a9 8ab 8af 8b2 8b6 8ba 8bd
8c1 8c5 8c8 8c9 8cb 8cf 8d3 8d4
8d9 8db 8df 8e3 8e6 8ea 8ee 8f1
8f5 8f9 8fc 8ff 904 907 90a 90d
90e 913 914 1 916 91b 91f 923
926 92b 930 933 937 938 93d 93e
943 947 94b 94e 953 958 95b 95f
963 966 967 96c 96f 974 975 97a
97d 981 985 988 989 98e 98f 994
996 99a 99d 9a1 9a5 9a9 9ad 9b1
9b5 9b9 9bd 9c1 9cd 9d2 9d6 9da
9de 9e2 9e4 9e5 9ea 1 9ee 9f2
9f6 9f9 9fd a01 a05 a09 a0c a10
a14 a17 a1a a1f a22 a25 a28 a29
a2e a2f 1 a31 a36 a3a a3e a41
a46 a4b a4e a52 a53 a58 a59 a5e
a62 a66 a69 a6e a73 a76 a7a a7b
a80 a83 a88 a89 a8e a91 a95 a99
a9c a9f aa0 aa2 aa3 aa8 aa9 aae
ab0 ab4 ab7 abb abf ac3 ac7 acb
acf ad3 adf ae4 ae8 aec af0 af4
af6 afa afc b08 b0a b0c b0d b12
b16 b18 b24 b28 b2a b2b b34 
327
2
0 1 a 6 9 :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 :2 14 23 14
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 53 59 5c :2 53 6a 7f
8 :2 6a d 10 :2 6a 13 16 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 28 2b :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 2a 2d :2 6a
32 35 :2 6a :2 7 49 :2 4 7 :2 11
23 :2 2d 39 3c 4b 4d 4e :2 4b
:2 23 :3 7 :2 d 12 1e 5b 5e :2 1e
:2 7 51 :2 4 :4 9 8 7 :4 1b 1a
19 :2 7 :4 34 33 32 :2 7 a :2 14
26 :2 30 3c 3f 4e 50 51 :2 4e
:2 26 :3 a :2 10 15 21 5e 61 :2 21
6e 71 :2 21 75 78 :2 21 82 85
8e 96 :2 9f :2 8e b0 :2 85 :2 21 :2 a
54 :2 7 a :2 14 26 :2 30 3c 3f
4e 50 51 :2 4e :2 26 :3 a :2 10 15
21 5e 61 :2 21 :2 a 54 :3 7 :2 12
28 :2 31 41 :2 7 4a :3 4 14 :2 4
15 :2 4 12 4 e 1b 2a 38
45 :2 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
52 54 55 :2 52 :2 29 :3 d :2 13 18
24 61 64 :2 24 71 74 :2 24 78
7b :2 24 87 8a :2 24 92 95 :2 24
a1 a4 ab b4 b7 :2 a4 :2 24 :2 d
58 :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a 7 11 1e
2d 3b 48 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 57 58 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 8a 8d :2 27 95
98 :2 27 a4 a7 ae b7 ba :2 a7
:2 27 :2 10 5b :2 d :2 a :4 16 :2 a 7
:3 35 7 17 :2 20 7 35 7 17
:2 20 7 :5 4 :3 f :2 4 17 26 34
3f 4d 5c 25 :2 17 4 7 10
21 :2 7 24 26 :2 24 7 1a :2 23
7 28 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4d 4e :2 4b :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e 6b 6e :2 1e
72 75 :2 1e 7f 82 8b 93 :2 8b
a5 :2 82 :2 1e ad b0 :2 1e b8 bb
:2 1e c0 c3 :2 1e cb ce :2 1e :2 7
51 :3 4 :2 f 21 2a 3b :2 21 3f
48 :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 4f 51 52 :2 4f
:2 26 :3 a :2 10 15 21 5e 61 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
55 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4c 4f 50 :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 53 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
327
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :6 d :6 e :7 10
:b 12 :11 13 14 :2 13
:2 14 :2 13 :2 14 :2 13
:2 15 :2 13 :2 15 :2 13
:2 15 :2 13 :2 15 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :4 13 :3 12 :11 19
:b 1a :3 19 :16 1d :11 1e
:20 1f :3 1e :11 21 :b 22
:3 21 :9 24 :3 1d :3 29
:3 2a :3 2b :6 2e :5 2f
2d 31 :5 32 :3 31
:2 33 :5 35 :11 36 :24 37
:3 36 :2 34 :6 33 30
:3 11 :a 3d :6 3f :5 40
3e 42 :5 43 :3 42
:2 44 :5 46 :11 47 :24 48
:3 47 :2 45 :6 44 41
:3 3d :5 4d 3d :5 4f
4e :3 3d :5 52 :7 54
55 :3 54 :9 57 :5 58
:3 57 :11 5b :2e 5c :3 5b
:c 5e 11 :3 61 :11 62
:b 63 :17 64 :3 62 :2 66
:3 67 :3 68 69 67
66 67 :3 6a :3 61
:2 6b :5 6d :11 6e :b 6f
:18 70 :3 6e :2 72 73
:3 74 75 73 72
73 :3 76 :2 6c :6 6b
60 :7 1 
b36
4
:3 0 1 :3 0 2
:a 0 322 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 322 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 320
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 320
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 320
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 320
0 e :6 0 11
:2 0 1d 10 :3 0
33 :7 0 37 34
35 320 0 f
:6 0 11 :2 0 1f
10 :3 0 39 :7 0
3d 3a 3b 320
0 12 :6 0 45
46 0 21 10
:3 0 3f :7 0 43
40 41 320 0
13 :6 0 4b 4c
0 23 8 :3 0
9 :2 0 4 47
:7 0 4a 48 0
320 0 14 :6 0
15 :3 0 16 :3 0
15 :3 0 17 :3 0
4e 4f 0 2
:4 0 25 50 52
4d 54 53 :2 0
18 :3 0 19 :3 0
56 57 0 1a
:4 0 15 :3 0 1b
:3 0 5a 5b 0
2 :4 0 27 5c
5e 1c :4 0 1d
:2 0 1e :3 0 29
61 63 :3 0 1f
:4 0 1d :2 0 20
:4 0 2c 66 68
:3 0 1d :2 0 3
:3 0 2f 6a 6c
:3 0 1d :2 0 20
:4 0 32 6e 70
:3 0 1d :2 0 21
:4 0 35 72 74
:3 0 1d :2 0 20
:4 0 38 76 78
:3 0 1d :2 0 5
:3 0 3b 7a 7c
:3 0 1d :2 0 20
:4 0 3e 7e 80
:3 0 1d :2 0 21
:4 0 41 82 84
:3 0 1d :2 0 20
:4 0 44 86 88
:3 0 1d :2 0 6
:3 0 47 8a 8c
:3 0 1d :2 0 20
:4 0 4a 8e 90
:3 0 1d :2 0 22
:4 0 4d 92 94
:3 0 50 58 96
:2 0 98 55 99
55 98 0 9a
57 0 280 15
:3 0 16 :3 0 9b
9c 0 15 :3 0
23 :3 0 9e 9f
0 24 :2 0 2
:4 0 25 :2 0 26
:2 0 24 :2 0 59
a4 a6 :3 0 5c
a0 a8 9d aa
a9 :2 0 18 :3 0
27 :3 0 ac ad
0 1a :4 0 28
:4 0 1d :2 0 1e
:3 0 60 b1 b3
:3 0 63 ae b5
:2 0 b7 66 b8
ab b7 0 b9
68 0 280 3
:3 0 29 :2 0 6a
bb bc :3 0 bd
:2 0 be :2 0 5
:3 0 29 :2 0 6c
c1 c2 :3 0 c3
:2 0 c4 :2 0 bf
c6 c5 :2 0 6
:3 0 29 :2 0 6e
c9 ca :3 0 cb
:2 0 cc :2 0 c7
ce cd :2 0 15
:3 0 16 :3 0 d0
d1 0 15 :3 0
23 :3 0 d3 d4
0 2a :2 0 2
:4 0 2b :2 0 26
:2 0 24 :2 0 70
d9 db :3 0 73
d5 dd d2 df
de :2 0 18 :3 0
27 :3 0 e1 e2
0 1a :4 0 2c
:4 0 1d :2 0 1e
:3 0 77 e6 e8
:3 0 1d :2 0 2d
:4 0 7a ea ec
:3 0 1d :2 0 2e
:4 0 7d ee f0
:3 0 1d :2 0 2f
:3 0 30 :3 0 31
:3 0 32 :3 0 f5
f6 0 80 f4
f8 33 :4 0 82
f3 fb 85 f2
fd :3 0 88 e3
ff :2 0 101 8b
102 e0 101 0
103 8d 0 12c
15 :3 0 16 :3 0
104 105 0 15
:3 0 23 :3 0 107
108 0 24 :2 0
2 :4 0 34 :2 0
26 :2 0 24 :2 0
8f 10d 10f :3 0
92 109 111 106
113 112 :2 0 18
:3 0 27 :3 0 115
116 0 1a :4 0
35 :4 0 1d :2 0
1e :3 0 96 11a
11c :3 0 99 117
11e :2 0 120 9c
121 114 120 0
122 9e 0 12c
36 :3 0 37 :3 0
123 124 0 31
:3 0 32 :3 0 126
127 0 38 :3 0
a0 125 12a :2 0
12c a3 12d cf
12c 0 12e a7
0 280 a :3 0
3 :3 0 12f 130
0 280 e :3 0
5 :3 0 132 133
0 280 d :3 0
6 :3 0 135 136
0 280 39 :3 0
12 :3 0 3a :3 0
3b :3 0 a :4 0
3c 1 :8 0 143
8 :3 0 3d :3 0
13e 13f 0 3e
:3 0 140 141 0
143 a9 196 3f
:3 0 8 :3 0 3d
:3 0 145 146 0
3e :3 0 147 148
0 14a ac 14c
ae 14b 14a :2 0
194 40 :3 0 8
:3 0 3d :3 0 14f
150 0 3e :3 0
151 152 0 18c
15 :3 0 16 :3 0
154 155 0 15
:3 0 23 :3 0 157
158 0 41 :2 0
2 :4 0 42 :2 0
26 :2 0 24 :2 0
b0 15d 15f :3 0
b3 159 161 156
163 162 :2 0 18
:3 0 27 :3 0 165
166 0 1a :4 0
43 :4 0 1d :2 0
1e :3 0 b7 16a
16c :3 0 1d :2 0
2d :4 0 ba 16e
170 :3 0 1d :2 0
44 :4 0 bd 172
174 :3 0 1d :2 0
3e :3 0 c0 176
178 :3 0 1d :2 0
45 :4 0 c3 17a
17c :3 0 1d :2 0
46 :3 0 47 :3 0
24 :2 0 48 :2 0
c6 17f 183 ca
17e 185 :3 0 cd
167 187 :2 0 189
d0 18a 164 189
0 18b d2 0
18c d4 18f :3 0
18f 0 18f 18e
18c 18d :6 0 191
2 :3 0 d7 193
d9 192 191 :2 0
194 db :2 0 196
0 196 195 143
194 :6 0 280 1
:3 0 8 :3 0 3d
:3 0 198 199 0
8 :3 0 49 :2 0
4a :3 0 19b 19d
0 e0 19c 19f
:3 0 1a0 :2 0 39
:3 0 12 :3 0 4b
:3 0 3b :3 0 a
:4 0 4c 1 :8 0
1ad 8 :3 0 3d
:3 0 1a8 1a9 0
3e :3 0 1aa 1ab
0 1ad e3 200
3f :3 0 8 :3 0
3d :3 0 1af 1b0
0 3e :3 0 1b1
1b2 0 1b4 e6
1b6 e8 1b5 1b4
:2 0 1fe 40 :3 0
8 :3 0 3d :3 0
1b9 1ba 0 3e
:3 0 1bb 1bc 0
1f6 15 :3 0 16
:3 0 1be 1bf 0
15 :3 0 23 :3 0
1c1 1c2 0 41
:2 0 2 :4 0 4d
:2 0 26 :2 0 24
:2 0 ea 1c7 1c9
:3 0 ed 1c3 1cb
1c0 1cd 1cc :2 0
18 :3 0 27 :3 0
1cf 1d0 0 1a
:4 0 4e :4 0 1d
:2 0 1e :3 0 f1
1d4 1d6 :3 0 1d
:2 0 2d :4 0 f4
1d8 1da :3 0 1d
:2 0 44 :4 0 f7
1dc 1de :3 0 1d
:2 0 3e :3 0 fa
1e0 1e2 :3 0 1d
:2 0 45 :4 0 fd
1e4 1e6 :3 0 1d
:2 0 46 :3 0 47
:3 0 24 :2 0 48
:2 0 100 1e9 1ed
104 1e8 1ef :3 0
107 1d1 1f1 :2 0
1f3 10a 1f4 1ce
1f3 0 1f5 10c
0 1f6 10e 1f9
:3 0 1f9 0 1f9
1f8 1f6 1f7 :6 0
1fb 4 :3 0 111
1fd 113 1fc 1fb
:2 0 1fe 115 :2 0
200 0 200 1ff
1ad 1fe :6 0 207
1 :3 0 f :3 0
31 :3 0 4f :3 0
203 204 0 202
205 0 207 118
20e f :3 0 31
:3 0 50 :3 0 209
20a 0 208 20b
0 20d 11b 20f
1a1 207 0 210
0 20d 0 210
11d 0 280 c
:3 0 51 :4 0 212
213 :3 0 211 214
0 280 13 :3 0
52 :3 0 f :3 0
12 :3 0 a :3 0
e :3 0 d :3 0
c :3 0 120 217
21e 216 21f 0
280 2f :3 0 13
:3 0 11 :2 0 127
221 224 49 :2 0
24 :2 0 12c 226
228 :3 0 13 :3 0
31 :3 0 53 :3 0
22b 22c 0 22a
22d 0 22f 12f
230 229 22f 0
231 131 0 280
15 :3 0 16 :3 0
232 233 0 15
:3 0 23 :3 0 235
236 0 54 :2 0
2 :4 0 55 :2 0
26 :2 0 24 :2 0
133 23b 23d :3 0
136 237 23f 234
241 240 :2 0 18
:3 0 27 :3 0 243
244 0 1a :4 0
56 :4 0 1d :2 0
1e :3 0 13a 248
24a :3 0 1d :2 0
2d :4 0 13d 24c
24e :3 0 1d :2 0
2e :4 0 140 250
252 :3 0 1d :2 0
2f :3 0 30 :3 0
13 :3 0 143 256
258 33 :4 0 145
255 25b 148 254
25d :3 0 1d :2 0
57 :4 0 14b 25f
261 :3 0 1d :2 0
20 :4 0 14e 263
265 :3 0 1d :2 0
c :3 0 151 267
269 :3 0 1d :2 0
20 :4 0 154 26b
26d :3 0 157 245
26f :2 0 271 15a
272 242 271 0
273 15c 0 280
36 :3 0 58 :3 0
274 275 0 2f
:3 0 13 :3 0 11
:2 0 15e 277 27a
c :3 0 38 :3 0
161 276 27e :2 0
280 165 321 8
:3 0 59 :2 0 4
281 282 0 15
:3 0 16 :3 0 284
285 0 15 :3 0
23 :3 0 287 288
0 41 :2 0 2
:4 0 5a :2 0 26
:2 0 24 :2 0 173
28d 28f :3 0 176
289 291 286 293
292 :2 0 18 :3 0
27 :3 0 295 296
0 1a :4 0 5b
:4 0 1d :2 0 1e
:3 0 17a 29a 29c
:3 0 17d 297 29e
:2 0 2b7 18 :3 0
27 :3 0 2a0 2a1
0 1a :4 0 5c
:4 0 1d :2 0 8
:3 0 5d :3 0 2a6
2a7 0 180 2a5
2a9 :3 0 1d :2 0
57 :4 0 183 2ab
2ad :3 0 1d :2 0
8 :3 0 5e :3 0
2b0 2b1 0 186
2af 2b3 :3 0 189
2a2 2b5 :2 0 2b7
18c 2b8 294 2b7
0 2b9 18f 0
2c9 5f :3 0 14
:3 0 8 :3 0 5d
:3 0 60 :3 0 8
:3 0 5e :3 0 3
:3 0 61 :4 0 62
1 :a 0 2c5 :2 0
2c9 2bb 2c3 :2 0
7 :3 0 14 :3 0
2c7 :2 0 2c9 191
2cb 195 2ca 2c9
:2 0 31f 40 :3 0
8 :3 0 3d :3 0
2ce 2cf 0 3e
:3 0 2d0 2d1 0
317 15 :3 0 16
:3 0 2d3 2d4 0
15 :3 0 23 :3 0
2d6 2d7 0 41
:2 0 2 :4 0 63
:2 0 26 :2 0 24
:2 0 197 2dc 2de
:3 0 19a 2d8 2e0
2d5 2e2 2e1 :2 0
18 :3 0 27 :3 0
2e4 2e5 0 1a
:4 0 64 :4 0 1d
:2 0 1e :3 0 19e
2e9 2eb :3 0 1a1
2e6 2ed :2 0 307
18 :3 0 27 :3 0
2ef 2f0 0 1a
:4 0 44 :4 0 1d
:2 0 3e :3 0 1a4
2f4 2f6 :3 0 1d
:2 0 45 :4 0 1a7
2f8 2fa :3 0 1d
:2 0 46 :3 0 47
:3 0 24 :2 0 48
:2 0 1aa 2fd 301
1ae 2fc 303 :3 0
1b1 2f1 305 :2 0
307 1b4 308 2e3
307 0 309 1b7
0 317 5f :3 0
14 :3 0 60 :3 0
8 :3 0 5e :3 0
3 :3 0 61 :4 0
65 1 :a 0 313
:2 0 317 30b 311
:2 0 7 :3 0 14
:3 0 315 :2 0 317
1b9 31a :3 0 31a
0 31a 319 317
318 :6 0 31c 1
:3 0 1be 31e 1c0
31d 31c :2 0 31f
1c2 :2 0 321 1c5
321 320 280 31f
:6 0 322 :2 0 2
14 321 325 :3 0
324 322 326 :8 0

1ce
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
3e 1 44 1
51 1 5d 2
60 62 2 65
67 2 69 6b
2 6d 6f 2
71 73 2 75
77 2 79 7b
2 7d 7f 2
81 83 2 85
87 2 89 8b
2 8d 8f 2
91 93 4 59
5f 64 95 1
97 1 99 2
a3 a5 3 a1
a2 a7 2 b0
b2 2 af b4
1 b6 1 b8
1 ba 1 c0
1 c8 2 d8
da 3 d6 d7
dc 2 e5 e7
2 e9 eb 2
ed ef 1 f7
2 f9 fa 2
f1 fc 2 e4
fe 1 100 1
102 2 10c 10e
3 10a 10b 110
2 119 11b 2
118 11d 1 11f
1 121 2 128
129 3 103 122
12b 1 12d 2
13d 142 1 149
1 144 2 15c
15e 3 15a 15b
160 2 169 16b
2 16d 16f 2
171 173 2 175
177 2 179 17b
3 180 181 182
2 17d 184 2
168 186 1 188
1 18a 2 153
18b 1 18f 1
14e 2 14c 193
1 19e 2 19a
19e 2 1a7 1ac
1 1b3 1 1ae
2 1c6 1c8 3
1c4 1c5 1ca 2
1d3 1d5 2 1d7
1d9 2 1db 1dd
2 1df 1e1 2
1e3 1e5 3 1ea
1eb 1ec 2 1e7
1ee 2 1d2 1f0
1 1f2 1 1f4
2 1bd 1f5 1
1f9 1 1b8 2
1b6 1fd 2 200
206 1 20c 2
20e 20f 6 218
219 21a 21b 21c
21d 2 222 223
1 227 2 225
227 1 22e 1
230 2 23a 23c
3 238 239 23e
2 247 249 2
24b 24d 2 24f
251 1 257 2
259 25a 2 253
25c 2 25e 260
2 262 264 2
266 268 2 26a
26c 2 246 26e
1 270 1 272
2 278 279 3
27b 27c 27d d
9a b9 12e 131
134 137 196 210
215 220 231 273
27f 2 28c 28e
3 28a 28b 290
2 299 29b 2
298 29d 2 2a4
2a8 2 2aa 2ac
2 2ae 2b2 2
2a3 2b4 2 29f
2b6 1 2b8 3
2b9 2c4 2c8 1
283 2 2db 2dd
3 2d9 2da 2df
2 2e8 2ea 2
2e7 2ec 2 2f3
2f5 2 2f7 2f9
3 2fe 2ff 300
2 2fb 302 2
2f2 304 2 2ee
306 1 308 4
2d2 309 312 316
1 31a 1 2cd
2 2cb 31e 8
1b 22 29 30
36 3c 42 49

1
4
0 
325
0
1
14
6
c
0 1 2 1 4 1 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
3 1 0
7 1 0
3e 1 0
38 1 0
2 0 1
1d 1 0
32 1 0
24 1 0
44 1 0
0

/
SHOW ERRORS FUNCTION SP_A_CRIRES;
ALTER FUNCTION SP_A_CRIRES COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_REQRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_REQRES ==
CREATE OR REPLACE FUNCTION SP_A_REQRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
59
2 :e:
1FUNCTION:
1SP_A_REQRES:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TYPE_ID:
1PLS_INTEGER:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_REQRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
123:
1+:
1FPUT:
1               ENTER:: SP_A_REQRES(24) :: cplan.sql(6865) :: :
1IS NULL:
18:
128:
1      RETURN_INVALID:: SP_A_REQRES(29) :: cplan.sql(6870) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
131:
1                EXIT:: SP_A_REQRES(32) :: cplan.sql(6873) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_WBS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
152:
1           EXCEPTION:: SP_A_REQRES(53) :: cplan.sql(6894) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
14:
164:
1       RETURN_STATUS:: SP_A_REQRES(65) :: cplan.sql(6906) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
171:
1           EXCEPTION:: SP_A_REQRES(72) :: cplan.sql(6913) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
183:
1           EXCEPTION:: SP_A_REQRES(84) :: cplan.sql(6925) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
284
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c a0 7e b4 2e 5a
a0 7e b4 2e 5a 52 10 a0
7e b4 2e :2 5a 52 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 b4 2e d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
284
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
119 104 108 e4 10c 114 103 120
124 100 128 12c 130 133 138 139
1 13b 140 144 148 14b 150 154
158 15b 160 161 163 168 16b 16f
170 175 17a 17d 182 183 188 18b
18f 190 195 198 19d 19e 1a3 1a6
1ab 1ac 1b1 1b4 1b9 1ba 1bf 1c2
1c6 1c7 1cc 1cf 1d4 1d5 1da 1dd
1e2 1e3 1e8 1eb 1f0 1f1 1f6 1f9
1fd 1fe 203 206 20b 20c 211 214
219 21a 21f 220 225 227 22b 22e
232 236 239 23d 241 244 247 24c
24f 252 255 256 25b 25c 1 25e
263 267 26b 26e 273 278 27b 27f
280 285 286 28b 28d 291 294 298
29b 29c 2a1 2a4 2a8 2ab 2ac 2b1
1 2b4 2b9 2bd 2c0 2c1 2c6 2c9
1 2cc 2d1 2d5 2d9 2dc 2e0 2e4
2e7 2ea 2ef 2f2 2f5 2f8 2f9 2fe
2ff 1 301 306 30a 30e 311 316
31b 31e 322 323 328 32b 330 331
336 339 33e 33f 344 347 34b 34f
353 357 35a 35b 35d 362 363 365
366 36b 36c 371 373 377 37a 37e
382 385 389 38d 390 393 398 39b
39e 3a1 3a2 3a7 3a8 1 3aa 3af
3b3 3b7 3ba 3bf 3c4 3c7 3cb 3cc
3d1 3d2 3d7 3d9 3dd 3e0 3e4 3e8
3eb 3ef 3f3 3f6 3fa 3fb 400 402
406 409 40d 411 415 419 41d 421
425 429 42d 431 435 439 43d 441
44d 451 455 458 45c 460 462 466
46a 46e 471 475 479 47b 47c 481
1 485 489 48d 490 494 498 49c
4a0 4a3 4a7 4ab 4ae 4b1 4b6 4b9
4bc 4bf 4c0 4c5 4c6 1 4c8 4cd
4d1 4d5 4d8 4dd 4e2 4e5 4e9 4ea
4ef 4f2 4f7 4f8 4fd 500 505 506
50b 50e 512 513 518 51b 520 521
526 529 52d 531 534 537 538 53a
53b 540 541 546 548 54c 54f 551
555 557 563 565 567 568 56d 571
573 57f 581 585 589 58a 58f 593
597 59b 59e 5a2 5a6 5a9 5ac 5b1
5b4 5b7 5ba 5bb 5c0 5c1 1 5c3
5c8 5cc 5d0 5d3 5d8 5dd 5e0 5e4
5e5 5ea 5ed 5f2 5f3 5f8 5fb 600
601 606 609 60d 611 615 619 61c
61d 61f 624 625 627 628 62d 630
635 636 63b 63e 643 644 649 64c
650 651 656 659 65e 65f 664 665
66a 66c 670 673 677 67b 67e 682
686 689 68d 691 692 697 699 69d
6a1 6a4 6a8 6ac 6af 6b3 6b7 6ba
6bd 6c2 6c5 6c8 6cb 6cc 6d1 6d2
1 6d4 6d9 6dd 6e1 6e4 6e9 6ee
6f1 6f5 6f6 6fb 6fc 701 705 709
70c 711 716 719 71d 721 724 725
72a 72d 732 733 738 73b 73f 743
746 747 74c 74d 752 754 758 75b
75f 763 767 76b 76f 773 777 77b
77f 78b 790 794 798 79c 7a0 7a2
7a3 7a8 1 7ac 7b0 7b4 7b7 7bb
7bf 7c3 7c7 7ca 7ce 7d2 7d5 7d8
7dd 7e0 7e3 7e6 7e7 7ec 7ed 1
7ef 7f4 7f8 7fc 7ff 804 809 80c
810 811 816 817 81c 820 824 827
82c 831 834 838 839 83e 841 846
847 84c 84f 853 857 85a 85d 85e
860 861 866 867 86c 86e 872 875
879 87d 881 885 889 88d 891 89d
8a2 8a6 8aa 8ae 8b2 8b4 8b8 8ba
8c6 8c8 8ca 8cb 8d0 8d4 8d6 8e2
8e6 8e8 8e9 8f2 
284
2
0 1 a 6 9 :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 e 1d e
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 53 59 5c :2 53 6a 7f
8 :2 6a d 10 :2 6a 13 16 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 28 2b :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 2a 2d :2 6a
32 35 :2 6a :2 7 49 :2 4 7 :2 11
23 :2 2d 39 3c 4b 4d 4e :2 4b
:2 23 :3 7 :2 d 12 1e 5b 5e :2 1e
:2 7 51 :2 4 :4 8 7 :4 18 17 :2 7
:4 30 2f 2e :2 7 a :2 14 26 :2 30
3c 3f 4e 50 51 :2 4e :2 26 :3 a
:2 10 15 21 5e 61 :2 21 6e 71
:2 21 75 78 :2 21 82 85 8e 96
:2 9f :2 8e b0 :2 85 :2 21 :2 a 54 :2 7
a :2 14 26 :2 30 3c 3f 4e 50
51 :2 4e :2 26 :3 a :2 10 15 21 5e
61 :2 21 :2 a 54 :3 7 :2 12 28 :2 31
41 :2 7 46 :3 4 14 :2 4 15 :2 4
12 4 e 1b 2a 38 45 :2 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 52 54
55 :2 52 :2 29 :3 d :2 13 18 24 61
64 :2 24 71 74 :2 24 78 7b :2 24
87 8a :2 24 92 95 :2 24 a1 a4
ab b4 b7 :2 a4 :2 24 :2 d 58 :2 a
:2 7 :4 13 :2 7 4 :3 1 4 :3 f 4
7 :2 11 23 :2 2d 39 3c 4b 4d
4e :2 4b :2 23 :3 7 :2 d 12 1e 5b
5e :2 1e 6b 6e :2 1e 72 75 :2 1e
7f 82 8b 93 :2 9c :2 8b a7 :2 82
:2 1e af b2 :2 1e ba bd :2 1e c2
c5 :2 1e cd d0 :2 1e :2 7 51 :3 4
:2 f 21 :2 2a 34 3d :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
4f 51 52 :2 4f :2 26 :3 a :2 10 15
21 5e 61 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 55 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4c 4e 4f :2 4c :2 23 :3 7 :2 d 12
1e 5b 5e :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 52 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
284
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :7 e :b 10 :11 11
12 :2 11 :2 12 :2 11
:2 12 :2 11 :2 13 :2 11
:2 13 :2 11 :2 13 :2 11
:2 13 :2 11 :2 14 :2 11
:2 14 :2 11 :2 14 :2 11
:2 14 :2 11 :2 14 :4 11
:3 10 :11 17 :b 18 :3 17
:14 1b :11 1c :20 1d :3 1c
:11 1f :b 20 :3 1f :9 22
:3 1b :3 27 :3 28 :3 29
:6 2c :5 2d 2b 2f
:5 30 :3 2f :2 31 :5 33
:11 34 :24 35 :3 34 :2 32
:6 31 2e :3 f :5 3c
:11 40 :30 41 :3 40 :a 43
f :3 46 :11 47 :b 48
:17 49 :3 47 :2 4b :3 4c
:3 4d 4e 4c 4b
4c :3 4f :3 46 :2 50
:5 52 :11 53 :b 54 :18 55
:3 53 :2 57 58 :3 59
5a 58 57 58
:3 5b :2 51 :6 50 45
:7 1 
8f4
4
:3 0 1 :3 0 2
:a 0 27f 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 27f 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 27d
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 27d
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 27d
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 27d
0 e :6 0 39
3a 0 1d 10
:3 0 33 :7 0 37
34 35 27d 0
f :6 0 3f 40
0 1f 8 :3 0
9 :2 0 4 3b
:7 0 3e 3c 0
27d 0 12 :6 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
42 43 0 2
:4 0 21 44 46
41 48 47 :2 0
16 :3 0 17 :3 0
4a 4b 0 18
:4 0 13 :3 0 19
:3 0 4e 4f 0
2 :4 0 23 50
52 1a :4 0 1b
:2 0 1c :3 0 25
55 57 :3 0 1d
:4 0 1b :2 0 1e
:4 0 28 5a 5c
:3 0 1b :2 0 3
:3 0 2b 5e 60
:3 0 1b :2 0 1e
:4 0 2e 62 64
:3 0 1b :2 0 1f
:4 0 31 66 68
:3 0 1b :2 0 1e
:4 0 34 6a 6c
:3 0 1b :2 0 5
:3 0 37 6e 70
:3 0 1b :2 0 1e
:4 0 3a 72 74
:3 0 1b :2 0 1f
:4 0 3d 76 78
:3 0 1b :2 0 1e
:4 0 40 7a 7c
:3 0 1b :2 0 6
:3 0 43 7e 80
:3 0 1b :2 0 1e
:4 0 46 82 84
:3 0 1b :2 0 20
:4 0 49 86 88
:3 0 :2 4c 8a :2 0
8c 51 8d 49
8c 0 8e 53
0 1dd 13 :3 0
14 :3 0 8f 90
0 13 :3 0 21
:3 0 92 93 0
22 :2 0 2 :4 0
23 :2 0 24 :2 0
22 :2 0 55 98
9a :3 0 58 94
9c 91 9e 9d
:2 0 16 :3 0 25
:3 0 a0 a1 0
18 :4 0 26 :4 0
1b :2 0 1c :3 0
5c a5 a7 :3 0
5f a2 a9 :2 0
ab 62 ac 9f
ab 0 ad 64
0 1dd 3 :3 0
27 :2 0 66 af
b0 :3 0 b1 :2 0
5 :3 0 27 :2 0
68 b4 b5 :3 0
b6 :2 0 b2 b8
b7 :2 0 6 :3 0
27 :2 0 6a bb
bc :3 0 bd :2 0
be :2 0 b9 c0
bf :2 0 13 :3 0
14 :3 0 c2 c3
0 13 :3 0 21
:3 0 c5 c6 0
28 :2 0 2 :4 0
29 :2 0 24 :2 0
22 :2 0 6c cb
cd :3 0 6f c7
cf c4 d1 d0
:2 0 16 :3 0 25
:3 0 d3 d4 0
18 :4 0 2a :4 0
1b :2 0 1c :3 0
73 d8 da :3 0
1b :2 0 2b :4 0
76 dc de :3 0
1b :2 0 2c :4 0
79 e0 e2 :3 0
1b :2 0 2d :3 0
2e :3 0 2f :3 0
30 :3 0 e7 e8
0 7c e6 ea
31 :4 0 7e e5
ed 81 e4 ef
:3 0 84 d5 f1
:2 0 f3 87 f4
d2 f3 0 f5
89 0 11e 13
:3 0 14 :3 0 f6
f7 0 13 :3 0
21 :3 0 f9 fa
0 22 :2 0 2
:4 0 32 :2 0 24
:2 0 22 :2 0 8b
ff 101 :3 0 8e
fb 103 f8 105
104 :2 0 16 :3 0
25 :3 0 107 108
0 18 :4 0 33
:4 0 1b :2 0 1c
:3 0 92 10c 10e
:3 0 95 109 110
:2 0 112 98 113
106 112 0 114
9a 0 11e 34
:3 0 35 :3 0 115
116 0 2f :3 0
30 :3 0 118 119
0 36 :3 0 9c
117 11c :2 0 11e
9f 11f c1 11e
0 120 a3 0
1dd a :3 0 3
:3 0 121 122 0
1dd e :3 0 5
:3 0 124 125 0
1dd d :3 0 6
:3 0 127 128 0
1dd 37 :3 0 f
:3 0 38 :3 0 39
:3 0 a :4 0 3a
1 :8 0 135 8
:3 0 3b :3 0 130
131 0 3c :3 0
132 133 0 135
a5 188 3d :3 0
8 :3 0 3b :3 0
137 138 0 3c
:3 0 139 13a 0
13c a8 13e aa
13d 13c :2 0 186
3e :3 0 8 :3 0
3b :3 0 141 142
0 3c :3 0 143
144 0 17e 13
:3 0 14 :3 0 146
147 0 13 :3 0
21 :3 0 149 14a
0 3f :2 0 2
:4 0 40 :2 0 24
:2 0 22 :2 0 ac
14f 151 :3 0 af
14b 153 148 155
154 :2 0 16 :3 0
25 :3 0 157 158
0 18 :4 0 41
:4 0 1b :2 0 1c
:3 0 b3 15c 15e
:3 0 1b :2 0 2b
:4 0 b6 160 162
:3 0 1b :2 0 42
:4 0 b9 164 166
:3 0 1b :2 0 3c
:3 0 bc 168 16a
:3 0 1b :2 0 43
:4 0 bf 16c 16e
:3 0 1b :2 0 44
:3 0 45 :3 0 22
:2 0 46 :2 0 c2
171 175 c6 170
177 :3 0 c9 159
179 :2 0 17b cc
17c 156 17b 0
17d ce 0 17e
d0 181 :3 0 181
0 181 180 17e
17f :6 0 183 2
:3 0 d3 185 d5
184 183 :2 0 186
d7 :2 0 188 0
188 187 135 186
:6 0 1dd 1 :3 0
c :3 0 47 :4 0
18b 18c :3 0 18a
18d 0 1dd 13
:3 0 14 :3 0 18f
190 0 13 :3 0
21 :3 0 192 193
0 48 :2 0 2
:4 0 49 :2 0 24
:2 0 22 :2 0 da
198 19a :3 0 dd
194 19c 191 19e
19d :2 0 16 :3 0
25 :3 0 1a0 1a1
0 18 :4 0 4a
:4 0 1b :2 0 1c
:3 0 e1 1a5 1a7
:3 0 1b :2 0 2b
:4 0 e4 1a9 1ab
:3 0 1b :2 0 2c
:4 0 e7 1ad 1af
:3 0 1b :2 0 2d
:3 0 2e :3 0 8
:3 0 3b :3 0 1b4
1b5 0 ea 1b3
1b7 31 :4 0 ec
1b2 1ba ef 1b1
1bc :3 0 1b :2 0
4b :4 0 f2 1be
1c0 :3 0 1b :2 0
1e :4 0 f5 1c2
1c4 :3 0 1b :2 0
c :3 0 f8 1c6
1c8 :3 0 1b :2 0
1e :4 0 fb 1ca
1cc :3 0 fe 1a2
1ce :2 0 1d0 101
1d1 19f 1d0 0
1d2 103 0 1dd
34 :3 0 4c :3 0
1d3 1d4 0 8
:3 0 3b :3 0 1d6
1d7 0 c :3 0
36 :3 0 105 1d5
1db :2 0 1dd 109
27e 8 :3 0 4d
:2 0 4 1de 1df
0 13 :3 0 14
:3 0 1e1 1e2 0
13 :3 0 21 :3 0
1e4 1e5 0 3f
:2 0 2 :4 0 4e
:2 0 24 :2 0 22
:2 0 114 1ea 1ec
:3 0 117 1e6 1ee
1e3 1f0 1ef :2 0
16 :3 0 25 :3 0
1f2 1f3 0 18
:4 0 4f :4 0 1b
:2 0 1c :3 0 11b
1f7 1f9 :3 0 11e
1f4 1fb :2 0 214
16 :3 0 25 :3 0
1fd 1fe 0 18
:4 0 50 :4 0 1b
:2 0 8 :3 0 51
:3 0 203 204 0
121 202 206 :3 0
1b :2 0 4b :4 0
124 208 20a :3 0
1b :2 0 8 :3 0
52 :3 0 20d 20e
0 127 20c 210
:3 0 12a 1ff 212
:2 0 214 12d 215
1f1 214 0 216
130 0 226 53
:3 0 12 :3 0 8
:3 0 51 :3 0 54
:3 0 8 :3 0 52
:3 0 3 :3 0 55
:4 0 56 1 :a 0
222 :2 0 226 218
220 :2 0 7 :3 0
12 :3 0 224 :2 0
226 132 228 136
227 226 :2 0 27c
3e :3 0 8 :3 0
3b :3 0 22b 22c
0 3c :3 0 22d
22e 0 274 13
:3 0 14 :3 0 230
231 0 13 :3 0
21 :3 0 233 234
0 3f :2 0 2
:4 0 57 :2 0 24
:2 0 22 :2 0 138
239 23b :3 0 13b
235 23d 232 23f
23e :2 0 16 :3 0
25 :3 0 241 242
0 18 :4 0 58
:4 0 1b :2 0 1c
:3 0 13f 246 248
:3 0 142 243 24a
:2 0 264 16 :3 0
25 :3 0 24c 24d
0 18 :4 0 42
:4 0 1b :2 0 3c
:3 0 145 251 253
:3 0 1b :2 0 43
:4 0 148 255 257
:3 0 1b :2 0 44
:3 0 45 :3 0 22
:2 0 46 :2 0 14b
25a 25e 14f 259
260 :3 0 152 24e
262 :2 0 264 155
265 240 264 0
266 158 0 274
53 :3 0 12 :3 0
54 :3 0 8 :3 0
52 :3 0 3 :3 0
55 :4 0 59 1
:a 0 270 :2 0 274
268 26e :2 0 7
:3 0 12 :3 0 272
:2 0 274 15a 277
:3 0 277 0 277
276 274 275 :6 0
279 1 :3 0 15f
27b 161 27a 279
:2 0 27c 163 :2 0
27e 166 27e 27d
1dd 27c :6 0 27f
:2 0 2 14 27e
282 :3 0 281 27f
283 :8 0 
16d
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
45 1 51 2
54 56 2 59
5b 2 5d 5f
2 61 63 2
65 67 2 69
6b 2 6d 6f
2 71 73 2
75 77 2 79
7b 2 7d 7f
2 81 83 2
85 87 4 4d
53 58 89 1
8b 1 8d 2
97 99 3 95
96 9b 2 a4
a6 2 a3 a8
1 aa 1 ac
1 ae 1 b3
1 ba 2 ca
cc 3 c8 c9
ce 2 d7 d9
2 db dd 2
df e1 1 e9
2 eb ec 2
e3 ee 2 d6
f0 1 f2 1
f4 2 fe 100
3 fc fd 102
2 10b 10d 2
10a 10f 1 111
1 113 2 11a
11b 3 f5 114
11d 1 11f 2
12f 134 1 13b
1 136 2 14e
150 3 14c 14d
152 2 15b 15d
2 15f 161 2
163 165 2 167
169 2 16b 16d
3 172 173 174
2 16f 176 2
15a 178 1 17a
1 17c 2 145
17d 1 181 1
140 2 13e 185
2 197 199 3
195 196 19b 2
1a4 1a6 2 1a8
1aa 2 1ac 1ae
1 1b6 2 1b8
1b9 2 1b0 1bb
2 1bd 1bf 2
1c1 1c3 2 1c5
1c7 2 1c9 1cb
2 1a3 1cd 1
1cf 1 1d1 3
1d8 1d9 1da a
8e ad 120 123
126 129 188 18e
1d2 1dc 2 1e9
1eb 3 1e7 1e8
1ed 2 1f6 1f8
2 1f5 1fa 2
201 205 2 207
209 2 20b 20f
2 200 211 2
1fc 213 1 215
3 216 221 225
1 1e0 2 238
23a 3 236 237
23c 2 245 247
2 244 249 2
250 252 2 254
256 3 25b 25c
25d 2 258 25f
2 24f 261 2
24b 263 1 265
4 22f 266 26f
273 1 277 1
22a 2 228 27b
6 1b 22 29
30 36 3d 
1
4
0 
282
0
1
14
4
a
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
3 1 0
7 1 0
32 1 0
1d 1 0
24 1 0
2 0 1
38 1 0
0

/
SHOW ERRORS FUNCTION SP_A_REQRES;
ALTER FUNCTION SP_A_REQRES COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_POOLRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_POOLRES ==
CREATE OR REPLACE FUNCTION SP_A_POOLRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
5f
2 :e:
1FUNCTION:
1SP_A_POOLRES:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_POOLRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
125:
1+:
1FPUT:
1               ENTER:: SP_A_POOLRES(26) :: cplan.sql(6975) :: :
1IS NULL:
18:
130:
1      RETURN_INVALID:: SP_A_POOLRES(31) :: cplan.sql(6980) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
133:
1                EXIT:: SP_A_POOLRES(34) :: cplan.sql(6983) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_TABLE_POL:
1TYPE_ID:
1TMT_POOLS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_POOLS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
155:
1           EXCEPTION:: SP_A_POOLRES(56) :: cplan.sql(7005) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1ASSIGNRESOURCE:
1=:
1RECORD_ALREADY_ASSIGNED:
14:
170:
1       RETURN_STATUS:: SP_A_POOLRES(71) :: cplan.sql(7020) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
177:
1           EXCEPTION:: SP_A_POOLRES(78) :: cplan.sql(7027) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
189:
1           EXCEPTION:: SP_A_POOLRES(90) :: cplan.sql(7039) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2b3
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a 52 10 a0 7e b4 2e :2 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c :2 a0 d :2 a0 d
:2 a0 d :3 a0 6b d :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
b4 2e d :8 a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e :3 a0
6b d b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 51 a5 b :2 a0
a5 57 b7 :2 a0 6b :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e a5 57
b7 19 3c :9 a0 12a e9 dd :2 a0
65 b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c :7 a0 12a e9 dd :2 a0 65 b7
a4 b1 11 4f b7 a6 9 a4
b1 11 68 4f 1d 17 b5 
2b3
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
115 104 108 e4 110 103 131 120
124 100 12c 11f 151 13c 140 11c
144 14c 13b 158 15c 138 160 164
168 16b 170 171 1 173 178 17c
180 183 188 18c 190 193 198 199
19b 1a0 1a3 1a7 1a8 1ad 1b2 1b5
1ba 1bb 1c0 1c3 1c7 1c8 1cd 1d0
1d5 1d6 1db 1de 1e3 1e4 1e9 1ec
1f1 1f2 1f7 1fa 1fe 1ff 204 207
20c 20d 212 215 21a 21b 220 223
228 229 22e 231 235 236 23b 23e
243 244 249 24c 251 252 257 258
25d 25f 263 266 26a 26e 271 275
279 27c 27f 284 287 28a 28d 28e
293 294 1 296 29b 29f 2a3 2a6
2ab 2b0 2b3 2b7 2b8 2bd 2be 2c3
2c5 2c9 2cc 2d0 2d3 2d4 2d9 2dc
2df 2e3 2e6 2e7 2ec 2ef 1 2f2
2f7 2fb 2fe 2ff 304 307 1 30a
30f 313 317 31a 31e 322 325 328
32d 330 333 336 337 33c 33d 1
33f 344 348 34c 34f 354 359 35c
360 361 366 369 36e 36f 374 377
37c 37d 382 385 389 38d 391 395
398 399 39b 3a0 3a1 3a3 3a4 3a9
3aa 3af 3b1 3b5 3b8 3bc 3c0 3c3
3c7 3cb 3ce 3d1 3d6 3d9 3dc 3df
3e0 3e5 3e6 1 3e8 3ed 3f1 3f5
3f8 3fd 402 405 409 40a 40f 410
415 417 41b 41e 422 426 429 42d
431 434 438 439 43e 440 444 447
44b 44f 453 457 45b 45f 463 467
46b 46f 473 477 47a 47e 482 486
48a 48e 492 49e 4a2 4a6 4a9 4ad
4b1 4b3 4b7 4bb 4bf 4c2 4c6 4ca
4cc 4cd 4d2 1 4d6 4da 4de 4e1
4e5 4e9 4ed 4f1 4f4 4f8 4fc 4ff
502 507 50a 50d 510 511 516 517
1 519 51e 522 526 529 52e 533
536 53a 53b 540 543 548 549 54e
551 556 557 55c 55f 563 564 569
56c 571 572 577 57a 57e 582 585
588 589 58b 58c 591 592 597 599
59d 5a0 5a2 5a6 5a8 5b4 5b6 5b8
5b9 5be 5c2 5c4 5d0 5d2 5d6 5da
5db 5e0 5e4 5e8 5ec 5f0 5f4 5f8
5fc 600 604 605 607 60b 60f 613
616 617 619 61c 61f 620 625 629
62d 631 634 638 63a 63e 641 645
649 64c 650 654 657 65a 65f 662
665 668 669 66e 66f 1 671 676
67a 67e 681 686 68b 68e 692 693
698 69b 6a0 6a1 6a6 6a9 6ae 6af
6b4 6b7 6bb 6bf 6c3 6c4 6c6 6cb
6cc 6ce 6cf 6d4 6d7 6dc 6dd 6e2
6e5 6ea 6eb 6f0 6f3 6f7 6f8 6fd
700 705 706 70b 70c 711 713 717
71a 71e 722 725 729 72d 730 731
733 737 73b 73c 741 743 747 74b
74e 752 756 759 75d 761 764 767
76c 76f 772 775 776 77b 77c 1
77e 783 787 78b 78e 793 798 79b
79f 7a0 7a5 7a6 7ab 7af 7b3 7b6
7bb 7c0 7c3 7c7 7cb 7ce 7cf 7d4
7d7 7dc 7dd 7e2 7e5 7e9 7ed 7f0
7f1 7f6 7f7 7fc 7fe 802 805 809
80d 811 815 819 81d 821 825 829
835 83a 83e 842 846 84a 84c 84d
852 1 856 85a 85e 861 865 869
86d 871 874 878 87c 87f 882 887
88a 88d 890 891 896 897 1 899
89e 8a2 8a6 8a9 8ae 8b3 8b6 8ba
8bb 8c0 8c1 8c6 8ca 8ce 8d1 8d6
8db 8de 8e2 8e3 8e8 8eb 8f0 8f1
8f6 8f9 8fd 901 904 907 908 90a
90b 910 911 916 918 91c 91f 923
927 92b 92f 933 937 93b 947 94c
950 954 958 95c 95e 962 964 970
972 974 975 97a 97e 980 98c 990
992 993 99c 
2b3
2
0 1 a 6 9 :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 :2 14 23 14
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 54 5a 5d :2 54 6b 81
8 :2 6b d 10 :2 6b 13 16 :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 28 2b :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 2a 2d :2 6b
32 35 :2 6b :2 7 4a :2 4 7 :2 11
23 :2 2d 39 3c 4c 4e 4f :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:2 7 52 :2 4 :4 9 8 7 :4 1b 1a
19 :2 7 :4 34 33 32 :2 7 a :2 14
26 :2 30 3c 3f 4f 51 52 :2 4f
:2 26 :3 a :2 10 15 21 5f 62 :2 21
6f 72 :2 21 76 79 :2 21 83 86
8f 97 :2 a0 :2 8f b1 :2 86 :2 21 :2 a
55 :2 7 a :2 14 26 :2 30 3c 3f
4f 51 52 :2 4f :2 26 :3 a :2 10 15
21 5f 62 :2 21 :2 a 55 :3 7 :2 12
28 :2 31 41 :2 7 4a :3 4 14 :2 4
15 :2 4 12 :2 4 14 :2 1d 4 e
1b 2a 3a 47 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 53 55 56 :2 53 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 88 8b :2 24
93 96 :2 24 a2 a5 ac b5 b8
:2 a5 :2 24 :2 d 59 :2 a :2 7 :4 13 :2 7
4 :3 1 4 :3 f :2 4 17 26 34
3f 4d 5c 25 :2 17 4 7 10
21 :2 7 24 26 :2 24 7 1a :2 23
7 28 :2 4 7 :2 11 23 :2 2d 39
3c 4c 4e 4f :2 4c :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e 6c 6f :2 1e
73 76 :2 1e 80 83 8c 94 :2 8c
a6 :2 83 :2 1e ae b1 :2 1e b9 bc
:2 1e c1 c4 :2 1e cc cf :2 1e :2 7
52 :3 4 :2 f 21 2a 3b :2 21 3f
48 :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 50 52 53 :2 50
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
56 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4d 4f 50 :2 4d
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 53 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
2b3
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :6 d :6 e :7 10
:b 12 :11 13 14 :2 13
:2 14 :2 13 :2 14 :2 13
:2 15 :2 13 :2 15 :2 13
:2 15 :2 13 :2 15 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :4 13 :3 12 :11 19
:b 1a :3 19 :16 1d :11 1e
:20 1f :3 1e :11 21 :b 22
:3 21 :9 24 :3 1d :3 29
:3 2a :3 2b :5 2c :6 2f
:5 30 2e 32 :5 33
:3 32 :2 34 :5 36 :11 37
:24 38 :3 37 :2 35 :6 34
31 :3 11 :5 3d :7 3f
40 :3 3f :9 42 :5 43
:3 42 :11 46 :2e 47 :3 46
:c 49 11 :3 4c :11 4d
:b 4e :17 4f :3 4d :2 51
:3 52 :3 53 54 52
51 52 :3 55 :3 4c
:2 56 :5 58 :11 59 :b 5a
:18 5b :3 59 :2 5d 5e
:3 5f 60 5e 5d
5e :3 61 :2 57 :6 56
4b :7 1 
99e
4
:3 0 1 :3 0 2
:a 0 2ae 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 2ae 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 2ac
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 2ac
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 2ac
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 2ac
0 e :6 0 11
:2 0 1d 10 :3 0
33 :7 0 37 34
35 2ac 0 f
:6 0 11 :2 0 1f
10 :3 0 39 :7 0
3d 3a 3b 2ac
0 12 :6 0 45
46 0 21 10
:3 0 3f :7 0 43
40 41 2ac 0
13 :6 0 4b 4c
0 23 8 :3 0
9 :2 0 4 47
:7 0 4a 48 0
2ac 0 14 :6 0
15 :3 0 16 :3 0
15 :3 0 17 :3 0
4e 4f 0 2
:4 0 25 50 52
4d 54 53 :2 0
18 :3 0 19 :3 0
56 57 0 1a
:4 0 15 :3 0 1b
:3 0 5a 5b 0
2 :4 0 27 5c
5e 1c :4 0 1d
:2 0 1e :3 0 29
61 63 :3 0 1f
:4 0 1d :2 0 20
:4 0 2c 66 68
:3 0 1d :2 0 3
:3 0 2f 6a 6c
:3 0 1d :2 0 20
:4 0 32 6e 70
:3 0 1d :2 0 21
:4 0 35 72 74
:3 0 1d :2 0 20
:4 0 38 76 78
:3 0 1d :2 0 5
:3 0 3b 7a 7c
:3 0 1d :2 0 20
:4 0 3e 7e 80
:3 0 1d :2 0 21
:4 0 41 82 84
:3 0 1d :2 0 20
:4 0 44 86 88
:3 0 1d :2 0 6
:3 0 47 8a 8c
:3 0 1d :2 0 20
:4 0 4a 8e 90
:3 0 1d :2 0 22
:4 0 4d 92 94
:3 0 50 58 96
:2 0 98 55 99
55 98 0 9a
57 0 20c 15
:3 0 16 :3 0 9b
9c 0 15 :3 0
23 :3 0 9e 9f
0 24 :2 0 2
:4 0 25 :2 0 26
:2 0 24 :2 0 59
a4 a6 :3 0 5c
a0 a8 9d aa
a9 :2 0 18 :3 0
27 :3 0 ac ad
0 1a :4 0 28
:4 0 1d :2 0 1e
:3 0 60 b1 b3
:3 0 63 ae b5
:2 0 b7 66 b8
ab b7 0 b9
68 0 20c 3
:3 0 29 :2 0 6a
bb bc :3 0 bd
:2 0 be :2 0 5
:3 0 29 :2 0 6c
c1 c2 :3 0 c3
:2 0 c4 :2 0 bf
c6 c5 :2 0 6
:3 0 29 :2 0 6e
c9 ca :3 0 cb
:2 0 cc :2 0 c7
ce cd :2 0 15
:3 0 16 :3 0 d0
d1 0 15 :3 0
23 :3 0 d3 d4
0 2a :2 0 2
:4 0 2b :2 0 26
:2 0 24 :2 0 70
d9 db :3 0 73
d5 dd d2 df
de :2 0 18 :3 0
27 :3 0 e1 e2
0 1a :4 0 2c
:4 0 1d :2 0 1e
:3 0 77 e6 e8
:3 0 1d :2 0 2d
:4 0 7a ea ec
:3 0 1d :2 0 2e
:4 0 7d ee f0
:3 0 1d :2 0 2f
:3 0 30 :3 0 31
:3 0 32 :3 0 f5
f6 0 80 f4
f8 33 :4 0 82
f3 fb 85 f2
fd :3 0 88 e3
ff :2 0 101 8b
102 e0 101 0
103 8d 0 12c
15 :3 0 16 :3 0
104 105 0 15
:3 0 23 :3 0 107
108 0 24 :2 0
2 :4 0 34 :2 0
26 :2 0 24 :2 0
8f 10d 10f :3 0
92 109 111 106
113 112 :2 0 18
:3 0 27 :3 0 115
116 0 1a :4 0
35 :4 0 1d :2 0
1e :3 0 96 11a
11c :3 0 99 117
11e :2 0 120 9c
121 114 120 0
122 9e 0 12c
36 :3 0 37 :3 0
123 124 0 31
:3 0 32 :3 0 126
127 0 38 :3 0
a0 125 12a :2 0
12c a3 12d cf
12c 0 12e a7
0 20c a :3 0
3 :3 0 12f 130
0 20c e :3 0
5 :3 0 132 133
0 20c d :3 0
6 :3 0 135 136
0 20c f :3 0
31 :3 0 39 :3 0
139 13a 0 138
13b 0 20c 3a
:3 0 12 :3 0 3b
:3 0 3c :3 0 a
:4 0 3d 1 :8 0
148 8 :3 0 3e
:3 0 143 144 0
3f :3 0 145 146
0 148 a9 19b
40 :3 0 8 :3 0
3e :3 0 14a 14b
0 3f :3 0 14c
14d 0 14f ac
151 ae 150 14f
:2 0 199 41 :3 0
8 :3 0 3e :3 0
154 155 0 3f
:3 0 156 157 0
191 15 :3 0 16
:3 0 159 15a 0
15 :3 0 23 :3 0
15c 15d 0 42
:2 0 2 :4 0 43
:2 0 26 :2 0 24
:2 0 b0 162 164
:3 0 b3 15e 166
15b 168 167 :2 0
18 :3 0 27 :3 0
16a 16b 0 1a
:4 0 44 :4 0 1d
:2 0 1e :3 0 b7
16f 171 :3 0 1d
:2 0 2d :4 0 ba
173 175 :3 0 1d
:2 0 45 :4 0 bd
177 179 :3 0 1d
:2 0 3f :3 0 c0
17b 17d :3 0 1d
:2 0 46 :4 0 c3
17f 181 :3 0 1d
:2 0 47 :3 0 48
:3 0 24 :2 0 49
:2 0 c6 184 188
ca 183 18a :3 0
cd 16c 18c :2 0
18e d0 18f 169
18e 0 190 d2
0 191 d4 194
:3 0 194 0 194
193 191 192 :6 0
196 2 :3 0 d7
198 d9 197 196
:2 0 199 db :2 0
19b 0 19b 19a
148 199 :6 0 20c
1 :3 0 c :3 0
4a :4 0 19e 19f
:3 0 19d 1a0 0
20c 13 :3 0 4b
:3 0 f :3 0 12
:3 0 a :3 0 e
:3 0 d :3 0 c
:3 0 de 1a3 1aa
1a2 1ab 0 20c
2f :3 0 13 :3 0
11 :2 0 e5 1ad
1b0 4c :2 0 24
:2 0 ea 1b2 1b4
:3 0 13 :3 0 31
:3 0 4d :3 0 1b7
1b8 0 1b6 1b9
0 1bb ed 1bc
1b5 1bb 0 1bd
ef 0 20c 15
:3 0 16 :3 0 1be
1bf 0 15 :3 0
23 :3 0 1c1 1c2
0 4e :2 0 2
:4 0 4f :2 0 26
:2 0 24 :2 0 f1
1c7 1c9 :3 0 f4
1c3 1cb 1c0 1cd
1cc :2 0 18 :3 0
27 :3 0 1cf 1d0
0 1a :4 0 50
:4 0 1d :2 0 1e
:3 0 f8 1d4 1d6
:3 0 1d :2 0 2d
:4 0 fb 1d8 1da
:3 0 1d :2 0 2e
:4 0 fe 1dc 1de
:3 0 1d :2 0 2f
:3 0 30 :3 0 13
:3 0 101 1e2 1e4
33 :4 0 103 1e1
1e7 106 1e0 1e9
:3 0 1d :2 0 51
:4 0 109 1eb 1ed
:3 0 1d :2 0 20
:4 0 10c 1ef 1f1
:3 0 1d :2 0 c
:3 0 10f 1f3 1f5
:3 0 1d :2 0 20
:4 0 112 1f7 1f9
:3 0 115 1d1 1fb
:2 0 1fd 118 1fe
1ce 1fd 0 1ff
11a 0 20c 36
:3 0 52 :3 0 200
201 0 2f :3 0
13 :3 0 11 :2 0
11c 203 206 c
:3 0 38 :3 0 11f
202 20a :2 0 20c
123 2ad 8 :3 0
53 :2 0 4 20d
20e 0 15 :3 0
16 :3 0 210 211
0 15 :3 0 23
:3 0 213 214 0
42 :2 0 2 :4 0
54 :2 0 26 :2 0
24 :2 0 131 219
21b :3 0 134 215
21d 212 21f 21e
:2 0 18 :3 0 27
:3 0 221 222 0
1a :4 0 55 :4 0
1d :2 0 1e :3 0
138 226 228 :3 0
13b 223 22a :2 0
243 18 :3 0 27
:3 0 22c 22d 0
1a :4 0 56 :4 0
1d :2 0 8 :3 0
57 :3 0 232 233
0 13e 231 235
:3 0 1d :2 0 51
:4 0 141 237 239
:3 0 1d :2 0 8
:3 0 58 :3 0 23c
23d 0 144 23b
23f :3 0 147 22e
241 :2 0 243 14a
244 220 243 0
245 14d 0 255
59 :3 0 14 :3 0
8 :3 0 57 :3 0
5a :3 0 8 :3 0
58 :3 0 3 :3 0
5b :4 0 5c 1
:a 0 251 :2 0 255
247 24f :2 0 7
:3 0 14 :3 0 253
:2 0 255 14f 257
153 256 255 :2 0
2ab 41 :3 0 8
:3 0 3e :3 0 25a
25b 0 3f :3 0
25c 25d 0 2a3
15 :3 0 16 :3 0
25f 260 0 15
:3 0 23 :3 0 262
263 0 42 :2 0
2 :4 0 5d :2 0
26 :2 0 24 :2 0
155 268 26a :3 0
158 264 26c 261
26e 26d :2 0 18
:3 0 27 :3 0 270
271 0 1a :4 0
5e :4 0 1d :2 0
1e :3 0 15c 275
277 :3 0 15f 272
279 :2 0 293 18
:3 0 27 :3 0 27b
27c 0 1a :4 0
45 :4 0 1d :2 0
3f :3 0 162 280
282 :3 0 1d :2 0
46 :4 0 165 284
286 :3 0 1d :2 0
47 :3 0 48 :3 0
24 :2 0 49 :2 0
168 289 28d 16c
288 28f :3 0 16f
27d 291 :2 0 293
172 294 26f 293
0 295 175 0
2a3 59 :3 0 14
:3 0 5a :3 0 8
:3 0 58 :3 0 3
:3 0 5b :4 0 5f
1 :a 0 29f :2 0
2a3 297 29d :2 0
7 :3 0 14 :3 0
2a1 :2 0 2a3 177
2a6 :3 0 2a6 0
2a6 2a5 2a3 2a4
:6 0 2a8 1 :3 0
17c 2aa 17e 2a9
2a8 :2 0 2ab 180
:2 0 2ad 183 2ad
2ac 20c 2ab :6 0
2ae :2 0 2 14
2ad 2b1 :3 0 2b0
2ae 2b2 :8 0 
18c
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
3e 1 44 1
51 1 5d 2
60 62 2 65
67 2 69 6b
2 6d 6f 2
71 73 2 75
77 2 79 7b
2 7d 7f 2
81 83 2 85
87 2 89 8b
2 8d 8f 2
91 93 4 59
5f 64 95 1
97 1 99 2
a3 a5 3 a1
a2 a7 2 b0
b2 2 af b4
1 b6 1 b8
1 ba 1 c0
1 c8 2 d8
da 3 d6 d7
dc 2 e5 e7
2 e9 eb 2
ed ef 1 f7
2 f9 fa 2
f1 fc 2 e4
fe 1 100 1
102 2 10c 10e
3 10a 10b 110
2 119 11b 2
118 11d 1 11f
1 121 2 128
129 3 103 122
12b 1 12d 2
142 147 1 14e
1 149 2 161
163 3 15f 160
165 2 16e 170
2 172 174 2
176 178 2 17a
17c 2 17e 180
3 185 186 187
2 182 189 2
16d 18b 1 18d
1 18f 2 158
190 1 194 1
153 2 151 198
6 1a4 1a5 1a6
1a7 1a8 1a9 2
1ae 1af 1 1b3
2 1b1 1b3 1
1ba 1 1bc 2
1c6 1c8 3 1c4
1c5 1ca 2 1d3
1d5 2 1d7 1d9
2 1db 1dd 1
1e3 2 1e5 1e6
2 1df 1e8 2
1ea 1ec 2 1ee
1f0 2 1f2 1f4
2 1f6 1f8 2
1d2 1fa 1 1fc
1 1fe 2 204
205 3 207 208
209 d 9a b9
12e 131 134 137
13c 19b 1a1 1ac
1bd 1ff 20b 2
218 21a 3 216
217 21c 2 225
227 2 224 229
2 230 234 2
236 238 2 23a
23e 2 22f 240
2 22b 242 1
244 3 245 250
254 1 20f 2
267 269 3 265
266 26b 2 274
276 2 273 278
2 27f 281 2
283 285 3 28a
28b 28c 2 287
28e 2 27e 290
2 27a 292 1
294 4 25e 295
29e 2a2 1 2a6
1 259 2 257
2aa 8 1b 22
29 30 36 3c
42 49 
1
4
0 
2b1
0
1
14
4
c
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
2 0 1
3 1 0
7 1 0
3e 1 0
38 1 0
1d 1 0
32 1 0
24 1 0
44 1 0
0

/
SHOW ERRORS FUNCTION SP_A_POOLRES;
ALTER FUNCTION SP_A_POOLRES COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_DOCRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_DOCRES ==
CREATE OR REPLACE FUNCTION SP_A_DOCRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
7e
2 :e:
1FUNCTION:
1SP_A_DOCRES:
1TABLE_TYPE001:
1PLS_INTEGER:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
10:
1H_TYPE_ID:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_DOCRES(:
1COALESCE:
1TO_CHAR:
1NULL:
1, :
1':
1);:
1CHECK_TRACE:
11:
127:
1+:
1FPUT:
1               ENTER:: SP_A_DOCRES(28) :: cplan.sql(7093) :: :
1IS NULL:
18:
1      RETURN_INVALID:: SP_A_DOCRES(33) :: cplan.sql(7098) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
135:
1                EXIT:: SP_A_DOCRES(36) :: cplan.sql(7101) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1=:
1SC_TABLE_DOC:
1TYPE_ID:
1TMT_DOCUMENTS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_DOCUMENTS WHERE ELEMENT_ID = h_element+
1_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
158:
1           EXCEPTION:: SP_A_DOCRES(59) :: cplan.sql(7124) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1ELSIF:
1SC_TABLE_SCD:
1TMT_ASSIGNED_SCORECARDS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_ASSIGNED_SCORECARDS WHERE ELEMENT_ID =+
1 h_element_id:
173:
1           EXCEPTION:: SP_A_DOCRES(74) :: cplan.sql(7139) :: :
1SC_TABLE_POL_DOC:
1TMT_POOL_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_POOL_DOCUMENTS WHERE ELEMENT_ID = h_el+
1ement_id:
188:
1           EXCEPTION:: SP_A_DOCRES(89) :: cplan.sql(7154) :: :
1SC_TABLE_RES_DOC:
1TMT_RESOURCE_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_RESOURCE_DOCUMENTS WHERE ELEMENT_ID = +
1h_element_id:
1103:
1           EXCEPTION:: SP_A_DOCRES(104) :: cplan.sql(7169) :: :
1SC_TABLE_CLN_DOC:
1TMT_CLIENT_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_CLIENT_DOCUMENTS WHERE ELEMENT_ID = h_+
1element_id:
1118:
1           EXCEPTION:: SP_A_DOCRES(119) :: cplan.sql(7184) :: :
1SC_TABLE_AST_DOC:
1TMT_ASSET_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_ASSET_DOCUMENTS WHERE ELEMENT_ID = h_e+
1lement_id:
1133:
1           EXCEPTION:: SP_A_DOCRES(134) :: cplan.sql(7199) :: :
1SC_TABLE_VDR_DOC:
1TMT_VENDOR_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_VENDOR_DOCUMENTS WHERE ELEMENT_ID = h_+
1element_id:
1148:
1           EXCEPTION:: SP_A_DOCRES(149) :: cplan.sql(7214) :: :
1SYS_GUID:
1ASSIGNRESOURCE:
1RECORD_ALREADY_ASSIGNED:
14:
1164:
1       RETURN_STATUS:: SP_A_DOCRES(165) :: cplan.sql(7230) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1171:
1           EXCEPTION:: SP_A_DOCRES(172) :: cplan.sql(7237) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1183:
1           EXCEPTION:: SP_A_DOCRES(184) :: cplan.sql(7249) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
566
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
a0 7e b4 2e :2 5a a0 7e b4
2e :2 5a 52 10 a0 7e b4 2e
:2 5a 52 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 51 a5
b a0 7e a0 6b b4 2e :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 51 a5 b a0
7e a0 6b b4 2e :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
b7 19 :2 a0 51 a5 b a0 7e
a0 6b b4 2e :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 b7
19 :2 a0 51 a5 b a0 7e a0
6b b4 2e :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 b7 19
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 b7 19 :2 a0
51 a5 b a0 7e a0 6b b4
2e :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 b4 2e
d :8 a0 a5 b d :2 a0 51 a5
b 7e 51 b4 2e :3 a0 6b d
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 51 a5 b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
566
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ef
dd bc e1 e2 ea dc 10b fa
fe d9 106 f9 127 116 11a f6
122 115 143 132 136 112 13e 131
163 14e 152 12e 156 15e 14d 16a
16e 14a 172 176 17a 17d 182 183
1 185 18a 18e 192 195 19a 19e
1a2 1a5 1aa 1ab 1ad 1b2 1b5 1b9
1ba 1bf 1c4 1c7 1cb 1cf 1d3 1d4
1d6 1db 1dc 1de 1df 1e4 1e7 1ec
1ed 1f2 1f5 1fa 1fb 200 203 207
208 20d 210 215 216 21b 21e 223
224 229 22c 231 232 237 23a 23e
23f 244 247 24c 24d 252 255 25a
25b 260 263 268 269 26e 271 275
276 27b 27e 283 284 289 28c 291
292 297 298 29d 29f 2a3 2a6 2aa
2ae 2b1 2b5 2b9 2bc 2bf 2c4 2c7
2ca 2cd 2ce 2d3 2d4 1 2d6 2db
2df 2e3 2e6 2eb 2f0 2f3 2f7 2f8
2fd 2fe 303 305 309 30c 310 313
314 319 31c 31f 323 326 327 32c
32f 1 332 337 33b 33e 33f 344
347 1 34a 34f 353 357 35a 35e
362 365 368 36d 370 373 376 377
37c 37d 1 37f 384 388 38c 38f
394 399 39c 3a0 3a1 3a6 3a9 3ae
3af 3b4 3b7 3bc 3bd 3c2 3c5 3c9
3cd 3d1 3d5 3d8 3d9 3db 3e0 3e1
3e3 3e4 3e9 3ea 3ef 3f1 3f5 3f8
3fc 400 403 407 40b 40e 411 416
419 41c 41f 420 425 426 1 428
42d 431 435 438 43d 442 445 449
44a 44f 450 455 457 45b 45e 462
466 469 46d 471 474 478 479 47e
480 484 487 48b 48f 493 497 49b
49f 4a3 4a7 4ab 4af 4b3 4b7 4bb
4bf 4c2 4c3 4c5 4c9 4cc 4d0 4d3
4d4 4d9 4dd 4e1 4e5 4e9 4ed 4f9
4fd 501 504 508 50c 50e 512 516
51a 51d 521 525 527 528 52d 1
531 535 539 53c 540 544 548 54c
54f 553 557 55a 55d 562 565 568
56b 56c 571 572 1 574 579 57d
581 584 589 58e 591 595 596 59b
59e 5a3 5a4 5a9 5ac 5b1 5b2 5b7
5ba 5be 5bf 5c4 5c7 5cc 5cd 5d2
5d5 5d9 5dd 5e0 5e3 5e4 5e6 5e7
5ec 5ed 5f2 5f4 5f8 5fb 5fd 601
603 60f 611 613 614 619 61d 61f
62b 62d 631 633 637 63b 63e 63f
641 645 648 64c 64f 650 655 659
65d 661 665 669 675 679 67d 680
684 688 68a 68e 692 696 699 69d
6a1 6a3 6a4 6a9 1 6ad 6b1 6b5
6b8 6bc 6c0 6c4 6c8 6cb 6cf 6d3
6d6 6d9 6de 6e1 6e4 6e7 6e8 6ed
6ee 1 6f0 6f5 6f9 6fd 700 705
70a 70d 711 712 717 71a 71f 720
725 728 72d 72e 733 736 73a 73b
740 743 748 749 74e 751 755 759
75c 75f 760 762 763 768 769 76e
770 774 777 779 77d 77f 78b 78d
78f 790 795 799 79b 7a7 7a9 7ad
7af 7b3 7b7 7bb 7be 7bf 7c1 7c5
7c8 7cc 7cf 7d0 7d5 7d9 7dd 7e1
7e5 7e9 7f5 7f9 7fd 800 804 808
80a 80e 812 816 819 81d 821 823
824 829 1 82d 831 835 838 83c
840 844 848 84b 84f 853 856 859
85e 861 864 867 868 86d 86e 1
870 875 879 87d 880 885 88a 88d
891 892 897 89a 89f 8a0 8a5 8a8
8ad 8ae 8b3 8b6 8ba 8bb 8c0 8c3
8c8 8c9 8ce 8d1 8d5 8d9 8dc 8df
8e0 8e2 8e3 8e8 8e9 8ee 8f0 8f4
8f7 8f9 8fd 8ff 90b 90d 90f 910
915 919 91b 927 929 92d 92f 933
937 93b 93e 93f 941 945 948 94c
94f 950 955 959 95d 961 965 969
975 979 97d 980 984 988 98a 98e
992 996 999 99d 9a1 9a3 9a4 9a9
1 9ad 9b1 9b5 9b8 9bc 9c0 9c4
9c8 9cb 9cf 9d3 9d6 9d9 9de 9e1
9e4 9e7 9e8 9ed 9ee 1 9f0 9f5
9f9 9fd a00 a05 a0a a0d a11 a12
a17 a1a a1f a20 a25 a28 a2d a2e
a33 a36 a3a a3b a40 a43 a48 a49
a4e a51 a55 a59 a5c a5f a60 a62
a63 a68 a69 a6e a70 a74 a77 a79
a7d a7f a8b a8d a8f a90 a95 a99
a9b aa7 aa9 aad aaf ab3 ab7 abb
abe abf ac1 ac5 ac8 acc acf ad0
ad5 ad9 add ae1 ae5 ae9 af5 af9
afd b00 b04 b08 b0a b0e b12 b16
b19 b1d b21 b23 b24 b29 1 b2d
b31 b35 b38 b3c b40 b44 b48 b4b
b4f b53 b56 b59 b5e b61 b64 b67
b68 b6d b6e 1 b70 b75 b79 b7d
b80 b85 b8a b8d b91 b92 b97 b9a
b9f ba0 ba5 ba8 bad bae bb3 bb6
bba bbb bc0 bc3 bc8 bc9 bce bd1
bd5 bd9 bdc bdf be0 be2 be3 be8
be9 bee bf0 bf4 bf7 bf9 bfd bff
c0b c0d c0f c10 c15 c19 c1b c27
c29 c2d c2f c33 c37 c3b c3e c3f
c41 c45 c48 c4c c4f c50 c55 c59
c5d c61 c65 c69 c75 c79 c7d c80
c84 c88 c8a c8e c92 c96 c99 c9d
ca1 ca3 ca4 ca9 1 cad cb1 cb5
cb8 cbc cc0 cc4 cc8 ccb ccf cd3
cd6 cd9 cde ce1 ce4 ce7 ce8 ced
cee 1 cf0 cf5 cf9 cfd d00 d05
d0a d0d d11 d12 d17 d1a d1f d20
d25 d28 d2d d2e d33 d36 d3a d3b
d40 d43 d48 d49 d4e d51 d55 d59
d5c d5f d60 d62 d63 d68 d69 d6e
d70 d74 d77 d79 d7d d7f d8b d8d
d8f d90 d95 d99 d9b da7 da9 dad
daf db3 db7 dbb dbe dbf dc1 dc5
dc8 dcc dcf dd0 dd5 dd9 ddd de1
de5 de9 df5 df9 dfd e00 e04 e08
e0a e0e e12 e16 e19 e1d e21 e23
e24 e29 1 e2d e31 e35 e38 e3c
e40 e44 e48 e4b e4f e53 e56 e59
e5e e61 e64 e67 e68 e6d e6e 1
e70 e75 e79 e7d e80 e85 e8a e8d
e91 e92 e97 e9a e9f ea0 ea5 ea8
ead eae eb3 eb6 eba ebb ec0 ec3
ec8 ec9 ece ed1 ed5 ed9 edc edf
ee0 ee2 ee3 ee8 ee9 eee ef0 ef4
ef7 ef9 efd eff f0b f0d f0f f10
f15 f19 f1b f27 f29 f2b f2f f33
f36 f3a f3e f3f f44 f48 f4c f50
f54 f58 f5c f60 f64 f68 f69 f6b
f6f f73 f77 f7a f7b f7d f80 f83
f84 f89 f8d f91 f95 f98 f9c f9e
fa2 fa5 fa9 fad fb0 fb4 fb8 fbb
fbe fc3 fc6 fc9 fcc fcd fd2 fd3
1 fd5 fda fde fe2 fe5 fea fef
ff2 ff6 ff7 ffc fff 1004 1005 100a
100d 1012 1013 1018 101b 101f 1023 1027
1028 102a 102f 1030 1032 1033 1038 103b
1040 1041 1046 1049 104e 104f 1054 1057
105b 105c 1061 1064 1069 106a 106f 1070
1075 1077 107b 107e 1082 1086 1089 108d
1091 1094 1095 1097 109b 109f 10a0 10a5
10a7 10ab 10af 10b2 10b6 10ba 10bd 10c1
10c5 10c8 10cb 10d0 10d3 10d6 10d9 10da
10df 10e0 1 10e2 10e7 10eb 10ef 10f2
10f7 10fc 10ff 1103 1104 1109 110a 110f
1113 1117 111a 111f 1124 1127 112b 112f
1132 1133 1138 113b 1140 1141 1146 1149
114d 1151 1154 1155 115a 115b 1160 1162
1166 1169 116d 1171 1175 1179 117d 1181
1185 1189 118d 1199 119e 11a2 11a6 11aa
11ae 11b0 11b1 11b6 1 11ba 11be 11c2
11c5 11c9 11cd 11d1 11d5 11d8 11dc 11e0
11e3 11e6 11eb 11ee 11f1 11f4 11f5 11fa
11fb 1 11fd 1202 1206 120a 120d 1212
1217 121a 121e 121f 1224 1225 122a 122e
1232 1235 123a 123f 1242 1246 1247 124c
124f 1254 1255 125a 125d 1261 1265 1268
126b 126c 126e 126f 1274 1275 127a 127c
1280 1283 1287 128b 128f 1293 1297 129b
129f 12ab 12b0 12b4 12b8 12bc 12c0 12c2
12c6 12c8 12d4 12d6 12d8 12d9 12de 12e2
12e4 12f0 12f4 12f6 12f7 1300 
566
2
0 1 a 6 14 :3 6 9 :3 6
10 :3 6 12 :2 6 1 3 a 13
a :2 1 4 11 1a 19 :2 11 :2 4
c 15 14 :2 c :2 4 f 18 17
:2 f :2 4 12 1b 1a :2 12 :2 4 :2 11
20 11 :2 4 :2 e 1d e :2 4 :2 14
23 14 :2 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 53 59 5c :2 53
6a 7f 8 11 19 :2 11 29 :2 8
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 21 24 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4d 4e :2 4b :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 51 :2 4
:4 9 8 7 :4 1b 1a 19 :2 7 :4 34
33 32 :2 7 a :2 14 26 :2 30 3c
3f 4e 50 51 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 6e 71 :2 21
75 78 :2 21 82 85 8e 96 :2 9f
:2 8e b0 :2 85 :2 21 :2 a 54 :2 7 a
:2 14 26 :2 30 3c 3f 4e 50 51
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 :2 a 54 :3 7 :2 12 28 :2 31 41
:2 7 4a :3 4 14 :2 4 15 :2 4 12
:2 4 14 4 7 10 1e :2 7 23
21 :2 2c :2 21 11 1e 2d 41 4e
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
57 58 :2 55 :2 2c :3 10 :2 16 1b 27
64 67 :2 27 74 77 :2 27 7b 7e
:2 27 8a 8d :2 27 95 98 :2 27 a4
a7 ae b7 ba :2 a7 :2 27 :2 10 5b
:2 d :2 a :4 16 :2 a 7 :3 39 4 39
a 13 21 :2 a 26 24 :2 2f :2 24
11 1e 2d 4b 58 :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 57 58 :2 55
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
74 77 :2 27 7b 7e :2 27 8a 8d
:2 27 95 98 :2 27 a4 a7 ae b7
ba :2 a7 :2 27 :2 10 5b :2 d :2 a :4 16
:2 a 7 :3 3c 4 3c 39 a 13
21 :2 a 26 24 :2 2f :2 24 11 1e
2d 46 53 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 57 58 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 8a 8d :2 27 95
98 :2 27 a4 a7 ae b7 ba :2 a7
:2 27 :2 10 5b :2 d :2 a :4 16 :2 a 7
:3 40 4 40 39 a 13 21 :2 a
26 24 :2 2f :2 24 11 1e 2d 4a
57 :2 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 8b 8e :2 27 96 99 :2 27
a5 a8 af b8 bb :2 a8 :2 27 :2 10
5c :2 d :2 a :4 16 :2 a 7 :3 40 4
40 39 a 13 21 :2 a 26 24
:2 2f :2 24 11 1e 2d 48 55 :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 75 78 :2 27 7c 7f :2 27
8b 8e :2 27 96 99 :2 27 a5 a8
af b8 bb :2 a8 :2 27 :2 10 5c :2 d
:2 a :4 16 :2 a 7 :3 40 4 40 39
a 13 21 :2 a 26 24 :2 2f :2 24
11 1e 2d 47 54 :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 40 4 40 39 a 13
21 :2 a 26 24 :2 2f :2 24 11 1e
2d 48 55 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 8b 8e :2 27 96
99 :2 27 a5 a8 af b8 bb :2 a8
:2 27 :2 10 5c :2 d :2 a :4 16 :2 a 7
:4 40 39 :3 4 :3 f :2 4 17 26 34
3f 4d 5c 25 :2 17 4 7 10
21 :2 7 24 26 :2 24 7 1a :2 23
7 28 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4e 4f :2 4b :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e 6c 6f :2 1e
73 76 :2 1e 80 83 8c 94 :2 8c
a6 :2 83 :2 1e ae b1 :2 1e b9 bc
:2 1e c1 c4 :2 1e cc cf :2 1e :2 7
52 :3 4 :2 f 21 2a 3b :2 21 3f
48 :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 4f 52 53 :2 4f
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
56 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4c 4f 50 :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 53 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
566
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:7 c :6 d :6 e :6 f
:7 11 :b 13 :11 14 :8 15
:2 14 :2 16 :2 14 :2 16
:2 14 :2 16 :2 14 :2 16
:2 14 :2 17 :2 14 :2 17
:2 14 :2 17 :2 14 :2 17
:2 14 :2 18 :2 14 :2 18
:2 14 :2 18 :2 14 :2 18
:2 14 :2 18 :4 14 :3 13
:11 1b :b 1c :3 1b :16 1f
:11 20 :20 21 :3 20 :11 23
:b 24 :3 23 :9 26 :3 1f
:3 2b :3 2c :3 2d :3 2e
:b 30 :6 32 :5 33 31
35 :5 36 :3 35 :2 37
:5 39 :11 3a :24 3b :3 3a
:2 38 :6 37 34 :3 30
3f 30 :b 3f :6 41
:5 42 40 44 :5 45
:3 44 :2 46 :5 48 :11 49
:24 4a :3 49 :2 47 :6 46
43 :3 3f 4e 3f
30 :b 4e :6 50 :5 51
4f 53 :5 54 :3 53
:2 55 :5 57 :11 58 :24 59
:3 58 :2 56 :6 55 52
:3 4e 5d 4e 30
:b 5d :6 5f :5 60 5e
62 :5 63 :3 62 :2 64
:5 66 :11 67 :24 68 :3 67
:2 65 :6 64 61 :3 5d
6c 5d 30 :b 6c
:6 6e :5 6f 6d 71
:5 72 :3 71 :2 73 :5 75
:11 76 :24 77 :3 76 :2 74
:6 73 70 :3 6c 7b
6c 30 :b 7b :6 7d
:5 7e 7c 80 :5 81
:3 80 :2 82 :5 84 :11 85
:24 86 :3 85 :2 83 :6 82
7f :3 7b 8a 7b
30 :b 8a :6 8c :5 8d
8b 8f :5 90 :3 8f
:2 91 :5 93 :11 94 :24 95
:3 94 :2 92 :6 91 8e
:4 8a :3 30 :5 9b :7 9d
9e :3 9d :9 a0 :5 a1
:3 a0 :11 a4 :2e a5 :3 a4
:c a7 12 :3 aa :11 ab
:b ac :17 ad :3 ab :2 af
:3 b0 :3 b1 b2 b0
af b0 :3 b3 :3 aa
:2 b4 :5 b6 :11 b7 :b b8
:18 b9 :3 b7 :2 bb bc
:3 bd be bc bb
bc :3 bf :2 b5 :6 b4
a9 :7 1 
1302
4
:3 0 1 :3 0 2
:a 0 561 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 15 16 0
b 6 :3 0 8
:7 0 11 10 :3 0
9 :3 0 a :3 0
b :2 0 4 13
17 0 561 2
18 :2 0 d :2 0
12 6 :3 0 d
:2 0 10 1b 1d
:6 0 20 1e 0
55f 0 c :6 0
d :2 0 16 6
:3 0 14 22 24
:6 0 27 25 0
55f 0 e :6 0
d :2 0 1a 6
:3 0 18 29 2b
:6 0 2e 2c 0
55f 0 f :6 0
12 :2 0 1e 6
:3 0 1c 30 32
:6 0 35 33 0
55f 0 10 :6 0
12 :2 0 20 4
:3 0 37 :7 0 3b
38 39 55f 0
11 :6 0 12 :2 0
22 4 :3 0 3d
:7 0 41 3e 3f
55f 0 13 :6 0
49 4a 0 24
4 :3 0 43 :7 0
47 44 45 55f
0 14 :6 0 4f
50 0 26 a
:3 0 b :2 0 4
4b :7 0 4e 4c
0 55f 0 15
:6 0 16 :3 0 17
:3 0 16 :3 0 18
:3 0 52 53 0
2 :4 0 28 54
56 51 58 57
:2 0 19 :3 0 1a
:3 0 5a 5b 0
1b :4 0 16 :3 0
1c :3 0 5e 5f
0 2 :4 0 2a
60 62 1d :4 0
1e :2 0 1f :3 0
2c 65 67 :3 0
20 :4 0 1e :2 0
21 :3 0 22 :3 0
3 :3 0 2f 6c
6e 23 :4 0 31
6b 71 34 6a
73 :3 0 1e :2 0
24 :4 0 37 75
77 :3 0 1e :2 0
25 :4 0 3a 79
7b :3 0 1e :2 0
5 :3 0 3d 7d
7f :3 0 1e :2 0
25 :4 0 40 81
83 :3 0 1e :2 0
24 :4 0 43 85
87 :3 0 1e :2 0
25 :4 0 46 89
8b :3 0 1e :2 0
7 :3 0 49 8d
8f :3 0 1e :2 0
25 :4 0 4c 91
93 :3 0 1e :2 0
24 :4 0 4f 95
97 :3 0 1e :2 0
25 :4 0 52 99
9b :3 0 1e :2 0
8 :3 0 55 9d
9f :3 0 1e :2 0
25 :4 0 58 a1
a3 :3 0 1e :2 0
26 :4 0 5b a5
a7 :3 0 5e 5c
a9 :2 0 ab 63
ac 59 ab 0
ad 65 0 4bf
16 :3 0 17 :3 0
ae af 0 16
:3 0 27 :3 0 b1
b2 0 28 :2 0
2 :4 0 29 :2 0
2a :2 0 28 :2 0
67 b7 b9 :3 0
6a b3 bb b0
bd bc :2 0 19
:3 0 2b :3 0 bf
c0 0 1b :4 0
2c :4 0 1e :2 0
1f :3 0 6e c4
c6 :3 0 71 c1
c8 :2 0 ca 74
cb be ca 0
cc 76 0 4bf
5 :3 0 2d :2 0
78 ce cf :3 0
d0 :2 0 d1 :2 0
7 :3 0 2d :2 0
7a d4 d5 :3 0
d6 :2 0 d7 :2 0
d2 d9 d8 :2 0
8 :3 0 2d :2 0
7c dc dd :3 0
de :2 0 df :2 0
da e1 e0 :2 0
16 :3 0 17 :3 0
e3 e4 0 16
:3 0 27 :3 0 e6
e7 0 2e :2 0
2 :4 0 d :2 0
2a :2 0 28 :2 0
7e ec ee :3 0
81 e8 f0 e5
f2 f1 :2 0 19
:3 0 2b :3 0 f4
f5 0 1b :4 0
2f :4 0 1e :2 0
1f :3 0 85 f9
fb :3 0 1e :2 0
30 :4 0 88 fd
ff :3 0 1e :2 0
31 :4 0 8b 101
103 :3 0 1e :2 0
21 :3 0 22 :3 0
32 :3 0 33 :3 0
108 109 0 8e
107 10b 23 :4 0
90 106 10e 93
105 110 :3 0 96
f6 112 :2 0 114
99 115 f3 114
0 116 9b 0
13f 16 :3 0 17
:3 0 117 118 0
16 :3 0 27 :3 0
11a 11b 0 28
:2 0 2 :4 0 34
:2 0 2a :2 0 28
:2 0 9d 120 122
:3 0 a0 11c 124
119 126 125 :2 0
19 :3 0 2b :3 0
128 129 0 1b
:4 0 35 :4 0 1e
:2 0 1f :3 0 a4
12d 12f :3 0 a7
12a 131 :2 0 133
aa 134 127 133
0 135 ac 0
13f 36 :3 0 37
:3 0 136 137 0
32 :3 0 33 :3 0
139 13a 0 38
:3 0 ae 138 13d
:2 0 13f b1 140
e2 13f 0 141
b5 0 4bf c
:3 0 5 :3 0 142
143 0 4bf 10
:3 0 7 :3 0 145
146 0 4bf f
:3 0 8 :3 0 148
149 0 4bf 11
:3 0 3 :3 0 14b
14c 0 4bf 21
:3 0 11 :3 0 12
:2 0 b7 14e 151
32 :3 0 39 :2 0
3a :3 0 153 155
0 bc 154 157
:3 0 3b :3 0 13
:3 0 3c :3 0 3d
:3 0 c :4 0 3e
1 :8 0 164 a
:3 0 3f :3 0 15f
160 0 40 :3 0
161 162 0 164
bf 1b7 41 :3 0
a :3 0 3f :3 0
166 167 0 40
:3 0 168 169 0
16b c2 16d c4
16c 16b :2 0 1b5
42 :3 0 a :3 0
3f :3 0 170 171
0 40 :3 0 172
173 0 1ad 16
:3 0 17 :3 0 175
176 0 16 :3 0
27 :3 0 178 179
0 43 :2 0 2
:4 0 44 :2 0 2a
:2 0 28 :2 0 c6
17e 180 :3 0 c9
17a 182 177 184
183 :2 0 19 :3 0
2b :3 0 186 187
0 1b :4 0 45
:4 0 1e :2 0 1f
:3 0 cd 18b 18d
:3 0 1e :2 0 30
:4 0 d0 18f 191
:3 0 1e :2 0 46
:4 0 d3 193 195
:3 0 1e :2 0 40
:3 0 d6 197 199
:3 0 1e :2 0 47
:4 0 d9 19b 19d
:3 0 1e :2 0 48
:3 0 49 :3 0 28
:2 0 4a :2 0 dc
1a0 1a4 e0 19f
1a6 :3 0 e3 188
1a8 :2 0 1aa e6
1ab 185 1aa 0
1ac e8 0 1ad
ea 1b0 :3 0 1b0
0 1b0 1af 1ad
1ae :6 0 1b2 2
:3 0 ed 1b4 ef
1b3 1b2 :2 0 1b5
f1 :2 0 1b7 0
1b7 1b6 164 1b5
:6 0 1ba 1 :3 0
4b :3 0 f4 44e
21 :3 0 11 :3 0
12 :2 0 f6 1bb
1be 32 :3 0 39
:2 0 4c :3 0 1c0
1c2 0 fb 1c1
1c4 :3 0 3b :3 0
13 :3 0 4d :3 0
3d :3 0 c :4 0
4e 1 :8 0 1d1
a :3 0 3f :3 0
1cc 1cd 0 40
:3 0 1ce 1cf 0
1d1 fe 224 41
:3 0 a :3 0 3f
:3 0 1d3 1d4 0
40 :3 0 1d5 1d6
0 1d8 101 1da
103 1d9 1d8 :2 0
222 42 :3 0 a
:3 0 3f :3 0 1dd
1de 0 40 :3 0
1df 1e0 0 21a
16 :3 0 17 :3 0
1e2 1e3 0 16
:3 0 27 :3 0 1e5
1e6 0 43 :2 0
2 :4 0 4f :2 0
2a :2 0 28 :2 0
105 1eb 1ed :3 0
108 1e7 1ef 1e4
1f1 1f0 :2 0 19
:3 0 2b :3 0 1f3
1f4 0 1b :4 0
50 :4 0 1e :2 0
1f :3 0 10c 1f8
1fa :3 0 1e :2 0
30 :4 0 10f 1fc
1fe :3 0 1e :2 0
46 :4 0 112 200
202 :3 0 1e :2 0
40 :3 0 115 204
206 :3 0 1e :2 0
47 :4 0 118 208
20a :3 0 1e :2 0
48 :3 0 49 :3 0
28 :2 0 4a :2 0
11b 20d 211 11f
20c 213 :3 0 122
1f5 215 :2 0 217
125 218 1f2 217
0 219 127 0
21a 129 21d :3 0
21d 0 21d 21c
21a 21b :6 0 21f
4 :3 0 12c 221
12e 220 21f :2 0
222 130 :2 0 224
0 224 223 1d1
222 :6 0 227 1
:3 0 4b :3 0 133
228 1c5 227 0
44f 21 :3 0 11
:3 0 12 :2 0 135
229 22c 32 :3 0
39 :2 0 51 :3 0
22e 230 0 13a
22f 232 :3 0 3b
:3 0 13 :3 0 52
:3 0 3d :3 0 c
:4 0 53 1 :8 0
23f a :3 0 3f
:3 0 23a 23b 0
40 :3 0 23c 23d
0 23f 13d 292
41 :3 0 a :3 0
3f :3 0 241 242
0 40 :3 0 243
244 0 246 140
248 142 247 246
:2 0 290 42 :3 0
a :3 0 3f :3 0
24b 24c 0 40
:3 0 24d 24e 0
288 16 :3 0 17
:3 0 250 251 0
16 :3 0 27 :3 0
253 254 0 43
:2 0 2 :4 0 54
:2 0 2a :2 0 28
:2 0 144 259 25b
:3 0 147 255 25d
252 25f 25e :2 0
19 :3 0 2b :3 0
261 262 0 1b
:4 0 55 :4 0 1e
:2 0 1f :3 0 14b
266 268 :3 0 1e
:2 0 30 :4 0 14e
26a 26c :3 0 1e
:2 0 46 :4 0 151
26e 270 :3 0 1e
:2 0 40 :3 0 154
272 274 :3 0 1e
:2 0 47 :4 0 157
276 278 :3 0 1e
:2 0 48 :3 0 49
:3 0 28 :2 0 4a
:2 0 15a 27b 27f
15e 27a 281 :3 0
161 263 283 :2 0
285 164 286 260
285 0 287 166
0 288 168 28b
:3 0 28b 0 28b
28a 288 289 :6 0
28d 6 :3 0 16b
28f 16d 28e 28d
:2 0 290 16f :2 0
292 0 292 291
23f 290 :6 0 295
1 :3 0 4b :3 0
172 296 233 295
0 44f 21 :3 0
11 :3 0 12 :2 0
174 297 29a 32
:3 0 39 :2 0 56
:3 0 29c 29e 0
179 29d 2a0 :3 0
3b :3 0 13 :3 0
57 :3 0 3d :3 0
c :4 0 58 1
:8 0 2ad a :3 0
3f :3 0 2a8 2a9
0 40 :3 0 2aa
2ab 0 2ad 17c
300 41 :3 0 a
:3 0 3f :3 0 2af
2b0 0 40 :3 0
2b1 2b2 0 2b4
17f 2b6 181 2b5
2b4 :2 0 2fe 42
:3 0 a :3 0 3f
:3 0 2b9 2ba 0
40 :3 0 2bb 2bc
0 2f6 16 :3 0
17 :3 0 2be 2bf
0 16 :3 0 27
:3 0 2c1 2c2 0
43 :2 0 2 :4 0
59 :2 0 2a :2 0
28 :2 0 183 2c7
2c9 :3 0 186 2c3
2cb 2c0 2cd 2cc
:2 0 19 :3 0 2b
:3 0 2cf 2d0 0
1b :4 0 5a :4 0
1e :2 0 1f :3 0
18a 2d4 2d6 :3 0
1e :2 0 30 :4 0
18d 2d8 2da :3 0
1e :2 0 46 :4 0
190 2dc 2de :3 0
1e :2 0 40 :3 0
193 2e0 2e2 :3 0
1e :2 0 47 :4 0
196 2e4 2e6 :3 0
1e :2 0 48 :3 0
49 :3 0 28 :2 0
4a :2 0 199 2e9
2ed 19d 2e8 2ef
:3 0 1a0 2d1 2f1
:2 0 2f3 1a3 2f4
2ce 2f3 0 2f5
1a5 0 2f6 1a7
2f9 :3 0 2f9 0
2f9 2f8 2f6 2f7
:6 0 2fb 8 :3 0
1aa 2fd 1ac 2fc
2fb :2 0 2fe 1ae
:2 0 300 0 300
2ff 2ad 2fe :6 0
303 1 :3 0 4b
:3 0 1b1 304 2a1
303 0 44f 21
:3 0 11 :3 0 12
:2 0 1b3 305 308
32 :3 0 39 :2 0
5b :3 0 30a 30c
0 1b8 30b 30e
:3 0 3b :3 0 13
:3 0 5c :3 0 3d
:3 0 c :4 0 5d
1 :8 0 31b a
:3 0 3f :3 0 316
317 0 40 :3 0
318 319 0 31b
1bb 36e 41 :3 0
a :3 0 3f :3 0
31d 31e 0 40
:3 0 31f 320 0
322 1be 324 1c0
323 322 :2 0 36c
42 :3 0 a :3 0
3f :3 0 327 328
0 40 :3 0 329
32a 0 364 16
:3 0 17 :3 0 32c
32d 0 16 :3 0
27 :3 0 32f 330
0 43 :2 0 2
:4 0 5e :2 0 2a
:2 0 28 :2 0 1c2
335 337 :3 0 1c5
331 339 32e 33b
33a :2 0 19 :3 0
2b :3 0 33d 33e
0 1b :4 0 5f
:4 0 1e :2 0 1f
:3 0 1c9 342 344
:3 0 1e :2 0 30
:4 0 1cc 346 348
:3 0 1e :2 0 46
:4 0 1cf 34a 34c
:3 0 1e :2 0 40
:3 0 1d2 34e 350
:3 0 1e :2 0 47
:4 0 1d5 352 354
:3 0 1e :2 0 48
:3 0 49 :3 0 28
:2 0 4a :2 0 1d8
357 35b 1dc 356
35d :3 0 1df 33f
35f :2 0 361 1e2
362 33c 361 0
363 1e4 0 364
1e6 367 :3 0 367
0 367 366 364
365 :6 0 369 a
:3 0 1e9 36b 1eb
36a 369 :2 0 36c
1ed :2 0 36e 0
36e 36d 31b 36c
:6 0 371 1 :3 0
4b :3 0 1f0 372
30f 371 0 44f
21 :3 0 11 :3 0
12 :2 0 1f2 373
376 32 :3 0 39
:2 0 60 :3 0 378
37a 0 1f7 379
37c :3 0 3b :3 0
13 :3 0 61 :3 0
3d :3 0 c :4 0
62 1 :8 0 389
a :3 0 3f :3 0
384 385 0 40
:3 0 386 387 0
389 1fa 3dc 41
:3 0 a :3 0 3f
:3 0 38b 38c 0
40 :3 0 38d 38e
0 390 1fd 392
1ff 391 390 :2 0
3da 42 :3 0 a
:3 0 3f :3 0 395
396 0 40 :3 0
397 398 0 3d2
16 :3 0 17 :3 0
39a 39b 0 16
:3 0 27 :3 0 39d
39e 0 43 :2 0
2 :4 0 63 :2 0
2a :2 0 28 :2 0
201 3a3 3a5 :3 0
204 39f 3a7 39c
3a9 3a8 :2 0 19
:3 0 2b :3 0 3ab
3ac 0 1b :4 0
64 :4 0 1e :2 0
1f :3 0 208 3b0
3b2 :3 0 1e :2 0
30 :4 0 20b 3b4
3b6 :3 0 1e :2 0
46 :4 0 20e 3b8
3ba :3 0 1e :2 0
40 :3 0 211 3bc
3be :3 0 1e :2 0
47 :4 0 214 3c0
3c2 :3 0 1e :2 0
48 :3 0 49 :3 0
28 :2 0 4a :2 0
217 3c5 3c9 21b
3c4 3cb :3 0 21e
3ad 3cd :2 0 3cf
221 3d0 3aa 3cf
0 3d1 223 0
3d2 225 3d5 :3 0
3d5 0 3d5 3d4
3d2 3d3 :6 0 3d7
c :3 0 228 3d9
22a 3d8 3d7 :2 0
3da 22c :2 0 3dc
0 3dc 3db 389
3da :6 0 3df 1
:3 0 4b :3 0 22f
3e0 37d 3df 0
44f 21 :3 0 11
:3 0 12 :2 0 231
3e1 3e4 32 :3 0
39 :2 0 65 :3 0
3e6 3e8 0 236
3e7 3ea :3 0 3b
:3 0 13 :3 0 66
:3 0 3d :3 0 c
:4 0 67 1 :8 0
3f7 a :3 0 3f
:3 0 3f2 3f3 0
40 :3 0 3f4 3f5
0 3f7 239 44a
41 :3 0 a :3 0
3f :3 0 3f9 3fa
0 40 :3 0 3fb
3fc 0 3fe 23c
400 23e 3ff 3fe
:2 0 448 42 :3 0
a :3 0 3f :3 0
403 404 0 40
:3 0 405 406 0
440 16 :3 0 17
:3 0 408 409 0
16 :3 0 27 :3 0
40b 40c 0 43
:2 0 2 :4 0 68
:2 0 2a :2 0 28
:2 0 240 411 413
:3 0 243 40d 415
40a 417 416 :2 0
19 :3 0 2b :3 0
419 41a 0 1b
:4 0 69 :4 0 1e
:2 0 1f :3 0 247
41e 420 :3 0 1e
:2 0 30 :4 0 24a
422 424 :3 0 1e
:2 0 46 :4 0 24d
426 428 :3 0 1e
:2 0 40 :3 0 250
42a 42c :3 0 1e
:2 0 47 :4 0 253
42e 430 :3 0 1e
:2 0 48 :3 0 49
:3 0 28 :2 0 4a
:2 0 256 433 437
25a 432 439 :3 0
25d 41b 43b :2 0
43d 260 43e 418
43d 0 43f 262
0 440 264 443
:3 0 443 0 443
442 440 441 :6 0
445 e :3 0 267
447 269 446 445
:2 0 448 26b :2 0
44a 0 44a 449
3f7 448 :6 0 44c
1 :3 0 26e 44d
3eb 44c 0 44f
158 1ba 0 44f
270 0 4bf e
:3 0 6a :4 0 451
452 :3 0 450 453
0 4bf 14 :3 0
6b :3 0 11 :3 0
13 :3 0 c :3 0
10 :3 0 f :3 0
e :3 0 278 456
45d 455 45e 0
4bf 21 :3 0 14
:3 0 12 :2 0 27f
460 463 39 :2 0
28 :2 0 284 465
467 :3 0 14 :3 0
32 :3 0 6c :3 0
46a 46b 0 469
46c 0 46e 287
46f 468 46e 0
470 289 0 4bf
16 :3 0 17 :3 0
471 472 0 16
:3 0 27 :3 0 474
475 0 6d :2 0
2 :4 0 6e :2 0
2a :2 0 28 :2 0
28b 47a 47c :3 0
28e 476 47e 473
480 47f :2 0 19
:3 0 2b :3 0 482
483 0 1b :4 0
6f :4 0 1e :2 0
1f :3 0 292 487
489 :3 0 1e :2 0
30 :4 0 295 48b
48d :3 0 1e :2 0
31 :4 0 298 48f
491 :3 0 1e :2 0
21 :3 0 22 :3 0
14 :3 0 29b 495
497 23 :4 0 29d
494 49a 2a0 493
49c :3 0 1e :2 0
70 :4 0 2a3 49e
4a0 :3 0 1e :2 0
25 :4 0 2a6 4a2
4a4 :3 0 1e :2 0
e :3 0 2a9 4a6
4a8 :3 0 1e :2 0
25 :4 0 2ac 4aa
4ac :3 0 2af 484
4ae :2 0 4b0 2b2
4b1 481 4b0 0
4b2 2b4 0 4bf
36 :3 0 71 :3 0
4b3 4b4 0 21
:3 0 14 :3 0 12
:2 0 2b6 4b6 4b9
e :3 0 38 :3 0
2b9 4b5 4bd :2 0
4bf 2bd 560 a
:3 0 72 :2 0 4
4c0 4c1 0 16
:3 0 17 :3 0 4c3
4c4 0 16 :3 0
27 :3 0 4c6 4c7
0 43 :2 0 2
:4 0 73 :2 0 2a
:2 0 28 :2 0 2cb
4cc 4ce :3 0 2ce
4c8 4d0 4c5 4d2
4d1 :2 0 19 :3 0
2b :3 0 4d4 4d5
0 1b :4 0 74
:4 0 1e :2 0 1f
:3 0 2d2 4d9 4db
:3 0 2d5 4d6 4dd
:2 0 4f6 19 :3 0
2b :3 0 4df 4e0
0 1b :4 0 75
:4 0 1e :2 0 a
:3 0 76 :3 0 4e5
4e6 0 2d8 4e4
4e8 :3 0 1e :2 0
70 :4 0 2db 4ea
4ec :3 0 1e :2 0
a :3 0 77 :3 0
4ef 4f0 0 2de
4ee 4f2 :3 0 2e1
4e1 4f4 :2 0 4f6
2e4 4f7 4d3 4f6
0 4f8 2e7 0
508 78 :3 0 15
:3 0 a :3 0 76
:3 0 79 :3 0 a
:3 0 77 :3 0 5
:3 0 7a :4 0 7b
1 :a 0 504 :2 0
508 4fa 502 :2 0
9 :3 0 15 :3 0
506 :2 0 508 2e9
50a 2ed 509 508
:2 0 55e 42 :3 0
a :3 0 3f :3 0
50d 50e 0 40
:3 0 50f 510 0
556 16 :3 0 17
:3 0 512 513 0
16 :3 0 27 :3 0
515 516 0 43
:2 0 2 :4 0 7c
:2 0 2a :2 0 28
:2 0 2ef 51b 51d
:3 0 2f2 517 51f
514 521 520 :2 0
19 :3 0 2b :3 0
523 524 0 1b
:4 0 7d :4 0 1e
:2 0 1f :3 0 2f6
528 52a :3 0 2f9
525 52c :2 0 546
19 :3 0 2b :3 0
52e 52f 0 1b
:4 0 46 :4 0 1e
:2 0 40 :3 0 2fc
533 535 :3 0 1e
:2 0 47 :4 0 2ff
537 539 :3 0 1e
:2 0 48 :3 0 49
:3 0 28 :2 0 4a
:2 0 302 53c 540
306 53b 542 :3 0
309 530 544 :2 0
546 30c 547 522
546 0 548 30f
0 556 78 :3 0
15 :3 0 79 :3 0
a :3 0 77 :3 0
5 :3 0 7a :4 0
7e 1 :a 0 552
:2 0 556 54a 550
:2 0 9 :3 0 15
:3 0 554 :2 0 556
311 559 :3 0 559
0 559 558 556
557 :6 0 55b 1
:3 0 316 55d 318
55c 55b :2 0 55e
31a :2 0 560 31d
560 55f 4bf 55e
:6 0 561 :2 0 2
18 560 564 :3 0
563 561 565 :8 0

326
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 31
1 2f 1 36
1 3c 1 42
1 48 1 55
1 61 2 64
66 1 6d 2
6f 70 2 69
72 2 74 76
2 78 7a 2
7c 7e 2 80
82 2 84 86
2 88 8a 2
8c 8e 2 90
92 2 94 96
2 98 9a 2
9c 9e 2 a0
a2 2 a4 a6
4 5d 63 68
a8 1 aa 1
ac 2 b6 b8
3 b4 b5 ba
2 c3 c5 2
c2 c7 1 c9
1 cb 1 cd
1 d3 1 db
2 eb ed 3
e9 ea ef 2
f8 fa 2 fc
fe 2 100 102
1 10a 2 10c
10d 2 104 10f
2 f7 111 1
113 1 115 2
11f 121 3 11d
11e 123 2 12c
12e 2 12b 130
1 132 1 134
2 13b 13c 3
116 135 13e 1
140 2 14f 150
1 156 2 152
156 2 15e 163
1 16a 1 165
2 17d 17f 3
17b 17c 181 2
18a 18c 2 18e
190 2 192 194
2 196 198 2
19a 19c 3 1a1
1a2 1a3 2 19e
1a5 2 189 1a7
1 1a9 1 1ab
2 174 1ac 1
1b0 1 16f 2
16d 1b4 1 1b7
2 1bc 1bd 1
1c3 2 1bf 1c3
2 1cb 1d0 1
1d7 1 1d2 2
1ea 1ec 3 1e8
1e9 1ee 2 1f7
1f9 2 1fb 1fd
2 1ff 201 2
203 205 2 207
209 3 20e 20f
210 2 20b 212
2 1f6 214 1
216 1 218 2
1e1 219 1 21d
1 1dc 2 1da
221 1 224 2
22a 22b 1 231
2 22d 231 2
239 23e 1 245
1 240 2 258
25a 3 256 257
25c 2 265 267
2 269 26b 2
26d 26f 2 271
273 2 275 277
3 27c 27d 27e
2 279 280 2
264 282 1 284
1 286 2 24f
287 1 28b 1
24a 2 248 28f
1 292 2 298
299 1 29f 2
29b 29f 2 2a7
2ac 1 2b3 1
2ae 2 2c6 2c8
3 2c4 2c5 2ca
2 2d3 2d5 2
2d7 2d9 2 2db
2dd 2 2df 2e1
2 2e3 2e5 3
2ea 2eb 2ec 2
2e7 2ee 2 2d2
2f0 1 2f2 1
2f4 2 2bd 2f5
1 2f9 1 2b8
2 2b6 2fd 1
300 2 306 307
1 30d 2 309
30d 2 315 31a
1 321 1 31c
2 334 336 3
332 333 338 2
341 343 2 345
347 2 349 34b
2 34d 34f 2
351 353 3 358
359 35a 2 355
35c 2 340 35e
1 360 1 362
2 32b 363 1
367 1 326 2
324 36b 1 36e
2 374 375 1
37b 2 377 37b
2 383 388 1
38f 1 38a 2
3a2 3a4 3 3a0
3a1 3a6 2 3af
3b1 2 3b3 3b5
2 3b7 3b9 2
3bb 3bd 2 3bf
3c1 3 3c6 3c7
3c8 2 3c3 3ca
2 3ae 3cc 1
3ce 1 3d0 2
399 3d1 1 3d5
1 394 2 392
3d9 1 3dc 2
3e2 3e3 1 3e9
2 3e5 3e9 2
3f1 3f6 1 3fd
1 3f8 2 410
412 3 40e 40f
414 2 41d 41f
2 421 423 2
425 427 2 429
42b 2 42d 42f
3 434 435 436
2 431 438 2
41c 43a 1 43c
1 43e 2 407
43f 1 443 1
402 2 400 447
1 44a 7 44e
228 296 304 372
3e0 44d 6 457
458 459 45a 45b
45c 2 461 462
1 466 2 464
466 1 46d 1
46f 2 479 47b
3 477 478 47d
2 486 488 2
48a 48c 2 48e
490 1 496 2
498 499 2 492
49b 2 49d 49f
2 4a1 4a3 2
4a5 4a7 2 4a9
4ab 2 485 4ad
1 4af 1 4b1
2 4b7 4b8 3
4ba 4bb 4bc d
ad cc 141 144
147 14a 14d 44f
454 45f 470 4b2
4be 2 4cb 4cd
3 4c9 4ca 4cf
2 4d8 4da 2
4d7 4dc 2 4e3
4e7 2 4e9 4eb
2 4ed 4f1 2
4e2 4f3 2 4de
4f5 1 4f7 3
4f8 503 507 1
4c2 2 51a 51c
3 518 519 51e
2 527 529 2
526 52b 2 532
534 2 536 538
3 53d 53e 53f
2 53a 541 2
531 543 2 52d
545 1 547 4
511 548 551 555
1 559 1 50c
2 50a 55d 8
1f 26 2d 34
3a 40 46 4d

1
4
0 
564
0
1
14
10
d
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
0 0 0 0 
f 1 0
1a 1 0
2f 1 0
7 1 0
b 1 0
42 1 0
3c 1 0
21 1 0
36 1 0
28 1 0
3 1 0
2 0 1
48 1 0
0

/
SHOW ERRORS FUNCTION SP_A_DOCRES;
ALTER FUNCTION SP_A_DOCRES COMPILE DEBUG;
/*****************************************************************************************/
Prompt == FUNCTION FC_U_CREATETMPTABLE ==
CREATE OR REPLACE FUNCTION FC_U_CREATETMPTABLE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1f
2 :e:
1FUNCTION:
1FC_U_CREATETMPTABLE:
1RETURN:
1PLS_INTEGER:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_CREATETMPTABLE();:
1CHECK_TRACE:
11:
18:
1+:
1FPUT:
1               ENTER:: FC_U_CREATETMPTABLE(9) :: cplan.sql(7274) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN01_TEMP:
1PMO_DB2M:
1SC_STATE:
10:
117:
1                EXIT:: FC_U_CREATETMPTABLE(18) :: cplan.sql(7283) :: :
1 :
1STATE:: :
0

0
0
8c
2
0 a0 8d a0 b4 a0 2c 6a
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6e 11e 11d :2 a0 6b 51 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 a4 b1 11 68 4f
1d 17 b5 
8c
2
0 3 f b a 23 27 2b
2f 33 7 37 3b 3f 42 47
48 1 4a 4f 53 57 5a 5f
63 67 6a 6f 70 72 77 7a
7e 7f 84 89 8a 8f 91 95
98 9c a0 a3 a7 ab ae b1
b6 b9 bc bf c0 c5 c6 1
c8 cd d1 d5 d8 dd e2 e5
e9 ea ef f0 f5 f7 fb fe
102 106 10b 110 114 118 11c 11f
122 126 12a 12e 131 135 139 13c
13f 144 147 14a 14d 14e 153 154
1 156 15b 15f 163 166 16b 170
173 177 178 17d 180 185 186 18b
18e 193 194 199 19c 1a0 1a4 1a7
1a8 1ad 1ae 1b3 1b5 1b9 1bc 1c0
1c4 1c8 1cb 1cf 1d1 1d5 1d7 1e3
1e7 1e9 1ea 1f3 
8c
2
0 1 a 1e 0 25 :2 1 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 5b 61 64 :2 5b
72 :2 7 51 :2 4 7 :2 11 23 :2 2d
39 3c 53 54 55 :2 53 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 58
:3 4 c 16 :3 4 :2 d 19 4 7
:2 11 23 :2 2d 39 3c 53 55 56
:2 53 :2 23 :3 7 :2 d 12 1e 63 66
:2 1e 73 76 :2 1e 7a 7d :2 1e 87
8a :2 93 :2 1e :2 7 59 :3 4 b :2 14
4 :9 1 
8c
4
0 :3 1 0 :3 1
:b 4 :12 5 :3 4 :11 8
:b 9 :3 8 :5 e :5 f
:11 11 :19 12 :3 11 :5 14
:2 3 :7 1 
1f5
4
:3 0 1 :3 0 8
9 :2 0 3 :3 0
2 :a 0 87 1
:7 0 4 :3 0 4
5 0 87 2
6 :2 0 5 :3 0
6 :3 0 5 :3 0
7 :3 0 b c
0 2 :4 0 3
d f a 11
10 :2 0 8 :3 0
9 :3 0 13 14
0 a :4 0 5
:3 0 b :3 0 17
18 0 2 :4 0
5 19 1b c
:4 0 d :2 0 e
:3 0 7 1e 20
:3 0 f :4 0 a
15 23 :2 0 25
f 26 12 25
0 27 11 0
83 5 :3 0 6
:3 0 28 29 0
5 :3 0 10 :3 0
2b 2c 0 11
:2 0 2 :4 0 12
:2 0 13 :2 0 11
:2 0 13 31 33
:3 0 16 2d 35
2a 37 36 :2 0
8 :3 0 14 :3 0
39 3a 0 a
:4 0 15 :4 0 d
:2 0 e :3 0 1a
3e 40 :3 0 1d
3b 42 :2 0 44
20 45 38 44
0 46 22 0
83 16 :3 0 17
:3 0 18 :4 0 49
:4 0 4a :2 0 83
19 :3 0 1a :3 0
4c 4d 0 1b
:2 0 4e 4f 0
83 5 :3 0 6
:3 0 51 52 0
5 :3 0 10 :3 0
54 55 0 11
:2 0 2 :4 0 1c
:2 0 13 :2 0 11
:2 0 24 5a 5c
:3 0 27 56 5e
53 60 5f :2 0
8 :3 0 14 :3 0
62 63 0 a
:4 0 1d :4 0 d
:2 0 e :3 0 2b
67 69 :3 0 d
:2 0 1e :4 0 2e
6b 6d :3 0 d
:2 0 1f :4 0 31
6f 71 :3 0 d
:2 0 19 :3 0 1a
:3 0 74 75 0
34 73 77 :3 0
37 64 79 :2 0
7b 3a 7c 61
7b 0 7d 3c
0 83 3 :3 0
19 :3 0 1a :3 0
7f 80 0 81
:2 0 83 3e 86
:3 0 86 0 86
85 83 84 :6 0
87 :2 0 2 6
86 8a :3 0 89
87 8b :8 0 
45
4
:3 0 1 e 1
1a 2 1d 1f
4 16 1c 21
22 1 24 1
26 2 30 32
3 2e 2f 34
2 3d 3f 2
3c 41 1 43
1 45 2 59
5b 3 57 58
5d 2 66 68
2 6a 6c 2
6e 70 2 72
76 2 65 78
1 7a 1 7c
6 27 46 4b
50 7d 82 
1
4
0 
8a
0
1
14
1
1
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
0

/
SHOW ERRORS FUNCTION FC_U_CREATETMPTABLE;
ALTER FUNCTION FC_U_CREATETMPTABLE COMPILE DEBUG;
/************************************************************************************************/
/*****************************************************************************************/
Prompt == FUNCTION FC_U_TSKRES2 ==
CREATE OR REPLACE FUNCTION FC_U_TSKRES2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ee
2 :e:
1FUNCTION:
1FC_U_TSKRES2:
1H_ASSIGN_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1H_AND_ROLES:
1H_AND_SKILLS:
1SH_H_WORK_LOCATION:
1PLS_INTEGER:
1H_START_DATE:
1H_FINISH_DATE:
1SH_H_EFFORT:
1SH_H_WORK:
1SH_H_EUNIT:
1SH_H_UNIT:
1SH_H_WORK_TYPE:
1SH_H_BITFLAG:
1SH_H_CONTOUR:
1SH_H_CONTOUR_TYPE:
1SH_H_OCCURRENCE:
1H_ASSIGN_STRING:
1H_REC_USER:
1RETURN:
1H_WORK_LOCATION:
1H_EFFORT:
1H_WORK:
1H_EUNIT:
1H_UNIT:
1H_WORK_TYPE:
1H_BITFLAG:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_OCCURRENCE:
1H_TASK_ID:
132:
1H_RES_ID:
1H_START_DT:
126:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_LAST_SUBMITTED:
1H_TSK_ASSIGNMENT_ID:
1H_PROJECT_ID:
1H_CALENDAR_ID:
1H_SECURITY_ID:
1H_RES_TYPE:
11:
1H_BIT_FLAG:
1H_FULL_NAME:
1255:
1H_NULL_STR:
1H_MIN_PER_DAY:
10:
1H_TYPE:
1H_PER_WEEK:
1H_CONSIDER:
1H_ROLLUP:
1H_CRI:
1H_TEMP_SC_STATE:
1H_TRANSFED_CRI:
1H_WORK_TODATE:
1H_TEMP_VAR:
1H_TEMP_SECURITY_ID:
1H_TEMP2_SECURITY_ID:
1H_SD:
1H_FD:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DURATION:
1H_PERCENT_UNITS:
1H_SCHED_WORK:
1H_PRIORITY:
1H_UPDATE:
1H_ZERO:
1H_RES_COST:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_TSKRES2(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
194:
1+:
1FPUT:
1               ENTER:: FC_U_TSKRES2(95) :: cplan.sql(7390) :: :
1PMO_CNST:
1>=:
1SC_BIT_30:
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1ELSIF:
1SC_BIT_28:
1SC_BIT_NOT_28:
10.00:
1=:
1PROJECT_ID:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1LAST_SUBMITTED:
1WORK_TODATE:
1TO_DATE:
1SUBSTR:
1SCHED_START:
1SCHED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT:n         PROJECT_ID,:n         TASK_ID,:n         RESOURCE_ID,:n     +
1    RESOURCE_TYPE,:n         LAST_SUBMITTED,:n         WORK_TODATE,:n        +
1 TO_DATE(SubStr(SCHED_START, 1, 10)),:n         TO_DATE(SubStr(SCHED_FINISH, +
11, 10)),:n         BILLABLE,:n         CAPITAL_EXPENSE,:n         REGULAR_COS+
1T,:n         REGULAR_RATE:n         INTO:n         h_project_id,:n         h_+
1task_id,:n         h_res_id,:n         h_res_type,:n         h_last_submitted+
1,:n         h_work_todate,:n         h_SD,:n         h_FD,:n         h_billab+
1le,:n         h_capital_expense,:n         h_reg_cost,:n         h_reg_sale:n+
1         FROM TASK_ASSIGNMENTS:n         WHERE TSK_ASSIGNMENT_ID = h_tsk_assi+
1gnment_id:
1PMO_DB2M:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1165:
1           EXCEPTION:: FC_U_TSKRES2(166) :: cplan.sql(7461) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1172:
1                EXIT:: FC_U_TSKRES2(173) :: cplan.sql(7468) :: :
1RECORD_NOT_FOUND:
1ELEMENT_ID:
1ELEMENT_TYPE:
1SECURITY_ID:
1CRI_SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1RES_ASSIGNMENT_ID:
1SELECT PROJECT_ID, ELEMENT_ID, RESOURCE_ID, ELEMENT_TYPE, :n         RESOURCE+
1_TYPE, SECURITY_ID, CASE WHEN CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END:n    +
1     INTO h_project_id, h_task_id, h_res_id, h_type,:n         h_res_type, h_+
1security_id, h_transfed_cri:n         FROM RESOURCE_ASSIGNMENTS :n         WH+
1ERE RES_ASSIGNMENT_ID = h_assign_id:
1192:
1           EXCEPTION:: FC_U_TSKRES2(193) :: cplan.sql(7488) :: :
1199:
1                EXIT:: FC_U_TSKRES2(200) :: cplan.sql(7495) :: :
1ISWBSTRANSFEREDDELIV:
1!=:
1204:
1                EXIT:: FC_U_TSKRES2(205) :: cplan.sql(7500) :: :
1TASK_ASSIGNMENT_ERROR:
1WORK_LOCATION:
1UPDATE RESOURCE_ASSIGNMENTS SET WORK_LOCATION = h_work_location:n         WHE+
1RE RES_ASSIGNMENT_ID = h_assign_id:
1FOUND:
1TRUE:
1100:
1224:
1           EXCEPTION:: FC_U_TSKRES2(225) :: cplan.sql(7520) :: :
1ISPROJECTTYPE:
1NOT:
1SELECT TSK_ASSIGNMENT_ID INTO h_tsk_assignment_id:n            FROM TASK_ASSI+
1GNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
1241:
1           EXCEPTION:: FC_U_TSKRES2(242) :: cplan.sql(7537) :: :
1SC_SQL_SUCCESS:
1248:
1                EXIT:: FC_U_TSKRES2(249) :: cplan.sql(7544) :: :
1RECORD_ALREADY_ASSIGNED:
1FC_AFTER_U_RES_ASSIGN:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1CALENDAR_ID:
1PRIORITY:
1TMT_WBS:
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), CALEND+
1AR_ID, PRIORITY:n      INTO h_min_per_day, h_per_week, h_calendar_id, h_prior+
1ity:n      FROM TMT_WBS WHERE ELEMENT_ID = h_project_id:
1270:
1           EXCEPTION:: FC_U_TSKRES2(271) :: cplan.sql(7566) :: :
1>:
15:
1*:
1IS NULL:
1SUM:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1DAY_YEAR:
1SELECT SUM(AVAILABLE_MIN) INTO h_effort FROM CALENDAR_DAY_OF_YEAR:n          +
1     WHERE ELEMENT_ID=h_project_id AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_star+
1t_date, 1, 10)) AND TO_DATE(SubStr(h_finish_date, 1, 10)):
1298:
1           EXCEPTION:: FC_U_TSKRES2(299) :: cplan.sql(7594) :: :
160:
12:
13:
1315:
1                EXIT:: FC_U_TSKRES2(316) :: cplan.sql(7611) :: :
1SC_BIT_NOT_30:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1BIT_FLAG:
1SELECT TSK_ASSIGNMENT_ID, UNRESOLVED_START, UNRESOLVED_FINISH, PLANNED_WORK+S+
1CHED_WORK, BIT_FLAG:n         INTO h_tsk_assignment_id, h_start_DT, h_finish_+
1DT, h_sched_work, h_bit_flag:n         FROM TASK_ASSIGNMENTS:n         WHERE +
1PROJECT_ID = h_project_id AND TASK_ID = h_project_id AND RESOURCE_ID = h_res_+
1id:
1338:
1           EXCEPTION:: FC_U_TSKRES2(339) :: cplan.sql(7634) :: :
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1BIT_OR:
1<:
1FC_DECLARE_PMO_TMP_SEARCH:
1SC_SRCH_FROM_PROJECT:
1FC_SEARCH_2:
1ETC:
1UPDATE TASK_ASSIGNMENTS SET ETC = h_effort:n                  WHERE RES_ASSIG+
1NMENT_ID = h_assign_id:
1389:
1           EXCEPTION:: FC_U_TSKRES2(390) :: cplan.sql(7685) :: :
1395:
1                EXIT:: FC_U_TSKRES2(396) :: cplan.sql(7691) :: :
1U_TSKRES2:
1110:
1RESOURCE_UNAVAILABLE:
1489:
1                EXIT:: FC_U_TSKRES2(490) :: cplan.sql(7785) :: :
1STATE:: :
0

0
0
af1
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 8f
a0 b0 3d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 90
:3 a0 b0 3f 90 :3 a0 b0 3f b4
:2 a0 2c 6a a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 51 a5 b a0 7e
a0 6b b4 2e :3 a0 6b :3 a0 51
a5 b :2 a0 6b a5 b 5a 51
a5 b d :4 a0 51 a5 b :2 a0
6b a5 b d a0 51 d a0
51 d a0 b7 :2 a0 51 a5 b
a0 7e a0 6b b4 2e :4 a0 51
a5 b :2 a0 6b a5 b 5a d
:4 a0 51 a5 b :2 a0 6b a5 b
5a d a0 51 d b7 19 :3 a0
51 a5 b d a0 51 d a0
51 d b7 :2 19 3c a0 51 d
a0 6e d a0 51 d a0 4d
d a0 4d d a0 4d d a0
4d d a0 51 d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d :1f a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c b7 :11 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 a0 b7 :3 a0
51 a5 b a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
:2 19 3c :5 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b a5 b
5a 7e 51 b4 2e 7e b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c b7 19 3c :3 a0
a5 b d b7 :2 19 3c :d a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e a0 7e b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d b7 19 3c b7
:d a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 :2 a0 51
a5 b 7e 51 b4 2e :3 a0 51
a5 b 7e 51 b4 2e d a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d a0 b7 19
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d b7 :2 19 3c b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e :4 a0 51
a5 b :2 a0 6b a5 b 5a d
a0 b7 :2 a0 :2 51 a5 b 7e 6e
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :12 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e 5a a 10
:4 a0 51 a5 b :2 a0 6b a5 b
5a d :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 :2 51 a5 b 7e 6e
b4 2e :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 19 3c
a0 51 d b7 19 3c b7 :2 a0
51 a5 b 7e 51 b4 2e :3 a0
6b :2 a0 51 a5 b :2 a0 6b a5
b 5a d b7 19 3c :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 :2 51
a5 b 7e 6e b4 2e a0 51
d b7 19 3c :2 a0 b4 2e d
:3 a0 6b d :20 a0 51 a5 b :4 51
a5 b d b7 19 3c :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c a0 51 65 b7 19 3c b7
:2 19 3c b7 19 3c b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 5a 52 10
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 51
a5 b a5 b 5a d b7 19
3c :18 a0 :2 51 a5 b d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 51
a5 b a5 b 5a d b7 19
3c :18 a0 :2 51 a5 b d b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
a 10 :2 a0 6b :2 a0 6b d b7
:2 19 3c :2 a0 6b 7e 51 b4 2e
:2 a0 6b 51 d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 a4 b1 11 68 4f
1d 17 b5 
af1
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 73 6f 37
7b 8c 80 84 88 6e 93 a8
9c a0 a4 6b af b8 b4 9b
c0 cd c9 98 d5 de da c8
e6 f3 ef c5 fb 104 100 ee
10c 119 115 eb 121 12a 126 114
132 13f 13b 111 147 150 14c 13a
158 16d 161 165 169 137 174 185
179 17d 181 160 18c 15d 191 195
199 19d 1ba 1a5 1a9 1b1 1b5 1a4
1da 1c5 1c9 1d1 1d5 1a1 1f6 1e1
1e5 1ed 1f1 1c4 216 201 205 20d
211 1c1 232 21d 221 229 22d 200
252 23d 241 249 24d 1fd 26e 259
25d 265 269 23c 28e 279 27d 285
289 239 2aa 295 299 2a1 2a5 278
2ca 2b5 2b9 2c1 2c5 275 2e6 2d1
2d5 2d8 2d9 2e1 2b4 303 2f1 2b1
2f5 2f6 2fe 2f0 320 30e 2ed 312
313 31b 30d 33d 32b 30a 32f 330
338 32a 359 348 34c 354 327 371
360 364 36c 347 38e 37c 344 380
381 389 37b 3ab 399 378 39d 39e
3a6 398 3c8 3b6 395 3ba 3bb 3c3
3b5 3e5 3d3 3b2 3d7 3d8 3e0 3d2
402 3f0 3cf 3f4 3f5 3fd 3ef 41f
40d 3ec 411 412 41a 40c 43c 42a
409 42e 42f 437 429 459 447 426
44b 44c 454 446 475 464 468 443
470 463 491 480 484 460 48c 47f
4ad 49c 4a0 47c 4a8 49b 4c9 4b8
4bc 498 4c4 4b7 4e5 4d4 4d8 4b4
4e0 4d3 501 4f0 4f4 4d0 4fc 4ef
51d 50c 510 4ec 518 50b 539 528
52c 508 534 527 555 544 548 524
550 543 571 560 564 540 56c 55f
58e 57c 55c 580 581 589 57b 5ab
599 578 59d 59e 5a6 598 5c7 5b6
5ba 5c2 595 5df 5ce 5d2 5da 5b5
5fb 5ea 5ee 5b2 5f6 5e9 617 606
60a 5e6 612 605 633 622 626 602
62e 621 64f 63e 642 61e 64a 63d
66b 65a 65e 63a 666 659 687 676
67a 656 682 675 6a3 692 696 672
69e 691 6bf 6ae 6b2 68e 6ba 6ad
6db 6ca 6ce 6aa 6d6 6c9 6f7 6e6
6ea 6c6 6f2 6e5 713 702 706 6e2
70e 701 72f 71e 722 6fe 72a 71d
736 73a 71a 73e 742 746 749 74e
74f 1 751 756 75a 75e 761 766
76a 76e 771 776 777 779 77e 781
785 786 78b 790 793 798 799 79e
7a1 7a5 7a6 7ab 7ae 7b3 7b4 7b9
7bc 7c1 7c2 7c7 7ca 7cf 7d0 7d5
7d8 7dc 7dd 7e2 7e5 7ea 7eb 7f0
7f3 7f8 7f9 7fe 801 806 807 80c
80f 813 814 819 81c 821 822 827
82a 82f 830 835 838 83c 840 844
845 847 84c 84d 84f 850 855 858
85d 85e 863 866 86b 86c 871 874
878 879 87e 881 886 887 88c 88f
894 895 89a 89d 8a2 8a3 8a8 8ab
8af 8b0 8b5 8b8 8bd 8be 8c3 8c6
8cb 8cc 8d1 8d4 8d8 8dc 8e0 8e1
8e3 8e8 8e9 8eb 8ec 8f1 8f4 8f9
8fa 8ff 902 906 90a 90e 90f 911
916 917 919 91a 91f 922 927 928
92d 930 934 938 93c 93d 93f 944
945 947 948 94d 950 955 956 95b
95e 962 966 96a 96b 96d 972 973
975 976 97b 97e 983 984 989 98c
990 994 998 999 99b 9a0 9a1 9a3
9a4 9a9 9ac 9b1 9b2 9b7 9ba 9be
9c2 9c6 9c7 9c9 9ce 9cf 9d1 9d2
9d7 9da 9df 9e0 9e5 9e8 9ec 9f0
9f4 9f5 9f7 9fc 9fd 9ff a00 a05
a08 a0d a0e a13 a16 a1a a1e a22
a23 a25 a2a a2b a2d a2e a33 a36
a3b a3c a41 a44 a48 a4c a50 a51
a53 a58 a59 a5b a5c a61 a64 a69
a6a a6f a72 a77 a78 a7d a80 a84
a85 a8a a8d a92 a93 a98 a9b aa0
aa1 aa6 aa9 aae aaf ab4 ab7 abb
abc ac1 ac4 ac9 aca acf ad2 ad7
ad8 add ade ae3 ae5 ae9 aec af0
af4 af7 afb aff b02 b05 b0a b0d
b10 b13 b14 b19 b1a 1 b1c b21
b25 b29 b2c b31 b36 b39 b3d b3e
b43 b44 b49 b4b b4f b52 b56 b5a
b5d b5e b60 b64 b67 b6b b6e b6f
b74 b78 b7c b80 b83 b87 b8b b8f
b92 b93 b95 b99 b9d ba0 ba1 ba3
ba6 ba9 baa bac bb0 bb4 bb8 bbc
bc0 bc3 bc4 bc6 bca bce bd1 bd2
bd4 bd8 bdc bdf be3 be7 bea bee
bf2 bf4 bf8 bfc bff c00 c02 c06
c09 c0d c10 c11 c16 c1a c1e c22
c26 c29 c2a c2c c30 c34 c37 c38
c3a c3d c41 c45 c49 c4d c51 c54
c55 c57 c5b c5f c62 c63 c65 c68
c6c c70 c73 c77 c79 c7d c81 c85
c89 c8c c8d c8f c93 c97 c9a c9e
ca2 ca5 ca9 cab caf cb3 cb6 cba
cbd cc1 cc5 cca cce cd2 cd5 cd9
cdd cde ce2 ce6 ce7 ceb cef cf0
cf4 cf8 cf9 cfd d01 d04 d08 d0c
d10 d13 d14 d16 d19 d1c d1d d22
d26 d2a d2e d32 d36 d3a d3e d42
d46 d4a d4e d52 d56 d5a d5e d62
d66 d6a d6e d72 d76 d7a d7e d82
d86 d8a d8e d92 d96 d9a d9e da2
da6 daa db6 dba dbe dc1 dc5 dc9
dcb dcf dd3 dd7 dda dde de2 de4
de5 dea 1 dee df2 df6 df9 dfd
e01 e05 e09 e0c e10 e14 e17 e1a
e1f e22 e25 e28 e29 e2e e2f 1
e31 e36 e3a e3e e41 e46 e4b e4e
e52 e53 e58 e5b e60 e61 e66 e69
e6e e6f e74 e77 e7b e7c e81 e84
e89 e8a e8f e92 e96 e9a e9d ea0
ea1 ea3 ea4 ea9 eaa eaf eb1 eb5
eb8 eba ebe ec0 ecc ece ed0 ed1
ed6 eda edc ee8 eea eee ef2 ef5
ef9 efc f00 f03 f04 f09 f0c f10
f14 f17 f1b f1f f22 f25 f2a f2d
f30 f33 f34 f39 f3a 1 f3c f41
f45 f49 f4c f51 f56 f59 f5d f5e
f63 f64 f69 f6b f6f f72 f76 f7a
f7e f81 f85 f87 f8b f8e f90 f94
f98 f9c fa0 fa4 fa8 fac fb0 fb4
fb8 fbc fc0 fc4 fc8 fcc fd0 fd4
fe0 fe4 fe8 feb fef ff3 ff5 ff9
ffd 1001 1004 1008 100c 100e 100f 1014
1 1018 101c 1020 1023 1027 102b 102f
1033 1036 103a 103e 1041 1044 1049 104c
104f 1052 1053 1058 1059 1 105b 1060
1064 1068 106b 1070 1075 1078 107c 107d
1082 1085 108a 108b 1090 1093 1098 1099
109e 10a1 10a5 10a6 10ab 10ae 10b3 10b4
10b9 10bc 10c0 10c4 10c7 10ca 10cb 10cd
10ce 10d3 10d4 10d9 10db 10df 10e2 10e4
10e8 10ea 10f6 10f8 10fa 10fb 1100 1104
1106 1112 1114 1118 111c 111f 1123 1126
112a 112d 112e 1133 1136 113a 113e 1141
1145 1149 114c 114f 1154 1157 115a 115d
115e 1163 1164 1 1166 116b 116f 1173
1176 117b 1180 1183 1187 1188 118d 118e
1193 1195 1199 119c 11a0 11a4 11a8 11ab
11af 11b3 11b5 11b9 11bd 11c1 11c4 11c5
11c7 11c8 11ca 11cd 11d0 11d1 11d6 11da
11de 11e1 11e5 11e9 11ec 11ef 11f4 11f7
11fa 11fd 11fe 1203 1204 1 1206 120b
120f 1213 1216 121b 1220 1223 1227 1228
122d 122e 1233 1235 1239 123c 1240 1244
1248 124b 124f 1251 1255 1259 125c 1260
1264 1268 126c 1270 127c 1280 1285 1289
128c 128d 1292 1296 129a 129d 12a0 12a4
12a6 12aa 12ae 12b1 12b4 12b8 12ba 12be
12c2 12c5 12c7 12cb 12cf 12d3 12d6 12da
12de 12e0 12e1 12e6 1 12ea 12ee 12f2
12f5 12f9 12fd 1301 1305 1308 130c 1310
1313 1316 131b 131e 1321 1324 1325 132a
132b 1 132d 1332 1336 133a 133d 1342
1347 134a 134e 134f 1354 1357 135c 135d
1362 1365 136a 136b 1370 1373 1377 1378
137d 1380 1385 1386 138b 138e 1392 1396
1399 139c 139d 139f 13a0 13a5 13a6 13ab
13ad 13b1 13b4 13b6 13ba 13bc 13c8 13ca
13cc 13cd 13d2 13d6 13d8 13e4 13e6 13ea
13ee 13f2 13f5 13f6 13f8 13f9 13fb 13fe
1401 1404 1405 140a 140d 140e 1413 1417
141b 141f 1423 1427 1433 1437 143b 143e
1442 1446 1448 144c 1450 1454 1457 145b
145f 1461 1462 1467 1 146b 146f 1473
1476 147a 147e 1482 1486 1489 148d 1491
1494 1497 149c 149f 14a2 14a5 14a6 14ab
14ac 1 14ae 14b3 14b7 14bb 14be 14c3
14c8 14cb 14cf 14d0 14d5 14d8 14dd 14de
14e3 14e6 14eb 14ec 14f1 14f4 14f8 14f9
14fe 1501 1506 1507 150c 150f 1513 1517
151a 151d 151e 1520 1521 1526 1527 152c
152e 1532 1535 1537 153b 153d 1549 154b
154d 154e 1553 1557 1559 1565 1567 156b
156f 1572 1576 1579 157d 1580 1581 1586
1589 158d 1591 1594 1598 159c 159f 15a2
15a7 15aa 15ad 15b0 15b1 15b6 15b7 1
15b9 15be 15c2 15c6 15c9 15ce 15d3 15d6
15da 15db 15e0 15e1 15e6 15e8 15ec 15ef
15f3 15f7 15fb 15fe 1602 1604 1608 160b
160d 1611 1614 1618 161c 1620 1621 1623
1627 1629 162d 1631 1634 1638 163c 1640
1644 1648 164c 1650 1654 1658 165c 1660
1664 1668 1674 1678 167c 167f 1683 1687
1689 168d 1691 1695 1698 169c 16a0 16a2
16a3 16a8 1 16ac 16b0 16b4 16b7 16bb
16bf 16c3 16c7 16ca 16ce 16d2 16d5 16d8
16dd 16e0 16e3 16e6 16e7 16ec 16ed 1
16ef 16f4 16f8 16fc 16ff 1704 1709 170c
1710 1711 1716 1719 171e 171f 1724 1727
172c 172d 1732 1735 1739 173a 173f 1742
1747 1748 174d 1750 1754 1758 175b 175e
175f 1761 1762 1767 1768 176d 176f 1773
1776 1778 177c 177e 178a 178c 178e 178f
1794 1798 179a 17a6 17a8 17ac 17b0 17b3
17b4 17b6 17b9 17bc 17bd 17c2 17c6 17ca
17cd 17ce 17d0 17d3 17d6 17d7 17dc 17df
17e3 17e7 17ea 17eb 17ed 17f0 17f3 17f4
17f9 1 17fc 1801 1805 1809 180d 1810
1811 1813 1816 181a 181e 1821 1822 1824
1825 182a 182e 1830 1834 1837 183b 183f
1842 1843 1845 1848 184b 184c 1851 1855
1858 1859 185e 1861 1865 1869 186c 186d
186f 1872 1875 1876 187b 187f 1883 1887
188a 188b 188d 1890 1894 1898 189b 189c
189e 189f 18a4 18a8 18aa 18ae 18b1 18b3
18b7 18bb 18bf 18c3 18c7 18cb 18cf 18d3
18d7 18db 18df 18e3 18e7 18f3 18f7 18fb
18fe 1902 1906 1908 190c 1910 1914 1917
191b 191f 1921 1922 1927 1 192b 192f
1933 1936 193a 193e 1942 1946 1949 194d
1951 1954 1957 195c 195f 1962 1965 1966
196b 196c 1 196e 1973 1977 197b 197e
1983 1988 198b 198f 1990 1995 1998 199d
199e 19a3 19a6 19ab 19ac 19b1 19b4 19b8
19b9 19be 19c1 19c6 19c7 19cc 19cf 19d3
19d7 19da 19dd 19de 19e0 19e1 19e6 19e7
19ec 19ee 19f2 19f5 19f7 19fb 19fd 1a09
1a0b 1a0d 1a0e 1a13 1a17 1a19 1a25 1a27
1a29 1a2d 1a31 1a34 1a36 1a3a 1a3e 1a41
1a42 1a44 1a47 1a4a 1a4b 1a50 1a54 1a58
1a5c 1a5f 1a60 1a62 1a65 1a68 1a69 1a6e
1a72 1a76 1a78 1a7c 1a80 1a83 1a84 1a86
1a89 1a8c 1a8d 1a92 1a96 1a9a 1a9e 1aa1
1aa2 1aa4 1aa7 1aab 1aaf 1ab2 1ab3 1ab5
1ab6 1abb 1abf 1ac3 1ac5 1ac9 1acd 1ad1
1ad4 1ad5 1ad7 1ada 1add 1ade 1ae3 1ae7
1aeb 1aef 1af2 1af3 1af5 1af8 1afc 1b00
1b03 1b04 1b06 1b07 1b0c 1b10 1b12 1b16
1b1a 1b1d 1b1f 1b23 1b27 1b2a 1b2e 1b32
1b35 1b36 1b38 1b3b 1b3e 1b3f 1b44 1b48
1b4c 1b4f 1b53 1b57 1b5a 1b5d 1b62 1b65
1b68 1b6b 1b6c 1b71 1b72 1 1b74 1b79
1b7d 1b81 1b84 1b89 1b8e 1b91 1b95 1b96
1b9b 1b9c 1ba1 1ba3 1ba7 1baa 1bae 1bb2
1bb6 1bb9 1bbd 1bbf 1bc3 1bc6 1bc8 1bcc
1bcf 1bd3 1bd7 1bda 1bdb 1bdd 1be0 1be3
1be4 1be9 1bed 1bf1 1bf5 1bf9 1bfc 1bfd
1bff 1c03 1c07 1c0a 1c0b 1c0d 1c10 1c14
1c18 1c1a 1c1e 1c22 1c25 1c28 1c29 1c2b
1c2e 1c33 1c34 1c39 1c3c 1c40 1c44 1c47
1c48 1c4a 1c4d 1c50 1c51 1c56 1 1c59
1c5e 1c62 1c66 1c6a 1c6e 1c72 1c76 1c7a
1c7e 1c82 1c86 1c8a 1c8e 1c92 1c96 1c9a
1c9e 1ca2 1ca6 1cb2 1cb6 1cba 1cbd 1cc1
1cc5 1cc7 1ccb 1ccf 1cd3 1cd6 1cda 1cde
1ce0 1ce1 1ce6 1 1cea 1cee 1cf2 1cf5
1cf9 1cfd 1d01 1d05 1d08 1d0c 1d10 1d13
1d16 1d1b 1d1e 1d21 1d24 1d25 1d2a 1d2b
1 1d2d 1d32 1d36 1d3a 1d3d 1d42 1d47
1d4a 1d4e 1d4f 1d54 1d57 1d5c 1d5d 1d62
1d65 1d6a 1d6b 1d70 1d73 1d77 1d78 1d7d
1d80 1d85 1d86 1d8b 1d8e 1d92 1d96 1d99
1d9c 1d9d 1d9f 1da0 1da5 1da6 1dab 1dad
1db1 1db4 1db6 1dba 1dbc 1dc8 1dca 1dcc
1dcd 1dd2 1dd6 1dd8 1de4 1de6 1dea 1dee
1df1 1df5 1df8 1dfc 1dff 1e00 1e05 1e08
1e0c 1e0f 1e10 1e15 1 1e18 1e1d 1e21
1e25 1e29 1e2d 1e30 1e31 1e33 1e37 1e3b
1e3e 1e3f 1e41 1e44 1e48 1e4c 1e50 1e53
1e57 1e5b 1e5e 1e5f 1e61 1e64 1e67 1e68
1e6d 1e70 1e74 1e78 1e7b 1e7f 1e83 1e86
1e87 1e89 1e8c 1e8f 1e90 1e95 1 1e98
1e9d 1ea1 1ea5 1ea8 1eab 1eac 1eae 1eb1
1eb6 1eb7 1ebc 1ec0 1ec4 1ec7 1ec8 1eca
1ecd 1ed0 1ed1 1ed6 1eda 1edd 1ee1 1ee3
1ee7 1eea 1eee 1ef1 1ef5 1ef7 1efb 1efe
1f00 1f04 1f08 1f0b 1f0c 1f0e 1f11 1f14
1f15 1f1a 1f1e 1f22 1f26 1f29 1f2d 1f31
1f34 1f35 1f37 1f3b 1f3f 1f42 1f43 1f45
1f48 1f4c 1f4e 1f52 1f55 1f59 1f5d 1f60
1f61 1f63 1f67 1f6a 1f6e 1f71 1f72 1f74
1f75 1f7a 1f7e 1f82 1f85 1f86 1f88 1f8b
1f8e 1f8f 1f94 1f98 1f9c 1f9f 1fa3 1fa7
1faa 1fab 1fad 1fb0 1fb3 1fb4 1 1fb9
1fbe 1fc2 1fc6 1fc9 1fcc 1fcd 1fcf 1fd2
1fd7 1fd8 1fdd 1fe1 1fe4 1fe8 1fea 1fee
1ff1 1ff5 1ff9 1ffa 1fff 2003 2007 200b
200f 2012 2016 201a 201e 2022 2026 202a
202e 2032 2036 203a 203e 2042 2046 204a
204e 2052 2056 205a 205e 2062 2066 206a
206e 2072 2076 207a 207e 2082 2086 208a
208e 2092 2096 2099 209a 209c 209f 20a2
20a5 20a8 20a9 20ab 20af 20b1 20b5 20b8
20bc 20c0 20c4 20c8 20cc 20d8 20dc 20e1
20e5 20e8 20e9 20ee 20f2 20f6 20f9 20fc
2100 2102 2106 210a 210d 2110 2114 2116
211a 211e 2121 2123 2127 212b 212f 2132
2136 213a 213c 213d 2142 1 2146 214a
214e 2151 2155 2159 215d 2161 2164 2168
216c 216f 2172 2177 217a 217d 2180 2181
2186 2187 1 2189 218e 2192 2196 2199
219e 21a3 21a6 21aa 21ab 21b0 21b3 21b8
21b9 21be 21c1 21c6 21c7 21cc 21cf 21d3
21d4 21d9 21dc 21e1 21e2 21e7 21ea 21ee
21f2 21f5 21f8 21f9 21fb 21fc 2201 2202
2207 2209 220d 2210 2212 2216 2218 2224
2226 2228 2229 222e 2232 2234 2240 2242
2246 224a 224d 2251 2255 2258 225b 2260
2263 2266 2269 226a 226f 2270 1 2272
2277 227b 227f 2282 2287 228c 228f 2293
2294 2299 229a 229f 22a1 22a5 22a8 22ac
22af 22b3 22b5 22b9 22bc 22be 22c2 22c6
22c9 22cb 22cf 22d2 22d4 22d8 22dc 22df
22e3 22e7 22ea 22eb 22ed 22f0 22f3 22f4
22f9 22fc 2300 2304 2307 2308 230a 230e
2311 2315 2318 2319 231b 231c 2321 1
2324 2329 232d 2331 2334 2335 2337 233a
233d 233e 2343 2347 234b 234f 2352 2356
235a 235d 235e 2360 2364 2368 236b 236c
236e 236f 2371 2374 2378 237a 237e 2381
2385 2389 238d 2391 2395 2399 239d 23a1
23a5 23a9 23ad 23b1 23b5 23b9 23bd 23c1
23c5 23c9 23cd 23d1 23d5 23d9 23dd 23e1
23e4 23e7 23e8 23ea 23ee 23f2 23f4 23f8
23fc 23ff 2400 2402 2405 2408 2409 240e
2412 2416 2419 241a 241c 241f 2422 2423
2428 242c 2430 2434 2437 243b 243f 2442
2443 2445 2449 244d 2450 2451 2453 2454
2456 2459 245d 245f 2463 2466 246a 246e
2472 2476 247a 247e 2482 2486 248a 248e
2492 2496 249a 249e 24a2 24a6 24aa 24ae
24b2 24b6 24ba 24be 24c2 24c6 24c9 24cc
24cd 24cf 24d3 24d5 24d9 24dd 24e0 24e4
24e8 24eb 24ec 24ee 24f1 24f4 24f5 24fa
24fe 2502 2505 2509 250d 2510 2514 2518
251a 251e 2522 2525 2526 2528 252b 252e
252f 2534 2538 253c 253f 2540 2542 2545
2548 2549 1 254e 2553 2557 255b 255e
2562 2566 2569 256d 256f 2573 2577 257a
257e 2582 2585 2588 258b 258c 2591 2595
2599 259c 259f 25a3 25a5 25a9 25ac 25b0
25b4 25b7 25bb 25bf 25c2 25c5 25ca 25cd
25d0 25d3 25d4 25d9 25da 1 25dc 25e1
25e5 25e9 25ec 25f1 25f6 25f9 25fd 25fe
2603 2606 260b 260c 2611 2614 2619 261a
261f 2622 2626 262a 262d 262e 2633 2634
2639 263b 263f 2642 2646 264a 264e 2651
2655 2657 265b 265d 2669 266d 266f 2670
2679 
af1
2
0 1 a 6 15 19 20 :3 6
15 19 20 :3 6 16 1a 21 :3 6
19 :3 6 16 1a 21 :3 6 17 1b
22 :3 6 12 :3 6 10 :3 6 11 :3 6
10 :3 6 15 :3 6 13 :3 6 13 :3 6
18 :3 6 16 :3 6 19 1d 24 :3 6
14 18 1f :2 6 1 3 a :2 1
4 :2 14 23 14 :2 4 :2 d 1c d
:2 4 :2 b 1a b :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 10 1f 10
:2 4 :2 e 1d e :2 4 :2 e 1d e
:2 4 :2 13 22 13 :2 4 :2 11 20 11
:2 4 e 17 16 :2 e :2 4 d 16
15 :2 d :2 4 f 18 17 :2 f :2 4
10 19 18 :2 10 :2 4 :3 10 :2 4 :3 15
:2 4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 12 1b 1a :2 12 :2 4
12 1b 1a :2 12 :2 4 f 18 17
:2 f :2 4 f 18 17 :2 f :2 4 10
19 18 :2 10 :2 4 f 18 17 :2 f
:2 4 :2 12 21 12 :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 a 19 a
:2 4 :2 14 23 14 :2 4 :2 13 22 13
:2 4 :2 12 21 12 :2 4 :2 f 1e f
:2 4 17 20 1f :2 17 :2 4 18 21
20 :2 18 :2 4 :3 9 :2 4 :3 9 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 :2 f
1e f :2 4 :2 16 25 16 :2 4 :2 11
20 11 :2 4 :2 f 1e f :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 :2 f
1e f :2 4 :2 d 1c d :2 4 :2 b
1a b :2 4 :2 f 19 f 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 54 5a 5d :2 54
6b 81 8 :2 6b d 10 :2 6b 1c
1f :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 2a 2d :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 2b
2e :2 6b b e :2 6b 13 16 1f
27 :2 1f 3c :2 16 :2 6b b e :2 6b
13 16 :2 6b 1b 1e :2 6b 2b 2e
:2 6b b e :2 6b 13 16 :2 6b 1b
1e :2 6b 2c 2f :2 6b b e :2 6b
13 16 1f 27 :2 1f 35 :2 16 :2 6b
b e :2 6b 13 16 1f 27 :2 1f
33 :2 16 :2 6b b e :2 6b 13 16
1f 27 :2 1f 34 :2 16 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 33 :2 16
:2 6b b e :2 6b 13 16 1f 27
:2 1f 38 :2 16 :2 6b b e :2 6b 13
16 1f 27 :2 1f 36 :2 16 :2 6b b
e :2 6b 13 16 1f 27 :2 1f 36
:2 16 :2 6b b e :2 6b 13 16 1f
27 :2 1f 3b :2 16 :2 6b b e :2 6b
13 16 1f 27 :2 1f 39 :2 16 :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 2e 31 :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 29 2c :2 6b
31 34 :2 6b :2 7 4a :2 4 7 :2 11
23 :2 2d 39 3c 4c 4e 4f :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:2 7 52 :2 4 7 10 1b :2 7 21
1e :2 2a :2 1e 7 10 :2 19 25 2c
35 40 :2 2c 44 :2 4d :2 25 24 5c
:2 10 :2 7 15 1c 25 30 :2 1c 34
:2 3d :2 15 :2 7 14 :2 7 13 7 4
34 a 13 1e :2 a 24 21 :2 2d
:2 21 7 14 1b 24 2f :2 1b 33
:2 3c :2 14 13 :2 7 15 1c 25 30
:2 1c 34 :2 3d :2 15 14 :2 7 15 7
37 34 7 15 1e 29 :2 15 :2 7
14 :2 7 13 7 :5 4 12 :2 4 12
:2 4 15 :2 4 18 :2 4 c :2 4 c
:2 4 12 :2 4 12 4 7 10 1b
:2 7 1e 20 :2 1e 7 1e 7 :7 a
12 19 a 12 19 :10 a f 10
24 fffa a :2 13 1f a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8c 8f :2 27 97 9a
:2 27 a6 a9 b0 b9 bc :2 a9 :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 22
b :2 14 1f 1d :2 28 :2 1d a d
:2 17 29 :2 33 3f 42 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 63 66
:2 24 :2 d 59 :3 a 11 :2 1a a 38
:2 7 22 11 1d 29 36 a 19
30 f 1d 28 32 a 16 25
f 10 24 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 4 b :2 14 1f 1d :2 28 :2 1d a
d :2 17 29 :2 33 3f 42 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 63
66 :2 24 :2 d 59 :3 a 11 :2 1a a
7 38 d 22 2b 33 :2 22 :2 d
37 3a :2 37 d :2 17 29 :2 33 3f
42 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 63 66 :2 24 :2 d 59 :3 a
11 :2 1a a 3c 38 :2 7 11 2a
3a 10 24 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 4 f 1d 26 2e
:2 1d :2 f e 33 36 :2 33 :3 a 14
2b 12 29 3d :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5c 5d :2 59 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :3 38 e :2 17 22 20 :2 2b :2 20
d 10 :2 1a 2c :2 36 42 45 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 :2 10 5c :3 d 14 :2 1d
d 3b :2 a 38 :3 7 1a 30 :2 1a
7 :4 4 e 17 2d 36 4e 5b
c 1b 27 36 c 1a 27 :2 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 53 56
57 :2 53 :2 29 :3 d :2 13 18 24 63
66 :2 24 73 76 :2 24 7a 7d :2 24
89 8c :2 24 94 97 :2 24 a3 a6
ad b6 b9 :2 a6 :2 24 :2 d 5a :2 a
:2 7 :4 13 :2 7 4 :3 1 7 10 1a
:2 7 1d 1f :2 1d b 14 1c :2 b
1f 21 :2 1f a 29 32 3a :2 29
3d 3f :2 3d 28 :3 a 14 1d 2c
:2 14 2f 31 3a 42 :2 31 :2 14 a
42 :2 7 a 13 1d :2 a 20 22
:2 20 :4 e d 10 19 21 :2 10 24
26 :2 24 10 1c 25 33 :2 1c 36
38 41 49 :2 38 :2 1c 10 28 :2 d
25 17 1b 2f 3d 16 21 32
43 4b 52 6c 74 7b :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5c 5f 60
:2 5c :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :7 a 24 d 16 1f
:2 d 22 24 :2 22 d 19 22 2c
:2 19 2f 31 :2 19 d a 26 10
19 22 :2 10 25 27 :2 25 d 19
22 31 :2 19 34 36 3f 49 :2 36
:2 19 d a 29 26 10 19 22
:2 10 25 27 :2 25 d 19 22 2e
:2 19 31 33 3c 46 :2 33 :2 19 d
29 26 :2 a :4 7 a 13 1d :2 a
20 22 :2 20 d :2 17 29 :2 33 3f
42 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 63 66 :2 24 :2 d 59 :3 a
11 :2 1a a 24 :2 7 21 :2 4 7
10 1b :2 7 1e 20 :2 1e 7 15
1c 25 30 :2 1c 34 :2 3d :2 15 14
7 4 22 b 12 1e 21 :2 b
24 26 :2 24 a 30 39 46 :2 30
49 4b :2 49 2f :2 a 11 24 36
49 56 62 f 24 30 3d 4b
f 10 1d 2e 38 49 57 :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 4e b :2 14 1f
1d :2 28 :2 1d a :4 3d 3c :3 a 18
1f 28 33 :2 1f 37 :2 40 :2 18 17
a e :2 19 21 2f 3b :2 e 3f
42 :2 3f d 4a :2 55 5d 12 21
:2 4a 25 28 :2 25 49 :2 d 10 17
23 26 :2 10 29 2b :2 29 13 1c
26 :2 13 29 2b :2 29 13 20 13
2d :3 10 1f 10 2f :2 d 2b 10
19 24 :2 10 27 29 :2 27 10 1f
:2 28 2f 38 44 :2 2f 48 :2 51 :2 1f
1e 10 2b :2 d 10 19 27 :2 10
2c 2a 35 3f :2 2c :2 2a 13 1c
2a :2 13 2d 2f :2 2d 35 :2 40 48
56 63 :2 35 67 6a :2 67 :2 13 16
1d 29 2c :2 16 2f 31 :2 2f 16
22 16 35 :3 13 :3 26 :2 13 21 :2 2a
:2 13 26 32 3f 4d 58 62 6e
22 2f 3d 49 55 22 2f 37
45 4d 56 5e 22 2e 3a 47
52 22 30 3a 49 55 22 2b
3a :2 22 3e 41 47 4d :2 26 13
6c :2 10 1a 2f 35 19 2d 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5f 62 63 :2 5f :2 35 :3 19 :2 1f
24 30 6f 72 :2 30 7f 82 :2 30
86 89 :2 30 95 98 :2 30 a0 a3
:2 30 af b2 b9 c2 c5 :2 b2 :2 30
:2 19 66 :2 16 :2 13 :4 1f :2 13 10 :3 42
13 :2 1d 2f :2 39 45 48 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 69
6c :2 2a :2 13 5f :3 10 17 10 42
:2 d :4 a 5e :2 7 4e 22 :2 4 8
11 1c :2 8 1f 21 :2 1f 7 28
31 3f :2 28 44 42 4d 5c :2 44
:2 42 27 :2 7 a 13 1d :2 a 20
23 :2 20 a 18 :2 21 28 31 3c
:2 28 40 49 53 :2 40 :2 18 17 a
25 :3 7 1a 24 31 3f 4a 54
20 2e 3c 4b 55 5d 20 28
34 41 4c 57 20 2e 3a 4b
57 20 26 :2 1a 7 4 60 a
13 1e :2 a 21 23 :2 21 a 13
1d :2 a 20 23 :2 20 a 18 :2 21
28 31 3c :2 28 40 49 53 :2 40
:2 18 17 a 25 :3 7 1a 24 39
47 52 5c 20 2e 3c 4b 55
5d 20 28 34 41 4c 57 20
2e 3a 4b 57 20 26 :2 1a 7
25 60 :2 4 7 10 21 :2 7 24
26 :2 24 7 :2 10 1c :2 25 7 4
2a a 13 24 :2 a 27 2a :2 27
30 39 4a :2 30 4d 50 :2 4d :2 a
7 :2 10 1c :2 25 7 54 2a :2 4
7 :2 10 19 1b :2 19 7 :2 10 1c
7 1f :2 4 7 :2 11 23 :2 2d 39
3c 4c 4f 50 :2 4c :2 23 :3 7 :2 d
12 1e 5d 60 :2 1e 6d 70 :2 1e
74 77 :2 1e 81 84 :2 8d :2 1e :2 7
53 :3 4 b :2 14 4 :9 1 
af1
4
0 :2 1 :6 3 :6 4
:6 5 :4 6 :6 7 :6 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :6 12 :6 13 2
:2 14 :2 1 :6 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:7 20 :7 21 :7 22 :7 23
:5 24 :5 25 :7 26 :7 27
:7 28 :7 29 :7 2a :7 2b
:7 2c :7 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:7 38 :7 39 :5 3a :5 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:b 49 :11 4a 4b :2 4a
:2 4b :2 4a :2 4b :2 4a
:2 4c :2 4a :2 4c :2 4a
:2 4c :2 4a :2 4c :2 4a
:2 4d :2 4a :2 4d :2 4a
:2 4d :2 4a :2 4d :2 4a
:2 4e :2 4a :9 4e :2 4a
:2 4f :2 4a :2 4f :2 4a
:2 4f :2 4a :2 4f :2 4a
:2 50 :2 4a :2 50 :2 4a
:2 50 :2 4a :2 50 :2 4a
:2 51 :2 4a :9 51 :2 4a
:2 52 :2 4a :9 52 :2 4a
:2 53 :2 4a :9 53 :2 4a
:2 54 :2 4a :9 54 :2 4a
:2 55 :2 4a :9 55 :2 4a
:2 56 :2 4a :9 56 :2 4a
:2 57 :2 4a :9 57 :2 4a
:2 58 :2 4a :9 58 :2 4a
:2 59 :2 4a :9 59 :2 4a
:2 5a :2 4a :2 5a :2 4a
:2 5a :2 4a :2 5a :2 4a
:2 5b :2 4a :2 5b :2 4a
:2 5b :2 4a :2 5b :2 4a
:2 5b :4 4a :3 49 :11 5e
:b 5f :3 5e :b 64 :14 65
:d 67 :3 68 :3 69 6a
64 :b 6a :e 6b :e 6d
:3 6f 6a 64 :7 71
:3 72 :3 73 70 :3 64
:3 76 :3 77 :3 78 :3 79
:3 7a :3 7b :3 7c :3 7d
:9 7f :3 80 83 84
85 86 87 88
:3 89 :3 8a 8b 8c
8d 8e 90 91
92 93 94 95
96 97 98 99
9a 9b 9c :2 9d
83 :5 9e 81 a0
:5 a1 :3 a0 :2 a2 :5 a4
:11 a5 :24 a6 :3 a5 :2 a3
:6 a2 9f :3 7f :a ab
:11 ac :b ad :3 ac :5 af
:3 ab 7f :4 b3 :3 b4
:4 b5 :3 b6 b7 :2 b8
b3 :5 b9 b2 bb
:5 bc :3 bb :2 bd :5 bf
:11 c0 :24 c1 :3 c0 :2 be
:6 bd ba :3 b1 :a c6
:11 c7 :b c8 :3 c7 :5 ca
cb c6 :c cb :11 cc
:b cd :3 cc :5 cf cb
:3 c6 :3 d3 :2 d4 d3
:6 d5 :5 d6 d5 :5 d8
d7 :3 d5 d2 db
:5 dc :3 db :2 dd :5 df
:11 e0 :24 e1 :3 e0 :2 de
:6 dd da :3 b1 :10 e6
:2 e8 :3 e9 e8 :5 ea
e7 ec :5 ed :3 ec
:2 ee :5 f0 :11 f1 :24 f2
:3 f1 :2 ef :6 ee eb
:3 e6 :a f7 :11 f8 :b f9
:3 f8 :5 fb :3 f7 :3 e6
:6 ff b1 :3 7f :6 104
:4 105 :3 106 104 :5 107
103 109 :5 10a :3 109
:2 10b :5 10d :11 10e :24 10f
:3 10e :2 10c :6 10b 108
:3 48 :9 114 :16 115 :f 116
:3 115 :9 119 :5 11b :9 11c
:f 11d :3 11c 11b :4 121
:9 122 121 :5 123 120
125 :5 126 :3 125 :2 127
:5 129 :11 12a :24 12b :3 12a
:2 128 :6 127 124 :4 11f
:3 11b 119 :9 131 :b 132
133 131 :9 133 :f 134
135 133 131 :9 135
:f 136 135 :3 131 130
:3 119 :9 13a :11 13b :b 13c
:3 13b :5 13e :3 13a :3 114
:9 142 :e 143 145 142
:17 145 :6 147 :5 148 149
:6 14a 147 :5 14b 146
14d :5 14e :3 14d :2 14f
:5 151 :11 152 :24 153 :3 152
:2 150 :6 14f 14c :3 145
:11 158 :e 159 :11 15b :2 15c
:2 15b :4 15c :3 15b :a 15d
:9 15e :3 15f :3 15e :3 161
:3 15d 15c :9 164 :10 165
:3 164 :d 168 :17 169 :a 16a
:3 16b :3 16a :5 16d :5 16e
:8 16f :5 170 :7 171 :5 172
:5 173 :9 174 :3 16f :3 169
:3 178 :2 179 178 :6 17a
:5 17b 17a :5 17d 17c
:3 17a 177 180 :5 181
:3 180 :2 182 :5 184 :11 185
:24 186 :3 185 :2 183 :6 182
17f :3 168 :11 18b :b 18c
:3 18b :3 18e :3 168 163
:3 15b :3 158 145 :3 142
:1a 194 :9 195 :12 196 :3 195
:7 19a :6 19b :6 19c :5 19d
:2 19e :3 19a 19f 194
:9 19f :9 1a0 :12 1a1 :3 1a0
:7 1d7 :6 1d8 :6 1d9 :5 1da
:2 1db :3 1d7 19f :3 194
:9 1df :7 1e0 1e1 1df
:14 1e1 :7 1e2 1e1 :3 1df
:7 1e5 :5 1e6 :3 1e5 :11 1e9
:19 1ea :3 1e9 :5 1ec :2 48
:7 1 
267b
4
:3 0 1 :3 0 2
:a 0 aec 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
6 :3 0 8 :5 0
1 13 12 :3 0
d 98 0 b
a :3 0 9 :7 0
17 16 :3 0 4
:3 0 5 :3 0 6
:3 0 b :5 0 1
1d 1c :3 0 11
c5 0 f 4
:3 0 5 :3 0 6
:3 0 c :5 0 1
23 22 :3 0 a
:3 0 d :7 0 27
26 :3 0 15 eb
0 13 a :3 0
e :7 0 2b 2a
:3 0 a :3 0 f
:7 0 2f 2e :3 0
19 111 0 17
a :3 0 10 :7 0
33 32 :3 0 a
:3 0 11 :7 0 37
36 :3 0 1d 137
0 1b a :3 0
12 :7 0 3b 3a
:3 0 a :3 0 13
:7 0 3f 3e :3 0
21 15d 0 1f
a :3 0 14 :7 0
43 42 :3 0 a
:3 0 15 :7 0 47
46 :3 0 25 :2 0
23 4 :3 0 5
:3 0 6 :3 0 16
:5 0 1 4d 4c
:3 0 4 :3 0 5
:3 0 6 :3 0 17
:5 0 1 53 52
:3 0 18 :3 0 a
:3 0 55 57 0
aec 2 58 :2 0
39 1c1 0 37
a :3 0 5b :7 0
9 :3 0 5f 5c
5d aea 0 19
:6 0 3d 1fd 0
3b a :3 0 61
:7 0 d :3 0 65
62 63 aea 0
1a :6 0 a :3 0
67 :7 0 e :3 0
6b 68 69 aea
0 1b :6 0 41
239 0 3f a
:3 0 6d :7 0 f
:3 0 71 6e 6f
aea 0 1c :6 0
a :3 0 73 :7 0
10 :3 0 77 74
75 aea 0 1d
:6 0 45 275 0
43 a :3 0 79
:7 0 11 :3 0 7d
7a 7b aea 0
1e :6 0 a :3 0
7f :7 0 12 :3 0
83 80 81 aea
0 1f :6 0 49
2b1 0 47 a
:3 0 85 :7 0 13
:3 0 89 86 87
aea 0 20 :6 0
a :3 0 8b :7 0
14 :3 0 8f 8c
8d aea 0 21
:6 0 24 :2 0 4d
a :3 0 91 :7 0
15 :3 0 95 92
93 aea 0 22
:6 0 6 :3 0 24
:2 0 4b 97 99
:6 0 9c 9a 0
aea 0 23 :6 0
27 :2 0 51 6
:3 0 4f 9e a0
:6 0 a3 a1 0
aea 0 25 :6 0
27 :2 0 55 6
:3 0 53 a5 a7
:6 0 aa a8 0
aea 0 26 :6 0
5b 344 0 59
6 :3 0 57 ac
ae :6 0 b1 af
0 aea 0 28
:6 0 24 :2 0 5d
2a :3 0 b3 :7 0
b6 b4 0 aea
0 29 :6 0 2a
:3 0 b8 :7 0 bb
b9 0 aea 0
2b :6 0 24 :2 0
61 6 :3 0 5f
bd bf :6 0 c2
c0 0 aea 0
2c :6 0 24 :2 0
65 6 :3 0 63
c4 c6 :6 0 c9
c7 0 aea 0
2d :6 0 24 :2 0
69 6 :3 0 67
cb cd :6 0 d0
ce 0 aea 0
2e :6 0 31 :2 0
6d 6 :3 0 6b
d2 d4 :6 0 d7
d5 0 aea 0
2f :6 0 31 :2 0
71 6 :3 0 6f
d9 db :6 0 de
dc 0 aea 0
30 :6 0 34 :2 0
75 6 :3 0 73
e0 e2 :6 0 e5
e3 0 aea 0
32 :6 0 31 :2 0
79 6 :3 0 77
e7 e9 :6 0 ec
ea 0 aea 0
33 :6 0 37 :2 0
7d 6 :3 0 7b
ee f0 :6 0 f3
f1 0 aea 0
35 :6 0 37 :2 0
7f a :3 0 f5
:7 0 f9 f6 f7
aea 0 36 :6 0
37 :2 0 81 a
:3 0 fb :7 0 ff
fc fd aea 0
38 :6 0 37 :2 0
83 a :3 0 101
:7 0 105 102 103
aea 0 39 :6 0
37 :2 0 85 a
:3 0 107 :7 0 10b
108 109 aea 0
3a :6 0 37 :2 0
87 a :3 0 10d
:7 0 111 10e 10f
aea 0 3b :6 0
37 :2 0 89 a
:3 0 113 :7 0 117
114 115 aea 0
3c :6 0 37 :2 0
8b a :3 0 119
:7 0 11d 11a 11b
aea 0 3d :6 0
37 :2 0 8d a
:3 0 11f :7 0 123
120 121 aea 0
3e :6 0 37 :2 0
8f a :3 0 125
:7 0 129 126 127
aea 0 3f :6 0
24 :2 0 91 a
:3 0 12b :7 0 12f
12c 12d aea 0
40 :6 0 24 :2 0
95 6 :3 0 93
131 133 :6 0 136
134 0 aea 0
41 :6 0 9b 5b2
0 99 6 :3 0
97 138 13a :6 0
13d 13b 0 aea
0 42 :6 0 37
:2 0 9d 2a :3 0
13f :7 0 142 140
0 aea 0 43
:6 0 2a :3 0 144
:7 0 147 145 0
aea 0 44 :6 0
37 :2 0 9f 46
:3 0 149 :7 0 14d
14a 14b aea 0
45 :6 0 37 :2 0
a1 46 :3 0 14f
:7 0 153 150 151
aea 0 47 :6 0
37 :2 0 a3 a
:3 0 155 :7 0 159
156 157 aea 0
48 :6 0 37 :2 0
a5 a :3 0 15b
:7 0 15f 15c 15d
aea 0 49 :6 0
37 :2 0 a7 a
:3 0 161 :7 0 165
162 163 aea 0
4a :6 0 37 :2 0
a9 a :3 0 167
:7 0 16b 168 169
aea 0 4b :6 0
37 :2 0 ab a
:3 0 16d :7 0 171
16e 16f aea 0
4c :6 0 37 :2 0
ad a :3 0 173
:7 0 177 174 175
aea 0 4d :6 0
37 :2 0 af a
:3 0 179 :7 0 17d
17a 17b aea 0
4e :6 0 37 :2 0
b1 a :3 0 17f
:7 0 183 180 181
aea 0 4f :6 0
37 :2 0 b3 a
:3 0 185 :7 0 189
186 187 aea 0
50 :6 0 190 191
0 b5 46 :3 0
18b :7 0 18f 18c
18d aea 0 51
:6 0 52 :3 0 53
:3 0 52 :3 0 54
:3 0 193 194 0
2 :4 0 b7 195
197 192 199 198
:2 0 55 :3 0 56
:3 0 19b 19c 0
57 :4 0 52 :3 0
58 :3 0 19f 1a0
0 2 :4 0 b9
1a1 1a3 59 :4 0
5a :2 0 5b :3 0
bb 1a6 1a8 :3 0
5c :4 0 5a :2 0
5d :4 0 be 1ab
1ad :3 0 5a :2 0
3 :3 0 c1 1af
1b1 :3 0 5a :2 0
5d :4 0 c4 1b3
1b5 :3 0 5a :2 0
5e :4 0 c7 1b7
1b9 :3 0 5a :2 0
5d :4 0 ca 1bb
1bd :3 0 5a :2 0
7 :3 0 cd 1bf
1c1 :3 0 5a :2 0
5d :4 0 d0 1c3
1c5 :3 0 5a :2 0
5e :4 0 d3 1c7
1c9 :3 0 5a :2 0
5d :4 0 d6 1cb
1cd :3 0 5a :2 0
8 :3 0 d9 1cf
1d1 :3 0 5a :2 0
5d :4 0 dc 1d3
1d5 :3 0 5a :2 0
5e :4 0 df 1d7
1d9 :3 0 5a :2 0
5f :3 0 60 :3 0
9 :3 0 e2 1dd
1df 61 :4 0 e4
1dc 1e2 e7 1db
1e4 :3 0 5a :2 0
5e :4 0 ea 1e6
1e8 :3 0 5a :2 0
5d :4 0 ed 1ea
1ec :3 0 5a :2 0
b :3 0 f0 1ee
1f0 :3 0 5a :2 0
5d :4 0 f3 1f2
1f4 :3 0 5a :2 0
5e :4 0 f6 1f6
1f8 :3 0 5a :2 0
5d :4 0 f9 1fa
1fc :3 0 5a :2 0
c :3 0 fc 1fe
200 :3 0 5a :2 0
5d :4 0 ff 202
204 :3 0 5a :2 0
5e :4 0 102 206
208 :3 0 5a :2 0
5f :3 0 60 :3 0
d :3 0 105 20c
20e 61 :4 0 107
20b 211 10a 20a
213 :3 0 5a :2 0
5e :4 0 10d 215
217 :3 0 5a :2 0
5f :3 0 60 :3 0
e :3 0 110 21b
21d 61 :4 0 112
21a 220 115 219
222 :3 0 5a :2 0
5e :4 0 118 224
226 :3 0 5a :2 0
5f :3 0 60 :3 0
f :3 0 11b 22a
22c 61 :4 0 11d
229 22f 120 228
231 :3 0 5a :2 0
5e :4 0 123 233
235 :3 0 5a :2 0
5f :3 0 60 :3 0
10 :3 0 126 239
23b 61 :4 0 128
238 23e 12b 237
240 :3 0 5a :2 0
5e :4 0 12e 242
244 :3 0 5a :2 0
5f :3 0 60 :3 0
11 :3 0 131 248
24a 61 :4 0 133
247 24d 136 246
24f :3 0 5a :2 0
5e :4 0 139 251
253 :3 0 5a :2 0
5f :3 0 60 :3 0
12 :3 0 13c 257
259 61 :4 0 13e
256 25c 141 255
25e :3 0 5a :2 0
5e :4 0 144 260
262 :3 0 5a :2 0
5f :3 0 60 :3 0
13 :3 0 147 266
268 61 :4 0 149
265 26b 14c 264
26d :3 0 5a :2 0
5e :4 0 14f 26f
271 :3 0 5a :2 0
5f :3 0 60 :3 0
14 :3 0 152 275
277 61 :4 0 154
274 27a 157 273
27c :3 0 5a :2 0
5e :4 0 15a 27e
280 :3 0 5a :2 0
5f :3 0 60 :3 0
15 :3 0 15d 284
286 61 :4 0 15f
283 289 162 282
28b :3 0 5a :2 0
5e :4 0 165 28d
28f :3 0 5a :2 0
5d :4 0 168 291
293 :3 0 5a :2 0
16 :3 0 16b 295
297 :3 0 5a :2 0
5d :4 0 16e 299
29b :3 0 5a :2 0
5e :4 0 171 29d
29f :3 0 5a :2 0
5d :4 0 174 2a1
2a3 :3 0 5a :2 0
17 :3 0 177 2a5
2a7 :3 0 5a :2 0
5d :4 0 17a 2a9
2ab :3 0 5a :2 0
62 :4 0 17d 2ad
2af :3 0 180 19d
2b1 :2 0 2b3 185
2b4 19a 2b3 0
2b5 187 0 ae8
52 :3 0 53 :3 0
2b6 2b7 0 52
:3 0 63 :3 0 2b9
2ba 0 31 :2 0
2 :4 0 64 :2 0
65 :2 0 31 :2 0
189 2bf 2c1 :3 0
18c 2bb 2c3 2b8
2c5 2c4 :2 0 55
:3 0 66 :3 0 2c7
2c8 0 57 :4 0
67 :4 0 5a :2 0
5b :3 0 190 2cc
2ce :3 0 193 2c9
2d0 :2 0 2d2 196
2d3 2c6 2d2 0
2d4 198 0 ae8
5f :3 0 1f :3 0
37 :2 0 19a 2d5
2d8 68 :3 0 69
:2 0 6a :3 0 2da
2dc 0 19f 2db
2de :3 0 3c :3 0
6b :3 0 6c :3 0
2e1 2e2 0 6d
:3 0 5f :3 0 1f
:3 0 37 :2 0 1a2
2e5 2e8 68 :3 0
6e :3 0 2ea 2eb
0 1a5 2e4 2ed
2ee :2 0 6f :2 0
1a8 2e3 2f1 2e0
2f2 0 308 3a
:3 0 6d :3 0 5f
:3 0 1f :3 0 37
:2 0 1ab 2f6 2f9
68 :3 0 70 :3 0
2fb 2fc 0 1ae
2f5 2fe 2f4 2ff
0 308 1f :3 0
37 :2 0 301 302
0 308 3b :3 0
37 :2 0 304 305
0 308 71 :3 0
1b1 343 5f :3 0
1f :3 0 37 :2 0
1b6 309 30c 68
:3 0 69 :2 0 72
:3 0 30e 310 0
1bb 30f 312 :3 0
3b :3 0 6d :3 0
5f :3 0 1f :3 0
37 :2 0 1be 316
319 68 :3 0 72
:3 0 31b 31c 0
1c1 315 31e 31f
:2 0 314 320 0
333 1f :3 0 6d
:3 0 5f :3 0 1f
:3 0 37 :2 0 1c4
324 327 68 :3 0
73 :3 0 329 32a
0 1c7 323 32c
32d :2 0 322 32e
0 333 3a :3 0
37 :2 0 330 331
0 333 1ca 334
313 333 0 345
3a :3 0 5f :3 0
1f :3 0 37 :2 0
1ce 336 339 335
33a 0 342 1f
:3 0 37 :2 0 33c
33d 0 342 3b
:3 0 37 :2 0 33f
340 0 342 1d1
344 2df 308 0
345 0 342 0
345 1d5 0 ae8
4b :3 0 37 :2 0
346 347 0 ae8
30 :3 0 37 :4 0
349 34a 0 ae8
3f :3 0 37 :2 0
34c 34d 0 ae8
2b :4 0 34f 350
0 ae8 43 :4 0
352 353 0 ae8
44 :4 0 355 356
0 ae8 35 :4 0
358 359 0 ae8
51 :3 0 74 :2 0
35b 35c 0 ae8
5f :3 0 1f :3 0
37 :2 0 1d9 35e
361 75 :2 0 31
:2 0 1de 363 365
:3 0 2c :3 0 3
:3 0 367 368 0
415 76 :3 0 77
:3 0 78 :3 0 79
:3 0 7a :3 0 7b
:3 0 7c :3 0 7d
:3 0 7e :3 0 7c
:3 0 7d :3 0 7f
:3 0 80 :3 0 81
:3 0 82 :3 0 83
:3 0 2d :3 0 23
:3 0 25 :3 0 30
:3 0 2b :3 0 3f
:3 0 43 :3 0 44
:3 0 48 :3 0 49
:3 0 45 :3 0 47
:3 0 84 :3 0 85
:3 0 2c :4 0 86
1 :8 0 38f 87
:3 0 88 :3 0 38a
38b 0 89 :3 0
38c 38d 0 38f
1e1 3e2 8a :3 0
87 :3 0 88 :3 0
391 392 0 89
:3 0 393 394 0
396 1e4 398 1e6
397 396 :2 0 3e0
8b :3 0 87 :3 0
88 :3 0 39b 39c
0 89 :3 0 39d
39e 0 3d8 52
:3 0 53 :3 0 3a0
3a1 0 52 :3 0
63 :3 0 3a3 3a4
0 8c :2 0 2
:4 0 8d :2 0 65
:2 0 31 :2 0 1e8
3a9 3ab :3 0 1eb
3a5 3ad 3a2 3af
3ae :2 0 55 :3 0
66 :3 0 3b1 3b2
0 57 :4 0 8e
:4 0 5a :2 0 5b
:3 0 1ef 3b6 3b8
:3 0 5a :2 0 8f
:4 0 1f2 3ba 3bc
:3 0 5a :2 0 90
:4 0 1f5 3be 3c0
:3 0 5a :2 0 89
:3 0 1f8 3c2 3c4
:3 0 5a :2 0 91
:4 0 1fb 3c6 3c8
:3 0 5a :2 0 7d
:3 0 92 :3 0 31
:2 0 93 :2 0 1fe
3cb 3cf 202 3ca
3d1 :3 0 205 3b3
3d3 :2 0 3d5 208
3d6 3b0 3d5 0
3d7 20a 0 3d8
20c 3db :3 0 3db
0 3db 3da 3d8
3d9 :6 0 3dd 2
:3 0 20f 3df 211
3de 3dd :2 0 3e0
213 :2 0 3e2 0
3e2 3e1 38f 3e0
:6 0 415 1 :3 0
87 :3 0 88 :3 0
3e4 3e5 0 87
:3 0 75 :2 0 94
:3 0 3e7 3e9 0
218 3e8 3eb :3 0
3ec :2 0 52 :3 0
53 :3 0 3ee 3ef
0 52 :3 0 63
:3 0 3f1 3f2 0
31 :2 0 2 :4 0
95 :2 0 65 :2 0
31 :2 0 21b 3f7
3f9 :3 0 21e 3f3
3fb 3f0 3fd 3fc
:2 0 55 :3 0 66
:3 0 3ff 400 0
57 :4 0 96 :4 0
5a :2 0 5b :3 0
222 404 406 :3 0
225 401 408 :2 0
40a 228 40b 3fe
40a 0 40c 22a
0 412 18 :3 0
68 :3 0 97 :3 0
40e 40f 0 410
:2 0 412 22c 413
3ed 412 0 414
22f 0 415 231
601 76 :3 0 98
:3 0 78 :3 0 99
:3 0 79 :3 0 9a
:3 0 9b :3 0 2d
:3 0 23 :3 0 25
:3 0 38 :3 0 30
:3 0 2f :3 0 3e
:3 0 9c :3 0 9d
:3 0 3 :4 0 9e
1 :8 0 42d 87
:3 0 88 :3 0 428
429 0 89 :3 0
42a 42b 0 42d
235 480 8a :3 0
87 :3 0 88 :3 0
42f 430 0 89
:3 0 431 432 0
434 238 436 23a
435 434 :2 0 47e
8b :3 0 87 :3 0
88 :3 0 439 43a
0 89 :3 0 43b
43c 0 476 52
:3 0 53 :3 0 43e
43f 0 52 :3 0
63 :3 0 441 442
0 8c :2 0 2
:4 0 9f :2 0 65
:2 0 31 :2 0 23c
447 449 :3 0 23f
443 44b 440 44d
44c :2 0 55 :3 0
66 :3 0 44f 450
0 57 :4 0 a0
:4 0 5a :2 0 5b
:3 0 243 454 456
:3 0 5a :2 0 8f
:4 0 246 458 45a
:3 0 5a :2 0 90
:4 0 249 45c 45e
:3 0 5a :2 0 89
:3 0 24c 460 462
:3 0 5a :2 0 91
:4 0 24f 464 466
:3 0 5a :2 0 7d
:3 0 92 :3 0 31
:2 0 93 :2 0 252
469 46d 256 468
46f :3 0 259 451
471 :2 0 473 25c
474 44e 473 0
475 25e 0 476
260 479 :3 0 479
0 479 478 476
477 :6 0 47b 4
:3 0 263 47d 265
47c 47b :2 0 47e
267 :2 0 480 0
480 47f 42d 47e
:6 0 600 1 :3 0
87 :3 0 88 :3 0
482 483 0 87
:3 0 75 :2 0 94
:3 0 485 487 0
26c 486 489 :3 0
48a :2 0 52 :3 0
53 :3 0 48c 48d
0 52 :3 0 63
:3 0 48f 490 0
31 :2 0 2 :4 0
a1 :2 0 65 :2 0
31 :2 0 26f 495
497 :3 0 272 491
499 48e 49b 49a
:2 0 55 :3 0 66
:3 0 49d 49e 0
57 :4 0 a2 :4 0
5a :2 0 5b :3 0
276 4a2 4a4 :3 0
279 49f 4a6 :2 0
4a8 27c 4a9 49c
4a8 0 4aa 27e
0 4b1 18 :3 0
68 :3 0 97 :3 0
4ac 4ad 0 4ae
:2 0 4b1 71 :3 0
280 4e4 a3 :3 0
5f :3 0 38 :3 0
37 :2 0 283 4b3
4b6 286 4b2 4b8
a4 :2 0 37 :2 0
28a 4ba 4bc :3 0
52 :3 0 53 :3 0
4be 4bf 0 52
:3 0 63 :3 0 4c1
4c2 0 31 :2 0
2 :4 0 a5 :2 0
65 :2 0 31 :2 0
28d 4c7 4c9 :3 0
290 4c3 4cb 4c0
4cd 4cc :2 0 55
:3 0 66 :3 0 4cf
4d0 0 57 :4 0
a6 :4 0 5a :2 0
5b :3 0 294 4d4
4d6 :3 0 297 4d1
4d8 :2 0 4da 29a
4db 4ce 4da 0
4dc 29c 0 4e2
18 :3 0 68 :3 0
a7 :3 0 4de 4df
0 4e0 :2 0 4e2
29e 4e3 4bd 4e2
0 4e5 48b 4b1
0 4e5 2a1 0
600 9c :3 0 a8
:3 0 19 :3 0 9d
:3 0 3 :4 0 a9
1 :8 0 501 aa
:4 0 4ec :3 0 ab
:3 0 75 :2 0 2a6
4ef 4f0 :3 0 87
:3 0 88 :3 0 4f2
4f3 0 37 :2 0
4f4 4f5 0 4f7
2a9 4fe 87 :3 0
88 :3 0 4f8 4f9
0 ac :2 0 4fa
4fb 0 4fd 2ab
4ff 4f1 4f7 0
500 0 4fd 0
500 2ad 0 501
2b0 554 8a :3 0
87 :3 0 88 :3 0
503 504 0 89
:3 0 505 506 0
508 2b3 50a 2b5
509 508 :2 0 552
8b :3 0 87 :3 0
88 :3 0 50d 50e
0 89 :3 0 50f
510 0 54a 52
:3 0 53 :3 0 512
513 0 52 :3 0
63 :3 0 515 516
0 8c :2 0 2
:4 0 ad :2 0 65
:2 0 31 :2 0 2b7
51b 51d :3 0 2ba
517 51f 514 521
520 :2 0 55 :3 0
66 :3 0 523 524
0 57 :4 0 ae
:4 0 5a :2 0 5b
:3 0 2be 528 52a
:3 0 5a :2 0 8f
:4 0 2c1 52c 52e
:3 0 5a :2 0 90
:4 0 2c4 530 532
:3 0 5a :2 0 89
:3 0 2c7 534 536
:3 0 5a :2 0 91
:4 0 2ca 538 53a
:3 0 5a :2 0 7d
:3 0 92 :3 0 31
:2 0 93 :2 0 2cd
53d 541 2d1 53c
543 :3 0 2d4 525
545 :2 0 547 2d7
548 522 547 0
549 2d9 0 54a
2db 54d :3 0 54d
0 54d 54c 54a
54b :6 0 54f 6
:3 0 2de 551 2e0
550 54f :2 0 552
2e2 :2 0 554 0
554 553 501 552
:6 0 600 1 :3 0
af :3 0 5f :3 0
38 :3 0 37 :2 0
2e5 557 55a 2e8
556 55c 55d :2 0
a4 :2 0 37 :2 0
2ec 55f 561 :3 0
b0 :2 0 2ef 563
564 :3 0 85 :3 0
2c :3 0 84 :3 0
9d :3 0 3 :4 0
b1 1 :8 0 571
87 :3 0 88 :3 0
56c 56d 0 89
:3 0 56e 56f 0
571 2f1 5c4 8a
:3 0 87 :3 0 88
:3 0 573 574 0
89 :3 0 575 576
0 578 2f4 57a
2f6 579 578 :2 0
5c2 8b :3 0 87
:3 0 88 :3 0 57d
57e 0 89 :3 0
57f 580 0 5ba
52 :3 0 53 :3 0
582 583 0 52
:3 0 63 :3 0 585
586 0 8c :2 0
2 :4 0 b2 :2 0
65 :2 0 31 :2 0
2f8 58b 58d :3 0
2fb 587 58f 584
591 590 :2 0 55
:3 0 66 :3 0 593
594 0 57 :4 0
b3 :4 0 5a :2 0
5b :3 0 2ff 598
59a :3 0 5a :2 0
8f :4 0 302 59c
59e :3 0 5a :2 0
90 :4 0 305 5a0
5a2 :3 0 5a :2 0
89 :3 0 308 5a4
5a6 :3 0 5a :2 0
91 :4 0 30b 5a8
5aa :3 0 5a :2 0
7d :3 0 92 :3 0
31 :2 0 93 :2 0
30e 5ad 5b1 312
5ac 5b3 :3 0 315
595 5b5 :2 0 5b7
318 5b8 592 5b7
0 5b9 31a 0
5ba 31c 5bd :3 0
5bd 0 5bd 5bc
5ba 5bb :6 0 5bf
8 :3 0 31f 5c1
321 5c0 5bf :2 0
5c2 323 :2 0 5c4
0 5c4 5c3 571
5c2 :6 0 5f7 1
:3 0 87 :3 0 88
:3 0 5c6 5c7 0
87 :3 0 75 :2 0
b4 :3 0 5c9 5cb
0 328 5ca 5cd
:3 0 5ce :2 0 52
:3 0 53 :3 0 5d0
5d1 0 52 :3 0
63 :3 0 5d3 5d4
0 31 :2 0 2
:4 0 b5 :2 0 65
:2 0 31 :2 0 32b
5d9 5db :3 0 32e
5d5 5dd 5d2 5df
5de :2 0 55 :3 0
66 :3 0 5e1 5e2
0 57 :4 0 b6
:4 0 5a :2 0 5b
:3 0 332 5e6 5e8
:3 0 335 5e3 5ea
:2 0 5ec 338 5ed
5e0 5ec 0 5ee
33a 0 5f4 18
:3 0 68 :3 0 b7
:3 0 5f0 5f1 0
5f2 :2 0 5f4 33c
5f5 5cf 5f4 0
5f6 33f 0 5f7
341 5f8 565 5f7
0 5f9 344 0
600 3d :3 0 b8
:3 0 3 :3 0 346
5fb 5fd 5fa 5fe
0 600 348 602
366 415 0 603
0 600 0 603
34e 0 ae8 5f
:3 0 b9 :3 0 5f
:3 0 ba :3 0 bb
:3 0 bc :3 0 36
:3 0 39 :3 0 2e
:3 0 4e :3 0 bd
:3 0 98 :3 0 2d
:4 0 be 1 :8 0
617 87 :3 0 88
:3 0 612 613 0
89 :3 0 614 615
0 617 351 66a
8a :3 0 87 :3 0
88 :3 0 619 61a
0 89 :3 0 61b
61c 0 61e 354
620 356 61f 61e
:2 0 668 8b :3 0
87 :3 0 88 :3 0
623 624 0 89
:3 0 625 626 0
660 52 :3 0 53
:3 0 628 629 0
52 :3 0 63 :3 0
62b 62c 0 8c
:2 0 2 :4 0 bf
:2 0 65 :2 0 31
:2 0 358 631 633
:3 0 35b 62d 635
62a 637 636 :2 0
55 :3 0 66 :3 0
639 63a 0 57
:4 0 c0 :4 0 5a
:2 0 5b :3 0 35f
63e 640 :3 0 5a
:2 0 8f :4 0 362
642 644 :3 0 5a
:2 0 90 :4 0 365
646 648 :3 0 5a
:2 0 89 :3 0 368
64a 64c :3 0 5a
:2 0 91 :4 0 36b
64e 650 :3 0 5a
:2 0 7d :3 0 92
:3 0 31 :2 0 93
:2 0 36e 653 657
372 652 659 :3 0
375 63b 65b :2 0
65d 378 65e 638
65d 0 65f 37a
0 660 37c 663
:3 0 663 0 663
662 660 661 :6 0
665 a :3 0 37f
667 381 666 665
:2 0 668 383 :2 0
66a 0 66a 669
617 668 :6 0 ae8
1 :3 0 5f :3 0
3b :3 0 37 :2 0
386 66c 66f 75
:2 0 37 :2 0 38b
671 673 :3 0 5f
:3 0 1b :3 0 37
:2 0 38e 675 678
c1 :2 0 37 :2 0
393 67a 67c :3 0
67d :2 0 5f :3 0
1d :3 0 37 :2 0
396 67f 682 75
:2 0 c2 :2 0 39b
684 686 :3 0 687
:2 0 67e 689 688
:2 0 1b :3 0 5f
:3 0 36 :3 0 37
:2 0 39e 68c 68f
c3 :2 0 5f :3 0
1b :3 0 37 :2 0
3a1 692 695 3a4
691 697 :3 0 68b
698 0 69a 3a7
69b 68a 69a 0
69c 3a9 0 7b5
5f :3 0 1a :3 0
37 :2 0 3ab 69d
6a0 75 :2 0 37
:2 0 3b0 6a2 6a4
:3 0 c :3 0 c4
:2 0 3b3 6a7 6a8
:3 0 6a9 :2 0 5f
:3 0 1b :3 0 37
:2 0 3b5 6ab 6ae
c1 :2 0 37 :2 0
3ba 6b0 6b2 :3 0
1a :3 0 5f :3 0
22 :3 0 37 :2 0
3bd 6b5 6b8 c3
:2 0 5f :3 0 1b
:3 0 37 :2 0 3c0
6bb 6be 3c3 6ba
6c0 :3 0 6b4 6c1
0 6c3 3c6 6c4
6b3 6c3 0 6c5
3c8 0 6c6 3ca
730 c5 :3 0 c6
:3 0 1a :3 0 c7
:3 0 98 :3 0 2d
:3 0 c8 :3 0 7c
:3 0 7d :3 0 b
:3 0 7c :3 0 7d
:3 0 c :4 0 c9
1 :8 0 6da 87
:3 0 88 :3 0 6d5
6d6 0 89 :3 0
6d7 6d8 0 6da
3cc 72d 8a :3 0
87 :3 0 88 :3 0
6dc 6dd 0 89
:3 0 6de 6df 0
6e1 3cf 6e3 3d1
6e2 6e1 :2 0 72b
8b :3 0 87 :3 0
88 :3 0 6e6 6e7
0 89 :3 0 6e8
6e9 0 723 52
:3 0 53 :3 0 6eb
6ec 0 52 :3 0
63 :3 0 6ee 6ef
0 8c :2 0 2
:4 0 ca :2 0 65
:2 0 31 :2 0 3d3
6f4 6f6 :3 0 3d6
6f0 6f8 6ed 6fa
6f9 :2 0 55 :3 0
66 :3 0 6fc 6fd
0 57 :4 0 cb
:4 0 5a :2 0 5b
:3 0 3da 701 703
:3 0 5a :2 0 8f
:4 0 3dd 705 707
:3 0 5a :2 0 90
:4 0 3e0 709 70b
:3 0 5a :2 0 89
:3 0 3e3 70d 70f
:3 0 5a :2 0 91
:4 0 3e6 711 713
:3 0 5a :2 0 7d
:3 0 92 :3 0 31
:2 0 93 :2 0 3e9
716 71a 3ed 715
71c :3 0 3f0 6fe
71e :2 0 720 3f3
721 6fb 720 0
722 3f5 0 723
3f7 726 :3 0 726
0 726 725 723
724 :6 0 728 c
:3 0 3fa 72a 3fc
729 728 :2 0 72b
3fe :2 0 72d 0
72d 72c 6da 72b
:6 0 72f 1 :3 0
401 731 6aa 6c6
0 732 0 72f
0 732 403 0
733 406 782 5f
:3 0 1c :3 0 37
:2 0 408 734 737
75 :2 0 31 :2 0
40d 739 73b :3 0
1a :3 0 5f :3 0
1a :3 0 37 :2 0
410 73e 741 c3
:2 0 cc :2 0 413
743 745 :3 0 73d
746 0 749 71
:3 0 416 77f 5f
:3 0 1c :3 0 37
:2 0 418 74a 74d
75 :2 0 cd :2 0
41d 74f 751 :3 0
1a :3 0 5f :3 0
36 :3 0 37 :2 0
420 754 757 c3
:2 0 5f :3 0 1a
:3 0 37 :2 0 423
75a 75d 426 759
75f :3 0 753 760
0 763 71 :3 0
429 764 752 763
0 780 5f :3 0
1c :3 0 37 :2 0
42b 765 768 75
:2 0 ce :2 0 430
76a 76c :3 0 1a
:3 0 5f :3 0 39
:3 0 37 :2 0 433
76f 772 c3 :2 0
5f :3 0 1a :3 0
37 :2 0 436 775
778 439 774 77a
:3 0 76e 77b 0
77d 43c 77e 76d
77d 0 780 73c
749 0 780 43e
0 781 442 783
6a5 733 0 784
0 781 0 784
444 0 7b5 5f
:3 0 1a :3 0 37
:2 0 447 785 788
75 :2 0 37 :2 0
44c 78a 78c :3 0
52 :3 0 53 :3 0
78e 78f 0 52
:3 0 63 :3 0 791
792 0 31 :2 0
2 :4 0 cf :2 0
65 :2 0 31 :2 0
44f 797 799 :3 0
452 793 79b 790
79d 79c :2 0 55
:3 0 66 :3 0 79f
7a0 0 57 :4 0
d0 :4 0 5a :2 0
5b :3 0 456 7a4
7a6 :3 0 459 7a1
7a8 :2 0 7aa 45c
7ab 79e 7aa 0
7ac 45e 0 7b2
18 :3 0 68 :3 0
a7 :3 0 7ae 7af
0 7b0 :2 0 7b2
460 7b3 78d 7b2
0 7b4 463 0
7b5 465 7b6 674
7b5 0 7b7 469
0 ae8 5f :3 0
1f :3 0 37 :2 0
46b 7b8 7bb 75
:2 0 cd :2 0 470
7bd 7bf :3 0 1f
:3 0 6d :3 0 5f
:3 0 1f :3 0 37
:2 0 473 7c3 7c6
68 :3 0 d1 :3 0
7c8 7c9 0 476
7c2 7cb 7cc :2 0
7c1 7cd 0 7d0
71 :3 0 479 9d5
7d :3 0 30 :3 0
31 :2 0 31 :2 0
47b 7d1 7d5 75
:2 0 37 :4 0 481
7d7 7d9 :3 0 7da
:2 0 5f :3 0 1e
:3 0 37 :2 0 484
7dc 7df 75 :2 0
37 :2 0 489 7e1
7e3 :3 0 7e4 :2 0
7db 7e6 7e5 :2 0
85 :3 0 d2 :3 0
d3 :3 0 d4 :3 0
d5 :3 0 d6 :3 0
2c :3 0 26 :3 0
28 :3 0 4d :3 0
32 :3 0 84 :3 0
76 :3 0 2d :3 0
77 :3 0 2d :3 0
78 :3 0 25 :4 0
d7 1 :8 0 800
87 :3 0 88 :3 0
7fb 7fc 0 89
:3 0 7fd 7fe 0
800 48c 853 8a
:3 0 87 :3 0 88
:3 0 802 803 0
89 :3 0 804 805
0 807 48f 809
491 808 807 :2 0
851 8b :3 0 87
:3 0 88 :3 0 80c
80d 0 89 :3 0
80e 80f 0 849
52 :3 0 53 :3 0
811 812 0 52
:3 0 63 :3 0 814
815 0 8c :2 0
2 :4 0 d8 :2 0
65 :2 0 31 :2 0
493 81a 81c :3 0
496 816 81e 813
820 81f :2 0 55
:3 0 66 :3 0 822
823 0 57 :4 0
d9 :4 0 5a :2 0
5b :3 0 49a 827
829 :3 0 5a :2 0
8f :4 0 49d 82b
82d :3 0 5a :2 0
90 :4 0 4a0 82f
831 :3 0 5a :2 0
89 :3 0 4a3 833
835 :3 0 5a :2 0
91 :4 0 4a6 837
839 :3 0 5a :2 0
7d :3 0 92 :3 0
31 :2 0 93 :2 0
4a9 83c 840 4ad
83b 842 :3 0 4b0
824 844 :2 0 846
4b3 847 821 846
0 848 4b5 0
849 4b7 84c :3 0
84c 0 84c 84b
849 84a :6 0 84e
e :3 0 4ba 850
4bc 84f 84e :2 0
851 4be :2 0 853
0 853 852 800
851 :6 0 9d3 1
:3 0 87 :3 0 88
:3 0 855 856 0
87 :3 0 75 :2 0
b4 :3 0 858 85a
0 4c3 859 85c
:3 0 85d :2 0 2c
:3 0 da :2 0 4c6
860 861 :3 0 862
:2 0 85e 864 863
:2 0 1f :3 0 6d
:3 0 5f :3 0 1f
:3 0 37 :2 0 4c8
868 86b 68 :3 0
d1 :3 0 86d 86e
0 4cb 867 870
871 :2 0 866 872
0 9d0 db :3 0
dc :3 0 874 875
0 b :3 0 26
:3 0 dd :2 0 4ce
876 87a 69 :2 0
37 :2 0 4d4 87c
87e :3 0 87f :2 0
db :3 0 dc :3 0
881 882 0 28
:3 0 c :3 0 dd
:2 0 4d7 883 887
69 :2 0 37 :2 0
4dd 889 88b :3 0
88c :2 0 880 88e
88d :2 0 7d :3 0
32 :3 0 31 :2 0
31 :2 0 4e0 890
894 75 :2 0 cd
:4 0 4e6 896 898
:3 0 5f :3 0 3b
:3 0 37 :2 0 4e9
89a 89d 75 :2 0
37 :2 0 4ee 89f
8a1 :3 0 1f :3 0
cd :2 0 8a3 8a4
0 8a6 4f1 8a7
8a2 8a6 0 8a8
4f3 0 8ac 1e
:3 0 cd :2 0 8a9
8aa 0 8ac 4f5
8ad 899 8ac 0
8ae 4f8 0 8af
4fa 9cd 5f :3 0
1f :3 0 37 :2 0
4fc 8b0 8b3 75
:2 0 31 :2 0 501
8b5 8b7 :3 0 3a
:3 0 6b :3 0 de
:3 0 8ba 8bb 0
5f :3 0 3a :3 0
37 :2 0 504 8bd
8c0 68 :3 0 6a
:3 0 8c2 8c3 0
507 8bc 8c5 8c6
:2 0 8b9 8c7 0
8c9 50a 8ca 8b8
8c9 0 8cb 50c
0 9cc 5f :3 0
4d :3 0 37 :2 0
50e 8cc 8cf 5f
:3 0 df :2 0 1a
:3 0 37 :2 0 511
8d1 8d5 516 8d2
8d7 :3 0 5f :3 0
4d :3 0 37 :2 0
519 8d9 8dc c1
:2 0 37 :2 0 51e
8de 8e0 :3 0 db
:3 0 dc :3 0 8e2
8e3 0 b :3 0
28 :3 0 dd :2 0
521 8e4 8e8 69
:2 0 37 :2 0 527
8ea 8ec :3 0 8e1
8ee 8ed :2 0 7d
:3 0 32 :3 0 31
:2 0 31 :2 0 52a
8f0 8f4 75 :2 0
37 :4 0 530 8f6
8f8 :3 0 4f :3 0
ce :2 0 8fa 8fb
0 8fd 533 8fe
8f9 8fd 0 8ff
535 0 934 3d
:3 0 e0 :4 0 901
902 :3 0 900 903
0 934 3a :3 0
68 :3 0 e1 :3 0
906 907 0 905
908 0 934 3d
:3 0 e2 :3 0 3
:3 0 2d :3 0 23
:3 0 25 :3 0 51
:3 0 38 :3 0 7
:3 0 8 :3 0 35
:3 0 35 :3 0 b
:3 0 28 :3 0 50
:3 0 4d :3 0 1b
:3 0 1c :3 0 1d
:3 0 50 :3 0 3a
:3 0 30 :3 0 1e
:3 0 1f :3 0 20
:3 0 22 :3 0 4f
:3 0 36 :3 0 4e
:3 0 17 :3 0 5f
:3 0 36 :3 0 37
:2 0 537 928 92b
37 :2 0 74 :2 0
74 :2 0 37 :2 0
53a 90b 931 90a
932 0 934 55c
935 8ef 934 0
936 561 0 9c9
84 :3 0 e3 :3 0
1a :3 0 9d :3 0
3 :4 0 e4 1
:8 0 952 aa :4 0
93d :3 0 ab :3 0
75 :2 0 565 940
941 :3 0 87 :3 0
88 :3 0 943 944
0 37 :2 0 945
946 0 948 568
94f 87 :3 0 88
:3 0 949 94a 0
ac :2 0 94b 94c
0 94e 56a 950
942 948 0 951
0 94e 0 951
56c 0 952 56f
9a5 8a :3 0 87
:3 0 88 :3 0 954
955 0 89 :3 0
956 957 0 959
572 95b 574 95a
959 :2 0 9a3 8b
:3 0 87 :3 0 88
:3 0 95e 95f 0
89 :3 0 960 961
0 99b 52 :3 0
53 :3 0 963 964
0 52 :3 0 63
:3 0 966 967 0
8c :2 0 2 :4 0
e5 :2 0 65 :2 0
31 :2 0 576 96c
96e :3 0 579 968
970 965 972 971
:2 0 55 :3 0 66
:3 0 974 975 0
57 :4 0 e6 :4 0
5a :2 0 5b :3 0
57d 979 97b :3 0
5a :2 0 8f :4 0
580 97d 97f :3 0
5a :2 0 90 :4 0
583 981 983 :3 0
5a :2 0 89 :3 0
586 985 987 :3 0
5a :2 0 91 :4 0
589 989 98b :3 0
5a :2 0 7d :3 0
92 :3 0 31 :2 0
93 :2 0 58c 98e
992 590 98d 994
:3 0 593 976 996
:2 0 998 596 999
973 998 0 99a
598 0 99b 59a
99e :3 0 99e 0
99e 99d 99b 99c
:6 0 9a0 10 :3 0
59d 9a2 59f 9a1
9a0 :2 0 9a3 5a1
:2 0 9a5 0 9a5
9a4 952 9a3 :6 0
9c9 1 :3 0 52
:3 0 53 :3 0 9a7
9a8 0 52 :3 0
63 :3 0 9aa 9ab
0 31 :2 0 2
:4 0 e7 :2 0 65
:2 0 31 :2 0 5a4
9b0 9b2 :3 0 5a7
9ac 9b4 9a9 9b6
9b5 :2 0 55 :3 0
66 :3 0 9b8 9b9
0 57 :4 0 e8
:4 0 5a :2 0 5b
:3 0 5ab 9bd 9bf
:3 0 5ae 9ba 9c1
:2 0 9c3 5b1 9c4
9b7 9c3 0 9c5
5b3 0 9c9 18
:3 0 37 :2 0 9c7
:2 0 9c9 5b5 9ca
8d8 9c9 0 9cb
5ba 0 9cc 5bc
9ce 88f 8af 0
9cf 0 9cc 0
9cf 5bf 0 9d0
5c2 9d1 865 9d0
0 9d2 5c5 0
9d3 5c7 9d4 7e7
9d3 0 9d6 7c0
7d0 0 9d6 5ca
0 ae8 5f :3 0
1f :3 0 37 :2 0
5cd 9d7 9da 75
:2 0 37 :2 0 5d2
9dc 9de :3 0 9df
:2 0 5f :3 0 22
:3 0 37 :2 0 5d5
9e1 9e4 5f :3 0
75 :2 0 3f :3 0
37 :2 0 5d8 9e6
9ea 5dd 9e7 9ec
:3 0 9ed :2 0 9e0
9ef 9ee :2 0 5f
:3 0 3b :3 0 37
:2 0 5e0 9f1 9f4
a4 :2 0 37 :2 0
5e5 9f6 9f8 :3 0
1f :3 0 6b :3 0
de :3 0 9fb 9fc
0 5f :3 0 1f
:3 0 37 :2 0 5e8
9fe a01 5f :3 0
3b :3 0 37 :2 0
5eb a03 a06 5ee
9fd a08 a09 :2 0
9fa a0a 0 a0c
5f1 a0d 9f9 a0c
0 a0e 5f3 0
a2d 3d :3 0 e9
:3 0 3 :3 0 2d
:3 0 23 :3 0 25
:3 0 7 :3 0 8
:3 0 b :3 0 c
:3 0 1a :3 0 1b
:3 0 1c :3 0 1d
:3 0 30 :3 0 1e
:3 0 1f :3 0 20
:3 0 21 :3 0 22
:3 0 3a :3 0 16
:3 0 17 :3 0 36
:3 0 74 :2 0 74
:2 0 5f5 a10 a29
a0f a2a 0 a2d
71 :3 0 60e a74
5f :3 0 1f :3 0
37 :2 0 611 a2e
a31 75 :2 0 31
:2 0 616 a33 a35
:3 0 5f :3 0 3b
:3 0 37 :2 0 619
a37 a3a a4 :2 0
37 :2 0 61e a3c
a3e :3 0 1f :3 0
6b :3 0 de :3 0
a41 a42 0 5f
:3 0 1f :3 0 37
:2 0 621 a44 a47
5f :3 0 3b :3 0
37 :2 0 624 a49
a4c 627 a43 a4e
a4f :2 0 a40 a50
0 a52 62a a53
a3f a52 0 a54
62c 0 a72 3d
:3 0 e9 :3 0 2c
:3 0 2d :3 0 23
:3 0 25 :3 0 7
:3 0 8 :3 0 b
:3 0 c :3 0 1a
:3 0 1b :3 0 1c
:3 0 1d :3 0 30
:3 0 1e :3 0 1f
:3 0 20 :3 0 21
:3 0 22 :3 0 3a
:3 0 16 :3 0 17
:3 0 36 :3 0 74
:2 0 74 :2 0 62e
a56 a6f a55 a70
0 a72 647 a73
a36 a72 0 a75
9f0 a2d 0 a75
64a 0 ae8 5f
:3 0 3d :3 0 37
:2 0 64d a76 a79
75 :2 0 ea :2 0
652 a7b a7d :3 0
87 :3 0 88 :3 0
a7f a80 0 68
:3 0 eb :3 0 a82
a83 0 a81 a84
0 a87 71 :3 0
655 aa5 5f :3 0
3d :3 0 37 :2 0
657 a88 a8b a4
:2 0 37 :2 0 65c
a8d a8f :3 0 5f
:3 0 3d :3 0 37
:2 0 65f a91 a94
a4 :2 0 ac :2 0
664 a96 a98 :3 0
a90 a9a a99 :2 0
87 :3 0 88 :3 0
a9c a9d 0 68
:3 0 a7 :3 0 a9f
aa0 0 a9e aa1
0 aa3 667 aa4
a9b aa3 0 aa6
a7e a87 0 aa6
669 0 ae8 87
:3 0 88 :3 0 aa7
aa8 0 75 :2 0
ac :2 0 66e aaa
aac :3 0 87 :3 0
88 :3 0 aae aaf
0 37 :2 0 ab0
ab1 0 ab3 671
ab4 aad ab3 0
ab5 673 0 ae8
52 :3 0 53 :3 0
ab6 ab7 0 52
:3 0 63 :3 0 ab9
aba 0 31 :2 0
2 :4 0 ec :2 0
65 :2 0 31 :2 0
675 abf ac1 :3 0
678 abb ac3 ab8
ac5 ac4 :2 0 55
:3 0 66 :3 0 ac7
ac8 0 57 :4 0
ed :4 0 5a :2 0
5b :3 0 67c acc
ace :3 0 5a :2 0
8f :4 0 67f ad0
ad2 :3 0 5a :2 0
ee :4 0 682 ad4
ad6 :3 0 5a :2 0
87 :3 0 88 :3 0
ad9 ada 0 685
ad8 adc :3 0 688
ac9 ade :2 0 ae0
68b ae1 ac6 ae0
0 ae2 68d 0
ae8 18 :3 0 87
:3 0 88 :3 0 ae4
ae5 0 ae6 :2 0
ae8 68f aeb :3 0
aeb 6a4 aeb aea
ae8 ae9 :6 0 aec
:2 0 2 58 aeb
aef :3 0 aee aec
af0 :8 0 
6d7
4
:3 0 1 3 1
9 1 f 1
15 1 19 1
1f 1 25 1
29 1 2d 1
31 1 35 1
39 1 3d 1
41 1 45 1
49 1 4f 11
8 e 14 18
1e 24 28 2c
30 34 38 3c
40 44 48 4e
54 1 5a 1
60 1 66 1
6c 1 72 1
78 1 7e 1
84 1 8a 1
90 1 98 1
96 1 9f 1
9d 1 a6 1
a4 1 ad 1
ab 1 b2 1
b7 1 be 1
bc 1 c5 1
c3 1 cc 1
ca 1 d3 1
d1 1 da 1
d8 1 e1 1
df 1 e8 1
e6 1 ef 1
ed 1 f4 1
fa 1 100 1
106 1 10c 1
112 1 118 1
11e 1 124 1
12a 1 132 1
130 1 139 1
137 1 13e 1
143 1 148 1
14e 1 154 1
15a 1 160 1
166 1 16c 1
172 1 178 1
17e 1 184 1
18a 1 196 1
1a2 2 1a5 1a7
2 1aa 1ac 2
1ae 1b0 2 1b2
1b4 2 1b6 1b8
2 1ba 1bc 2
1be 1c0 2 1c2
1c4 2 1c6 1c8
2 1ca 1cc 2
1ce 1d0 2 1d2
1d4 2 1d6 1d8
1 1de 2 1e0
1e1 2 1da 1e3
2 1e5 1e7 2
1e9 1eb 2 1ed
1ef 2 1f1 1f3
2 1f5 1f7 2
1f9 1fb 2 1fd
1ff 2 201 203
2 205 207 1
20d 2 20f 210
2 209 212 2
214 216 1 21c
2 21e 21f 2
218 221 2 223
225 1 22b 2
22d 22e 2 227
230 2 232 234
1 23a 2 23c
23d 2 236 23f
2 241 243 1
249 2 24b 24c
2 245 24e 2
250 252 1 258
2 25a 25b 2
254 25d 2 25f
261 1 267 2
269 26a 2 263
26c 2 26e 270
1 276 2 278
279 2 272 27b
2 27d 27f 1
285 2 287 288
2 281 28a 2
28c 28e 2 290
292 2 294 296
2 298 29a 2
29c 29e 2 2a0
2a2 2 2a4 2a6
2 2a8 2aa 2
2ac 2ae 4 19e
1a4 1a9 2b0 1
2b2 1 2b4 2
2be 2c0 3 2bc
2bd 2c2 2 2cb
2cd 2 2ca 2cf
1 2d1 1 2d3
2 2d6 2d7 1
2dd 2 2d9 2dd
2 2e6 2e7 2
2e9 2ec 2 2ef
2f0 2 2f7 2f8
2 2fa 2fd 4
2f3 300 303 306
2 30a 30b 1
311 2 30d 311
2 317 318 2
31a 31d 2 325
326 2 328 32b
3 321 32f 332
2 337 338 3
33b 33e 341 3
343 334 344 2
35f 360 1 364
2 362 364 2
389 38e 1 395
1 390 2 3a8
3aa 3 3a6 3a7
3ac 2 3b5 3b7
2 3b9 3bb 2
3bd 3bf 2 3c1
3c3 2 3c5 3c7
3 3cc 3cd 3ce
2 3c9 3d0 2
3b4 3d2 1 3d4
1 3d6 2 39f
3d7 1 3db 1
39a 2 398 3df
1 3ea 2 3e6
3ea 2 3f6 3f8
3 3f4 3f5 3fa
2 403 405 2
402 407 1 409
1 40b 2 40c
411 1 413 3
369 3e2 414 2
427 42c 1 433
1 42e 2 446
448 3 444 445
44a 2 453 455
2 457 459 2
45b 45d 2 45f
461 2 463 465
3 46a 46b 46c
2 467 46e 2
452 470 1 472
1 474 2 43d
475 1 479 1
438 2 436 47d
1 488 2 484
488 2 494 496
3 492 493 498
2 4a1 4a3 2
4a0 4a5 1 4a7
1 4a9 2 4aa
4af 2 4b4 4b5
1 4b7 1 4bb
2 4b9 4bb 2
4c6 4c8 3 4c4
4c5 4ca 2 4d3
4d5 2 4d2 4d7
1 4d9 1 4db
2 4dc 4e1 2
4e4 4e3 1 4ee
2 4ed 4ee 1
4f6 1 4fc 2
4fe 4ff 2 4eb
500 1 507 1
502 2 51a 51c
3 518 519 51e
2 527 529 2
52b 52d 2 52f
531 2 533 535
2 537 539 3
53e 53f 540 2
53b 542 2 526
544 1 546 1
548 2 511 549
1 54d 1 50c
2 50a 551 2
558 559 1 55b
1 560 2 55e
560 1 562 2
56b 570 1 577
1 572 2 58a
58c 3 588 589
58e 2 597 599
2 59b 59d 2
59f 5a1 2 5a3
5a5 2 5a7 5a9
3 5ae 5af 5b0
2 5ab 5b2 2
596 5b4 1 5b6
1 5b8 2 581
5b9 1 5bd 1
57c 2 57a 5c1
1 5cc 2 5c8
5cc 2 5d8 5da
3 5d6 5d7 5dc
2 5e5 5e7 2
5e4 5e9 1 5eb
1 5ed 2 5ee
5f3 1 5f5 2
5c4 5f6 1 5f8
1 5fc 5 480
4e5 554 5f9 5ff
2 601 602 2
611 616 1 61d
1 618 2 630
632 3 62e 62f
634 2 63d 63f
2 641 643 2
645 647 2 649
64b 2 64d 64f
3 654 655 656
2 651 658 2
63c 65a 1 65c
1 65e 2 627
65f 1 663 1
622 2 620 667
2 66d 66e 1
672 2 670 672
2 676 677 1
67b 2 679 67b
2 680 681 1
685 2 683 685
2 68d 68e 2
693 694 2 690
696 1 699 1
69b 2 69e 69f
1 6a3 2 6a1
6a3 1 6a6 2
6ac 6ad 1 6b1
2 6af 6b1 2
6b6 6b7 2 6bc
6bd 2 6b9 6bf
1 6c2 1 6c4
1 6c5 2 6d4
6d9 1 6e0 1
6db 2 6f3 6f5
3 6f1 6f2 6f7
2 700 702 2
704 706 2 708
70a 2 70c 70e
2 710 712 3
717 718 719 2
714 71b 2 6ff
71d 1 71f 1
721 2 6ea 722
1 726 1 6e5
2 6e3 72a 1
72d 2 730 731
1 732 2 735
736 1 73a 2
738 73a 2 73f
740 2 742 744
1 747 2 74b
74c 1 750 2
74e 750 2 755
756 2 75b 75c
2 758 75e 1
761 2 766 767
1 76b 2 769
76b 2 770 771
2 776 777 2
773 779 1 77c
3 77f 764 77e
1 780 2 782
783 2 786 787
1 78b 2 789
78b 2 796 798
3 794 795 79a
2 7a3 7a5 2
7a2 7a7 1 7a9
1 7ab 2 7ac
7b1 1 7b3 3
69c 784 7b4 1
7b6 2 7b9 7ba
1 7be 2 7bc
7be 2 7c4 7c5
2 7c7 7ca 1
7ce 3 7d2 7d3
7d4 1 7d8 2
7d6 7d8 2 7dd
7de 1 7e2 2
7e0 7e2 2 7fa
7ff 1 806 1
801 2 819 81b
3 817 818 81d
2 826 828 2
82a 82c 2 82e
830 2 832 834
2 836 838 3
83d 83e 83f 2
83a 841 2 825
843 1 845 1
847 2 810 848
1 84c 1 80b
2 809 850 1
85b 2 857 85b
1 85f 2 869
86a 2 86c 86f
3 877 878 879
1 87d 2 87b
87d 3 884 885
886 1 88a 2
888 88a 3 891
892 893 1 897
2 895 897 2
89b 89c 1 8a0
2 89e 8a0 1
8a5 1 8a7 2
8a8 8ab 1 8ad
1 8ae 2 8b1
8b2 1 8b6 2
8b4 8b6 2 8be
8bf 2 8c1 8c4
1 8c8 1 8ca
2 8cd 8ce 2
8d3 8d4 1 8d6
2 8d0 8d6 2
8da 8db 1 8df
2 8dd 8df 3
8e5 8e6 8e7 1
8eb 2 8e9 8eb
3 8f1 8f2 8f3
1 8f7 2 8f5
8f7 1 8fc 1
8fe 2 929 92a
21 90c 90d 90e
90f 910 911 912
913 914 915 916
917 918 919 91a
91b 91c 91d 91e
91f 920 921 922
923 924 925 926
927 92c 92d 92e
92f 930 4 8ff
904 909 933 1
935 1 93f 2
93e 93f 1 947
1 94d 2 94f
950 2 93c 951
1 958 1 953
2 96b 96d 3
969 96a 96f 2
978 97a 2 97c
97e 2 980 982
2 984 986 2
988 98a 3 98f
990 991 2 98c
993 2 977 995
1 997 1 999
2 962 99a 1
99e 1 95d 2
95b 9a2 2 9af
9b1 3 9ad 9ae
9b3 2 9bc 9be
2 9bb 9c0 1
9c2 1 9c4 4
936 9a5 9c5 9c8
1 9ca 2 8cb
9cb 2 9cd 9ce
2 873 9cf 1
9d1 2 853 9d2
2 9d5 9d4 2
9d8 9d9 1 9dd
2 9db 9dd 2
9e2 9e3 2 9e8
9e9 1 9eb 2
9e5 9eb 2 9f2
9f3 1 9f7 2
9f5 9f7 2 9ff
a00 2 a04 a05
2 a02 a07 1
a0b 1 a0d 18
a11 a12 a13 a14
a15 a16 a17 a18
a19 a1a a1b a1c
a1d a1e a1f a20
a21 a22 a23 a24
a25 a26 a27 a28
2 a0e a2b 2
a2f a30 1 a34
2 a32 a34 2
a38 a39 1 a3d
2 a3b a3d 2
a45 a46 2 a4a
a4b 2 a48 a4d
1 a51 1 a53
18 a57 a58 a59
a5a a5b a5c a5d
a5e a5f a60 a61
a62 a63 a64 a65
a66 a67 a68 a69
a6a a6b a6c a6d
a6e 2 a54 a71
2 a74 a73 2
a77 a78 1 a7c
2 a7a a7c 1
a85 2 a89 a8a
1 a8e 2 a8c
a8e 2 a92 a93
1 a97 2 a95
a97 1 aa2 2
aa5 aa4 1 aab
2 aa9 aab 1
ab2 1 ab4 2
abe ac0 3 abc
abd ac2 2 acb
acd 2 acf ad1
2 ad3 ad5 2
ad7 adb 2 aca
add 1 adf 1
ae1 14 2b5 2d4
345 348 34b 34e
351 354 357 35a
35d 603 66a 7b7
9d6 a75 aa6 ab5
ae2 ae7 32 5e
64 6a 70 76
7c 82 88 8e
94 9b a2 a9
b0 b5 ba c1
c8 cf d6 dd
e4 eb f2 f8
fe 104 10a 110
116 11c 122 128
12e 135 13c 141
146 14c 152 158
15e 164 16a 170
176 17c 182 188
18e 
1
4
0 
aef
0
1
14
11
44
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 0 0 0 
ca 1 0
2 0 1
12a 1 0
41 1 0
39 1 0
f4 1 0
106 1 0
15 1 0
112 1 0
1f 1 0
bc 1 0
29 1 0
160 1 0
130 1 0
25 1 0
d8 1 0
14e 1 0
3 1 0
17e 1 0
b2 1 0
118 1 0
16c 1 0
10c 1 0
b7 1 0
72 1 0
f 1 0
a4 1 0
60 1 0
3d 1 0
8a 1 0
19 1 0
9 1 0
90 1 0
154 1 0
11e 1 0
d1 1 0
7e 1 0
2d 1 0
184 1 0
172 1 0
143 1 0
ab 1 0
15a 1 0
100 1 0
96 1 0
45 1 0
124 1 0
18a 1 0
6c 1 0
66 1 0
178 1 0
df 1 0
78 1 0
fa 1 0
c3 1 0
9d 1 0
35 1 0
5a 1 0
148 1 0
13e 1 0
31 1 0
e6 1 0
166 1 0
4f 1 0
49 1 0
84 1 0
137 1 0
ed 1 0
0

/
SHOW ERRORS FUNCTION FC_U_TSKRES2;
ALTER FUNCTION FC_U_TSKRES2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_TSKRES2
#Short Description :Update resource/profile assignment
#Description       :Gets call from FC_SEARCH_2
#Table Name        :
#Parameters        :
 $$if bitflag  = 0 then insert new assignment (assign_id = RES_ASSIGNMENT_ID)
               = 1 then update an existing assignment (assign_id = TSK_ASSIGNMENT_ID)
               = 2 then insert new assignment using project assignment (assign_id = RES_ASSIGNMENT_ID)
               = 3 then reject a profile replacement, uncommit everything
               = 9 MSP
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_TSKRES2 ==
CREATE OR REPLACE FUNCTION SP_U_TSKRES2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
71
2 :e:
1FUNCTION:
1SP_U_TSKRES2:
1ASSIGN_ID:
1VARCHAR2:
1AND_ROLES:
1AND_SKILLS:
1WORK_LOCATION001:
1PLS_INTEGER:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1WORK001:
1EUNIT:
1UNIT:
1WORK_TYPE:
1BITFLAG001:
1CONTOUR001:
1CONTOUR_TYPE001:
1OCCURRENCE:
1ASSIGN_STRING001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ASSIGN_ID:
132:
1H_AND_ROLES:
18000:
1H_AND_SKILLS:
1H_WORK_LOCATION:
10:
1H_START_DATE:
126:
1H_FINISH_DATE:
1H_EFFORT:
1H_WORK:
1H_EUNIT:
1H_UNIT:
1H_WORK_TYPE:
1H_BITFLAG:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_OCCURRENCE:
1H_ASSIGN_STRING:
18192:
1H_REC_USER:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_TSKRES2(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
164:
1+:
1FPUT:
1               ENTER:: SP_U_TSKRES2(65) :: cplan.sql(7873) :: :
1IS NULL:
18:
172:
1      RETURN_INVALID:: SP_U_TSKRES2(73) :: cplan.sql(7881) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
175:
1                EXIT:: SP_U_TSKRES2(76) :: cplan.sql(7884) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_STATE:
1FC_U_TSKRES2:
14:
1105:
1       RETURN_STATUS:: SP_U_TSKRES2(106) :: cplan.sql(7914) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
116:
1113:
1           EXCEPTION:: SP_U_TSKRES2(114) :: cplan.sql(7922) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
1125:
1           EXCEPTION:: SP_U_TSKRES2(126) :: cplan.sql(7934) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
3ca
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
52 10 a0 7e b4 2e :2 5a 52
10 a0 7e b4 2e :2 5a 52 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :12 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
3ca
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 13a
160 164 168 16c 16f 173 190 17b
17f 182 183 18b 17a 1ad 19b 177
19f 1a0 1a8 19a 1ca 1b8 197 1bc
1bd 1c5 1b7 1e6 1d5 1d9 1b4 1e1
1d4 203 1f1 1d1 1f5 1f6 1fe 1f0
220 20e 1ed 212 213 21b 20d 23c
22b 22f 20a 237 22a 258 247 24b
227 253 246 274 263 267 243 26f
262 290 27f 283 25f 28b 27e 2ac
29b 29f 27b 2a7 29a 2c8 2b7 2bb
297 2c3 2b6 2e4 2d3 2d7 2b3 2df
2d2 300 2ef 2f3 2cf 2fb 2ee 31c
30b 30f 2eb 317 30a 339 327 307
32b 32c 334 326 356 344 323 348
349 351 343 372 361 365 340 36d
360 392 37d 381 35d 385 38d 37c
399 39d 379 3a1 3a5 3a9 3ac 3b1
3b2 1 3b4 3b9 3bd 3c1 3c4 3c9
3cd 3d1 3d4 3d9 3da 3dc 3e1 3e4
3e8 3e9 3ee 3f3 3f6 3fb 3fc 401
404 408 409 40e 411 416 417 41c
41f 424 425 42a 42d 432 433 438
43b 43f 440 445 448 44d 44e 453
456 45b 45c 461 464 469 46a 46f
472 476 477 47c 47f 484 485 48a
48d 492 493 498 49b 49f 4a3 4a7
4a8 4aa 4af 4b0 4b2 4b3 4b8 4bb
4c0 4c1 4c6 4c9 4ce 4cf 4d4 4d7
4db 4dc 4e1 4e4 4e9 4ea 4ef 4f2
4f7 4f8 4fd 500 505 506 50b 50e
512 513 518 51b 520 521 526 529
52e 52f 534 537 53b 53f 543 544
546 54b 54c 54e 54f 554 557 55c
55d 562 565 569 56d 571 572 574
579 57a 57c 57d 582 585 58a 58b
590 593 597 59b 59f 5a0 5a2 5a7
5a8 5aa 5ab 5b0 5b3 5b8 5b9 5be
5c1 5c5 5c9 5cd 5ce 5d0 5d5 5d6
5d8 5d9 5de 5e1 5e6 5e7 5ec 5ef
5f3 5f7 5fb 5fc 5fe 603 604 606
607 60c 60f 614 615 61a 61d 621
625 629 62a 62c 631 632 634 635
63a 63d 642 643 648 64b 64f 653
657 658 65a 65f 660 662 663 668
66b 670 671 676 679 67d 681 685
686 688 68d 68e 690 691 696 699
69e 69f 6a4 6a7 6ab 6af 6b3 6b4
6b6 6bb 6bc 6be 6bf 6c4 6c7 6cc
6cd 6d2 6d5 6da 6db 6e0 6e3 6e7
6e8 6ed 6f0 6f5 6f6 6fb 6fe 703
704 709 70c 711 712 717 71a 71e
71f 724 727 72c 72d 732 735 73a
73b 740 741 746 748 74c 74f 753
757 75a 75e 762 765 768 76d 770
773 776 777 77c 77d 1 77f 784
788 78c 78f 794 799 79c 7a0 7a1
7a6 7a7 7ac 7ae 7b2 7b5 7b9 7bc
7bd 7c2 7c5 7c8 7cc 7cf 7d0 7d5
7d8 1 7db 7e0 7e4 7e7 7e8 7ed
7f0 1 7f3 7f8 7fc 7ff 800 805
808 1 80b 810 814 818 81b 81f
823 826 829 82e 831 834 837 838
83d 83e 1 840 845 849 84d 850
855 85a 85d 861 862 867 86a 86f
870 875 878 87d 87e 883 886 88a
88e 892 896 899 89a 89c 8a1 8a2
8a4 8a5 8aa 8ab 8b0 8b2 8b6 8b9
8bd 8c1 8c4 8c8 8cc 8cf 8d2 8d7
8da 8dd 8e0 8e1 8e6 8e7 1 8e9
8ee 8f2 8f6 8f9 8fe 903 906 90a
90b 910 911 916 918 91c 91f 923
927 92a 92e 932 935 939 93a 93f
941 945 948 94c 950 954 958 95c
960 964 968 96c 970 974 978 97c
980 984 988 98c 990 994 998 99c
9a0 9a4 9a8 9ac 9b0 9b4 9b8 9bc
9c0 9c4 9c8 9cc 9d0 9d4 9d8 9dc
9e0 9e4 9e8 9ec 9f0 9f4 9f8 9fc
a00 a04 a08 a0c a10 a14 a18 a1c
a1f a23 a27 a2b a2f a33 a37 a3b
a3f a43 a47 a4b a4f a53 a57 a5b
a5f a63 a67 a68 a6a a6e a72 a76
a79 a7d a81 a84 a87 a8c a8f a92
a95 a96 a9b a9c 1 a9e aa3 aa7
aab aae ab3 ab8 abb abf ac0 ac5
ac8 acd ace ad3 ad6 adb adc ae1
ae4 ae8 aec af0 af4 af7 af8 afa
aff b00 b02 b03 b08 b0b b10 b11
b16 b19 b1e b1f b24 b27 b2b b2c
b31 b34 b39 b3a b3f b40 b45 b47
b4b b4e b52 b56 b59 b5d b61 b64
b68 b6c b6d b72 b74 b78 b7c b7f
b83 b87 b8a b8e b92 b95 b98 b9d
ba0 ba3 ba6 ba7 bac bad 1 baf
bb4 bb8 bbc bbf bc4 bc9 bcc bd0
bd1 bd6 bd7 bdc be0 be4 be7 bec
bf1 bf4 bf8 bfc bff c00 c05 c08
c0d c0e c13 c16 c1a c1e c21 c22
c27 c28 c2d c2f c33 c36 c3a c3e
c42 c46 c4a c4e c52 c56 c5a c66
c6b c6f c73 c77 c7b c7d c7e c83
1 c87 c8b c8f c92 c96 c9a c9e
ca2 ca5 ca9 cad cb0 cb3 cb8 cbb
cbe cc1 cc2 cc7 cc8 1 cca ccf
cd3 cd7 cda cdf ce4 ce7 ceb cec
cf1 cf2 cf7 cfb cff d02 d07 d0c
d0f d13 d14 d19 d1c d21 d22 d27
d2a d2e d32 d35 d38 d39 d3b d3c
d41 d42 d47 d49 d4d d50 d54 d58
d5c d60 d64 d68 d6c d78 d7d d81
d85 d89 d8d d8f d93 d95 da1 da3
da5 da6 dab daf db1 dbd dc1 dc3
dc4 dcd 
3ca
2
0 1 a 6 10 :3 6 10 :3 6
11 :3 6 17 :3 6 14 :3 6 15 :3 6
10 :3 6 e :3 6 c :3 6 b :3 6
10 :3 6 11 :3 6 11 :3 6 16 :3 6
11 :3 6 17 :3 6 12 :2 6 1 3
a 13 a :2 1 4 10 19 18
:2 10 :2 4 10 19 18 :2 10 :2 4 11
1a 19 :2 11 :2 4 :2 14 23 14 :2 4
11 1a 19 :2 11 :2 4 12 1b 1a
:2 12 :2 4 :2 d 1c d :2 4 :2 b 1a
b :2 4 :2 c 1b c :2 4 :2 b 1a
b :2 4 :2 10 1f 10 :2 4 :2 e 1d
e :2 4 :2 e 1d e :2 4 :2 13 22
13 :2 4 :2 11 20 11 :2 4 14 1d
1c :2 14 :2 4 f 18 17 :2 f :2 4
:2 14 23 14 :2 4 e 17 :3 e 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 54 5a 5d
:2 54 6b 81 8 :2 6b d 10 :2 6b
1a 1d :2 6b b e :2 6b 13 16
:2 6b 1b 1e :2 6b 28 2b :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
29 2c :2 6b b e :2 6b 13 16
1f 27 :2 1f 3a :2 16 :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 2c
2f :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 2d 30 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 33 :2 16
:2 6b b e :2 6b 13 16 1f 27
:2 1f 31 :2 16 :2 6b b e :2 6b 13
16 1f 27 :2 1f 2f :2 16 :2 6b b
e :2 6b 13 16 1f 27 :2 1f 2e
:2 16 :2 6b b e :2 6b 13 16 1f
27 :2 1f 33 :2 16 :2 6b b e :2 6b
13 16 1f 27 :2 1f 34 :2 16 :2 6b
b e :2 6b 13 16 1f 27 :2 1f
34 :2 16 :2 6b b e :2 6b 13 16
1f 27 :2 1f 39 :2 16 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 34 :2 16
:2 6b b e :2 6b 13 16 :2 6b 1b
1e :2 6b 2f 32 :2 6b b e :2 6b
13 16 :2 6b 1b 1e :2 6b 2a 2d
:2 6b 32 35 :2 6b :2 7 4a :2 4 7
:2 11 23 :2 2d 39 3c 4c 4e 4f
:2 4c :2 23 :3 7 :2 d 12 1e 5c 5f
:2 1e :2 7 52 :2 4 :4 9 8 7 :4 22
21 20 :2 7 :4 3f 3e 3d :2 7 :4 f
e d :2 7 a :2 14 26 :2 30 3c
3f 4f 51 52 :2 4f :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b1 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4f 51 52
:2 4f :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 41
:2 7 2a :3 4 13 :2 4 13 :2 4 14
:2 4 14 :2 4 15 :2 4 17 :2 4 12
:2 4 17 :2 4 10 :2 4 e :2 4 f
:2 4 e :2 4 13 :2 4 11 :2 4 11
:2 4 16 :2 4 14 :2 4 :2 d 19 26
33 40 4e 25 33 42 4c 54
5d 25 32 3d 48 58 25 36
:2 19 4 7 :2 11 23 :2 2d 39 3c
4c 4f 50 :2 4c :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e 6d 70 :2 1e 74
77 :2 1e 81 84 8d 95 :2 9e :2 8d
a9 :2 84 :2 1e b1 b4 :2 1e bc bf
:2 1e c4 c7 :2 1e d3 d6 :2 1e :2 7
53 :3 4 :2 f 21 :2 2a 34 41 :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 60 63 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 57 :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 4d 50 51 :2 4d :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
54 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
3ca
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 2
:4 14 :2 1 :7 16 :7 17
:7 18 :6 19 :7 1a :7 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :7 25 :7 26 :6 27
:7 29 :b 2b :11 2c 2d
:2 2c :2 2d :2 2c :2 2d
:2 2c :2 2e :2 2c :2 2e
:2 2c :2 2e :2 2c :2 2e
:2 2c :2 2f :2 2c :2 2f
:2 2c :2 2f :2 2c :2 2f
:2 2c :2 30 :2 2c :9 30
:2 2c :2 31 :2 2c :2 31
:2 2c :2 31 :2 2c :2 31
:2 2c :2 32 :2 2c :2 32
:2 2c :2 32 :2 2c :2 32
:2 2c :2 33 :2 2c :9 33
:2 2c :2 34 :2 2c :9 34
:2 2c :2 35 :2 2c :9 35
:2 2c :2 36 :2 2c :9 36
:2 2c :2 37 :2 2c :9 37
:2 2c :2 38 :2 2c :9 38
:2 2c :2 39 :2 2c :9 39
:2 2c :2 3a :2 2c :9 3a
:2 2c :2 3b :2 2c :9 3b
:2 2c :2 3c :2 2c :2 3c
:2 2c :2 3c :2 2c :2 3c
:2 2c :2 3d :2 2c :2 3d
:2 2c :2 3d :2 2c :2 3d
:2 2c :2 3d :4 2c :3 2b
:11 40 :b 41 :3 40 :16 46
:6 47 :2 46 :11 48 :20 49
:3 48 :11 4b :b 4c :3 4b
:9 4e 47 :2 46 :3 51
:3 52 :3 53 :3 54 :3 55
:3 56 :3 57 :3 59 :3 5a
:3 5b :3 5c :3 5d :3 5e
:3 5f :3 60 :3 61 :3 62
:8 64 :6 65 :5 66 :2 67
:3 64 :11 69 :30 6a :3 69
:a 6c 2a :3 70 :11 71
:b 72 :17 73 :3 71 :2 75
:3 76 :3 77 78 76
75 76 :3 79 :3 70
:2 7a :5 7c :11 7d :b 7e
:18 7f :3 7d :2 81 82
:3 83 84 82 81
82 :3 85 :2 7b :6 7a
6f :7 1 
dcf
4
:3 0 1 :3 0 2
:a 0 3c5 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
4 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 4
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 8
:3 0 12 :7 0 39
38 :3 0 8 :3 0
13 :7 0 3d 3c
:3 0 25 :2 0 23
4 :3 0 14 :7 0
41 40 :3 0 4
:3 0 15 :7 0 45
44 :3 0 16 :3 0
17 :3 0 18 :2 0
4 49 4a 0
47 4b 0 3c5
2 4c :2 0 1c
:2 0 39 4 :3 0
1a :2 0 37 4f
51 :6 0 54 52
0 3c3 0 19
:6 0 1c :2 0 3d
4 :3 0 3b 56
58 :6 0 5b 59
0 3c3 0 1b
:6 0 1f :2 0 41
4 :3 0 3f 5d
5f :6 0 62 60
0 3c3 0 1d
:6 0 21 :2 0 43
8 :3 0 64 :7 0
68 65 66 3c3
0 1e :6 0 21
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 3c3
0 20 :6 0 1f
:2 0 4b 4 :3 0
49 71 73 :6 0
76 74 0 3c3
0 22 :6 0 1f
:2 0 4d 8 :3 0
78 :7 0 7c 79
7a 3c3 0 23
:6 0 1f :2 0 4f
8 :3 0 7e :7 0
82 7f 80 3c3
0 24 :6 0 1f
:2 0 51 8 :3 0
84 :7 0 88 85
86 3c3 0 25
:6 0 1f :2 0 53
8 :3 0 8a :7 0
8e 8b 8c 3c3
0 26 :6 0 1f
:2 0 55 8 :3 0
90 :7 0 94 91
92 3c3 0 27
:6 0 1f :2 0 57
8 :3 0 96 :7 0
9a 97 98 3c3
0 28 :6 0 1f
:2 0 59 8 :3 0
9c :7 0 a0 9d
9e 3c3 0 29
:6 0 1f :2 0 5b
8 :3 0 a2 :7 0
a6 a3 a4 3c3
0 2a :6 0 2d
:2 0 5d 8 :3 0
a8 :7 0 ac a9
aa 3c3 0 2b
:6 0 1a :2 0 61
4 :3 0 5f ae
b0 :6 0 b3 b1
0 3c3 0 2c
:6 0 1f :2 0 65
4 :3 0 63 b5
b7 :6 0 ba b8
0 3c3 0 2e
:6 0 c2 c3 0
67 8 :3 0 bc
:7 0 c0 bd be
3c3 0 2f :6 0
c8 c9 0 69
17 :3 0 18 :2 0
4 c4 :7 0 c7
c5 0 3c3 0
30 :6 0 31 :3 0
32 :3 0 31 :3 0
33 :3 0 cb cc
0 2 :4 0 6b
cd cf ca d1
d0 :2 0 34 :3 0
35 :3 0 d3 d4
0 36 :4 0 31
:3 0 37 :3 0 d7
d8 0 2 :4 0
6d d9 db 38
:4 0 39 :2 0 3a
:3 0 6f de e0
:3 0 3b :4 0 39
:2 0 3c :4 0 72
e3 e5 :3 0 39
:2 0 3 :3 0 75
e7 e9 :3 0 39
:2 0 3c :4 0 78
eb ed :3 0 39
:2 0 3d :4 0 7b
ef f1 :3 0 39
:2 0 3c :4 0 7e
f3 f5 :3 0 39
:2 0 5 :3 0 81
f7 f9 :3 0 39
:2 0 3c :4 0 84
fb fd :3 0 39
:2 0 3d :4 0 87
ff 101 :3 0 39
:2 0 3c :4 0 8a
103 105 :3 0 39
:2 0 6 :3 0 8d
107 109 :3 0 39
:2 0 3c :4 0 90
10b 10d :3 0 39
:2 0 3d :4 0 93
10f 111 :3 0 39
:2 0 3e :3 0 3f
:3 0 7 :3 0 96
115 117 40 :4 0
98 114 11a 9b
113 11c :3 0 39
:2 0 3d :4 0 9e
11e 120 :3 0 39
:2 0 3c :4 0 a1
122 124 :3 0 39
:2 0 9 :3 0 a4
126 128 :3 0 39
:2 0 3c :4 0 a7
12a 12c :3 0 39
:2 0 3d :4 0 aa
12e 130 :3 0 39
:2 0 3c :4 0 ad
132 134 :3 0 39
:2 0 a :3 0 b0
136 138 :3 0 39
:2 0 3c :4 0 b3
13a 13c :3 0 39
:2 0 3d :4 0 b6
13e 140 :3 0 39
:2 0 3e :3 0 3f
:3 0 b :3 0 b9
144 146 40 :4 0
bb 143 149 be
142 14b :3 0 39
:2 0 3d :4 0 c1
14d 14f :3 0 39
:2 0 3e :3 0 3f
:3 0 c :3 0 c4
153 155 40 :4 0
c6 152 158 c9
151 15a :3 0 39
:2 0 3d :4 0 cc
15c 15e :3 0 39
:2 0 3e :3 0 3f
:3 0 d :3 0 cf
162 164 40 :4 0
d1 161 167 d4
160 169 :3 0 39
:2 0 3d :4 0 d7
16b 16d :3 0 39
:2 0 3e :3 0 3f
:3 0 e :3 0 da
171 173 40 :4 0
dc 170 176 df
16f 178 :3 0 39
:2 0 3d :4 0 e2
17a 17c :3 0 39
:2 0 3e :3 0 3f
:3 0 f :3 0 e5
180 182 40 :4 0
e7 17f 185 ea
17e 187 :3 0 39
:2 0 3d :4 0 ed
189 18b :3 0 39
:2 0 3e :3 0 3f
:3 0 10 :3 0 f0
18f 191 40 :4 0
f2 18e 194 f5
18d 196 :3 0 39
:2 0 3d :4 0 f8
198 19a :3 0 39
:2 0 3e :3 0 3f
:3 0 11 :3 0 fb
19e 1a0 40 :4 0
fd 19d 1a3 100
19c 1a5 :3 0 39
:2 0 3d :4 0 103
1a7 1a9 :3 0 39
:2 0 3e :3 0 3f
:3 0 12 :3 0 106
1ad 1af 40 :4 0
108 1ac 1b2 10b
1ab 1b4 :3 0 39
:2 0 3d :4 0 10e
1b6 1b8 :3 0 39
:2 0 3e :3 0 3f
:3 0 13 :3 0 111
1bc 1be 40 :4 0
113 1bb 1c1 116
1ba 1c3 :3 0 39
:2 0 3d :4 0 119
1c5 1c7 :3 0 39
:2 0 3c :4 0 11c
1c9 1cb :3 0 39
:2 0 14 :3 0 11f
1cd 1cf :3 0 39
:2 0 3c :4 0 122
1d1 1d3 :3 0 39
:2 0 3d :4 0 125
1d5 1d7 :3 0 39
:2 0 3c :4 0 128
1d9 1db :3 0 39
:2 0 15 :3 0 12b
1dd 1df :3 0 39
:2 0 3c :4 0 12e
1e1 1e3 :3 0 39
:2 0 41 :4 0 131
1e5 1e7 :3 0 134
d5 1e9 :2 0 1eb
139 1ec d2 1eb
0 1ed 13b 0
323 31 :3 0 32
:3 0 1ee 1ef 0
31 :3 0 42 :3 0
1f1 1f2 0 43
:2 0 2 :4 0 44
:2 0 45 :2 0 43
:2 0 13d 1f7 1f9
:3 0 140 1f3 1fb
1f0 1fd 1fc :2 0
34 :3 0 46 :3 0
1ff 200 0 36
:4 0 47 :4 0 39
:2 0 3a :3 0 144
204 206 :3 0 147
201 208 :2 0 20a
14a 20b 1fe 20a
0 20c 14c 0
323 3 :3 0 48
:2 0 14e 20e 20f
:3 0 210 :2 0 211
:2 0 9 :3 0 48
:2 0 150 214 215
:3 0 216 :2 0 217
:2 0 212 219 218
:2 0 a :3 0 48
:2 0 152 21c 21d
:3 0 21e :2 0 21f
:2 0 21a 221 220
:2 0 14 :3 0 48
:2 0 154 224 225
:3 0 226 :2 0 227
:2 0 222 229 228
:2 0 31 :3 0 32
:3 0 22b 22c 0
31 :3 0 42 :3 0
22e 22f 0 49
:2 0 2 :4 0 4a
:2 0 45 :2 0 43
:2 0 156 234 236
:3 0 159 230 238
22d 23a 239 :2 0
34 :3 0 46 :3 0
23c 23d 0 36
:4 0 4b :4 0 39
:2 0 3a :3 0 15d
241 243 :3 0 39
:2 0 4c :4 0 160
245 247 :3 0 39
:2 0 4d :4 0 163
249 24b :3 0 39
:2 0 3e :3 0 3f
:3 0 4e :3 0 4f
:3 0 250 251 0
166 24f 253 40
:4 0 168 24e 256
16b 24d 258 :3 0
16e 23e 25a :2 0
25c 171 25d 23b
25c 0 25e 173
0 287 31 :3 0
32 :3 0 25f 260
0 31 :3 0 42
:3 0 262 263 0
43 :2 0 2 :4 0
50 :2 0 45 :2 0
43 :2 0 175 268
26a :3 0 178 264
26c 261 26e 26d
:2 0 34 :3 0 46
:3 0 270 271 0
36 :4 0 51 :4 0
39 :2 0 3a :3 0
17c 275 277 :3 0
17f 272 279 :2 0
27b 182 27c 26f
27b 0 27d 184
0 287 52 :3 0
53 :3 0 27e 27f
0 4e :3 0 4f
:3 0 281 282 0
54 :3 0 186 280
285 :2 0 287 189
288 22a 287 0
289 18d 0 323
19 :3 0 3 :3 0
28a 28b 0 323
1b :3 0 5 :3 0
28d 28e 0 323
1d :3 0 6 :3 0
290 291 0 323
20 :3 0 9 :3 0
293 294 0 323
22 :3 0 a :3 0
296 297 0 323
2c :3 0 14 :3 0
299 29a 0 323
2e :3 0 15 :3 0
29c 29d 0 323
1e :3 0 7 :3 0
29f 2a0 0 323
23 :3 0 b :3 0
2a2 2a3 0 323
24 :3 0 c :3 0
2a5 2a6 0 323
25 :3 0 d :3 0
2a8 2a9 0 323
26 :3 0 e :3 0
2ab 2ac 0 323
27 :3 0 f :3 0
2ae 2af 0 323
28 :3 0 10 :3 0
2b1 2b2 0 323
29 :3 0 11 :3 0
2b4 2b5 0 323
2a :3 0 12 :3 0
2b7 2b8 0 323
2b :3 0 13 :3 0
2ba 2bb 0 323
17 :3 0 55 :3 0
2bd 2be 0 56
:3 0 19 :3 0 1b
:3 0 1d :3 0 1e
:3 0 20 :3 0 22
:3 0 23 :3 0 24
:3 0 25 :3 0 26
:3 0 27 :3 0 28
:3 0 29 :3 0 2a
:3 0 2b :3 0 2c
:3 0 2e :3 0 18f
2c0 2d2 2bf 2d3
0 323 31 :3 0
32 :3 0 2d5 2d6
0 31 :3 0 42
:3 0 2d8 2d9 0
57 :2 0 2 :4 0
58 :2 0 45 :2 0
43 :2 0 1a1 2de
2e0 :3 0 1a4 2da
2e2 2d7 2e4 2e3
:2 0 34 :3 0 46
:3 0 2e6 2e7 0
36 :4 0 59 :4 0
39 :2 0 3a :3 0
1a8 2eb 2ed :3 0
39 :2 0 4c :4 0
1ab 2ef 2f1 :3 0
39 :2 0 4d :4 0
1ae 2f3 2f5 :3 0
39 :2 0 3e :3 0
3f :3 0 17 :3 0
55 :3 0 2fa 2fb
0 1b1 2f9 2fd
40 :4 0 1b3 2f8
300 1b6 2f7 302
:3 0 39 :2 0 5a
:4 0 1b9 304 306
:3 0 39 :2 0 3c
:4 0 1bc 308 30a
:3 0 39 :2 0 19
:3 0 1bf 30c 30e
:3 0 39 :2 0 3c
:4 0 1c2 310 312
:3 0 1c5 2e8 314
:2 0 316 1c8 317
2e5 316 0 318
1ca 0 323 52
:3 0 5b :3 0 319
31a 0 17 :3 0
55 :3 0 31c 31d
0 19 :3 0 54
:3 0 1cc 31b 321
:2 0 323 1d0 3c4
17 :3 0 5c :2 0
4 324 325 0
31 :3 0 32 :3 0
327 328 0 31
:3 0 42 :3 0 32a
32b 0 5d :2 0
2 :4 0 5e :2 0
45 :2 0 43 :2 0
1e8 330 332 :3 0
1eb 32c 334 329
336 335 :2 0 34
:3 0 46 :3 0 338
339 0 36 :4 0
5f :4 0 39 :2 0
3a :3 0 1ef 33d
33f :3 0 1f2 33a
341 :2 0 35a 34
:3 0 46 :3 0 343
344 0 36 :4 0
60 :4 0 39 :2 0
17 :3 0 61 :3 0
349 34a 0 1f5
348 34c :3 0 39
:2 0 5a :4 0 1f8
34e 350 :3 0 39
:2 0 17 :3 0 62
:3 0 353 354 0
1fb 352 356 :3 0
1fe 345 358 :2 0
35a 201 35b 337
35a 0 35c 204
0 36c 63 :3 0
30 :3 0 17 :3 0
61 :3 0 64 :3 0
17 :3 0 62 :3 0
65 :3 0 66 :4 0
67 1 :a 0 368
:2 0 36c 35e 366
:2 0 16 :3 0 30
:3 0 36a :2 0 36c
206 36e 20a 36d
36c :2 0 3c2 68
:3 0 17 :3 0 55
:3 0 371 372 0
69 :3 0 373 374
0 3ba 31 :3 0
32 :3 0 376 377
0 31 :3 0 42
:3 0 379 37a 0
5d :2 0 2 :4 0
6a :2 0 45 :2 0
43 :2 0 20c 37f
381 :3 0 20f 37b
383 378 385 384
:2 0 34 :3 0 46
:3 0 387 388 0
36 :4 0 6b :4 0
39 :2 0 3a :3 0
213 38c 38e :3 0
216 389 390 :2 0
3aa 34 :3 0 46
:3 0 392 393 0
36 :4 0 6c :4 0
39 :2 0 69 :3 0
219 397 399 :3 0
39 :2 0 6d :4 0
21c 39b 39d :3 0
39 :2 0 6e :3 0
6f :3 0 43 :2 0
70 :2 0 21f 3a0
3a4 223 39f 3a6
:3 0 226 394 3a8
:2 0 3aa 229 3ab
386 3aa 0 3ac
22c 0 3ba 63
:3 0 30 :3 0 64
:3 0 17 :3 0 62
:3 0 65 :3 0 66
:4 0 71 1 :a 0
3b6 :2 0 3ba 3ae
3b4 :2 0 16 :3 0
30 :3 0 3b8 :2 0
3ba 22e 3bd :3 0
3bd 0 3bd 3bc
3ba 3bb :6 0 3bf
1 :3 0 233 3c1
235 3c0 3bf :2 0
3c2 237 :2 0 3c4
23a 3c4 3c3 323
3c2 :6 0 3c5 :2 0
2 4c 3c4 3c8
:3 0 3c7 3c5 3c9
:8 0 
24e
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 11
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 1 50 1
4e 1 57 1
55 1 5e 1
5c 1 63 1
6b 1 69 1
72 1 70 1
77 1 7d 1
83 1 89 1
8f 1 95 1
9b 1 a1 1
a7 1 af 1
ad 1 b6 1
b4 1 bb 1
c1 1 ce 1
da 2 dd df
2 e2 e4 2
e6 e8 2 ea
ec 2 ee f0
2 f2 f4 2
f6 f8 2 fa
fc 2 fe 100
2 102 104 2
106 108 2 10a
10c 2 10e 110
1 116 2 118
119 2 112 11b
2 11d 11f 2
121 123 2 125
127 2 129 12b
2 12d 12f 2
131 133 2 135
137 2 139 13b
2 13d 13f 1
145 2 147 148
2 141 14a 2
14c 14e 1 154
2 156 157 2
150 159 2 15b
15d 1 163 2
165 166 2 15f
168 2 16a 16c
1 172 2 174
175 2 16e 177
2 179 17b 1
181 2 183 184
2 17d 186 2
188 18a 1 190
2 192 193 2
18c 195 2 197
199 1 19f 2
1a1 1a2 2 19b
1a4 2 1a6 1a8
1 1ae 2 1b0
1b1 2 1aa 1b3
2 1b5 1b7 1
1bd 2 1bf 1c0
2 1b9 1c2 2
1c4 1c6 2 1c8
1ca 2 1cc 1ce
2 1d0 1d2 2
1d4 1d6 2 1d8
1da 2 1dc 1de
2 1e0 1e2 2
1e4 1e6 4 d6
dc e1 1e8 1
1ea 1 1ec 2
1f6 1f8 3 1f4
1f5 1fa 2 203
205 2 202 207
1 209 1 20b
1 20d 1 213
1 21b 1 223
2 233 235 3
231 232 237 2
240 242 2 244
246 2 248 24a
1 252 2 254
255 2 24c 257
2 23f 259 1
25b 1 25d 2
267 269 3 265
266 26b 2 274
276 2 273 278
1 27a 1 27c
2 283 284 3
25e 27d 286 1
288 11 2c1 2c2
2c3 2c4 2c5 2c6
2c7 2c8 2c9 2ca
2cb 2cc 2cd 2ce
2cf 2d0 2d1 2
2dd 2df 3 2db
2dc 2e1 2 2ea
2ec 2 2ee 2f0
2 2f2 2f4 1
2fc 2 2fe 2ff
2 2f6 301 2
303 305 2 307
309 2 30b 30d
2 30f 311 2
2e9 313 1 315
1 317 3 31e
31f 320 17 1ed
20c 289 28c 28f
292 295 298 29b
29e 2a1 2a4 2a7
2aa 2ad 2b0 2b3
2b6 2b9 2bc 2d4
318 322 2 32f
331 3 32d 32e
333 2 33c 33e
2 33b 340 2
347 34b 2 34d
34f 2 351 355
2 346 357 2
342 359 1 35b
3 35c 367 36b
1 326 2 37e
380 3 37c 37d
382 2 38b 38d
2 38a 38f 2
396 398 2 39a
39c 3 3a1 3a2
3a3 2 39e 3a5
2 395 3a7 2
391 3a9 1 3ab
4 375 3ac 3b5
3b9 1 3bd 1
370 2 36e 3c1
13 53 5a 61
67 6e 75 7b
81 87 8d 93
99 9f a5 ab
b2 b9 bf c6

1
4
0 
3c8
0
1
14
2
25
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
43 1 0
2b 1 0
b 1 0
70 1 0
3b 1 0
27 1 0
23 1 0
4e 1 0
f 1 0
bb 1 0
2 0 1
1f 1 0
89 1 0
5c 1 0
77 1 0
a1 1 0
69 1 0
55 1 0
1b 1 0
a7 1 0
95 1 0
3 1 0
33 1 0
13 1 0
83 1 0
7d 1 0
8f 1 0
37 1 0
7 1 0
63 1 0
2f 1 0
b4 1 0
3f 1 0
ad 1 0
9b 1 0
17 1 0
c1 1 0
0

/
SHOW ERRORS FUNCTION SP_U_TSKRES2;
ALTER FUNCTION SP_U_TSKRES2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_ASSIGN_MSP
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_ASSIGN_MSP ==
CREATE OR REPLACE FUNCTION SP_ASSIGN_MSP wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1a2
2 :e:
1FUNCTION:
1SP_ASSIGN_MSP:
1ID:
1VARCHAR2:
1ACTION_TYPE001:
1PLS_INTEGER:
1TASK_ID001:
1START_DT001:
1FINISH_DT001:
1EFFORT001:
1ASSIGN_STRING001:
1WORK_TODATE001:
1PERCENT_COMPLETE001:
1EETC:
1DATA_FLAG:
1UNITS:
1CONTOUR_TYPE001:
1BASELINE_START001:
1BASELINE_FINISH001:
1BASELINE_DURATION001:
1BASELINE_WORK001:
1ACTUAL_START001:
1ACTUAL_FINISH001:
1ACTUAL_EFFORT001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_NAME:
1255:
1H_FULL_NAME:
1H_MESSAGE:
18192:
1H_SUBJECT:
12048:
1H_REVISION:
116:
1H_TEMP_ID:
132:
1H_TEMP_ID2:
1H_WKF_DEF_ID:
1H_UNIQUEID:
1H_RA_ID:
1H_RESOURCE_ID:
1H_PROJECT_ID:
1H_TASK_ID:
1H_REC_USER:
1H_TYPE_ID:
10:
1H_WORK_LOCATION:
1H_ZERO:
1H_TWO:
12:
1H_WORK:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_UNITS:
1H_PER_DAY:
1480:
1H_IMPEX_ROLLUP:
1H_EFFORT:
1H_COUNT:
1H_TOTAL:
1H_MINUTES:
1H_DATA_FLAG:
1H_WORK_TODATE:
1H_DAYOFYEAR:
1DATE:
1H_FINISH_D:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_NULL_STR:
11:
1H_START_DATE:
1TIMESTAMP:
1H_START_DT:
1H_ACTUAL_START:
1H_FINISH_DT:
1H_REC_DT:
1H_LOCK_DT:
1H_ASSIGN_STRING:
1H_TABLE_TYPE:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_OCCURRENCE:
1H_BIT_MINUTES:
1H_ACTION_TYPE:
1H_ETC:
1H_SD:
1H_FD:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_PERCENT_UNITS:
1CURSOR:
1C_H_WBS:
1ELEMENT_NAME:
1RTRIM:
1TO_CHAR:
1MAJOR_REVISION:
1MINOR_REVISION:
1TMT_WBS:
1PROJECT_ID:
1ELEMENT_ID:
1REC_DATETIME:
1ROWNUM:
1SELECT * FROM (SELECT ELEMENT_NAME,RTRIM(TO_CHAR(MAJOR_REVISION)) || '.' || R+
1TRIM(TO_CHAR(MINOR_REVISION)):n         FROM TMT_WBS:n         WHERE PROJECT_+
1ID = h_project_id AND ELEMENT_ID = h_task_id:n         ORDER BY REC_DATETIME +
1DESC ) WHERE ROWNUM<=1:
1CAF:
1SCHED_MIN:
1DAY_YEAR:
1ACTUAL_FLAG:
1TASK_DAY_OF_YEAR:
1TSK_ASSIGNMENT_ID:
1ACTUAL_MIN:
1SELECT SCHED_MIN, DAY_YEAR, ACTUAL_FLAG:n         FROM TASK_DAY_OF_YEAR:n    +
1     WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id:n         FOR UPDATE OF ACTUAL_MIN,ACTUAL_FLAG:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ASSIGN_MSP(:
1':
1, :
1COALESCE:
1NULL:
1);:
1CHECK_TRACE:
1123:
1+:
1FPUT:
1               ENTER:: SP_ASSIGN_MSP(124) :: cplan.sql(8082) :: :
1IS NULL:
1<:
1>:
13:
18:
1129:
1      RETURN_INVALID:: SP_ASSIGN_MSP(130) :: cplan.sql(8088) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1132:
1                EXIT:: SP_ASSIGN_MSP(133) :: cplan.sql(8091) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1139:
1      RETURN_INVALID:: SP_ASSIGN_MSP(140) :: cplan.sql(8098) :: :
1142:
1                EXIT:: SP_ASSIGN_MSP(143) :: cplan.sql(8101) :: :
1265:
1LENGTH:
1SC_ASSIGN_STRING_LENGTH:
1=:
1171:
1      RETURN_INVALID:: SP_ASSIGN_MSP(172) :: cplan.sql(8130) :: :
1174:
1                EXIT:: SP_ASSIGN_MSP(175) :: cplan.sql(8133) :: :
1TYPE_ID:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type_id:n            FROM TMT+
1_WBS WHERE ELEMENT_ID = h_task_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
1194:
1           EXCEPTION:: SP_ASSIGN_MSP(195) :: cplan.sql(8153) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1GETTABLE:
1ASSIGNRESOURCE:
1COUNT:
1DUAL:
1PROFILES:
1PROFILE_ID:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL:n               WHERE EXISTS (SEL+
1ECT 'X' FROM PROFILES:n               WHERE PROJECT_ID = h_project_id AND PRO+
1FILE_ID = h_resource_id):
1221:
1           EXCEPTION:: SP_ASSIGN_MSP(222) :: cplan.sql(8180) :: :
1!=:
15:
11*5:
1IS NOT NULL:
1TO_TIMESTAMP:
1PMO_ORASTD:
1DB2TIMESTAMP:
1SELECT TO_TIMESTAMP(PMO_ORASTD.DB2TIMESTAMP(h_start_DT)) + (5 / 1440.0) INTO +
1h_finish_DT FROM DUAL:
1242:
1           EXCEPTION:: SP_ASSIGN_MSP(243) :: cplan.sql(8201) :: :
1ISWBSDELIV:
1TASK_ID:
1RESOURCE_ID:
1WORK_TODATE:
1PROJECT_ASSIGNMENT_ID:
1UNITS_MSP:
1C_EFFORT:
1C_CONTOUR:
1CONTOUR_TYPE:
1TASK_ASSIGNMENTS:
1SELECT PROJECT_ID, TASK_ID, RESOURCE_ID, WORK_TODATE, PROJECT_ASSIGNMENT_ID,+
1:n            UNITS_MSP, C_EFFORT, C_CONTOUR, CONTOUR_TYPE, REC_DATETIME:n   +
1         INTO h_project_id, h_task_id, h_resource_id, h_work_todate, h_prj_as+
1signment_id,:n            h_percent_units, h_work, h_contour, h_contour_type,+
1 h_rec_DT:n            FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_ra_i+
1d:
1271:
1           EXCEPTION:: SP_ASSIGN_MSP(272) :: cplan.sql(8230) :: :
1SC_SQL_SUCCESS:
1282:
1        RETURN_ERROR:: SP_ASSIGN_MSP(283) :: cplan.sql(8241) :: :
1 ID:: :
1285:
1                EXIT:: SP_ASSIGN_MSP(286) :: cplan.sql(8244) :: :
1PMO_RETURN_ERROR_SP:
1295:
1        RETURN_ERROR:: SP_ASSIGN_MSP(296) :: cplan.sql(8254) :: :
1298:
1                EXIT:: SP_ASSIGN_MSP(299) :: cplan.sql(8257) :: :
1307:
1      RETURN_INVALID:: SP_ASSIGN_MSP(308) :: cplan.sql(8266) :: :
1310:
1                EXIT:: SP_ASSIGN_MSP(311) :: cplan.sql(8269) :: :
1SC_BIT_28:
1103079040:
1MINUTE_PER_DAY:
1SELECT COALESCE(MINUTE_PER_DAY, 480) INTO h_per_day FROM TMT_WBS WHERE ELEMEN+
1T_ID = h_task_id:
1335:
1           EXCEPTION:: SP_ASSIGN_MSP(336) :: cplan.sql(8294) :: :
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000:
10.49:
1BITAND:
1FC_U_TSKRES2:
1ETC:
1PROPOSED_START:
1SCHED_START:
1PROPOSED_FINISH:
1SCHED_FINISH:
1PROPOSED_WORK:
1SCHED_WORK:
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                        PROPOSED_STA+
1RT = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n +
1                       WHERE PROJECT_ID = h_project_id AND TASK_ID = h_task_i+
1d AND RESOURCE_ID = h_resource_id:
1FOUND:
1100:
1406:
1           EXCEPTION:: SP_ASSIGN_MSP(407) :: cplan.sql(8365) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                        PROPOSED_STA+
1RT = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n +
1                       WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1444:
1           EXCEPTION:: SP_ASSIGN_MSP(445) :: cplan.sql(8403) :: :
1MILESTONE_PERCENT:
1ACTUAL_START:
1ACTUAL_FINISH:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1              UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n          +
1           PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOS+
1ED_WORK = SCHED_WORK,:n                     ACTUAL_START = h_start_DT, ACTUAL+
1_FINISH = h_finish_DT,:n                     WORK_TODATE = work_todate001,:n +
1                    ETC = eetc:n                     WHERE TSK_ASSIGNMENT_ID +
1= h_ra_id:
1481:
1           EXCEPTION:: SP_ASSIGN_MSP(482) :: cplan.sql(8440) :: :
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = SCHED_MIN, ACTUAL_FLAG = 1:n        +
1             WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_ra_id:
1501:
1           EXCEPTION:: SP_ASSIGN_MSP(502) :: cplan.sql(8460) :: :
1LAST_SUBMITTED:
1UPDATE TASK_ASSIGNMENTS SET LAST_SUBMITTED = h_finish_DT:n                   +
1  WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1521:
1           EXCEPTION:: SP_ASSIGN_MSP(522) :: cplan.sql(8480) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                     PROPOSED_START +
1= SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n    +
1                 WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1542:
1           EXCEPTION:: SP_ASSIGN_MSP(543) :: cplan.sql(8501) :: :
1SC_NOT_32:
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                     PROPOSED_START +
1= SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n    +
1                 WHERE PROJECT_ID = h_project_id AND TASK_ID = h_task_id AND +
1RESOURCE_ID = h_resource_id:
1575:
1           EXCEPTION:: SP_ASSIGN_MSP(576) :: cplan.sql(8534) :: :
1SELECT SUBSTR(h_lock_DT,1,10) || '-' || SUBSTR(h_lock_DT,12,2) || '.' || SUBS+
1TR(h_lock_DT,15,2) || '.' || SUBSTR(h_lock_DT,18,9) INTO h_lock_DT FROM DUAL:
1597:
1           EXCEPTION:: SP_ASSIGN_MSP(598) :: cplan.sql(8556) :: :
1STRNCMP:
119:
1SC_TASK:
1TMT_WORKFLOW_CYCLES:
1PARENT_ID:
1SELECT ELEMENT_ID INTO h_wkf_def_id:n                        FROM TMT_WORKFLO+
1W_CYCLES:n                        WHERE PARENT_ID = 'NOTIFICATION':
1618:
1           EXCEPTION:: SP_ASSIGN_MSP(619) :: cplan.sql(8577) :: :
1FC_A_NOTIFICATION:
1OPEN:
1CLOSE:
1652:
1           EXCEPTION:: SP_ASSIGN_MSP(653) :: cplan.sql(8611) :: :
1FULL_NAME:
1RESOURCES:
1SELECT FULL_NAME INTO h_full_name FROM RESOURCES:n                           +
1WHERE RESOURCE_ID = h_resource_id:
1668:
1           EXCEPTION:: SP_ASSIGN_MSP(669) :: cplan.sql(8627) :: :
1Import of assignment failed.:
1Import cannot modify assignment for resource:: :
1 on the task:::
1. Assignment was modified in Timesheets during the time of export of the proj+
1ect.:
1FC_U_WORKFLOW:
1689:
1        RETURN_ERROR:: SP_ASSIGN_MSP(690) :: cplan.sql(8648) :: :
1692:
1                EXIT:: SP_ASSIGN_MSP(693) :: cplan.sql(8651) :: :
1724:
1           EXCEPTION:: SP_ASSIGN_MSP(725) :: cplan.sql(8683) :: :
1735:
1        RETURN_ERROR:: SP_ASSIGN_MSP(736) :: cplan.sql(8694) :: :
1738:
1                EXIT:: SP_ASSIGN_MSP(739) :: cplan.sql(8697) :: :
1RES_ASSIGNMENT_ID:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,+
1PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actual_st+
1art001,:n                        ACTUAL_FINISH = actual_finish001,:n         +
1               WORK_TODATE = actual_effort001:n                        WHERE +
1RES_ASSIGNMENT_ID = h_ra_id:
1773:
1           EXCEPTION:: SP_ASSIGN_MSP(774) :: cplan.sql(8732) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units,:n                        CONTOUR_TYPE =+
1 h_contour_type:n                        WHERE RES_ASSIGNMENT_ID = h_ra_id:
1795:
1           EXCEPTION:: SP_ASSIGN_MSP(796) :: cplan.sql(8754) :: :
1BASELINE3_START:
1BASELINE3_SCH_FLAG:
1BASELINE3_FINISH:
1BASELINE3_DURATION:
1BASELINE3_WORK:
1BASELINE2_START:
1BASELINE1_START:
1BASELINE2_FINISH:
1BASELINE1_FINISH:
1BASELINE2_DURATION:
1BASELINE1_DURATION:
1BASELINE2_WORK:
1BASELINE1_WORK:
1B_REGULAR_COST:
1REGULAR_COST:
1B_REGULAR_RATE:
1REGULAR_RATE:
1B_SPECIAL_COST:
1SPECIAL_COST:
1B_SPECIAL_RATE:
1SPECIAL_RATE:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = R+
1EGULAR_RATE, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n +
1                       :n                        BASELINE3_SCH_FLAG = 1,:n   +
1                     PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FIN+
1ISH,PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actua+
1l_start001,:n                        ACTUAL_FINISH = actual_finish001,:n     +
1                   WORK_TODATE = actual_effort001:n                        WH+
1ERE RES_ASSIGNMENT_ID = h_ra_id:
1840:
1           EXCEPTION:: SP_ASSIGN_MSP(841) :: cplan.sql(8799) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = R+
1EGULAR_RATE, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n +
1                       :n                        BASELINE3_SCH_FLAG = 1:n    +
1                    WHERE RES_ASSIGNMENT_ID = h_ra_id:
1879:
1           EXCEPTION:: SP_ASSIGN_MSP(880) :: cplan.sql(8838) :: :
1ELSIF:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1           UNITS_MSP = h_units,:n                  CONTOUR_TYPE = h_contour_t+
1ype:n                  WHERE RES_ASSIGNMENT_ID = h_ra_id:
1903:
1           EXCEPTION:: SP_ASSIGN_MSP(904) :: cplan.sql(8862) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,+
1PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actual_st+
1art001,:n                        ACTUAL_FINISH = actual_finish001,:n         +
1               WORK_TODATE = actual_effort001:n                        WHERE +
1TSK_ASSIGNMENT_ID = h_ra_id:
1933:
1           EXCEPTION:: SP_ASSIGN_MSP(934) :: cplan.sql(8892) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001:n                        WHERE +
1TSK_ASSIGNMENT_ID = h_ra_id:
1955:
1           EXCEPTION:: SP_ASSIGN_MSP(956) :: cplan.sql(8914) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = R+
1EGULAR_RATE, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n +
1                       :n                        BASELINE3_SCH_FLAG = 1,:n   +
1                     PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FIN+
1ISH,PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actua+
1l_start001,:n                        ACTUAL_FINISH = actual_finish001,:n     +
1                   WORK_TODATE = actual_effort001:n                        WH+
1ERE TSK_ASSIGNMENT_ID = h_ra_id:
11000:
1           EXCEPTION:: SP_ASSIGN_MSP(1001) :: cplan.sql(8959) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001,:n                        BASEL+
1INE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(baseline_star+
1t001) ELSE BASELINE3_START END,:n                        BASELINE3_FINISH = C+
1ASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(baseline_finish001) ELSE BA+
1SELINE3_FINISH END,:n                        BASELINE3_DURATION = CASE WHEN B+
1ASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BASELINE3_DURATION END,+
1:n                        BASELINE3_WORK = CASE WHEN BASELINE3_SCH_FLAG = 0 T+
1HEN baseline_work001 ELSE BASELINE3_WORK END,:n                        :n    +
1                    BASELINE2_START = BASELINE1_START,:n                     +
1   BASELINE2_FINISH = BASELINE1_FINISH,:n                        BASELINE2_DU+
1RATION = BASELINE1_DURATION,:n                        BASELINE2_WORK = BASELI+
1NE1_WORK,:n                        :n                        BASELINE1_START +
1= baseline_start001,:n                        BASELINE1_FINISH = baseline_fin+
1ish001,:n                        BASELINE1_DURATION = baseline_duration001,:n+
1                        BASELINE1_WORK = baseline_work001,:n                 +
1       B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = REGULAR_RATE, B_SPECIA+
1L_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n                      +
1  :n                        BASELINE3_SCH_FLAG = 1:n                        W+
1HERE TSK_ASSIGNMENT_ID = h_ra_id:
11039:
1           EXCEPTION:: SP_ASSIGN_MSP(1040) :: cplan.sql(8998) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001,:n                        ETC =+
1 h_effort - work_todate001:n                        WHERE TSK_ASSIGNMENT_ID =+
1 h_ra_id:
11066:
1           EXCEPTION:: SP_ASSIGN_MSP(1067) :: cplan.sql(9025) :: :
11088:
1           EXCEPTION:: SP_ASSIGN_MSP(1089) :: cplan.sql(9047) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1              UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n          +
1           WORK_TODATE = work_todate001:n                     WHERE TSK_ASSIG+
1NMENT_ID = h_ra_id:
11111:
1           EXCEPTION:: SP_ASSIGN_MSP(1112) :: cplan.sql(9070) :: :
1:
1TO_DATE:
1BILLABLE:
1CAPITAL_EXPENSE:
1SELECT TSK_ASSIGNMENT_ID, SCHED_WORK, TASK_ID, TO_DATE(SubStr(SCHED_START, 1,+
1 10)), TO_DATE(SubStr(SCHED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGUL+
1AR_COST, REGULAR_RATE:n                  INTO h_tsk_assignment_id, h_effort, +
1h_task_id, h_SD, h_FD, h_billable, h_capital_expense, h_reg_cost, h_reg_sale+
1:n                  FROM TASK_ASSIGNMENTS:n                  WHERE RES_ASSIGN+
1MENT_ID = h_ra_id:
11142:
1           EXCEPTION:: SP_ASSIGN_MSP(1143) :: cplan.sql(9101) :: :
1SELECT SCHED_WORK, TASK_ID, TO_DATE(SubStr(SCHED_START, 1, 10)), TO_DATE(SubS+
1tr(SCHED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RA+
1TE:n                  INTO h_effort, h_task_id, h_SD, h_FD, h_billable, h_cap+
1ital_expense, h_reg_cost, h_reg_sale:n                  FROM TASK_ASSIGNMENTS+
1:n                  WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11161:
1           EXCEPTION:: SP_ASSIGN_MSP(1162) :: cplan.sql(9120) :: :
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = SCHED_MIN, ACTUAL_FLAG = 1:n        +
1             WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_as+
1signment_id:
11186:
1           EXCEPTION:: SP_ASSIGN_MSP(1187) :: cplan.sql(9145) :: :
1MAX:
1UPDATE TASK_ASSIGNMENTS SET WORK_TODATE = SCHED_WORK,:n                     L+
1AST_SUBMITTED = (SELECT MAX(DAY_YEAR) FROM TASK_DAY_OF_YEAR:n                +
1     WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id):n                     WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11208:
1           EXCEPTION:: SP_ASSIGN_MSP(1209) :: cplan.sql(9167) :: :
1LOOP:
1EXIT:
1>=:
1-:
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = h_minutes, ACTUAL_FLAG = 1 WHERE CUR+
1RENT OF CAF:
11267:
1           EXCEPTION:: SP_ASSIGN_MSP(1268) :: cplan.sql(9226) :: :
11290:
1           EXCEPTION:: SP_ASSIGN_MSP(1291) :: cplan.sql(9249) :: :
1UPDATE TASK_ASSIGNMENTS SET LAST_SUBMITTED = h_finish_D WHERE TSK_ASSIGNMENT_+
1ID = h_tsk_assignment_id:
11311:
1           EXCEPTION:: SP_ASSIGN_MSP(1312) :: cplan.sql(9270) :: :
1FC_GENERATE_TS_ALL:
1FC_GENERATE_TS_MSP:
14:
11407:
1       RETURN_STATUS:: SP_ASSIGN_MSP(1408) :: cplan.sql(9366) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
11415:
1           EXCEPTION:: SP_ASSIGN_MSP(1416) :: cplan.sql(9374) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11427:
1           EXCEPTION:: SP_ASSIGN_MSP(1428) :: cplan.sql(9386) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1e7a
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a0 f4 b4 bf c8 :e a0
12a bd b7 11 a4 b1 a0 f4
b4 bf c8 :a a0 12a bd b7 11
a4 b1 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e :2 5a :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a 52 10
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c a0 4d d a0 4d d a0
51 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d a0 51
d :3 a0 a5 b 51 a5 b a0
7e a0 6b b4 2e :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 a0 7e b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :7 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 b4 2e d :4 a0 51 a5 b
a5 b d :8 a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e 52
10 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
a0 51 d :8 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
a0 51 d a0 6e d a0 7e
b4 2e 5a :6 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 19 3c b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e 5a :3 a0
51 a5 b a5 b 5a 7e 51
b4 2e a 10 a0 51 d b7
19 3c b7 :2 a0 d :17 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 5a a 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 51
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b 51 :2 a0 a5 57 b7 19 3c
b7 :2 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c a0 7e b4 2e 5a
a0 7e b4 2e 5a 52 10 a0
7e b4 2e 5a 52 10 a0 7e
b4 2e 5a 52 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 19 3c :3 a0
6b d :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 19 3c
:6 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :5 a0 a5 b 51 a5 b
7e :3 a0 a5 b 51 a5 b b4
2e 5a 7e 51 b4 2e 5a 7e
51 b4 2e a5 b d :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e a0 51 d a0 51 d
b7 a0 51 d b7 :2 19 3c b7
19 3c a0 4d d :3 a0 51 a5
b 51 a5 b 5a 7e 51 b4
2e :2 a0 51 a5 b 7e 51 b4
2e :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :12 a0 a5 b d :2 a0
6b 7e 51 b4 2e :f a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 :2 a0 6b :12 a0 a5 b d b7
:2 19 3c b7 :3 a0 51 a5 b 7e
51 b4 2e d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :12 a0 a5
b d :2 a0 6b 7e 51 b4 2e
:b a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 :2 a0 6b :12 a0 a5
b d b7 :2 19 3c b7 :2 19 3c
:2 a0 6b 7e 51 b4 2e 5a :3 a0
51 a5 b 51 a5 b 5a 7e
51 b4 2e 5a a 10 :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :17 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :8 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 19 3c
b7 :4 a0 51 a5 b :2 a0 6b a5
b d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :12 a0 a5 b d
:2 a0 6b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :f a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 a0 7e b4 2e 5a :2 a0 d
:a a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e :3 a0 6b d a0
51 d :4 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :8 a0 a5 b d
:2 a0 51 a5 b 7e 51 b4 2e
a0 4d d a0 4d d a0 4d
d a0 4d d a0 4d d :2 a0
e9 dd b3 :3 a0 e9 d3 5 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 6e d a0 6e d
:3 a0 7e a0 b4 2e :2 51 a5 b
d :3 a0 7e 6e b4 2e :2 51 a5
b d :3 a0 7e a0 b4 2e :2 51
a5 b d :3 a0 7e 6e b4 2e
:2 51 a5 b d :11 a0 a5 b d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :2 a0
51 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b 51 :2 a0 a5 57 b7 19
3c b7 19 3c b7 19 3c :3 a0
51 a5 b 7e 51 b4 2e d
:2 a0 6b :12 a0 a5 b d :2 a0 6b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :b a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c b7 :2 19
3c b7 :2 19 3c :2 a0 6b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :2 a0 d :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 a0 51 d b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 51 a5 b 5a
7e 51 b4 2e a0 7e b4 2e
5a a0 7e b4 2e 5a :15 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 a0 7e b4 2e 5a
:40 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :34 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :2 19 3c a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :3 a0 51 a5
b 51 a5 b 5a 7e 51 b4
2e a0 7e b4 2e 5a a0 7e
b4 2e 5a :15 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
a0 7e b4 2e 5a :40 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :36 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :2 19 3c a0 b7 :2 a0 51
a5 b 7e 51 b4 2e a0 7e
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e :e a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:b a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c b7 :2 19
3c a0 7e b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 a0 6e d
a0 4d d a0 51 d a0 51
d :2 a0 51 a5 b 7e 51 b4
2e :19 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 a0 d :17 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :8 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :d a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 a0 e9 dd b3 :5 a0 e9 d3 5
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
7e 51 b4 2e a0 2b b7 19
3c :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :3 a0 51 a5
b d b7 :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e 7e :2 a0
51 a5 b b4 2e d b7 :2 19
3c b7 19 3c :5 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 d b7 19
3c :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e a0 2b b7
19 3c b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
5a a0 7e b4 2e :2 5a a 10
:5 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 :2 19 3c :2 a0 51
a5 b 7e 51 b4 2e :3 a0 51
a5 b 51 a5 b 5a 7e 51
b4 2e :4 a0 a5 b d b7 :4 a0
a5 b d b7 :2 19 3c b7 19
3c b7 19 3c b7 19 3c b7
19 3c :2 a0 6b 7e 51 b4 2e
:2 a0 6b 51 d b7 19 3c b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
1e7a
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 168
164 13a 170 179 175 163 181 18e
18a 160 196 19f 19b 189 1a7 186
1ac 1b0 1b4 1b8 1bb 1bf 1dc 1c7
1cb 1ce 1cf 1d7 1c6 1f9 1e7 1c3
1eb 1ec 1f4 1e6 216 204 1e3 208
209 211 203 233 221 200 225 226
22e 220 250 23e 21d 242 243 24b
23d 26d 25b 23a 25f 260 268 25a
28a 278 257 27c 27d 285 277 2a7
295 274 299 29a 2a2 294 2c4 2b2
291 2b6 2b7 2bf 2b1 2e1 2cf 2ae
2d3 2d4 2dc 2ce 2fe 2ec 2cb 2f0
2f1 2f9 2eb 31b 309 2e8 30d 30e
316 308 338 326 305 32a 32b 333
325 355 343 322 347 348 350 342
371 360 364 33f 36c 35f 38d 37c
380 35c 388 37b 3a9 398 39c 378
3a4 397 3c5 3b4 3b8 394 3c0 3b3
3e1 3d0 3d4 3b0 3dc 3cf 3fd 3ec
3f0 3cc 3f8 3eb 419 408 40c 3e8
414 407 435 424 428 404 430 423
451 440 444 420 44c 43f 46d 45c
460 43c 468 45b 489 478 47c 458
484 477 4a5 494 498 474 4a0 493
4c1 4b0 4b4 490 4bc 4af 4dd 4cc
4d0 4ac 4d8 4cb 4f9 4e8 4ec 4c8
4f4 4e7 515 504 508 4e4 510 503
531 520 524 52c 500 549 538 53c
544 51f 566 554 51c 558 559 561
553 583 571 550 575 576 57e 570
5a0 58e 56d 592 593 59b 58d 5bc
5ab 5af 5b7 58a 5d4 5c3 5c7 5cf
5aa 5f0 5df 5e3 5eb 5a7 608 5f7
5fb 603 5de 624 613 617 61f 5db
63c 62b 62f 637 612 659 647 60f
64b 64c 654 646 675 664 668 643
670 663 691 680 684 660 68c 67f
6ad 69c 6a0 67c 6a8 69b 6c9 6b8
6bc 698 6c4 6b7 6e5 6d4 6d8 6b4
6e0 6d3 701 6f0 6f4 6d0 6fc 6ef
71d 70c 710 6ec 718 70b 739 728
72c 734 708 751 740 744 74c 727
76d 75c 760 724 768 75b 789 778
77c 758 784 777 7a5 794 798 774
7a0 793 7c1 7b0 7b4 790 7bc 7af
7dd 7cc 7d0 7ac 7d8 7cb 7f9 7e8
7ec 7c8 7f4 7e7 800 804 7e4 815
818 81c 820 824 828 82c 830 834
838 83c 840 844 848 84c 850 854
860 865 867 873 877 879 87d 88e
88f 892 896 89a 89e 8a2 8a6 8aa
8ae 8b2 8b6 8ba 8be 8ca 8cf 8d1
8dd 8e1 8ff 8e7 8eb 8ef 8f2 8fa
8e6 906 90a 8e3 90e 912 916 919
91e 91f 1 921 926 92a 92e 931
936 93a 93e 941 946 947 949 94e
951 955 956 95b 960 963 968 969
96e 971 975 976 97b 97e 983 984
989 98c 991 992 997 99a 99e 9a2
9a6 9a7 9a9 9ae 9af 9b1 9b2 9b7
9ba 9bf 9c0 9c5 9c8 9cd 9ce 9d3
9d6 9da 9db 9e0 9e3 9e8 9e9 9ee
9f1 9f6 9f7 9fc 9ff a04 a05 a0a
a0d a11 a12 a17 a1a a1f a20 a25
a28 a2d a2e a33 a36 a3b a3c a41
a44 a48 a49 a4e a51 a56 a57 a5c
a5f a64 a65 a6a a6d a71 a75 a79
a7a a7c a81 a82 a84 a85 a8a a8d
a92 a93 a98 a9b aa0 aa1 aa6 aa9
aad aae ab3 ab6 abb abc ac1 ac4
ac9 aca acf ad2 ad6 ada ade adf
ae1 ae6 ae7 ae9 aea aef af2 af7
af8 afd b00 b04 b08 b0c b0d b0f
b14 b15 b17 b18 b1d b20 b25 b26
b2b b2e b32 b36 b3a b3b b3d b42
b43 b45 b46 b4b b4e b53 b54 b59
b5c b60 b64 b68 b69 b6b b70 b71
b73 b74 b79 b7c b81 b82 b87 b8a
b8e b92 b96 b97 b99 b9e b9f ba1
ba2 ba7 baa baf bb0 bb5 bb8 bbc
bc0 bc4 bc5 bc7 bcc bcd bcf bd0
bd5 bd8 bdd bde be3 be6 beb bec
bf1 bf4 bf8 bf9 bfe c01 c06 c07
c0c c0f c14 c15 c1a c1d c22 c23
c28 c2b c2f c30 c35 c38 c3d c3e
c43 c46 c4b c4c c51 c54 c58 c5c
c60 c61 c63 c68 c69 c6b c6c c71
c74 c79 c7a c7f c82 c86 c8a c8e
c8f c91 c96 c97 c99 c9a c9f ca2
ca7 ca8 cad cb0 cb5 cb6 cbb cbe
cc2 cc3 cc8 ccb cd0 cd1 cd6 cd9
cde cdf ce4 ce7 cec ced cf2 cf5
cf9 cfa cff d02 d07 d08 d0d d10
d15 d16 d1b d1e d22 d26 d2a d2b
d2d d32 d33 d35 d36 d3b d3e d43
d44 d49 d4c d51 d52 d57 d5a d5e
d5f d64 d67 d6c d6d d72 d75 d7a
d7b d80 d81 d86 d88 d8c d8f d93
d97 d9a d9e da2 da5 da8 dad db0
db3 db6 db7 dbc dbd 1 dbf dc4
dc8 dcc dcf dd4 dd9 ddc de0 de1
de6 de7 dec dee df2 df5 df9 dfc
dfd e02 e05 e08 e0c e10 e13 e14
e16 e19 e1c e1d e22 e25 e29 e2d
e30 e31 e33 e36 e39 e3a e3f 1
e42 e47 1 e4a e4f e53 e57 e5a
e5e e62 e65 e68 e6d e70 e73 e76
e77 e7c e7d 1 e7f e84 e88 e8c
e8f e94 e99 e9c ea0 ea1 ea6 ea9
eae eaf eb4 eb7 ebc ebd ec2 ec5
ec9 ecd ed1 ed5 ed8 ed9 edb ee0
ee1 ee3 ee4 ee9 eea eef ef1 ef5
ef8 efc f00 f03 f07 f0b f0e f11
f16 f19 f1c f1f f20 f25 f26 1
f28 f2d f31 f35 f38 f3d f42 f45
f49 f4a f4f f50 f55 f57 f5b f5e
f62 f66 f69 f6d f71 f74 f78 f79
f7e f80 f84 f87 f8b f8e f8f f94
f97 f9a f9e fa1 fa2 fa7 faa 1
fad fb2 fb6 fb9 fba fbf fc2 1
fc5 fca fce fd2 fd5 fd9 fdd fe0
fe3 fe8 feb fee ff1 ff2 ff7 ff8
1 ffa fff 1003 1007 100a 100f 1014
1017 101b 101c 1021 1024 1029 102a 102f
1032 1037 1038 103d 1040 1044 1048 104c
1050 1053 1054 1056 105b 105c 105e 105f
1064 1065 106a 106c 1070 1073 1077 107b
107e 1082 1086 1089 108c 1091 1094 1097
109a 109b 10a0 10a1 1 10a3 10a8 10ac
10b0 10b3 10b8 10bd 10c0 10c4 10c5 10ca
10cb 10d0 10d2 10d6 10d9 10dd 10e1 10e4
10e8 10ec 10ef 10f3 10f4 10f9 10fb 10ff
1102 1106 1107 110b 110f 1110 1114 1118
111b 111f 1123 1127 112b 112f 1133 1137
113b 113f 1143 1147 114b 114f 1153 1157
115b 115f 1163 1167 116b 116f 1173 1177
117b 117f 1183 1187 118b 118f 1193 1197
119b 119e 11a2 11a6 11aa 11ae 11af 11b1
11b4 11b5 11b7 11bb 11be 11c2 11c5 11c6
11cb 11cf 11d3 11d6 11d7 11d9 11dc 11df
11e0 11e5 11e8 11ec 11f0 11f3 11f4 11f6
11f9 11fc 11fd 1202 1 1205 120a 120e
1211 1212 1217 121a 121e 1222 1225 1229
122d 1230 1233 1238 123b 123e 1241 1242
1247 1248 1 124a 124f 1253 1257 125a
125f 1264 1267 126b 126c 1271 1274 1279
127a 127f 1282 1287 1288 128d 1290 1294
1298 129c 12a0 12a3 12a4 12a6 12ab 12ac
12ae 12af 12b4 12b5 12ba 12bc 12c0 12c3
12c7 12cb 12ce 12d2 12d6 12d9 12dc 12e1
12e4 12e7 12ea 12eb 12f0 12f1 1 12f3
12f8 12fc 1300 1303 1308 130d 1310 1314
1315 131a 131b 1320 1322 1326 1329 132d
1331 1334 1338 133c 133f 1343 1344 1349
134b 134f 1352 1356 135a 135e 1362 1366
136a 136e 1372 1376 137a 137e 1382 1386
138a 138e 1392 139e 13a2 13a6 13a9 13ad
13b1 13b3 13b7 13bb 13bf 13c2 13c6 13ca
13cc 13cd 13d2 1 13d6 13da 13de 13e1
13e5 13e9 13ed 13f1 13f4 13f8 13fc 13ff
1402 1407 140a 140d 1410 1411 1416 1417
1 1419 141e 1422 1426 1429 142e 1433
1436 143a 143b 1440 1443 1448 1449 144e
1451 1456 1457 145c 145f 1463 1464 1469
146c 1471 1472 1477 147a 147e 1482 1485
1488 1489 148b 148c 1491 1492 1497 1499
149d 14a0 14a2 14a6 14a8 14b4 14b6 14b8
14b9 14be 14c2 14c4 14d0 14d2 14d6 14da
14db 14e0 14e4 14e8 14ec 14f0 14f4 14f7
14f8 14fa 14fb 14fd 1501 1505 1509 150d
1511 1515 1519 151d 1521 1522 1524 1528
152c 1530 1533 1534 1536 1539 153c 153d
1542 1546 154a 154d 154e 1550 1553 1556
1557 1 155c 1561 1564 1568 156c 156f
1570 1572 1575 1578 1579 157e 1 1581
1586 158a 158e 1591 1592 1594 1597 159a
159b 15a0 1 15a3 15a8 15ac 15af 15b3
15b7 15bb 15bf 15c3 15c7 15cb 15cf 15d3
15df 15e3 15e7 15ea 15ee 15f2 15f4 15f8
15fc 1600 1603 1607 160b 160d 160e 1613
1 1617 161b 161f 1622 1626 162a 162e
1632 1635 1639 163d 1640 1643 1648 164b
164e 1651 1652 1657 1658 1 165a 165f
1663 1667 166a 166f 1674 1677 167b 167c
1681 1684 1689 168a 168f 1692 1697 1698
169d 16a0 16a4 16a5 16aa 16ad 16b2 16b3
16b8 16bb 16bf 16c3 16c6 16c9 16ca 16cc
16cd 16d2 16d3 16d8 16da 16de 16e1 16e3
16e7 16e9 16f5 16f7 16f9 16fa 16ff 1703
1705 1711 1713 1717 171b 171e 171f 1721
1724 1727 1728 172d 1731 1734 1738 173c
173f 1743 1747 174c 1750 1754 1757 1758
175d 1760 1764 1768 176c 1770 1774 1778
1784 1788 178c 178f 1793 1797 1799 179d
17a1 17a5 17a8 17ac 17b0 17b2 17b3 17b8
1 17bc 17c0 17c4 17c7 17cb 17cf 17d3
17d7 17da 17de 17e2 17e5 17e8 17ed 17f0
17f3 17f6 17f7 17fc 17fd 1 17ff 1804
1808 180c 180f 1814 1819 181c 1820 1821
1826 1829 182e 182f 1834 1837 183c 183d
1842 1845 1849 184a 184f 1852 1857 1858
185d 1860 1864 1868 186b 186e 186f 1871
1872 1877 1878 187d 187f 1883 1886 1888
188c 188e 189a 189c 189e 189f 18a4 18a8
18aa 18b6 18b8 18ba 18be 18c1 18c3 18c7
18ca 18cc 18d0 18d3 18d7 18db 18de 18df
18e1 18e4 18e7 18e8 18ed 18f0 18f4 18f8
18fc 18ff 1900 1902 1903 1905 1908 190b
190e 190f 1 1914 1919 191d 1920 1924
1926 192a 192d 192f 1933 1937 193b 193f
1943 1947 194b 194f 1953 1957 195b 195f
1963 1967 196b 196f 1973 1977 197b 197f
1983 1987 198b 198f 1993 1997 19a3 19a7
19ab 19ae 19b2 19b6 19b8 19bc 19c0 19c4
19c7 19cb 19cf 19d1 19d2 19d7 1 19db
19df 19e3 19e6 19ea 19ee 19f2 19f6 19f9
19fd 1a01 1a04 1a07 1a0c 1a0f 1a12 1a15
1a16 1a1b 1a1c 1 1a1e 1a23 1a27 1a2b
1a2e 1a33 1a38 1a3b 1a3f 1a40 1a45 1a48
1a4d 1a4e 1a53 1a56 1a5b 1a5c 1a61 1a64
1a68 1a69 1a6e 1a71 1a76 1a77 1a7c 1a7f
1a83 1a87 1a8a 1a8d 1a8e 1a90 1a91 1a96
1a97 1a9c 1a9e 1aa2 1aa5 1aa7 1aab 1aad
1ab9 1abb 1abd 1abe 1ac3 1ac7 1ac9 1ad5
1ad7 1adb 1adf 1ae2 1ae6 1ae9 1aed 1af0
1af1 1af6 1af9 1afd 1b01 1b04 1b05 1b07
1b0b 1b0e 1b12 1b15 1b16 1b18 1b19 1b1e
1 1b21 1b26 1b2a 1b2e 1b31 1b35 1b39
1b3c 1b3f 1b44 1b47 1b4a 1b4d 1b4e 1b53
1b54 1 1b56 1b5b 1b5f 1b63 1b66 1b6b
1b70 1b73 1b77 1b78 1b7d 1b80 1b85 1b86
1b8b 1b8e 1b93 1b94 1b99 1b9c 1ba0 1ba4
1ba7 1ba8 1baa 1baf 1bb0 1bb2 1bb3 1bb8
1bbb 1bc0 1bc1 1bc6 1bc9 1bce 1bcf 1bd4
1bd7 1bdb 1bdc 1be1 1be4 1be9 1bea 1bef
1bf0 1bf5 1bf7 1bfb 1bfe 1c02 1c06 1c09
1c0d 1c11 1c14 1c17 1c1c 1c1f 1c22 1c25
1c26 1c2b 1c2c 1 1c2e 1c33 1c37 1c3b
1c3e 1c43 1c48 1c4b 1c4f 1c50 1c55 1c56
1c5b 1c5d 1c61 1c64 1c68 1c6c 1c6f 1c72
1c76 1c7a 1c7b 1c80 1c82 1c86 1c89 1c8b
1c8f 1c93 1c96 1c9a 1c9e 1ca1 1ca2 1ca4
1ca7 1caa 1cab 1cb0 1cb4 1cb8 1cbb 1cbe
1cc1 1cc2 1cc7 1ccb 1ccf 1cd2 1cd6 1cda
1cdd 1ce0 1ce5 1ce8 1ceb 1cee 1cef 1cf4
1cf5 1 1cf7 1cfc 1d00 1d04 1d07 1d0c
1d11 1d14 1d18 1d19 1d1e 1d21 1d26 1d27
1d2c 1d2f 1d34 1d35 1d3a 1d3d 1d41 1d45
1d49 1d4d 1d50 1d51 1d53 1d58 1d59 1d5b
1d5c 1d61 1d64 1d69 1d6a 1d6f 1d72 1d77
1d78 1d7d 1d80 1d84 1d85 1d8a 1d8d 1d92
1d93 1d98 1d99 1d9e 1da0 1da4 1da7 1dab
1daf 1db2 1db6 1dba 1dbd 1dc0 1dc5 1dc8
1dcb 1dce 1dcf 1dd4 1dd5 1 1dd7 1ddc
1de0 1de4 1de7 1dec 1df1 1df4 1df8 1df9
1dfe 1dff 1e04 1e06 1e0a 1e0d 1e11 1e15
1e18 1e1c 1e20 1e23 1e27 1e2b 1e2c 1e31
1e33 1e37 1e3a 1e3e 1e41 1e42 1e47 1e4a
1e4e 1e51 1e52 1e57 1 1e5a 1e5f 1e63
1e66 1e67 1e6c 1 1e6f 1e74 1e78 1e7b
1e7c 1e81 1 1e84 1e89 1e8d 1e91 1e94
1e98 1e9c 1e9f 1ea2 1ea7 1eaa 1ead 1eb0
1eb1 1eb6 1eb7 1 1eb9 1ebe 1ec2 1ec6
1ec9 1ece 1ed3 1ed6 1eda 1edb 1ee0 1ee3
1ee8 1ee9 1eee 1ef1 1ef6 1ef7 1efc 1eff
1f03 1f07 1f0b 1f0f 1f12 1f13 1f15 1f1a
1f1b 1f1d 1f1e 1f23 1f24 1f29 1f2b 1f2f
1f32 1f36 1f3a 1f3d 1f41 1f45 1f48 1f4b
1f50 1f53 1f56 1f59 1f5a 1f5f 1f60 1
1f62 1f67 1f6b 1f6f 1f72 1f77 1f7c 1f7f
1f83 1f84 1f89 1f8a 1f8f 1f91 1f95 1f98
1f9c 1fa0 1fa3 1fa7 1fab 1fae 1fb2 1fb3
1fb8 1fba 1fbe 1fc1 1fc5 1fc9 1fcd 1fd0
1fd4 1fd8 1fdc 1fdf 1fe0 1fe2 1fe5 1fe8
1fe9 1fee 1ff2 1ff5 1ff9 1ffb 1fff 2002
2006 200a 200e 2012 2016 201a 2026 202a
202e 2031 2035 2039 203b 203f 2043 2047
204a 204e 2052 2054 2055 205a 1 205e
2062 2066 2069 206d 2071 2075 2079 207c
2080 2084 2087 208a 208f 2092 2095 2098
2099 209e 209f 1 20a1 20a6 20aa 20ae
20b1 20b6 20bb 20be 20c2 20c3 20c8 20cb
20d0 20d1 20d6 20d9 20de 20df 20e4 20e7
20eb 20ec 20f1 20f4 20f9 20fa 20ff 2102
2106 210a 210d 2110 2111 2113 2114 2119
211a 211f 2121 2125 2128 212a 212e 2130
213c 213e 2140 2141 2146 214a 214c 2158
215a 215e 2162 2165 2166 2168 216b 216e
216f 2174 2178 217c 2180 2184 2188 2189
218b 218e 218f 2191 2194 2198 219c 21a0
21a1 21a3 21a6 21a7 21a9 21aa 21af 21b2
21b5 21b8 21b9 21be 21c1 21c4 21c7 21c8
21cd 21ce 21d0 21d4 21d8 21dc 21df 21e0
21e2 21e6 21e9 21ed 21f0 21f1 21f3 21f4
21f9 21fd 2200 2204 2208 220b 220f 2211
2215 2218 221c 221e 2222 2226 2229 222b
222f 2232 2236 2237 223b 223f 2243 2247
224a 224b 224d 2250 2251 2253 2256 2259
225c 225d 2262 2266 226a 226d 226e 2270
2273 2276 2277 227c 2280 2284 2287 2288
228a 228d 2290 2291 2296 229a 229e 22a1
22a5 22a9 22ad 22b1 22b5 22b9 22bd 22c1
22c5 22c9 22cd 22d1 22d5 22d9 22dd 22e1
22e5 22e9 22ea 22ec 22f0 22f4 22f8 22fb
22fe 2301 2302 2307 230b 230f 2313 2317
231b 231f 2323 2327 232b 232f 2333 2337
233b 233f 2343 234f 2353 2358 235c 235f
2360 2365 2369 236d 2370 2373 2377 2379
237d 2381 2384 2387 238b 238d 2391 2395
2398 239a 239e 23a2 23a6 23a9 23ad 23b1
23b3 23b4 23b9 1 23bd 23c1 23c5 23c8
23cc 23d0 23d4 23d8 23db 23df 23e3 23e6
23e9 23ee 23f1 23f4 23f7 23f8 23fd 23fe
1 2400 2405 2409 240d 2410 2415 241a
241d 2421 2422 2427 242a 242f 2430 2435
2438 243d 243e 2443 2446 244a 244b 2450
2453 2458 2459 245e 2461 2465 2469 246c
246f 2470 2472 2473 2478 2479 247e 2480
2484 2487 2489 248d 248f 249b 249d 249f
24a0 24a5 24a9 24ab 24b7 24b9 24bb 24bf
24c2 24c4 24c8 24cc 24cf 24d3 24d7 24db
24df 24e3 24e7 24eb 24ef 24f3 24f7 24fb
24ff 2503 2507 250b 250f 2513 2517 2518
251a 251e 2520 2524 2528 252b 252d 2531
2535 2539 253c 253d 253f 2542 2545 2546
254b 254f 2553 2557 255a 255b 255d 2560
2563 2564 2569 256d 2571 2574 2578 257c
2580 2584 2588 258c 2590 2594 2598 259c
25a0 25a4 25a8 25ac 25b0 25b4 25b8 25bc
25bd 25bf 25c3 25c7 25cb 25ce 25d1 25d4
25d5 25da 25de 25e2 25e6 25ea 25ee 25f2
25f6 25fa 25fe 2602 2606 2612 2616 261b
261f 2622 2623 2628 262c 2630 2633 2636
263a 263c 2640 2644 2647 264a 264e 2650
2654 2658 265b 265d 2661 2665 2669 266c
2670 2674 2676 2677 267c 1 2680 2684
2688 268b 268f 2693 2697 269b 269e 26a2
26a6 26a9 26ac 26b1 26b4 26b7 26ba 26bb
26c0 26c1 1 26c3 26c8 26cc 26d0 26d3
26d8 26dd 26e0 26e4 26e5 26ea 26ed 26f2
26f3 26f8 26fb 2700 2701 2706 2709 270d
270e 2713 2716 271b 271c 2721 2724 2728
272c 272f 2732 2733 2735 2736 273b 273c
2741 2743 2747 274a 274c 2750 2752 275e
2760 2762 2763 2768 276c 276e 277a 277c
277e 2782 2785 2787 278b 278f 2792 2796
279a 279e 27a2 27a6 27aa 27ae 27b2 27b6
27ba 27be 27c2 27c6 27ca 27ce 27d2 27d6
27da 27db 27dd 27e1 27e3 27e7 27eb 27ee
27f0 27f4 27f8 27fb 27ff 2803 2806 2809
280c 280d 2812 2815 2819 281d 2821 2824
2825 2827 282a 282b 282d 2830 2833 2836
2837 283c 1 283f 2844 2848 284c 284f
2850 2852 2856 2859 285d 2860 2861 2863
2864 2869 286c 2870 2874 2877 2878 287a
287d 2880 2881 2886 1 2889 288e 2892
2896 2899 289a 289c 289f 28a2 28a3 28a8
1 28ab 28b0 28b4 28b8 28bc 28c0 28c4
28c8 28cc 28d0 28d4 28d8 28dc 28e0 28e4
28e8 28ec 28f0 28f4 28f8 28fc 2900 2904
2908 290c 2918 291c 2921 2925 2928 2929
292e 2932 2936 2939 293c 2940 2942 2946
294a 294d 2950 2954 2956 295a 295e 2961
2963 2967 296b 296f 2972 2976 297a 297c
297d 2982 1 2986 298a 298e 2991 2995
2999 299d 29a1 29a4 29a8 29ac 29af 29b2
29b7 29ba 29bd 29c0 29c1 29c6 29c7 1
29c9 29ce 29d2 29d6 29d9 29de 29e3 29e6
29ea 29eb 29f0 29f3 29f8 29f9 29fe 2a01
2a06 2a07 2a0c 2a0f 2a13 2a14 2a19 2a1c
2a21 2a22 2a27 2a2a 2a2e 2a32 2a35 2a38
2a39 2a3b 2a3c 2a41 2a42 2a47 2a49 2a4d
2a50 2a52 2a56 2a58 2a64 2a66 2a68 2a69
2a6e 2a72 2a74 2a80 2a82 2a86 2a8a 2a8e
2a92 2a96 2a9a 2a9e 2aa2 2aae 2ab2 2ab7
2abb 2abe 2abf 2ac4 2ac8 2acc 2acf 2ad2
2ad6 2ad8 2adc 2ae0 2ae3 2ae6 2aea 2aec
2af0 2af4 2af7 2af9 2afd 2b01 2b05 2b08
2b0c 2b10 2b12 2b13 2b18 1 2b1c 2b20
2b24 2b27 2b2b 2b2f 2b33 2b37 2b3a 2b3e
2b42 2b45 2b48 2b4d 2b50 2b53 2b56 2b57
2b5c 2b5d 1 2b5f 2b64 2b68 2b6c 2b6f
2b74 2b79 2b7c 2b80 2b81 2b86 2b89 2b8e
2b8f 2b94 2b97 2b9c 2b9d 2ba2 2ba5 2ba9
2baa 2baf 2bb2 2bb7 2bb8 2bbd 2bc0 2bc4
2bc8 2bcb 2bce 2bcf 2bd1 2bd2 2bd7 2bd8
2bdd 2bdf 2be3 2be6 2be8 2bec 2bee 2bfa
2bfc 2bfe 2bff 2c04 2c08 2c0a 2c16 2c18
2c1c 2c20 2c24 2c28 2c2c 2c38 2c3c 2c41
2c45 2c48 2c49 2c4e 2c52 2c56 2c59 2c5c
2c60 2c62 2c66 2c6a 2c6d 2c70 2c74 2c76
2c7a 2c7e 2c81 2c83 2c87 2c8b 2c8f 2c92
2c96 2c9a 2c9c 2c9d 2ca2 1 2ca6 2caa
2cae 2cb1 2cb5 2cb9 2cbd 2cc1 2cc4 2cc8
2ccc 2ccf 2cd2 2cd7 2cda 2cdd 2ce0 2ce1
2ce6 2ce7 1 2ce9 2cee 2cf2 2cf6 2cf9
2cfe 2d03 2d06 2d0a 2d0b 2d10 2d13 2d18
2d19 2d1e 2d21 2d26 2d27 2d2c 2d2f 2d33
2d34 2d39 2d3c 2d41 2d42 2d47 2d4a 2d4e
2d52 2d55 2d58 2d59 2d5b 2d5c 2d61 2d62
2d67 2d69 2d6d 2d70 2d72 2d76 2d78 2d84
2d86 2d88 2d89 2d8e 2d92 2d94 2da0 2da2
2da4 2da8 2dac 2db0 2db4 2db8 2dbc 2dc0
2dc4 2dc8 2dcc 2dd0 2ddc 2de0 2de5 2de9
2dec 2ded 2df2 2df6 2dfa 2dfd 2e00 2e04
2e06 2e0a 2e0e 2e11 2e14 2e18 2e1a 2e1e
2e22 2e25 2e27 2e2b 2e2f 2e33 2e36 2e3a
2e3e 2e40 2e41 2e46 1 2e4a 2e4e 2e52
2e55 2e59 2e5d 2e61 2e65 2e68 2e6c 2e70
2e73 2e76 2e7b 2e7e 2e81 2e84 2e85 2e8a
2e8b 1 2e8d 2e92 2e96 2e9a 2e9d 2ea2
2ea7 2eaa 2eae 2eaf 2eb4 2eb7 2ebc 2ebd
2ec2 2ec5 2eca 2ecb 2ed0 2ed3 2ed7 2ed8
2edd 2ee0 2ee5 2ee6 2eeb 2eee 2ef2 2ef6
2ef9 2efc 2efd 2eff 2f00 2f05 2f06 2f0b
2f0d 2f11 2f14 2f16 2f1a 2f1c 2f28 2f2a
2f2c 2f2d 2f32 2f36 2f38 2f44 2f46 2f48
2f4c 2f50 2f53 2f55 2f59 2f5c 2f5e 2f62
2f66 2f6a 2f6e 2f71 2f72 2f74 2f78 2f7c
2f7f 2f80 2f82 2f86 2f8a 2f8e 2f91 2f92
2f94 2f97 2f9a 2f9b 2fa0 2fa4 2fa8 2fab
2faf 2fb3 2fb7 2fbb 2fbf 2fc3 2fc7 2fcb
2fcf 2fd3 2fd7 2fdb 2fdf 2fe3 2fe7 2feb
2fef 2ff3 2ff4 2ff6 2ffa 2ffe 3002 3005
3008 300b 300c 3011 3014 3018 301c 301f
3020 3022 3025 3028 3029 302e 1 3031
3036 303a 303e 3041 3042 3044 3047 304a
304b 3050 1 3053 3058 305c 3060 3064
3068 306c 3070 3074 3078 307c 3080 3084
3088 308c 3090 3094 30a0 30a4 30a9 30ad
30b0 30b1 30b6 30ba 30be 30c1 30c4 30c8
30ca 30ce 30d2 30d5 30d8 30dc 30de 30e2
30e6 30e9 30eb 30ef 30f3 30f7 30fa 30fe
3102 3104 3105 310a 1 310e 3112 3116
3119 311d 3121 3125 3129 312c 3130 3134
3137 313a 313f 3142 3145 3148 3149 314e
314f 1 3151 3156 315a 315e 3161 3166
316b 316e 3172 3173 3178 317b 3180 3181
3186 3189 318e 318f 3194 3197 319b 319c
31a1 31a4 31a9 31aa 31af 31b2 31b6 31ba
31bd 31c0 31c1 31c3 31c4 31c9 31ca 31cf
31d1 31d5 31d8 31da 31de 31e0 31ec 31ee
31f0 31f1 31f6 31fa 31fc 3208 320a 320c
3210 3213 3215 3219 321c 321d 3222 3225
3229 322d 3231 3235 3239 323d 3241 3245
3249 324d 3251 3255 3259 3265 3269 326d
3270 3274 3278 327a 327e 3282 3286 3289
328d 3291 3293 3294 3299 1 329d 32a1
32a5 32a8 32ac 32b0 32b4 32b8 32bb 32bf
32c3 32c6 32c9 32ce 32d1 32d4 32d7 32d8
32dd 32de 1 32e0 32e5 32e9 32ed 32f0
32f5 32fa 32fd 3301 3302 3307 330a 330f
3310 3315 3318 331d 331e 3323 3326 332a
332b 3330 3333 3338 3339 333e 3341 3345
3349 334c 334f 3350 3352 3353 3358 3359
335e 3360 3364 3367 3369 336d 336f 337b
337d 337f 3380 3385 3389 338b 3397 3399
339d 33a1 33a4 33a8 33ac 33af 33b0 33b2
33b5 33b8 33b9 33be 33c2 33c6 33ca 33cd
33d1 33d5 33d8 33dc 33e0 33e4 33e8 33ec
33f8 33fc 3400 3403 3407 340b 340d 3411
3415 3419 341c 3420 3424 3426 3427 342c
1 3430 3434 3438 343b 343f 3443 3447
344b 344e 3452 3456 3459 345c 3461 3464
3467 346a 346b 3470 3471 1 3473 3478
347c 3480 3483 3488 348d 3490 3494 3495
349a 349d 34a2 34a3 34a8 34ab 34b0 34b1
34b6 34b9 34bd 34be 34c3 34c6 34cb 34cc
34d1 34d4 34d8 34dc 34df 34e2 34e3 34e5
34e6 34eb 34ec 34f1 34f3 34f7 34fa 34fc
3500 3502 350e 3510 3512 3513 3518 351c
351e 352a 352c 3530 3534 3538 353c 3540
3544 3548 354c 354d 354f 3553 3557 355b
355e 355f 3561 3564 3567 3568 356d 3571
3572 3576 357a 357b 357f 3583 3584 3588
358c 358d 3591 3595 3596 359a 359e 35a2
35a7 35ab 35ac 35b0 35b4 35b8 35bd 35c2
35c6 35ca 35ce 35d3 35d7 35db 35de 35e1
35e5 35e7 35eb 35ef 35f2 35f5 35f9 35fb
35ff 3603 3606 360a 360e 3613 3615 3619
361d 3620 3624 3628 362a 362e 3632 3636
3639 363d 3641 3643 3644 3649 1 364d
3651 3655 3658 365c 3660 3664 3668 366b
366f 3673 3676 3679 367e 3681 3684 3687
3688 368d 368e 1 3690 3695 3699 369d
36a0 36a5 36aa 36ad 36b1 36b2 36b7 36ba
36bf 36c0 36c5 36c8 36cd 36ce 36d3 36d6
36da 36db 36e0 36e3 36e8 36e9 36ee 36f1
36f5 36f9 36fc 36ff 3700 3702 3703 3708
3709 370e 3710 3714 3717 3719 371d 371f
372b 372d 372f 3730 3735 3739 373b 3747
3749 374d 3751 3755 3759 375d 3769 376d
3771 3774 3778 377c 377e 3782 3786 378a
378d 3791 3795 3797 3798 379d 1 37a1
37a5 37a9 37ac 37b0 37b4 37b8 37bc 37bf
37c3 37c7 37ca 37cd 37d2 37d5 37d8 37db
37dc 37e1 37e2 1 37e4 37e9 37ed 37f1
37f4 37f9 37fe 3801 3805 3806 380b 380e
3813 3814 3819 381c 3821 3822 3827 382a
382e 382f 3834 3837 383c 383d 3842 3845
3849 384d 3850 3853 3854 3856 3857 385c
385d 3862 3864 3868 386b 386d 3871 3873
387f 3881 3883 3884 3889 388d 388f 389b
389d 38a1 38a6 38aa 38ae 38b3 38b7 38bb
38bf 38c3 38c6 38ca 38cb 38d0 38d3 38d6
38d7 38d9 38dd 38e1 38e5 38e9 38ec 38f1
38f2 38f7 38fa 38fd 38fe 3900 3904 3908
390c 3910 3913 3917 3918 391d 3920 3923
3924 3926 392a 392e 3932 3936 3939 393e
393f 3944 3947 394a 394b 394d 3951 3955
3959 395d 3961 3965 3969 396d 3971 3975
3979 397d 3981 3985 3989 398d 3991 3995
3996 3998 399c 39a0 39a4 39a7 39ab 39af
39b2 39b5 39ba 39bd 39c0 39c3 39c4 39c9
39ca 1 39cc 39d1 39d5 39d9 39dc 39e1
39e6 39e9 39ed 39ee 39f3 39f6 39fb 39fc
3a01 3a04 3a09 3a0a 3a0f 3a12 3a16 3a1a
3a1d 3a1e 3a20 3a25 3a26 3a28 3a29 3a2e
3a31 3a36 3a37 3a3c 3a3f 3a44 3a45 3a4a
3a4d 3a51 3a52 3a57 3a5a 3a5f 3a60 3a65
3a66 3a6b 3a6d 3a71 3a74 3a78 3a7c 3a7f
3a83 3a87 3a8a 3a8d 3a92 3a95 3a98 3a9b
3a9c 3aa1 3aa2 1 3aa4 3aa9 3aad 3ab1
3ab4 3ab9 3abe 3ac1 3ac5 3ac6 3acb 3acc
3ad1 3ad3 3ad7 3ada 3ade 3ae2 3ae5 3ae8
3aec 3af0 3af1 3af6 3af8 3afc 3aff 3b01
3b05 3b08 3b0a 3b0e 3b11 3b15 3b19 3b1d
3b20 3b21 3b23 3b26 3b29 3b2a 3b2f 3b33
3b37 3b3b 3b3e 3b42 3b46 3b4a 3b4e 3b52
3b56 3b5a 3b5e 3b62 3b66 3b6a 3b6e 3b72
3b76 3b7a 3b7e 3b82 3b86 3b87 3b89 3b8d
3b91 3b95 3b98 3b9b 3b9e 3b9f 3ba4 3ba7
3bab 3baf 3bb2 3bb3 3bb5 3bb8 3bbb 3bbc
3bc1 1 3bc4 3bc9 3bcd 3bd1 3bd4 3bd5
3bd7 3bda 3bdd 3bde 3be3 1 3be6 3beb
3bef 3bf3 3bf7 3bfb 3bff 3c03 3c07 3c0b
3c0f 3c13 3c17 3c23 3c27 3c2c 3c30 3c33
3c34 3c39 3c3d 3c41 3c44 3c47 3c4b 3c4d
3c51 3c55 3c58 3c5b 3c5f 3c61 3c65 3c69
3c6c 3c6e 3c72 3c76 3c7a 3c7d 3c81 3c85
3c87 3c88 3c8d 1 3c91 3c95 3c99 3c9c
3ca0 3ca4 3ca8 3cac 3caf 3cb3 3cb7 3cba
3cbd 3cc2 3cc5 3cc8 3ccb 3ccc 3cd1 3cd2
1 3cd4 3cd9 3cdd 3ce1 3ce4 3ce9 3cee
3cf1 3cf5 3cf6 3cfb 3cfe 3d03 3d04 3d09
3d0c 3d11 3d12 3d17 3d1a 3d1e 3d1f 3d24
3d27 3d2c 3d2d 3d32 3d35 3d39 3d3d 3d40
3d43 3d44 3d46 3d47 3d4c 3d4d 3d52 3d54
3d58 3d5b 3d5d 3d61 3d63 3d6f 3d71 3d73
3d74 3d79 3d7d 3d7f 3d8b 3d8d 3d8f 3d93
3d96 3d98 3d9c 3da0 3da3 3da5 3da9 3dad
3db0 3db4 3db8 3dbb 3dbe 3dc1 3dc2 3dc7
3dcb 3dcf 3dd2 3dd6 3dda 3ddd 3de0 3de5
3de8 3deb 3dee 3def 3df4 3df5 1 3df7
3dfc 3e00 3e04 3e07 3e0c 3e11 3e14 3e18
3e19 3e1e 3e21 3e26 3e27 3e2c 3e2f 3e34
3e35 3e3a 3e3d 3e41 3e45 3e49 3e4d 3e50
3e51 3e53 3e58 3e59 3e5b 3e5c 3e61 3e64
3e69 3e6a 3e6f 3e72 3e77 3e78 3e7d 3e80
3e84 3e85 3e8a 3e8d 3e92 3e93 3e98 3e99
3e9e 3ea0 3ea4 3ea7 3eab 3eaf 3eb2 3eb6
3eba 3ebd 3ec0 3ec5 3ec8 3ecb 3ece 3ecf
3ed4 3ed5 1 3ed7 3edc 3ee0 3ee4 3ee7
3eec 3ef1 3ef4 3ef8 3ef9 3efe 3eff 3f04
3f06 3f0a 3f0d 3f11 3f15 3f18 3f1c 3f20
3f23 3f27 3f2b 3f2c 3f31 3f33 3f37 3f3a
3f3e 3f42 3f46 3f4a 3f4e 3f51 3f52 3f54
3f57 3f5a 3f5b 3f60 3f63 3f67 3f6b 3f6e
3f6f 3f71 3f74 3f77 3f78 3f7d 1 3f80
3f85 3f89 3f8c 3f90 3f92 3f96 3f99 3f9d
3fa1 3fa4 3fa5 3fa7 3faa 3fad 3fae 3fb3
3fb7 3fbb 3fbf 3fc2 3fc3 3fc5 3fc8 3fc9
3fcb 3fce 3fd1 3fd4 3fd5 3fda 3fde 3fe1
3fe2 3fe7 3fea 3fee 3ff1 3ff2 3ff7 3ffa
3ffe 4002 4006 400a 400e 4012 4016 401a
401e 4022 4026 402a 402e 4032 4036 403a
403e 4042 4046 404a 404e 405a 405e 4063
4067 406a 406b 4070 4074 4078 407b 407e
4082 4084 4088 408c 408f 4092 4096 4098
409c 40a0 40a3 40a5 40a9 40ad 40b1 40b4
40b8 40bc 40be 40bf 40c4 1 40c8 40cc
40d0 40d3 40d7 40db 40df 40e3 40e6 40ea
40ee 40f1 40f4 40f9 40fc 40ff 4102 4103
4108 4109 1 410b 4110 4114 4118 411b
4120 4125 4128 412c 412d 4132 4135 413a
413b 4140 4143 4148 4149 414e 4151 4155
4156 415b 415e 4163 4164 4169 416c 4170
4174 4177 417a 417b 417d 417e 4183 4184
4189 418b 418f 4192 4194 4198 419a 41a6
41a8 41aa 41ab 41b0 41b4 41b6 41c2 41c4
41c6 41ca 41ce 41d2 41d6 41da 41de 41e2
41e6 41ea 41f6 41fa 41ff 4203 4206 4207
420c 4210 4214 4217 421a 421e 4220 4224
4228 422b 422e 4232 4234 4238 423c 423f
4241 4245 4249 424d 4250 4254 4258 425a
425b 4260 1 4264 4268 426c 426f 4273
4277 427b 427f 4282 4286 428a 428d 4290
4295 4298 429b 429e 429f 42a4 42a5 1
42a7 42ac 42b0 42b4 42b7 42bc 42c1 42c4
42c8 42c9 42ce 42d1 42d6 42d7 42dc 42df
42e4 42e5 42ea 42ed 42f1 42f2 42f7 42fa
42ff 4300 4305 4308 430c 4310 4313 4316
4317 4319 431a 431f 4320 4325 4327 432b
432e 4330 4334 4336 4342 4344 4346 4347
434c 4350 4352 435e 4360 4362 4366 436a
436d 436f 4373 4376 4377 437c 437f 4383
4387 438b 438f 4393 4397 439b 439f 43a3
43a7 43ab 43af 43b3 43b7 43bb 43bf 43c3
43c7 43cb 43cf 43d3 43d7 43db 43df 43e3
43e7 43eb 43ef 43f3 43f7 43fb 43ff 4403
4407 440b 440f 4413 4417 441b 441f 4423
4427 442b 442f 4433 4437 443b 443f 4443
4447 444b 444f 4453 4457 445b 445f 4463
4467 446b 446f 4473 4477 447b 447f 448b
448f 4494 4498 449b 449c 44a1 44a5 44a9
44ac 44af 44b3 44b5 44b9 44bd 44c0 44c3
44c7 44c9 44cd 44d1 44d4 44d6 44da 44de
44e2 44e5 44e9 44ed 44ef 44f0 44f5 1
44f9 44fd 4501 4504 4508 450c 4510 4514
4517 451b 451f 4522 4525 452a 452d 4530
4533 4534 4539 453a 1 453c 4541 4545
4549 454c 4551 4556 4559 455d 455e 4563
4566 456b 456c 4571 4574 4579 457a 457f
4582 4586 4587 458c 458f 4594 4595 459a
459d 45a1 45a5 45a8 45ab 45ac 45ae 45af
45b4 45b5 45ba 45bc 45c0 45c3 45c5 45c9
45cb 45d7 45d9 45db 45dc 45e1 45e5 45e7
45f3 45f5 45f7 45fb 45ff 4603 4607 460b
460f 4613 4617 461b 461f 4623 4627 462b
462f 4633 4637 463b 463f 4643 4647 464b
464f 4653 4657 465b 465f 4663 4667 466b
466f 4673 4677 467b 467f 4683 4687 468b
468f 4693 4697 469b 469f 46a3 46a7 46ab
46af 46b3 46b7 46bb 46bf 46c3 46c7 46d3
46d7 46dc 46e0 46e3 46e4 46e9 46ed 46f1
46f4 46f7 46fb 46fd 4701 4705 4708 470b
470f 4711 4715 4719 471c 471e 4722 4726
472a 472d 4731 4735 4737 4738 473d 1
4741 4745 4749 474c 4750 4754 4758 475c
475f 4763 4767 476a 476d 4772 4775 4778
477b 477c 4781 4782 1 4784 4789 478d
4791 4794 4799 479e 47a1 47a5 47a6 47ab
47ae 47b3 47b4 47b9 47bc 47c1 47c2 47c7
47ca 47ce 47cf 47d4 47d7 47dc 47dd 47e2
47e5 47e9 47ed 47f0 47f3 47f4 47f6 47f7
47fc 47fd 4802 4804 4808 480b 480d 4811
4813 481f 4821 4823 4824 4829 482d 482f
483b 483d 483f 4843 4847 484a 484c 4850
4854 4857 485b 485d 4861 4865 4868 4869
486b 486e 4871 4872 4877 487b 487f 4883
4887 488b 488f 4893 4897 489b 48a7 48ab
48b0 48b4 48b7 48b8 48bd 48c1 48c5 48c8
48cb 48cf 48d1 48d5 48d9 48dc 48df 48e3
48e5 48e9 48ed 48f0 48f2 48f6 48fa 48fe
4901 4905 4909 490b 490c 4911 1 4915
4919 491d 4920 4924 4928 492c 4930 4933
4937 493b 493e 4941 4946 4949 494c 494f
4950 4955 4956 1 4958 495d 4961 4965
4968 496d 4972 4975 4979 497a 497f 4982
4987 4988 498d 4990 4995 4996 499b 499e
49a2 49a3 49a8 49ab 49b0 49b1 49b6 49b9
49bd 49c1 49c4 49c7 49c8 49ca 49cb 49d0
49d1 49d6 49d8 49dc 49df 49e1 49e5 49e7
49f3 49f5 49f7 49f8 49fd 4a01 4a03 4a0f
4a11 4a13 4a17 4a1b 4a1e 4a20 4a24 4a28
4a2c 4a2f 4a30 4a32 4a35 4a36 4a38 4a3b
4a3e 4a41 4a42 4a47 4a4b 4a4e 4a4f 4a54
4a57 4a5b 4a5e 4a5f 4a64 4a67 4a6b 4a6f
4a73 4a77 4a7b 4a7f 4a83 4a87 4a8b 4a8f
4a93 4a97 4a9b 4a9f 4aa3 4aa7 4aab 4aaf
4ab3 4ab7 4abb 4ac7 4acb 4ad0 4ad4 4ad7
4ad8 4add 4ae1 4ae5 4ae8 4aeb 4aef 4af1
4af5 4af9 4afc 4aff 4b03 4b05 4b09 4b0d
4b10 4b12 4b16 4b1a 4b1e 4b21 4b25 4b29
4b2b 4b2c 4b31 1 4b35 4b39 4b3d 4b40
4b44 4b48 4b4c 4b50 4b53 4b57 4b5b 4b5e
4b61 4b66 4b69 4b6c 4b6f 4b70 4b75 4b76
1 4b78 4b7d 4b81 4b85 4b88 4b8d 4b92
4b95 4b99 4b9a 4b9f 4ba2 4ba7 4ba8 4bad
4bb0 4bb5 4bb6 4bbb 4bbe 4bc2 4bc3 4bc8
4bcb 4bd0 4bd1 4bd6 4bd9 4bdd 4be1 4be4
4be7 4be8 4bea 4beb 4bf0 4bf1 4bf6 4bf8
4bfc 4bff 4c01 4c05 4c07 4c13 4c15 4c17
4c18 4c1d 4c21 4c23 4c2f 4c31 4c33 4c37
4c3b 4c3f 4c43 4c47 4c4b 4c4f 4c53 4c57
4c5b 4c5f 4c6b 4c6f 4c74 4c78 4c7b 4c7c
4c81 4c85 4c89 4c8c 4c8f 4c93 4c95 4c99
4c9d 4ca0 4ca3 4ca7 4ca9 4cad 4cb1 4cb4
4cb6 4cba 4cbe 4cc2 4cc5 4cc9 4ccd 4ccf
4cd0 4cd5 1 4cd9 4cdd 4ce1 4ce4 4ce8
4cec 4cf0 4cf4 4cf7 4cfb 4cff 4d02 4d05
4d0a 4d0d 4d10 4d13 4d14 4d19 4d1a 1
4d1c 4d21 4d25 4d29 4d2c 4d31 4d36 4d39
4d3d 4d3e 4d43 4d46 4d4b 4d4c 4d51 4d54
4d59 4d5a 4d5f 4d62 4d66 4d67 4d6c 4d6f
4d74 4d75 4d7a 4d7d 4d81 4d85 4d88 4d8b
4d8c 4d8e 4d8f 4d94 4d95 4d9a 4d9c 4da0
4da3 4da5 4da9 4dab 4db7 4db9 4dbb 4dbc
4dc1 4dc5 4dc7 4dd3 4dd5 4dd7 4ddb 4ddf
4de2 4de4 4de8 4deb 4dec 4df1 4df4 4df8
4dfc 4e00 4e04 4e08 4e0c 4e10 4e14 4e18
4e1c 4e20 4e24 4e28 4e2c 4e30 4e34 4e38
4e3c 4e40 4e44 4e48 4e4c 4e50 4e54 4e58
4e5c 4e60 4e64 4e68 4e6c 4e70 4e74 4e78
4e7c 4e80 4e84 4e88 4e8c 4e90 4e94 4e98
4e9c 4ea0 4ea4 4ea8 4eac 4eb0 4eb4 4eb8
4ebc 4ec0 4ec4 4ec8 4ecc 4ed0 4ed4 4ed8
4edc 4ee0 4ee4 4ee8 4eec 4ef0 4ef4 4f00
4f04 4f09 4f0d 4f10 4f11 4f16 4f1a 4f1e
4f21 4f24 4f28 4f2a 4f2e 4f32 4f35 4f38
4f3c 4f3e 4f42 4f46 4f49 4f4b 4f4f 4f53
4f57 4f5a 4f5e 4f62 4f64 4f65 4f6a 1
4f6e 4f72 4f76 4f79 4f7d 4f81 4f85 4f89
4f8c 4f90 4f94 4f97 4f9a 4f9f 4fa2 4fa5
4fa8 4fa9 4fae 4faf 1 4fb1 4fb6 4fba
4fbe 4fc1 4fc6 4fcb 4fce 4fd2 4fd3 4fd8
4fdb 4fe0 4fe1 4fe6 4fe9 4fee 4fef 4ff4
4ff7 4ffb 4ffc 5001 5004 5009 500a 500f
5012 5016 501a 501d 5020 5021 5023 5024
5029 502a 502f 5031 5035 5038 503a 503e
5040 504c 504e 5050 5051 5056 505a 505c
5068 506a 506c 5070 5074 5078 507c 5080
5084 5088 508c 5090 5094 5098 509c 50a0
50a4 50a8 50ac 50b0 50b4 50b8 50bc 50c0
50c4 50c8 50cc 50d0 50d4 50d8 50dc 50e0
50e4 50e8 50ec 50f0 50f4 50f8 50fc 5100
5104 5108 510c 5110 5114 5118 511c 5120
5124 5128 512c 5130 5134 5138 513c 5140
5144 5150 5154 5159 515d 5160 5161 5166
516a 516e 5171 5174 5178 517a 517e 5182
5185 5188 518c 518e 5192 5196 5199 519b
519f 51a3 51a7 51aa 51ae 51b2 51b4 51b5
51ba 1 51be 51c2 51c6 51c9 51cd 51d1
51d5 51d9 51dc 51e0 51e4 51e7 51ea 51ef
51f2 51f5 51f8 51f9 51fe 51ff 1 5201
5206 520a 520e 5211 5216 521b 521e 5222
5223 5228 522b 5230 5231 5236 5239 523e
523f 5244 5247 524b 524c 5251 5254 5259
525a 525f 5262 5266 526a 526d 5270 5271
5273 5274 5279 527a 527f 5281 5285 5288
528a 528e 5290 529c 529e 52a0 52a1 52a6
52aa 52ac 52b8 52ba 52bc 52c0 52c4 52c7
52c9 52cd 52d1 52d4 52d8 52da 52de 52e2
52e5 52e6 52e8 52eb 52ee 52ef 52f4 52f8
52fb 52fc 5301 5304 5308 530c 530f 5310
5312 5315 5318 5319 531e 5322 5326 532a
532e 5332 5336 533a 533e 5342 5346 534a
534e 5352 5356 5362 5366 536b 536f 5372
5373 5378 537c 5380 5383 5386 538a 538c
5390 5394 5397 539a 539e 53a0 53a4 53a8
53ab 53ad 53b1 53b5 53b9 53bc 53c0 53c4
53c6 53c7 53cc 1 53d0 53d4 53d8 53db
53df 53e3 53e7 53eb 53ee 53f2 53f6 53f9
53fc 5401 5404 5407 540a 540b 5410 5411
1 5413 5418 541c 5420 5423 5428 542d
5430 5434 5435 543a 543d 5442 5443 5448
544b 5450 5451 5456 5459 545d 545e 5463
5466 546b 546c 5471 5474 5478 547c 547f
5482 5483 5485 5486 548b 548c 5491 5493
5497 549a 549c 54a0 54a2 54ae 54b0 54b2
54b3 54b8 54bc 54be 54ca 54cc 54ce 54d2
54d6 54da 54de 54e2 54e6 54ea 54ee 54f2
54f6 54fa 5506 550a 550f 5513 5516 5517
551c 5520 5524 5527 552a 552e 5530 5534
5538 553b 553e 5542 5544 5548 554c 554f
5551 5555 5559 555d 5560 5564 5568 556a
556b 5570 1 5574 5578 557c 557f 5583
5587 558b 558f 5592 5596 559a 559d 55a0
55a5 55a8 55ab 55ae 55af 55b4 55b5 1
55b7 55bc 55c0 55c4 55c7 55cc 55d1 55d4
55d8 55d9 55de 55e1 55e6 55e7 55ec 55ef
55f4 55f5 55fa 55fd 5601 5602 5607 560a
560f 5610 5615 5618 561c 5620 5623 5626
5627 5629 562a 562f 5630 5635 5637 563b
563e 5640 5644 5646 5652 5654 5656 5657
565c 5660 5662 566e 5670 5672 5676 567a
567d 567f 5683 5687 568b 568f 5693 5697
569b 569f 56a3 56a7 56ab 56b7 56bb 56c0
56c4 56c7 56c8 56cd 56d1 56d5 56d8 56db
56df 56e1 56e5 56e9 56ec 56ef 56f3 56f5
56f9 56fd 5700 5702 5706 570a 570e 5711
5715 5719 571b 571c 5721 1 5725 5729
572d 5730 5734 5738 573c 5740 5743 5747
574b 574e 5751 5756 5759 575c 575f 5760
5765 5766 1 5768 576d 5771 5775 5778
577d 5782 5785 5789 578a 578f 5792 5797
5798 579d 57a0 57a5 57a6 57ab 57ae 57b2
57b3 57b8 57bb 57c0 57c1 57c6 57c9 57cd
57d1 57d4 57d7 57d8 57da 57db 57e0 57e1
57e6 57e8 57ec 57ef 57f1 57f5 57f7 5803
5805 5807 5808 580d 5811 5813 581f 5821
5823 5827 582b 582e 5830 5834 5838 583b
583d 5841 5845 5848 584c 584f 5850 5855
5858 585c 5860 5863 5864 5866 5869 586c
586d 5872 1 5875 587a 587d 5881 5885
5888 5889 588b 588e 5891 5892 5897 1
589a 589f 58a3 58a8 58ac 58b0 58b1 58b5
58b9 58bc 58c0 58c4 58c7 58cb 58cf 58d3
58d6 58d7 58d9 58dc 58df 58e0 58e5 58e9
58ed 58f1 58f5 58f9 58fd 5901 5905 5909
590d 5911 5915 5919 591d 5921 5925 5929
592d 5931 5935 5939 593d 5941 5945 5949
5955 5959 595d 5960 5964 5968 596a 596e
5972 5976 5979 597d 5981 5983 5984 5989
1 598d 5991 5995 5998 599c 59a0 59a4
59a8 59ab 59af 59b3 59b6 59b9 59be 59c1
59c4 59c7 59c8 59cd 59ce 1 59d0 59d5
59d9 59dd 59e0 59e5 59ea 59ed 59f1 59f2
59f7 59fa 59ff 5a00 5a05 5a08 5a0d 5a0e
5a13 5a16 5a1a 5a1b 5a20 5a23 5a28 5a29
5a2e 5a31 5a35 5a39 5a3c 5a3f 5a40 5a42
5a43 5a48 5a49 5a4e 5a50 5a54 5a57 5a59
5a5d 5a5f 5a6b 5a6d 5a6f 5a70 5a75 5a79
5a7b 5a87 5a89 5a8b 5a8f 5a93 5a97 5a9b
5a9f 5aa3 5aa7 5aab 5aaf 5ab3 5ab7 5abb
5abf 5ac3 5ac7 5acb 5acf 5ad3 5ad7 5adb
5adf 5ae3 5ae7 5aeb 5aef 5af3 5aff 5b03
5b07 5b0a 5b0e 5b12 5b14 5b18 5b1c 5b20
5b23 5b27 5b2b 5b2d 5b2e 5b33 1 5b37
5b3b 5b3f 5b42 5b46 5b4a 5b4e 5b52 5b55
5b59 5b5d 5b60 5b63 5b68 5b6b 5b6e 5b71
5b72 5b77 5b78 1 5b7a 5b7f 5b83 5b87
5b8a 5b8f 5b94 5b97 5b9b 5b9c 5ba1 5ba4
5ba9 5baa 5baf 5bb2 5bb7 5bb8 5bbd 5bc0
5bc4 5bc5 5bca 5bcd 5bd2 5bd3 5bd8 5bdb
5bdf 5be3 5be6 5be9 5bea 5bec 5bed 5bf2
5bf3 5bf8 5bfa 5bfe 5c01 5c03 5c07 5c09
5c15 5c17 5c19 5c1a 5c1f 5c23 5c25 5c31
5c33 5c35 5c39 5c3d 5c40 5c44 5c48 5c4b
5c4f 5c52 5c56 5c59 5c5a 5c5f 5c62 5c66
5c6a 5c6d 5c6e 5c70 5c74 5c77 5c7b 5c7e
5c7f 5c81 5c82 5c87 5c8a 5c8e 5c92 5c95
5c96 5c98 5c9b 5c9e 5c9f 5ca4 1 5ca7
5cac 5cb0 5cb4 5cb7 5cb8 5cba 5cbd 5cc0
5cc1 5cc6 1 5cc9 5cce 5cd2 5cd6 5cda
5cde 5ce2 5ce6 5cea 5cee 5cfa 5cfe 5d03
5d07 5d0a 5d0b 5d10 5d14 5d18 5d1b 5d1e
5d22 5d24 5d28 5d2c 5d2f 5d32 5d36 5d38
5d3c 5d40 5d43 5d45 5d49 5d4d 5d51 5d54
5d58 5d5c 5d5e 5d5f 5d64 1 5d68 5d6c
5d70 5d73 5d77 5d7b 5d7f 5d83 5d86 5d8a
5d8e 5d91 5d94 5d99 5d9c 5d9f 5da2 5da3
5da8 5da9 1 5dab 5db0 5db4 5db8 5dbb
5dc0 5dc5 5dc8 5dcc 5dcd 5dd2 5dd5 5dda
5ddb 5de0 5de3 5de8 5de9 5dee 5df1 5df5
5df6 5dfb 5dfe 5e03 5e04 5e09 5e0c 5e10
5e14 5e17 5e1a 5e1b 5e1d 5e1e 5e23 5e24
5e29 5e2b 5e2f 5e32 5e34 5e38 5e3a 5e46
5e48 5e4a 5e4b 5e50 5e54 5e56 5e62 5e64
5e68 5e6c 5e70 5e74 5e78 5e7c 5e80 5e84
5e88 5e8c 5e90 5e94 5e98 5ea4 5ea8 5ead
5eb1 5eb4 5eb5 5eba 5ebe 5ec2 5ec5 5ec8
5ecc 5ece 5ed2 5ed6 5ed9 5edc 5ee0 5ee2
5ee6 5eea 5eed 5eef 5ef3 5ef7 5efb 5efe
5f02 5f06 5f08 5f09 5f0e 1 5f12 5f16
5f1a 5f1d 5f21 5f25 5f29 5f2d 5f30 5f34
5f38 5f3b 5f3e 5f43 5f46 5f49 5f4c 5f4d
5f52 5f53 1 5f55 5f5a 5f5e 5f62 5f65
5f6a 5f6f 5f72 5f76 5f77 5f7c 5f7f 5f84
5f85 5f8a 5f8d 5f92 5f93 5f98 5f9b 5f9f
5fa0 5fa5 5fa8 5fad 5fae 5fb3 5fb6 5fba
5fbe 5fc1 5fc4 5fc5 5fc7 5fc8 5fcd 5fce
5fd3 5fd5 5fd9 5fdc 5fde 5fe2 5fe4 5ff0
5ff2 5ff4 5ff5 5ffa 5ffe 6000 600c 600e
6010 6014 6018 601d 6021 6022 6026 602a
602e 6032 6036 603b 6040 6044 6048 604c
6051 6055 6059 605c 605f 6063 6065 6069
606d 6070 6073 6077 6079 607d 6081 6084
6088 608c 608f 6092 6095 6096 609b 609f
60a5 60a7 60ab 60ae 60b2 60b6 60ba 60bd
60be 60c0 60c3 60c7 60cb 60ce 60cf 60d1
60d2 60d7 60db 60df 60e3 60e6 60e7 60e9
60ec 60ef 60f0 60f5 60f9 60fd 6100 6101
6103 6107 610a 610e 6111 6112 6114 6115
611a 611e 6122 6125 6126 6128 612c 612f
6133 6136 6137 6139 613a 613f 6143 6147
614b 614e 614f 6151 6155 6157 615b 615f
6163 6166 6167 6169 616c 6170 6174 6177
6178 617a 617b 6180 6183 6187 618b 618e
618f 6191 6192 6197 619b 619d 61a1 61a5
61a8 61aa 61ae 61b1 61b5 61b9 61bd 61c1
61c5 61d1 61d5 61da 61de 61e1 61e2 61e7
61eb 61ef 61f2 61f5 61f9 61fb 61ff 6203
6206 6209 620d 620f 6213 6217 621a 621c
6220 6224 6228 622b 622f 6233 6235 6236
623b 1 623f 6243 6247 624a 624e 6252
6256 625a 625d 6261 6265 6268 626b 6270
6273 6276 6279 627a 627f 6280 1 6282
6287 628b 628f 6292 6297 629c 629f 62a3
62a4 62a9 62ac 62b1 62b2 62b7 62ba 62bf
62c0 62c5 62c8 62cc 62cd 62d2 62d5 62da
62db 62e0 62e3 62e7 62eb 62ee 62f1 62f2
62f4 62f5 62fa 62fb 6300 6302 6306 6309
630b 630f 6311 631d 631f 6321 6322 6327
632b 632d 6339 633b 633f 6343 6347 6349
634d 6350 6354 6358 635b 635c 635e 6362
6365 6369 636c 636d 636f 6370 6375 6379
637f 6381 6385 6388 638a 638e 6395 6399
639d 63a2 63a4 63a8 63ac 63af 63b3 63b7
63b9 63bd 63c1 63c5 63c8 63cc 63d0 63d2
63d3 63d8 1 63dc 63e0 63e4 63e7 63eb
63ef 63f3 63f7 63fa 63fe 6402 6405 6408
640d 6410 6413 6416 6417 641c 641d 1
641f 6424 6428 642c 642f 6434 6439 643c
6440 6441 6446 6449 644e 644f 6454 6457
645c 645d 6462 6465 6469 646a 646f 6472
6477 6478 647d 6480 6484 6488 648b 648e
648f 6491 6492 6497 6498 649d 649f 64a3
64a6 64a8 64ac 64ae 64ba 64bc 64be 64bf
64c4 64c8 64ca 64d6 64d8 64dc 64e0 64e3
64e4 64e6 64e9 64ec 64ed 64f2 64f5 64f9
64fc 64fd 6502 6505 1 6508 650d 6511
6515 6519 651d 6521 652d 6531 6536 653a
653d 653e 6543 6547 654b 654e 6551 6555
6557 655b 655f 6562 6565 6569 656b 656f
6573 6576 6578 657c 6580 6584 6587 658b
658f 6591 6592 6597 1 659b 659f 65a3
65a6 65aa 65ae 65b2 65b6 65b9 65bd 65c1
65c4 65c7 65cc 65cf 65d2 65d5 65d6 65db
65dc 1 65de 65e3 65e7 65eb 65ee 65f3
65f8 65fb 65ff 6600 6605 6608 660d 660e
6613 6616 661b 661c 6621 6624 6628 6629
662e 6631 6636 6637 663c 663f 6643 6647
664a 664d 664e 6650 6651 6656 6657 665c
665e 6662 6665 6667 666b 666d 6679 667b
667d 667e 6683 6687 6689 6695 6697 6699
669d 66a0 66a2 66a6 66aa 66ad 66b1 66b5
66b8 66b9 66bb 66be 66c1 66c2 66c7 66cb
66cf 66d3 66d6 66d7 66d9 66dc 66dd 66df
66e2 66e5 66e8 66e9 66ee 66f2 66f6 66fa
66fe 66ff 6701 6705 6707 670b 670f 6713
6717 6718 671a 671e 6720 6724 6728 672b
672d 6731 6734 6736 673a 673d 673f 6743
6746 6748 674c 674f 6753 6757 675a 675d
6760 6761 6766 676a 676e 6771 6774 6778
677a 677e 6781 6783 6787 678a 678e 6792
6795 6799 679d 67a0 67a3 67a8 67ab 67ae
67b1 67b2 67b7 67b8 1 67ba 67bf 67c3
67c7 67ca 67cf 67d4 67d7 67db 67dc 67e1
67e4 67e9 67ea 67ef 67f2 67f7 67f8 67fd
6800 6804 6808 680c 6810 6813 6814 6816
681b 681c 681e 681f 6824 6827 682c 682d
6832 6835 683a 683b 6840 6843 6847 6848
684d 6850 6855 6856 685b 685c 6861 6863
6867 686a 686e 6872 6875 6879 687d 6880
6884 6888 6889 688e 6890 6894 6898 689b
689f 68a3 68a6 68aa 68ae 68b1 68b4 68b9
68bc 68bf 68c2 68c3 68c8 68c9 1 68cb
68d0 68d4 68d8 68db 68e0 68e5 68e8 68ec
68ed 68f2 68f3 68f8 68fc 6900 6903 6908
690d 6910 6914 6918 691b 691c 6921 6924
6929 692a 692f 6932 6936 693a 693d 693e
6943 6944 6949 694b 694f 6952 6956 695a
695e 6962 6966 696a 696e 6972 6976 6982
6987 698b 698f 6993 6997 6999 699a 699f
1 69a3 69a7 69ab 69ae 69b2 69b6 69ba
69be 69c1 69c5 69c9 69cc 69cf 69d4 69d7
69da 69dd 69de 69e3 69e4 1 69e6 69eb
69ef 69f3 69f6 69fb 6a00 6a03 6a07 6a08
6a0d 6a0e 6a13 6a17 6a1b 6a1e 6a23 6a28
6a2b 6a2f 6a30 6a35 6a38 6a3d 6a3e 6a43
6a46 6a4a 6a4e 6a51 6a54 6a55 6a57 6a58
6a5d 6a5e 6a63 6a65 6a69 6a6c 6a70 6a74
6a78 6a7c 6a80 6a84 6a88 6a94 6a99 6a9d
6aa1 6aa5 6aa9 6aab 6aaf 6ab1 6abd 6abf
6ac1 6ac2 6ac7 6acb 6acd 6ad9 6add 6adf
6ae0 6ae9 
1e7a
2
0 1 a 6 9 :3 6 15 :3 6
11 :3 6 12 :3 6 13 :3 6 10 :3 6
17 :3 6 15 :3 6 1a :3 6 b :3 6
10 :3 6 c :3 6 16 :3 6 18 :3 6
19 :3 6 1b :3 6 17 :3 6 16 :3 6
17 :3 6 17 :3 6 12 :2 6 1 3
a 13 a :2 1 4 13 1c 1b
:2 13 :2 4 10 19 18 :2 10 :2 4 e
17 16 :2 e :2 4 e 17 16 :2 e
:2 4 f 18 17 :2 f :2 4 e 17
16 :2 e :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 f 18 17
:2 f :2 4 c 15 14 :2 c :2 4 12
1b 1a :2 12 :2 4 11 1a 19 :2 11
:2 4 e 17 16 :2 e :2 4 f 18
17 :2 f :2 4 :2 e 1d e :2 4 :2 14
23 14 :2 4 :2 b 1a b :2 4 :2 a
19 a :2 4 :2 b 1a b :2 4 :2 e
1d e :2 4 :2 13 22 13 :2 4 :2 c
1b c :2 4 :2 e 1d e :2 4 :2 13
22 13 :2 4 :2 d 1c d :2 4 :2 c
1b c :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 10 1f 10 :2 4 :2 12
21 12 :2 4 :3 10 :2 4 :3 f :2 4 18
21 20 :2 18 :2 4 18 21 20 :2 18
:2 4 f 18 17 :2 f :2 4 :3 11 :2 4
:3 f :2 4 :3 13 :2 4 :3 10 :2 4 :3 d :2 4
:3 e :2 4 14 1d 1c :2 14 :2 4 :2 11
20 11 :2 4 :2 f 1e f :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 :2 12
21 12 :2 4 :2 12 21 12 :2 4 :2 a
19 a :2 4 :3 9 :2 4 :3 9 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 :2 f
1e f :2 4 :2 16 25 16 :2 4 :2 11
20 11 :2 4 :2 14 23 14 4 7
e 0 :2 7 20 2d 33 3b 56
5c 64 f 10 1d 2e 3b 13
2d a :6 7 e 0 :2 7 11 1c
26 f 10 1d 2e 42 18 23
a :5 7 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 55 5b 5e :2 55
6c 83 8 :2 6c d 10 :2 6c 13
16 :2 6c b e :2 6c 13 16 1f
27 :2 1f 38 :2 16 :2 6c b e :2 6c
13 16 :2 6c 1b 1e :2 6c 29 2c
:2 6c b e :2 6c 13 16 :2 6c 1b
1e :2 6c 2a 2d :2 6c b e :2 6c
13 16 :2 6c 1b 1e :2 6c 2b 2e
:2 6c b e :2 6c 13 16 1f 27
:2 1f 33 :2 16 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 2f 32 :2 6c
b e :2 6c 13 16 1f 27 :2 1f
38 :2 16 :2 6c b e :2 6c 13 16
1f 27 :2 1f 3d :2 16 :2 6c b e
:2 6c 13 16 1f 27 :2 1f 2e :2 16
:2 6c b e :2 6c 13 16 1f 27
:2 1f 33 :2 16 :2 6c b e :2 6c 13
16 1f 27 :2 1f 2f :2 16 :2 6c b
e :2 6c 13 16 1f 27 :2 1f 39
:2 16 :2 6c b e :2 6c 13 16 :2 6c
1b 1e :2 6c 30 33 :2 6c b e
:2 6c 13 16 :2 6c 1b 1e :2 6c 31
34 :2 6c b e :2 6c 13 16 1f
27 :2 1f 3e :2 16 :2 6c b e :2 6c
13 16 1f 27 :2 1f 3a :2 16 :2 6c
b e :2 6c 13 16 :2 6c 1b 1e
:2 6c 2e 31 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 2f 32 :2 6c
b e :2 6c 13 16 1f 27 :2 1f
3a :2 16 :2 6c b e :2 6c 13 16
:2 6c 1b 1e :2 6c 2a 2d :2 6c 32
35 :2 6c :2 7 4b :2 4 7 :2 11 23
:2 2d 39 3c 4d 50 51 :2 4d :2 23
:3 7 :2 d 12 1e 5e 61 :2 1e :2 7
54 :2 4 :4 9 8 7 27 30 40
:2 27 43 45 :2 43 26 4c a 1a
:2 4c 1d 1f :2 1d 4b :2 26 25 :2 7
a :2 14 26 :2 30 3c 3f 50 53
54 :2 50 :2 26 :3 a :2 10 15 21 61
64 :2 21 71 74 :2 21 78 7b :2 21
85 88 91 99 :2 a2 :2 91 b3 :2 88
:2 21 :2 a 57 :2 7 a :2 14 26 :2 30
3c 3f 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 61 64 :2 21 :2 a 57
:3 7 :2 12 28 :2 31 41 :2 7 23 :2 4
:4 9 8 7 :4 1b 1a 19 :2 7 :4 34
33 32 :2 7 a :2 14 26 :2 30 3c
3f 50 53 54 :2 50 :2 26 :3 a :2 10
15 21 61 64 :2 21 71 74 :2 21
78 7b :2 21 85 88 91 99 :2 a2
:2 91 b3 :2 88 :2 21 :2 a 57 :2 7 a
:2 14 26 :2 30 3c 3f 50 53 54
:2 50 :2 26 :3 a :2 10 15 21 61 64
:2 21 :2 a 57 :3 7 :2 12 28 :2 31 41
:2 7 4a :3 4 16 :2 4 10 :2 4 17
:2 4 12 :2 4 13 :2 4 17 :2 4 12
:2 4 10 :2 4 13 :2 4 15 :2 4 f
:2 4 16 :2 4 15 :2 4 14 4 7
10 17 :2 10 29 :2 7 2e 2c :2 37
:2 2c b 14 23 :2 b 26 28 :2 26
a 2f 38 47 :2 2f 4a 4c :2 4a
2e :2 a :4 e d 10 :2 1a 2c :2 36
42 45 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 67 6a :2 27 77 7a
:2 27 7e 81 :2 27 8b 8e 97 9f
:2 a8 :2 97 b9 :2 8e :2 27 :2 10 5d :2 d
10 :2 1a 2c :2 36 42 45 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 :2 10 5d :3 d :2 18 2e :2 37
47 :2 d 22 :3 a 1b :2 a 17 :2 a
18 a 14 20 2d 3b 12 20
2d :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5a 5d 5e :2 5a :2 2f :3 13 :2 19 1e
2a 6a 6d :2 2a 7a 7d :2 2a 81
84 :2 2a 90 93 :2 2a 9b 9e :2 2a
aa ad b4 bd c0 :2 ad :2 2a :2 13
61 :2 10 :2 d :4 19 :2 d a :3 4f a
:3 15 :2 a 1a 23 2c 37 :2 23 :2 1a
:2 a 1d 2c 3a 45 50 5f 25
:2 1d a e 17 28 :2 e 2b 2d
:2 2b 32 3b 4c :2 32 4f 51 :2 4f
:2 e d 59 10 1f :2 59 22 24
:2 22 58 :2 d 2c 35 3f :2 2c 42
44 :2 42 2b :3 d 1b d 17 27
37 2e 16 23 34 41 :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5d 60 61
:2 5d :2 32 :3 16 :2 1c 21 2d 6d 70
:2 2d 7d 80 :2 2d 84 87 :2 2d 93
96 :2 2d 9e a1 :2 2d ad b0 b7
c0 c3 :2 b0 :2 2d :2 16 64 :2 13 :2 10
:4 1c :2 10 d :3 47 10 19 25 :2 10
28 2b :2 28 10 21 :2 10 1c :2 10
23 10 :4 14 13 1d 2a 35 42
63 74 :2 16 :2 1f 2b 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 63 66 67 :2 63 :2 38 :3 1c :2 22
27 33 73 76 :2 33 83 86 :2 33
8a 8d :2 33 99 9c :2 33 a4 a7
:2 33 b3 b6 bd c6 c9 :2 b6 :2 33
:2 1c 6a :2 19 :2 16 :4 22 :2 16 13 :4 2c
:2 10 2d :2 d 47 :2 a e 17 26
:2 e 29 2b :2 29 d 33 3e 47
52 :2 3e :2 33 32 57 5a :2 57 :3 d
1e d 5c :2 a 4f a 15 a
14 20 29 36 43 d 18 22
2d 3b 12 20 2b 3a 49 d
1e 26 31 41 12 29 3d :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5a 5d
5e :2 5a :2 2f :3 13 :2 19 1e 2a 6a
6d :2 2a 7a 7d :2 2a 81 84 :2 2a
90 93 :2 2a 9b 9e :2 2a aa ad
b4 bd c0 :2 ad :2 2a :2 13 61 :2 10
:2 d :4 19 :2 d a :3 7 e :2 17 22
20 :2 2b :2 20 d 40 49 59 :2 40
5f 5c 10 1f :2 5f :2 5c 3f :2 d
10 :2 1a 2c :2 36 42 46 57 5a
5b :2 57 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8b 8e 97 9f :2 97 a3 :2 8e :2 27
ab ae :2 27 b6 b9 :2 27 be c1
:2 27 c9 cc :2 27 :2 10 5e :2 d 10
:2 1a 2c :2 36 42 45 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 :2 10 5d :3 d :2 18 2c 2f 38
:2 d 23 :2 a :4 7 a 13 22 :2 a
25 28 :2 25 d :2 16 1f 22 :2 1f
10 :2 1a 2c :2 36 42 46 57 5a
5b :2 57 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8b 8e 97 9f :2 a8 :2 97 b3 :2 8e
:2 27 bb be :2 27 c6 c9 :2 27 ce
d1 :2 27 d9 dc :2 27 :2 10 5e :2 d
10 :2 1a 2c :2 36 42 45 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 :2 10 5d :3 d :2 18 2c :2 35
3f 48 :2 d 24 :2 a :4 e d :4 26
25 :2 d :4 3f 3e :2 d :4 14 13 :2 d
10 :2 1a 2c :2 36 42 45 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8b 8e 97 9f :2 a8 :2 97 b9 :2 8e
:2 27 :2 10 5d :2 d 10 :2 1a 2c :2 36
42 45 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 67 6a :2 27 :2 10 5d
:3 d :2 18 2e :2 37 47 :2 d 2d :3 a
1c :2 25 a d 16 1f :2 d 22
24 :2 22 d 18 d 2e :2 a 14
1d 37 46 54 61 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5a 5d 5e :2 5a
:2 2f :3 13 :2 19 1e 2a 6a 6d :2 2a
7a 7d :2 2a 81 84 :2 2a 90 93
:2 2a 9b 9e :2 2a aa ad b4 bd
c0 :2 ad :2 2a :2 13 61 :2 10 :2 d :4 19
:2 d a :3 2a d 16 1e :2 d 21
23 :2 21 d 1b 23 2c 36 :2 2c
3f :2 23 42 44 4d 57 :2 4d 63
:2 44 :2 23 22 67 69 :2 22 21 20
22 :2 21 :2 1b d 10 19 22 :2 10
28 25 31 3d :2 28 :2 25 10 1a
:2 10 1d 10 40 10 1b 10 :4 d
25 :3 a 18 a e 15 1e 29
:2 15 2d :2 e d 32 34 :2 32 10
19 28 :2 10 2b 2d :2 2b 13 1c
2c :2 13 2f 31 :2 2f 13 :2 1c 28
35 3e 4a 56 67 25 32 3c
44 4c 54 25 35 40 50 25
36 :2 28 13 16 :2 1f 28 2a :2 28
20 35 3b 19 2a 36 48 55
65 1f 2c 3d 47 55 63 19
20 1c 28 :3 26 1c :2 25 31 1c
2d 1c :2 25 31 1c :4 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 66 69 6a :2 66 :2 3b :3 1f :2 25
2a 36 76 79 :2 36 86 89 :2 36
8d 90 :2 36 9c 9f :2 36 a7 aa
:2 36 b6 b9 c0 c9 cc :2 b9 :2 36
:2 1f 6d :2 1c :2 19 :4 25 :2 19 16 :4 2c
:2 13 33 13 :2 1c 28 35 3e 4a
56 67 25 32 3c 44 4c 54
25 35 40 50 25 36 :2 28 13
:4 10 2f 10 22 2b 3b :2 22 3e
40 :2 22 10 13 1c 2c :2 13 2f
31 :2 2f 13 :2 1c 28 35 3e 4a
56 67 25 32 3c 44 4c 54
25 35 40 50 25 36 :2 28 13
16 :2 1f 28 2a :2 28 20 35 3b
19 2a 36 48 55 65 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 66 69 6a :2 66 :2 3b :3 1f
:2 25 2a 36 76 79 :2 36 86 89
:2 36 8d 90 :2 36 9c 9f :2 36 a7
aa :2 36 b6 b9 c0 c9 cc :2 b9
:2 36 :2 1f 6d :2 1c :2 19 :4 25 :2 19 16
:4 2c :2 13 33 13 :2 1c 28 35 3e
4a 56 67 25 32 3c 44 4c
54 25 35 40 50 25 36 :2 28
13 :4 10 :4 d 11 :2 1a 23 25 :2 23
10 2e 35 3e 49 :2 35 4d :2 2e
2d 51 53 :2 51 2c :2 10 14 1d
2d :2 14 32 30 3b 46 :2 32 :2 30
13 4f 58 5e :2 4f 61 63 :2 61
4e :2 13 6b 2c 41 :2 6b 44 46
:2 44 6a :2 13 1d 32 46 16 22
2b 3a 16 27 33 45 52 62
16 25 31 41 16 24 16 :2 1c
30 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 63 66 67 :2 63 :2 38
:3 1c :2 22 27 33 73 76 :2 33 83
86 :2 33 8a 8d :2 33 99 9c :2 33
a4 a7 :2 33 b3 b6 bd c6 c9
:2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22 :2 16
13 :3 4d 1d 32 3f 4a 1c 29
3a 4e 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 63 66 67 :2 63
:2 38 :3 1c :2 22 27 33 73 76 :2 33
83 86 :2 33 8a 8d :2 33 99 9c
:2 33 a4 a7 :2 33 b3 b6 bd c6
c9 :2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22
:2 16 13 :3 4d 1d 32 43 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 63 66 67 :2 63 :2 38 :3 1c
:2 22 27 33 73 76 :2 33 83 86
:2 33 8a 8d :2 33 99 9c :2 33 a4
a7 :2 33 b3 b6 bd c6 c9 :2 b6
:2 33 :2 1c 6a :2 19 :2 16 :4 22 :2 16 13
:4 4d 1d 32 38 16 27 33 45
52 62 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 63 66
67 :2 63 :2 38 :3 1c :2 22 27 33 73
76 :2 33 83 86 :2 33 8a 8d :2 33
99 9c :2 33 a4 a7 :2 33 b3 b6
bd c6 c9 :2 b6 :2 33 :2 1c 6a :2 19
:2 16 :4 22 :2 16 13 :7 10 56 :2 d 37
d 1c 23 2c 39 :2 23 3d :2 46
:2 1c d 10 19 28 :2 10 2b 2d
:2 2b 10 :2 19 25 32 3b 47 53
64 25 32 3c 44 4c 54 25
35 40 50 25 36 :2 25 10 14
:2 1d 26 28 :2 26 13 30 39 44
:2 30 47 49 :2 47 2f :2 13 51 5a
63 :2 51 66 68 :2 66 50 :2 13 1d
32 38 16 27 33 45 52 62
1c 29 3a 44 52 60 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
63 66 67 :2 63 :2 38 :3 1c :2 22 27
33 73 76 :2 33 83 86 :2 33 8a
8d :2 33 99 9c :2 33 a4 a7 :2 33
b3 b6 bd c6 c9 :2 b6 :2 33 :2 1c
6a :2 19 :2 16 :4 22 :2 16 13 :4 6b :2 10
2f :4 14 :2 13 20 13 1d 24 3e
45 5f 66 80 87 9c ab :2 16
:2 1f 2b 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 63 66
67 :2 63 :2 38 :3 1c :2 22 27 33 73
76 :2 33 83 86 :2 33 8a 8d :2 33
99 9c :2 33 a4 a7 :2 33 b3 b6
bd c6 c9 :2 b6 :2 33 :2 1c 6a :2 19
:2 16 :4 22 :2 16 13 :3 33 16 :2 21 29
34 3e :2 16 42 44 :2 42 16 23
:2 2c :2 16 26 16 20 30 1e 1f
:2 19 :2 22 2e 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 66
69 6a :2 66 :2 3b :3 1f :2 25 2a 36
76 79 :2 36 86 89 :2 36 8d 90
:2 36 9c 9f :2 36 a7 aa :2 36 b6
b9 c0 c9 cc :2 b9 :2 36 :2 1f 6d
:2 1c :2 19 :4 25 :2 19 16 :3 46 16 29
3b 49 54 62 6d 28 :2 29 16
19 22 33 :2 19 36 38 :2 36 19
26 :2 19 27 :2 19 2b :2 19 27 :2 19
28 :2 19 1e :3 19 1f 2c 3c :3 19
1c 24 :2 1c :2 25 31 1c 2a 1c
:2 25 31 1c :4 19 1c 22 :3 1c :2 25
31 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 69 6c 6d
:2 69 :2 3e :3 22 :2 28 2d 39 79 7c
:2 39 89 8c :2 39 90 93 :2 39 9f
a2 :2 39 aa ad :2 39 b9 bc c3
cc cf :2 bc :2 39 :2 22 70 :2 1f :2 1c
:4 28 :2 1c 19 :3 3a 23 32 43 22
30 :2 1c :2 25 31 1c 19 21 1f
:2 28 34 1f 2f :2 1c :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
69 6c 6d :2 69 :2 3e :3 22 :2 28 2d
39 79 7c :2 39 89 8c :2 39 90
93 :2 39 9f a2 :2 39 aa ad :2 39
b9 bc c3 cc cf :2 bc :2 39 :2 22
70 :2 1f :2 1c :4 28 :2 1c 19 :3 3a 19
26 :2 19 26 :2 19 26 2d 37 3a
:2 2d 47 4a :2 26 :2 19 26 2d 37
3a :2 2d 4b 4e :2 26 :2 19 26 2d
37 3a :2 2d 4a 4d :2 26 :2 19 26
2d 37 22 :2 2d 24 27 :2 26 :2 19
2c 3a 46 52 5a 62 6e 24
2f 3a 46 52 5e 24 2f 3b
:2 2c 19 1c :2 26 38 :2 42 4e 52
63 66 67 :2 63 :2 38 :3 1c :2 22 27
33 73 76 :2 33 83 86 :2 33 8a
8d :2 33 97 9a a3 ab :2 a3 af
:2 9a :2 33 b7 ba :2 33 c2 c5 :2 33
ca cd :2 33 d5 d8 :2 33 :2 1c 6a
:2 19 1c :2 26 38 :2 42 4e 51 62
65 66 :2 62 :2 38 :3 1c :2 22 27 33
73 76 :2 33 :2 1c 69 :3 19 :2 24 38
3b 44 :2 19 3a :2 16 46 :2 13 33
:3 10 22 2b 3b :2 22 3e 40 :2 22
:2 10 :2 19 25 32 3b 47 53 64
25 32 3c 44 4c 54 25 35
40 50 25 36 :2 25 10 14 :2 1d
26 28 :2 26 13 30 39 44 :2 30
47 49 :2 47 2f :2 13 51 5a 63
:2 51 66 68 :2 66 50 :2 13 1d 32
38 16 27 33 45 52 62 1c
30 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 63 66 67 :2 63 :2 38
:3 1c :2 22 27 33 73 76 :2 33 83
86 :2 33 8a 8d :2 33 99 9c :2 33
a4 a7 :2 33 b3 b6 bd c6 c9
:2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22 :2 16
13 :4 6b :2 10 :4 d :4 a d :2 16 1f
22 :2 1f 10 :2 1a 2c :2 36 42 46
57 5a 5b :2 57 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 77 7a :2 27 7e
81 :2 27 8b 8e 97 9f :2 a8 :2 97
b3 :2 8e :2 27 bb be :2 27 c6 c9
:2 27 ce d1 :2 27 d9 dc :2 27 :2 10
5e :2 d 10 :2 1a 2c :2 36 42 45
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 :2 10 5d :3 d :2 18
2c :2 35 3f 48 :2 d 24 :3 a 1c
a e 17 20 :2 e 23 26 :2 23
d 32 3b 4b :2 32 4e 50 :2 4e
31 :3 d 1f d 53 :2 a d 16
25 :2 d 28 2a :2 28 11 18 21
2c :2 18 30 :2 11 10 35 37 :2 35
:4 14 13 :4 17 16 20 35 49 19
25 2e 3d 19 2a 36 48 55
65 19 28 19 29 19 27 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 66 69 6a :2 66 :2 3b
:3 1f :2 25 2a 36 76 79 :2 36 86
89 :2 36 8d 90 :2 36 9c 9f :2 36
a7 aa :2 36 b6 b9 c0 c9 cc
:2 b9 :2 36 :2 1f 6d :2 1c :2 19 :4 25 :2 19
16 :4 33 20 35 49 19 25 19
28 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 69 6a
:2 66 :2 3b :3 1f :2 25 2a 36 76 79
:2 36 86 89 :2 36 8d 90 :2 36 9c
9f :2 36 a7 aa :2 36 b6 b9 c0
c9 cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19
:4 25 :2 19 16 :7 13 2f :4 17 16 20
35 49 19 25 2e 3d 19 35
51 5e 76 19 36 52 5f 78
19 38 54 6e 19 34 50 66
19 2b 19 2c 19 2e 19 2a
19 2b 19 2c 19 2e 19 2a
19 2a 38 49 57 68 76 87
:2 19 2a 36 48 55 65 19 28
19 29 19 27 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
66 69 6a :2 66 :2 3b :3 1f :2 25 2a
36 76 79 :2 36 86 89 :2 36 8d
90 :2 36 9c 9f :2 36 a7 aa :2 36
b6 b9 c0 c9 cc :2 b9 :2 36 :2 1f
6d :2 1c :2 19 :4 25 :2 19 16 :4 33 20
35 49 19 25 2e 3d 19 35
51 5e 76 19 36 52 5f 78
19 38 54 6e 19 34 50 66
19 2b 19 2c 19 2e 19 2a
19 2b 19 2c 19 2e 19 2a
19 2a 38 49 57 68 76 87
19 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 69 6a
:2 66 :2 3b :3 1f :2 25 2a 36 76 79
:2 36 86 89 :2 36 8d 90 :2 36 9c
9f :2 36 a7 aa :2 36 b6 b9 c0
c9 cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19
:4 25 :2 19 16 :7 13 :4 10 d 3a 13
1c 25 :2 13 28 2a :2 28 1a 2f
43 13 1f 13 22 19 2d 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 60 63 64 :2 60 :2 35 :3 19 :2 1f
24 30 70 73 :2 30 80 83 :2 30
87 8a :2 30 96 99 :2 30 a1 a4
:2 30 b0 b3 ba c3 c6 :2 b3 :2 30
:2 19 67 :2 16 :2 13 :4 1f :2 13 10 :4 2c
3a :2 d 2c 11 18 21 2c :2 18
30 :2 11 10 35 37 :2 35 :4 14 13
:4 17 16 20 35 49 19 25 2e
3d 19 2a 36 48 55 65 19
28 19 29 19 27 1f 33 19
20 1c 28 :3 26 1c :2 25 31 1c
2d 1c :2 25 31 1c :4 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 66 69 6a :2 66 :2 3b :3 1f :2 25
2a 36 76 79 :2 36 86 89 :2 36
8d 90 :2 36 9c 9f :2 36 a7 aa
:2 36 b6 b9 c0 c9 cc :2 b9 :2 36
:2 1f 6d :2 1c :2 19 :4 25 :2 19 16 :4 33
20 35 49 19 25 2e 3d 19
27 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 69 6a
:2 66 :2 3b :3 1f :2 25 2a 36 76 79
:2 36 86 89 :2 36 8d 90 :2 36 9c
9f :2 36 a7 aa :2 36 b6 b9 c0
c9 cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19
:4 25 :2 19 16 :7 13 2f :4 17 16 20
35 49 19 25 2e 3d 19 35
51 5e 76 19 36 52 5f 78
19 38 54 6e 19 34 50 66
19 2b 19 2c 19 2e 19 2a
19 2b 19 2c 19 2e 19 2a
19 2a 38 49 57 68 76 87
:2 19 2a 36 48 55 65 19 28
19 29 19 27 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
66 6a 6b :2 66 :2 3b :3 1f :2 25 2a
36 77 7a :2 36 87 8a :2 36 8e
91 :2 36 9d a0 :2 36 a8 ab :2 36
b7 ba c1 ca cd :2 ba :2 36 :2 1f
6e :2 1c :2 19 :4 25 :2 19 16 :4 33 20
35 49 19 25 2e 3d 19 27
19 35 51 5e 76 19 36 52
5f 78 19 38 54 6e 19 34
50 66 19 2b 19 2c 19 2e
19 2a 19 2b 19 2c 19 2e
19 2a 19 2a 38 49 57 68
76 87 19 1f 33 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 66
6a 6b :2 66 :2 3b :3 1f :2 25 2a 36
77 7a :2 36 87 8a :2 36 8e 91
:2 36 9d a0 :2 36 a8 ab :2 36 b7
ba c1 ca cd :2 ba :2 36 :2 1f 6e
:2 1c :2 19 :4 25 :2 19 16 :7 13 :4 10 d
3a 13 1c 25 :2 13 28 2a :2 28
:4 14 13 16 1f 25 :2 16 28 2a
:2 28 20 35 49 19 25 2e 3d
19 27 19 1f 2a 1f 33 19
20 1c 28 :3 26 1c :2 25 31 1c
2d 1c :2 25 31 1c :4 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 66 6a 6b :2 66 :2 3b :3 1f :2 25
2a 36 77 7a :2 36 87 8a :2 36
8e 91 :2 36 9d a0 :2 36 a8 ab
:2 36 b7 ba c1 ca cd :2 ba :2 36
:2 1f 6e :2 1c :2 19 :4 25 :2 19 16 :4 2c
20 35 49 19 25 2e 3d 19
27 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 6a 6b
:2 66 :2 3b :3 1f :2 25 2a 36 77 7a
:2 36 87 8a :2 36 8e 91 :2 36 9d
a0 :2 36 a8 ab :2 36 b7 ba c1
ca cd :2 ba :2 36 :2 1f 6e :2 1c :2 19
:4 25 :2 19 16 :7 13 31 1d 32 46
16 22 2b 3a 16 24 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 63 67 68 :2 63 :2 38 :3 1c
:2 22 27 33 74 77 :2 33 84 87
:2 33 8b 8e :2 33 9a 9d :2 33 a5
a8 :2 33 b4 b7 be c7 ca :2 b7
:2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16 13
:7 10 2c 3a :2 d :4 a :4 f e 30
39 4b :2 30 4e 50 :2 4e 2f :2 e
d 58 10 20 :2 58 23 25 :2 23
57 :3 d 1b :2 d 1b :2 d 18 :2 d
18 d 10 19 28 :2 10 2b 2d
:2 2b 1a 2d 39 42 4a 51 67
6f 76 8d 97 a8 b6 18 2d
37 42 48 4e 5a 6d 79 18
19 2d :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 60 64 65 :2 60 :2 35 :3 19 :2 1f
24 30 71 74 :2 30 81 84 :2 30
88 8b :2 30 97 9a :2 30 a2 a5
:2 30 b1 b4 bb c4 c7 :2 b4 :2 30
:2 19 68 :2 16 :2 13 :4 1f :2 13 10 :4 2f
10 27 10 1a 26 2f 37 3e
54 5c 63 7a 84 95 a3 18
22 2d 33 39 45 58 64 18
19 2d :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 60 64 65 :2 60 :2 35 :3 19 :2 1f
24 30 71 74 :2 30 81 84 :2 30
88 8b :2 30 97 9a :2 30 a2 a5
:2 30 b1 b4 bb c4 c7 :2 b4 :2 30
:2 19 68 :2 16 :2 13 :4 1f :2 13 10 :7 d
11 :2 1a 25 23 :2 2e :2 23 10 14
1d 2d :2 14 32 30 3b 46 :2 32
:2 30 13 4f 58 5e :2 4f 61 63
:2 61 4e :2 13 6b 2c 41 :2 6b 44
46 :2 44 6a :2 13 1d 32 3f 4a
1c 29 3a 4e 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 63 67
68 :2 63 :2 38 :3 1c :2 22 27 33 74
77 :2 33 84 87 :2 33 8b 8e :2 33
9a 9d :2 33 a5 a8 :2 33 b4 b7
be c7 ca :2 b7 :2 33 :2 1c 6b :2 19
:2 16 :4 22 :2 16 13 :3 4d 1d 32 40
16 2f 33 42 1c 29 3a 4e
1c 30 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 63 67 68 :2 63
:2 38 :3 1c :2 22 27 33 74 77 :2 33
84 87 :2 33 8b 8e :2 33 9a 9d
:2 33 a5 a8 :2 33 b4 b7 be c7
ca :2 b7 :2 33 :2 1c 6b :2 19 :2 16 :4 22
:2 16 13 :4 4d 13 18 :4 13 1c 25
30 3d :3 16 19 1d :2 19 :2 22 2e
19 23 19 :2 22 2e 19 :4 16 19
:2 22 2b 2e :2 2b :2 19 30 :3 16 21
2a 33 :2 21 36 38 41 4c :2 38
:2 21 16 19 22 2b :2 19 2e 30
:2 2e 1c 25 2e :2 1c 33 31 3c
4b :2 33 :2 31 1f 28 33 :2 1f 39
36 42 51 :2 39 :2 36 1f 2c 35
44 :2 2c 1f 54 1f 2c 35 44
:2 2c 47 49 52 5b :2 49 :2 2c 5e
60 69 74 :2 60 :2 2c 1f :4 1c 4e
:2 19 23 38 45 50 71 1c 23
1f 2b :3 29 1f :2 28 34 1f 30
1f :2 28 34 1f :4 1c 19 21 1f
:2 28 34 1f 2f :2 1c :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
69 6d 6e :2 69 :2 3e :3 22 :2 28 2d
39 7a 7d :2 39 8a 8d :2 39 91
94 :2 39 a0 a3 :2 39 ab ae :2 39
ba bd c4 cd d0 :2 bd :2 39 :2 22
71 :2 1f :2 1c :4 28 :2 1c 19 :3 32 19
27 19 32 :2 16 19 22 2b :2 19
31 2e 3a 49 :2 31 :2 2e :2 19 4c
:2 16 13 17 10 16 1c :3 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 63 67 68
:2 63 :2 38 :3 1c :2 22 27 33 74 77
:2 33 84 87 :2 33 8b 8e :2 33 9a
9d :2 33 a5 a8 :2 33 b4 b7 be
c7 ca :2 b7 :2 33 :2 1c 6b :2 19 :2 16
:4 22 :2 16 13 :3 10 17 20 29 :2 17
2c 2e :2 2c 16 :4 37 36 35 :2 16
20 35 46 57 6b 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 66
6a 6b :2 66 :2 3b :3 1f :2 25 2a 36
77 7a :2 36 87 8a :2 36 8e 91
:2 36 9d a0 :2 36 a8 ab :2 36 b7
ba c1 ca cd :2 ba :2 36 :2 1f 6e
:2 1c :2 19 :4 25 :2 19 16 :4 50 :2 13 :4 10
13 1c 2b :2 13 2e 30 :2 2e 17
1e 27 32 :2 1e 36 :2 17 16 3b
3d :2 3b 16 29 3c 51 :2 29 16
40 16 29 3c 51 :2 29 16 :4 13
32 :2 10 3e :2 d 28 :2 a 2a :2 7
a :2 13 1c 1e :2 1c a :2 13 1f
a 22 :2 7 4f :2 4 7 :2 11 23
:2 2d 39 3c 4d 51 52 :2 4d :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e 6f
72 :2 1e 76 79 :2 1e 83 86 8f
97 :2 a0 :2 8f ab :2 86 :2 1e b3 b6
:2 1e be c1 :2 1e c6 c9 :2 1e cc
cf :2 1e :2 7 55 :3 4 :2 f 21 :2 2a
34 38 :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 51 55 56
:2 51 :2 26 :3 a :2 10 15 21 62 65
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 59 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4e 52 53
:2 4e :2 23 :3 7 :2 d 12 1e 5f 62
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 56 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
1e7a
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 :4 14
:4 15 :4 16 :4 17 2
:4 18 :2 1 :7 1a :7 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :7 26 :7 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:5 38 :5 39 :7 3a :7 3b
:7 3c :5 3d :5 3e :5 3f
:5 40 :5 41 :5 42 :7 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :5 4b
:5 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :2 54
0 :2 54 :7 55 56
:4 57 :2 58 55 :5 54
:2 5a 0 :2 5a :3 5b
5c :4 5d :2 5e 5b
:5 5a :7 60 :b 62 :11 63
64 :2 63 :2 64 :2 63
:2 64 :2 63 :2 65 :2 63
:9 65 :2 63 :2 66 :2 63
:2 66 :2 63 :2 66 :2 63
:2 66 :2 63 :2 67 :2 63
:2 67 :2 63 :2 67 :2 63
:2 67 :2 63 :2 68 :2 63
:2 68 :2 63 :2 68 :2 63
:2 68 :2 63 :2 69 :2 63
:9 69 :2 63 :2 6a :2 63
:2 6a :2 63 :2 6a :2 63
:2 6a :2 63 :2 6b :2 63
:9 6b :2 63 :2 6c :2 63
:9 6c :2 63 :2 6d :2 63
:9 6d :2 63 :2 6e :2 63
:9 6e :2 63 :2 6f :2 63
:9 6f :2 63 :2 70 :2 63
:9 70 :2 63 :2 71 :2 63
:2 71 :2 63 :2 71 :2 63
:2 71 :2 63 :2 72 :2 63
:2 72 :2 63 :2 72 :2 63
:2 72 :2 63 :2 73 :2 63
:9 73 :2 63 :2 74 :2 63
:9 74 :2 63 :2 75 :2 63
:2 75 :2 63 :2 75 :2 63
:2 75 :2 63 :2 76 :2 63
:2 76 :2 63 :2 76 :2 63
:2 76 :2 63 :2 77 :2 63
:9 77 :2 63 :2 78 :2 63
:2 78 :2 63 :2 78 :2 63
:2 78 :2 63 :2 78 :4 63
:3 62 :11 7b :b 7c :3 7b
:11 7f :2 80 :2 7f :4 80
:6 7f :11 81 :20 82 :3 81
:11 84 :b 85 :3 84 :9 87
80 :2 7f :16 8a :11 8b
:20 8c :3 8b :11 8e :b 8f
:3 8e :9 91 :3 8a :3 96
:3 97 :3 98 :3 99 :3 9a
:3 9b :3 9c :3 9d :3 9e
:3 9f :3 a0 :3 a1 :3 a2
:3 a3 :e a7 :16 a8 :5 aa
:11 ab :20 ac :3 ab :11 ae
:b af :3 ae :9 b1 :3 aa
:3 b4 :3 b5 :3 b6 :4 b9
:3 ba b9 :5 bb b8
bd :5 be :3 bd :2 bf
:5 c1 :11 c2 :24 c3 :3 c2
:2 c0 :6 bf bc :3 a8
:5 c8 :a c9 :7 cb cc
:3 cb :16 cf :2 d0 :2 cf
:4 d0 :3 cf :a d0 :2 cf
:3 d1 :3 d3 d4 :4 d5
d3 :5 d6 d2 d8
:5 d9 :3 d8 :2 da :5 dc
:11 dd :24 de :3 dd :2 db
:6 da d7 :3 d0 :9 e3
:3 e4 :3 e5 :3 e6 :5 e8
:7 ea :5 eb e9 ed
:5 ee :3 ed :2 ef :5 f1
:11 f2 :24 f3 :3 f2 :2 f0
:6 ef ec :6 e8 :3 e3
d0 :2 cf :19 fc :3 fd
:3 fc a8 :3 100 :5 103
:5 104 :5 105 :5 106 :3 107
103 :5 108 102 10a
:5 10b :3 10a :2 10c :5 10e
:11 10f :24 110 :3 10f :2 10d
:6 10c 109 :3 ff :11 116
:2 117 :7 116 :11 11a :2e 11b
:3 11a :11 11d :b 11e :3 11d
:8 120 117 :2 116 ff
:3 a8 :9 125 :7 126 :11 127
:30 128 :3 127 :11 12a :b 12b
:3 12a :a 12d :3 126 :13 131
:5 132 :2 131 :11 133 :20 134
:3 133 :11 136 :b 137 :3 136
:9 139 132 :2 131 :5 13c
:9 13f :3 140 :3 13f :7 147
:5 148 146 14a :5 14b
:3 14a :2 14c :5 14e :11 14f
:24 150 :3 14f :2 14d :6 14c
149 :3 125 :9 155 :1b 157
:2 158 :5 157 :d 15a :3 15b
:3 15c 15a :3 15e 15d
:3 15a :3 155 :3 17b :e 17d
:9 17e :9 17f :9 180 :6 181
:4 182 :2 183 :3 180 :7 186
:3 188 :6 189 :6 18a 188
:6 18b :5 18c 18b :5 18e
18d :3 18b 187 191
:5 192 :3 191 :2 193 :5 195
:11 196 :24 197 :3 196 :2 194
:6 193 190 :6 186 17f
:9 19d :6 19e :4 19f :2 1a0
:3 19d 19c :3 17f 17e
:b 1a4 :9 1a5 :9 1a6 :6 1a7
:4 1a8 :2 1a9 :3 1a6 :7 1ac
:3 1ae :6 1af :2 1b0 1ae
:6 1b1 :5 1b2 1b1 :5 1b4
1b3 :3 1b1 1ad 1b7
:5 1b8 :3 1b7 :2 1b9 :5 1bb
:11 1bc :24 1bd :3 1bc :2 1ba
:6 1b9 1b6 :6 1ac 1a5
:9 1c3 :6 1c4 :4 1c5 :2 1c6
:3 1c3 1c2 :3 1a5 1a3
:3 17e :19 1cb :1b 1cc :2 1cd
:2 1cc :4 1cd :3 1cc :3 1cf
:4 1d0 :6 1d1 :4 1d2 :2 1d3
:2 1d4 :2 1d5 1cf :6 1d6
:5 1d7 1d6 :5 1d9 1d8
:3 1d6 1ce 1dc :5 1dd
:3 1dc :2 1de :5 1e0 :11 1e1
:24 1e2 :3 1e1 :2 1df :6 1de
1db :3 1cd :4 1e8 :4 1e9
1e8 :6 1ea :5 1eb 1ea
:5 1ed 1ec :3 1ea 1e7
1f0 :5 1f1 :3 1f0 :2 1f2
:5 1f4 :11 1f5 :24 1f6 :3 1f5
:2 1f3 :6 1f2 1ef :3 1cd
:3 1fc :2 1fd 1fc :6 1fe
:5 1ff 1fe :5 201 200
:3 1fe 1fb 204 :5 205
:3 204 :2 206 :5 208 :11 209
:24 20a :3 209 :2 207 :6 206
203 :4 1cd :3 210 :6 211
:2 212 210 :6 213 :5 214
213 :5 216 215 :3 213
20f 219 :5 21a :3 219
:2 21b :5 21d :11 21e :24 21f
:3 21e :2 21c :6 21b 218
:4 20e :3 1cc :3 1cb 17d
:d 226 :9 228 :9 229 :6 22a
:4 22b :2 22c :3 229 :20 22f
:3 231 :6 232 :6 233 231
:6 234 :5 235 234 :5 237
236 :3 234 230 23a
:5 23b :3 23a :2 23c :5 23e
:11 23f :24 240 :3 23f :2 23d
:6 23c 239 :6 22f 228
:5 246 :3 247 :b 24d :5 24e
24c 250 :5 251 :3 250
:2 252 :5 254 :11 255 :24 256
:3 255 :2 253 :6 252 24f
:3 246 :c 25b :5 25c :3 25d
:2 260 261 262 260
:5 263 25f 265 :5 266
:3 265 :2 267 :5 269 :11 26a
:24 26b :3 26a :2 268 :6 267
264 :3 25b :7 270 271
:3 270 :9 273 :3 274 :3 275
:3 276 :3 277 :3 278 :5 27a
:6 27c :3 27d :5 27e 27d
:5 280 27f :3 27d :4 284
:5 285 283 287 :5 288
:3 287 :2 289 :5 28b :11 28c
:24 28d :3 28c :2 28a :6 289
286 :3 273 :3 293 :2 294
293 :5 295 292 297
:5 298 :3 297 :2 299 :5 29b
:11 29c :24 29d :3 29c :2 29a
:6 299 296 :3 273 :3 2a3
:3 2a5 :c 2a6 :c 2a7 :c 2a8
:4 2a9 2aa :2 2a9 :2 2ab
:3 2a9 :8 2ad :6 2ae :3 2af
:3 2ad :11 2b1 :2e 2b2 :3 2b1
:11 2b4 :b 2b5 :3 2b4 :8 2b7
:3 273 :3 25b :3 246 :b 2bc
:9 2bd :6 2be :4 2bf :2 2c0
:3 2bd :20 2c4 :3 2c6 :6 2c7
:2 2c8 2c6 :6 2c9 :5 2ca
2c9 :5 2cc 2cb :3 2c9
2c5 2cf :5 2d0 :3 2cf
:2 2d1 :5 2d3 :11 2d4 :24 2d5
:3 2d4 :2 2d2 :6 2d1 2ce
:6 2c4 245 :3 228 225
:3 17d :7 2de :11 2df :30 2e0
:3 2df :11 2e2 :b 2e3 :3 2e2
:a 2e5 :3 2de :3 2e8 :16 2e9
:3 2ea :3 2e9 :9 2ed :e 2ee
:5 2ef :5 2f1 :3 2f3 :4 2f4
:6 2f5 :2 2f6 :2 2f7 :2 2f8
:2 2f9 2f3 :6 2fa :5 2fb
2fa :5 2fd 2fc :3 2fa
2f2 300 :5 301 :3 300
:2 302 :5 304 :11 305 :24 306
:3 305 :2 303 :6 302 2ff
:4 2f1 :3 30c :2 30d :2 30e
:2 30f 30c :6 310 :5 311
310 :5 313 312 :3 310
30b 316 :5 317 :3 316
:2 318 :5 31a :11 31b :24 31c
:3 31b :2 319 :6 318 315
:4 30a :3 2f1 2ef :5 323
:3 325 :4 326 :5 327 :5 328
:4 329 :4 32a :2 32c :2 32d
:2 32e :2 32f :2 331 :2 332
:2 333 :2 334 :8 335 337
:6 338 :2 339 :2 33a :2 33b
:2 33c 325 :6 33d :5 33e
33d :5 340 33f :3 33d
324 343 :5 344 :3 343
:2 345 :5 347 :11 348 :24 349
:3 348 :2 346 :6 345 342
:4 323 :3 350 :4 351 :5 352
:5 353 :4 354 :4 355 :2 357
:2 358 :2 359 :2 35a :2 35c
:2 35d :2 35e :2 35f :8 360
362 :2 363 350 :6 364
:5 365 364 :5 367 366
:3 364 34f 36a :5 36b
:3 36a :2 36c :5 36e :11 36f
:24 370 :3 36f :2 36d :6 36c
369 :4 34e :3 323 321
:3 2ef 376 2ee :9 376
:3 378 :2 379 :2 37a :2 37b
378 :6 37c :5 37d 37c
:5 37f 37e :3 37c 377
382 :5 383 :3 382 :2 384
:5 386 :11 387 :24 388 :3 387
:2 385 :6 384 381 :4 376
:3 2ee 2ed :e 38e :5 38f
:5 391 :3 393 :4 394 :6 395
:2 396 :2 397 :2 398 :2 399
393 :6 39a :5 39b 39a
:5 39d 39c :3 39a 392
3a0 :5 3a1 :3 3a0 :2 3a2
:5 3a4 :11 3a5 :24 3a6 :3 3a5
:2 3a3 :6 3a2 39f :4 391
:3 3ac :4 3ad :2 3ae :2 3af
3ac :6 3b0 :5 3b1 3b0
:5 3b3 3b2 :3 3b0 3ab
3b6 :5 3b7 :3 3b6 :2 3b8
:5 3ba :11 3bb :24 3bc :3 3bb
:2 3b9 :6 3b8 3b5 :4 3aa
:3 391 38f :5 3c3 :3 3c5
:4 3c6 :5 3c7 :5 3c8 :4 3c9
:4 3ca :2 3cc :2 3cd :2 3ce
:2 3cf :2 3d1 :2 3d2 :2 3d3
:2 3d4 :8 3d5 3d7 :6 3d8
:2 3d9 :2 3da :2 3db :2 3dc
3c5 :6 3dd :5 3de 3dd
:5 3e0 3df :3 3dd 3c4
3e3 :5 3e4 :3 3e3 :2 3e5
:5 3e7 :11 3e8 :24 3e9 :3 3e8
:2 3e6 :6 3e5 3e2 :4 3c3
:3 3ef :4 3f0 :2 3f1 :5 3f2
:5 3f3 :4 3f4 :4 3f5 :2 3f7
:2 3f8 :2 3f9 :2 3fa :2 3fc
:2 3fd :2 3fe :2 3ff :8 400
402 :2 403 3ef :6 404
:5 405 404 :5 407 406
:3 404 3ee 40a :5 40b
:3 40a :2 40c :5 40e :11 40f
:24 410 :3 40f :2 40d :6 40c
409 :4 3ed :3 3c3 3c1
:3 38f 416 38e :9 416
:5 417 :9 418 :3 41a :4 41b
:2 41c :3 41d :2 41e 41a
:6 41f :5 420 41f :5 422
421 :3 41f 419 425
:5 426 :3 425 :2 427 :5 429
:11 42a :24 42b :3 42a :2 428
:6 427 424 :4 418 :3 431
:4 432 :2 433 :2 434 431
:6 435 :5 436 435 :5 438
437 :3 435 430 43b
:5 43c :3 43b :2 43d :5 43f
:11 440 :24 441 :3 440 :2 43e
:6 43d 43a :4 42f :3 418
417 :3 448 :4 449 :2 44a
:2 44b 448 :6 44c :5 44d
44c :5 44f 44e :3 44c
447 452 :5 453 :3 452
:2 454 :5 456 :11 457 :24 458
:3 457 :2 455 :6 454 451
:4 446 :3 417 416 :3 38e
38d :3 2ed :13 462 :2 463
:2 462 :4 463 :3 462 :3 464
:3 465 :3 466 :3 467 :9 469
:d 46b :9 46c 46d :2 46e
46b :5 46f 46a 471
:5 472 :3 471 :2 473 :5 475
:11 476 :24 477 :3 476 :2 474
:6 473 470 :4 469 :3 47c
:c 47e :8 47f 480 :2 481
47e :5 482 47d 484
:5 485 :3 484 :2 486 :5 488
:11 489 :24 48a :3 489 :2 487
:6 486 483 :4 47b :3 469
:a 491 :1b 492 :2 493 :2 492
:4 493 :3 492 :4 495 :4 496
495 :6 497 :5 498 497
:5 49a 499 :3 497 494
49d :5 49e :3 49d :2 49f
:5 4a1 :11 4a2 :24 4a3 :3 4a2
:2 4a0 :6 49f 49c :3 493
:3 4a9 :4 4aa :4 4ab :2 4ac
4a9 :6 4ad :5 4ae 4ad
:5 4b0 4af :3 4ad 4a8
4b3 :5 4b4 :3 4b3 :2 4b5
:5 4b7 :11 4b8 :24 4b9 :3 4b8
:2 4b6 :6 4b5 4b2 :4 493
:5 4cd 4cf :7 4d0 :3 4d1
:5 4d2 4d1 :5 4d4 4d3
:3 4d1 :7 4d6 :2 4d7 :3 4d6
:f 4db :9 4dd :d 4de :d 4df
:7 4e0 4df :17 4e2 4e1
:3 4df :3 4de :6 4e7 :6 4e8
:5 4e9 4e8 :5 4eb 4ea
:3 4e8 4e6 4ee :5 4ef
:3 4ee :2 4f0 :5 4f2 :11 4f3
:24 4f4 :3 4f3 :2 4f1 :6 4f0
4ed :3 4dd :3 4f9 :3 4dd
:d 4fc :2 4fd :3 4fc 4cf
4ff 4cc :4 502 :5 503
501 505 :5 506 :3 505
:2 507 :5 509 :11 50a :24 50b
:3 50a :2 508 :6 507 504
:3 4cc :12 511 :6 513 :6 514
:5 515 514 :5 517 516
:3 514 512 51a :5 51b
:3 51a :2 51c :5 51e :11 51f
:24 520 :3 51f :2 51d :6 51c
519 :6 511 4cc :3 492
:9 56d :e 56e :7 56f 56e
:7 571 570 :3 56e :3 56d
:3 491 463 :2 462 :3 125
:7 578 :5 579 :3 578 :3 a7
:11 57f :30 580 :3 57f :a 582
61 :3 586 :11 587 :b 588
:17 589 :3 587 :2 58b :3 58c
:3 58d 58e 58c 58b
58c :3 58f :3 586 :2 590
:5 592 :11 593 :b 594 :18 595
:3 593 :2 597 598 :3 599
59a 598 597 598
:3 59b :2 591 :6 590 585
:7 1 
6aeb
4
:3 0 1 :3 0 2
:a 0 1e75 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 4 :3 0
7 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 8
:7 0 11 10 :3 0
4 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 6
:3 0 a :7 0 19
18 :3 0 4 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 6 :3 0 c
:7 0 21 20 :3 0
6 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 6
:3 0 e :7 0 29
28 :3 0 6 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 6 :3 0 10
:7 0 31 30 :3 0
6 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 4
:3 0 12 :7 0 39
38 :3 0 4 :3 0
13 :7 0 3d 3c
:3 0 25 160 0
23 6 :3 0 14
:7 0 41 40 :3 0
6 :3 0 15 :7 0
45 44 :3 0 29
186 0 27 4
:3 0 16 :7 0 49
48 :3 0 4 :3 0
17 :7 0 4d 4c
:3 0 2d :2 0 2b
6 :3 0 18 :7 0
51 50 :3 0 4
:3 0 19 :7 0 55
54 :3 0 1a :3 0
1b :3 0 1c :2 0
4 59 5a 0
57 5b 0 1e75
2 5c :2 0 1e
:2 0 45 4 :3 0
1e :2 0 43 5f
61 :6 0 64 62
0 1e73 0 1d
:6 0 21 :2 0 49
4 :3 0 47 66
68 :6 0 6b 69
0 1e73 0 1f
:6 0 23 :2 0 4d
4 :3 0 4b 6d
6f :6 0 72 70
0 1e73 0 20
:6 0 25 :2 0 51
4 :3 0 4f 74
76 :6 0 79 77
0 1e73 0 22
:6 0 27 :2 0 55
4 :3 0 53 7b
7d :6 0 80 7e
0 1e73 0 24
:6 0 27 :2 0 59
4 :3 0 57 82
84 :6 0 87 85
0 1e73 0 26
:6 0 27 :2 0 5d
4 :3 0 5b 89
8b :6 0 8e 8c
0 1e73 0 28
:6 0 27 :2 0 61
4 :3 0 5f 90
92 :6 0 95 93
0 1e73 0 29
:6 0 27 :2 0 65
4 :3 0 63 97
99 :6 0 9c 9a
0 1e73 0 2a
:6 0 27 :2 0 69
4 :3 0 67 9e
a0 :6 0 a3 a1
0 1e73 0 2b
:6 0 27 :2 0 6d
4 :3 0 6b a5
a7 :6 0 aa a8
0 1e73 0 2c
:6 0 27 :2 0 71
4 :3 0 6f ac
ae :6 0 b1 af
0 1e73 0 2d
:6 0 27 :2 0 75
4 :3 0 73 b3
b5 :6 0 b8 b6
0 1e73 0 2e
:6 0 31 :2 0 79
4 :3 0 77 ba
bc :6 0 bf bd
0 1e73 0 2f
:6 0 31 :2 0 7b
6 :3 0 c1 :7 0
c5 c2 c3 1e73
0 30 :6 0 31
:2 0 7d 6 :3 0
c7 :7 0 cb c8
c9 1e73 0 32
:6 0 35 :2 0 7f
6 :3 0 cd :7 0
d1 ce cf 1e73
0 33 :6 0 31
:2 0 81 6 :3 0
d3 :7 0 d7 d4
d5 1e73 0 34
:6 0 31 :2 0 83
6 :3 0 d9 :7 0
dd da db 1e73
0 36 :6 0 31
:2 0 85 6 :3 0
df :7 0 e3 e0
e1 1e73 0 37
:6 0 31 :2 0 87
6 :3 0 e5 :7 0
e9 e6 e7 1e73
0 38 :6 0 3b
:2 0 89 6 :3 0
eb :7 0 ef ec
ed 1e73 0 39
:6 0 31 :2 0 8b
6 :3 0 f1 :7 0
f5 f2 f3 1e73
0 3a :6 0 31
:2 0 8d 6 :3 0
f7 :7 0 fb f8
f9 1e73 0 3c
:6 0 31 :2 0 8f
6 :3 0 fd :7 0
101 fe ff 1e73
0 3d :6 0 31
:2 0 91 6 :3 0
103 :7 0 107 104
105 1e73 0 3e
:6 0 31 :2 0 93
6 :3 0 109 :7 0
10d 10a 10b 1e73
0 3f :6 0 31
:2 0 95 6 :3 0
10f :7 0 113 110
111 1e73 0 40
:6 0 31 :2 0 97
6 :3 0 115 :7 0
119 116 117 1e73
0 41 :6 0 9b
51c 0 99 6
:3 0 11b :7 0 11f
11c 11d 1e73 0
42 :6 0 27 :2 0
9d 44 :3 0 121
:7 0 124 122 0
1e73 0 43 :6 0
44 :3 0 126 :7 0
129 127 0 1e73
0 45 :6 0 27
:2 0 a1 4 :3 0
9f 12b 12d :6 0
130 12e 0 1e73
0 46 :6 0 49
:2 0 a5 4 :3 0
a3 132 134 :6 0
137 135 0 1e73
0 47 :6 0 ab
5a7 0 a9 4
:3 0 a7 139 13b
:6 0 13e 13c 0
1e73 0 48 :6 0
af 5db 0 ad
4b :3 0 140 :7 0
143 141 0 1e73
0 4a :6 0 4b
:3 0 145 :7 0 148
146 0 1e73 0
4c :6 0 b3 60f
0 b1 4b :3 0
14a :7 0 14d 14b
0 1e73 0 4d
:6 0 4b :3 0 14f
:7 0 152 150 0
1e73 0 4e :6 0
21 :2 0 b5 4b
:3 0 154 :7 0 157
155 0 1e73 0
4f :6 0 4b :3 0
159 :7 0 15c 15a
0 1e73 0 50
:6 0 31 :2 0 b9
4 :3 0 b7 15e
160 :6 0 163 161
0 1e73 0 51
:6 0 31 :2 0 bb
6 :3 0 165 :7 0
169 166 167 1e73
0 52 :6 0 31
:2 0 bd 6 :3 0
16b :7 0 16f 16c
16d 1e73 0 53
:6 0 31 :2 0 bf
6 :3 0 171 :7 0
175 172 173 1e73
0 54 :6 0 31
:2 0 c1 6 :3 0
177 :7 0 17b 178
179 1e73 0 55
:6 0 31 :2 0 c3
6 :3 0 17d :7 0
181 17e 17f 1e73
0 56 :6 0 31
:2 0 c5 6 :3 0
183 :7 0 187 184
185 1e73 0 57
:6 0 c9 724 0
c7 6 :3 0 189
:7 0 18d 18a 18b
1e73 0 58 :6 0
31 :2 0 cb 44
:3 0 18f :7 0 192
190 0 1e73 0
59 :6 0 44 :3 0
194 :7 0 197 195
0 1e73 0 5a
:6 0 31 :2 0 cd
5c :3 0 199 :7 0
19d 19a 19b 1e73
0 5b :6 0 31
:2 0 cf 5c :3 0
19f :7 0 1a3 1a0
1a1 1e73 0 5d
:6 0 31 :2 0 d1
6 :3 0 1a5 :7 0
1a9 1a6 1a7 1e73
0 5e :6 0 31
:2 0 d3 6 :3 0
1ab :7 0 1af 1ac
1ad 1e73 0 5f
:6 0 31 :2 0 d5
6 :3 0 1b1 :7 0
1b5 1b2 1b3 1e73
0 60 :9 0 d7
6 :3 0 1b7 :7 0
1bb 1b8 1b9 1e73
0 61 :6 0 62
:3 0 63 :a 0 2
1d0 :4 0 1bd 1c0
0 1be :3 0 64
:3 0 65 :3 0 66
:3 0 67 :3 0 65
:3 0 66 :3 0 68
:3 0 69 :3 0 6a
:3 0 2d :3 0 6b
:3 0 2e :3 0 6c
:3 0 6d :4 0 6e
1 :8 0 1d1 1bd
1c0 1d2 0 1e73
d9 1d2 1d4 1d1
1d3 :6 0 1d0 :7 0
1d2 62 :3 0 6f
:a 0 3 1e5 :5 0
1d6 1d9 0 1d7
:3 0 70 :3 0 71
:3 0 72 :3 0 73
:3 0 6a :3 0 2d
:3 0 74 :3 0 46
:3 0 75 :3 0 72
:4 0 76 1 :8 0
1e6 1d6 1d9 1e7
0 1e73 db 1e7
1e9 1e6 1e8 :6 0
1e5 :7 0 1e7 1f1
1f2 0 dd 1b
:3 0 1c :2 0 4
1eb 1ec 0 1ed
:7 0 1f0 1ee 0
1e73 0 77 :6 0
78 :3 0 79 :3 0
78 :3 0 7a :3 0
1f4 1f5 0 2
:4 0 df 1f6 1f8
1f3 1fa 1f9 :2 0
7b :3 0 7c :3 0
1fc 1fd 0 7d
:4 0 78 :3 0 7e
:3 0 200 201 0
2 :4 0 e1 202
204 7f :4 0 80
:2 0 81 :3 0 e3
207 209 :3 0 82
:4 0 80 :2 0 83
:4 0 e6 20c 20e
:3 0 80 :2 0 3
:3 0 e9 210 212
:3 0 80 :2 0 83
:4 0 ec 214 216
:3 0 80 :2 0 84
:4 0 ef 218 21a
:3 0 80 :2 0 85
:3 0 66 :3 0 5
:3 0 f2 21e 220
86 :4 0 f4 21d
223 f7 21c 225
:3 0 80 :2 0 84
:4 0 fa 227 229
:3 0 80 :2 0 83
:4 0 fd 22b 22d
:3 0 80 :2 0 7
:3 0 100 22f 231
:3 0 80 :2 0 83
:4 0 103 233 235
:3 0 80 :2 0 84
:4 0 106 237 239
:3 0 80 :2 0 83
:4 0 109 23b 23d
:3 0 80 :2 0 8
:3 0 10c 23f 241
:3 0 80 :2 0 83
:4 0 10f 243 245
:3 0 80 :2 0 84
:4 0 112 247 249
:3 0 80 :2 0 83
:4 0 115 24b 24d
:3 0 80 :2 0 9
:3 0 118 24f 251
:3 0 80 :2 0 83
:4 0 11b 253 255
:3 0 80 :2 0 84
:4 0 11e 257 259
:3 0 80 :2 0 85
:3 0 66 :3 0 a
:3 0 121 25d 25f
86 :4 0 123 25c
262 126 25b 264
:3 0 80 :2 0 84
:4 0 129 266 268
:3 0 80 :2 0 83
:4 0 12c 26a 26c
:3 0 80 :2 0 b
:3 0 12f 26e 270
:3 0 80 :2 0 83
:4 0 132 272 274
:3 0 80 :2 0 84
:4 0 135 276 278
:3 0 80 :2 0 85
:3 0 66 :3 0 c
:3 0 138 27c 27e
86 :4 0 13a 27b
281 13d 27a 283
:3 0 80 :2 0 84
:4 0 140 285 287
:3 0 80 :2 0 85
:3 0 66 :3 0 d
:3 0 143 28b 28d
86 :4 0 145 28a
290 148 289 292
:3 0 80 :2 0 84
:4 0 14b 294 296
:3 0 80 :2 0 85
:3 0 66 :3 0 e
:3 0 14e 29a 29c
86 :4 0 150 299
29f 153 298 2a1
:3 0 80 :2 0 84
:4 0 156 2a3 2a5
:3 0 80 :2 0 85
:3 0 66 :3 0 f
:3 0 159 2a9 2ab
86 :4 0 15b 2a8
2ae 15e 2a7 2b0
:3 0 80 :2 0 84
:4 0 161 2b2 2b4
:3 0 80 :2 0 85
:3 0 66 :3 0 10
:3 0 164 2b8 2ba
86 :4 0 166 2b7
2bd 169 2b6 2bf
:3 0 80 :2 0 84
:4 0 16c 2c1 2c3
:3 0 80 :2 0 85
:3 0 66 :3 0 11
:3 0 16f 2c7 2c9
86 :4 0 171 2c6
2cc 174 2c5 2ce
:3 0 80 :2 0 84
:4 0 177 2d0 2d2
:3 0 80 :2 0 83
:4 0 17a 2d4 2d6
:3 0 80 :2 0 12
:3 0 17d 2d8 2da
:3 0 80 :2 0 83
:4 0 180 2dc 2de
:3 0 80 :2 0 84
:4 0 183 2e0 2e2
:3 0 80 :2 0 83
:4 0 186 2e4 2e6
:3 0 80 :2 0 13
:3 0 189 2e8 2ea
:3 0 80 :2 0 83
:4 0 18c 2ec 2ee
:3 0 80 :2 0 84
:4 0 18f 2f0 2f2
:3 0 80 :2 0 85
:3 0 66 :3 0 14
:3 0 192 2f6 2f8
86 :4 0 194 2f5
2fb 197 2f4 2fd
:3 0 80 :2 0 84
:4 0 19a 2ff 301
:3 0 80 :2 0 85
:3 0 66 :3 0 15
:3 0 19d 305 307
86 :4 0 19f 304
30a 1a2 303 30c
:3 0 80 :2 0 84
:4 0 1a5 30e 310
:3 0 80 :2 0 83
:4 0 1a8 312 314
:3 0 80 :2 0 16
:3 0 1ab 316 318
:3 0 80 :2 0 83
:4 0 1ae 31a 31c
:3 0 80 :2 0 84
:4 0 1b1 31e 320
:3 0 80 :2 0 83
:4 0 1b4 322 324
:3 0 80 :2 0 17
:3 0 1b7 326 328
:3 0 80 :2 0 83
:4 0 1ba 32a 32c
:3 0 80 :2 0 84
:4 0 1bd 32e 330
:3 0 80 :2 0 85
:3 0 66 :3 0 18
:3 0 1c0 334 336
86 :4 0 1c2 333
339 1c5 332 33b
:3 0 80 :2 0 84
:4 0 1c8 33d 33f
:3 0 80 :2 0 83
:4 0 1cb 341 343
:3 0 80 :2 0 19
:3 0 1ce 345 347
:3 0 80 :2 0 83
:4 0 1d1 349 34b
:3 0 80 :2 0 87
:4 0 1d4 34d 34f
:3 0 1d7 1fe 351
:2 0 353 1dc 354
1fb 353 0 355
1de 0 1dd3 78
:3 0 79 :3 0 356
357 0 78 :3 0
88 :3 0 359 35a
0 49 :2 0 2
:4 0 89 :2 0 8a
:2 0 49 :2 0 1e0
35f 361 :3 0 1e3
35b 363 358 365
364 :2 0 7b :3 0
8b :3 0 367 368
0 7d :4 0 8c
:4 0 80 :2 0 81
:3 0 1e7 36c 36e
:3 0 1ea 369 370
:2 0 372 1ed 373
366 372 0 374
1ef 0 1dd3 5
:3 0 8d :2 0 1f1
376 377 :3 0 378
:2 0 379 :2 0 85
:3 0 5 :3 0 31
:2 0 1f3 37b 37e
8e :2 0 49 :2 0
1f8 380 382 :3 0
383 :2 0 85 :3 0
5 :3 0 31 :2 0
1fb 385 388 8f
:2 0 90 :2 0 200
38a 38c :3 0 38d
:2 0 384 38f 38e
:2 0 390 :2 0 37a
392 391 :2 0 78
:3 0 79 :3 0 394
395 0 78 :3 0
88 :3 0 397 398
0 91 :2 0 2
:4 0 92 :2 0 8a
:2 0 49 :2 0 203
39d 39f :3 0 206
399 3a1 396 3a3
3a2 :2 0 7b :3 0
8b :3 0 3a5 3a6
0 7d :4 0 93
:4 0 80 :2 0 81
:3 0 20a 3aa 3ac
:3 0 80 :2 0 94
:4 0 20d 3ae 3b0
:3 0 80 :2 0 95
:4 0 210 3b2 3b4
:3 0 80 :2 0 85
:3 0 66 :3 0 96
:3 0 97 :3 0 3b9
3ba 0 213 3b8
3bc 86 :4 0 215
3b7 3bf 218 3b6
3c1 :3 0 21b 3a7
3c3 :2 0 3c5 21e
3c6 3a4 3c5 0
3c7 220 0 3f0
78 :3 0 79 :3 0
3c8 3c9 0 78
:3 0 88 :3 0 3cb
3cc 0 49 :2 0
2 :4 0 98 :2 0
8a :2 0 49 :2 0
222 3d1 3d3 :3 0
225 3cd 3d5 3ca
3d7 3d6 :2 0 7b
:3 0 8b :3 0 3d9
3da 0 7d :4 0
99 :4 0 80 :2 0
81 :3 0 229 3de
3e0 :3 0 22c 3db
3e2 :2 0 3e4 22f
3e5 3d8 3e4 0
3e6 231 0 3f0
9a :3 0 9b :3 0
3e7 3e8 0 96
:3 0 97 :3 0 3ea
3eb 0 9c :3 0
233 3e9 3ee :2 0
3f0 236 3f1 393
3f0 0 3f2 23a
0 1dd3 3 :3 0
8d :2 0 23c 3f4
3f5 :3 0 3f6 :2 0
3f7 :2 0 f :3 0
8d :2 0 23e 3fa
3fb :3 0 3fc :2 0
3fd :2 0 3f8 3ff
3fe :2 0 19 :3 0
8d :2 0 240 402
403 :3 0 404 :2 0
405 :2 0 400 407
406 :2 0 78 :3 0
79 :3 0 409 40a
0 78 :3 0 88
:3 0 40c 40d 0
91 :2 0 2 :4 0
9d :2 0 8a :2 0
49 :2 0 242 412
414 :3 0 245 40e
416 40b 418 417
:2 0 7b :3 0 8b
:3 0 41a 41b 0
7d :4 0 9e :4 0
80 :2 0 81 :3 0
249 41f 421 :3 0
80 :2 0 94 :4 0
24c 423 425 :3 0
80 :2 0 95 :4 0
24f 427 429 :3 0
80 :2 0 85 :3 0
66 :3 0 96 :3 0
97 :3 0 42e 42f
0 252 42d 431
86 :4 0 254 42c
434 257 42b 436
:3 0 25a 41c 438
:2 0 43a 25d 43b
419 43a 0 43c
25f 0 465 78
:3 0 79 :3 0 43d
43e 0 78 :3 0
88 :3 0 440 441
0 49 :2 0 2
:4 0 9f :2 0 8a
:2 0 49 :2 0 261
446 448 :3 0 264
442 44a 43f 44c
44b :2 0 7b :3 0
8b :3 0 44e 44f
0 7d :4 0 a0
:4 0 80 :2 0 81
:3 0 268 453 455
:3 0 26b 450 457
:2 0 459 26e 45a
44d 459 0 45b
270 0 465 9a
:3 0 9b :3 0 45c
45d 0 96 :3 0
97 :3 0 45f 460
0 9c :3 0 272
45e 463 :2 0 465
275 466 408 465
0 467 279 0
1dd3 4d :4 0 468
469 0 1dd3 4f
:4 0 46b 46c 0
1dd3 32 :3 0 a1
:2 0 46e 46f 0
1dd3 4c :3 0 8
:3 0 471 472 0
1dd3 4e :3 0 9
:3 0 474 475 0
1dd3 51 :3 0 b
:3 0 477 478 0
1dd3 2f :3 0 19
:3 0 47a 47b 0
1dd3 3d :3 0 a
:3 0 47d 47e 0
1dd3 41 :3 0 f
:3 0 480 481 0
1dd3 57 :3 0 5
:3 0 483 484 0
1dd3 39 :3 0 10
:3 0 486 487 0
1dd3 4d :3 0 16
:3 0 489 48a 0
1dd3 42 :3 0 c
:3 0 48c 48d 0
1dd3 55 :3 0 31
:2 0 48f 490 0
1dd3 85 :3 0 a2
:3 0 51 :3 0 27b
493 495 31 :2 0
27d 492 498 96
:3 0 8e :2 0 a3
:3 0 49a 49c 0
282 49b 49e :3 0
85 :3 0 57 :3 0
31 :2 0 285 4a0
4a3 a4 :2 0 49
:2 0 28a 4a5 4a7
:3 0 4a8 :2 0 85
:3 0 57 :3 0 31
:2 0 28d 4aa 4ad
a4 :2 0 90 :2 0
292 4af 4b1 :3 0
4b2 :2 0 4a9 4b4
4b3 :2 0 7 :3 0
8d :2 0 295 4b7
4b8 :3 0 4b9 :2 0
78 :3 0 79 :3 0
4bb 4bc 0 78
:3 0 88 :3 0 4be
4bf 0 91 :2 0
2 :4 0 a5 :2 0
8a :2 0 49 :2 0
297 4c4 4c6 :3 0
29a 4c0 4c8 4bd
4ca 4c9 :2 0 7b
:3 0 8b :3 0 4cc
4cd 0 7d :4 0
a6 :4 0 80 :2 0
81 :3 0 29e 4d1
4d3 :3 0 80 :2 0
94 :4 0 2a1 4d5
4d7 :3 0 80 :2 0
95 :4 0 2a4 4d9
4db :3 0 80 :2 0
85 :3 0 66 :3 0
96 :3 0 97 :3 0
4e0 4e1 0 2a7
4df 4e3 86 :4 0
2a9 4de 4e6 2ac
4dd 4e8 :3 0 2af
4ce 4ea :2 0 4ec
2b2 4ed 4cb 4ec
0 4ee 2b4 0
517 78 :3 0 79
:3 0 4ef 4f0 0
78 :3 0 88 :3 0
4f2 4f3 0 49
:2 0 2 :4 0 a7
:2 0 8a :2 0 49
:2 0 2b6 4f8 4fa
:3 0 2b9 4f4 4fc
4f1 4fe 4fd :2 0
7b :3 0 8b :3 0
500 501 0 7d
:4 0 a8 :4 0 80
:2 0 81 :3 0 2bd
505 507 :3 0 2c0
502 509 :2 0 50b
2c3 50c 4ff 50b
0 50d 2c5 0
517 9a :3 0 9b
:3 0 50e 50f 0
96 :3 0 97 :3 0
511 512 0 9c
:3 0 2c7 510 515
:2 0 517 2ca 518
4ba 517 0 519
2ce 0 6d2 2c
:3 0 3 :3 0 51a
51b 0 6d2 2e
:3 0 7 :3 0 51d
51e 0 6d2 2f
:3 0 19 :3 0 520
521 0 6d2 6a
:3 0 a9 :3 0 2d
:3 0 30 :3 0 69
:3 0 6b :3 0 2e
:4 0 aa 1 :8 0
530 1b :3 0 ab
:3 0 52b 52c 0
ac :3 0 52d 52e
0 530 2d0 583
ad :3 0 1b :3 0
ab :3 0 532 533
0 ac :3 0 534
535 0 537 2d3
539 2d5 538 537
:2 0 581 ae :3 0
1b :3 0 ab :3 0
53c 53d 0 ac
:3 0 53e 53f 0
579 78 :3 0 79
:3 0 541 542 0
78 :3 0 88 :3 0
544 545 0 25
:2 0 2 :4 0 af
:2 0 8a :2 0 49
:2 0 2d7 54a 54c
:3 0 2da 546 54e
543 550 54f :2 0
7b :3 0 8b :3 0
552 553 0 7d
:4 0 b0 :4 0 80
:2 0 81 :3 0 2de
557 559 :3 0 80
:2 0 94 :4 0 2e1
55b 55d :3 0 80
:2 0 b1 :4 0 2e4
55f 561 :3 0 80
:2 0 ac :3 0 2e7
563 565 :3 0 80
:2 0 b2 :4 0 2ea
567 569 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 2ed 56c 570
2f1 56b 572 :3 0
2f4 554 574 :2 0
576 2f7 577 551
576 0 578 2f9
0 579 2fb 57c
:3 0 57c 0 57c
57b 579 57a :6 0
57e 4 :3 0 2fe
580 300 57f 57e
:2 0 581 302 :2 0
583 0 583 582
530 581 :6 0 6d2
1 :3 0 2b :3 0
b6 :4 0 586 587
:3 0 585 588 0
6d2 52 :3 0 b7
:3 0 85 :3 0 30
:3 0 31 :2 0 305
58c 58f 308 58b
591 58a 592 0
6d2 54 :3 0 b8
:3 0 52 :3 0 30
:3 0 2e :3 0 2c
:3 0 2f :3 0 2b
:3 0 30a 595 59c
594 59d 0 6d2
85 :3 0 54 :3 0
31 :2 0 311 59f
5a2 a4 :2 0 31
:2 0 316 5a4 5a6
:3 0 85 :3 0 54
:3 0 31 :2 0 319
5a8 5ab a4 :2 0
49 :2 0 31e 5ad
5af :3 0 5a7 5b1
5b0 :2 0 5b2 :2 0
85 :3 0 57 :3 0
31 :2 0 321 5b4
5b7 a4 :2 0 90
:2 0 326 5b9 5bb
:3 0 5bc :2 0 5b3
5be 5bd :2 0 85
:3 0 3d :3 0 31
:2 0 329 5c0 5c3
a4 :2 0 31 :2 0
32e 5c5 5c7 :3 0
5c8 :2 0 5bf 5ca
5c9 :2 0 53 :3 0
31 :2 0 5cc 5cd
0 6b0 b9 :3 0
53 :3 0 ba :3 0
bb :3 0 6a :3 0
2d :3 0 bc :3 0
2c :4 0 bd 1
:8 0 5dd 1b :3 0
ab :3 0 5d8 5d9
0 ac :3 0 5da
5db 0 5dd 331
630 ad :3 0 1b
:3 0 ab :3 0 5df
5e0 0 ac :3 0
5e1 5e2 0 5e4
334 5e6 336 5e5
5e4 :2 0 62e ae
:3 0 1b :3 0 ab
:3 0 5e9 5ea 0
ac :3 0 5eb 5ec
0 626 78 :3 0
79 :3 0 5ee 5ef
0 78 :3 0 88
:3 0 5f1 5f2 0
25 :2 0 2 :4 0
be :2 0 8a :2 0
49 :2 0 338 5f7
5f9 :3 0 33b 5f3
5fb 5f0 5fd 5fc
:2 0 7b :3 0 8b
:3 0 5ff 600 0
7d :4 0 bf :4 0
80 :2 0 81 :3 0
33f 604 606 :3 0
80 :2 0 94 :4 0
342 608 60a :3 0
80 :2 0 b1 :4 0
345 60c 60e :3 0
80 :2 0 ac :3 0
348 610 612 :3 0
80 :2 0 b2 :4 0
34b 614 616 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 34e 619
61d 352 618 61f
:3 0 355 601 621
:2 0 623 358 624
5fe 623 0 625
35a 0 626 35c
629 :3 0 629 0
629 628 626 627
:6 0 62b 6 :3 0
35f 62d 361 62c
62b :2 0 62e 363
:2 0 630 0 630
62f 5dd 62e :6 0
6b0 1 :3 0 85
:3 0 53 :3 0 31
:2 0 366 632 635
c0 :2 0 31 :2 0
36b 637 639 :3 0
57 :3 0 49 :2 0
63b 63c 0 6ad
3d :3 0 c1 :2 0
63e 63f 0 6ad
51 :3 0 c2 :4 0
641 642 0 6ad
4c :3 0 c3 :2 0
36e 645 646 :3 0
647 :2 0 c4 :3 0
c5 :3 0 c6 :3 0
4c :3 0 4e :3 0
ba :4 0 c7 1
:8 0 655 1b :3 0
ab :3 0 650 651
0 ac :3 0 652
653 0 655 370
6a8 ad :3 0 1b
:3 0 ab :3 0 657
658 0 ac :3 0
659 65a 0 65c
373 65e 375 65d
65c :2 0 6a6 ae
:3 0 1b :3 0 ab
:3 0 661 662 0
ac :3 0 663 664
0 69e 78 :3 0
79 :3 0 666 667
0 78 :3 0 88
:3 0 669 66a 0
25 :2 0 2 :4 0
c8 :2 0 8a :2 0
49 :2 0 377 66f
671 :3 0 37a 66b
673 668 675 674
:2 0 7b :3 0 8b
:3 0 677 678 0
7d :4 0 c9 :4 0
80 :2 0 81 :3 0
37e 67c 67e :3 0
80 :2 0 94 :4 0
381 680 682 :3 0
80 :2 0 b1 :4 0
384 684 686 :3 0
80 :2 0 ac :3 0
387 688 68a :3 0
80 :2 0 b2 :4 0
38a 68c 68e :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 38d 691
695 391 690 697
:3 0 394 679 699
:2 0 69b 397 69c
676 69b 0 69d
399 0 69e 39b
6a1 :3 0 6a1 0
6a1 6a0 69e 69f
:6 0 6a3 8 :3 0
39e 6a5 3a0 6a4
6a3 :2 0 6a6 3a2
:2 0 6a8 0 6a8
6a7 655 6a6 :6 0
6aa 1 :3 0 3a5
6ab 648 6aa 0
6ac 3a7 0 6ad
3a9 6ae 63a 6ad
0 6af 3ae 0
6b0 3b0 6b1 5cb
6b0 0 6b2 3b4
0 6d2 85 :3 0
57 :3 0 31 :2 0
3b6 6b3 6b6 a4
:2 0 49 :2 0 3bb
6b8 6ba :3 0 6bb
:2 0 ca :3 0 85
:3 0 30 :3 0 31
:2 0 3be 6be 6c1
3c1 6bd 6c3 6c4
:2 0 c0 :2 0 31
:2 0 3c5 6c6 6c8
:3 0 6bc 6ca 6c9
:2 0 57 :3 0 90
:2 0 6cc 6cd 0
6cf 3c8 6d0 6cb
6cf 0 6d1 3ca
0 6d2 3cc 7cf
2b :3 0 3 :3 0
6d3 6d4 0 7ce
6a :3 0 cb :3 0
cc :3 0 cd :3 0
ce :3 0 cf :3 0
d0 :3 0 d1 :3 0
d2 :3 0 6c :3 0
2d :3 0 2e :3 0
2c :3 0 42 :3 0
47 :3 0 61 :3 0
36 :3 0 37 :3 0
38 :3 0 4f :3 0
d3 :3 0 74 :3 0
2b :4 0 d4 1
:8 0 6f3 1b :3 0
ab :3 0 6ee 6ef
0 ac :3 0 6f0
6f1 0 6f3 3d7
746 ad :3 0 1b
:3 0 ab :3 0 6f5
6f6 0 ac :3 0
6f7 6f8 0 6fa
3da 6fc 3dc 6fb
6fa :2 0 744 ae
:3 0 1b :3 0 ab
:3 0 6ff 700 0
ac :3 0 701 702
0 73c 78 :3 0
79 :3 0 704 705
0 78 :3 0 88
:3 0 707 708 0
25 :2 0 2 :4 0
d5 :2 0 8a :2 0
49 :2 0 3de 70d
70f :3 0 3e1 709
711 706 713 712
:2 0 7b :3 0 8b
:3 0 715 716 0
7d :4 0 d6 :4 0
80 :2 0 81 :3 0
3e5 71a 71c :3 0
80 :2 0 94 :4 0
3e8 71e 720 :3 0
80 :2 0 b1 :4 0
3eb 722 724 :3 0
80 :2 0 ac :3 0
3ee 726 728 :3 0
80 :2 0 b2 :4 0
3f1 72a 72c :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 3f4 72f
733 3f8 72e 735
:3 0 3fb 717 737
:2 0 739 3fe 73a
714 739 0 73b
400 0 73c 402
73f :3 0 73f 0
73f 73e 73c 73d
:6 0 741 a :3 0
405 743 407 742
741 :2 0 744 409
:2 0 746 0 746
745 6f3 744 :6 0
7ce 1 :3 0 1b
:3 0 ab :3 0 748
749 0 1b :3 0
a4 :2 0 d7 :3 0
74b 74d 0 40e
74c 74f :3 0 750
:2 0 85 :3 0 c
:3 0 31 :2 0 411
752 755 85 :3 0
c0 :2 0 42 :3 0
31 :2 0 414 757
75b 419 758 75d
:3 0 75e :2 0 751
760 75f :2 0 78
:3 0 79 :3 0 762
763 0 78 :3 0
88 :3 0 765 766
0 27 :2 0 2
:4 0 d8 :2 0 8a
:2 0 49 :2 0 41c
76b 76d :3 0 41f
767 76f 764 771
770 :2 0 7b :3 0
8b :3 0 773 774
0 7d :4 0 d9
:4 0 80 :2 0 81
:3 0 423 778 77a
:3 0 80 :2 0 94
:4 0 426 77c 77e
:3 0 80 :2 0 95
:4 0 429 780 782
:3 0 80 :2 0 85
:3 0 66 :3 0 31
:2 0 42c 786 788
86 :4 0 42e 785
78b 431 784 78d
:3 0 80 :2 0 da
:4 0 434 78f 791
:3 0 80 :2 0 83
:4 0 437 793 795
:3 0 80 :2 0 2b
:3 0 43a 797 799
:3 0 80 :2 0 83
:4 0 43d 79b 79d
:3 0 440 775 79f
:2 0 7a1 443 7a2
772 7a1 0 7a3
445 0 7cb 78
:3 0 79 :3 0 7a4
7a5 0 78 :3 0
88 :3 0 7a7 7a8
0 49 :2 0 2
:4 0 db :2 0 8a
:2 0 49 :2 0 447
7ad 7af :3 0 44a
7a9 7b1 7a6 7b3
7b2 :2 0 7b :3 0
8b :3 0 7b5 7b6
0 7d :4 0 dc
:4 0 80 :2 0 81
:3 0 44e 7ba 7bc
:3 0 451 7b7 7be
:2 0 7c0 454 7c1
7b4 7c0 0 7c2
456 0 7cb 9a
:3 0 dd :3 0 7c3
7c4 0 31 :2 0
2b :3 0 9c :3 0
458 7c5 7c9 :2 0
7cb 45c 7cc 761
7cb 0 7cd 460
0 7ce 462 7d0
4b5 6d2 0 7d1
0 7ce 0 7d1
466 0 1d82 85
:3 0 57 :3 0 31
:2 0 469 7d2 7d5
c0 :2 0 90 :2 0
46e 7d7 7d9 :3 0
1b :3 0 ab :3 0
7db 7dc 0 c0
:2 0 31 :2 0 473
7de 7e0 :3 0 78
:3 0 79 :3 0 7e2
7e3 0 78 :3 0
88 :3 0 7e5 7e6
0 27 :2 0 2
:4 0 de :2 0 8a
:2 0 49 :2 0 476
7eb 7ed :3 0 479
7e7 7ef 7e4 7f1
7f0 :2 0 7b :3 0
8b :3 0 7f3 7f4
0 7d :4 0 df
:4 0 80 :2 0 81
:3 0 47d 7f8 7fa
:3 0 80 :2 0 94
:4 0 480 7fc 7fe
:3 0 80 :2 0 95
:4 0 483 800 802
:3 0 80 :2 0 85
:3 0 66 :3 0 1b
:3 0 ab :3 0 807
808 0 486 806
80a 86 :4 0 488
805 80d 48b 804
80f :3 0 80 :2 0
da :4 0 48e 811
813 :3 0 80 :2 0
83 :4 0 491 815
817 :3 0 80 :2 0
2b :3 0 494 819
81b :3 0 80 :2 0
83 :4 0 497 81d
81f :3 0 49a 7f5
821 :2 0 823 49d
824 7f2 823 0
825 49f 0 84f
78 :3 0 79 :3 0
826 827 0 78
:3 0 88 :3 0 829
82a 0 49 :2 0
2 :4 0 e0 :2 0
8a :2 0 49 :2 0
4a1 82f 831 :3 0
4a4 82b 833 828
835 834 :2 0 7b
:3 0 8b :3 0 837
838 0 7d :4 0
e1 :4 0 80 :2 0
81 :3 0 4a8 83c
83e :3 0 4ab 839
840 :2 0 842 4ae
843 836 842 0
844 4b0 0 84f
9a :3 0 dd :3 0
845 846 0 1b
:3 0 ab :3 0 848
849 0 2b :3 0
9c :3 0 4b2 847
84d :2 0 84f 4b6
850 7e1 84f 0
851 4ba 0 1d70
4c :3 0 8d :2 0
4bc 853 854 :3 0
855 :2 0 4e :3 0
8d :2 0 4be 858
859 :3 0 85a :2 0
856 85c 85b :2 0
3d :3 0 8d :2 0
4c0 85f 860 :3 0
861 :2 0 85d 863
862 :2 0 51 :3 0
8d :2 0 4c2 866
867 :3 0 868 :2 0
864 86a 869 :2 0
78 :3 0 79 :3 0
86c 86d 0 78
:3 0 88 :3 0 86f
870 0 91 :2 0
2 :4 0 e2 :2 0
8a :2 0 49 :2 0
4c4 875 877 :3 0
4c7 871 879 86e
87b 87a :2 0 7b
:3 0 8b :3 0 87d
87e 0 7d :4 0
e3 :4 0 80 :2 0
81 :3 0 4cb 882
884 :3 0 80 :2 0
94 :4 0 4ce 886
888 :3 0 80 :2 0
95 :4 0 4d1 88a
88c :3 0 80 :2 0
85 :3 0 66 :3 0
96 :3 0 97 :3 0
891 892 0 4d4
890 894 86 :4 0
4d6 88f 897 4d9
88e 899 :3 0 4dc
87f 89b :2 0 89d
4df 89e 87c 89d
0 89f 4e1 0
8c8 78 :3 0 79
:3 0 8a0 8a1 0
78 :3 0 88 :3 0
8a3 8a4 0 49
:2 0 2 :4 0 e4
:2 0 8a :2 0 49
:2 0 4e3 8a9 8ab
:3 0 4e6 8a5 8ad
8a2 8af 8ae :2 0
7b :3 0 8b :3 0
8b1 8b2 0 7d
:4 0 e5 :4 0 80
:2 0 81 :3 0 4ea
8b6 8b8 :3 0 4ed
8b3 8ba :2 0 8bc
4f0 8bd 8b0 8bc
0 8be 4f2 0
8c8 9a :3 0 9b
:3 0 8bf 8c0 0
96 :3 0 97 :3 0
8c2 8c3 0 9c
:3 0 4f4 8c1 8c6
:2 0 8c8 4f7 8c9
86b 8c8 0 8ca
4fb 0 1d70 3c
:3 0 96 :3 0 e6
:3 0 8cc 8cd 0
8cb 8ce 0 1d70
85 :3 0 39 :3 0
31 :2 0 4fd 8d0
8d3 8f :2 0 e7
:2 0 502 8d5 8d7
:3 0 39 :3 0 e7
:2 0 8d9 8da 0
8dc 505 8dd 8d8
8dc 0 8de 507
0 1d70 85 :3 0
e8 :3 0 3a :3 0
69 :3 0 6b :3 0
2e :4 0 e9 1
:8 0 8eb 1b :3 0
ab :3 0 8e6 8e7
0 ac :3 0 8e8
8e9 0 8eb 509
93e ad :3 0 1b
:3 0 ab :3 0 8ed
8ee 0 ac :3 0
8ef 8f0 0 8f2
50c 8f4 50e 8f3
8f2 :2 0 93c ae
:3 0 1b :3 0 ab
:3 0 8f7 8f8 0
ac :3 0 8f9 8fa
0 934 78 :3 0
79 :3 0 8fc 8fd
0 78 :3 0 88
:3 0 8ff 900 0
25 :2 0 2 :4 0
ea :2 0 8a :2 0
49 :2 0 510 905
907 :3 0 513 901
909 8fe 90b 90a
:2 0 7b :3 0 8b
:3 0 90d 90e 0
7d :4 0 eb :4 0
80 :2 0 81 :3 0
517 912 914 :3 0
80 :2 0 94 :4 0
51a 916 918 :3 0
80 :2 0 b1 :4 0
51d 91a 91c :3 0
80 :2 0 ac :3 0
520 91e 920 :3 0
80 :2 0 b2 :4 0
523 922 924 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 526 927
92b 52a 926 92d
:3 0 52d 90f 92f
:2 0 931 530 932
90c 931 0 933
532 0 934 534
937 :3 0 937 0
937 936 934 935
:6 0 939 c :3 0
537 93b 539 93a
939 :2 0 93c 53b
:2 0 93e 0 93e
93d 8eb 93c :6 0
1d70 1 :3 0 85
:3 0 36 :3 0 31
:2 0 53e 940 943
8f :2 0 31 :2 0
543 945 947 :3 0
53 :3 0 ec :3 0
85 :3 0 ed :3 0
36 :3 0 546 94c
94e 31 :2 0 548
94b 951 ee :2 0
85 :3 0 ed :3 0
3a :3 0 54b 955
957 31 :2 0 54d
954 95a 550 953
95c :3 0 95d :2 0
ef :2 0 f0 :2 0
553 95f 961 :3 0
962 :2 0 8a :2 0
f1 :2 0 556 964
966 :3 0 559 94a
968 949 969 0
986 85 :3 0 39
:3 0 31 :2 0 55b
96b 96e 85 :3 0
c0 :2 0 53 :3 0
31 :2 0 55e 970
974 563 971 976
:3 0 36 :3 0 31
:2 0 978 979 0
97e 37 :3 0 31
:2 0 97b 97c 0
97e 566 983 39
:3 0 31 :2 0 97f
980 0 982 569
984 977 97e 0
985 0 982 0
985 56b 0 986
56e 987 948 986
0 988 571 0
1d70 48 :4 0 989
98a 0 1d70 f2
:3 0 85 :3 0 f
:3 0 31 :2 0 573
98d 990 25 :2 0
576 98c 993 994
:2 0 a4 :2 0 25
:2 0 57b 996 998
:3 0 85 :3 0 57
:3 0 31 :2 0 57e
99a 99d a4 :2 0
49 :2 0 583 99f
9a1 :3 0 85 :3 0
c :3 0 31 :2 0
586 9a3 9a6 8f
:2 0 31 :2 0 58b
9a8 9aa :3 0 1b
:3 0 ab :3 0 9ac
9ad 0 f3 :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
34 :3 0 3c :3 0
37 :3 0 38 :3 0
55 :3 0 51 :3 0
2f :3 0 58e 9af
9c1 9ae 9c2 0
a48 1b :3 0 ab
:3 0 9c4 9c5 0
a4 :2 0 31 :2 0
5a2 9c7 9c9 :3 0
d3 :3 0 f4 :3 0
e :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 6a :3 0
2d :3 0 cb :3 0
2e :3 0 cc :3 0
2c :4 0 fb 1
:8 0 9f0 fc :4 0
9db :3 0 9c :3 0
a4 :2 0 5a7 9de
9df :3 0 1b :3 0
ab :3 0 9e1 9e2
0 31 :2 0 9e3
9e4 0 9e6 5aa
9ed 1b :3 0 ab
:3 0 9e7 9e8 0
fd :2 0 9e9 9ea
0 9ec 5ac 9ee
9e0 9e6 0 9ef
0 9ec 0 9ef
5ae 0 9f0 5b1
a43 ad :3 0 1b
:3 0 ab :3 0 9f2
9f3 0 ac :3 0
9f4 9f5 0 9f7
5b4 9f9 5b6 9f8
9f7 :2 0 a41 ae
:3 0 1b :3 0 ab
:3 0 9fc 9fd 0
ac :3 0 9fe 9ff
0 a39 78 :3 0
79 :3 0 a01 a02
0 78 :3 0 88
:3 0 a04 a05 0
25 :2 0 2 :4 0
fe :2 0 8a :2 0
49 :2 0 5b8 a0a
a0c :3 0 5bb a06
a0e a03 a10 a0f
:2 0 7b :3 0 8b
:3 0 a12 a13 0
7d :4 0 ff :4 0
80 :2 0 81 :3 0
5bf a17 a19 :3 0
80 :2 0 94 :4 0
5c2 a1b a1d :3 0
80 :2 0 b1 :4 0
5c5 a1f a21 :3 0
80 :2 0 ac :3 0
5c8 a23 a25 :3 0
80 :2 0 b2 :4 0
5cb a27 a29 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 5ce a2c
a30 5d2 a2b a32
:3 0 5d5 a14 a34
:2 0 a36 5d8 a37
a11 a36 0 a38
5da 0 a39 5dc
a3c :3 0 a3c 0
a3c a3b a39 a3a
:6 0 a3e e :3 0
5df a40 5e1 a3f
a3e :2 0 a41 5e3
:2 0 a43 0 a43
a42 9f0 a41 :6 0
a45 1 :3 0 5e6
a46 9ca a45 0
a47 5e8 0 a48
5ea a62 1b :3 0
ab :3 0 a49 a4a
0 f3 :3 0 2b
:3 0 48 :3 0 48
:3 0 32 :3 0 4c
:3 0 4e :3 0 3d
:3 0 36 :3 0 33
:3 0 33 :3 0 33
:3 0 3c :3 0 37
:3 0 38 :3 0 55
:3 0 51 :3 0 2f
:3 0 5ed a4c a5e
a4b a5f 0 a61
5ff a63 9ab a48
0 a64 0 a61
0 a64 601 0
a65 604 b30 3c
:3 0 85 :3 0 3c
:3 0 31 :2 0 606
a67 a6a 8a :2 0
49 :2 0 609 a6c
a6e :3 0 a66 a6f
0 b2f 85 :3 0
c :3 0 31 :2 0
60c a71 a74 8f
:2 0 31 :2 0 611
a76 a78 :3 0 1b
:3 0 ab :3 0 a7a
a7b 0 f3 :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
34 :3 0 3c :3 0
37 :3 0 38 :3 0
55 :3 0 51 :3 0
2f :3 0 614 a7d
a8f a7c a90 0
b12 1b :3 0 ab
:3 0 a92 a93 0
a4 :2 0 31 :2 0
628 a95 a97 :3 0
d3 :3 0 f4 :3 0
e :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 74 :3 0
2b :4 0 100 1
:8 0 aba fc :4 0
aa5 :3 0 9c :3 0
a4 :2 0 62d aa8
aa9 :3 0 1b :3 0
ab :3 0 aab aac
0 31 :2 0 aad
aae 0 ab0 630
ab7 1b :3 0 ab
:3 0 ab1 ab2 0
fd :2 0 ab3 ab4
0 ab6 632 ab8
aaa ab0 0 ab9
0 ab6 0 ab9
634 0 aba 637
b0d ad :3 0 1b
:3 0 ab :3 0 abc
abd 0 ac :3 0
abe abf 0 ac1
63a ac3 63c ac2
ac1 :2 0 b0b ae
:3 0 1b :3 0 ab
:3 0 ac6 ac7 0
ac :3 0 ac8 ac9
0 b03 78 :3 0
79 :3 0 acb acc
0 78 :3 0 88
:3 0 ace acf 0
25 :2 0 2 :4 0
101 :2 0 8a :2 0
49 :2 0 63e ad4
ad6 :3 0 641 ad0
ad8 acd ada ad9
:2 0 7b :3 0 8b
:3 0 adc add 0
7d :4 0 102 :4 0
80 :2 0 81 :3 0
645 ae1 ae3 :3 0
80 :2 0 94 :4 0
648 ae5 ae7 :3 0
80 :2 0 b1 :4 0
64b ae9 aeb :3 0
80 :2 0 ac :3 0
64e aed aef :3 0
80 :2 0 b2 :4 0
651 af1 af3 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 654 af6
afa 658 af5 afc
:3 0 65b ade afe
:2 0 b00 65e b01
adb b00 0 b02
660 0 b03 662
b06 :3 0 b06 0
b06 b05 b03 b04
:6 0 b08 10 :3 0
665 b0a 667 b09
b08 :2 0 b0b 669
:2 0 b0d 0 b0d
b0c aba b0b :6 0
b0f 1 :3 0 66c
b10 a98 b0f 0
b11 66e 0 b12
670 b2c 1b :3 0
ab :3 0 b13 b14
0 f3 :3 0 2b
:3 0 48 :3 0 48
:3 0 32 :3 0 4c
:3 0 4e :3 0 3d
:3 0 36 :3 0 33
:3 0 33 :3 0 33
:3 0 3c :3 0 37
:3 0 38 :3 0 55
:3 0 51 :3 0 2f
:3 0 673 b16 b28
b15 b29 0 b2b
685 b2d a79 b12
0 b2e 0 b2b
0 b2e 687 0
b2f 68a b31 9a2
a65 0 b32 0
b2f 0 b32 68d
0 d55 1b :3 0
ab :3 0 b33 b34
0 a4 :2 0 31
:2 0 692 b36 b38
:3 0 b39 :2 0 f2
:3 0 85 :3 0 f
:3 0 31 :2 0 695
b3c b3f 35 :2 0
698 b3b b42 b43
:2 0 a4 :2 0 35
:2 0 69d b45 b47
:3 0 b48 :2 0 b3a
b4a b49 :2 0 85
:3 0 c :3 0 31
:2 0 6a0 b4c b4f
85 :3 0 a4 :2 0
a :3 0 31 :2 0
6a3 b51 b55 6a8
b52 b57 :3 0 b58
:2 0 85 :3 0 e
:3 0 31 :2 0 6ab
b5a b5d a4 :2 0
31 :2 0 6b0 b5f
b61 :3 0 b62 :2 0
b59 b64 b63 :2 0
85 :3 0 d :3 0
31 :2 0 6b3 b66
b69 a4 :2 0 f0
:2 0 6b8 b6b b6d
:3 0 b6e :2 0 b65
b70 b6f :2 0 d3
:3 0 103 :3 0 d
:3 0 cf :3 0 39
:3 0 d2 :3 0 38
:3 0 f5 :3 0 f6
:3 0 f7 :3 0 f8
:3 0 f9 :3 0 fa
:3 0 104 :3 0 4c
:3 0 105 :3 0 4e
:3 0 cd :3 0 c
:3 0 f4 :3 0 e
:3 0 74 :3 0 2b
:4 0 106 1 :8 0
b9f fc :4 0 b8a
:3 0 9c :3 0 a4
:2 0 6bd b8d b8e
:3 0 1b :3 0 ab
:3 0 b90 b91 0
31 :2 0 b92 b93
0 b95 6c0 b9c
1b :3 0 ab :3 0
b96 b97 0 fd
:2 0 b98 b99 0
b9b 6c2 b9d b8f
b95 0 b9e 0
b9b 0 b9e 6c4
0 b9f 6c7 bf2
ad :3 0 1b :3 0
ab :3 0 ba1 ba2
0 ac :3 0 ba3
ba4 0 ba6 6ca
ba8 6cc ba7 ba6
:2 0 bf0 ae :3 0
1b :3 0 ab :3 0
bab bac 0 ac
:3 0 bad bae 0
be8 78 :3 0 79
:3 0 bb0 bb1 0
78 :3 0 88 :3 0
bb3 bb4 0 25
:2 0 2 :4 0 107
:2 0 8a :2 0 49
:2 0 6ce bb9 bbb
:3 0 6d1 bb5 bbd
bb2 bbf bbe :2 0
7b :3 0 8b :3 0
bc1 bc2 0 7d
:4 0 108 :4 0 80
:2 0 81 :3 0 6d5
bc6 bc8 :3 0 80
:2 0 94 :4 0 6d8
bca bcc :3 0 80
:2 0 b1 :4 0 6db
bce bd0 :3 0 80
:2 0 ac :3 0 6de
bd2 bd4 :3 0 80
:2 0 b2 :4 0 6e1
bd6 bd8 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 6e4 bdb bdf
6e8 bda be1 :3 0
6eb bc3 be3 :2 0
be5 6ee be6 bc0
be5 0 be7 6f0
0 be8 6f2 beb
:3 0 beb 0 beb
bea be8 be9 :6 0
bed 12 :3 0 6f5
bef 6f7 bee bed
:2 0 bf0 6f9 :2 0
bf2 0 bf2 bf1
b9f bf0 :6 0 cd7
1 :3 0 73 :3 0
75 :3 0 70 :3 0
72 :3 0 6a :3 0
2d :3 0 74 :3 0
2b :4 0 109 1
:8 0 c12 fc :4 0
bfd :3 0 9c :3 0
a4 :2 0 6fe c00
c01 :3 0 1b :3 0
ab :3 0 c03 c04
0 31 :2 0 c05
c06 0 c08 701
c0f 1b :3 0 ab
:3 0 c09 c0a 0
fd :2 0 c0b c0c
0 c0e 703 c10
c02 c08 0 c11
0 c0e 0 c11
705 0 c12 708
c65 ad :3 0 1b
:3 0 ab :3 0 c14
c15 0 ac :3 0
c16 c17 0 c19
70b c1b 70d c1a
c19 :2 0 c63 ae
:3 0 1b :3 0 ab
:3 0 c1e c1f 0
ac :3 0 c20 c21
0 c5b 78 :3 0
79 :3 0 c23 c24
0 78 :3 0 88
:3 0 c26 c27 0
25 :2 0 2 :4 0
10a :2 0 8a :2 0
49 :2 0 70f c2c
c2e :3 0 712 c28
c30 c25 c32 c31
:2 0 7b :3 0 8b
:3 0 c34 c35 0
7d :4 0 10b :4 0
80 :2 0 81 :3 0
716 c39 c3b :3 0
80 :2 0 94 :4 0
719 c3d c3f :3 0
80 :2 0 b1 :4 0
71c c41 c43 :3 0
80 :2 0 ac :3 0
71f c45 c47 :3 0
80 :2 0 b2 :4 0
722 c49 c4b :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 725 c4e
c52 729 c4d c54
:3 0 72c c36 c56
:2 0 c58 72f c59
c33 c58 0 c5a
731 0 c5b 733
c5e :3 0 c5e 0
c5e c5d c5b c5c
:6 0 c60 14 :3 0
736 c62 738 c61
c60 :2 0 c63 73a
:2 0 c65 0 c65
c64 c12 c63 :6 0
cd7 1 :3 0 d3
:3 0 10c :3 0 4e
:3 0 74 :3 0 2b
:4 0 10d 1 :8 0
c82 fc :4 0 c6d
:3 0 9c :3 0 a4
:2 0 73f c70 c71
:3 0 1b :3 0 ab
:3 0 c73 c74 0
31 :2 0 c75 c76
0 c78 742 c7f
1b :3 0 ab :3 0
c79 c7a 0 fd
:2 0 c7b c7c 0
c7e 744 c80 c72
c78 0 c81 0
c7e 0 c81 746
0 c82 749 cd5
ad :3 0 1b :3 0
ab :3 0 c84 c85
0 ac :3 0 c86
c87 0 c89 74c
c8b 74e c8a c89
:2 0 cd3 ae :3 0
1b :3 0 ab :3 0
c8e c8f 0 ac
:3 0 c90 c91 0
ccb 78 :3 0 79
:3 0 c93 c94 0
78 :3 0 88 :3 0
c96 c97 0 25
:2 0 2 :4 0 10e
:2 0 8a :2 0 49
:2 0 750 c9c c9e
:3 0 753 c98 ca0
c95 ca2 ca1 :2 0
7b :3 0 8b :3 0
ca4 ca5 0 7d
:4 0 10f :4 0 80
:2 0 81 :3 0 757
ca9 cab :3 0 80
:2 0 94 :4 0 75a
cad caf :3 0 80
:2 0 b1 :4 0 75d
cb1 cb3 :3 0 80
:2 0 ac :3 0 760
cb5 cb7 :3 0 80
:2 0 b2 :4 0 763
cb9 cbb :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 766 cbe cc2
76a cbd cc4 :3 0
76d ca6 cc6 :2 0
cc8 770 cc9 ca3
cc8 0 cca 772
0 ccb 774 cce
:3 0 cce 0 cce
ccd ccb ccc :6 0
cd0 16 :3 0 777
cd2 779 cd1 cd0
:2 0 cd3 77b :2 0
cd5 0 cd5 cd4
c82 cd3 :6 0 cd7
1 :3 0 77e d4f
d3 :3 0 f4 :3 0
e :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 74 :3 0
2b :4 0 110 1
:8 0 cf9 fc :4 0
ce4 :3 0 9c :3 0
a4 :2 0 784 ce7
ce8 :3 0 1b :3 0
ab :3 0 cea ceb
0 31 :2 0 cec
ced 0 cef 787
cf6 1b :3 0 ab
:3 0 cf0 cf1 0
fd :2 0 cf2 cf3
0 cf5 789 cf7
ce9 cef 0 cf8
0 cf5 0 cf8
78b 0 cf9 78e
d4c ad :3 0 1b
:3 0 ab :3 0 cfb
cfc 0 ac :3 0
cfd cfe 0 d00
791 d02 793 d01
d00 :2 0 d4a ae
:3 0 1b :3 0 ab
:3 0 d05 d06 0
ac :3 0 d07 d08
0 d42 78 :3 0
79 :3 0 d0a d0b
0 78 :3 0 88
:3 0 d0d d0e 0
25 :2 0 2 :4 0
111 :2 0 8a :2 0
49 :2 0 795 d13
d15 :3 0 798 d0f
d17 d0c d19 d18
:2 0 7b :3 0 8b
:3 0 d1b d1c 0
7d :4 0 112 :4 0
80 :2 0 81 :3 0
79c d20 d22 :3 0
80 :2 0 94 :4 0
79f d24 d26 :3 0
80 :2 0 b1 :4 0
7a2 d28 d2a :3 0
80 :2 0 ac :3 0
7a5 d2c d2e :3 0
80 :2 0 b2 :4 0
7a8 d30 d32 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 7ab d35
d39 7af d34 d3b
:3 0 7b2 d1d d3d
:2 0 d3f 7b5 d40
d1a d3f 0 d41
7b7 0 d42 7b9
d45 :3 0 d45 0
d45 d44 d42 d43
:6 0 d47 18 :3 0
7bc d49 7be d48
d47 :2 0 d4a 7c0
:2 0 d4c 0 d4c
d4b cf9 d4a :6 0
d4e 1 :3 0 7c3
d50 b71 cd7 0
d51 0 d4e 0
d51 7c5 0 d52
7c8 d53 b4b d52
0 d54 7ca 0
d55 7cc 117d 41
:3 0 f2 :3 0 85
:3 0 41 :3 0 31
:2 0 7cf d58 d5b
96 :3 0 113 :3 0
d5d d5e 0 7d2
d57 d60 d56 d61
0 117c 85 :3 0
57 :3 0 31 :2 0
7d5 d63 d66 a4
:2 0 49 :2 0 7da
d68 d6a :3 0 1b
:3 0 ab :3 0 d6c
d6d 0 f3 :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
41 :3 0 3c :3 0
37 :3 0 38 :3 0
55 :3 0 51 :3 0
2f :3 0 7dd d6f
d81 d6e d82 0
e21 1b :3 0 ab
:3 0 d84 d85 0
a4 :2 0 31 :2 0
7f1 d87 d89 :3 0
d8a :2 0 85 :3 0
f :3 0 31 :2 0
7f4 d8c d8f a4
:2 0 35 :2 0 7f9
d91 d93 :3 0 d94
:2 0 d8b d96 d95
:2 0 85 :3 0 3e
:3 0 31 :2 0 7fc
d98 d9b a4 :2 0
31 :2 0 801 d9d
d9f :3 0 da0 :2 0
d97 da2 da1 :2 0
d3 :3 0 f4 :3 0
e :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 6a :3 0
2d :3 0 cb :3 0
2e :3 0 cc :3 0
2c :4 0 114 1
:8 0 dc9 fc :4 0
db4 :3 0 9c :3 0
a4 :2 0 806 db7
db8 :3 0 1b :3 0
ab :3 0 dba dbb
0 31 :2 0 dbc
dbd 0 dbf 809
dc6 1b :3 0 ab
:3 0 dc0 dc1 0
fd :2 0 dc2 dc3
0 dc5 80b dc7
db9 dbf 0 dc8
0 dc5 0 dc8
80d 0 dc9 810
e1c ad :3 0 1b
:3 0 ab :3 0 dcb
dcc 0 ac :3 0
dcd dce 0 dd0
813 dd2 815 dd1
dd0 :2 0 e1a ae
:3 0 1b :3 0 ab
:3 0 dd5 dd6 0
ac :3 0 dd7 dd8
0 e12 78 :3 0
79 :3 0 dda ddb
0 78 :3 0 88
:3 0 ddd dde 0
25 :2 0 2 :4 0
115 :2 0 8a :2 0
49 :2 0 817 de3
de5 :3 0 81a ddf
de7 ddc de9 de8
:2 0 7b :3 0 8b
:3 0 deb dec 0
7d :4 0 116 :4 0
80 :2 0 81 :3 0
81e df0 df2 :3 0
80 :2 0 94 :4 0
821 df4 df6 :3 0
80 :2 0 b1 :4 0
824 df8 dfa :3 0
80 :2 0 ac :3 0
827 dfc dfe :3 0
80 :2 0 b2 :4 0
82a e00 e02 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 82d e05
e09 831 e04 e0b
:3 0 834 ded e0d
:2 0 e0f 837 e10
dea e0f 0 e11
839 0 e12 83b
e15 :3 0 e15 0
e15 e14 e12 e13
:6 0 e17 1a :3 0
83e e19 840 e18
e17 :2 0 e1a 842
:2 0 e1c 0 e1c
e1b dc9 e1a :6 0
e1e 1 :3 0 845
e1f da3 e1e 0
e20 847 0 e21
849 1179 12 :3 0
c3 :2 0 84c e23
e24 :3 0 e25 :2 0
50 :3 0 12 :3 0
e27 e28 0 10b9
b3 :3 0 50 :3 0
b3 :3 0 50 :3 0
b3 :3 0 50 :3 0
b3 :3 0 50 :3 0
50 :3 0 ba :4 0
117 1 :8 0 e3a
1b :3 0 ab :3 0
e35 e36 0 ac
:3 0 e37 e38 0
e3a 84e e8d ad
:3 0 1b :3 0 ab
:3 0 e3c e3d 0
ac :3 0 e3e e3f
0 e41 851 e43
853 e42 e41 :2 0
e8b ae :3 0 1b
:3 0 ab :3 0 e46
e47 0 ac :3 0
e48 e49 0 e83
78 :3 0 79 :3 0
e4b e4c 0 78
:3 0 88 :3 0 e4e
e4f 0 25 :2 0
2 :4 0 118 :2 0
8a :2 0 49 :2 0
855 e54 e56 :3 0
858 e50 e58 e4d
e5a e59 :2 0 7b
:3 0 8b :3 0 e5c
e5d 0 7d :4 0
119 :4 0 80 :2 0
81 :3 0 85c e61
e63 :3 0 80 :2 0
94 :4 0 85f e65
e67 :3 0 80 :2 0
b1 :4 0 862 e69
e6b :3 0 80 :2 0
ac :3 0 865 e6d
e6f :3 0 80 :2 0
b2 :4 0 868 e71
e73 :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
86b e76 e7a 86f
e75 e7c :3 0 872
e5e e7e :2 0 e80
875 e81 e5b e80
0 e82 877 0
e83 879 e86 :3 0
e86 0 e86 e85
e83 e84 :6 0 e88
1c :3 0 87c e8a
87e e89 e88 :2 0
e8b 880 :2 0 e8d
0 e8d e8c e3a
e8b :6 0 10b9 1
:3 0 c5 :3 0 11a
:3 0 e8f e90 0
50 :3 0 4f :3 0
11b :2 0 883 e91
e95 8e :2 0 31
:2 0 889 e97 e99
:3 0 30 :3 0 96
:3 0 11c :3 0 e9c
e9d 0 e9b e9e
0 10b6 52 :3 0
49 :2 0 ea0 ea1
0 10b6 6b :3 0
29 :3 0 11d :3 0
11e :4 0 11f 1
:8 0 ead 1b :3 0
ab :3 0 ea8 ea9
0 ac :3 0 eaa
eab 0 ead 88c
f00 ad :3 0 1b
:3 0 ab :3 0 eaf
eb0 0 ac :3 0
eb1 eb2 0 eb4
88f eb6 891 eb5
eb4 :2 0 efe ae
:3 0 1b :3 0 ab
:3 0 eb9 eba 0
ac :3 0 ebb ebc
0 ef6 78 :3 0
79 :3 0 ebe ebf
0 78 :3 0 88
:3 0 ec1 ec2 0
25 :2 0 2 :4 0
120 :2 0 8a :2 0
49 :2 0 893 ec7
ec9 :3 0 896 ec3
ecb ec0 ecd ecc
:2 0 7b :3 0 8b
:3 0 ecf ed0 0
7d :4 0 121 :4 0
80 :2 0 81 :3 0
89a ed4 ed6 :3 0
80 :2 0 94 :4 0
89d ed8 eda :3 0
80 :2 0 b1 :4 0
8a0 edc ede :3 0
80 :2 0 ac :3 0
8a3 ee0 ee2 :3 0
80 :2 0 b2 :4 0
8a6 ee4 ee6 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 8a9 ee9
eed 8ad ee8 eef
:3 0 8b0 ed1 ef1
:2 0 ef3 8b3 ef4
ece ef3 0 ef5
8b5 0 ef6 8b7
ef9 :3 0 ef9 0
ef9 ef8 ef6 ef7
:6 0 efb 1e :3 0
8ba efd 8bc efc
efb :2 0 efe 8be
:2 0 f00 0 f00
eff ead efe :6 0
10b6 1 :3 0 54
:3 0 122 :3 0 52
:3 0 2e :3 0 29
:3 0 30 :3 0 2f
:3 0 2a :3 0 8c1
f03 f0a f02 f0b
0 10b6 85 :3 0
54 :3 0 31 :2 0
8c8 f0d f10 a4
:2 0 31 :2 0 8cd
f12 f14 :3 0 26
:4 0 f16 f17 0
10b3 28 :4 0 f19
f1a 0 10b3 1d
:4 0 f1c f1d 0
10b3 24 :4 0 f1f
f20 0 10b3 1f
:4 0 f22 f23 0
10b3 123 :3 0 63
:4 0 f28 :2 0 10b3
f26 f29 :3 0 63
:3 0 1d :3 0 24
:4 0 f2e :2 0 10b3
f2a f2f :3 0 8d0
:3 0 63 :3 0 fc
:3 0 f30 f31 :3 0
1b :3 0 ab :3 0
f33 f34 0 31
:2 0 f35 f36 0
f38 8d3 f3f 1b
:3 0 ab :3 0 f39
f3a 0 fd :2 0
f3b f3c 0 f3e
8d5 f40 f32 f38
0 f41 0 f3e
0 f41 8d7 0
10b3 124 :3 0 63
:4 0 f45 :2 0 f4b
f43 0 1b :3 0
ab :3 0 f46 f47
0 ac :3 0 f48
f49 0 f4b 8da
f9e ad :3 0 1b
:3 0 ab :3 0 f4d
f4e 0 ac :3 0
f4f f50 0 f52
8dd f54 8df f53
f52 :2 0 f9c ae
:3 0 1b :3 0 ab
:3 0 f57 f58 0
ac :3 0 f59 f5a
0 f94 78 :3 0
79 :3 0 f5c f5d
0 78 :3 0 88
:3 0 f5f f60 0
25 :2 0 2 :4 0
125 :2 0 8a :2 0
49 :2 0 8e1 f65
f67 :3 0 8e4 f61
f69 f5e f6b f6a
:2 0 7b :3 0 8b
:3 0 f6d f6e 0
7d :4 0 126 :4 0
80 :2 0 81 :3 0
8e8 f72 f74 :3 0
80 :2 0 94 :4 0
8eb f76 f78 :3 0
80 :2 0 b1 :4 0
8ee f7a f7c :3 0
80 :2 0 ac :3 0
8f1 f7e f80 :3 0
80 :2 0 b2 :4 0
8f4 f82 f84 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 8f7 f87
f8b 8fb f86 f8d
:3 0 8fe f6f f8f
:2 0 f91 901 f92
f6c f91 0 f93
903 0 f94 905
f97 :3 0 f97 0
f97 f96 f94 f95
:6 0 f99 20 :3 0
908 f9b 90a f9a
f99 :2 0 f9c 90c
:2 0 f9e 0 f9e
f9d f4b f9c :6 0
10b3 1 :3 0 127
:3 0 1f :3 0 128
:3 0 cc :3 0 2c
:4 0 129 1 :8 0
fab 1b :3 0 ab
:3 0 fa6 fa7 0
ac :3 0 fa8 fa9
0 fab 90f ffe
ad :3 0 1b :3 0
ab :3 0 fad fae
0 ac :3 0 faf
fb0 0 fb2 912
fb4 914 fb3 fb2
:2 0 ffc ae :3 0
1b :3 0 ab :3 0
fb7 fb8 0 ac
:3 0 fb9 fba 0
ff4 78 :3 0 79
:3 0 fbc fbd 0
78 :3 0 88 :3 0
fbf fc0 0 25
:2 0 2 :4 0 12a
:2 0 8a :2 0 49
:2 0 916 fc5 fc7
:3 0 919 fc1 fc9
fbe fcb fca :2 0
7b :3 0 8b :3 0
fcd fce 0 7d
:4 0 12b :4 0 80
:2 0 81 :3 0 91d
fd2 fd4 :3 0 80
:2 0 94 :4 0 920
fd6 fd8 :3 0 80
:2 0 b1 :4 0 923
fda fdc :3 0 80
:2 0 ac :3 0 926
fde fe0 :3 0 80
:2 0 b2 :4 0 929
fe2 fe4 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 92c fe7 feb
930 fe6 fed :3 0
933 fcf fef :2 0
ff1 936 ff2 fcc
ff1 0 ff3 938
0 ff4 93a ff7
:3 0 ff7 0 ff7
ff6 ff4 ff5 :6 0
ff9 22 :3 0 93d
ffb 93f ffa ff9
:2 0 ffc 941 :2 0
ffe 0 ffe ffd
fab ffc :6 0 10b3
1 :3 0 22 :3 0
12c :4 0 1000 1001
0 10b3 20 :3 0
12d :4 0 1003 1004
0 10b3 20 :3 0
b3 :3 0 20 :3 0
80 :2 0 1f :3 0
944 1009 100b :3 0
49 :2 0 21 :2 0
947 1007 100f 1006
1010 0 10b3 20
:3 0 b3 :3 0 20
:3 0 80 :2 0 12e
:4 0 94b 1015 1017
:3 0 49 :2 0 21
:2 0 94e 1013 101b
1012 101c 0 10b3
20 :3 0 b3 :3 0
20 :3 0 80 :2 0
1d :3 0 952 1021
1023 :3 0 49 :2 0
21 :2 0 955 101f
1027 101e 1028 0
10b3 20 :3 0 b3
:3 0 20 :3 0 80
:2 0 12f :4 0 959
102d 102f :3 0 49
:2 0 21 :2 0 95c
102b 1033 102a 1034
0 10b3 54 :3 0
130 :3 0 2a :3 0
24 :3 0 33 :3 0
33 :3 0 48 :3 0
33 :3 0 22 :3 0
20 :3 0 2f :3 0
48 :3 0 48 :3 0
33 :3 0 26 :3 0
28 :3 0 2f :3 0
960 1037 1047 1036
1048 0 10b3 78
:3 0 79 :3 0 104a
104b 0 78 :3 0
88 :3 0 104d 104e
0 27 :2 0 2
:4 0 131 :2 0 8a
:2 0 49 :2 0 970
1053 1055 :3 0 973
104f 1057 104c 1059
1058 :2 0 7b :3 0
8b :3 0 105b 105c
0 7d :4 0 132
:4 0 80 :2 0 81
:3 0 977 1060 1062
:3 0 80 :2 0 94
:4 0 97a 1064 1066
:3 0 80 :2 0 95
:4 0 97d 1068 106a
:3 0 80 :2 0 85
:3 0 66 :3 0 31
:2 0 980 106e 1070
86 :4 0 982 106d
1073 985 106c 1075
:3 0 80 :2 0 da
:4 0 988 1077 1079
:3 0 80 :2 0 83
:4 0 98b 107b 107d
:3 0 80 :2 0 2b
:3 0 98e 107f 1081
:3 0 80 :2 0 83
:4 0 991 1083 1085
:3 0 994 105d 1087
:2 0 1089 997 108a
105a 1089 0 108b
999 0 10b3 78
:3 0 79 :3 0 108c
108d 0 78 :3 0
88 :3 0 108f 1090
0 49 :2 0 2
:4 0 133 :2 0 8a
:2 0 49 :2 0 99b
1095 1097 :3 0 99e
1091 1099 108e 109b
109a :2 0 7b :3 0
8b :3 0 109d 109e
0 7d :4 0 134
:4 0 80 :2 0 81
:3 0 9a2 10a2 10a4
:3 0 9a5 109f 10a6
:2 0 10a8 9a8 10a9
109c 10a8 0 10aa
9aa 0 10b3 9a
:3 0 dd :3 0 10ab
10ac 0 31 :2 0
2b :3 0 9c :3 0
9ac 10ad 10b1 :2 0
10b3 9b0 10b4 f15
10b3 0 10b5 9c5
0 10b6 9c7 10b7
e9a 10b6 0 10b8
9cd 0 10b9 9cf
10ba e26 10b9 0
10bb 9d3 0 1178
3c :3 0 85 :3 0
3c :3 0 31 :2 0
9d5 10bd 10c0 8a
:2 0 49 :2 0 9d8
10c2 10c4 :3 0 10bc
10c5 0 1178 1b
:3 0 ab :3 0 10c7
10c8 0 f3 :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
41 :3 0 3c :3 0
37 :3 0 38 :3 0
55 :3 0 51 :3 0
2f :3 0 9db 10ca
10dc 10c9 10dd 0
1178 1b :3 0 ab
:3 0 10df 10e0 0
a4 :2 0 31 :2 0
9ef 10e2 10e4 :3 0
10e5 :2 0 85 :3 0
f :3 0 31 :2 0
9f2 10e7 10ea a4
:2 0 35 :2 0 9f7
10ec 10ee :3 0 10ef
:2 0 10e6 10f1 10f0
:2 0 85 :3 0 3e
:3 0 31 :2 0 9fa
10f3 10f6 a4 :2 0
31 :2 0 9ff 10f8
10fa :3 0 10fb :2 0
10f2 10fd 10fc :2 0
d3 :3 0 f4 :3 0
e :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 74 :3 0
2b :4 0 110 1
:8 0 1120 fc :4 0
110b :3 0 9c :3 0
a4 :2 0 a04 110e
110f :3 0 1b :3 0
ab :3 0 1111 1112
0 31 :2 0 1113
1114 0 1116 a07
111d 1b :3 0 ab
:3 0 1117 1118 0
fd :2 0 1119 111a
0 111c a09 111e
1110 1116 0 111f
0 111c 0 111f
a0b 0 1120 a0e
1173 ad :3 0 1b
:3 0 ab :3 0 1122
1123 0 ac :3 0
1124 1125 0 1127
a11 1129 a13 1128
1127 :2 0 1171 ae
:3 0 1b :3 0 ab
:3 0 112c 112d 0
ac :3 0 112e 112f
0 1169 78 :3 0
79 :3 0 1131 1132
0 78 :3 0 88
:3 0 1134 1135 0
25 :2 0 2 :4 0
135 :2 0 8a :2 0
49 :2 0 a15 113a
113c :3 0 a18 1136
113e 1133 1140 113f
:2 0 7b :3 0 8b
:3 0 1142 1143 0
7d :4 0 136 :4 0
80 :2 0 81 :3 0
a1c 1147 1149 :3 0
80 :2 0 94 :4 0
a1f 114b 114d :3 0
80 :2 0 b1 :4 0
a22 114f 1151 :3 0
80 :2 0 ac :3 0
a25 1153 1155 :3 0
80 :2 0 b2 :4 0
a28 1157 1159 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 a2b 115c
1160 a2f 115b 1162
:3 0 a32 1144 1164
:2 0 1166 a35 1167
1141 1166 0 1168
a37 0 1169 a39
116c :3 0 116c 0
116c 116b 1169 116a
:6 0 116e 24 :3 0
a3c 1170 a3e 116f
116e :2 0 1171 a40
:2 0 1173 0 1173
1172 1120 1171 :6 0
1175 1 :3 0 a43
1176 10fe 1175 0
1177 a45 0 1178
a47 117a d6b e21
0 117b 0 1178
0 117b a4c 0
117c a4f 117e 999
d55 0 117f 0
117c 0 117f a52
0 1d70 1b :3 0
ab :3 0 1180 1181
0 c0 :2 0 31
:2 0 a57 1183 1185
:3 0 78 :3 0 79
:3 0 1187 1188 0
78 :3 0 88 :3 0
118a 118b 0 27
:2 0 2 :4 0 137
:2 0 8a :2 0 49
:2 0 a5a 1190 1192
:3 0 a5d 118c 1194
1189 1196 1195 :2 0
7b :3 0 8b :3 0
1198 1199 0 7d
:4 0 138 :4 0 80
:2 0 81 :3 0 a61
119d 119f :3 0 80
:2 0 94 :4 0 a64
11a1 11a3 :3 0 80
:2 0 95 :4 0 a67
11a5 11a7 :3 0 80
:2 0 85 :3 0 66
:3 0 1b :3 0 ab
:3 0 11ac 11ad 0
a6a 11ab 11af 86
:4 0 a6c 11aa 11b2
a6f 11a9 11b4 :3 0
80 :2 0 da :4 0
a72 11b6 11b8 :3 0
80 :2 0 83 :4 0
a75 11ba 11bc :3 0
80 :2 0 2b :3 0
a78 11be 11c0 :3 0
80 :2 0 83 :4 0
a7b 11c2 11c4 :3 0
a7e 119a 11c6 :2 0
11c8 a81 11c9 1197
11c8 0 11ca a83
0 11f4 78 :3 0
79 :3 0 11cb 11cc
0 78 :3 0 88
:3 0 11ce 11cf 0
49 :2 0 2 :4 0
139 :2 0 8a :2 0
49 :2 0 a85 11d4
11d6 :3 0 a88 11d0
11d8 11cd 11da 11d9
:2 0 7b :3 0 8b
:3 0 11dc 11dd 0
7d :4 0 13a :4 0
80 :2 0 81 :3 0
a8c 11e1 11e3 :3 0
a8f 11de 11e5 :2 0
11e7 a92 11e8 11db
11e7 0 11e9 a94
0 11f4 9a :3 0
dd :3 0 11ea 11eb
0 1b :3 0 ab
:3 0 11ed 11ee 0
2b :3 0 9c :3 0
a96 11ec 11f2 :2 0
11f4 a9a 11f5 1186
11f4 0 11f6 a9e
0 1d70 38 :3 0
11 :3 0 11f7 11f8
0 1d70 85 :3 0
39 :3 0 31 :2 0
aa0 11fa 11fd c0
:2 0 f0 :2 0 aa5
11ff 1201 :3 0 1202
:2 0 85 :3 0 38
:3 0 31 :2 0 aa8
1204 1207 a4 :2 0
31 :2 0 aad 1209
120b :3 0 120c :2 0
1203 120e 120d :2 0
38 :3 0 49 :2 0
1210 1211 0 1213
ab0 1214 120f 1213
0 1215 ab2 0
1d70 85 :3 0 57
:3 0 31 :2 0 ab4
1216 1219 a4 :2 0
49 :2 0 ab9 121b
121d :3 0 f2 :3 0
85 :3 0 f :3 0
31 :2 0 abc 1220
1223 25 :2 0 abf
121f 1226 1227 :2 0
a4 :2 0 25 :2 0
ac4 1229 122b :3 0
12 :3 0 8d :2 0
ac7 122e 122f :3 0
1230 :2 0 4d :3 0
c3 :2 0 ac9 1233
1234 :3 0 1235 :2 0
d3 :3 0 103 :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 104 :3 0
16 :3 0 105 :3 0
17 :3 0 cd :3 0
18 :3 0 13b :3 0
2b :4 0 13c 1
:8 0 1262 fc :4 0
124d :3 0 9c :3 0
a4 :2 0 acd 1250
1251 :3 0 1b :3 0
ab :3 0 1253 1254
0 31 :2 0 1255
1256 0 1258 ad0
125f 1b :3 0 ab
:3 0 1259 125a 0
fd :2 0 125b 125c
0 125e ad2 1260
1252 1258 0 1261
0 125e 0 1261
ad4 0 1262 ad7
12b5 ad :3 0 1b
:3 0 ab :3 0 1264
1265 0 ac :3 0
1266 1267 0 1269
ada 126b adc 126a
1269 :2 0 12b3 ae
:3 0 1b :3 0 ab
:3 0 126e 126f 0
ac :3 0 1270 1271
0 12ab 78 :3 0
79 :3 0 1273 1274
0 78 :3 0 88
:3 0 1276 1277 0
25 :2 0 2 :4 0
13d :2 0 8a :2 0
49 :2 0 ade 127c
127e :3 0 ae1 1278
1280 1275 1282 1281
:2 0 7b :3 0 8b
:3 0 1284 1285 0
7d :4 0 13e :4 0
80 :2 0 81 :3 0
ae5 1289 128b :3 0
80 :2 0 94 :4 0
ae8 128d 128f :3 0
80 :2 0 b1 :4 0
aeb 1291 1293 :3 0
80 :2 0 ac :3 0
aee 1295 1297 :3 0
80 :2 0 b2 :4 0
af1 1299 129b :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 af4 129e
12a2 af8 129d 12a4
:3 0 afb 1286 12a6
:2 0 12a8 afe 12a9
1283 12a8 0 12aa
b00 0 12ab b02
12ae :3 0 12ae 0
12ae 12ad 12ab 12ac
:6 0 12b0 26 :3 0
b05 12b2 b07 12b1
12b0 :2 0 12b3 b09
:2 0 12b5 0 12b5
12b4 1262 12b3 :6 0
12b7 1 :3 0 b0c
132d d3 :3 0 103
:3 0 d :3 0 cf
:3 0 39 :3 0 d2
:3 0 38 :3 0 13b
:3 0 2b :4 0 13f
1 :8 0 12d7 fc
:4 0 12c2 :3 0 9c
:3 0 a4 :2 0 b10
12c5 12c6 :3 0 1b
:3 0 ab :3 0 12c8
12c9 0 31 :2 0
12ca 12cb 0 12cd
b13 12d4 1b :3 0
ab :3 0 12ce 12cf
0 fd :2 0 12d0
12d1 0 12d3 b15
12d5 12c7 12cd 0
12d6 0 12d3 0
12d6 b17 0 12d7
b1a 132a ad :3 0
1b :3 0 ab :3 0
12d9 12da 0 ac
:3 0 12db 12dc 0
12de b1d 12e0 b1f
12df 12de :2 0 1328
ae :3 0 1b :3 0
ab :3 0 12e3 12e4
0 ac :3 0 12e5
12e6 0 1320 78
:3 0 79 :3 0 12e8
12e9 0 78 :3 0
88 :3 0 12eb 12ec
0 25 :2 0 2
:4 0 140 :2 0 8a
:2 0 49 :2 0 b21
12f1 12f3 :3 0 b24
12ed 12f5 12ea 12f7
12f6 :2 0 7b :3 0
8b :3 0 12f9 12fa
0 7d :4 0 141
:4 0 80 :2 0 81
:3 0 b28 12fe 1300
:3 0 80 :2 0 94
:4 0 b2b 1302 1304
:3 0 80 :2 0 b1
:4 0 b2e 1306 1308
:3 0 80 :2 0 ac
:3 0 b31 130a 130c
:3 0 80 :2 0 b2
:4 0 b34 130e 1310
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 b37
1313 1317 b3b 1312
1319 :3 0 b3e 12fb
131b :2 0 131d b41
131e 12f8 131d 0
131f b43 0 1320
b45 1323 :3 0 1323
0 1323 1322 1320
1321 :6 0 1325 28
:3 0 b48 1327 b4a
1326 1325 :2 0 1328
b4c :2 0 132a 0
132a 1329 12d7 1328
:6 0 132c 1 :3 0
b4f 132e 1236 12b7
0 132f 0 132c
0 132f b51 0
1330 b54 1486 4d
:3 0 c3 :2 0 b56
1332 1333 :3 0 1334
:2 0 d3 :3 0 103
:3 0 d :3 0 cf
:3 0 39 :3 0 d2
:3 0 38 :3 0 142
:3 0 143 :3 0 c4
:3 0 12 :3 0 142
:3 0 144 :3 0 143
:3 0 c4 :3 0 13
:3 0 144 :3 0 145
:3 0 143 :3 0 14
:3 0 145 :3 0 146
:3 0 143 :3 0 15
:3 0 146 :3 0 147
:3 0 148 :3 0 149
:3 0 14a :3 0 14b
:3 0 14c :3 0 14d
:3 0 14e :3 0 148
:3 0 12 :3 0 14a
:3 0 13 :3 0 14c
:3 0 14 :3 0 14e
:3 0 15 :3 0 14f
:3 0 150 :3 0 151
:3 0 152 :3 0 153
:3 0 154 :3 0 155
:3 0 156 :3 0 143
:3 0 f5 :3 0 f6
:3 0 f7 :3 0 f8
:3 0 f9 :3 0 fa
:3 0 104 :3 0 16
:3 0 105 :3 0 17
:3 0 cd :3 0 18
:3 0 13b :3 0 2b
:4 0 157 1 :8 0
138c fc :4 0 1377
:3 0 9c :3 0 a4
:2 0 b5a 137a 137b
:3 0 1b :3 0 ab
:3 0 137d 137e 0
31 :2 0 137f 1380
0 1382 b5d 1389
1b :3 0 ab :3 0
1383 1384 0 fd
:2 0 1385 1386 0
1388 b5f 138a 137c
1382 0 138b 0
1388 0 138b b61
0 138c b64 13df
ad :3 0 1b :3 0
ab :3 0 138e 138f
0 ac :3 0 1390
1391 0 1393 b67
1395 b69 1394 1393
:2 0 13dd ae :3 0
1b :3 0 ab :3 0
1398 1399 0 ac
:3 0 139a 139b 0
13d5 78 :3 0 79
:3 0 139d 139e 0
78 :3 0 88 :3 0
13a0 13a1 0 25
:2 0 2 :4 0 158
:2 0 8a :2 0 49
:2 0 b6b 13a6 13a8
:3 0 b6e 13a2 13aa
139f 13ac 13ab :2 0
7b :3 0 8b :3 0
13ae 13af 0 7d
:4 0 159 :4 0 80
:2 0 81 :3 0 b72
13b3 13b5 :3 0 80
:2 0 94 :4 0 b75
13b7 13b9 :3 0 80
:2 0 b1 :4 0 b78
13bb 13bd :3 0 80
:2 0 ac :3 0 b7b
13bf 13c1 :3 0 80
:2 0 b2 :4 0 b7e
13c3 13c5 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 b81 13c8 13cc
b85 13c7 13ce :3 0
b88 13b0 13d0 :2 0
13d2 b8b 13d3 13ad
13d2 0 13d4 b8d
0 13d5 b8f 13d8
:3 0 13d8 0 13d8
13d7 13d5 13d6 :6 0
13da 2a :3 0 b92
13dc b94 13db 13da
:2 0 13dd b96 :2 0
13df 0 13df 13de
138c 13dd :6 0 13e1
1 :3 0 b99 1482
d3 :3 0 103 :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 142 :3 0
143 :3 0 c4 :3 0
12 :3 0 142 :3 0
144 :3 0 143 :3 0
c4 :3 0 13 :3 0
144 :3 0 145 :3 0
143 :3 0 14 :3 0
145 :3 0 146 :3 0
143 :3 0 15 :3 0
146 :3 0 147 :3 0
148 :3 0 149 :3 0
14a :3 0 14b :3 0
14c :3 0 14d :3 0
14e :3 0 148 :3 0
12 :3 0 14a :3 0
13 :3 0 14c :3 0
14 :3 0 14e :3 0
15 :3 0 14f :3 0
150 :3 0 151 :3 0
152 :3 0 153 :3 0
154 :3 0 155 :3 0
156 :3 0 143 :3 0
13b :3 0 2b :4 0
15a 1 :8 0 142c
fc :4 0 1417 :3 0
9c :3 0 a4 :2 0
b9d 141a 141b :3 0
1b :3 0 ab :3 0
141d 141e 0 31
:2 0 141f 1420 0
1422 ba0 1429 1b
:3 0 ab :3 0 1423
1424 0 fd :2 0
1425 1426 0 1428
ba2 142a 141c 1422
0 142b 0 1428
0 142b ba4 0
142c ba7 147f ad
:3 0 1b :3 0 ab
:3 0 142e 142f 0
ac :3 0 1430 1431
0 1433 baa 1435
bac 1434 1433 :2 0
147d ae :3 0 1b
:3 0 ab :3 0 1438
1439 0 ac :3 0
143a 143b 0 1475
78 :3 0 79 :3 0
143d 143e 0 78
:3 0 88 :3 0 1440
1441 0 25 :2 0
2 :4 0 15b :2 0
8a :2 0 49 :2 0
bae 1446 1448 :3 0
bb1 1442 144a 143f
144c 144b :2 0 7b
:3 0 8b :3 0 144e
144f 0 7d :4 0
15c :4 0 80 :2 0
81 :3 0 bb5 1453
1455 :3 0 80 :2 0
94 :4 0 bb8 1457
1459 :3 0 80 :2 0
b1 :4 0 bbb 145b
145d :3 0 80 :2 0
ac :3 0 bbe 145f
1461 :3 0 80 :2 0
b2 :4 0 bc1 1463
1465 :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
bc4 1468 146c bc8
1467 146e :3 0 bcb
1450 1470 :2 0 1472
bce 1473 144d 1472
0 1474 bd0 0
1475 bd2 1478 :3 0
1478 0 1478 1477
1475 1476 :6 0 147a
2c :3 0 bd5 147c
bd7 147b 147a :2 0
147d bd9 :2 0 147f
0 147f 147e 142c
147d :6 0 1481 1
:3 0 bdc 1483 1335
13e1 0 1484 0
1481 0 1484 bde
0 1485 be1 1487
1231 1330 0 1488
0 1485 0 1488
be3 0 148a 15d
:3 0 be6 150a 85
:3 0 3e :3 0 31
:2 0 be8 148b 148e
a4 :2 0 31 :2 0
bed 1490 1492 :3 0
d3 :3 0 103 :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 13b :3 0
2b :4 0 15e 1
:8 0 14b3 fc :4 0
149e :3 0 9c :3 0
a4 :2 0 bf2 14a1
14a2 :3 0 1b :3 0
ab :3 0 14a4 14a5
0 31 :2 0 14a6
14a7 0 14a9 bf5
14b0 1b :3 0 ab
:3 0 14aa 14ab 0
fd :2 0 14ac 14ad
0 14af bf7 14b1
14a3 14a9 0 14b2
0 14af 0 14b2
bf9 0 14b3 bfc
1506 ad :3 0 1b
:3 0 ab :3 0 14b5
14b6 0 ac :3 0
14b7 14b8 0 14ba
bff 14bc c01 14bb
14ba :2 0 1504 ae
:3 0 1b :3 0 ab
:3 0 14bf 14c0 0
ac :3 0 14c1 14c2
0 14fc 78 :3 0
79 :3 0 14c4 14c5
0 78 :3 0 88
:3 0 14c7 14c8 0
25 :2 0 2 :4 0
15f :2 0 8a :2 0
49 :2 0 c03 14cd
14cf :3 0 c06 14c9
14d1 14c6 14d3 14d2
:2 0 7b :3 0 8b
:3 0 14d5 14d6 0
7d :4 0 160 :4 0
80 :2 0 81 :3 0
c0a 14da 14dc :3 0
80 :2 0 94 :4 0
c0d 14de 14e0 :3 0
80 :2 0 b1 :4 0
c10 14e2 14e4 :3 0
80 :2 0 ac :3 0
c13 14e6 14e8 :3 0
80 :2 0 b2 :4 0
c16 14ea 14ec :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 c19 14ef
14f3 c1d 14ee 14f5
:3 0 c20 14d7 14f7
:2 0 14f9 c23 14fa
14d4 14f9 0 14fb
c25 0 14fc c27
14ff :3 0 14ff 0
14ff 14fe 14fc 14fd
:6 0 1501 2e :3 0
c2a 1503 c2c 1502
1501 :2 0 1504 c2e
:2 0 1506 0 1506
1505 14b3 1504 :6 0
1508 1 :3 0 c31
1509 1493 1508 0
150b 122c 148a 0
150b c33 0 150c
c36 1908 f2 :3 0
85 :3 0 f :3 0
31 :2 0 c38 150e
1511 25 :2 0 c3b
150d 1514 1515 :2 0
a4 :2 0 25 :2 0
c40 1517 1519 :3 0
12 :3 0 8d :2 0
c43 151c 151d :3 0
151e :2 0 4d :3 0
c3 :2 0 c45 1521
1522 :3 0 1523 :2 0
d3 :3 0 103 :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 104 :3 0
16 :3 0 105 :3 0
17 :3 0 cd :3 0
18 :3 0 74 :3 0
2b :4 0 161 1
:8 0 1550 fc :4 0
153b :3 0 9c :3 0
a4 :2 0 c49 153e
153f :3 0 1b :3 0
ab :3 0 1541 1542
0 31 :2 0 1543
1544 0 1546 c4c
154d 1b :3 0 ab
:3 0 1547 1548 0
fd :2 0 1549 154a
0 154c c4e 154e
1540 1546 0 154f
0 154c 0 154f
c50 0 1550 c53
15a3 ad :3 0 1b
:3 0 ab :3 0 1552
1553 0 ac :3 0
1554 1555 0 1557
c56 1559 c58 1558
1557 :2 0 15a1 ae
:3 0 1b :3 0 ab
:3 0 155c 155d 0
ac :3 0 155e 155f
0 1599 78 :3 0
79 :3 0 1561 1562
0 78 :3 0 88
:3 0 1564 1565 0
25 :2 0 2 :4 0
162 :2 0 8a :2 0
49 :2 0 c5a 156a
156c :3 0 c5d 1566
156e 1563 1570 156f
:2 0 7b :3 0 8b
:3 0 1572 1573 0
7d :4 0 163 :4 0
80 :2 0 81 :3 0
c61 1577 1579 :3 0
80 :2 0 94 :4 0
c64 157b 157d :3 0
80 :2 0 b1 :4 0
c67 157f 1581 :3 0
80 :2 0 ac :3 0
c6a 1583 1585 :3 0
80 :2 0 b2 :4 0
c6d 1587 1589 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 c70 158c
1590 c74 158b 1592
:3 0 c77 1574 1594
:2 0 1596 c7a 1597
1571 1596 0 1598
c7c 0 1599 c7e
159c :3 0 159c 0
159c 159b 1599 159a
:6 0 159e 30 :3 0
c81 15a0 c83 159f
159e :2 0 15a1 c85
:2 0 15a3 0 15a3
15a2 1550 15a1 :6 0
15a5 1 :3 0 c88
161d d3 :3 0 103
:3 0 d :3 0 cf
:3 0 39 :3 0 d2
:3 0 38 :3 0 cd
:3 0 c :3 0 74
:3 0 2b :4 0 164
1 :8 0 15c7 fc
:4 0 15b2 :3 0 9c
:3 0 a4 :2 0 c8c
15b5 15b6 :3 0 1b
:3 0 ab :3 0 15b8
15b9 0 31 :2 0
15ba 15bb 0 15bd
c8f 15c4 1b :3 0
ab :3 0 15be 15bf
0 fd :2 0 15c0
15c1 0 15c3 c91
15c5 15b7 15bd 0
15c6 0 15c3 0
15c6 c93 0 15c7
c96 161a ad :3 0
1b :3 0 ab :3 0
15c9 15ca 0 ac
:3 0 15cb 15cc 0
15ce c99 15d0 c9b
15cf 15ce :2 0 1618
ae :3 0 1b :3 0
ab :3 0 15d3 15d4
0 ac :3 0 15d5
15d6 0 1610 78
:3 0 79 :3 0 15d8
15d9 0 78 :3 0
88 :3 0 15db 15dc
0 25 :2 0 2
:4 0 165 :2 0 8a
:2 0 49 :2 0 c9d
15e1 15e3 :3 0 ca0
15dd 15e5 15da 15e7
15e6 :2 0 7b :3 0
8b :3 0 15e9 15ea
0 7d :4 0 166
:4 0 80 :2 0 81
:3 0 ca4 15ee 15f0
:3 0 80 :2 0 94
:4 0 ca7 15f2 15f4
:3 0 80 :2 0 b1
:4 0 caa 15f6 15f8
:3 0 80 :2 0 ac
:3 0 cad 15fa 15fc
:3 0 80 :2 0 b2
:4 0 cb0 15fe 1600
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 cb3
1603 1607 cb7 1602
1609 :3 0 cba 15eb
160b :2 0 160d cbd
160e 15e8 160d 0
160f cbf 0 1610
cc1 1613 :3 0 1613
0 1613 1612 1610
1611 :6 0 1615 32
:3 0 cc4 1617 cc6
1616 1615 :2 0 1618
cc8 :2 0 161a 0
161a 1619 15c7 1618
:6 0 161c 1 :3 0
ccb 161e 1524 15a5
0 161f 0 161c
0 161f ccd 0
1620 cd0 1778 4d
:3 0 c3 :2 0 cd2
1622 1623 :3 0 1624
:2 0 d3 :3 0 103
:3 0 d :3 0 cf
:3 0 39 :3 0 d2
:3 0 38 :3 0 142
:3 0 143 :3 0 c4
:3 0 12 :3 0 142
:3 0 144 :3 0 143
:3 0 c4 :3 0 13
:3 0 144 :3 0 145
:3 0 143 :3 0 14
:3 0 145 :3 0 146
:3 0 143 :3 0 15
:3 0 146 :3 0 147
:3 0 148 :3 0 149
:3 0 14a :3 0 14b
:3 0 14c :3 0 14d
:3 0 14e :3 0 148
:3 0 12 :3 0 14a
:3 0 13 :3 0 14c
:3 0 14 :3 0 14e
:3 0 15 :3 0 14f
:3 0 150 :3 0 151
:3 0 152 :3 0 153
:3 0 154 :3 0 155
:3 0 156 :3 0 143
:3 0 f5 :3 0 f6
:3 0 f7 :3 0 f8
:3 0 f9 :3 0 fa
:3 0 104 :3 0 16
:3 0 105 :3 0 17
:3 0 cd :3 0 18
:3 0 74 :3 0 2b
:4 0 167 1 :8 0
167c fc :4 0 1667
:3 0 9c :3 0 a4
:2 0 cd6 166a 166b
:3 0 1b :3 0 ab
:3 0 166d 166e 0
31 :2 0 166f 1670
0 1672 cd9 1679
1b :3 0 ab :3 0
1673 1674 0 fd
:2 0 1675 1676 0
1678 cdb 167a 166c
1672 0 167b 0
1678 0 167b cdd
0 167c ce0 16cf
ad :3 0 1b :3 0
ab :3 0 167e 167f
0 ac :3 0 1680
1681 0 1683 ce3
1685 ce5 1684 1683
:2 0 16cd ae :3 0
1b :3 0 ab :3 0
1688 1689 0 ac
:3 0 168a 168b 0
16c5 78 :3 0 79
:3 0 168d 168e 0
78 :3 0 88 :3 0
1690 1691 0 25
:2 0 2 :4 0 168
:2 0 8a :2 0 49
:2 0 ce7 1696 1698
:3 0 cea 1692 169a
168f 169c 169b :2 0
7b :3 0 8b :3 0
169e 169f 0 7d
:4 0 169 :4 0 80
:2 0 81 :3 0 cee
16a3 16a5 :3 0 80
:2 0 94 :4 0 cf1
16a7 16a9 :3 0 80
:2 0 b1 :4 0 cf4
16ab 16ad :3 0 80
:2 0 ac :3 0 cf7
16af 16b1 :3 0 80
:2 0 b2 :4 0 cfa
16b3 16b5 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 cfd 16b8 16bc
d01 16b7 16be :3 0
d04 16a0 16c0 :2 0
16c2 d07 16c3 169d
16c2 0 16c4 d09
0 16c5 d0b 16c8
:3 0 16c8 0 16c8
16c7 16c5 16c6 :6 0
16ca 34 :3 0 d0e
16cc d10 16cb 16ca
:2 0 16cd d12 :2 0
16cf 0 16cf 16ce
167c 16cd :6 0 16d1
1 :3 0 d15 1774
d3 :3 0 103 :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 cd :3 0
c :3 0 142 :3 0
143 :3 0 c4 :3 0
12 :3 0 142 :3 0
144 :3 0 143 :3 0
c4 :3 0 13 :3 0
144 :3 0 145 :3 0
143 :3 0 14 :3 0
145 :3 0 146 :3 0
143 :3 0 15 :3 0
146 :3 0 147 :3 0
148 :3 0 149 :3 0
14a :3 0 14b :3 0
14c :3 0 14d :3 0
14e :3 0 148 :3 0
12 :3 0 14a :3 0
13 :3 0 14c :3 0
14 :3 0 14e :3 0
15 :3 0 14f :3 0
150 :3 0 151 :3 0
152 :3 0 153 :3 0
154 :3 0 155 :3 0
156 :3 0 143 :3 0
74 :3 0 2b :4 0
16a 1 :8 0 171e
fc :4 0 1709 :3 0
9c :3 0 a4 :2 0
d19 170c 170d :3 0
1b :3 0 ab :3 0
170f 1710 0 31
:2 0 1711 1712 0
1714 d1c 171b 1b
:3 0 ab :3 0 1715
1716 0 fd :2 0
1717 1718 0 171a
d1e 171c 170e 1714
0 171d 0 171a
0 171d d20 0
171e d23 1771 ad
:3 0 1b :3 0 ab
:3 0 1720 1721 0
ac :3 0 1722 1723
0 1725 d26 1727
d28 1726 1725 :2 0
176f ae :3 0 1b
:3 0 ab :3 0 172a
172b 0 ac :3 0
172c 172d 0 1767
78 :3 0 79 :3 0
172f 1730 0 78
:3 0 88 :3 0 1732
1733 0 25 :2 0
2 :4 0 16b :2 0
8a :2 0 49 :2 0
d2a 1738 173a :3 0
d2d 1734 173c 1731
173e 173d :2 0 7b
:3 0 8b :3 0 1740
1741 0 7d :4 0
16c :4 0 80 :2 0
81 :3 0 d31 1745
1747 :3 0 80 :2 0
94 :4 0 d34 1749
174b :3 0 80 :2 0
b1 :4 0 d37 174d
174f :3 0 80 :2 0
ac :3 0 d3a 1751
1753 :3 0 80 :2 0
b2 :4 0 d3d 1755
1757 :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
d40 175a 175e d44
1759 1760 :3 0 d47
1742 1762 :2 0 1764
d4a 1765 173f 1764
0 1766 d4c 0
1767 d4e 176a :3 0
176a 0 176a 1769
1767 1768 :6 0 176c
36 :3 0 d51 176e
d53 176d 176c :2 0
176f d55 :2 0 1771
0 1771 1770 171e
176f :6 0 1773 1
:3 0 d58 1775 1625
16d1 0 1776 0
1773 0 1776 d5a
0 1777 d5d 1779
151f 1620 0 177a
0 1777 0 177a
d5f 0 177c 15d
:3 0 d62 1905 85
:3 0 3e :3 0 31
:2 0 d64 177d 1780
a4 :2 0 31 :2 0
d69 1782 1784 :3 0
47 :3 0 8d :2 0
d6c 1787 1788 :3 0
1789 :2 0 85 :3 0
e :3 0 31 :2 0
d6e 178b 178e a4
:2 0 31 :2 0 d73
1790 1792 :3 0 d3
:3 0 103 :3 0 d
:3 0 cf :3 0 39
:3 0 d2 :3 0 38
:3 0 cd :3 0 c
:3 0 f4 :3 0 3d
:3 0 c :3 0 74
:3 0 2b :4 0 16d
1 :8 0 17b8 fc
:4 0 17a3 :3 0 9c
:3 0 a4 :2 0 d78
17a6 17a7 :3 0 1b
:3 0 ab :3 0 17a9
17aa 0 31 :2 0
17ab 17ac 0 17ae
d7b 17b5 1b :3 0
ab :3 0 17af 17b0
0 fd :2 0 17b1
17b2 0 17b4 d7d
17b6 17a8 17ae 0
17b7 0 17b4 0
17b7 d7f 0 17b8
d82 180b ad :3 0
1b :3 0 ab :3 0
17ba 17bb 0 ac
:3 0 17bc 17bd 0
17bf d85 17c1 d87
17c0 17bf :2 0 1809
ae :3 0 1b :3 0
ab :3 0 17c4 17c5
0 ac :3 0 17c6
17c7 0 1801 78
:3 0 79 :3 0 17c9
17ca 0 78 :3 0
88 :3 0 17cc 17cd
0 25 :2 0 2
:4 0 16e :2 0 8a
:2 0 49 :2 0 d89
17d2 17d4 :3 0 d8c
17ce 17d6 17cb 17d8
17d7 :2 0 7b :3 0
8b :3 0 17da 17db
0 7d :4 0 16f
:4 0 80 :2 0 81
:3 0 d90 17df 17e1
:3 0 80 :2 0 94
:4 0 d93 17e3 17e5
:3 0 80 :2 0 b1
:4 0 d96 17e7 17e9
:3 0 80 :2 0 ac
:3 0 d99 17eb 17ed
:3 0 80 :2 0 b2
:4 0 d9c 17ef 17f1
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 d9f
17f4 17f8 da3 17f3
17fa :3 0 da6 17dc
17fc :2 0 17fe da9
17ff 17d9 17fe 0
1800 dab 0 1801
dad 1804 :3 0 1804
0 1804 1803 1801
1802 :6 0 1806 38
:3 0 db0 1808 db2
1807 1806 :2 0 1809
db4 :2 0 180b 0
180b 180a 17b8 1809
:6 0 180d 1 :3 0
db7 1885 d3 :3 0
103 :3 0 d :3 0
cf :3 0 39 :3 0
d2 :3 0 38 :3 0
cd :3 0 c :3 0
74 :3 0 2b :4 0
164 1 :8 0 182f
fc :4 0 181a :3 0
9c :3 0 a4 :2 0
dbb 181d 181e :3 0
1b :3 0 ab :3 0
1820 1821 0 31
:2 0 1822 1823 0
1825 dbe 182c 1b
:3 0 ab :3 0 1826
1827 0 fd :2 0
1828 1829 0 182b
dc0 182d 181f 1825
0 182e 0 182b
0 182e dc2 0
182f dc5 1882 ad
:3 0 1b :3 0 ab
:3 0 1831 1832 0
ac :3 0 1833 1834
0 1836 dc8 1838
dca 1837 1836 :2 0
1880 ae :3 0 1b
:3 0 ab :3 0 183b
183c 0 ac :3 0
183d 183e 0 1878
78 :3 0 79 :3 0
1840 1841 0 78
:3 0 88 :3 0 1843
1844 0 25 :2 0
2 :4 0 170 :2 0
8a :2 0 49 :2 0
dcc 1849 184b :3 0
dcf 1845 184d 1842
184f 184e :2 0 7b
:3 0 8b :3 0 1851
1852 0 7d :4 0
171 :4 0 80 :2 0
81 :3 0 dd3 1856
1858 :3 0 80 :2 0
94 :4 0 dd6 185a
185c :3 0 80 :2 0
b1 :4 0 dd9 185e
1860 :3 0 80 :2 0
ac :3 0 ddc 1862
1864 :3 0 80 :2 0
b2 :4 0 ddf 1866
1868 :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
de2 186b 186f de6
186a 1871 :3 0 de9
1853 1873 :2 0 1875
dec 1876 1850 1875
0 1877 dee 0
1878 df0 187b :3 0
187b 0 187b 187a
1878 1879 :6 0 187d
3a :3 0 df3 187f
df5 187e 187d :2 0
1880 df7 :2 0 1882
0 1882 1881 182f
1880 :6 0 1884 1
:3 0 dfa 1886 1793
180d 0 1887 0
1884 0 1887 dfc
0 1888 dff 1900
d3 :3 0 103 :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 cd :3 0
c :3 0 74 :3 0
2b :4 0 172 1
:8 0 18aa fc :4 0
1895 :3 0 9c :3 0
a4 :2 0 e03 1898
1899 :3 0 1b :3 0
ab :3 0 189b 189c
0 31 :2 0 189d
189e 0 18a0 e06
18a7 1b :3 0 ab
:3 0 18a1 18a2 0
fd :2 0 18a3 18a4
0 18a6 e08 18a8
189a 18a0 0 18a9
0 18a6 0 18a9
e0a 0 18aa e0d
18fd ad :3 0 1b
:3 0 ab :3 0 18ac
18ad 0 ac :3 0
18ae 18af 0 18b1
e10 18b3 e12 18b2
18b1 :2 0 18fb ae
:3 0 1b :3 0 ab
:3 0 18b6 18b7 0
ac :3 0 18b8 18b9
0 18f3 78 :3 0
79 :3 0 18bb 18bc
0 78 :3 0 88
:3 0 18be 18bf 0
25 :2 0 2 :4 0
173 :2 0 8a :2 0
49 :2 0 e14 18c4
18c6 :3 0 e17 18c0
18c8 18bd 18ca 18c9
:2 0 7b :3 0 8b
:3 0 18cc 18cd 0
7d :4 0 174 :4 0
80 :2 0 81 :3 0
e1b 18d1 18d3 :3 0
80 :2 0 94 :4 0
e1e 18d5 18d7 :3 0
80 :2 0 b1 :4 0
e21 18d9 18db :3 0
80 :2 0 ac :3 0
e24 18dd 18df :3 0
80 :2 0 b2 :4 0
e27 18e1 18e3 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 e2a 18e6
18ea e2e 18e5 18ec
:3 0 e31 18ce 18ee
:2 0 18f0 e34 18f1
18cb 18f0 0 18f2
e36 0 18f3 e38
18f6 :3 0 18f6 0
18f6 18f5 18f3 18f4
:6 0 18f8 3c :3 0
e3b 18fa e3d 18f9
18f8 :2 0 18fb e3f
:2 0 18fd 0 18fd
18fc 18aa 18fb :6 0
18ff 1 :3 0 e42
1901 178a 1888 0
1902 0 18ff 0
1902 e44 0 1903
e47 1904 1785 1903
0 1906 151a 177c
0 1906 e49 0
1907 e4c 1909 121e
150c 0 190a 0
1907 0 190a e4e
0 1d70 4d :3 0
c3 :2 0 e51 190c
190d :3 0 190e :2 0
85 :3 0 18 :3 0
31 :2 0 e53 1910
1913 8f :2 0 31
:2 0 e58 1915 1917
:3 0 1918 :2 0 190f
191a 1919 :2 0 191b
:2 0 85 :3 0 c
:3 0 31 :2 0 e5b
191d 1920 8f :2 0
31 :2 0 e60 1922
1924 :3 0 1925 :2 0
191c 1927 1926 :2 0
45 :3 0 175 :4 0
1929 192a 0 1d6d
45 :4 0 192c 192d
0 1d6d 3f :3 0
31 :2 0 192f 1930
0 1d6d 3e :3 0
31 :2 0 1932 1933
0 1d6d 85 :3 0
57 :3 0 31 :2 0
e63 1935 1938 a4
:2 0 49 :2 0 e68
193a 193c :3 0 74
:3 0 fa :3 0 cb
:3 0 176 :3 0 b3
:3 0 f6 :3 0 176
:3 0 b3 :3 0 f8
:3 0 177 :3 0 178
:3 0 150 :3 0 152
:3 0 46 :3 0 3d
:3 0 2e :3 0 59
:3 0 5a :3 0 5e
:3 0 5f :3 0 5b
:3 0 5d :3 0 d3
:3 0 13b :3 0 2b
:4 0 179 1 :8 0
195d 1b :3 0 ab
:3 0 1958 1959 0
ac :3 0 195a 195b
0 195d e6b 19b0
ad :3 0 1b :3 0
ab :3 0 195f 1960
0 ac :3 0 1961
1962 0 1964 e6e
1966 e70 1965 1964
:2 0 19ae ae :3 0
1b :3 0 ab :3 0
1969 196a 0 ac
:3 0 196b 196c 0
19a6 78 :3 0 79
:3 0 196e 196f 0
78 :3 0 88 :3 0
1971 1972 0 25
:2 0 2 :4 0 17a
:2 0 8a :2 0 49
:2 0 e72 1977 1979
:3 0 e75 1973 197b
1970 197d 197c :2 0
7b :3 0 8b :3 0
197f 1980 0 7d
:4 0 17b :4 0 80
:2 0 81 :3 0 e79
1984 1986 :3 0 80
:2 0 94 :4 0 e7c
1988 198a :3 0 80
:2 0 b1 :4 0 e7f
198c 198e :3 0 80
:2 0 ac :3 0 e82
1990 1992 :3 0 80
:2 0 b2 :4 0 e85
1994 1996 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 e88 1999 199d
e8c 1998 199f :3 0
e8f 1981 19a1 :2 0
19a3 e92 19a4 197e
19a3 0 19a5 e94
0 19a6 e96 19a9
:3 0 19a9 0 19a9
19a8 19a6 19a7 :6 0
19ab 3e :3 0 e99
19ad e9b 19ac 19ab
:2 0 19ae e9d :2 0
19b0 0 19b0 19af
195d 19ae :6 0 19b2
1 :3 0 ea0 1a29
46 :3 0 2b :3 0
19b3 19b4 0 1a28
fa :3 0 cb :3 0
176 :3 0 b3 :3 0
f6 :3 0 176 :3 0
b3 :3 0 f8 :3 0
177 :3 0 178 :3 0
150 :3 0 152 :3 0
3d :3 0 2e :3 0
59 :3 0 5a :3 0
5e :3 0 5f :3 0
5b :3 0 5d :3 0
d3 :3 0 74 :3 0
46 :4 0 17c 1
:8 0 19d3 1b :3 0
ab :3 0 19ce 19cf
0 ac :3 0 19d0
19d1 0 19d3 ea2
1a26 ad :3 0 1b
:3 0 ab :3 0 19d5
19d6 0 ac :3 0
19d7 19d8 0 19da
ea5 19dc ea7 19db
19da :2 0 1a24 ae
:3 0 1b :3 0 ab
:3 0 19df 19e0 0
ac :3 0 19e1 19e2
0 1a1c 78 :3 0
79 :3 0 19e4 19e5
0 78 :3 0 88
:3 0 19e7 19e8 0
25 :2 0 2 :4 0
17d :2 0 8a :2 0
49 :2 0 ea9 19ed
19ef :3 0 eac 19e9
19f1 19e6 19f3 19f2
:2 0 7b :3 0 8b
:3 0 19f5 19f6 0
7d :4 0 17e :4 0
80 :2 0 81 :3 0
eb0 19fa 19fc :3 0
80 :2 0 94 :4 0
eb3 19fe 1a00 :3 0
80 :2 0 b1 :4 0
eb6 1a02 1a04 :3 0
80 :2 0 ac :3 0
eb9 1a06 1a08 :3 0
80 :2 0 b2 :4 0
ebc 1a0a 1a0c :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 ebf 1a0f
1a13 ec3 1a0e 1a15
:3 0 ec6 19f7 1a17
:2 0 1a19 ec9 1a1a
19f4 1a19 0 1a1b
ecb 0 1a1c ecd
1a1f :3 0 1a1f 0
1a1f 1a1e 1a1c 1a1d
:6 0 1a21 40 :3 0
ed0 1a23 ed2 1a22
1a21 :2 0 1a24 ed4
:2 0 1a26 0 1a26
1a25 19d3 1a24 :6 0
1a28 1 :3 0 ed7
1a2a 193d 19b2 0
1a2b 0 1a28 0
1a2b eda 0 1d6d
1b :3 0 ab :3 0
1a2c 1a2d 0 1b
:3 0 a4 :2 0 d7
:3 0 1a2f 1a31 0
edf 1a30 1a33 :3 0
1a34 :2 0 85 :3 0
c :3 0 31 :2 0
ee2 1a36 1a39 85
:3 0 a4 :2 0 a
:3 0 31 :2 0 ee5
1a3b 1a3f eea 1a3c
1a41 :3 0 1a42 :2 0
85 :3 0 e :3 0
31 :2 0 eed 1a44
1a47 a4 :2 0 31
:2 0 ef2 1a49 1a4b
:3 0 1a4c :2 0 1a43
1a4e 1a4d :2 0 85
:3 0 d :3 0 31
:2 0 ef5 1a50 1a53
a4 :2 0 f0 :2 0
efa 1a55 1a57 :3 0
1a58 :2 0 1a4f 1a5a
1a59 :2 0 73 :3 0
75 :3 0 70 :3 0
72 :3 0 6a :3 0
2d :3 0 74 :3 0
46 :4 0 17f 1
:8 0 1a7a fc :4 0
1a65 :3 0 9c :3 0
a4 :2 0 eff 1a68
1a69 :3 0 1b :3 0
ab :3 0 1a6b 1a6c
0 31 :2 0 1a6d
1a6e 0 1a70 f02
1a77 1b :3 0 ab
:3 0 1a71 1a72 0
fd :2 0 1a73 1a74
0 1a76 f04 1a78
1a6a 1a70 0 1a79
0 1a76 0 1a79
f06 0 1a7a f09
1acd ad :3 0 1b
:3 0 ab :3 0 1a7c
1a7d 0 ac :3 0
1a7e 1a7f 0 1a81
f0c 1a83 f0e 1a82
1a81 :2 0 1acb ae
:3 0 1b :3 0 ab
:3 0 1a86 1a87 0
ac :3 0 1a88 1a89
0 1ac3 78 :3 0
79 :3 0 1a8b 1a8c
0 78 :3 0 88
:3 0 1a8e 1a8f 0
25 :2 0 2 :4 0
180 :2 0 8a :2 0
49 :2 0 f10 1a94
1a96 :3 0 f13 1a90
1a98 1a8d 1a9a 1a99
:2 0 7b :3 0 8b
:3 0 1a9c 1a9d 0
7d :4 0 181 :4 0
80 :2 0 81 :3 0
f17 1aa1 1aa3 :3 0
80 :2 0 94 :4 0
f1a 1aa5 1aa7 :3 0
80 :2 0 b1 :4 0
f1d 1aa9 1aab :3 0
80 :2 0 ac :3 0
f20 1aad 1aaf :3 0
80 :2 0 b2 :4 0
f23 1ab1 1ab3 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 f26 1ab6
1aba f2a 1ab5 1abc
:3 0 f2d 1a9e 1abe
:2 0 1ac0 f30 1ac1
1a9b 1ac0 0 1ac2
f32 0 1ac3 f34
1ac6 :3 0 1ac6 0
1ac6 1ac5 1ac3 1ac4
:6 0 1ac8 42 :3 0
f37 1aca f39 1ac9
1ac8 :2 0 1acb f3b
:2 0 1acd 0 1acd
1acc 1a7a 1acb :6 0
1b47 1 :3 0 d3
:3 0 cd :3 0 fa
:3 0 10c :3 0 182
:3 0 71 :3 0 73
:3 0 6a :3 0 2d
:3 0 74 :3 0 46
:3 0 74 :3 0 46
:4 0 183 1 :8 0
1af2 fc :4 0 1add
:3 0 9c :3 0 a4
:2 0 f40 1ae0 1ae1
:3 0 1b :3 0 ab
:3 0 1ae3 1ae4 0
31 :2 0 1ae5 1ae6
0 1ae8 f43 1aef
1b :3 0 ab :3 0
1ae9 1aea 0 fd
:2 0 1aeb 1aec 0
1aee f45 1af0 1ae2
1ae8 0 1af1 0
1aee 0 1af1 f47
0 1af2 f4a 1b45
ad :3 0 1b :3 0
ab :3 0 1af4 1af5
0 ac :3 0 1af6
1af7 0 1af9 f4d
1afb f4f 1afa 1af9
:2 0 1b43 ae :3 0
1b :3 0 ab :3 0
1afe 1aff 0 ac
:3 0 1b00 1b01 0
1b3b 78 :3 0 79
:3 0 1b03 1b04 0
78 :3 0 88 :3 0
1b06 1b07 0 25
:2 0 2 :4 0 184
:2 0 8a :2 0 49
:2 0 f51 1b0c 1b0e
:3 0 f54 1b08 1b10
1b05 1b12 1b11 :2 0
7b :3 0 8b :3 0
1b14 1b15 0 7d
:4 0 185 :4 0 80
:2 0 81 :3 0 f58
1b19 1b1b :3 0 80
:2 0 94 :4 0 f5b
1b1d 1b1f :3 0 80
:2 0 b1 :4 0 f5e
1b21 1b23 :3 0 80
:2 0 ac :3 0 f61
1b25 1b27 :3 0 80
:2 0 b2 :4 0 f64
1b29 1b2b :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 f67 1b2e 1b32
f6b 1b2d 1b34 :3 0
f6e 1b16 1b36 :2 0
1b38 f71 1b39 1b13
1b38 0 1b3a f73
0 1b3b f75 1b3e
:3 0 1b3e 0 1b3e
1b3d 1b3b 1b3c :6 0
1b40 44 :3 0 f78
1b42 f7a 1b41 1b40
:2 0 1b43 f7c :2 0
1b45 0 1b45 1b44
1af2 1b43 :6 0 1b47
1 :3 0 f7f 1d3a
123 :3 0 6f :4 0
1b4b :2 0 1d39 1b49
1b4c :3 0 186 :3 0
6f :3 0 40 :3 0
43 :3 0 3e :4 0
1b53 :2 0 1c53 1b4e
1b54 :3 0 f82 :3 0
6f :3 0 fc :3 0
1b55 1b56 :3 0 1b
:3 0 ab :3 0 1b58
1b59 0 31 :2 0
1b5a 1b5b 0 1b5d
f86 1b64 1b :3 0
ab :3 0 1b5e 1b5f
0 fd :2 0 1b60
1b61 0 1b63 f88
1b65 1b57 1b5d 0
1b66 0 1b63 0
1b66 f8a 0 1c53
1b :3 0 ab :3 0
1b67 1b68 0 c0
:2 0 31 :2 0 f8f
1b6a 1b6c :3 0 187
:8 0 1b70 f92 1b71
1b6d 1b70 0 1b72
f94 0 1c53 3f
:3 0 85 :3 0 3f
:3 0 31 :2 0 f96
1b74 1b77 8a :2 0
85 :3 0 40 :3 0
31 :2 0 f99 1b7a
1b7d f9c 1b79 1b7f
:3 0 1b73 1b80 0
1c53 85 :3 0 3e
:3 0 31 :2 0 f9f
1b82 1b85 a4 :2 0
31 :2 0 fa4 1b87
1b89 :3 0 85 :3 0
3f :3 0 31 :2 0
fa7 1b8b 1b8e 85
:3 0 8f :2 0 42
:3 0 31 :2 0 faa
1b90 1b94 faf 1b91
1b96 :3 0 85 :3 0
40 :3 0 31 :2 0
fb2 1b98 1b9b 85
:3 0 188 :2 0 42
:3 0 31 :2 0 fb5
1b9d 1ba1 fba 1b9e
1ba3 :3 0 40 :3 0
85 :3 0 42 :3 0
31 :2 0 fbd 1ba6
1ba9 1ba5 1baa 0
1bac fc0 1bc5 40
:3 0 85 :3 0 42
:3 0 31 :2 0 fc2
1bae 1bb1 189 :2 0
85 :3 0 3f :3 0
31 :2 0 fc5 1bb4
1bb7 fc8 1bb3 1bb9
:3 0 8a :2 0 85
:3 0 40 :3 0 31
:2 0 fcb 1bbc 1bbf
fce 1bbb 1bc1 :3 0
1bad 1bc2 0 1bc4
fd1 1bc6 1ba4 1bac
0 1bc7 0 1bc4
0 1bc7 fd3 0
1bc8 fd6 1bc9 1b97
1bc8 0 1bca fd8
0 1c3e 73 :3 0
75 :3 0 40 :3 0
72 :3 0 6f :4 0
18a 1 :8 0 1be6
fc :4 0 1bd1 :3 0
9c :3 0 a4 :2 0
fdc 1bd4 1bd5 :3 0
1b :3 0 ab :3 0
1bd7 1bd8 0 31
:2 0 1bd9 1bda 0
1bdc fdf 1be3 1b
:3 0 ab :3 0 1bdd
1bde 0 fd :2 0
1bdf 1be0 0 1be2
fe1 1be4 1bd6 1bdc
0 1be5 0 1be2
0 1be5 fe3 0
1be6 fe6 1c39 ad
:3 0 1b :3 0 ab
:3 0 1be8 1be9 0
ac :3 0 1bea 1beb
0 1bed fe9 1bef
feb 1bee 1bed :2 0
1c37 ae :3 0 1b
:3 0 ab :3 0 1bf2
1bf3 0 ac :3 0
1bf4 1bf5 0 1c2f
78 :3 0 79 :3 0
1bf7 1bf8 0 78
:3 0 88 :3 0 1bfa
1bfb 0 25 :2 0
2 :4 0 18b :2 0
8a :2 0 49 :2 0
fed 1c00 1c02 :3 0
ff0 1bfc 1c04 1bf9
1c06 1c05 :2 0 7b
:3 0 8b :3 0 1c08
1c09 0 7d :4 0
18c :4 0 80 :2 0
81 :3 0 ff4 1c0d
1c0f :3 0 80 :2 0
94 :4 0 ff7 1c11
1c13 :3 0 80 :2 0
b1 :4 0 ffa 1c15
1c17 :3 0 80 :2 0
ac :3 0 ffd 1c19
1c1b :3 0 80 :2 0
b2 :4 0 1000 1c1d
1c1f :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
1003 1c22 1c26 1007
1c21 1c28 :3 0 100a
1c0a 1c2a :2 0 1c2c
100d 1c2d 1c07 1c2c
0 1c2e 100f 0
1c2f 1011 1c32 :3 0
1c32 0 1c32 1c31
1c2f 1c30 :6 0 1c34
47 :3 0 1014 1c36
1016 1c35 1c34 :2 0
1c37 1018 :2 0 1c39
0 1c39 1c38 1be6
1c37 :6 0 1c3e 46
:3 0 45 :3 0 43
:3 0 1c3b 1c3c 0
1c3e 101b 1c3f 1b8a
1c3e 0 1c40 101f
0 1c53 85 :3 0
3f :3 0 31 :2 0
1021 1c41 1c44 85
:3 0 188 :2 0 42
:3 0 31 :2 0 1024
1c46 1c4a 1029 1c47
1c4c :3 0 187 :8 0
1c50 102c 1c51 1c4d
1c50 0 1c52 102e
0 1c53 1030 1c55
186 :4 0 1c53 :4 0
1d39 124 :3 0 6f
:4 0 1c59 :2 0 1c5f
1c57 0 1b :3 0
ab :3 0 1c5a 1c5b
0 ac :3 0 1c5c
1c5d 0 1c5f 1037
1cb2 ad :3 0 1b
:3 0 ab :3 0 1c61
1c62 0 ac :3 0
1c63 1c64 0 1c66
103a 1c68 103c 1c67
1c66 :2 0 1cb0 ae
:3 0 1b :3 0 ab
:3 0 1c6b 1c6c 0
ac :3 0 1c6d 1c6e
0 1ca8 78 :3 0
79 :3 0 1c70 1c71
0 78 :3 0 88
:3 0 1c73 1c74 0
25 :2 0 2 :4 0
18d :2 0 8a :2 0
49 :2 0 103e 1c79
1c7b :3 0 1041 1c75
1c7d 1c72 1c7f 1c7e
:2 0 7b :3 0 8b
:3 0 1c81 1c82 0
7d :4 0 18e :4 0
80 :2 0 81 :3 0
1045 1c86 1c88 :3 0
80 :2 0 94 :4 0
1048 1c8a 1c8c :3 0
80 :2 0 b1 :4 0
104b 1c8e 1c90 :3 0
80 :2 0 ac :3 0
104e 1c92 1c94 :3 0
80 :2 0 b2 :4 0
1051 1c96 1c98 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 1054 1c9b
1c9f 1058 1c9a 1ca1
:3 0 105b 1c83 1ca3
:2 0 1ca5 105e 1ca6
1c80 1ca5 0 1ca7
1060 0 1ca8 1062
1cab :3 0 1cab 0
1cab 1caa 1ca8 1ca9
:6 0 1cad 49 :3 0
1065 1caf 1067 1cae
1cad :2 0 1cb0 1069
:2 0 1cb2 0 1cb2
1cb1 1c5f 1cb0 :6 0
1d39 1 :3 0 85
:3 0 3f :3 0 31
:2 0 106c 1cb4 1cb7
8f :2 0 31 :2 0
1071 1cb9 1cbb :3 0
1cbc :2 0 45 :3 0
c3 :2 0 1074 1cbf
1cc0 :3 0 1cc1 :2 0
1cc2 :2 0 1cbd 1cc4
1cc3 :2 0 d3 :3 0
10c :3 0 45 :3 0
74 :3 0 46 :4 0
18f 1 :8 0 1ce1
fc :4 0 1ccc :3 0
9c :3 0 a4 :2 0
1078 1ccf 1cd0 :3 0
1b :3 0 ab :3 0
1cd2 1cd3 0 31
:2 0 1cd4 1cd5 0
1cd7 107b 1cde 1b
:3 0 ab :3 0 1cd8
1cd9 0 fd :2 0
1cda 1cdb 0 1cdd
107d 1cdf 1cd1 1cd7
0 1ce0 0 1cdd
0 1ce0 107f 0
1ce1 1082 1d34 ad
:3 0 1b :3 0 ab
:3 0 1ce3 1ce4 0
ac :3 0 1ce5 1ce6
0 1ce8 1085 1cea
1087 1ce9 1ce8 :2 0
1d32 ae :3 0 1b
:3 0 ab :3 0 1ced
1cee 0 ac :3 0
1cef 1cf0 0 1d2a
78 :3 0 79 :3 0
1cf2 1cf3 0 78
:3 0 88 :3 0 1cf5
1cf6 0 25 :2 0
2 :4 0 190 :2 0
8a :2 0 49 :2 0
1089 1cfb 1cfd :3 0
108c 1cf7 1cff 1cf4
1d01 1d00 :2 0 7b
:3 0 8b :3 0 1d03
1d04 0 7d :4 0
191 :4 0 80 :2 0
81 :3 0 1090 1d08
1d0a :3 0 80 :2 0
94 :4 0 1093 1d0c
1d0e :3 0 80 :2 0
b1 :4 0 1096 1d10
1d12 :3 0 80 :2 0
ac :3 0 1099 1d14
1d16 :3 0 80 :2 0
b2 :4 0 109c 1d18
1d1a :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
109f 1d1d 1d21 10a3
1d1c 1d23 :3 0 10a6
1d05 1d25 :2 0 1d27
10a9 1d28 1d02 1d27
0 1d29 10ab 0
1d2a 10ad 1d2d :3 0
1d2d 0 1d2d 1d2c
1d2a 1d2b :6 0 1d2f
4b :3 0 10b0 1d31
10b2 1d30 1d2f :2 0
1d32 10b4 :2 0 1d34
0 1d34 1d33 1ce1
1d32 :6 0 1d36 1
:3 0 10b7 1d37 1cc5
1d36 0 1d38 10b9
0 1d39 10bb 1d3b
1a5b 1b47 0 1d3c
0 1d39 0 1d3c
10c0 0 1d6a 85
:3 0 57 :3 0 31
:2 0 10c3 1d3d 1d40
a4 :2 0 49 :2 0
10c8 1d42 1d44 :3 0
f2 :3 0 85 :3 0
f :3 0 31 :2 0
10cb 1d47 1d4a 27
:2 0 10ce 1d46 1d4d
1d4e :2 0 a4 :2 0
27 :2 0 10d3 1d50
1d52 :3 0 54 :3 0
192 :3 0 46 :3 0
2f :3 0 10d6 1d55
1d58 1d54 1d59 0
1d5b 10d9 1d64 54
:3 0 193 :3 0 46
:3 0 2f :3 0 10db
1d5d 1d60 1d5c 1d61
0 1d63 10de 1d65
1d53 1d5b 0 1d66
0 1d63 0 1d66
10e0 0 1d67 10e3
1d68 1d45 1d67 0
1d69 10e5 0 1d6a
10e7 1d6b 1a35 1d6a
0 1d6c 10ea 0
1d6d 10ec 1d6e 1928
1d6d 0 1d6f 10f3
0 1d70 10f5 1d71
7da 1d70 0 1d72
1103 0 1d82 1b
:3 0 ab :3 0 1d73
1d74 0 a4 :2 0
fd :2 0 1107 1d76
1d78 :3 0 1b :3 0
ab :3 0 1d7a 1d7b
0 31 :2 0 1d7c
1d7d 0 1d7f 110a
1d80 1d79 1d7f 0
1d81 110c 0 1d82
110e 1d83 49f 1d82
0 1d84 1112 0
1dd3 78 :3 0 79
:3 0 1d85 1d86 0
78 :3 0 88 :3 0
1d88 1d89 0 194
:2 0 2 :4 0 195
:2 0 8a :2 0 49
:2 0 1114 1d8e 1d90
:3 0 1117 1d8a 1d92
1d87 1d94 1d93 :2 0
7b :3 0 8b :3 0
1d96 1d97 0 7d
:4 0 196 :4 0 80
:2 0 81 :3 0 111b
1d9b 1d9d :3 0 80
:2 0 94 :4 0 111e
1d9f 1da1 :3 0 80
:2 0 95 :4 0 1121
1da3 1da5 :3 0 80
:2 0 85 :3 0 66
:3 0 1b :3 0 ab
:3 0 1daa 1dab 0
1124 1da9 1dad 86
:4 0 1126 1da8 1db0
1129 1da7 1db2 :3 0
80 :2 0 da :4 0
112c 1db4 1db6 :3 0
80 :2 0 83 :4 0
112f 1db8 1dba :3 0
80 :2 0 3 :3 0
1132 1dbc 1dbe :3 0
80 :2 0 83 :4 0
1135 1dc0 1dc2 :3 0
1138 1d98 1dc4 :2 0
1dc6 113b 1dc7 1d95
1dc6 0 1dc8 113d
0 1dd3 9a :3 0
197 :3 0 1dc9 1dca
0 1b :3 0 ab
:3 0 1dcc 1dcd 0
3 :3 0 9c :3 0
113f 1dcb 1dd1 :2 0
1dd3 1143 1e74 1b
:3 0 198 :2 0 4
1dd4 1dd5 0 78
:3 0 79 :3 0 1dd7
1dd8 0 78 :3 0
88 :3 0 1dda 1ddb
0 25 :2 0 2
:4 0 199 :2 0 8a
:2 0 49 :2 0 1159
1de0 1de2 :3 0 115c
1ddc 1de4 1dd9 1de6
1de5 :2 0 7b :3 0
8b :3 0 1de8 1de9
0 7d :4 0 19a
:4 0 80 :2 0 81
:3 0 1160 1ded 1def
:3 0 1163 1dea 1df1
:2 0 1e0a 7b :3 0
8b :3 0 1df3 1df4
0 7d :4 0 19b
:4 0 80 :2 0 1b
:3 0 19c :3 0 1df9
1dfa 0 1166 1df8
1dfc :3 0 80 :2 0
da :4 0 1169 1dfe
1e00 :3 0 80 :2 0
1b :3 0 19d :3 0
1e03 1e04 0 116c
1e02 1e06 :3 0 116f
1df5 1e08 :2 0 1e0a
1172 1e0b 1de7 1e0a
0 1e0c 1175 0
1e1c 123 :3 0 77
:3 0 1b :3 0 19c
:3 0 19e :3 0 1b
:3 0 19d :3 0 3
:3 0 ba :4 0 19f
1 :a 0 1e18 :2 0
1e1c 1e0e 1e16 :2 0
1a :3 0 77 :3 0
1e1a :2 0 1e1c 1177
1e1e 117b 1e1d 1e1c
:2 0 1e72 ae :3 0
1b :3 0 ab :3 0
1e21 1e22 0 ac
:3 0 1e23 1e24 0
1e6a 78 :3 0 79
:3 0 1e26 1e27 0
78 :3 0 88 :3 0
1e29 1e2a 0 25
:2 0 2 :4 0 1a0
:2 0 8a :2 0 49
:2 0 117d 1e2f 1e31
:3 0 1180 1e2b 1e33
1e28 1e35 1e34 :2 0
7b :3 0 8b :3 0
1e37 1e38 0 7d
:4 0 1a1 :4 0 80
:2 0 81 :3 0 1184
1e3c 1e3e :3 0 1187
1e39 1e40 :2 0 1e5a
7b :3 0 8b :3 0
1e42 1e43 0 7d
:4 0 b1 :4 0 80
:2 0 ac :3 0 118a
1e47 1e49 :3 0 80
:2 0 b2 :4 0 118d
1e4b 1e4d :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 1190 1e50 1e54
1194 1e4f 1e56 :3 0
1197 1e44 1e58 :2 0
1e5a 119a 1e5b 1e36
1e5a 0 1e5c 119d
0 1e6a 123 :3 0
77 :3 0 19e :3 0
1b :3 0 19d :3 0
3 :3 0 ba :4 0
1a2 1 :a 0 1e66
:2 0 1e6a 1e5e 1e64
:2 0 1a :3 0 77
:3 0 1e68 :2 0 1e6a
119f 1e6d :3 0 1e6d
0 1e6d 1e6c 1e6a
1e6b :6 0 1e6f 1
:3 0 11a4 1e71 11a6
1e70 1e6f :2 0 1e72
11a8 :2 0 1e74 11ab
1e74 1e73 1dd3 1e72
:6 0 1e75 :2 0 2
5c 1e74 1e78 :3 0
1e77 1e75 1e79 :8 0

11e8
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 1
47 1 4b 1
4f 1 53 15
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 4a 4e 52
56 1 60 1
5e 1 67 1
65 1 6e 1
6c 1 75 1
73 1 7c 1
7a 1 83 1
81 1 8a 1
88 1 91 1
8f 1 98 1
96 1 9f 1
9d 1 a6 1
a4 1 ad 1
ab 1 b4 1
b2 1 bb 1
b9 1 c0 1
c6 1 cc 1
d2 1 d8 1
de 1 e4 1
ea 1 f0 1
f6 1 fc 1
102 1 108 1
10e 1 114 1
11a 1 120 1
125 1 12c 1
12a 1 133 1
131 1 13a 1
138 1 13f 1
144 1 149 1
14e 1 153 1
158 1 15f 1
15d 1 164 1
16a 1 170 1
176 1 17c 1
182 1 188 1
18e 1 193 1
198 1 19e 1
1a4 1 1aa 1
1b0 1 1b6 1
1cf 1 1e4 1
1ea 1 1f7 1
203 2 206 208
2 20b 20d 2
20f 211 2 213
215 2 217 219
1 21f 2 221
222 2 21b 224
2 226 228 2
22a 22c 2 22e
230 2 232 234
2 236 238 2
23a 23c 2 23e
240 2 242 244
2 246 248 2
24a 24c 2 24e
250 2 252 254
2 256 258 1
25e 2 260 261
2 25a 263 2
265 267 2 269
26b 2 26d 26f
2 271 273 2
275 277 1 27d
2 27f 280 2
279 282 2 284
286 1 28c 2
28e 28f 2 288
291 2 293 295
1 29b 2 29d
29e 2 297 2a0
2 2a2 2a4 1
2aa 2 2ac 2ad
2 2a6 2af 2
2b1 2b3 1 2b9
2 2bb 2bc 2
2b5 2be 2 2c0
2c2 1 2c8 2
2ca 2cb 2 2c4
2cd 2 2cf 2d1
2 2d3 2d5 2
2d7 2d9 2 2db
2dd 2 2df 2e1
2 2e3 2e5 2
2e7 2e9 2 2eb
2ed 2 2ef 2f1
1 2f7 2 2f9
2fa 2 2f3 2fc
2 2fe 300 1
306 2 308 309
2 302 30b 2
30d 30f 2 311
313 2 315 317
2 319 31b 2
31d 31f 2 321
323 2 325 327
2 329 32b 2
32d 32f 1 335
2 337 338 2
331 33a 2 33c
33e 2 340 342
2 344 346 2
348 34a 2 34c
34e 4 1ff 205
20a 350 1 352
1 354 2 35e
360 3 35c 35d
362 2 36b 36d
2 36a 36f 1
371 1 373 1
375 2 37c 37d
1 381 2 37f
381 2 386 387
1 38b 2 389
38b 2 39c 39e
3 39a 39b 3a0
2 3a9 3ab 2
3ad 3af 2 3b1
3b3 1 3bb 2
3bd 3be 2 3b5
3c0 2 3a8 3c2
1 3c4 1 3c6
2 3d0 3d2 3
3ce 3cf 3d4 2
3dd 3df 2 3dc
3e1 1 3e3 1
3e5 2 3ec 3ed
3 3c7 3e6 3ef
1 3f1 1 3f3
1 3f9 1 401
2 411 413 3
40f 410 415 2
41e 420 2 422
424 2 426 428
1 430 2 432
433 2 42a 435
2 41d 437 1
439 1 43b 2
445 447 3 443
444 449 2 452
454 2 451 456
1 458 1 45a
2 461 462 3
43c 45b 464 1
466 1 494 2
496 497 1 49d
2 499 49d 2
4a1 4a2 1 4a6
2 4a4 4a6 2
4ab 4ac 1 4b0
2 4ae 4b0 1
4b6 2 4c3 4c5
3 4c1 4c2 4c7
2 4d0 4d2 2
4d4 4d6 2 4d8
4da 1 4e2 2
4e4 4e5 2 4dc
4e7 2 4cf 4e9
1 4eb 1 4ed
2 4f7 4f9 3
4f5 4f6 4fb 2
504 506 2 503
508 1 50a 1
50c 2 513 514
3 4ee 50d 516
1 518 2 52a
52f 1 536 1
531 2 549 54b
3 547 548 54d
2 556 558 2
55a 55c 2 55e
560 2 562 564
2 566 568 3
56d 56e 56f 2
56a 571 2 555
573 1 575 1
577 2 540 578
1 57c 1 53b
2 539 580 2
58d 58e 1 590
6 596 597 598
599 59a 59b 2
5a0 5a1 1 5a5
2 5a3 5a5 2
5a9 5aa 1 5ae
2 5ac 5ae 2
5b5 5b6 1 5ba
2 5b8 5ba 2
5c1 5c2 1 5c6
2 5c4 5c6 2
5d7 5dc 1 5e3
1 5de 2 5f6
5f8 3 5f4 5f5
5fa 2 603 605
2 607 609 2
60b 60d 2 60f
611 2 613 615
3 61a 61b 61c
2 617 61e 2
602 620 1 622
1 624 2 5ed
625 1 629 1
5e8 2 5e6 62d
2 633 634 1
638 2 636 638
1 644 2 64f
654 1 65b 1
656 2 66e 670
3 66c 66d 672
2 67b 67d 2
67f 681 2 683
685 2 687 689
2 68b 68d 3
692 693 694 2
68f 696 2 67a
698 1 69a 1
69c 2 665 69d
1 6a1 1 660
2 65e 6a5 1
6a8 1 6ab 4
63d 640 643 6ac
1 6ae 3 5ce
630 6af 1 6b1
2 6b4 6b5 1
6b9 2 6b7 6b9
2 6bf 6c0 1
6c2 1 6c7 2
6c5 6c7 1 6ce
1 6d0 a 519
51c 51f 522 583
589 593 59e 6b2
6d1 2 6ed 6f2
1 6f9 1 6f4
2 70c 70e 3
70a 70b 710 2
719 71b 2 71d
71f 2 721 723
2 725 727 2
729 72b 3 730
731 732 2 72d
734 2 718 736
1 738 1 73a
2 703 73b 1
73f 1 6fe 2
6fc 743 1 74e
2 74a 74e 2
753 754 2 759
75a 1 75c 2
756 75c 2 76a
76c 3 768 769
76e 2 777 779
2 77b 77d 2
77f 781 1 787
2 789 78a 2
783 78c 2 78e
790 2 792 794
2 796 798 2
79a 79c 2 776
79e 1 7a0 1
7a2 2 7ac 7ae
3 7aa 7ab 7b0
2 7b9 7bb 2
7b8 7bd 1 7bf
1 7c1 3 7c6
7c7 7c8 3 7a3
7c2 7ca 1 7cc
3 6d5 746 7cd
2 7cf 7d0 2
7d3 7d4 1 7d8
2 7d6 7d8 1
7df 2 7dd 7df
2 7ea 7ec 3
7e8 7e9 7ee 2
7f7 7f9 2 7fb
7fd 2 7ff 801
1 809 2 80b
80c 2 803 80e
2 810 812 2
814 816 2 818
81a 2 81c 81e
2 7f6 820 1
822 1 824 2
82e 830 3 82c
82d 832 2 83b
83d 2 83a 83f
1 841 1 843
3 84a 84b 84c
3 825 844 84e
1 850 1 852
1 857 1 85e
1 865 2 874
876 3 872 873
878 2 881 883
2 885 887 2
889 88b 1 893
2 895 896 2
88d 898 2 880
89a 1 89c 1
89e 2 8a8 8aa
3 8a6 8a7 8ac
2 8b5 8b7 2
8b4 8b9 1 8bb
1 8bd 2 8c4
8c5 3 89f 8be
8c7 1 8c9 2
8d1 8d2 1 8d6
2 8d4 8d6 1
8db 1 8dd 2
8e5 8ea 1 8f1
1 8ec 2 904
906 3 902 903
908 2 911 913
2 915 917 2
919 91b 2 91d
91f 2 921 923
3 928 929 92a
2 925 92c 2
910 92e 1 930
1 932 2 8fb
933 1 937 1
8f6 2 8f4 93b
2 941 942 1
946 2 944 946
1 94d 2 94f
950 1 956 2
958 959 2 952
95b 2 95e 960
2 963 965 1
967 2 96c 96d
2 972 973 1
975 2 96f 975
2 97a 97d 1
981 2 983 984
2 96a 985 1
987 2 98e 98f
2 991 992 1
997 2 995 997
2 99b 99c 1
9a0 2 99e 9a0
2 9a4 9a5 1
9a9 2 9a7 9a9
11 9b0 9b1 9b2
9b3 9b4 9b5 9b6
9b7 9b8 9b9 9ba
9bb 9bc 9bd 9be
9bf 9c0 1 9c8
2 9c6 9c8 1
9dd 2 9dc 9dd
1 9e5 1 9eb
2 9ed 9ee 2
9da 9ef 1 9f6
1 9f1 2 a09
a0b 3 a07 a08
a0d 2 a16 a18
2 a1a a1c 2
a1e a20 2 a22
a24 2 a26 a28
3 a2d a2e a2f
2 a2a a31 2
a15 a33 1 a35
1 a37 2 a00
a38 1 a3c 1
9fb 2 9f9 a40
1 a43 1 a46
2 9c3 a47 11
a4d a4e a4f a50
a51 a52 a53 a54
a55 a56 a57 a58
a59 a5a a5b a5c
a5d 1 a60 2
a62 a63 1 a64
2 a68 a69 2
a6b a6d 2 a72
a73 1 a77 2
a75 a77 11 a7e
a7f a80 a81 a82
a83 a84 a85 a86
a87 a88 a89 a8a
a8b a8c a8d a8e
1 a96 2 a94
a96 1 aa7 2
aa6 aa7 1 aaf
1 ab5 2 ab7
ab8 2 aa4 ab9
1 ac0 1 abb
2 ad3 ad5 3
ad1 ad2 ad7 2
ae0 ae2 2 ae4
ae6 2 ae8 aea
2 aec aee 2
af0 af2 3 af7
af8 af9 2 af4
afb 2 adf afd
1 aff 1 b01
2 aca b02 1
b06 1 ac5 2
ac3 b0a 1 b0d
1 b10 2 a91
b11 11 b17 b18
b19 b1a b1b b1c
b1d b1e b1f b20
b21 b22 b23 b24
b25 b26 b27 1
b2a 2 b2c b2d
2 a70 b2e 2
b30 b31 1 b37
2 b35 b37 2
b3d b3e 2 b40
b41 1 b46 2
b44 b46 2 b4d
b4e 2 b53 b54
1 b56 2 b50
b56 2 b5b b5c
1 b60 2 b5e
b60 2 b67 b68
1 b6c 2 b6a
b6c 1 b8c 2
b8b b8c 1 b94
1 b9a 2 b9c
b9d 2 b89 b9e
1 ba5 1 ba0
2 bb8 bba 3
bb6 bb7 bbc 2
bc5 bc7 2 bc9
bcb 2 bcd bcf
2 bd1 bd3 2
bd5 bd7 3 bdc
bdd bde 2 bd9
be0 2 bc4 be2
1 be4 1 be6
2 baf be7 1
beb 1 baa 2
ba8 bef 1 bff
2 bfe bff 1
c07 1 c0d 2
c0f c10 2 bfc
c11 1 c18 1
c13 2 c2b c2d
3 c29 c2a c2f
2 c38 c3a 2
c3c c3e 2 c40
c42 2 c44 c46
2 c48 c4a 3
c4f c50 c51 2
c4c c53 2 c37
c55 1 c57 1
c59 2 c22 c5a
1 c5e 1 c1d
2 c1b c62 1
c6f 2 c6e c6f
1 c77 1 c7d
2 c7f c80 2
c6c c81 1 c88
1 c83 2 c9b
c9d 3 c99 c9a
c9f 2 ca8 caa
2 cac cae 2
cb0 cb2 2 cb4
cb6 2 cb8 cba
3 cbf cc0 cc1
2 cbc cc3 2
ca7 cc5 1 cc7
1 cc9 2 c92
cca 1 cce 1
c8d 2 c8b cd2
3 bf2 c65 cd5
1 ce6 2 ce5
ce6 1 cee 1
cf4 2 cf6 cf7
2 ce3 cf8 1
cff 1 cfa 2
d12 d14 3 d10
d11 d16 2 d1f
d21 2 d23 d25
2 d27 d29 2
d2b d2d 2 d2f
d31 3 d36 d37
d38 2 d33 d3a
2 d1e d3c 1
d3e 1 d40 2
d09 d41 1 d45
1 d04 2 d02
d49 1 d4c 2
d4f d50 1 d51
1 d53 2 b32
d54 2 d59 d5a
2 d5c d5f 2
d64 d65 1 d69
2 d67 d69 11
d70 d71 d72 d73
d74 d75 d76 d77
d78 d79 d7a d7b
d7c d7d d7e d7f
d80 1 d88 2
d86 d88 2 d8d
d8e 1 d92 2
d90 d92 2 d99
d9a 1 d9e 2
d9c d9e 1 db6
2 db5 db6 1
dbe 1 dc4 2
dc6 dc7 2 db3
dc8 1 dcf 1
dca 2 de2 de4
3 de0 de1 de6
2 def df1 2
df3 df5 2 df7
df9 2 dfb dfd
2 dff e01 3
e06 e07 e08 2
e03 e0a 2 dee
e0c 1 e0e 1
e10 2 dd9 e11
1 e15 1 dd4
2 dd2 e19 1
e1c 1 e1f 2
d83 e20 1 e22
2 e34 e39 1
e40 1 e3b 2
e53 e55 3 e51
e52 e57 2 e60
e62 2 e64 e66
2 e68 e6a 2
e6c e6e 2 e70
e72 3 e77 e78
e79 2 e74 e7b
2 e5f e7d 1
e7f 1 e81 2
e4a e82 1 e86
1 e45 2 e43
e8a 3 e92 e93
e94 1 e98 2
e96 e98 2 ea7
eac 1 eb3 1
eae 2 ec6 ec8
3 ec4 ec5 eca
2 ed3 ed5 2
ed7 ed9 2 edb
edd 2 edf ee1
2 ee3 ee5 3
eea eeb eec 2
ee7 eee 2 ed2
ef0 1 ef2 1
ef4 2 ebd ef5
1 ef9 1 eb8
2 eb6 efd 6
f04 f05 f06 f07
f08 f09 2 f0e
f0f 1 f13 2
f11 f13 2 f2b
f2c 1 f37 1
f3d 2 f3f f40
2 f44 f4a 1
f51 1 f4c 2
f64 f66 3 f62
f63 f68 2 f71
f73 2 f75 f77
2 f79 f7b 2
f7d f7f 2 f81
f83 3 f88 f89
f8a 2 f85 f8c
2 f70 f8e 1
f90 1 f92 2
f5b f93 1 f97
1 f56 2 f54
f9b 2 fa5 faa
1 fb1 1 fac
2 fc4 fc6 3
fc2 fc3 fc8 2
fd1 fd3 2 fd5
fd7 2 fd9 fdb
2 fdd fdf 2
fe1 fe3 3 fe8
fe9 fea 2 fe5
fec 2 fd0 fee
1 ff0 1 ff2
2 fbb ff3 1
ff7 1 fb6 2
fb4 ffb 2 1008
100a 3 100c 100d
100e 2 1014 1016
3 1018 1019 101a
2 1020 1022 3
1024 1025 1026 2
102c 102e 3 1030
1031 1032 f 1038
1039 103a 103b 103c
103d 103e 103f 1040
1041 1042 1043 1044
1045 1046 2 1052
1054 3 1050 1051
1056 2 105f 1061
2 1063 1065 2
1067 1069 1 106f
2 1071 1072 2
106b 1074 2 1076
1078 2 107a 107c
2 107e 1080 2
1082 1084 2 105e
1086 1 1088 1
108a 2 1094 1096
3 1092 1093 1098
2 10a1 10a3 2
10a0 10a5 1 10a7
1 10a9 3 10ae
10af 10b0 14 f18
f1b f1e f21 f24
f27 f2d f41 f9e
ffe 1002 1005 1011
101d 1029 1035 1049
108b 10aa 10b2 1
10b4 5 e9f ea2
f00 f0c 10b5 1
10b7 3 e29 e8d
10b8 1 10ba 2
10be 10bf 2 10c1
10c3 11 10cb 10cc
10cd 10ce 10cf 10d0
10d1 10d2 10d3 10d4
10d5 10d6 10d7 10d8
10d9 10da 10db 1
10e3 2 10e1 10e3
2 10e8 10e9 1
10ed 2 10eb 10ed
2 10f4 10f5 1
10f9 2 10f7 10f9
1 110d 2 110c
110d 1 1115 1
111b 2 111d 111e
2 110a 111f 1
1126 1 1121 2
1139 113b 3 1137
1138 113d 2 1146
1148 2 114a 114c
2 114e 1150 2
1152 1154 2 1156
1158 3 115d 115e
115f 2 115a 1161
2 1145 1163 1
1165 1 1167 2
1130 1168 1 116c
1 112b 2 1129
1170 1 1173 1
1176 4 10bb 10c6
10de 1177 2 1179
117a 2 d62 117b
2 117d 117e 1
1184 2 1182 1184
2 118f 1191 3
118d 118e 1193 2
119c 119e 2 11a0
11a2 2 11a4 11a6
1 11ae 2 11b0
11b1 2 11a8 11b3
2 11b5 11b7 2
11b9 11bb 2 11bd
11bf 2 11c1 11c3
2 119b 11c5 1
11c7 1 11c9 2
11d3 11d5 3 11d1
11d2 11d7 2 11e0
11e2 2 11df 11e4
1 11e6 1 11e8
3 11ef 11f0 11f1
3 11ca 11e9 11f3
1 11f5 2 11fb
11fc 1 1200 2
11fe 1200 2 1205
1206 1 120a 2
1208 120a 1 1212
1 1214 2 1217
1218 1 121c 2
121a 121c 2 1221
1222 2 1224 1225
1 122a 2 1228
122a 1 122d 1
1232 1 124f 2
124e 124f 1 1257
1 125d 2 125f
1260 2 124c 1261
1 1268 1 1263
2 127b 127d 3
1279 127a 127f 2
1288 128a 2 128c
128e 2 1290 1292
2 1294 1296 2
1298 129a 3 129f
12a0 12a1 2 129c
12a3 2 1287 12a5
1 12a7 1 12a9
2 1272 12aa 1
12ae 1 126d 2
126b 12b2 1 12b5
1 12c4 2 12c3
12c4 1 12cc 1
12d2 2 12d4 12d5
2 12c1 12d6 1
12dd 1 12d8 2
12f0 12f2 3 12ee
12ef 12f4 2 12fd
12ff 2 1301 1303
2 1305 1307 2
1309 130b 2 130d
130f 3 1314 1315
1316 2 1311 1318
2 12fc 131a 1
131c 1 131e 2
12e7 131f 1 1323
1 12e2 2 12e0
1327 1 132a 2
132d 132e 1 132f
1 1331 1 1379
2 1378 1379 1
1381 1 1387 2
1389 138a 2 1376
138b 1 1392 1
138d 2 13a5 13a7
3 13a3 13a4 13a9
2 13b2 13b4 2
13b6 13b8 2 13ba
13bc 2 13be 13c0
2 13c2 13c4 3
13c9 13ca 13cb 2
13c6 13cd 2 13b1
13cf 1 13d1 1
13d3 2 139c 13d4
1 13d8 1 1397
2 1395 13dc 1
13df 1 1419 2
1418 1419 1 1421
1 1427 2 1429
142a 2 1416 142b
1 1432 1 142d
2 1445 1447 3
1443 1444 1449 2
1452 1454 2 1456
1458 2 145a 145c
2 145e 1460 2
1462 1464 3 1469
146a 146b 2 1466
146d 2 1451 146f
1 1471 1 1473
2 143c 1474 1
1478 1 1437 2
1435 147c 1 147f
2 1482 1483 1
1484 2 1486 1487
1 1488 2 148c
148d 1 1491 2
148f 1491 1 14a0
2 149f 14a0 1
14a8 1 14ae 2
14b0 14b1 2 149d
14b2 1 14b9 1
14b4 2 14cc 14ce
3 14ca 14cb 14d0
2 14d9 14db 2
14dd 14df 2 14e1
14e3 2 14e5 14e7
2 14e9 14eb 3
14f0 14f1 14f2 2
14ed 14f4 2 14d8
14f6 1 14f8 1
14fa 2 14c3 14fb
1 14ff 1 14be
2 14bc 1503 1
1506 2 150a 1509
1 150b 2 150f
1510 2 1512 1513
1 1518 2 1516
1518 1 151b 1
1520 1 153d 2
153c 153d 1 1545
1 154b 2 154d
154e 2 153a 154f
1 1556 1 1551
2 1569 156b 3
1567 1568 156d 2
1576 1578 2 157a
157c 2 157e 1580
2 1582 1584 2
1586 1588 3 158d
158e 158f 2 158a
1591 2 1575 1593
1 1595 1 1597
2 1560 1598 1
159c 1 155b 2
1559 15a0 1 15a3
1 15b4 2 15b3
15b4 1 15bc 1
15c2 2 15c4 15c5
2 15b1 15c6 1
15cd 1 15c8 2
15e0 15e2 3 15de
15df 15e4 2 15ed
15ef 2 15f1 15f3
2 15f5 15f7 2
15f9 15fb 2 15fd
15ff 3 1604 1605
1606 2 1601 1608
2 15ec 160a 1
160c 1 160e 2
15d7 160f 1 1613
1 15d2 2 15d0
1617 1 161a 2
161d 161e 1 161f
1 1621 1 1669
2 1668 1669 1
1671 1 1677 2
1679 167a 2 1666
167b 1 1682 1
167d 2 1695 1697
3 1693 1694 1699
2 16a2 16a4 2
16a6 16a8 2 16aa
16ac 2 16ae 16b0
2 16b2 16b4 3
16b9 16ba 16bb 2
16b6 16bd 2 16a1
16bf 1 16c1 1
16c3 2 168c 16c4
1 16c8 1 1687
2 1685 16cc 1
16cf 1 170b 2
170a 170b 1 1713
1 1719 2 171b
171c 2 1708 171d
1 1724 1 171f
2 1737 1739 3
1735 1736 173b 2
1744 1746 2 1748
174a 2 174c 174e
2 1750 1752 2
1754 1756 3 175b
175c 175d 2 1758
175f 2 1743 1761
1 1763 1 1765
2 172e 1766 1
176a 1 1729 2
1727 176e 1 1771
2 1774 1775 1
1776 2 1778 1779
1 177a 2 177e
177f 1 1783 2
1781 1783 1 1786
2 178c 178d 1
1791 2 178f 1791
1 17a5 2 17a4
17a5 1 17ad 1
17b3 2 17b5 17b6
2 17a2 17b7 1
17be 1 17b9 2
17d1 17d3 3 17cf
17d0 17d5 2 17de
17e0 2 17e2 17e4
2 17e6 17e8 2
17ea 17ec 2 17ee
17f0 3 17f5 17f6
17f7 2 17f2 17f9
2 17dd 17fb 1
17fd 1 17ff 2
17c8 1800 1 1804
1 17c3 2 17c1
1808 1 180b 1
181c 2 181b 181c
1 1824 1 182a
2 182c 182d 2
1819 182e 1 1835
1 1830 2 1848
184a 3 1846 1847
184c 2 1855 1857
2 1859 185b 2
185d 185f 2 1861
1863 2 1865 1867
3 186c 186d 186e
2 1869 1870 2
1854 1872 1 1874
1 1876 2 183f
1877 1 187b 1
183a 2 1838 187f
1 1882 2 1885
1886 1 1887 1
1897 2 1896 1897
1 189f 1 18a5
2 18a7 18a8 2
1894 18a9 1 18b0
1 18ab 2 18c3
18c5 3 18c1 18c2
18c7 2 18d0 18d2
2 18d4 18d6 2
18d8 18da 2 18dc
18de 2 18e0 18e2
3 18e7 18e8 18e9
2 18e4 18eb 2
18cf 18ed 1 18ef
1 18f1 2 18ba
18f2 1 18f6 1
18b5 2 18b3 18fa
1 18fd 2 1900
1901 1 1902 2
1905 1904 1 1906
2 1908 1909 1
190b 2 1911 1912
1 1916 2 1914
1916 2 191e 191f
1 1923 2 1921
1923 2 1936 1937
1 193b 2 1939
193b 2 1957 195c
1 1963 1 195e
2 1976 1978 3
1974 1975 197a 2
1983 1985 2 1987
1989 2 198b 198d
2 198f 1991 2
1993 1995 3 199a
199b 199c 2 1997
199e 2 1982 19a0
1 19a2 1 19a4
2 196d 19a5 1
19a9 1 1968 2
1966 19ad 1 19b0
2 19cd 19d2 1
19d9 1 19d4 2
19ec 19ee 3 19ea
19eb 19f0 2 19f9
19fb 2 19fd 19ff
2 1a01 1a03 2
1a05 1a07 2 1a09
1a0b 3 1a10 1a11
1a12 2 1a0d 1a14
2 19f8 1a16 1
1a18 1 1a1a 2
19e3 1a1b 1 1a1f
1 19de 2 19dc
1a23 2 19b5 1a26
2 1a29 1a2a 1
1a32 2 1a2e 1a32
2 1a37 1a38 2
1a3d 1a3e 1 1a40
2 1a3a 1a40 2
1a45 1a46 1 1a4a
2 1a48 1a4a 2
1a51 1a52 1 1a56
2 1a54 1a56 1
1a67 2 1a66 1a67
1 1a6f 1 1a75
2 1a77 1a78 2
1a64 1a79 1 1a80
1 1a7b 2 1a93
1a95 3 1a91 1a92
1a97 2 1aa0 1aa2
2 1aa4 1aa6 2
1aa8 1aaa 2 1aac
1aae 2 1ab0 1ab2
3 1ab7 1ab8 1ab9
2 1ab4 1abb 2
1a9f 1abd 1 1abf
1 1ac1 2 1a8a
1ac2 1 1ac6 1
1a85 2 1a83 1aca
1 1adf 2 1ade
1adf 1 1ae7 1
1aed 2 1aef 1af0
2 1adc 1af1 1
1af8 1 1af3 2
1b0b 1b0d 3 1b09
1b0a 1b0f 2 1b18
1b1a 2 1b1c 1b1e
2 1b20 1b22 2
1b24 1b26 2 1b28
1b2a 3 1b2f 1b30
1b31 2 1b2c 1b33
2 1b17 1b35 1
1b37 1 1b39 2
1b02 1b3a 1 1b3e
1 1afd 2 1afb
1b42 2 1acd 1b45
3 1b4f 1b50 1b51
1 1b5c 1 1b62
2 1b64 1b65 1
1b6b 2 1b69 1b6b
1 1b6f 1 1b71
2 1b75 1b76 2
1b7b 1b7c 2 1b78
1b7e 2 1b83 1b84
1 1b88 2 1b86
1b88 2 1b8c 1b8d
2 1b92 1b93 1
1b95 2 1b8f 1b95
2 1b99 1b9a 2
1b9f 1ba0 1 1ba2
2 1b9c 1ba2 2
1ba7 1ba8 1 1bab
2 1baf 1bb0 2
1bb5 1bb6 2 1bb2
1bb8 2 1bbd 1bbe
2 1bba 1bc0 1
1bc3 2 1bc5 1bc6
1 1bc7 1 1bc9
1 1bd3 2 1bd2
1bd3 1 1bdb 1
1be1 2 1be3 1be4
2 1bd0 1be5 1
1bec 1 1be7 2
1bff 1c01 3 1bfd
1bfe 1c03 2 1c0c
1c0e 2 1c10 1c12
2 1c14 1c16 2
1c18 1c1a 2 1c1c
1c1e 3 1c23 1c24
1c25 2 1c20 1c27
2 1c0b 1c29 1
1c2b 1 1c2d 2
1bf6 1c2e 1 1c32
1 1bf1 2 1bef
1c36 3 1bca 1c39
1c3d 1 1c3f 2
1c42 1c43 2 1c48
1c49 1 1c4b 2
1c45 1c4b 1 1c4f
1 1c51 6 1b52
1b66 1b72 1b81 1c40
1c52 2 1c58 1c5e
1 1c65 1 1c60
2 1c78 1c7a 3
1c76 1c77 1c7c 2
1c85 1c87 2 1c89
1c8b 2 1c8d 1c8f
2 1c91 1c93 2
1c95 1c97 3 1c9c
1c9d 1c9e 2 1c99
1ca0 2 1c84 1ca2
1 1ca4 1 1ca6
2 1c6f 1ca7 1
1cab 1 1c6a 2
1c68 1caf 2 1cb5
1cb6 1 1cba 2
1cb8 1cba 1 1cbe
1 1cce 2 1ccd
1cce 1 1cd6 1
1cdc 2 1cde 1cdf
2 1ccb 1ce0 1
1ce7 1 1ce2 2
1cfa 1cfc 3 1cf8
1cf9 1cfe 2 1d07
1d09 2 1d0b 1d0d
2 1d0f 1d11 2
1d13 1d15 2 1d17
1d19 3 1d1e 1d1f
1d20 2 1d1b 1d22
2 1d06 1d24 1
1d26 1 1d28 2
1cf1 1d29 1 1d2d
1 1cec 2 1cea
1d31 1 1d34 1
1d37 4 1b4a 1c55
1cb2 1d38 2 1d3a
1d3b 2 1d3e 1d3f
1 1d43 2 1d41
1d43 2 1d48 1d49
2 1d4b 1d4c 1
1d51 2 1d4f 1d51
2 1d56 1d57 1
1d5a 2 1d5e 1d5f
1 1d62 2 1d64
1d65 1 1d66 1
1d68 2 1d3c 1d69
1 1d6b 6 192b
192e 1931 1934 1a2b
1d6c 1 1d6e d
851 8ca 8cf 8de
93e 988 98b 117f
11f6 11f9 1215 190a
1d6f 1 1d71 1
1d77 2 1d75 1d77
1 1d7e 1 1d80
3 7d1 1d72 1d81
1 1d83 2 1d8d
1d8f 3 1d8b 1d8c
1d91 2 1d9a 1d9c
2 1d9e 1da0 2
1da2 1da4 1 1dac
2 1dae 1daf 2
1da6 1db1 2 1db3
1db5 2 1db7 1db9
2 1dbb 1dbd 2
1dbf 1dc1 2 1d99
1dc3 1 1dc5 1
1dc7 3 1dce 1dcf
1dd0 15 355 374
3f2 467 46a 46d
470 473 476 479
47c 47f 482 485
488 48b 48e 491
1d84 1dc8 1dd2 2
1ddf 1de1 3 1ddd
1dde 1de3 2 1dec
1dee 2 1deb 1df0
2 1df7 1dfb 2
1dfd 1dff 2 1e01
1e05 2 1df6 1e07
2 1df2 1e09 1
1e0b 3 1e0c 1e17
1e1b 1 1dd6 2
1e2e 1e30 3 1e2c
1e2d 1e32 2 1e3b
1e3d 2 1e3a 1e3f
2 1e46 1e48 2
1e4a 1e4c 3 1e51
1e52 1e53 2 1e4e
1e55 2 1e45 1e57
2 1e41 1e59 1
1e5b 4 1e25 1e5c
1e65 1e69 1 1e6d
1 1e20 2 1e1e
1e71 3c 63 6a
71 78 7f 86
8d 94 9b a2
a9 b0 b7 be
c4 ca d0 d6
dc e2 e8 ee
f4 fa 100 106
10c 112 118 11e
123 128 12f 136
13d 142 147 14c
151 156 15b 162
168 16e 174 17a
180 186 18c 191
196 19c 1a2 1a8
1ae 1b4 1ba 1d0
1e5 1ef 
1
4
0 
1e78
0
1
50
4d
52
0 1 1 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 1 36 1
38 1 3a 1 3c 1 3e 1
40 1 42 1 44 1 46 47
1 49 1 4b 1 0 0 0

d2 1 0
53 1 0
1bd 1 2
3b 1 0
23 1 0
13 1 0
7a 1 0
a4 1 0
16a 1 0
182 1 0
43 1 0
f6 1 0
3 1 0
12a 1 0
1b0 1 0
131 1 0
188 1 0
2f 1 0
102 1 0
19e 1 0
88 1 0
114 1 0
37 1 0
120 1 0
170 1 0
10e 1 0
c0 1 0
81 1 0
1b6 1 0
17c 1 0
1f 1 0
2 0 1
144 1 0
fc 1 0
e4 1 0
f 1 0
13f 1 0
4b 1 0
17 1 0
8f 1 0
176 1 0
158 1 0
1a4 1 0
96 1 0
5e 1 0
153 1 0
47 1 0
b 1 0
cc 1 0
27 1 0
193 1 0
14e 1 0
7 1 0
108 1 0
73 1 0
1aa 1 0
1d6 1 3
2b 1 0
b2 1 0
149 1 0
11a 1 0
4f 1 0
9d 1 0
ea 1 0
d8 1 0
33 1 0
164 1 0
ab 1 0
f0 1 0
c6 1 0
3f 1 0
198 1 0
18e 1 0
125 1 0
6c 1 0
65 1 0
b9 1 0
1b 1 0
15d 1 0
de 1 0
1ea 1 0
138 1 0
0

/
SHOW ERRORS FUNCTION SP_ASSIGN_MSP;
ALTER FUNCTION SP_ASSIGN_MSP COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_RESTOPROF
#Short Description :Replace a profile with a resource
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_RESTOPROF ==
CREATE OR REPLACE FUNCTION SP_A_RESTOPROF wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
35f
2 :e:
1FUNCTION:
1SP_A_RESTOPROF:
1PRJ_ID:
1VARCHAR2:
1PROFILE_ID001:
1RES_ID001:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_BITID:
1RAW:
136:
1PMO_CNST:
1SC_ZERO_BIT:
1H_ID:
132:
1H_SECURITY_ID:
1H_REC_USER:
1H_ASSIGN_ID:
1H_PRJ_ASSIGN_ID:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_TMP_ASSIGNMENT_ID:
1H_CUR_PRJ_ASSIGN_ID:
1H_TASK_ID:
1H_RES_ID:
1H_PROJECT_ID:
1H_PROFILE_ID:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_BIT_FLAG:
11:
1H_NULL_STR:
1H_DAYOFYEAR:
1DATE:
1H_START_D:
1H_FINISH_D:
1H_RES_TYPE:
1H_RANK:
1200:
1H_START_DT:
1H_FINISH_DT:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_ROLE_ID:
1H_FULL_NAME:
1255:
1H_IN:
1H_PROFILE_NAME:
1H_LABOR_CODE:
150:
1H_RES_AVAILABLE:
10:
1H_PARTICIPANT:
1H_EVERY:
1H_EFFORT:
1H_CRI:
1H_TYPE:
1H_TYPE_ID:
1H_TOTAL:
1H_WORK:
1H_OCCURRENCE:
1H_EUNIT:
1H_UNIT:
1H_CONTOUR:
1H_DURATION:
1H_WORK_TYPE:
1H_PASSED:
1H_ASSIGNED:
1H_REMAINING:
1H_BITFLAG:
1H_PER_DAY:
1H_PER_WEEK:
1H_UPDATE:
1H_CONSIDER:
1H_PRIORITY:
1H_DAYS:
1H_OWNER:
1H_COUNT:
1H_AVAILABLE:
1H_CONTOUR_CHANGED:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_RATE_ECHANGE:
1H_CURRENCY_ID:
1H_DONOT_REPLACE_BITS:
1H_DONOT_REPLACE_RATE:
1H_DONOT_REPLACE_COST:
1H_FROM_PRJ:
1H_SAME_LABOR:
1H_FS_PROJECT:
1H_MINUTES:
1H_TA_EXISTS:
1H_AND_ROLES:
14000:
1H_AND_SKILLS:
1H_TEMP_RES_COST:
1H_TEMP_VAR:
1H_TEMP_RES_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_PA_TIMEPHASE:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_SD:
1H_FD:
1H_OLD_COST:
1H_OLD_SALE:
1H_PA_COUNT:
1H_TA_COUNT:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_TABLE_TYPE:
1H_PLANNED_EFFORT:
1H_TASK_TYPE:
1H_PERCENT_UNITS:
1H_TIMECODE_1_ID:
1H_TIMECODE_2_ID:
1H_OLD_PRJ_ASSIGN_ID:
1I_RETURN:
1I_ISTASK:
1ISWBSTASK:
1COALESCE:
1L_DATA_FLAG:
1I_MANY:
1PA_CONTINUE:
1PA_ASSIGN:
1CURSOR:
1CRCAL1:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1ROWNUM:
1ELEMENT_ID:
1SELECT AVAILABLE_MIN FROM CALENDAR_DAY_OF_YEAR:n         WHERE  ROWNUM <= 1 A+
1ND  ELEMENT_ID = h_res_id:
1CSA1:
1BAK_WORK:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1PROJECT_ASSIGNMENT_ID:
1SELECT BAK_WORK FROM TASK_ASSIGNMENTS:n         WHERE  ROWNUM <= 1 AND  PROJE+
1CT_ID = h_project_id AND RESOURCE_ID = h_res_id AND RESOURCE_TYPE = '0' AND:n+
1         PROJECT_ASSIGNMENT_ID IS NuLL:
1C6A:
1R:
1RES_ASSIGNMENT_ID:
1T:
1TSK_ASSIGNMENT_ID:
1TASK_ID:
1ELEMENT_TYPE:
1PLANNED_WORK:
1UNITS_MSP:
1PLANNED_START:
1TO_DATE:
1SUBSTR:
1PLANNED_FINISH:
1W:
1TASK_TYPE:
1PLANNED_DURATION:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1C_CONTOUR:
1CONTOUR_TYPE:
1TMT_WBS:
1RESOURCE_ASSIGNMENTS:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1RANK:
1SELECT r.RES_ASSIGNMENT_ID, t.TSK_ASSIGNMENT_ID, t.TASK_ID, r.ELEMENT_TYPE, t+
1.PLANNED_WORK, t.UNITS_MSP,:n         t.PLANNED_START, TO_DATE(SubStr(t.PLANN+
1ED_START, 1, 10)), TO_DATE(SubStr(t.PLANNED_FINISH, 1, 10)), w.TASK_TYPE, CAS+
1E WHEN t.PLANNED_DURATION = 0 THEN w.PLANNED_DURATION ELSE t.PLANNED_DURATION+
1 END,:n         t.PROJECT_ASSIGNMENT_ID, t.BILLABLE, t.CAPITAL_EXPENSE, t.REG+
1ULAR_COST, t.REGULAR_RATE,:n         t.C_EFFORT, t.T_UNIT, t.C_UNIT, t.C_CONT+
1OUR, t.CONTOUR_TYPE:n         FROM TMT_WBS w, RESOURCE_ASSIGNMENTS r, TASK_AS+
1SIGNMENTS t:n         WHERE r.PROJECT_ID = h_project_id AND r.RESOURCE_ID = h+
1_profile_id AND r.RESOURCE_TYPE = '1' :n         AND t.RES_ASSIGNMENT_ID = r.+
1RES_ASSIGNMENT_ID AND r.ELEMENT_ID = w.ELEMENT_ID :n         AND r.ELEMENT_TY+
1PE IN (pmo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,pmo_cnst.SC_TASK_TYPE2,pmo_cns+
1t.SC_TASK_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.SC_PERSONAL_TASK,pmo_cnst.SC_A+
1CTIVE_ADM_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pmo_cnst.SC_WBS_CHANGE_REQUEST_T+
1ASK,pmo_cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.SC_WBS_RISK_TASK,pmo_cnst.SC_WB+
1S_ISSUE_TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,pmo_cnst.SC_WBS_DEFECT_TASK,pmo+
1_cnst.SC_WBS_SERVICE_REQUEST_TASK) AND w.RANK LIKE h_rank:n         ORDER BY +
1t.PLANNED_START:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_RESTOPROF(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1171:
1+:
1FPUT:
1               ENTER:: SP_A_RESTOPROF(172) :: cplan.sql(9582) :: :
1BITAND:
1SC_1FFFFFFF:
1=:
1SC_SRCH_PROFILE:
1SC_SRCH_FROM_PROJECT:
14:
1:
1OPEN:
1FOUND:
1SC_STATE:
1100:
1CLOSE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1222:
1           EXCEPTION:: SP_A_RESTOPROF(223) :: cplan.sql(9633) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1229:
1        RETURN_ERROR:: SP_A_RESTOPROF(230) :: cplan.sql(9640) :: :
1STATE:: :
1RECORD_NOT_FOUND:
1 ID:: :
1232:
1                EXIT:: SP_A_RESTOPROF(233) :: cplan.sql(9643) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1TYPE_ID:
1TIMECODE_1_ID:
1TIMECODE_2_ID:
1UNRESOLVED_DURATION:
1SELECT TYPE_ID, RANK, PROJECT_ID, TIMECODE_1_ID, TIMECODE_2_ID, UNRESOLVED_DU+
1RATION:n      INTO h_type_id, h_rank, h_project_id, h_timecode_1_id, h_timeco+
1de_2_id, h_duration:n      FROM TMT_WBS WHERE ELEMENT_ID = h_task_id:
1249:
1           EXCEPTION:: SP_A_RESTOPROF(250) :: cplan.sql(9660) :: :
1SC_SQL_NO_DATA:
1257:
1        RETURN_ERROR:: SP_A_RESTOPROF(258) :: cplan.sql(9668) :: :
1260:
1                EXIT:: SP_A_RESTOPROF(261) :: cplan.sql(9671) :: :
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n      FROM PROJECT_DETAILS:n      WHERE PR+
1OJECT_ID = h_project_id:
1278:
1           EXCEPTION:: SP_A_RESTOPROF(279) :: cplan.sql(9689) :: :
1>:
1285:
1        RETURN_ERROR:: SP_A_RESTOPROF(286) :: cplan.sql(9696) :: :
1LEV_LOCKED_BY_LEVEL:
1288:
1                EXIT:: SP_A_RESTOPROF(289) :: cplan.sql(9699) :: :
1TW:
1FS_CODE:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1CURRENCY_ID:
1PMO_ORASTD:
1TODECIMAL:
1TD:
1ELEMENT_NAME:
1JOIN:
1TMT_DATAFIELDS:
1SELECT tw.TYPE_ID, CASE WHEN tw.FS_CODE IS NuLL THEN 0 ELSE 1 END, COALESCE(t+
1w.MINUTE_PER_DAY, 480), COALESCE(tw.MINUTE_PER_WEEK, 2400), tw.PRIORITY, tw.C+
1URRENCY_ID, PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4):n      INTO h_type, h_+
1fs_project, h_per_day, h_per_week, h_priority, h_currency_id, h_rate_echange+
1:n      FROM TMT_WBS tw JOIN TMT_DATAFIELDS td on tw.CURRENCY_ID = td.ELEMENT+
1_ID WHERE tw.ELEMENT_ID = h_project_id:
1305:
1           EXCEPTION:: SP_A_RESTOPROF(306) :: cplan.sql(9716) :: :
1312:
1        RETURN_ERROR:: SP_A_RESTOPROF(313) :: cplan.sql(9723) :: :
1315:
1                EXIT:: SP_A_RESTOPROF(316) :: cplan.sql(9726) :: :
1NICK_NAME:
1FS_LABOR_CODE:
1RESOURCES:
1SELECT NICK_NAME,FS_LABOR_CODE INTO h_full_name,h_labor_code FROM RESOURCES W+
1HERE RESOURCE_ID = h_res_id:
1330:
1           EXCEPTION:: SP_A_RESTOPROF(331) :: cplan.sql(9741) :: :
1337:
1        RETURN_ERROR:: SP_A_RESTOPROF(338) :: cplan.sql(9748) :: :
1340:
1                EXIT:: SP_A_RESTOPROF(341) :: cplan.sql(9751) :: :
1ROLE_ID:
1PROFILES:
1PROFILE_ID:
1SELECT ROLE_ID INTO h_role_id FROM PROFILES WHERE PROFILE_ID = h_profile_id:
1355:
1           EXCEPTION:: SP_A_RESTOPROF(356) :: cplan.sql(9766) :: :
1STRCMP:
1DEFAULTLEVEL:
1366:
1        RETURN_ERROR:: SP_A_RESTOPROF(367) :: cplan.sql(9777) :: :
1369:
1                EXIT:: SP_A_RESTOPROF(370) :: cplan.sql(9780) :: :
12:
1COUNT:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_ta_count :n      FROM TASK_ASSIGNMENTS+
1:n      WHERE PROJECT_ID = h_project_id AND PROJECT_ID <> TASK_ID AND RESOURC+
1E_ID = h_profile_id AND RESOURCE_TYPE = '1':
1403:
1           EXCEPTION:: SP_A_RESTOPROF(404) :: cplan.sql(9814) :: :
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_pa_count :n      FROM TASK_ASSIGNMENTS+
1:n      WHERE PROJECT_ID = h_project_id AND TASK_ID = h_project_id AND RESOUR+
1CE_ID = h_profile_id AND RESOURCE_TYPE = '1':
1420:
1           EXCEPTION:: SP_A_RESTOPROF(421) :: cplan.sql(9831) :: :
1!=:
1DUAL:
1SELECT COUNT('X') INTO h_ta_exists FROM DUAL WHERE EXISTS (SELECT 'X' FROM TA+
1SK_ASSIGNMENTS  :n            WHERE PROJECT_ID = h_project_id AND TASK_ID = h+
1_project_id AND RESOURCE_ID = h_res_id):
1440:
1           EXCEPTION:: SP_A_RESTOPROF(441) :: cplan.sql(9851) :: :
1NOT:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (SELECT 'X' FROM TAS+
1K_ASSIGNMENTS  :n               WHERE PROJECT_ID = h_project_id AND TASK_ID <+
1> PROJECT_ID AND RESOURCE_ID = h_res_id):
1459:
1           EXCEPTION:: SP_A_RESTOPROF(460) :: cplan.sql(9870) :: :
1466:
1        RETURN_ERROR:: SP_A_RESTOPROF(467) :: cplan.sql(9877) :: :
1CHILD_TASK_ASSIGNMENT_ALREADY_:
1469:
1                EXIT:: SP_A_RESTOPROF(470) :: cplan.sql(9880) :: :
1ELSIF:
1ISPROJECTTYPE:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (SELECT 'X' FROM TAS+
1K_ASSIGNMENTS  :n         WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h+
1_res_id AND RESOURCE_TYPE = '0':n         AND PROJECT_ASSIGNMENT_ID IS NuLL):
1492:
1           EXCEPTION:: SP_A_RESTOPROF(493) :: cplan.sql(9903) :: :
1499:
1        RETURN_ERROR:: SP_A_RESTOPROF(500) :: cplan.sql(9910) :: :
1502:
1                EXIT:: SP_A_RESTOPROF(503) :: cplan.sql(9913) :: :
1SC_SQL_SUCCESS:
1547:
1           EXCEPTION:: SP_A_RESTOPROF(548) :: cplan.sql(9958) :: :
1PARTICIPANT:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_prj_assign_id, h_owner:n      FR+
1OM RESOURCE_ASSIGNMENTS:n      WHERE ELEMENT_ID = h_project_id :n      AND RE+
1SOURCE_TYPE = h_res_type :n      AND RESOURCE_ID = h_res_id:
1572:
1           EXCEPTION:: SP_A_RESTOPROF(573) :: cplan.sql(9983) :: :
1SYS_GUID:
1SECURITY_ID:
1SELECT PARTICIPANT, SECURITY_ID INTO h_owner, h_temp_security_id:n         FR+
1OM RESOURCE_ASSIGNMENTS:n         WHERE ELEMENT_ID = h_project_id :n         +
1AND RESOURCE_TYPE = '1' :n         AND RESOURCE_ID = h_profile_id:
1595:
1           EXCEPTION:: SP_A_RESTOPROF(596) :: cplan.sql(10006) :: :
1PMO_FUNC:
1BIT_OR:
1SC_AFFECTED:
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1FC_BEFORE_I_RES_ASSIGN:
1GETTABLE:
1TABLE_TYPE:
1REC_USER:
1REC_DATETIME:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE,:n         RESOURCE_TYPE, RESOURCE_ID, PROFILE_ID, PARTICIPANT, S+
1ECURITY_ID, TABLE_TYPE,:n         REC_USER, REC_DATETIME):n         VALUES (h+
1_prj_assign_id, h_project_id, h_project_id, h_type,:n         h_res_type, h_r+
1es_id, h_profile_id, h_temp_participant, h_temp_security_id, h_table_type,:n +
1        rec_user001, SYSTIMESTAMP):
1633:
1           EXCEPTION:: SP_A_RESTOPROF(634) :: cplan.sql(10044) :: :
1PROFILE_NAME:
1SELECT PROFILE_NAME INTO h_profile_name FROM PROFILES WHERE PROFILE_ID = h_pr+
1ofile_id:
1648:
1           EXCEPTION:: SP_A_RESTOPROF(649) :: cplan.sql(10059) :: :
1BIT_FLAG:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_total FROM TASK_ASSIGNMENTS:n         +
1   WHERE PROJECT_ID = h_project_id AND TASK_ID <> h_task_id :n            AND+
1 RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1' AND BIT_FLAG = '0':
1668:
1           EXCEPTION:: SP_A_RESTOPROF(669) :: cplan.sql(10079) :: :
1ASSIGN_NAMES:
1REPLACE:
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_profile_name, h_fu+
1ll_name):n            WHERE ELEMENT_ID = h_project_id AND PROJECT_ID = h_proj+
1ect_id:
1691:
1           EXCEPTION:: SP_A_RESTOPROF(692) :: cplan.sql(10102) :: :
1INSTR:
1LENGTH:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n            ELSE:n  +
1          CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) >+
1 2040 THEN ASSIGN_NAMES:n            ELSE ASSIGN_NAMES || h_full_name || ';'+
1:n            END:n            END:n            WHERE PROJECT_ID = h_project_+
1id AND ELEMENT_ID = h_project_id:
1720:
1           EXCEPTION:: SP_A_RESTOPROF(721) :: cplan.sql(10131) :: :
1749:
1           EXCEPTION:: SP_A_RESTOPROF(750) :: cplan.sql(10160) :: :
1SELECT TSK_ASSIGNMENT_ID INTO h_prj_assignment_id  :n         FROM TASK_ASSIG+
1NMENTS:n         WHERE RES_ASSIGNMENT_ID = h_prj_assign_id AND BIT_FLAG = '0':
1769:
1           EXCEPTION:: SP_A_RESTOPROF(770) :: cplan.sql(10180) :: :
1SELECT TSK_ASSIGNMENT_ID INTO h_prj_assignment_id  :n            FROM TASK_AS+
1SIGNMENTS:n            WHERE RES_ASSIGNMENT_ID = h_prj_assign_id AND BIT_FLAG+
1 = '2':
1787:
1           EXCEPTION:: SP_A_RESTOPROF(788) :: cplan.sql(10198) :: :
1SC_PARTICIPANT:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n               PA+
1RTICIPANT = pmo_cnst.SC_AFFECTED, SECURITY_ID = h_temp_security_id:n         +
1      WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1816:
1           EXCEPTION:: SP_A_RESTOPROF(817) :: cplan.sql(10227) :: :
1FC_AFTER_U_RES_ASSIGN:
1PMO_STPU:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n               PA+
1RTICIPANT=PMO_STPU.BIT_OR(PARTICIPANT, pmo_cnst.SC_AFFECTED):n               +
1WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1839:
1           EXCEPTION:: SP_A_RESTOPROF(840) :: cplan.sql(10250) :: :
1SC_TEAMMEMBER:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n               PA+
1RTICIPANT=PMO_STPU.BIT_OR(PARTICIPANT, pmo_cnst.SC_TEAMMEMBER):n             +
1  WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1862:
1           EXCEPTION:: SP_A_RESTOPROF(863) :: cplan.sql(10273) :: :
1RS:
1SELECT CASE WHEN h_currency_id = rs.CURRENCY_ID THEN 1:n      ELSE h_rate_ech+
1ange / PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4) END:n      INTO h_rate_echa+
1nge:n      FROM RESOURCES rs JOIN TMT_DATAFIELDS td ON rs.CURRENCY_ID = td.EL+
1EMENT_ID AND rs.CURRENCY_ID > 0:n      WHERE RESOURCE_ID=h_res_id:
1886:
1           EXCEPTION:: SP_A_RESTOPROF(887) :: cplan.sql(10297) :: :
11.00:
1FC_DECLARE_PMO_TMP_SEARCH:
1FC_GET_RES_RATES:
1*:
1MAX:
1SELECT MAX(AVAILABLE_MIN) INTO h_res_available:n      FROM CALENDAR_DAY_OF_YE+
1AR:n      WHERE ELEMENT_ID = h_res_id:
1930:
1           EXCEPTION:: SP_A_RESTOPROF(931) :: cplan.sql(10341) :: :
1SELECT TSK_ASSIGNMENT_ID, BILLABLE INTO h_old_prj_assign_id, h_billable:n    +
1  FROM TASK_ASSIGNMENTS:n      WHERE PROJECT_ID = h_project_id AND TASK_ID = +
1h_project_id :n      AND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1':
1950:
1           EXCEPTION:: SP_A_RESTOPROF(951) :: cplan.sql(10361) :: :
1ASSIGNMENT_BILLABLE_FLAG:
1TIMEPHASE_PROJECT_ASSIGNMENT:
1SELECT ASSIGNMENT_BILLABLE_FLAG, TIMEPHASE_PROJECT_ASSIGNMENT INTO h_billable+
1, h_pa_timephase:n      FROM PROJECT_DETAILS WHERE PROJECT_ID = h_project_id:
1966:
1           EXCEPTION:: SP_A_RESTOPROF(967) :: cplan.sql(10377) :: :
1IS NOT NULL:
1SELECT RES_ASSIGNMENT_ID,PLANNED_WORK, TO_DATE(SubStr(PLANNED_START, 1, 10)),+
1 TO_DATE(SubStr(PLANNED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n        +
1    REGULAR_COST, REGULAR_RATE, TASK_ID, UNITS_MSP, C_EFFORT, T_UNIT, C_UNIT,+
1 C_CONTOUR:n            INTO h_id, h_planned_effort, h_start_D, h_finish_D, h+
1_billable, h_capital_expense,:n            h_old_cost, h_old_sale, h_task_id,+
1 h_percent_units, h_work, h_eunit, h_unit, h_contour:n            FROM TASK_A+
1SSIGNMENTS:n            WHERE TSK_ASSIGNMENT_ID = h_old_prj_assign_id:
1990:
1           EXCEPTION:: SP_A_RESTOPROF(991) :: cplan.sql(10401) :: :
1-:
1FC_TPHASE_SCHED_ASSIGN:
1SC_0000FFFF:
11007:
1        RETURN_ERROR:: SP_A_RESTOPROF(1008) :: cplan.sql(10418) :: :
1TASK_ASSIGNMENT_ERROR:
11010:
1                EXIT:: SP_A_RESTOPROF(1011) :: cplan.sql(10421) :: :
1Y:
1FINISH_DT:
1SELECT RES_ASSIGNMENT_ID, TO_DATE(SubStr(FINISH_DT, 1, 10)),BILLABLE, CAPITAL+
1_EXPENSE, PLANNED_WORK, :n                  C_EFFORT, C_UNIT, C_CONTOUR, TIME+
1CODE_1_ID, TIMECODE_2_ID, TABLE_TYPE:n                  INTO h_assign_id, h_s+
1tart_D, h_billable, h_capital_expense, h_planned_effort, :n                  +
1h_work, h_unit, h_contour, h_timecode_1_id, h_timecode_2_id, h_table_type:n  +
1                FROM TASK_ASSIGNMENTS:n                  WHERE TSK_ASSIGNMENT+
1_ID = h_prj_assignment_id:
11063:
1           EXCEPTION:: SP_A_RESTOPROF(1064) :: cplan.sql(10474) :: :
11074:
1        RETURN_ERROR:: SP_A_RESTOPROF(1075) :: cplan.sql(10485) :: :
11077:
1                EXIT:: SP_A_RESTOPROF(1078) :: cplan.sql(10488) :: :
1SUM:
1SCHED_MIN:
1TASK_DAY_OF_YEAR:
1PARENT_ID:
1SELECT SUM(SCHED_MIN) INTO h_planned_effort :n                              F+
1ROM TASK_DAY_OF_YEAR :n                              WHERE PROJECT_ID = h_pro+
1ject_id :n                              AND TSK_ASSIGNMENT_ID <> h_old_prj_as+
1sign_id AND PARENT_ID = h_old_prj_assign_id:
11103:
1           EXCEPTION:: SP_A_RESTOPROF(1104) :: cplan.sql(10514) :: :
1SELECT SUM(SCHED_MIN) INTO h_planned_effort :n                              F+
1ROM TASK_DAY_OF_YEAR :n                              WHERE PROJECT_ID = h_pro+
1ject_id AND RESOURCE_ID = h_profile_id:
11120:
1           EXCEPTION:: SP_A_RESTOPROF(1121) :: cplan.sql(10531) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id :n              +
1             AND TSK_ASSIGNMENT_ID <> h_old_prj_assign_id AND PARENT_ID = h_o+
1ld_prj_assign_id:
11143:
1           EXCEPTION:: SP_A_RESTOPROF(1144) :: cplan.sql(10554) :: :
1PROJECT_ASSIGNMENTS:
1DELETE FROM PROJECT_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND RESOURCE_+
1ID = h_profile_id:
11162:
1           EXCEPTION:: SP_A_RESTOPROF(1163) :: cplan.sql(10573) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_id:
11181:
1           EXCEPTION:: SP_A_RESTOPROF(1182) :: cplan.sql(10592) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_old_prj_assign_id:
11200:
1           EXCEPTION:: SP_A_RESTOPROF(1201) :: cplan.sql(10611) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_old_prj_assign_id:
11219:
1           EXCEPTION:: SP_A_RESTOPROF(1220) :: cplan.sql(10630) :: :
11232:
1        RETURN_ERROR:: SP_A_RESTOPROF(1233) :: cplan.sql(10643) :: :
11235:
1                EXIT:: SP_A_RESTOPROF(1236) :: cplan.sql(10646) :: :
1SPECIAL_COST:
1SPECIAL_RATE:
1ESTIMATION_LABOR_COST:
1SCHED_WORK:
1ROLLUP_BITS:
1SC_SET_ALL_BITS:
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_COST = h_reg_cost,:n                        SPECIAL_COST = h_sp+
1ec_cost,:n                        REGULAR_RATE = h_reg_sale,:n               +
1         SPECIAL_RATE = h_spec_sale,:n                        UNITS_MSP = CAS+
1E WHEN h_contour_changed = 0 THEN UNITS_MSP ELSE h_percent_units END,:n      +
1                  ESTIMATION_LABOR_COST = ((PLANNED_WORK+SCHED_WORK)/60.00) *+
1 h_reg_cost,:n                        ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BI+
1TS, pmo_cnst.SC_SET_ALL_BITS):n                        WHERE TSK_ASSIGNMENT_I+
1D = h_prj_assignment_id:
11268:
1           EXCEPTION:: SP_A_RESTOPROF(1269) :: cplan.sql(10679) :: :
1ESTIMATION_LABOR_REVENUE:
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_COST = h_reg_cost,:n                        SPECIAL_COST = h_sp+
1ec_cost,:n                        REGULAR_RATE = h_reg_sale,:n               +
1         SPECIAL_RATE = h_spec_sale,:n                        UNITS_MSP = CAS+
1E WHEN h_contour_changed = 0 THEN UNITS_MSP ELSE h_percent_units END,:n      +
1                  ESTIMATION_LABOR_COST = ((PLANNED_WORK+SCHED_WORK)/60.00) *+
1 h_reg_cost,:n                        ESTIMATION_LABOR_REVENUE = ((PLANNED_WO+
1RK+PLANNED_WORK)/60.00) * h_reg_sale,:n                        ROLLUP_BITS = +
1PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS):n                     +
1   WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11297:
1           EXCEPTION:: SP_A_RESTOPROF(1298) :: cplan.sql(10708) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1          RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                     +
1REGULAR_COST = h_reg_cost,:n                     SPECIAL_COST = h_spec_cost,+
1:n                     UNITS_MSP = CASE WHEN h_contour_changed = 0 THEN UNITS+
1_MSP ELSE h_percent_units END,:n                     ESTIMATION_LABOR_COST = +
1((PLANNED_WORK+SCHED_WORK)/60.00) * h_reg_cost,:n                     ROLLUP_+
1BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS):n              +
1       WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11324:
1           EXCEPTION:: SP_A_RESTOPROF(1325) :: cplan.sql(10735) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_RATE = h_reg_sale,:n                        SPECIAL_RATE = h_sp+
1ec_sale,:n                        UNITS_MSP = CASE WHEN h_contour_changed = 0+
1 THEN UNITS_MSP ELSE h_percent_units END,:n                        ROLLUP_BIT+
1S = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS):n                 +
1       WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11350:
1           EXCEPTION:: SP_A_RESTOPROF(1351) :: cplan.sql(10761) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_RATE = h_reg_sale,:n                        SPECIAL_RATE = h_sp+
1ec_sale,:n                        UNITS_MSP = CASE WHEN h_contour_changed = 0+
1 THEN UNITS_MSP ELSE h_percent_units END,:n                        ESTIMATION+
1_LABOR_REVENUE = ((PLANNED_WORK+PLANNED_WORK)/60.00) * h_reg_sale,:n         +
1               ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL+
1_BITS):n                        WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11376:
1           EXCEPTION:: SP_A_RESTOPROF(1377) :: cplan.sql(10787) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1          UNITS_MSP = CASE WHEN h_contour_changed = 0 THEN UNITS_MSP ELSE h_p+
1ercent_units END,:n                     RESOURCE_ID = h_res_id, RESOURCE_TYPE+
1 = '0':n                     WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11399:
1           EXCEPTION:: SP_A_RESTOPROF(1400) :: cplan.sql(10810) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_prj_assignment_id:
11419:
1           EXCEPTION:: SP_A_RESTOPROF(1420) :: cplan.sql(10830) :: :
11438:
1           EXCEPTION:: SP_A_RESTOPROF(1439) :: cplan.sql(10849) :: :
11457:
1           EXCEPTION:: SP_A_RESTOPROF(1458) :: cplan.sql(10868) :: :
1SC_BIT_27:
1<:
1ASSIGNLONG:
1FC_CALC_DURATION:
1INVALID_PARAMS:
18:
11496:
1      RETURN_INVALID:: SP_A_RESTOPROF(1497) :: cplan.sql(10907) :: :
11499:
1                EXIT:: SP_A_RESTOPROF(1500) :: cplan.sql(10910) :: :
1PMO_RETURN_INVALID_SP:
11504:
1        RETURN_ERROR:: SP_A_RESTOPROF(1505) :: cplan.sql(10915) :: :
11507:
1                EXIT:: SP_A_RESTOPROF(1508) :: cplan.sql(10918) :: :
10.00:
1FC_SEARCH_2:
1110:
11522:
1        RETURN_ERROR:: SP_A_RESTOPROF(1523) :: cplan.sql(10933) :: :
1RESOURCE_UNAVAILABLE:
11525:
1                EXIT:: SP_A_RESTOPROF(1526) :: cplan.sql(10936) :: :
11530:
1        RETURN_ERROR:: SP_A_RESTOPROF(1531) :: cplan.sql(10941) :: :
11533:
1                EXIT:: SP_A_RESTOPROF(1534) :: cplan.sql(10944) :: :
1U_ASSIGN_STRING:
1DAY_YEAR:
1SELECT MAX(DAY_YEAR) INTO h_start_date :n               FROM TASK_DAY_OF_YEAR+
1 :n               WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_p+
1rj_assignment_id:
11557:
1           EXCEPTION:: SP_A_RESTOPROF(1558) :: cplan.sql(10968) :: :
1%:
11582:
1           EXCEPTION:: SP_A_RESTOPROF(1583) :: cplan.sql(10993) :: :
1LOOP:
1EXIT:
1FC_BEFORE_D_RES_ASSIGN:
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
11642:
1           EXCEPTION:: SP_A_RESTOPROF(1643) :: cplan.sql(11053) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11661:
1           EXCEPTION:: SP_A_RESTOPROF(1662) :: cplan.sql(11072) :: :
1EFFORT_WEEK:
1DELETE FROM EFFORT_WEEK WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11680:
1           EXCEPTION:: SP_A_RESTOPROF(1681) :: cplan.sql(11091) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_tsk_assignment_id:
11699:
1           EXCEPTION:: SP_A_RESTOPROF(1700) :: cplan.sql(11110) :: :
1RESOURCE_ASSIGN_ROLES:
1DELETE FROM RESOURCE_ASSIGN_ROLES WHERE RES_ASSIGNMENT_ID = h_tsk_assignment_+
1id:
11718:
1           EXCEPTION:: SP_A_RESTOPROF(1719) :: cplan.sql(11129) :: :
1RESOURCE_ASSIGN_SKILLS:
1DELETE FROM RESOURCE_ASSIGN_SKILLS WHERE RES_ASSIGNMENT_ID = h_tsk_assignment+
1_id:
11737:
1           EXCEPTION:: SP_A_RESTOPROF(1738) :: cplan.sql(11148) :: :
1SUMMARY_TIMESHEETS:
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id :n            WHERE TSK_+
1ASSIGNMENT_ID = h_tsk_assignment_id :n            AND PROJECT_ID = h_project_+
1id :n            AND RESOURCE_ID = h_profile_id:
11762:
1           EXCEPTION:: SP_A_RESTOPROF(1763) :: cplan.sql(11173) :: :
1SELECT TSK_ASSIGNMENT_ID, BIT_FLAG INTO h_tmp_assignment_id, h_bit_flag :n   +
1         FROM TASK_ASSIGNMENTS:n            WHERE PROJECT_ID = h_project_id A+
1ND TASK_ID = h_task_id AND RESOURCE_ID = h_res_id:n            AND RESOURCE_T+
1YPE ='0':
11785:
1           EXCEPTION:: SP_A_RESTOPROF(1786) :: cplan.sql(11196) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_id, h_participant, +
1h_security_id:n               FROM RESOURCE_ASSIGNMENTS :n               WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_ID = h_res_id AND RESOURCE_TYPE='0':
11806:
1           EXCEPTION:: SP_A_RESTOPROF(1807) :: cplan.sql(11217) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                     PROFILE_ID		= h_profil+
1e_id,:n                     RESOURCE_ID		= h_res_id, :n                     R+
1ESOURCE_TYPE	= '0':n                     WHERE RES_ASSIGNMENT_ID = h_assign_i+
1d:
11832:
1           EXCEPTION:: SP_A_RESTOPROF(1833) :: cplan.sql(11243) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                     PARTICIPANT		= pmo_cns+
1t.SC_TEAMMEMBER, :n                     SECURITY_ID		= h_temp_security_id, :n+
1                     PROFILE_ID		= h_profile_id,:n                     RESOUR+
1CE_ID		= h_res_id, :n                     RESOURCE_TYPE	= '0':n              +
1       WHERE RES_ASSIGNMENT_ID = h_assign_id:
11860:
1           EXCEPTION:: SP_A_RESTOPROF(1861) :: cplan.sql(11271) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                     PARTICIPANT		= PMO_STP+
1U.BIT_OR(h_participant,pmo_cnst.SC_TEAMMEMBER), :n                     SECURI+
1TY_ID		= h_security_id, :n                     PROFILE_ID		= h_profile_id,:n +
1                    RESOURCE_ID		= h_res_id, :n                     RESOURCE_+
1TYPE	= '0':n                     WHERE RES_ASSIGNMENT_ID = h_assign_id:
11885:
1           EXCEPTION:: SP_A_RESTOPROF(1886) :: cplan.sql(11296) :: :
11906:
1           EXCEPTION:: SP_A_RESTOPROF(1907) :: cplan.sql(11317) :: :
1RA:
1CREATED_BY:
1TA:
1SELECT ra.RES_ASSIGNMENT_ID, SUBSTR(tw.ASSIGN_NAMES,1,InStr(tw.ASSIGN_NAMES, +
1';') - 1):n                  INTO h_id,h_in FROM TMT_WBS tw, RESOURCE_ASSIGNM+
1ENTS ra:n                  WHERE tw.ELEMENT_ID = h_task_id AND tw.ELEMENT_ID +
1= ra.ELEMENT_ID AND ra.PARTICIPANT = 32 :n                  AND ra.RESOURCE_I+
1D = tw.CREATED_BY AND NOT EXISTS(:n                  SELECT TSK_ASSIGNMENT_ID+
1 FROM TASK_ASSIGNMENTS ta WHERE ta.RES_ASSIGNMENT_ID = ra.RES_ASSIGNMENT_ID):
11926:
1           EXCEPTION:: SP_A_RESTOPROF(1927) :: cplan.sql(11337) :: :
1SC_RESPONSIBLE_GROUP:
11949:
1           EXCEPTION:: SP_A_RESTOPROF(1950) :: cplan.sql(11360) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE='0',:n +
1                    PROFILE_ID = h_profile_id, PARTICIPANT = 48, SECURITY_ID=+
1h_temp_security_id:n                     WHERE RES_ASSIGNMENT_ID = h_assign_i+
1d:
11970:
1           EXCEPTION:: SP_A_RESTOPROF(1971) :: cplan.sql(11381) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_in, h_full_name) +
1:n                     WHERE ELEMENT_ID = h_task_id:
11990:
1           EXCEPTION:: SP_A_RESTOPROF(1991) :: cplan.sql(11401) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_profile_name, h_fu+
1ll_name) :n                     WHERE ELEMENT_ID = h_task_id:
12010:
1           EXCEPTION:: SP_A_RESTOPROF(2011) :: cplan.sql(11421) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0' +
1:n                     WHERE RES_ASSIGNMENT_ID = h_assign_id:
12030:
1           EXCEPTION:: SP_A_RESTOPROF(2031) :: cplan.sql(11441) :: :
12051:
1           EXCEPTION:: SP_A_RESTOPROF(2052) :: cplan.sql(11462) :: :
12074:
1           EXCEPTION:: SP_A_RESTOPROF(2075) :: cplan.sql(11485) :: :
12093:
1           EXCEPTION:: SP_A_RESTOPROF(2094) :: cplan.sql(11504) :: :
12111:
1           EXCEPTION:: SP_A_RESTOPROF(2112) :: cplan.sql(11522) :: :
1SELECT CASE WHEN FS_LABOR_CODE IS NuLL THEN 0 WHEN FS_LABOR_CODE = h_labor_co+
1de THEN 1 ELSE 2 END:n                  INTO h_same_labor FROM TMT_WBS WHERE +
1ELEMENT_ID=h_task_id:
12137:
1           EXCEPTION:: SP_A_RESTOPROF(2138) :: cplan.sql(11548) :: :
1UPDATE TMT_WBS SET FS_LABOR_CODE = h_labor_code WHERE ELEMENT_ID=h_task_id:
12157:
1           EXCEPTION:: SP_A_RESTOPROF(2158) :: cplan.sql(11568) :: :
12172:
1           EXCEPTION:: SP_A_RESTOPROF(2173) :: cplan.sql(11583) :: :
12178:
1        RETURN_ERROR:: SP_A_RESTOPROF(2179) :: cplan.sql(11589) :: :
1CANNOT_ASSIGN_LABOR_CODE:
12181:
1                EXIT:: SP_A_RESTOPROF(2182) :: cplan.sql(11592) :: :
1SC_FIXED_DURATION:
1SC_FD_EFFORT_DRIVEN:
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLNF_0001:
1PMO_TMP_CPLNF_0001:
1INSERT INTO PMO_TMP_CPLNF_0001:n                     SELECT r.DAY_YEAR, 0 FRO+
1M CALENDAR_DAY_OF_YEAR r :n                     WHERE r.ELEMENT_ID = h_res_id+
1 AND r.DAY_YEAR BETWEEN TO_DATE(SubStr(h_SD, 1, 10)) AND TO_DATE(SubStr(h_FD,+
1 1, 10)):
12211:
1           EXCEPTION:: SP_A_RESTOPROF(2212) :: cplan.sql(11622) :: :
1TDY:
1INSERT INTO PMO_TMP_CPLNF_0001 SELECT r.DAY_YEAR, 0 :n                     FR+
1OM CALENDAR_DAY_OF_YEAR r, TASK_DAY_OF_YEAR tdy :n                     WHERE +
1r.ELEMENT_ID = h_res_id AND r.DAY_YEAR BETWEEN TO_DATE(SubStr(h_SD, 1, 10)) A+
1ND TO_DATE(SubStr(h_FD, 1, 10)) :n                     AND tdy.PROJECT_ID = h+
1_project_id AND tdy.TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n                +
1     AND r.DAY_YEAR = tdy.DAY_YEAR:
12234:
1           EXCEPTION:: SP_A_RESTOPROF(2235) :: cplan.sql(11645) :: :
1MIN:
1SELECT COUNT(DAY_YEAR), MIN(DAY_YEAR) INTO h_temp_var, h_dayofyear :n        +
1             FROM PMO_TMP_CPLNF_0001:
12253:
1           EXCEPTION:: SP_A_RESTOPROF(2254) :: cplan.sql(11664) :: :
1CONTINUE0000:
1DELETE FROM TASK_DAY_OF_YEAR :n                        WHERE PROJECT_ID = h_p+
1roject_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12276:
1           EXCEPTION:: SP_A_RESTOPROF(2277) :: cplan.sql(11687) :: :
1TRUNC:
1TO_NUMBER:
1/:
10.49:
1BIT_SCHED:
1SELECT AVAILABLE_MIN, BIT_SCHED INTO h_available, h_bitID:n                  +
1      FROM CALENDAR_DAY_OF_YEAR:n                        WHERE ELEMENT_ID = h+
1_project_id AND DAY_YEAR = h_dayofyear:
12295:
1           EXCEPTION:: SP_A_RESTOPROF(2296) :: cplan.sql(11706) :: :
1SKIPFIRSTBITSCLEARTOLAST:
1ACTUAL_FLAG:
1INSERT INTO TASK_DAY_OF_YEAR (:n                        PROJECT_ID,:n        +
1                RESOURCE_ID,:n                        TSK_ASSIGNMENT_ID,:n   +
1                     DAY_YEAR,:n                        BIT_FLAG,:n          +
1              SCHED_MIN,:n                        BIT_SCHED,:n               +
1         PARENT_ID,:n                        ACTUAL_FLAG,:n                  +
1      TASK_ID ):n                        SELECT:n                        h_pr+
1oject_id,:n                        h_res_id,:n                        h_tsk_a+
1ssignment_id,:n                        DAY_YEAR,:n                        '0'+
1,:n                        h_minutes,:n                        h_bitID,:n    +
1                    CASE WHEN h_assigned = 0 THEN h_tsk_assignment_id ELSE h_+
1prj_assignment_id END,:n                        0,:n                        h+
1_task_id:n                        FROM PMO_TMP_CPLNF_0001:
12340:
1           EXCEPTION:: SP_A_RESTOPROF(2341) :: cplan.sql(11751) :: :
1UPDATE TASK_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE='0', :n    +
1                 PROJECT_ASSIGNMENT_ID = CASE WHEN h_assigned = 0 THEN NuLL E+
1LSE h_prj_assignment_id END,:n                     REGULAR_COST = CASE WHEN h+
1_donot_replace_cost = 0 THEN h_reg_cost  ELSE REGULAR_COST END,:n            +
1         SPECIAL_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_cost E+
1LSE SPECIAL_COST END,:n                     REGULAR_RATE = CASE WHEN h_donot_+
1replace_rate = 0 THEN h_reg_sale  ELSE REGULAR_RATE END,:n                   +
1  SPECIAL_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE SPE+
1CIAL_RATE END,:n                     ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BI+
1TS, pmo_cnst.SC_SET_ALL_BITS):n                     WHERE TSK_ASSIGNMENT_ID =+
1 h_tsk_assignment_id:
12367:
1           EXCEPTION:: SP_A_RESTOPROF(2368) :: cplan.sql(11778) :: :
110000.00:
1SC_BIT_30:
110000:
1ETC:
1UPDATE TASK_ASSIGNMENTS SET:n                        ROLLUP_BITS  = PMO_STPU.+
1BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS), ETC = ETC + h_effort:n        +
1                WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12410:
1           EXCEPTION:: SP_A_RESTOPROF(2411) :: cplan.sql(11821) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                              RESOURCE_ID = h_re+
1s_id, RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                           +
1   CASE WHEN h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n        +
1                      REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN +
1h_reg_cost  ELSE REGULAR_COST END,:n                              SPECIAL_COS+
1T = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END+
1,:n                              REGULAR_RATE = CASE WHEN h_donot_replace_rat+
1e = 0 THEN h_reg_sale  ELSE REGULAR_RATE END,:n                              +
1SPECIAL_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE SPECI+
1AL_RATE END,:n                              UNITS_MSP    = work001, ETC = h_e+
1ffort,:n                              C_CONTOUR    = contour001,:n           +
1                   ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SE+
1T_ALL_BITS):n                              WHERE TSK_ASSIGNMENT_ID = h_tsk_as+
1signment_id:
12455:
1           EXCEPTION:: SP_A_RESTOPROF(2456) :: cplan.sql(11866) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                              RESOURCE_ID = h_re+
1s_id, RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                           +
1   CASE WHEN h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n        +
1                      REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN +
1h_reg_cost  ELSE REGULAR_COST END,:n                              SPECIAL_COS+
1T = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END+
1,:n                              REGULAR_RATE = CASE WHEN h_donot_replace_rat+
1e = 0 THEN h_reg_sale  ELSE REGULAR_RATE END,:n                              +
1SPECIAL_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE SPECI+
1AL_RATE END,:n                              C_EFFORT     = work001, ETC = h_e+
1ffort,:n                              C_UNIT       = unit,:n                 +
1             C_CONTOUR    = contour001,:n                              ROLLUP+
1_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS):n            +
1                  WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12485:
1           EXCEPTION:: SP_A_RESTOPROF(2486) :: cplan.sql(11896) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           RESOURCE_ID = h_res_i+
1d, RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                           CAS+
1E WHEN h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n              +
1             REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_cos+
1t  ELSE REGULAR_COST END,:n                           SPECIAL_COST = CASE WHE+
1N h_donot_replace_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END,:n         +
1                  REGULAR_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_re+
1g_sale  ELSE REGULAR_RATE END,:n                           SPECIAL_RATE = CAS+
1E WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE SPECIAL_RATE END,:n    +
1                       ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.S+
1C_SET_ALL_BITS), ETC = h_effort:n                           WHERE TSK_ASSIGNM+
1ENT_ID = h_tsk_assignment_id:
12513:
1           EXCEPTION:: SP_A_RESTOPROF(2514) :: cplan.sql(11924) :: :
12542:
1           EXCEPTION:: SP_A_RESTOPROF(2543) :: cplan.sql(11953) :: :
12548:
1      RETURN_INVALID:: SP_A_RESTOPROF(2549) :: cplan.sql(11959) :: :
12551:
1                EXIT:: SP_A_RESTOPROF(2552) :: cplan.sql(11962) :: :
12565:
1           EXCEPTION:: SP_A_RESTOPROF(2566) :: cplan.sql(11976) :: :
12571:
1        RETURN_ERROR:: SP_A_RESTOPROF(2572) :: cplan.sql(11982) :: :
12574:
1                EXIT:: SP_A_RESTOPROF(2575) :: cplan.sql(11985) :: :
130:
11.5:
12617:
1           EXCEPTION:: SP_A_RESTOPROF(2618) :: cplan.sql(12028) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                        RESOURCE_ID = h_res_id, +
1RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                        CASE WHEN+
1 h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n                    +
1    REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_cost  ELSE R+
1EGULAR_COST END,:n                        SPECIAL_COST = CASE WHEN h_donot_re+
1place_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END,:n                     +
1   REGULAR_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_reg_sale  ELSE RE+
1GULAR_RATE END,:n                        SPECIAL_RATE = CASE WHEN h_donot_rep+
1lace_rate = 0 THEN h_spec_sale ELSE SPECIAL_RATE END,:n                      +
1  ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS), ETC +
1= h_effort:n                        WHERE TSK_ASSIGNMENT_ID = h_tsk_assignmen+
1t_id:
12644:
1           EXCEPTION:: SP_A_RESTOPROF(2645) :: cplan.sql(12055) :: :
13:
12701:
1           EXCEPTION:: SP_A_RESTOPROF(2702) :: cplan.sql(12112) :: :
12707:
1        RETURN_ERROR:: SP_A_RESTOPROF(2708) :: cplan.sql(12118) :: :
12710:
1                EXIT:: SP_A_RESTOPROF(2711) :: cplan.sql(12121) :: :
12724:
1           EXCEPTION:: SP_A_RESTOPROF(2725) :: cplan.sql(12135) :: :
12730:
1        RETURN_ERROR:: SP_A_RESTOPROF(2731) :: cplan.sql(12141) :: :
12733:
1                EXIT:: SP_A_RESTOPROF(2734) :: cplan.sql(12144) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE(ASSIGN_NAMES,h_profile_name || ';',+
1'') WHERE ELEMENT_ID=h_task_id:
12759:
1           EXCEPTION:: SP_A_RESTOPROF(2760) :: cplan.sql(12170) :: :
1C:
1PROFICIENCY_LEVEL_ID:
1EXPERIENCE_ID:
1PREFERENCE_LEVEL_ID:
1LAST_USED_DATETIME:
1TMT_COMPETENCIES:
1P:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n               SELECT h_tsk_assignment_id,+
1 c.ELEMENT_ID, c.PROFICIENCY_LEVEL_ID, c.EXPERIENCE_ID, c.PREFERENCE_LEVEL_ID+
1, c.LAST_USED_DATETIME, '0':n               FROM TMT_COMPETENCIES c JOIN PROF+
1ILES p ON c.ELEMENT_ID = p.ROLE_ID WHERE p.PROFILE_ID = h_profile_id:
12781:
1           EXCEPTION:: SP_A_RESTOPROF(2782) :: cplan.sql(12192) :: :
1PRIMARY_ROLE:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n               SELECT h_tsk_assignment_id,+
1 ROLE_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, LAST_USED+
1_DATETIME, PRIMARY_ROLE:n               FROM RESOURCE_ASSIGN_ROLES WHERE RES_+
1ASSIGNMENT_ID = h_profile_id:
12803:
1           EXCEPTION:: SP_A_RESTOPROF(2804) :: cplan.sql(12214) :: :
1SKILL_ID:
1PRIMARY_SKILL:
1INSERT INTO RESOURCE_ASSIGN_SKILLS:n               SELECT h_tsk_assignment_id+
1, SKILL_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, LAST_US+
1ED_DATETIME, PRIMARY_SKILL:n               FROM RESOURCE_ASSIGN_SKILLS WHERE +
1RES_ASSIGNMENT_ID = h_profile_id:
12824:
1           EXCEPTION:: SP_A_RESTOPROF(2825) :: cplan.sql(12235) :: :
1FC_AFTER_REPLACE_RES_ASSIGN:
1UPDATE EFFORT_WEEK SET RESOURCE_ID = h_res_id:n               WHERE PROJECT_I+
1D = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12853:
1           EXCEPTION:: SP_A_RESTOPROF(2854) :: cplan.sql(12264) :: :
1ACTUAL_REGULAR_COST:
1ACTUAL_SPECIAL_COST:
1ACTUAL_REGULAR_RATE:
1ACTUAL_SPECIAL_RATE:
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                  ACTU+
1AL_REGULAR_COST = h_reg_cost  ,:n                  ACTUAL_SPECIAL_COST = h_sp+
1ec_cost ,:n                  ACTUAL_REGULAR_RATE = h_reg_sale  ,:n           +
1       ACTUAL_SPECIAL_RATE = h_spec_sale ,:n                  REC_USER = h_re+
1c_user, REC_DATETIME = SYSTIMESTAMP:n                  WHERE TSK_ASSIGNMENT_I+
1D = h_id:
12880:
1           EXCEPTION:: SP_A_RESTOPROF(2881) :: cplan.sql(12291) :: :
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                  ACTU+
1AL_REGULAR_COST = h_reg_cost  ,:n                  ACTUAL_SPECIAL_COST = h_sp+
1ec_cost ,:n                  REC_USER = h_rec_user, REC_DATETIME = SYSTIMESTA+
1MP:n                  WHERE TSK_ASSIGNMENT_ID = h_id:
12903:
1           EXCEPTION:: SP_A_RESTOPROF(2904) :: cplan.sql(12314) :: :
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                  ACTU+
1AL_REGULAR_RATE = h_reg_sale  ,:n                  ACTUAL_SPECIAL_RATE = h_sp+
1ec_sale ,:n                  REC_USER = h_rec_user, REC_DATETIME = SYSTIMESTA+
1MP:n                  WHERE TSK_ASSIGNMENT_ID = h_id:
12928:
1           EXCEPTION:: SP_A_RESTOPROF(2929) :: cplan.sql(12339) :: :
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                  REC_+
1USER = h_rec_user, REC_DATETIME = SYSTIMESTAMP:n                  WHERE TSK_A+
1SSIGNMENT_ID = h_id:
12951:
1           EXCEPTION:: SP_A_RESTOPROF(2952) :: cplan.sql(12362) :: :
1FC_D_RA_AFTER_REPLACE:
12978:
1           EXCEPTION:: SP_A_RESTOPROF(2979) :: cplan.sql(12389) :: :
1>=:
13018:
1      RETURN_INVALID:: SP_A_RESTOPROF(3019) :: cplan.sql(12429) :: :
13021:
1                EXIT:: SP_A_RESTOPROF(3022) :: cplan.sql(12432) :: :
13026:
1        RETURN_ERROR:: SP_A_RESTOPROF(3027) :: cplan.sql(12437) :: :
13029:
1                EXIT:: SP_A_RESTOPROF(3030) :: cplan.sql(12440) :: :
1DELETE FROM PMO_TMP_PA_SUM:
1PMO_TMP_PA_SUM:
1INSERT INTO PMO_TMP_PA_SUM SELECT DAY_YEAR, SUM(SCHED_MIN):n               FR+
1OM TASK_DAY_OF_YEAR:n               WHERE PROJECT_ID = h_project_id AND PAREN+
1T_ID = h_prj_assignment_id:n               GROUP BY DAY_YEAR:
13055:
1           EXCEPTION:: SP_A_RESTOPROF(3056) :: cplan.sql(12466) :: :
13085:
1        RETURN_ERROR:: SP_A_RESTOPROF(3086) :: cplan.sql(12496) :: :
13088:
1                EXIT:: SP_A_RESTOPROF(3089) :: cplan.sql(12499) :: :
13093:
1        RETURN_ERROR:: SP_A_RESTOPROF(3094) :: cplan.sql(12504) :: :
13096:
1                EXIT:: SP_A_RESTOPROF(3097) :: cplan.sql(12507) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1       RESOURCE_ID  = h_res_id, RESOURCE_TYPE = '0',:n                  REGUL+
1AR_COST = CASE WHEN h_donot_replace_rate = 0 THEN h_reg_cost  * h_rate_echang+
1e ELSE REGULAR_COST END,:n                  SPECIAL_COST = CASE WHEN h_donot_+
1replace_rate = 0 THEN h_spec_cost * h_rate_echange ELSE SPECIAL_COST END,:n  +
1                REGULAR_RATE = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_+
1sale  * h_rate_echange ELSE REGULAR_RATE END,:n                  SPECIAL_RATE+
1 = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_sale * h_rate_echange ELSE +
1SPECIAL_RATE END:n                  WHERE TSK_ASSIGNMENT_ID = h_prj_assignmen+
1t_id:
13121:
1           EXCEPTION:: SP_A_RESTOPROF(3122) :: cplan.sql(12532) :: :
1UPDATE TASK_DAY_OF_YEAR:n            SET PARENT_ID = h_prj_assignment_id:n   +
1         WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assign+
1ment_id:
13144:
1           EXCEPTION:: SP_A_RESTOPROF(3145) :: cplan.sql(12555) :: :
1SELECT COUNT(*) INTO h_count FROM RESOURCE_ASSIGNMENTS:n         WHERE ELEMEN+
1T_ID = h_project_id AND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1':
13161:
1           EXCEPTION:: SP_A_RESTOPROF(3162) :: cplan.sql(12572) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE(ASSIGN_NAMES,h_profile_name || ';',+
1''):n            WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_project_i+
1d:
13183:
1           EXCEPTION:: SP_A_RESTOPROF(3184) :: cplan.sql(12594) :: :
1SC_ASSIGNMENT_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_ASS+
1IGNMENT_BIT) WHERE ELEMENT_ID = h_project_id:
13208:
1           EXCEPTION:: SP_A_RESTOPROF(3209) :: cplan.sql(12619) :: :
1SELECT COUNT(*) INTO h_count FROM TASK_ASSIGNMENTS:n            WHERE PROJECT+
1_ID = h_project_id AND PROJECT_ASSIGNMENT_ID = h_old_prj_assign_id:
13226:
1           EXCEPTION:: SP_A_RESTOPROF(3227) :: cplan.sql(12637) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND:n       +
1        ELEMENT_ID = h_project_id AND RESOURCE_ID = h_profile_id AND RESOURCE+
1_TYPE = '1':
13248:
1           EXCEPTION:: SP_A_RESTOPROF(3249) :: cplan.sql(12659) :: :
13267:
1           EXCEPTION:: SP_A_RESTOPROF(3268) :: cplan.sql(12678) :: :
1BEST:
1BAK_START_DT:
1BAK_FINISH_DT:
1SELECT PLANNED_START, PLANNED_FINISH, BEST, TO_DATE(SubStr(BAK_START_DT, 1, 1+
10)), TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULA+
1R_COST, REGULAR_RATE:n            INTO h_start_DT, h_finish_DT, h_effort, h_s+
1tart_D, h_finish_D, h_billable, h_capital_expense, h_old_cost, h_old_sale:n  +
1          FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_old_prj_assign_id:
13291:
1           EXCEPTION:: SP_A_RESTOPROF(3292) :: cplan.sql(12702) :: :
1ESTIMATED_PLANNED_START:
1ESTIMATED_PLANNED_FINISH:
1ESTIMATED_PLANNED_EFFORT:
1ESTIMATED_PLANNED_COST:
1ESTIMATED_PLANNED_REVENUE:
1UPDATE PROJECT_ASSIGNMENTS SET:n                  ESTIMATED_PLANNED_START = h+
1_start_DT,:n                  ESTIMATED_PLANNED_FINISH = h_finish_DT,:n      +
1            ESTIMATED_PLANNED_EFFORT = h_effort,:n                  ESTIMATED+
1_PLANNED_COST = (h_effort/60.00) * h_old_cost,:n                  ESTIMATED_P+
1LANNED_REVENUE = 0.00:n                  WHERE PROJECT_ID = h_project_id AND +
1RESOURCE_ID = h_profile_id:
13317:
1           EXCEPTION:: SP_A_RESTOPROF(3318) :: cplan.sql(12728) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                  ESTIMATED_PLANNED_START = h+
1_start_DT,:n                  ESTIMATED_PLANNED_FINISH = h_finish_DT,:n      +
1            ESTIMATED_PLANNED_EFFORT = h_effort,:n                  ESTIMATED+
1_PLANNED_COST = (h_effort/60.00) * h_old_cost,:n                  ESTIMATED_P+
1LANNED_REVENUE = (h_effort/60.00) * h_old_sale:n                  WHERE PROJE+
1CT_ID = h_project_id AND RESOURCE_ID = h_profile_id:
13342:
1           EXCEPTION:: SP_A_RESTOPROF(3343) :: cplan.sql(12753) :: :
1SELECT PLANNED_START, PLANNED_FINISH, BEST, TO_DATE(SubStr(BAK_START_DT, 1, 1+
10)), TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULA+
1R_COST, REGULAR_RATE:n         INTO h_start_DT, h_finish_DT, h_effort, h_star+
1t_D, h_finish_D, h_billable, h_capital_expense, h_reg_cost, h_reg_sale:n     +
1    FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
13381:
1           EXCEPTION:: SP_A_RESTOPROF(3382) :: cplan.sql(12792) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n            ESTIMATED_PLANNED_START  = h_star+
1t_DT,:n            ESTIMATED_PLANNED_FINISH = h_finish_DT,:n            ESTIM+
1ATED_PLANNED_EFFORT = h_effort,:n            ESTIMATED_PLANNED_COST   = (h_ef+
1fort/60.00) * h_reg_cost,:n            ESTIMATED_PLANNED_REVENUE = 0.00:n    +
1        WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h_res_id:
13408:
1           EXCEPTION:: SP_A_RESTOPROF(3409) :: cplan.sql(12819) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n            ESTIMATED_PLANNED_START  = h_star+
1t_DT,:n            ESTIMATED_PLANNED_FINISH = h_finish_DT,:n            ESTIM+
1ATED_PLANNED_EFFORT = h_effort,:n            ESTIMATED_PLANNED_COST   = (h_ef+
1fort/60.00) * h_reg_cost,:n            ESTIMATED_PLANNED_REVENUE = (h_effort/+
160.00) * h_reg_sale:n            WHERE PROJECT_ID = h_project_id AND RESOURCE+
1_ID = h_res_id:
13433:
1           EXCEPTION:: SP_A_RESTOPROF(3434) :: cplan.sql(12844) :: :
1FC_ROLLUP:
13456:
1       RETURN_STATUS:: SP_A_RESTOPROF(3457) :: cplan.sql(12867) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
13463:
1           EXCEPTION:: SP_A_RESTOPROF(3464) :: cplan.sql(12874) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
13475:
1           EXCEPTION:: SP_A_RESTOPROF(3476) :: cplan.sql(12886) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
5217
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c :2 a0 6b 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c :3 a0 51 a5 b a5
b 5a 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a0 f4 b4 bf c8 :5 a0
12a bd b7 11 a4 b1 a0 f4
b4 bf c8 :9 a0 12a bd b7 11
a4 b1 a0 f4 b4 bf c8 :6d a0
12a bd b7 11 a4 b1 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :4 a0 51 a5 b
:2 a0 6b a5 b d :2 a0 51 a5
b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a 52 10 a0 51 d
b7 19 3c :2 a0 d a0 6e d
a0 6e d a0 51 d a0 6e
d a0 4d d a0 4d d :2 a0
e9 dd b3 :2 a0 e9 d3 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :3 a0 6b d :2 a0
e9 c1 :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :f a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c a0 51 d :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:25 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :7 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 6e
a5 b 7e 51 b4 2e a0 6e
d b7 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
d :4 a0 51 a5 b 51 a5 b
d :4 a0 51 a5 b 51 a5 b
d :4 a0 51 a5 b 51 a5 b
d :b a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :b a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :a a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e 7e b4 2e a0
51 d :a a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c b7 19
3c b7 19 3c a0 b7 :3 a0 51
a5 b a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
52 10 5a a 10 a0 51 d
:a a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 :2 19 3c a0
6e d a0 6e d a0 6e d
a0 4d d a0 4d d a0 4d
d :2 a0 e9 dd b3 :2 a0 e9 d3
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
51 d b7 a0 51 d b7 :2 19
3c :2 a0 e9 c1 :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 3c b7 19 3c :b a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
7e b4 2e a 10 a0 6e d
:2 a0 b4 2e d :a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :3 a0
6b :2 a0 51 a5 b :2 a0 6b a5
b d b7 :2 a0 51 :2 a0 51 a5
b :2 a0 6b a0 a5 b d :3 a0
6b d b7 :2 19 3c a0 6e d
a0 51 d :9 a0 a5 b d :4 a0
51 a5 b a5 b d :19 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 a5 b 7e 51 b4
2e a0 51 d b7 :c a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e :a a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :11 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :11 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c a0 b7
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 6e d :6 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :6 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 6e d b7 19 3c
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e 7e b4 2e :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 51 :2 a0 51 a5 b :2 a0 6b
a0 a5 b d :a a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 a5 b d
a0 b7 :3 a0 51 a5 b :2 a0 6b
a5 b 5a a0 7e a0 6b b4
2e :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 a5 b d a0 b7 19
:3 a0 51 a5 b :2 a0 6b a5 b
5a a0 7e a0 6b b4 2e :b a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
a5 b d b7 :2 19 3c b7 19
3c b7 :2 19 3c :16 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
51 d b7 19 3c a0 6e d
a0 6e d a0 6e d :2 a0 b4
2e d :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :c a0 a5
b d :2 a0 51 a5 b 7e 51
b4 2e :3 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e d :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d b7 19 3c
b7 19 3c a0 51 d a0 51
d :6 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 4d d :c a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:7 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 a5 b 7e
51 b4 2e 7e b4 2e a0 7e
b4 2e 5a a0 51 d :23 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e :2 5a a 10
a0 7e 51 b4 2e d :2 a0 6b
:b a0 a5 b d b7 19 3c a0
51 d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e 52 10 :3 a0 51 a5 b
:2 a0 6b a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e a0 51 d b7 19
3c b7 :2 19 3c b7 19 3c :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d b7 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 51 d
a0 51 d a0 7e b4 2e 5a
:2 a0 :2 51 a5 b 7e 6e b4 2e
a0 7e 51 b4 2e d :2 a0 6b
:b a0 a5 b d b7 19 3c :1b a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e 52 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :3 a0 :2 51
a5 b 7e 6e b4 2e 51 a6
122 51 122 124 d :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e :a a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :8 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e :7 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :5 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :5 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 19 3c b7 19 3c
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e 7e b4 2e :2 a0 51 a5
b 7e 51 b4 2e a 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 19
3c a0 7e 51 b4 2e :2 a0 d
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 51 a5 b
7e 51 b4 2e :1e a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :22 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e :1a a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 b7 19 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e :16 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :1a a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 19 :c a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c a0 7e 51 b4 2e :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
d b7 :3 a0 6b :2 a0 51 a5 b
:2 a0 6b a5 b d b7 :2 19 3c
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :3 a0
51 a5 b d b7 19 3c a0
51 d a0 51 d :2 a0 6b a0
51 a5 b 7e 51 b4 2e a0
51 d b7 a0 51 d b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 19 3c :6 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :3 a0
a5 b d :2 a0 51 a5 b a0
7e a0 6b b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 a0 b7 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
51 a5 b :2 a0 a5 57 b7 :2 19
3c a0 51 d :1e a0 :5 51 a5 b
d a0 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 a0 b7 a0
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 a0 51 d
:7 a0 51 a5 b :2 a0 51 a5 b
a5 b d b7 :2 19 3c b7 19
3c b7 19 3c :3 a0 6b d :8 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 19 3c a0
51 d b7 19 3c :3 a0 7e 6e
b4 2e :2 51 a5 b d a0 6e
d :2 a0 d :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 51 d
a0 51 d a0 51 d :2 a0 d
:2 a0 e9 dd b3 :17 a0 e9 d3 5
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
2b b7 19 3c a0 51 d :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b d :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :5 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d b7
19 3c :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 7e 51 b4 2e d
:2 a0 6b :b a0 a5 b d :c a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 51 d :c a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :3 a0
51 a5 b :2 a0 6b a5 b 5a
a0 7e a0 6b b4 2e a0 51
d :8 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 51 a5 b a0
7e a0 6b b4 2e :2 a0 51 :2 a0
51 a5 b :2 a0 6b a0 a5 b
d :d a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 :10 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :3 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 :22 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e :2 5a a 10
:2 a0 51 :2 a0 51 a5 b :2 a0 6b
a0 a5 b d :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :8 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :6 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :2 19 3c :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a0 51 d :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :5 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
:2 51 a5 b 7e 6e b4 2e a0
51 d b7 19 3c :2 a0 d b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e 5a a0 7e b4 2e :2 5a
a 10 :7 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:5 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 b7 :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c b7 19 3c :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 52 10 :2 a0 6e 11e 11d
:2 a0 6b 51 d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a 10 :10 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :1c a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 51 d :7 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
a0 3b b7 :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :5 a0 a5 b 51 a5
b 7e :3 a0 a5 b 51 a5 b
b4 2e 5a 7e 51 b4 2e a5
b d :9 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:2 a0 6b :2 a0 51 a5 b a0 a5
57 b7 19 3c :16 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :1f a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :5 a0
a5 b 51 a5 b 7e :3 a0 a5
b 51 a5 b b4 2e 5a 7e
51 b4 2e a5 b d :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
d :7 a0 51 a5 b :2 a0 51 a5
b a5 b d b7 a0 3b b7
:2 19 3c b7 a0 6e d a0 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e :2 a0 d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e a 10 :2 a0
51 a5 b 7e 51 b4 2e a
10 a0 51 d :3 a0 51 a5 b
d b7 19 3c :c a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :3 a0
51 a5 b :2 a0 6b a5 b 5a
7e 51 b4 2e 5a :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 52 10 5a
a 10 :2 a0 51 a5 b 7e 51
b4 2e :25 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :27 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :21 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 a0 51
d a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :3 a0 51 a5 b d
b7 :2 19 3c b7 :2 19 3c :6 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :3 a0 a5
b d :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
:2 a0 a5 57 b7 :2 19 3c b7 :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e a
10 :2 a0 51 a5 b 7e 51 b4
2e a 10 a0 51 d :3 a0 51
a5 b d b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e 5a 52 10 :3 a0 51
a5 b d b7 :4 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e a5
b d b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b 7e 51 b4 2e d b7 :5 a0
51 a5 b a5 b 7e 51 b4
2e a5 b d b7 :2 19 3c :2 a0
51 a5 b 7e 51 b4 2e :c a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:21 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c a0 51
d :2 a0 51 a5 b a0 7e a0
6b b4 2e a0 51 d b7 a0
51 d b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e :3 a0 6b d
b7 :3 a0 6b :2 a0 51 a5 b :2 a0
6b a5 b d b7 :2 19 3c a0
51 d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :4 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e 5a 7e 51
b4 2e 5a 7e 51 b4 2e a5
b d :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :3 a0 51
a5 b d :4 a0 51 a5 b 7e
51 b4 2e 5a 7e :2 a0 51 a5
b b4 2e 7e 51 b4 2e a5
b d b7 19 3c a0 b7 :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :3 a0 51 a5 b d
b7 :2 19 3c b7 19 3c :1e a0 :5 51
a5 b d a0 7e 51 b4 2e
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 a0 b7 a0 7e 51 b4
2e :2 a0 e9 c1 :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 19 3c b7 :2 19
3c :7 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :18 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b 7e 51 b4
2e d :3 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e d a0 6e
d :5 a0 a5 b d a0 6e d
:5 a0 a5 b d :7 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:11 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e :d a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b d a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e :d a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b d b7
19 :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b d :3 a0 51
a5 b d b7 :2 19 3c b7 19
3c b7 :2 19 3c :2 a0 6b :4 a0 a5
b d 93 4f b0 46 b7 a0
47 :2 a0 e9 c1 :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 51 d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 a0 7e b4
2e :2 5a a 10 :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
a0 51 d a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b d b7 :2 19 3c :6 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :3 a0 a5 b
d :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 :2 19 3c :2 a0
6e 11e 11d :2 a0 6b 51 d :a a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
6e d a0 51 d a0 51 d
a0 51 d a0 51 d :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
d a0 51 d b7 a0 51 d
b7 :2 19 3c a0 51 d :1e a0 :5 51
a5 b d a0 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 a0
b7 a0 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 :1c a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 19 3c a0 b7 a0
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a 10 a0 7e
b4 2e 5a a 10 :7 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:8 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 19 3c
a0 51 d a0 7e b4 2e 5a
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:7 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :5 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
a0 51 d :5 a0 :2 51 a5 b d
:19 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e :f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :11 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
:2 51 a5 b 7e 6e b4 2e 5a
a0 51 d :2 a0 6b :b a0 a5 b
d b7 19 3c b7 19 3c a0
7e b4 2e :2 5a :2 a0 6b :2 a0 a5
b 7e 51 b4 2e 5a a 10
a0 51 d b7 19 3c b7 19
3c b7 19 3c a0 7e b4 2e
5a a0 51 d :5 a0 :2 51 a5 b
d :19 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :11 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
:2 51 a5 b 7e 6e b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 a0 51 d :2 a0 6b
:b a0 a5 b d b7 19 3c b7
19 3c :3 a0 a5 b d :2 a0 6b
7e 51 b4 2e :2 a0 6b 51 d
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
5217
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 175 155
159 15c 15d 165 169 16d 170 154
192 180 151 184 185 18d 17f 1af
19d 17c 1a1 1a2 1aa 19c 1cc 1ba
199 1be 1bf 1c7 1b9 1e9 1d7 1b6
1db 1dc 1e4 1d6 206 1f4 1d3 1f8
1f9 201 1f3 223 211 1f0 215 216
21e 210 240 22e 20d 232 233 23b
22d 25d 24b 22a 24f 250 258 24a
27a 268 247 26c 26d 275 267 297
285 264 289 28a 292 284 2b4 2a2
281 2a6 2a7 2af 2a1 2d1 2bf 29e
2c3 2c4 2cc 2be 2ee 2dc 2bb 2e0
2e1 2e9 2db 30a 2f9 2fd 305 2d8
322 311 315 31d 2f8 33e 32d 331
339 2f5 356 345 349 351 32c 373
361 329 365 366 36e 360 390 37e
35d 382 383 38b 37d 3ac 39b 39f
3a7 37a 3c4 3b3 3b7 3bf 39a 3e0
3cf 3d3 3db 397 3fc 3e7 3eb 3ee
3ef 3f7 3ce 419 407 3cb 40b 40c
414 406 435 424 428 430 403 44d
43c 440 448 423 469 458 45c 464
420 481 470 474 47c 457 49e 48c
454 490 491 499 48b 4bb 4a9 488
4ad 4ae 4b6 4a8 4d8 4c6 4a5 4ca
4cb 4d3 4c5 4f5 4e3 4c2 4e7 4e8
4f0 4e2 512 500 4df 504 505 50d
4ff 52e 51d 521 4fc 529 51c 54a
539 53d 519 545 538 566 555 559
535 561 554 582 571 575 551 57d
570 59e 58d 591 56d 599 58c 5ba
5a9 5ad 589 5b5 5a8 5d6 5c5 5c9
5a5 5d1 5c4 5f2 5e1 5e5 5c1 5ed
5e0 60e 5fd 601 5dd 609 5fc 62a
619 61d 5f9 625 618 646 635 639
615 641 634 662 651 655 631 65d
650 67e 66d 671 64d 679 66c 69a
689 68d 669 695 688 6b6 6a5 6a9
685 6b1 6a4 6d2 6c1 6c5 6a1 6cd
6c0 6ee 6dd 6e1 6bd 6e9 6dc 70a
6f9 6fd 6d9 705 6f8 726 715 719
6f5 721 714 742 731 735 711 73d
730 75e 74d 751 72d 759 74c 77a
769 76d 749 775 768 796 785 789
765 791 784 7b2 7a1 7a5 781 7ad
7a0 7ce 7bd 7c1 79d 7c9 7bc 7ea
7d9 7dd 7b9 7e5 7d8 806 7f5 7f9
7d5 801 7f4 822 811 815 7f1 81d
810 83e 82d 831 80d 839 82c 85a
849 84d 829 855 848 876 865 869
845 871 864 892 881 885 861 88d
880 8ae 89d 8a1 87d 8a9 89c 8ca
8b9 8bd 899 8c5 8b8 8e6 8d5 8d9
8b5 8e1 8d4 902 8f1 8f5 8d1 8fd
8f0 91e 90d 911 8ed 919 90c 93a
929 92d 909 935 928 956 945 949
925 951 944 972 961 965 941 96d
960 98e 97d 981 95d 989 97c 9aa
999 99d 979 9a5 998 9c6 9b5 9b9
995 9c1 9b4 9e3 9d1 9b1 9d5 9d6
9de 9d0 a00 9ee 9cd 9f2 9f3 9fb
9ed a1c a0b a0f 9ea a17 a0a a38
a27 a2b a07 a33 a26 a55 a43 a23
a47 a48 a50 a42 a71 a60 a64 a3f
a6c a5f a8e a7c a5c a80 a81 a89
a7b aab a99 a78 a9d a9e aa6 a98
ac7 ab6 aba a95 ac2 ab5 ae3 ad2
ad6 ab2 ade ad1 aff aee af2 afa
ace b17 b06 b0a b12 aed b33 b22
b26 aea b2e b21 b4f b3e b42 b1e
b4a b3d b6b b5a b5e b3a b66 b59
b87 b76 b7a b56 b82 b75 ba3 b92
b96 b72 b9e b91 bbf bae bb2 b8e
bba bad bdb bca bce baa bd6 bc9
bf7 be6 bea bc6 bf2 be5 c13 c02
c06 be2 c0e c01 c2f c1e c22 bfe
c2a c1d c4b c3a c3e c1a c46 c39
c68 c56 c36 c5a c5b c63 c55 c85
c73 c52 c77 c78 c80 c72 ca2 c90
c6f c94 c95 c9d c8f cbe cad cb1
c8c cb9 cac cef cc9 ccd cd5 cd9
cdd ca9 ce1 ce2 ce4 ce5 ce7 cea
cc8 d0b cfa cfe cc5 d06 cf9 d27
d16 d1a cf6 d22 d15 d43 d32 d36
d3e d12 d5b d4a d4e d56 d31 d62
d66 d2e d77 d7a d7e d82 d86 d8a
d8e d92 d9e da3 da5 db1 db5 db7
dbb dcc dcd dd0 dd4 dd8 ddc de0
de4 de8 dec df0 df4 df8 e04 e09
e0b e17 e1b e1d e21 e32 e33 e36
e3a e3e e42 e46 e4a e4e e52 e56
e5a e5e e62 e66 e6a e6e e72 e76
e7a e7e e82 e86 e8a e8e e92 e96
e9a e9e ea2 ea6 eaa eae eb2 eb6
eba ebe ec2 ec6 eca ece ed2 ed6
eda ede ee2 ee6 eea eee ef2 ef6
efa efe f02 f06 f0a f0e f12 f16
f1a f1e f22 f26 f2a f2e f32 f36
f3a f3e f42 f46 f4a f4e f52 f56
f5a f5e f62 f66 f6a f6e f72 f76
f7a f7e f82 f86 f8a f8e f92 f96
f9a f9e fa2 fa6 faa fae fb2 fb6
fba fbe fc2 fc6 fca fce fd2 fd6
fda fde fe2 fe6 fea fee ffa fff
1001 100d 1011 102f 1017 101b 101f 1022
102a 1016 1036 103a 1013 103e 1042 1046
1049 104e 104f 1 1051 1056 105a 105e
1061 1066 106a 106e 1071 1076 1077 1079
107e 1081 1085 1086 108b 1090 1093 1098
1099 109e 10a1 10a5 10a6 10ab 10ae 10b3
10b4 10b9 10bc 10c1 10c2 10c7 10ca 10cf
10d0 10d5 10d8 10dc 10dd 10e2 10e5 10ea
10eb 10f0 10f3 10f8 10f9 10fe 1101 1106
1107 110c 110f 1113 1114 1119 111c 1121
1122 1127 112a 112f 1130 1135 1138 113d
113e 1143 1146 114a 114b 1150 1153 1158
1159 115e 1161 1166 1167 116c 116f 1174
1175 117a 117d 1181 1182 1187 118a 118f
1190 1195 1198 119d 119e 11a3 11a6 11aa
11ae 11b2 11b3 11b5 11ba 11bb 11bd 11be
11c3 11c6 11cb 11cc 11d1 11d4 11d8 11dc
11e0 11e1 11e3 11e8 11e9 11eb 11ec 11f1
11f4 11f9 11fa 11ff 1202 1206 120a 120e
120f 1211 1216 1217 1219 121a 121f 1222
1227 1228 122d 1230 1234 1238 123c 123d
123f 1244 1245 1247 1248 124d 1250 1255
1256 125b 125e 1262 1266 126a 126b 126d
1272 1273 1275 1276 127b 127e 1283 1284
1289 128c 1290 1294 1298 1299 129b 12a0
12a1 12a3 12a4 12a9 12ac 12b1 12b2 12b7
12ba 12be 12c2 12c6 12c7 12c9 12ce 12cf
12d1 12d2 12d7 12da 12df 12e0 12e5 12e8
12ec 12f0 12f4 12f5 12f7 12fc 12fd 12ff
1300 1305 1308 130d 130e 1313 1316 131a
131e 1322 1323 1325 132a 132b 132d 132e
1333 1336 133b 133c 1341 1344 1349 134a
134f 1352 1356 1357 135c 135f 1364 1365
136a 136d 1372 1373 1378 1379 137e 1380
1384 1387 138b 138f 1392 1396 139a 139d
13a0 13a5 13a8 13ab 13ae 13af 13b4 13b5
1 13b7 13bc 13c0 13c4 13c7 13cc 13d1
13d4 13d8 13d9 13de 13df 13e4 13e6 13ea
13ed 13f1 13f5 13f9 13fd 1401 1405 1409
140d 1411 1415 1419 141d 1421 1425 1429
142d 1431 1435 1439 143d 1441 1445 1448
1449 144b 144f 1453 1456 1457 1459 145d
1461 1465 1468 1469 146b 146f 1472 1476
1479 147a 147f 1482 1486 148a 148d 148e
1490 1494 1497 149b 149e 149f 14a4 1
14a7 14ac 14b0 14b3 14b7 14b9 14bd 14c0
14c4 14c8 14cc 14d0 14d5 14d9 14dd 14e2
14e6 14ea 14ed 14f1 14f5 14fa 14fe 1502
1503 1507 150b 150c 1510 1514 1518 151d
1521 1522 1526 152a 152f 1534 1538 153c
1541 1545 1549 154c 154f 1553 1555 1559
155d 1560 1563 1567 1569 156d 1571 1574
1578 157c 1580 1583 1587 158b 158f 1594
1596 159a 159e 15a1 15a5 15a9 15ab 15af
15b3 15b7 15ba 15be 15c2 15c4 15c5 15ca
1 15ce 15d2 15d6 15d9 15dd 15e1 15e5
15e9 15ec 15f0 15f4 15f7 15fa 15ff 1602
1605 1608 1609 160e 160f 1 1611 1616
161a 161e 1621 1626 162b 162e 1632 1633
1638 163b 1640 1641 1646 1649 164e 164f
1654 1657 165b 165c 1661 1664 1669 166a
166f 1672 1676 167a 167d 1680 1681 1683
1684 1689 168a 168f 1691 1695 1698 169a
169e 16a0 16ac 16ae 16b0 16b1 16b6 16ba
16bc 16c8 16ca 16ce 16d2 16d5 16d6 16d8
16db 16de 16df 16e4 16e8 16ec 16ef 16f3
16f7 16fa 16fd 1702 1705 1708 170b 170c
1711 1712 1 1714 1719 171d 1721 1724
1729 172e 1731 1735 1736 173b 173e 1743
1744 1749 174c 1751 1752 1757 175a 175e
1762 1766 176a 176d 176e 1770 1775 1776
1778 1779 177e 1781 1786 1787 178c 178f
1794 1795 179a 179d 17a1 17a2 17a7 17aa
17af 17b0 17b5 17b6 17bb 17bd 17c1 17c4
17c8 17cc 17cf 17d3 17d7 17da 17dd 17e2
17e5 17e8 17eb 17ec 17f1 17f2 1 17f4
17f9 17fd 1801 1804 1809 180e 1811 1815
1816 181b 181c 1821 1823 1827 182a 182e
1832 1835 1839 183d 1840 1844 1848 1849
184e 1850 1854 1857 185b 185f 1863 1867
186b 186f 1873 1877 187b 187f 1883 1887
188b 188f 1893 189f 18a3 18a7 18aa 18ae
18b2 18b4 18b8 18bc 18c0 18c3 18c7 18cb
18cd 18ce 18d3 1 18d7 18db 18df 18e2
18e6 18ea 18ee 18f2 18f5 18f9 18fd 1900
1903 1908 190b 190e 1911 1912 1917 1918
1 191a 191f 1923 1927 192a 192f 1934
1937 193b 193c 1941 1944 1949 194a 194f
1952 1957 1958 195d 1960 1964 1965 196a
196d 1972 1973 1978 197b 197f 1983 1986
1989 198a 198c 198d 1992 1993 1998 199a
199e 19a1 19a3 19a7 19a9 19b5 19b7 19b9
19ba 19bf 19c3 19c5 19d1 19d3 19d7 19db
19de 19e2 19e5 19e9 19ec 19ed 19f2 19f5
19f9 19fd 1a00 1a04 1a08 1a0b 1a0e 1a13
1a16 1a19 1a1c 1a1d 1a22 1a23 1 1a25
1a2a 1a2e 1a32 1a35 1a3a 1a3f 1a42 1a46
1a47 1a4c 1a4f 1a54 1a55 1a5a 1a5d 1a62
1a63 1a68 1a6b 1a6f 1a73 1a77 1a7b 1a7e
1a7f 1a81 1a86 1a87 1a89 1a8a 1a8f 1a92
1a97 1a98 1a9d 1aa0 1aa5 1aa6 1aab 1aae
1ab2 1ab3 1ab8 1abb 1ac0 1ac1 1ac6 1ac7
1acc 1ace 1ad2 1ad5 1ad9 1add 1ae0 1ae4
1ae8 1aeb 1aee 1af3 1af6 1af9 1afc 1afd
1b02 1b03 1 1b05 1b0a 1b0e 1b12 1b15
1b1a 1b1f 1b22 1b26 1b27 1b2c 1b2d 1b32
1b34 1b38 1b3b 1b3f 1b43 1b46 1b4a 1b4e
1b51 1b55 1b59 1b5a 1b5f 1b61 1b65 1b68
1b6c 1b6f 1b73 1b77 1b7b 1b7f 1b83 1b87
1b93 1b97 1b9b 1b9e 1ba2 1ba6 1ba8 1bac
1bb0 1bb4 1bb7 1bbb 1bbf 1bc1 1bc2 1bc7
1 1bcb 1bcf 1bd3 1bd6 1bda 1bde 1be2
1be6 1be9 1bed 1bf1 1bf4 1bf7 1bfc 1bff
1c02 1c05 1c06 1c0b 1c0c 1 1c0e 1c13
1c17 1c1b 1c1e 1c23 1c28 1c2b 1c2f 1c30
1c35 1c38 1c3d 1c3e 1c43 1c46 1c4b 1c4c
1c51 1c54 1c58 1c59 1c5e 1c61 1c66 1c67
1c6c 1c6f 1c73 1c77 1c7a 1c7d 1c7e 1c80
1c81 1c86 1c87 1c8c 1c8e 1c92 1c95 1c97
1c9b 1c9d 1ca9 1cab 1cad 1cae 1cb3 1cb7
1cb9 1cc5 1cc7 1ccb 1ccf 1cd2 1cd3 1cd5
1cd8 1cdb 1cdc 1ce1 1ce5 1ce9 1cec 1cf0
1cf4 1cf7 1cfa 1cff 1d02 1d05 1d08 1d09
1d0e 1d0f 1 1d11 1d16 1d1a 1d1e 1d21
1d26 1d2b 1d2e 1d32 1d33 1d38 1d3b 1d40
1d41 1d46 1d49 1d4e 1d4f 1d54 1d57 1d5b
1d5f 1d63 1d67 1d6a 1d6b 1d6d 1d72 1d73
1d75 1d76 1d7b 1d7e 1d83 1d84 1d89 1d8c
1d91 1d92 1d97 1d9a 1d9e 1d9f 1da4 1da7
1dac 1dad 1db2 1db3 1db8 1dba 1dbe 1dc1
1dc5 1dc9 1dcc 1dd0 1dd4 1dd7 1dda 1ddf
1de2 1de5 1de8 1de9 1dee 1def 1 1df1
1df6 1dfa 1dfe 1e01 1e06 1e0b 1e0e 1e12
1e13 1e18 1e19 1e1e 1e20 1e24 1e27 1e2b
1e2f 1e32 1e36 1e3a 1e3d 1e41 1e45 1e46
1e4b 1e4d 1e51 1e54 1e58 1e5c 1e60 1e64
1e68 1e6c 1e70 1e74 1e78 1e7c 1e80 1e84
1e88 1e8c 1e90 1e94 1e98 1e9c 1ea0 1ea4
1ea8 1eac 1eb0 1eb4 1eb8 1ebc 1ec0 1ec4
1ec8 1ecc 1ed0 1ed4 1ed8 1edc 1ee0 1ee4
1ee8 1ef4 1ef8 1efc 1eff 1f03 1f07 1f09
1f0d 1f11 1f15 1f18 1f1c 1f20 1f22 1f23
1f28 1 1f2c 1f30 1f34 1f37 1f3b 1f3f
1f43 1f47 1f4a 1f4e 1f52 1f55 1f58 1f5d
1f60 1f63 1f66 1f67 1f6c 1f6d 1 1f6f
1f74 1f78 1f7c 1f7f 1f84 1f89 1f8c 1f90
1f91 1f96 1f99 1f9e 1f9f 1fa4 1fa7 1fac
1fad 1fb2 1fb5 1fb9 1fba 1fbf 1fc2 1fc7
1fc8 1fcd 1fd0 1fd4 1fd8 1fdb 1fde 1fdf
1fe1 1fe2 1fe7 1fe8 1fed 1fef 1ff3 1ff6
1ff8 1ffc 1ffe 200a 200c 200e 200f 2014
2018 201a 2026 2028 202c 2030 2033 2037
203a 203e 2041 2042 2047 204a 204e 2052
2055 2059 205d 2060 2063 2068 206b 206e
2071 2072 2077 2078 1 207a 207f 2083
2087 208a 208f 2094 2097 209b 209c 20a1
20a4 20a9 20aa 20af 20b2 20b7 20b8 20bd
20c0 20c4 20c8 20cc 20d0 20d3 20d4 20d6
20db 20dc 20de 20df 20e4 20e7 20ec 20ed
20f2 20f5 20fa 20fb 2100 2103 2107 2108
210d 2110 2115 2116 211b 211c 2121 2123
2127 212a 212e 2132 2135 2139 213d 2140
2143 2148 214b 214e 2151 2152 2157 2158
1 215a 215f 2163 2167 216a 216f 2174
2177 217b 217c 2181 2182 2187 2189 218d
2190 2194 2198 219b 219f 21a3 21a6 21aa
21ae 21af 21b4 21b6 21ba 21bd 21c1 21c5
21c9 21cd 21d1 21d5 21d9 21e5 21e9 21ed
21f0 21f4 21f8 21fa 21fe 2202 2206 2209
220d 2211 2213 2214 2219 1 221d 2221
2225 2228 222c 2230 2234 2238 223b 223f
2243 2246 2249 224e 2251 2254 2257 2258
225d 225e 1 2260 2265 2269 226d 2270
2275 227a 227d 2281 2282 2287 228a 228f
2290 2295 2298 229d 229e 22a3 22a6 22aa
22ab 22b0 22b3 22b8 22b9 22be 22c1 22c5
22c9 22cc 22cf 22d0 22d2 22d3 22d8 22d9
22de 22e0 22e4 22e7 22e9 22ed 22ef 22fb
22fd 22ff 2300 2305 2309 230b 2317 2319
231d 2321 2324 2328 232b 232f 2332 2333
2338 233b 233f 2343 2346 234a 234e 2351
2354 2359 235c 235f 2362 2363 2368 2369
1 236b 2370 2374 2378 237b 2380 2385
2388 238c 238d 2392 2395 239a 239b 23a0
23a3 23a8 23a9 23ae 23b1 23b5 23b9 23bd
23c1 23c4 23c5 23c7 23cc 23cd 23cf 23d0
23d5 23d8 23dd 23de 23e3 23e6 23eb 23ec
23f1 23f4 23f8 23f9 23fe 2401 2406 2407
240c 240d 2412 2414 2418 241b 241f 2423
2426 242a 242e 2431 2434 2439 243c 243f
2442 2443 2448 2449 1 244b 2450 2454
2458 245b 2460 2465 2468 246c 246d 2472
2473 2478 247a 247e 2481 2485 2489 248c
2490 2494 2497 249b 249f 24a0 24a5 24a7
24ab 24ae 24b2 24b6 24ba 24be 24c2 24ce
24d2 24d6 24d9 24dd 24e1 24e3 24e7 24eb
24ef 24f2 24f6 24fa 24fc 24fd 2502 1
2506 250a 250e 2511 2515 2519 251d 2521
2524 2528 252c 252f 2532 2537 253a 253d
2540 2541 2546 2547 1 2549 254e 2552
2556 2559 255e 2563 2566 256a 256b 2570
2573 2578 2579 257e 2581 2586 2587 258c
258f 2593 2594 2599 259c 25a1 25a2 25a7
25aa 25ae 25b2 25b5 25b8 25b9 25bb 25bc
25c1 25c2 25c7 25c9 25cd 25d0 25d2 25d6
25d8 25e4 25e6 25e8 25e9 25ee 25f2 25f4
2600 2602 2606 260a 260d 2611 2616 2617
2619 261c 261f 2620 2625 2629 262e 2632
2634 2638 263b 263f 2643 2646 264a 264d
2651 2654 2655 265a 265d 2661 2665 2668
266c 2670 2673 2676 267b 267e 2681 2684
2685 268a 268b 1 268d 2692 2696 269a
269d 26a2 26a7 26aa 26ae 26af 26b4 26b7
26bc 26bd 26c2 26c5 26ca 26cb 26d0 26d3
26d7 26db 26df 26e3 26e6 26e7 26e9 26ee
26ef 26f1 26f2 26f7 26fa 26ff 2700 2705
2708 270d 270e 2713 2716 271a 271b 2720
2723 2728 2729 272e 272f 2734 2736 273a
273d 2741 2745 2748 274c 2750 2753 2756
275b 275e 2761 2764 2765 276a 276b 1
276d 2772 2776 277a 277d 2782 2787 278a
278e 278f 2794 2795 279a 279c 27a0 27a3
27a7 27ab 27ae 27b2 27b6 27b9 27bd 27c1
27c2 27c7 27c9 27cd 27d0 27d4 27d8 27dc
27e0 27e4 27e8 27ec 27ef 27f0 27f2 27f5
27f6 27f8 27fc 2800 2804 2808 280c 280f
2810 2812 2815 2816 2818 281c 2820 2824
2828 282c 282f 2830 2832 2835 2836 2838
283c 2840 2844 2848 284c 2850 2854 2858
285c 2860 2864 2868 2874 2878 287c 287f
2883 2887 2889 288d 2891 2895 2898 289c
28a0 28a2 28a3 28a8 1 28ac 28b0 28b4
28b7 28bb 28bf 28c3 28c7 28ca 28ce 28d2
28d5 28d8 28dd 28e0 28e3 28e6 28e7 28ec
28ed 1 28ef 28f4 28f8 28fc 28ff 2904
2909 290c 2910 2911 2916 2919 291e 291f
2924 2927 292c 292d 2932 2935 2939 293a
293f 2942 2947 2948 294d 2950 2954 2958
295b 295e 295f 2961 2962 2967 2968 296d
296f 2973 2976 2978 297c 297e 298a 298c
298e 298f 2994 2998 299a 29a6 29a8 29ac
29b0 29b4 29b8 29bc 29c0 29c4 29c8 29cc
29d0 29d4 29e0 29e4 29e8 29eb 29ef 29f3
29f5 29f9 29fd 2a01 2a04 2a08 2a0c 2a0e
2a0f 2a14 1 2a18 2a1c 2a20 2a23 2a27
2a2b 2a2f 2a33 2a36 2a3a 2a3e 2a41 2a44
2a49 2a4c 2a4f 2a52 2a53 2a58 2a59 1
2a5b 2a60 2a64 2a68 2a6b 2a70 2a75 2a78
2a7c 2a7d 2a82 2a85 2a8a 2a8b 2a90 2a93
2a98 2a99 2a9e 2aa1 2aa5 2aa6 2aab 2aae
2ab3 2ab4 2ab9 2abc 2ac0 2ac4 2ac7 2aca
2acb 2acd 2ace 2ad3 2ad4 2ad9 2adb 2adf
2ae2 2ae4 2ae8 2aea 2af6 2af8 2afa 2afb
2b00 2b04 2b06 2b12 2b14 2b18 2b1b 2b1e
2b1f 2b24 2b28 2b2c 2b2f 2b30 2b32 2b35
2b38 2b39 2b3e 2b42 2b46 2b4a 2b4e 2b52
2b56 2b5a 2b5e 2b62 2b66 2b72 2b76 2b7a
2b7d 2b81 2b85 2b87 2b8b 2b8f 2b93 2b96
2b9a 2b9e 2ba0 2ba1 2ba6 1 2baa 2bae
2bb2 2bb5 2bb9 2bbd 2bc1 2bc5 2bc8 2bcc
2bd0 2bd3 2bd6 2bdb 2bde 2be1 2be4 2be5
2bea 2beb 1 2bed 2bf2 2bf6 2bfa 2bfd
2c02 2c07 2c0a 2c0e 2c0f 2c14 2c17 2c1c
2c1d 2c22 2c25 2c2a 2c2b 2c30 2c33 2c37
2c38 2c3d 2c40 2c45 2c46 2c4b 2c4e 2c52
2c56 2c59 2c5c 2c5d 2c5f 2c60 2c65 2c66
2c6b 2c6d 2c71 2c74 2c76 2c7a 2c7c 2c88
2c8a 2c8c 2c8d 2c92 2c96 2c98 2ca4 2ca6
2caa 2cae 2cb1 2cb2 2cb4 2cb7 2cba 2cbb
2cc0 2cc3 2cc4 2cc9 2ccd 2cd0 2cd4 2cd8
2cdc 2ce0 2ce4 2ce8 2cec 2cf0 2cf4 2cf8
2cfc 2d08 2d0c 2d10 2d13 2d17 2d1b 2d1d
2d21 2d25 2d29 2d2c 2d30 2d34 2d36 2d37
2d3c 1 2d40 2d44 2d48 2d4b 2d4f 2d53
2d57 2d5b 2d5e 2d62 2d66 2d69 2d6c 2d71
2d74 2d77 2d7a 2d7b 2d80 2d81 1 2d83
2d88 2d8c 2d90 2d93 2d98 2d9d 2da0 2da4
2da5 2daa 2dad 2db2 2db3 2db8 2dbb 2dc0
2dc1 2dc6 2dc9 2dcd 2dce 2dd3 2dd6 2ddb
2ddc 2de1 2de4 2de8 2dec 2def 2df2 2df3
2df5 2df6 2dfb 2dfc 2e01 2e03 2e07 2e0a
2e0c 2e10 2e12 2e1e 2e20 2e22 2e23 2e28
2e2c 2e2e 2e3a 2e3c 2e40 2e44 2e47 2e48
2e4a 2e4d 2e50 2e51 2e56 2e5a 2e5e 2e61
2e65 2e69 2e6c 2e6f 2e74 2e77 2e7a 2e7d
2e7e 2e83 2e84 1 2e86 2e8b 2e8f 2e93
2e96 2e9b 2ea0 2ea3 2ea7 2ea8 2ead 2eb0
2eb5 2eb6 2ebb 2ebe 2ec3 2ec4 2ec9 2ecc
2ed0 2ed4 2ed8 2edc 2edf 2ee0 2ee2 2ee7
2ee8 2eea 2eeb 2ef0 2ef3 2ef8 2ef9 2efe
2f01 2f06 2f07 2f0c 2f0f 2f13 2f14 2f19
2f1c 2f21 2f22 2f27 2f28 2f2d 2f2f 2f33
2f36 2f3a 2f3e 2f41 2f45 2f49 2f4c 2f4f
2f54 2f57 2f5a 2f5d 2f5e 2f63 2f64 1
2f66 2f6b 2f6f 2f73 2f76 2f7b 2f80 2f83
2f87 2f88 2f8d 2f8e 2f93 2f95 2f99 2f9c
2fa0 2fa4 2fa7 2fab 2faf 2fb2 2fb6 2fba
2fbb 2fc0 2fc2 2fc6 2fc9 2fcb 2fcf 2fd2
2fd4 2fd8 2fdb 2fdf 2fe1 2fe5 2fe9 2fed
2ff0 2ff1 2ff3 2ff4 2ff6 2ff9 2ffc 2ffd
3002 3006 300a 300d 300e 3010 3013 3016
3017 301c 3020 3024 3027 3028 302a 302d
3030 3031 1 3036 303b 1 303e 3043
3047 304a 304e 3052 3056 305a 305e 3062
3066 306a 306e 3072 3076 3082 3086 308a
308d 3091 3095 3097 309b 309f 30a3 30a6
30aa 30ae 30b0 30b1 30b6 1 30ba 30be
30c2 30c5 30c9 30cd 30d1 30d5 30d8 30dc
30e0 30e3 30e6 30eb 30ee 30f1 30f4 30f5
30fa 30fb 1 30fd 3102 3106 310a 310d
3112 3117 311a 311e 311f 3124 3127 312c
312d 3132 3135 313a 313b 3140 3143 3147
3148 314d 3150 3155 3156 315b 315e 3162
3166 3169 316c 316d 316f 3170 3175 3176
317b 317d 3181 3184 3186 318a 318c 3198
319a 319c 319d 31a2 31a6 31a8 31b4 31b6
31ba 31be 31c1 31c2 31c4 31c7 31ca 31cb
31d0 31d4 31d8 31db 31df 31e3 31e6 31e9
31ee 31f1 31f4 31f7 31f8 31fd 31fe 1
3200 3205 3209 320d 3210 3215 321a 321d
3221 3222 3227 322a 322f 3230 3235 3238
323d 323e 3243 3246 324a 324e 3252 3256
3259 325a 325c 3261 3262 3264 3265 326a
326d 3272 3273 3278 327b 3280 3281 3286
3289 328d 328e 3293 3296 329b 329c 32a1
32a2 32a7 32a9 32ad 32b0 32b4 32b8 32bb
32bf 32c3 32c6 32c9 32ce 32d1 32d4 32d7
32d8 32dd 32de 1 32e0 32e5 32e9 32ed
32f0 32f5 32fa 32fd 3301 3302 3307 3308
330d 330f 3313 3316 331a 331e 3321 3325
3329 332c 3330 3334 3335 333a 333c 3340
3343 3345 3349 334d 3350 3354 3359 335d
3361 3366 336a 336e 3373 3377 337b 337c
3380 3384 3385 3389 338d 338e 3392 3396
339a 339f 33a3 33a4 33a8 33ac 33b1 33b6
33ba 33be 33c3 33c7 33cb 33ce 33d1 33d5
33d7 33db 33df 33e2 33e5 33e9 33eb 33ef
33f3 33f6 33fa 33fe 3401 3405 3408 340c
340f 3410 3415 3418 341c 341f 3423 3425
3429 342c 3430 3432 3436 343a 343d 3441
3445 344a 344c 3450 3454 3457 345b 345f
3461 3465 3469 346d 3470 3474 3478 347a
347b 3480 1 3484 3488 348c 348f 3493
3497 349b 349f 34a2 34a6 34aa 34ad 34b0
34b5 34b8 34bb 34be 34bf 34c4 34c5 1
34c7 34cc 34d0 34d4 34d7 34dc 34e1 34e4
34e8 34e9 34ee 34f1 34f6 34f7 34fc 34ff
3504 3505 350a 350d 3511 3512 3517 351a
351f 3520 3525 3528 352c 3530 3533 3536
3537 3539 353a 353f 3540 3545 3547 354b
354e 3550 3554 3556 3562 3564 3566 3567
356c 3570 3572 357e 3580 3584 3588 358b
358c 358e 3591 3594 3595 359a 359e 35a2
35a5 35a6 35a8 35ab 35ae 35af 35b4 35b8
35bb 35bf 35c1 35c5 35c8 35ca 35ce 35d1
35d5 35d9 35dd 35e1 35e5 35e9 35ed 35f1
35f5 35f9 35fd 3609 360d 3611 3614 3618
361c 361e 3622 3626 362a 362d 3631 3635
3637 3638 363d 1 3641 3645 3649 364c
3650 3654 3658 365c 365f 3663 3667 366a
366d 3672 3675 3678 367b 367c 3681 3682
1 3684 3689 368d 3691 3694 3699 369e
36a1 36a5 36a6 36ab 36ae 36b3 36b4 36b9
36bc 36c1 36c2 36c7 36ca 36ce 36cf 36d4
36d7 36dc 36dd 36e2 36e5 36e9 36ed 36f0
36f3 36f4 36f6 36f7 36fc 36fd 3702 3704
3708 370b 370d 3711 3713 371f 3721 3723
3724 3729 372d 372f 373b 373d 3741 3745
3748 374c 374f 3753 3756 3757 375c 375f
3763 3767 376a 376b 376d 3770 3773 3774
3779 377c 377d 1 3782 3787 378b 3790
3794 3798 379c 379d 37a2 37a6 37aa 37ae
37b2 37b6 37ba 37be 37c2 37c6 37ca 37ce
37da 37de 37e2 37e5 37e9 37ed 37ef 37f3
37f7 37fb 37fe 3802 3806 3808 3809 380e
1 3812 3816 381a 381d 3821 3825 3829
382d 3830 3834 3838 383b 383e 3843 3846
3849 384c 384d 3852 3853 1 3855 385a
385e 3862 3865 386a 386f 3872 3876 3877
387c 387f 3884 3885 388a 388d 3892 3893
3898 389b 389f 38a0 38a5 38a8 38ad 38ae
38b3 38b6 38ba 38be 38c1 38c4 38c5 38c7
38c8 38cd 38ce 38d3 38d5 38d9 38dc 38de
38e2 38e4 38f0 38f2 38f4 38f5 38fa 38fe
3900 390c 390e 3912 3916 3919 391d 3920
3924 3927 3928 392d 3930 3934 3938 393c
393f 3943 3947 394a 394b 394d 3951 3955
3958 3959 395b 395f 3961 3965 3969 396c
3970 3974 3977 3978 397a 397e 3982 3985
3989 398a 398c 3990 3994 3998 399c 399f
39a3 39a5 39a9 39ad 39b0 39b4 39b9 39bd
39c1 39c4 39c8 39cc 39d0 39d4 39d8 39dc
39e0 39e4 39e8 39ec 39ed 39ef 39f3 39f7
39fb 39ff 3a03 3a06 3a07 3a09 3a0a 3a0c
3a10 3a14 3a18 3a1c 3a20 3a24 3a28 3a2c
3a30 3a34 3a38 3a3c 3a40 3a44 3a48 3a4c
3a50 3a54 3a58 3a5c 3a60 3a64 3a68 3a6c
3a70 3a74 3a80 3a84 3a89 3a8d 3a90 3a91
3a96 3a9a 3a9e 3aa1 3aa4 3aa8 3aaa 3aae
3ab2 3ab5 3ab8 3abc 3abe 3ac2 3ac6 3ac9
3acb 3acf 3ad3 3ad7 3ada 3ade 3ae2 3ae4
3ae5 3aea 1 3aee 3af2 3af6 3af9 3afd
3b01 3b05 3b09 3b0c 3b10 3b14 3b17 3b1a
3b1f 3b22 3b25 3b28 3b29 3b2e 3b2f 1
3b31 3b36 3b3a 3b3e 3b41 3b46 3b4b 3b4e
3b52 3b53 3b58 3b5b 3b60 3b61 3b66 3b69
3b6e 3b6f 3b74 3b77 3b7b 3b7c 3b81 3b84
3b89 3b8a 3b8f 3b92 3b96 3b9a 3b9d 3ba0
3ba1 3ba3 3ba4 3ba9 3baa 3baf 3bb1 3bb5
3bb8 3bba 3bbe 3bc0 3bcc 3bce 3bd0 3bd1
3bd6 3bda 3bdc 3be8 3bea 3bee 3bf2 3bf6
3bfa 3bfe 3c0a 3c0e 3c12 3c15 3c19 3c1d
3c1f 3c23 3c27 3c2b 3c2e 3c32 3c36 3c38
3c39 3c3e 1 3c42 3c46 3c4a 3c4d 3c51
3c55 3c59 3c5d 3c60 3c64 3c68 3c6b 3c6e
3c73 3c76 3c79 3c7c 3c7d 3c82 3c83 1
3c85 3c8a 3c8e 3c92 3c95 3c9a 3c9f 3ca2
3ca6 3ca7 3cac 3caf 3cb4 3cb5 3cba 3cbd
3cc2 3cc3 3cc8 3ccb 3ccf 3cd0 3cd5 3cd8
3cdd 3cde 3ce3 3ce6 3cea 3cee 3cf1 3cf4
3cf5 3cf7 3cf8 3cfd 3cfe 3d03 3d05 3d09
3d0c 3d0e 3d12 3d14 3d20 3d22 3d24 3d25
3d2a 3d2e 3d30 3d3c 3d3e 3d42 3d46 3d49
3d4d 3d51 3d52 3d54 3d57 3d5a 3d5b 3d60
3d64 3d67 3d6b 3d6d 3d71 3d75 3d79 3d7d
3d81 3d85 3d89 3d8d 3d91 3d95 3d99 3d9d
3da9 3dad 3db1 3db4 3db8 3dbc 3dbe 3dc2
3dc6 3dca 3dcd 3dd1 3dd5 3dd7 3dd8 3ddd
1 3de1 3de5 3de9 3dec 3df0 3df4 3df8
3dfc 3dff 3e03 3e07 3e0a 3e0d 3e12 3e15
3e18 3e1b 3e1c 3e21 3e22 1 3e24 3e29
3e2d 3e31 3e34 3e39 3e3e 3e41 3e45 3e46
3e4b 3e4e 3e53 3e54 3e59 3e5c 3e61 3e62
3e67 3e6a 3e6e 3e6f 3e74 3e77 3e7c 3e7d
3e82 3e85 3e89 3e8d 3e90 3e93 3e94 3e96
3e97 3e9c 3e9d 3ea2 3ea4 3ea8 3eab 3ead
3eb1 3eb3 3ebf 3ec1 3ec3 3ec4 3ec9 3ecd
3ecf 3edb 3edd 3edf 3ee3 3ee7 3eea 3eee
3ef2 3ef5 3ef6 3ef8 3efb 3efe 3eff 3f04
3f08 3f0c 3f10 3f14 3f18 3f1c 3f20 3f24
3f28 3f2c 3f38 3f3c 3f41 3f45 3f48 3f49
3f4e 3f52 3f56 3f59 3f5c 3f60 3f62 3f66
3f6a 3f6d 3f70 3f74 3f76 3f7a 3f7e 3f81
3f83 3f87 3f8b 3f8f 3f92 3f96 3f9a 3f9c
3f9d 3fa2 1 3fa6 3faa 3fae 3fb1 3fb5
3fb9 3fbd 3fc1 3fc4 3fc8 3fcc 3fcf 3fd2
3fd7 3fda 3fdd 3fe0 3fe1 3fe6 3fe7 1
3fe9 3fee 3ff2 3ff6 3ff9 3ffe 4003 4006
400a 400b 4010 4013 4018 4019 401e 4021
4026 4027 402c 402f 4033 4034 4039 403c
4041 4042 4047 404a 404e 4052 4055 4058
4059 405b 405c 4061 4062 4067 4069 406d
4070 4072 4076 4078 4084 4086 4088 4089
408e 4092 4094 40a0 40a2 40a6 40aa 40ae
40b2 40b6 40ba 40be 40c2 40c6 40ca 40ce
40d2 40d6 40da 40de 40e2 40e6 40f2 40f6
40fb 40ff 4102 4103 4108 410c 4110 4113
4116 411a 411c 4120 4124 4127 412a 412e
4130 4134 4138 413b 413d 4141 4145 4149
414c 4150 4154 4156 4157 415c 1 4160
4164 4168 416b 416f 4173 4177 417b 417e
4182 4186 4189 418c 4191 4194 4197 419a
419b 41a0 41a1 1 41a3 41a8 41ac 41b0
41b3 41b8 41bd 41c0 41c4 41c5 41ca 41cd
41d2 41d3 41d8 41db 41e0 41e1 41e6 41e9
41ed 41ee 41f3 41f6 41fb 41fc 4201 4204
4208 420c 420f 4212 4213 4215 4216 421b
421c 4221 4223 4227 422a 422c 4230 4232
423e 4240 4242 4243 4248 424c 424e 425a
425c 425e 4262 4266 426a 426e 4272 4276
427a 427e 4282 4286 428a 428e 4292 4296
429a 429e 42a2 42ae 42b2 42b7 42bb 42be
42bf 42c4 42c8 42cc 42cf 42d2 42d6 42d8
42dc 42e0 42e3 42e6 42ea 42ec 42f0 42f4
42f7 42f9 42fd 4301 4305 4308 430c 4310
4312 4313 4318 1 431c 4320 4324 4327
432b 432f 4333 4337 433a 433e 4342 4345
4348 434d 4350 4353 4356 4357 435c 435d
1 435f 4364 4368 436c 436f 4374 4379
437c 4380 4381 4386 4389 438e 438f 4394
4397 439c 439d 43a2 43a5 43a9 43aa 43af
43b2 43b7 43b8 43bd 43c0 43c4 43c8 43cb
43ce 43cf 43d1 43d2 43d7 43d8 43dd 43df
43e3 43e6 43e8 43ec 43ee 43fa 43fc 43fe
43ff 4404 4408 440a 4416 4418 441a 441e
4422 4425 4429 442b 442f 4433 4436 443a
443d 4441 4444 4445 444a 444d 4451 4456
445a 445e 4462 4466 446a 446e 4472 447e
4482 4486 4489 448d 4491 4493 4497 449b
449f 44a2 44a6 44aa 44ac 44ad 44b2 1
44b6 44ba 44be 44c1 44c5 44c9 44cd 44d1
44d4 44d8 44dc 44df 44e2 44e7 44ea 44ed
44f0 44f1 44f6 44f7 1 44f9 44fe 4502
4506 4509 450e 4513 4516 451a 451b 4520
4523 4528 4529 452e 4531 4536 4537 453c
453f 4543 4544 4549 454c 4551 4552 4557
455a 455e 4562 4565 4568 4569 456b 456c
4571 4572 4577 4579 457d 4580 4582 4586
4588 4594 4596 4598 4599 459e 45a2 45a4
45b0 45b2 45b6 45ba 45bd 45c1 45c4 45c8
45cb 45cc 45d1 45d4 45d8 45dc 45e0 45e4
45e8 45ec 45f8 45fc 4600 4603 4607 460b
460d 4611 4615 4619 461c 4620 4624 4626
4627 462c 1 4630 4634 4638 463b 463f
4643 4647 464b 464e 4652 4656 4659 465c
4661 4664 4667 466a 466b 4670 4671 1
4673 4678 467c 4680 4683 4688 468d 4690
4694 4695 469a 469d 46a2 46a3 46a8 46ab
46b0 46b1 46b6 46b9 46bd 46be 46c3 46c6
46cb 46cc 46d1 46d4 46d8 46dc 46df 46e2
46e3 46e5 46e6 46eb 46ec 46f1 46f3 46f7
46fa 46fc 4700 4702 470e 4710 4712 4713
4718 471c 471e 472a 472c 4730 4734 4737
473b 473e 4742 4745 4746 474b 474e 4752
4757 475b 475d 4761 4764 4766 476a 476d
4771 4775 4778 4779 477b 477e 4781 4782
4787 478a 478b 4790 4794 4798 479b 479c
479e 47a2 47a5 47a9 47ac 47ad 47b2 47b6
47ba 47bd 47c1 47c5 47c8 47c9 47cb 47cf
47d3 47d6 47da 47db 47dd 47e1 47e5 47e9
47ed 47f1 47f5 47f9 47fd 4801 4805 4809
4815 4819 481e 4822 4825 4826 482b 482f
4833 4836 4839 483d 483f 4843 4847 484a
484d 4851 4853 4857 485b 485e 4860 4864
4868 486c 486f 4873 4877 4879 487a 487f
1 4883 4887 488b 488e 4892 4896 489a
489e 48a1 48a5 48a9 48ac 48af 48b4 48b7
48ba 48bd 48be 48c3 48c4 1 48c6 48cb
48cf 48d3 48d6 48db 48e0 48e3 48e7 48e8
48ed 48f0 48f5 48f6 48fb 48fe 4903 4904
4909 490c 4910 4911 4916 4919 491e 491f
4924 4927 492b 492f 4932 4935 4936 4938
4939 493e 493f 4944 4946 494a 494d 494f
4953 4955 4961 4963 4965 4966 496b 496f
4971 497d 497f 4983 4987 498b 498c 498e
4992 4996 4998 499c 49a0 49a4 49a7 49a8
49aa 49ae 49b2 49b5 49b6 49b8 49bb 49bf
49c2 49c6 49c9 49ca 49cf 49d3 49d7 49db
49df 49e3 49e7 49eb 49ef 49f3 49f7 49fb
4a07 4a0b 4a10 4a14 4a17 4a18 4a1d 4a21
4a25 4a28 4a2b 4a2f 4a31 4a35 4a39 4a3c
4a3f 4a43 4a45 4a49 4a4d 4a50 4a52 4a56
4a5a 4a5e 4a61 4a65 4a69 4a6b 4a6c 4a71
1 4a75 4a79 4a7d 4a80 4a84 4a88 4a8c
4a90 4a93 4a97 4a9b 4a9e 4aa1 4aa6 4aa9
4aac 4aaf 4ab0 4ab5 4ab6 1 4ab8 4abd
4ac1 4ac5 4ac8 4acd 4ad2 4ad5 4ad9 4ada
4adf 4ae2 4ae7 4ae8 4aed 4af0 4af5 4af6
4afb 4afe 4b02 4b03 4b08 4b0b 4b10 4b11
4b16 4b19 4b1d 4b21 4b24 4b27 4b28 4b2a
4b2b 4b30 4b31 4b36 4b38 4b3c 4b3f 4b41
4b45 4b47 4b53 4b55 4b57 4b58 4b5d 4b61
4b63 4b6f 4b71 4b75 4b79 4b7d 4b7e 4b80
4b84 4b88 4b8a 4b8e 4b92 4b96 4b9a 4b9d
4b9e 4ba0 4ba4 4ba8 4bab 4bac 4bae 4bb1
4bb5 4bb8 4bbc 4bbf 4bc0 4bc5 4bc9 4bcd
4bd1 4bd5 4bd9 4bdd 4be1 4be5 4be9 4bed
4bf1 4bfd 4c01 4c06 4c0a 4c0d 4c0e 4c13
4c17 4c1b 4c1e 4c21 4c25 4c27 4c2b 4c2f
4c32 4c35 4c39 4c3b 4c3f 4c43 4c46 4c48
4c4c 4c50 4c54 4c57 4c5b 4c5f 4c61 4c62
4c67 1 4c6b 4c6f 4c73 4c76 4c7a 4c7e
4c82 4c86 4c89 4c8d 4c91 4c94 4c97 4c9c
4c9f 4ca2 4ca5 4ca6 4cab 4cac 1 4cae
4cb3 4cb7 4cbb 4cbe 4cc3 4cc8 4ccb 4ccf
4cd0 4cd5 4cd8 4cdd 4cde 4ce3 4ce6 4ceb
4cec 4cf1 4cf4 4cf8 4cf9 4cfe 4d01 4d06
4d07 4d0c 4d0f 4d13 4d17 4d1a 4d1d 4d1e
4d20 4d21 4d26 4d27 4d2c 4d2e 4d32 4d35
4d37 4d3b 4d3d 4d49 4d4b 4d4d 4d4e 4d53
4d57 4d59 4d65 4d67 4d6b 4d6f 4d73 4d74
4d76 4d7a 4d7c 4d80 4d84 4d87 4d89 4d8d
4d90 4d92 4d96 4d9a 4d9d 4da1 4da5 4da9
4dad 4db1 4db5 4db9 4dbd 4dc1 4dc5 4dc9
4dcd 4dd1 4dd5 4dd9 4ddd 4de1 4de5 4de9
4ded 4df1 4df5 4e01 4e05 4e09 4e0c 4e10
4e14 4e16 4e1a 4e1e 4e22 4e25 4e29 4e2d
4e2f 4e30 4e35 1 4e39 4e3d 4e41 4e44
4e48 4e4c 4e50 4e54 4e57 4e5b 4e5f 4e62
4e65 4e6a 4e6d 4e70 4e73 4e74 4e79 4e7a
1 4e7c 4e81 4e85 4e89 4e8c 4e91 4e96
4e99 4e9d 4e9e 4ea3 4ea6 4eab 4eac 4eb1
4eb4 4eb9 4eba 4ebf 4ec2 4ec6 4ec7 4ecc
4ecf 4ed4 4ed5 4eda 4edd 4ee1 4ee5 4ee8
4eeb 4eec 4eee 4eef 4ef4 4ef5 4efa 4efc
4f00 4f03 4f05 4f09 4f0b 4f17 4f19 4f1b
4f1c 4f21 4f25 4f27 4f33 4f35 4f39 4f3d
4f40 4f44 4f47 4f4b 4f4e 4f4f 4f54 4f57
4f5b 4f5e 4f62 4f64 4f68 4f6b 4f6f 4f74
4f78 4f7c 4f81 4f85 4f89 4f8e 4f92 4f96
4f9a 4f9b 4fa0 4fa4 4fa8 4fac 4faf 4fb0
4fb2 4fb5 4fb8 4fb9 4fbe 4fc1 4fc5 4fc9
4fcc 4fcd 4fcf 4fd2 4fd5 4fd6 4fdb 1
4fde 4fe3 4fe7 4feb 4fef 4ff3 4ff7 4ffb
4fff 5003 5007 500b 500f 5013 5014 5016
501a 501e 5022 5025 5026 5028 502b 502e
502f 5034 5038 503c 5040 5043 5044 5046
5049 504d 5051 5054 5055 5057 5058 505d
5061 5065 5069 506d 5070 5071 5073 5076
507a 507e 5081 5082 5084 5085 508a 508e
5090 5094 5097 509b 509f 50a2 50a3 50a5
50a8 50ab 50ac 50b1 50b5 50b9 50bd 50c0
50c1 50c3 50c6 50ca 50ce 50d1 50d2 50d4
50d5 50da 50de 50e2 50e6 50ea 50ed 50ee
50f0 50f3 50f7 50fb 50fe 50ff 5101 5102
5107 510b 510d 5111 5114 5116 511a 511d
5121 5124 5128 512c 512f 5133 5137 513b
513f 5143 5147 514b 5157 515b 515f 5162
5166 516a 516c 5170 5174 5178 517b 517f
5183 5185 5186 518b 1 518f 5193 5197
519a 519e 51a2 51a6 51aa 51ad 51b1 51b5
51b8 51bb 51c0 51c3 51c6 51c9 51ca 51cf
51d0 1 51d2 51d7 51db 51df 51e2 51e7
51ec 51ef 51f3 51f4 51f9 51fc 5201 5202
5207 520a 520f 5210 5215 5218 521c 521d
5222 5225 522a 522b 5230 5233 5237 523b
523e 5241 5242 5244 5245 524a 524b 5250
5252 5256 5259 525b 525f 5261 526d 526f
5271 5272 5277 527b 527d 5289 528b 528f
5290 5294 5298 529c 52a0 52a4 52a8 52ac
52b0 52b4 52b8 52bc 52c0 52c4 52d0 52d4
52d8 52db 52df 52e3 52e5 52e9 52ed 52f1
52f4 52f8 52fc 52fe 52ff 5304 1 5308
530c 5310 5313 5317 531b 531f 5323 5326
532a 532e 5331 5334 5339 533c 533f 5342
5343 5348 5349 1 534b 5350 5354 5358
535b 5360 5365 5368 536c 536d 5372 5375
537a 537b 5380 5383 5388 5389 538e 5391
5395 5396 539b 539e 53a3 53a4 53a9 53ac
53b0 53b4 53b7 53ba 53bb 53bd 53be 53c3
53c4 53c9 53cb 53cf 53d2 53d4 53d8 53da
53e6 53e8 53ea 53eb 53f0 53f4 53f6 5402
5404 5408 540c 5410 5414 5418 541c 5420
542c 5430 5434 5437 543b 543f 5441 5445
5449 544d 5450 5454 5458 545a 545b 5460
1 5464 5468 546c 546f 5473 5477 547b
547f 5482 5486 548a 548d 5490 5495 5498
549b 549e 549f 54a4 54a5 1 54a7 54ac
54b0 54b4 54b7 54bc 54c1 54c4 54c8 54c9
54ce 54d1 54d6 54d7 54dc 54df 54e4 54e5
54ea 54ed 54f1 54f2 54f7 54fa 54ff 5500
5505 5508 550c 5510 5513 5516 5517 5519
551a 551f 5520 5525 5527 552b 552e 5530
5534 5536 5542 5544 5546 5547 554c 5550
5552 555e 5560 5564 5568 556b 556f 5573
5574 5576 5579 557c 557d 5582 5585 5586
558b 558f 5592 5593 5598 559b 559f 55a2
55a6 55aa 55ae 55b2 55b6 55ba 55be 55c2
55c6 55ca 55ce 55d2 55d6 55da 55de 55e2
55e6 55ea 55ee 55f2 55f6 55fa 55fe 5602
5606 560a 560e 5612 5616 561a 561e 5622
5626 562a 562e 5632 563e 5642 5646 5649
564d 5651 5653 5657 565b 565f 5662 5666
566a 566c 566d 5672 1 5676 567a 567e
5681 5685 5689 568d 5691 5694 5698 569c
569f 56a2 56a7 56aa 56ad 56b0 56b1 56b6
56b7 1 56b9 56be 56c2 56c6 56c9 56ce
56d3 56d6 56da 56db 56e0 56e3 56e8 56e9
56ee 56f1 56f6 56f7 56fc 56ff 5703 5704
5709 570c 5711 5712 5717 571a 571e 5722
5725 5728 5729 572b 572c 5731 5732 5737
5739 573d 5740 5742 5746 5748 5754 5756
5758 5759 575e 5762 5764 5770 5772 5776
577a 577d 5781 5784 5788 578b 578c 5791
5794 5798 579b 579c 57a1 57a4 1 57a7
57ac 57b0 57b3 57b6 57b7 57bc 57c0 57c4
57c8 57cb 57cf 57d3 57d7 57db 57df 57e3
57e7 57eb 57ef 57f3 57f7 57f8 57fa 57fe
5800 5804 5807 580b 580e 5812 5816 581a
581d 581e 5820 5823 5826 5827 582c 5830
5834 5837 5838 583a 583e 5841 5845 5848
5849 584b 584c 5851 5855 5859 585c 585d
585f 5863 5866 586a 586d 586e 5870 5871
1 5876 587b 587f 5883 5887 588a 588b
588d 5891 5895 5898 5899 589b 589e 58a1
58a2 58a7 58ab 58af 58b2 58b6 58ba 58bd
58c0 58c5 58c8 58cb 58ce 58cf 58d4 58d5
1 58d7 58dc 58e0 58e4 58e7 58ec 58f1
58f4 58f8 58f9 58fe 5901 5906 5907 590c
590f 5914 5915 591a 591d 5921 5925 5929
592d 5930 5931 5933 5938 5939 593b 593c
5941 5944 5949 594a 594f 5952 5957 5958
595d 5960 5964 5965 596a 596d 5972 5973
5978 5979 597e 5980 5984 5987 598b 598f
5992 5996 599a 599d 59a0 59a5 59a8 59ab
59ae 59af 59b4 59b5 1 59b7 59bc 59c0
59c4 59c7 59cc 59d1 59d4 59d8 59d9 59de
59df 59e4 59e6 59ea 59ed 59f1 59f5 59f8
59fc 5a00 5a03 5a07 5a0b 5a0c 5a11 5a13
5a17 5a1a 5a1e 5a22 5a26 5a29 5a2a 5a2c
5a2f 5a32 5a33 5a38 5a3c 5a3f 5a43 5a45
5a49 5a4c 5a4e 5a52 5a56 5a59 5a5b 5a5f
5a62 5a66 5a6a 5a6e 5a72 5a76 5a7a 5a7e
5a82 5a86 5a8a 5a8e 5a92 5a96 5a9a 5a9e
5aa2 5aa6 5aaa 5aae 5ab2 5ab6 5aba 5abe
5ac2 5ac6 5aca 5ace 5ad0 5ad4 5ad7 5adb
5adf 5ae2 5ae6 5ae9 5aed 5af0 5af1 5af6
5af9 5afd 5b00 5b04 5b08 5b0b 5b0f 5b13
5b16 5b17 5b1c 5b1f 5b23 5b27 5b2a 5b2d
5b2e 5b30 5b33 5b38 5b39 5b3e 5b42 5b45
5b48 5b49 5b4e 5b52 5b56 5b5a 5b5d 5b61
5b65 5b69 5b6d 5b71 5b75 5b79 5b7d 5b81
5b85 5b89 5b8a 5b8c 5b90 5b92 5b96 5b99
5b9d 5ba1 5ba5 5ba9 5bad 5bb1 5bb5 5bb9
5bbd 5bc1 5bc5 5bc9 5bcd 5bd1 5bd5 5bd9
5bdd 5be1 5be5 5be9 5bed 5bf1 5bf5 5bf9
5bfd 5c01 5c05 5c11 5c15 5c19 5c1c 5c20
5c24 5c26 5c2a 5c2e 5c32 5c35 5c39 5c3d
5c3f 5c40 5c45 1 5c49 5c4d 5c51 5c54
5c58 5c5c 5c60 5c64 5c67 5c6b 5c6f 5c72
5c75 5c7a 5c7d 5c80 5c83 5c84 5c89 5c8a
1 5c8c 5c91 5c95 5c99 5c9c 5ca1 5ca6
5ca9 5cad 5cae 5cb3 5cb6 5cbb 5cbc 5cc1
5cc4 5cc9 5cca 5ccf 5cd2 5cd6 5cd7 5cdc
5cdf 5ce4 5ce5 5cea 5ced 5cf1 5cf5 5cf8
5cfb 5cfc 5cfe 5cff 5d04 5d05 5d0a 5d0c
5d10 5d13 5d15 5d19 5d1b 5d27 5d29 5d2b
5d2c 5d31 5d35 5d37 5d43 5d45 5d49 5d4d
5d50 5d54 5d57 5d5b 5d5e 5d5f 5d64 5d67
5d6b 5d6f 5d72 5d73 5d75 5d79 5d7c 5d80
5d83 5d84 5d86 5d87 5d8c 5d90 5d94 5d97
5d98 5d9a 5d9e 5da1 5da5 5da8 5da9 5dab
5dac 1 5db1 5db6 5dba 5dbe 5dc1 5dc5
5dc9 5dcc 5dcf 5dd4 5dd7 5dda 5ddd 5dde
5de3 5de4 1 5de6 5deb 5def 5df3 5df6
5dfb 5e00 5e03 5e07 5e08 5e0d 5e10 5e15
5e16 5e1b 5e1e 5e23 5e24 5e29 5e2c 5e30
5e34 5e38 5e3c 5e3f 5e40 5e42 5e47 5e48
5e4a 5e4b 5e50 5e53 5e58 5e59 5e5e 5e61
5e66 5e67 5e6c 5e6f 5e73 5e74 5e79 5e7c
5e81 5e82 5e87 5e88 5e8d 5e8f 5e93 5e96
5e9a 5e9e 5ea1 5ea5 5ea9 5eac 5eaf 5eb4
5eb7 5eba 5ebd 5ebe 5ec3 5ec4 1 5ec6
5ecb 5ecf 5ed3 5ed6 5edb 5ee0 5ee3 5ee7
5ee8 5eed 5eee 5ef3 5ef5 5ef9 5efc 5f00
5f04 5f07 5f0b 5f0f 5f12 5f16 5f1a 5f1b
5f20 5f22 5f26 5f29 5f2d 5f31 5f35 5f38
5f3b 5f3c 5f3e 5f41 5f46 5f47 5f4c 5f4f
5f50 5f52 5f55 5f57 5f5b 5f5f 5f63 5f67
5f6a 5f6b 5f6d 5f70 5f73 5f74 5f79 5f7d
5f80 5f84 5f88 5f8b 5f8f 5f93 5f97 5f9a
5f9b 5f9d 5fa0 5fa3 5fa4 5fa9 5fad 5fb1
5fb4 5fb5 5fb7 5fba 5fbd 5fbe 5fc3 5fc7
5fcb 5fcf 5fd3 5fd7 5fdb 5fdf 5fe3 5fe7
5feb 5ff7 5ffb 5fff 6002 6006 600a 600c
6010 6014 6018 601b 601f 6023 6025 6026
602b 1 602f 6033 6037 603a 603e 6042
6046 604a 604d 6051 6055 6058 605b 6060
6063 6066 6069 606a 606f 6070 1 6072
6077 607b 607f 6082 6087 608c 608f 6093
6094 6099 609c 60a1 60a2 60a7 60aa 60af
60b0 60b5 60b8 60bc 60bd 60c2 60c5 60ca
60cb 60d0 60d3 60d7 60db 60de 60e1 60e2
60e4 60e5 60ea 60eb 60f0 60f2 60f6 60f9
60fb 60ff 6101 610d 610f 6111 6112 6117
611b 611d 6129 612b 612d 6131 6135 6139
613d 6141 6145 6149 614d 6159 615d 6161
6164 6168 616c 616e 6172 6176 617a 617d
6181 6185 6187 6188 618d 1 6191 6195
6199 619c 61a0 61a4 61a8 61ac 61af 61b3
61b7 61ba 61bd 61c2 61c5 61c8 61cb 61cc
61d1 61d2 1 61d4 61d9 61dd 61e1 61e4
61e9 61ee 61f1 61f5 61f6 61fb 61fe 6203
6204 6209 620c 6211 6212 6217 621a 621e
621f 6224 6227 622c 622d 6232 6235 6239
623d 6240 6243 6244 6246 6247 624c 624d
6252 6254 6258 625b 625d 6261 6263 626f
6271 6273 6274 6279 627d 627f 628b 628d
628f 6293 6297 629a 629c 62a0 62a3 62a7
62ab 62ae 62af 62b1 62b4 62b7 62b8 62bd
62c1 62c5 62c9 62cd 62d1 62d5 62d9 62e5
62e9 62ee 62f2 62f5 62f6 62fb 62ff 6303
6306 6309 630d 630f 6313 6317 631a 631d
6321 6323 6327 632b 632e 6330 6334 6338
633c 633f 6343 6347 6349 634a 634f 1
6353 6357 635b 635e 6362 6366 636a 636e
6371 6375 6379 637c 637f 6384 6387 638a
638d 638e 6393 6394 1 6396 639b 639f
63a3 63a6 63ab 63b0 63b3 63b7 63b8 63bd
63c0 63c5 63c6 63cb 63ce 63d3 63d4 63d9
63dc 63e0 63e1 63e6 63e9 63ee 63ef 63f4
63f7 63fb 63ff 6402 6405 6406 6408 6409
640e 640f 6414 6416 641a 641d 641f 6423
6425 6431 6433 6435 6436 643b 643f 6441
644d 644f 6451 6455 6459 645d 6461 6465
6471 6475 647a 647e 6481 6482 6487 648b
648f 6492 6495 6499 649b 649f 64a3 64a6
64a9 64ad 64af 64b3 64b7 64ba 64bc 64c0
64c4 64c8 64cb 64cf 64d3 64d5 64d6 64db
1 64df 64e3 64e7 64ea 64ee 64f2 64f6
64fa 64fd 6501 6505 6508 650b 6510 6513
6516 6519 651a 651f 6520 1 6522 6527
652b 652f 6532 6537 653c 653f 6543 6544
6549 654c 6551 6552 6557 655a 655f 6560
6565 6568 656c 656d 6572 6575 657a 657b
6580 6583 6587 658b 658e 6591 6592 6594
6595 659a 659b 65a0 65a2 65a6 65a9 65ab
65af 65b1 65bd 65bf 65c1 65c2 65c7 65cb
65cd 65d9 65db 65df 65e3 65e7 65f3 65f7
65fc 6600 6603 6604 6609 660d 6611 6614
6617 661b 661d 6621 6625 6628 662b 662f
6631 6635 6639 663c 663e 6642 6646 664a
664d 6651 6655 6657 6658 665d 1 6661
6665 6669 666c 6670 6674 6678 667c 667f
6683 6687 668a 668d 6692 6695 6698 669b
669c 66a1 66a2 1 66a4 66a9 66ad 66b1
66b4 66b9 66be 66c1 66c5 66c6 66cb 66ce
66d3 66d4 66d9 66dc 66e1 66e2 66e7 66ea
66ee 66ef 66f4 66f7 66fc 66fd 6702 6705
6709 670d 6710 6713 6714 6716 6717 671c
671d 6722 6724 6728 672b 672d 6731 6733
673f 6741 6743 6744 6749 674d 674f 675b
675d 6761 6765 6769 6775 6779 677e 6782
6785 6786 678b 678f 6793 6796 6799 679d
679f 67a3 67a7 67aa 67ad 67b1 67b3 67b7
67bb 67be 67c0 67c4 67c8 67cc 67cf 67d3
67d7 67d9 67da 67df 1 67e3 67e7 67eb
67ee 67f2 67f6 67fa 67fe 6801 6805 6809
680c 680f 6814 6817 681a 681d 681e 6823
6824 1 6826 682b 682f 6833 6836 683b
6840 6843 6847 6848 684d 6850 6855 6856
685b 685e 6863 6864 6869 686c 6870 6871
6876 6879 687e 687f 6884 6887 688b 688f
6892 6895 6896 6898 6899 689e 689f 68a4
68a6 68aa 68ad 68af 68b3 68b5 68c1 68c3
68c5 68c6 68cb 68cf 68d1 68dd 68df 68e3
68e7 68eb 68ef 68f3 68ff 6903 6908 690c
690f 6910 6915 6919 691d 6920 6923 6927
6929 692d 6931 6934 6937 693b 693d 6941
6945 6948 694a 694e 6952 6956 6959 695d
6961 6963 6964 6969 1 696d 6971 6975
6978 697c 6980 6984 6988 698b 698f 6993
6996 6999 699e 69a1 69a4 69a7 69a8 69ad
69ae 1 69b0 69b5 69b9 69bd 69c0 69c5
69ca 69cd 69d1 69d2 69d7 69da 69df 69e0
69e5 69e8 69ed 69ee 69f3 69f6 69fa 69fb
6a00 6a03 6a08 6a09 6a0e 6a11 6a15 6a19
6a1c 6a1f 6a20 6a22 6a23 6a28 6a29 6a2e
6a30 6a34 6a37 6a39 6a3d 6a3f 6a4b 6a4d
6a4f 6a50 6a55 6a59 6a5b 6a67 6a69 6a6b
6a6f 6a73 6a76 6a78 6a7c 6a7f 6a81 6a85
6a88 6a8c 6a8e 6a92 6a96 6a99 6a9a 6a9c
6a9f 6aa2 6aa3 6aa8 6aab 6aac 6ab1 6ab5
6ab9 6abc 6abd 6abf 6ac2 6ac5 6ac6 1
6acb 6ad0 6ad4 6ad8 6adb 6adf 6ae3 6ae6
6ae9 6aee 6af1 6af4 6af7 6af8 6afd 6afe
1 6b00 6b05 6b09 6b0d 6b10 6b15 6b1a
6b1d 6b21 6b22 6b27 6b2a 6b2f 6b30 6b35
6b38 6b3d 6b3e 6b43 6b46 6b4a 6b4e 6b52
6b56 6b59 6b5a 6b5c 6b61 6b62 6b64 6b65
6b6a 6b6d 6b72 6b73 6b78 6b7b 6b80 6b81
6b86 6b89 6b8d 6b8e 6b93 6b96 6b9b 6b9c
6ba1 6ba2 6ba7 6ba9 6bad 6bb0 6bb4 6bb8
6bbb 6bbf 6bc3 6bc6 6bc9 6bce 6bd1 6bd4
6bd7 6bd8 6bdd 6bde 1 6be0 6be5 6be9
6bed 6bf0 6bf5 6bfa 6bfd 6c01 6c02 6c07
6c08 6c0d 6c0f 6c13 6c16 6c1a 6c1e 6c21
6c25 6c29 6c2c 6c30 6c34 6c35 6c3a 6c3c
6c40 6c44 6c47 6c4b 6c4e 6c51 6c52 6c57
6c5b 6c5f 6c63 6c67 6c6b 6c6e 6c6f 6c71
6c74 6c77 6c78 6c7d 6c80 6c84 6c88 6c8b
6c8c 6c8e 6c91 6c94 6c95 6c9a 1 6c9d
6ca2 6ca6 6caa 6cad 6cae 6cb0 6cb3 6cb6
6cb7 6cbc 6cc0 6cc4 6cc8 6ccc 6cd0 6cd4
6cd8 6cdc 6ce0 6ce4 6ce8 6cec 6cf0 6cf4
6cf8 6cfc 6d00 6d04 6d08 6d0c 6d10 6d14
6d18 6d1c 6d20 6d24 6d28 6d2c 6d30 6d34
6d40 6d44 6d49 6d4d 6d50 6d51 6d56 6d5a
6d5e 6d61 6d64 6d68 6d6a 6d6e 6d72 6d75
6d78 6d7c 6d7e 6d82 6d86 6d89 6d8b 6d8f
6d93 6d97 6d9a 6d9e 6da2 6da4 6da5 6daa
1 6dae 6db2 6db6 6db9 6dbd 6dc1 6dc5
6dc9 6dcc 6dd0 6dd4 6dd7 6dda 6ddf 6de2
6de5 6de8 6de9 6dee 6def 1 6df1 6df6
6dfa 6dfe 6e01 6e06 6e0b 6e0e 6e12 6e13
6e18 6e1b 6e20 6e21 6e26 6e29 6e2e 6e2f
6e34 6e37 6e3b 6e3c 6e41 6e44 6e49 6e4a
6e4f 6e52 6e56 6e5a 6e5d 6e60 6e61 6e63
6e64 6e69 6e6a 6e6f 6e71 6e75 6e78 6e7a
6e7e 6e80 6e8c 6e8e 6e90 6e91 6e96 6e9a
6e9c 6ea8 6eaa 6eac 6eb0 6eb4 6eb8 6ebc
6ec0 6ec4 6ec8 6ecc 6ed0 6ed4 6ed8 6edc
6ee0 6ee4 6ee8 6eec 6ef0 6ef4 6ef8 6efc
6f00 6f04 6f08 6f0c 6f10 6f14 6f18 6f1c
6f20 6f24 6f28 6f2c 6f30 6f34 6f40 6f44
6f49 6f4d 6f50 6f51 6f56 6f5a 6f5e 6f61
6f64 6f68 6f6a 6f6e 6f72 6f75 6f78 6f7c
6f7e 6f82 6f86 6f89 6f8b 6f8f 6f93 6f97
6f9a 6f9e 6fa2 6fa4 6fa5 6faa 1 6fae
6fb2 6fb6 6fb9 6fbd 6fc1 6fc5 6fc9 6fcc
6fd0 6fd4 6fd7 6fda 6fdf 6fe2 6fe5 6fe8
6fe9 6fee 6fef 1 6ff1 6ff6 6ffa 6ffe
7001 7006 700b 700e 7012 7013 7018 701b
7020 7021 7026 7029 702e 702f 7034 7037
703b 703c 7041 7044 7049 704a 704f 7052
7056 705a 705d 7060 7061 7063 7064 7069
706a 706f 7071 7075 7078 707a 707e 7080
708c 708e 7090 7091 7096 709a 709c 70a8
70aa 70ac 70b0 70b4 70b7 70bb 70bd 70c1
70c5 70c8 70c9 70cb 70ce 70d1 70d2 70d7
70db 70df 70e3 70e7 70eb 70ef 70f3 70f7
70fb 70ff 7103 7107 710b 710f 7113 7117
711b 711f 7123 7127 712b 712f 7133 7137
713b 713f 714b 714f 7154 7158 715b 715c
7161 7165 7169 716c 716f 7173 7175 7179
717d 7180 7183 7187 7189 718d 7191 7194
7196 719a 719e 71a2 71a5 71a9 71ad 71af
71b0 71b5 1 71b9 71bd 71c1 71c4 71c8
71cc 71d0 71d4 71d7 71db 71df 71e2 71e5
71ea 71ed 71f0 71f3 71f4 71f9 71fa 1
71fc 7201 7205 7209 720c 7211 7216 7219
721d 721e 7223 7226 722b 722c 7231 7234
7239 723a 723f 7242 7246 7247 724c 724f
7254 7255 725a 725d 7261 7265 7268 726b
726c 726e 726f 7274 7275 727a 727c 7280
7283 7285 7289 728b 7297 7299 729b 729c
72a1 72a5 72a7 72b3 72b5 72b9 72bb 72bf
72c3 72c7 72ca 72cb 72cd 72d0 72d3 72d4
72d9 72dd 72e1 72e4 72e5 72e7 72ea 72ed
72ee 72f3 72f7 72fb 72ff 7303 7307 730b
730f 7313 7317 731b 731f 7323 7327 732b
732f 7333 7337 733b 733f 7343 7347 734b
7357 735b 7360 7364 7367 7368 736d 7371
7375 7378 737b 737f 7381 7385 7389 738c
738f 7393 7395 7399 739d 73a0 73a2 73a6
73aa 73ae 73b1 73b5 73b9 73bb 73bc 73c1
1 73c5 73c9 73cd 73d0 73d4 73d8 73dc
73e0 73e3 73e7 73eb 73ee 73f1 73f6 73f9
73fc 73ff 7400 7405 7406 1 7408 740d
7411 7415 7418 741d 7422 7425 7429 742a
742f 7432 7437 7438 743d 7440 7445 7446
744b 744e 7452 7453 7458 745b 7460 7461
7466 7469 746d 7471 7474 7477 7478 747a
747b 7480 7481 7486 7488 748c 748f 7491
7495 7497 74a3 74a5 74a7 74a8 74ad 74b1
74b3 74bf 74c1 74c3 74c7 74cb 74cf 74d3
74d7 74db 74df 74e3 74e7 74eb 74ef 74f3
74f7 74fb 74ff 7503 7507 750b 750f 7513
7517 751b 751f 7523 7527 752b 7537 753b
7540 7544 7547 7548 754d 7551 7555 7558
755b 755f 7561 7565 7569 756c 756f 7573
7575 7579 757d 7580 7582 7586 758a 758e
7591 7595 7599 759b 759c 75a1 1 75a5
75a9 75ad 75b0 75b4 75b8 75bc 75c0 75c3
75c7 75cb 75ce 75d1 75d6 75d9 75dc 75df
75e0 75e5 75e6 1 75e8 75ed 75f1 75f5
75f8 75fd 7602 7605 7609 760a 760f 7612
7617 7618 761d 7620 7625 7626 762b 762e
7632 7633 7638 763b 7640 7641 7646 7649
764d 7651 7654 7657 7658 765a 765b 7660
7661 7666 7668 766c 766f 7671 7675 7677
7683 7685 7687 7688 768d 7691 7693 769f
76a1 76a3 76a7 76ab 76ae 76b0 76b4 76b8
76bc 76c0 76c4 76c8 76cc 76d0 76d4 76d8
76dc 76e0 76e4 76f0 76f4 76f9 76fd 7700
7701 7706 770a 770e 7711 7714 7718 771a
771e 7722 7725 7728 772c 772e 7732 7736
7739 773b 773f 7743 7747 774a 774e 7752
7754 7755 775a 1 775e 7762 7766 7769
776d 7771 7775 7779 777c 7780 7784 7787
778a 778f 7792 7795 7798 7799 779e 779f
1 77a1 77a6 77aa 77ae 77b1 77b6 77bb
77be 77c2 77c3 77c8 77cb 77d0 77d1 77d6
77d9 77de 77df 77e4 77e7 77eb 77ec 77f1
77f4 77f9 77fa 77ff 7802 7806 780a 780d
7810 7811 7813 7814 7819 781a 781f 7821
7825 7828 782a 782e 7830 783c 783e 7840
7841 7846 784a 784c 7858 785a 785c 7860
7864 7867 786b 786f 7873 7877 787b 7887
788b 7890 7894 7897 7898 789d 78a1 78a5
78a8 78ab 78af 78b1 78b5 78b9 78bc 78bf
78c3 78c5 78c9 78cd 78d0 78d2 78d6 78da
78de 78e1 78e5 78e9 78eb 78ec 78f1 1
78f5 78f9 78fd 7900 7904 7908 790c 7910
7913 7917 791b 791e 7921 7926 7929 792c
792f 7930 7935 7936 1 7938 793d 7941
7945 7948 794d 7952 7955 7959 795a 795f
7962 7967 7968 796d 7970 7975 7976 797b
797e 7982 7983 7988 798b 7990 7991 7996
7999 799d 79a1 79a4 79a7 79a8 79aa 79ab
79b0 79b1 79b6 79b8 79bc 79bf 79c1 79c5
79c7 79d3 79d5 79d7 79d8 79dd 79e1 79e3
79ef 79f1 79f5 79f9 79fd 7a09 7a0d 7a12
7a16 7a19 7a1a 7a1f 7a23 7a27 7a2a 7a2d
7a31 7a33 7a37 7a3b 7a3e 7a41 7a45 7a47
7a4b 7a4f 7a52 7a54 7a58 7a5c 7a60 7a63
7a67 7a6b 7a6d 7a6e 7a73 1 7a77 7a7b
7a7f 7a82 7a86 7a8a 7a8e 7a92 7a95 7a99
7a9d 7aa0 7aa3 7aa8 7aab 7aae 7ab1 7ab2
7ab7 7ab8 1 7aba 7abf 7ac3 7ac7 7aca
7acf 7ad4 7ad7 7adb 7adc 7ae1 7ae4 7ae9
7aea 7aef 7af2 7af7 7af8 7afd 7b00 7b04
7b05 7b0a 7b0d 7b12 7b13 7b18 7b1b 7b1f
7b23 7b26 7b29 7b2a 7b2c 7b2d 7b32 7b33
7b38 7b3a 7b3e 7b41 7b43 7b47 7b49 7b55
7b57 7b59 7b5a 7b5f 7b63 7b65 7b71 7b73
7b77 7b7b 7b7f 7b83 7b87 7b93 7b97 7b9c
7ba0 7ba3 7ba4 7ba9 7bad 7bb1 7bb4 7bb7
7bbb 7bbd 7bc1 7bc5 7bc8 7bcb 7bcf 7bd1
7bd5 7bd9 7bdc 7bde 7be2 7be6 7bea 7bed
7bf1 7bf5 7bf7 7bf8 7bfd 1 7c01 7c05
7c09 7c0c 7c10 7c14 7c18 7c1c 7c1f 7c23
7c27 7c2a 7c2d 7c32 7c35 7c38 7c3b 7c3c
7c41 7c42 1 7c44 7c49 7c4d 7c51 7c54
7c59 7c5e 7c61 7c65 7c66 7c6b 7c6e 7c73
7c74 7c79 7c7c 7c81 7c82 7c87 7c8a 7c8e
7c8f 7c94 7c97 7c9c 7c9d 7ca2 7ca5 7ca9
7cad 7cb0 7cb3 7cb4 7cb6 7cb7 7cbc 7cbd
7cc2 7cc4 7cc8 7ccb 7ccd 7cd1 7cd3 7cdf
7ce1 7ce3 7ce4 7ce9 7ced 7cef 7cfb 7cfd
7cff 7d03 7d06 7d0a 7d0d 7d10 7d11 7d16
7d1a 7d1e 7d21 7d22 7d24 7d27 7d2a 7d2b
7d30 7d34 7d38 7d3c 7d3f 7d43 7d45 7d49
7d4d 7d51 7d54 7d58 7d5c 7d5f 7d60 7d62
7d66 7d6a 7d6d 7d6e 7d70 7d74 7d76 7d7a
7d7e 7d81 7d85 7d88 7d8c 7d90 7d94 7d97
7d98 7d9a 7d9d 7da0 7da1 7da6 7daa 7dae
7db1 7db2 7db4 7db8 7dbb 7dbf 7dc2 7dc3
7dc5 7dc6 7dcb 7dcf 7dd3 7dd7 7dda 7ddb
7ddd 7de1 7de3 7de7 7dea 7dee 7df1 7df5
7df9 7dfc 7e00 7e04 7e08 7e0b 7e0f 7e12
7e13 7e15 7e18 7e1b 7e1c 7e21 7e25 7e28
7e2c 7e2e 7e32 7e35 7e39 7e3b 7e3f 7e43
7e46 7e4a 7e4e 7e51 7e52 7e54 7e57 7e5a
7e5b 7e60 7e64 7e67 7e6b 7e6d 7e71 7e74
7e78 7e7c 7e80 7e84 7e88 7e8c 7e8f 7e90
7e92 7e96 7e9a 7e9d 7e9e 7ea0 7ea4 7ea8
7eab 7eac 7eae 7eb2 7eb6 7eb9 7eba 7ebc
7ec0 7ec4 7ec7 7ec8 7eca 7ece 7ed2 7ed5
7ed6 7ed8 7edc 7ee0 7ee3 7ee4 7ee6 7eea
7eee 7ef1 7ef2 7ef4 7ef8 7efc 7f00 7f01
7f03 7f07 7f0b 7f0f 7f12 7f13 7f15 7f19
7f1c 7f20 7f23 7f24 7f29 7f2d 7f31 7f34
7f38 7f3c 7f3f 7f42 7f47 7f4a 7f4d 7f50
7f51 7f56 7f57 1 7f59 7f5e 7f62 7f66
7f69 7f6e 7f73 7f76 7f7a 7f7b 7f80 7f83
7f88 7f89 7f8e 7f91 7f96 7f97 7f9c 7f9f
7fa3 7fa7 7fab 7faf 7fb2 7fb3 7fb5 7fba
7fbb 7fbd 7fbe 7fc3 7fc4 7fc9 7fcb 7fcf
7fd2 7fd6 7fda 7fdd 7fe1 7fe5 7fe8 7feb
7ff0 7ff3 7ff6 7ff9 7ffa 7fff 8000 1
8002 8007 800b 800f 8012 8017 801c 801f
8023 8024 8029 802a 802f 8031 8035 8038
803c 8040 8043 8047 804b 804e 8052 8053
8058 805c 805e 8062 8066 8069 806a 806c
806f 8072 8073 8078 807c 8080 8083 8087
808b 808e 8091 8096 8099 809c 809f 80a0
80a5 80a6 1 80a8 80ad 80b1 80b5 80b8
80bd 80c2 80c5 80c9 80ca 80cf 80d2 80d7
80d8 80dd 80e0 80e5 80e6 80eb 80ee 80f2
80f6 80fa 80fb 80fd 8102 8103 8105 8106
810b 810e 8113 8114 8119 811c 8121 8122
8127 812a 812e 812f 8134 8137 813c 813d
8142 8143 8148 814a 814e 8151 8155 8159
815c 8160 8164 8167 816a 816f 8172 8175
8178 8179 817e 817f 1 8181 8186 818a
818e 8191 8196 819b 819e 81a2 81a3 81a8
81a9 81ae 81b0 81b4 81b7 81bb 81bf 81c2
81c6 81ca 81cd 81ce 81d0 81d4 81d8 81d9
81de 81e0 81e4 81e8 81eb 81ef 81f2 81f6
81fa 81fe 8202 8206 820a 820e 8212 8216
821a 821e 8222 8226 822a 822e 8232 8236
823a 823e 8242 8246 824a 824e 8252 8256
825a 825e 8262 8266 826a 826e 8271 8274
8277 827a 827d 827e 8280 8284 8288 828b
828e 828f 8294 8298 829c 829f 82a3 82a7
82aa 82ad 82b2 82b5 82b8 82bb 82bc 82c1
82c2 1 82c4 82c9 82cd 82d1 82d4 82d9
82de 82e1 82e5 82e6 82eb 82ee 82f3 82f4
82f9 82fc 8301 8302 8307 830a 830e 8312
8316 831a 831d 831e 8320 8325 8326 8328
8329 832e 8331 8336 8337 833c 833f 8344
8345 834a 834d 8351 8352 8357 835a 835f
8360 8365 8366 836b 836d 8371 8374 8378
837c 837f 8383 8387 838a 838d 8392 8395
8398 839b 839c 83a1 83a2 1 83a4 83a9
83ad 83b1 83b4 83b9 83be 83c1 83c5 83c6
83cb 83cc 83d1 83d3 83d7 83da 83de 83e2
83e5 83e9 83ed 83f0 83f4 83f8 83f9 83fe
8402 8404 8408 840b 840e 840f 8414 8418
841c 841f 8423 8427 842a 842d 8432 8435
8438 843b 843c 8441 8442 1 8444 8449
844d 8451 8454 8459 845e 8461 8465 8466
846b 846e 8473 8474 8479 847c 8481 8482
8487 848a 848e 8492 8496 849a 849d 849e
84a0 84a5 84a6 84a8 84a9 84ae 84b1 84b6
84b7 84bc 84bf 84c4 84c5 84ca 84cd 84d1
84d2 84d7 84da 84df 84e0 84e5 84e6 84eb
84ed 84f1 84f4 84f8 84fc 84ff 8503 8507
850a 850d 8512 8515 8518 851b 851c 8521
8522 1 8524 8529 852d 8531 8534 8539
853e 8541 8545 8546 854b 854c 8551 8553
8557 855a 855e 8562 8565 8569 856d 8570
8574 8578 8579 857e 8580 8584 8588 858b
858f 8593 8597 859b 859f 85a3 85a7 85ab
85ae 85af 85b1 85b5 85b9 85bc 85bd 85bf
85c0 85c2 85c6 85c8 85cc 85d0 85d3 85d5
85d9 85dc 85de 85e2 85e5 85e9 85ed 85f1
85f4 85f8 85fc 8600 8604 8608 860c 8610
8614 8618 8624 8628 862c 862f 8633 8637
8639 863d 8641 8645 8648 864c 8650 8652
8653 8658 1 865c 8660 8664 8667 866b
866f 8673 8677 867a 867e 8682 8685 8688
868d 8690 8693 8696 8697 869c 869d 1
869f 86a4 86a8 86ac 86af 86b4 86b9 86bc
86c0 86c1 86c6 86c9 86ce 86cf 86d4 86d7
86dc 86dd 86e2 86e5 86e9 86ea 86ef 86f2
86f7 86f8 86fd 8700 8704 8708 870b 870e
870f 8711 8712 8717 8718 871d 871f 8723
8726 8728 872c 872e 873a 873c 873e 873f
8744 8748 874a 8756 8758 875a 875e 8761
8763 8767 876a 876e 8771 8775 8777 877b
877e 8782 8786 878a 878d 8792 8793 8798
879b 879e 879f 87a1 87a5 87a9 87ae 87b2
87b6 87ba 87be 87c2 87c6 87ca 87ce 87d2
87de 87e2 87e6 87e9 87ed 87f1 87f3 87f7
87fb 87ff 8802 8806 880a 880c 880d 8812
1 8816 881a 881e 8821 8825 8829 882d
8831 8834 8838 883c 883f 8842 8847 884a
884d 8850 8851 8856 8857 1 8859 885e
8862 8866 8869 886e 8873 8876 887a 887b
8880 8883 8888 8889 888e 8891 8896 8897
889c 889f 88a3 88a4 88a9 88ac 88b1 88b2
88b7 88ba 88be 88c2 88c5 88c8 88c9 88cb
88cc 88d1 88d2 88d7 88d9 88dd 88e0 88e2
88e6 88e8 88f4 88f6 88f8 88f9 88fe 8902
8904 8910 8912 8916 8919 891d 8921 8924
8928 892c 892f 8933 8937 893b 893f 8943
8947 894c 8950 8951 8955 8959 895d 8961
8965 8969 896d 8971 8975 8979 897d 8981
8985 8989 898d 8991 8995 8999 899d 89a1
89a5 89a9 89ad 89b2 89b7 89bb 89bf 89c3
89c8 89cc 89d0 89d3 89d6 89da 89dc 89e0
89e4 89e7 89ea 89ee 89f0 89f4 89f8 89fb
89ff 8a03 8a06 8a0a 8a0d 8a11 8a14 8a15
8a1a 8a1d 8a21 8a27 8a29 8a2d 8a30 8a34
8a37 8a3b 8a3f 8a43 8a46 8a47 8a49 8a4c
8a4f 8a50 8a55 8a59 8a5d 8a61 8a64 8a65
8a67 8a6b 8a6f 8a73 8a77 8a83 8a87 8a8c
8a90 8a93 8a94 8a99 8a9d 8aa1 8aa4 8aa7
8aab 8aad 8ab1 8ab5 8ab8 8abb 8abf 8ac1
8ac5 8ac9 8acc 8ace 8ad2 8ad6 8ada 8add
8ae1 8ae5 8ae7 8ae8 8aed 1 8af1 8af5
8af9 8afc 8b00 8b04 8b08 8b0c 8b0f 8b13
8b17 8b1a 8b1d 8b22 8b25 8b28 8b2b 8b2c
8b31 8b32 1 8b34 8b39 8b3d 8b41 8b44
8b49 8b4e 8b51 8b55 8b56 8b5b 8b5e 8b63
8b64 8b69 8b6c 8b71 8b72 8b77 8b7a 8b7e
8b7f 8b84 8b87 8b8c 8b8d 8b92 8b95 8b99
8b9d 8ba0 8ba3 8ba4 8ba6 8ba7 8bac 8bad
8bb2 8bb4 8bb8 8bbb 8bbd 8bc1 8bc3 8bcf
8bd1 8bd3 8bd4 8bd9 8bdd 8bdf 8beb 8bed
8bf1 8bf5 8bf9 8c05 8c09 8c0e 8c12 8c15
8c16 8c1b 8c1f 8c23 8c26 8c29 8c2d 8c2f
8c33 8c37 8c3a 8c3d 8c41 8c43 8c47 8c4b
8c4e 8c50 8c54 8c58 8c5c 8c5f 8c63 8c67
8c69 8c6a 8c6f 1 8c73 8c77 8c7b 8c7e
8c82 8c86 8c8a 8c8e 8c91 8c95 8c99 8c9c
8c9f 8ca4 8ca7 8caa 8cad 8cae 8cb3 8cb4
1 8cb6 8cbb 8cbf 8cc3 8cc6 8ccb 8cd0
8cd3 8cd7 8cd8 8cdd 8ce0 8ce5 8ce6 8ceb
8cee 8cf3 8cf4 8cf9 8cfc 8d00 8d01 8d06
8d09 8d0e 8d0f 8d14 8d17 8d1b 8d1f 8d22
8d25 8d26 8d28 8d29 8d2e 8d2f 8d34 8d36
8d3a 8d3d 8d3f 8d43 8d45 8d51 8d53 8d55
8d56 8d5b 8d5f 8d61 8d6d 8d6f 8d73 8d77
8d7b 8d87 8d8b 8d90 8d94 8d97 8d98 8d9d
8da1 8da5 8da8 8dab 8daf 8db1 8db5 8db9
8dbc 8dbf 8dc3 8dc5 8dc9 8dcd 8dd0 8dd2
8dd6 8dda 8dde 8de1 8de5 8de9 8deb 8dec
8df1 1 8df5 8df9 8dfd 8e00 8e04 8e08
8e0c 8e10 8e13 8e17 8e1b 8e1e 8e21 8e26
8e29 8e2c 8e2f 8e30 8e35 8e36 1 8e38
8e3d 8e41 8e45 8e48 8e4d 8e52 8e55 8e59
8e5a 8e5f 8e62 8e67 8e68 8e6d 8e70 8e75
8e76 8e7b 8e7e 8e82 8e83 8e88 8e8b 8e90
8e91 8e96 8e99 8e9d 8ea1 8ea4 8ea7 8ea8
8eaa 8eab 8eb0 8eb1 8eb6 8eb8 8ebc 8ebf
8ec1 8ec5 8ec7 8ed3 8ed5 8ed7 8ed8 8edd
8ee1 8ee3 8eef 8ef1 8ef5 8ef9 8efd 8f01
8f05 8f11 8f15 8f1a 8f1e 8f21 8f22 8f27
8f2b 8f2f 8f32 8f35 8f39 8f3b 8f3f 8f43
8f46 8f49 8f4d 8f4f 8f53 8f57 8f5a 8f5c
8f60 8f64 8f68 8f6b 8f6f 8f73 8f75 8f76
8f7b 1 8f7f 8f83 8f87 8f8a 8f8e 8f92
8f96 8f9a 8f9d 8fa1 8fa5 8fa8 8fab 8fb0
8fb3 8fb6 8fb9 8fba 8fbf 8fc0 1 8fc2
8fc7 8fcb 8fcf 8fd2 8fd7 8fdc 8fdf 8fe3
8fe4 8fe9 8fec 8ff1 8ff2 8ff7 8ffa 8fff
9000 9005 9008 900c 900d 9012 9015 901a
901b 9020 9023 9027 902b 902e 9031 9032
9034 9035 903a 903b 9040 9042 9046 9049
904b 904f 9051 905d 905f 9061 9062 9067
906b 906d 9079 907b 907f 9083 9087 9093
9097 909c 90a0 90a3 90a4 90a9 90ad 90b1
90b4 90b7 90bb 90bd 90c1 90c5 90c8 90cb
90cf 90d1 90d5 90d9 90dc 90de 90e2 90e6
90ea 90ed 90f1 90f5 90f7 90f8 90fd 1
9101 9105 9109 910c 9110 9114 9118 911c
911f 9123 9127 912a 912d 9132 9135 9138
913b 913c 9141 9142 1 9144 9149 914d
9151 9154 9159 915e 9161 9165 9166 916b
916e 9173 9174 9179 917c 9181 9182 9187
918a 918e 918f 9194 9197 919c 919d 91a2
91a5 91a9 91ad 91b0 91b3 91b4 91b6 91b7
91bc 91bd 91c2 91c4 91c8 91cb 91cd 91d1
91d3 91df 91e1 91e3 91e4 91e9 91ed 91ef
91fb 91fd 9201 9205 9209 9215 9219 921e
9222 9225 9226 922b 922f 9233 9236 9239
923d 923f 9243 9247 924a 924d 9251 9253
9257 925b 925e 9260 9264 9268 926c 926f
9273 9277 9279 927a 927f 1 9283 9287
928b 928e 9292 9296 929a 929e 92a1 92a5
92a9 92ac 92af 92b4 92b7 92ba 92bd 92be
92c3 92c4 1 92c6 92cb 92cf 92d3 92d6
92db 92e0 92e3 92e7 92e8 92ed 92f0 92f5
92f6 92fb 92fe 9303 9304 9309 930c 9310
9311 9316 9319 931e 931f 9324 9327 932b
932f 9332 9335 9336 9338 9339 933e 933f
9344 9346 934a 934d 934f 9353 9355 9361
9363 9365 9366 936b 936f 9371 937d 937f
9381 9385 9389 938c 938d 938f 9392 9395
9396 939b 939f 93a3 93a7 93a9 93ad 93b0
93b4 93b8 93bc 93c0 93c4 93c8 93cc 93d0
93d4 93e0 93e4 93e9 93ed 93f0 93f1 93f6
93fa 93fe 9401 9404 9408 940a 940e 9412
9415 9418 941c 941e 9422 9426 9429 942b
942f 9433 9437 943a 943e 9442 9444 9445
944a 1 944e 9452 9456 9459 945d 9461
9465 9469 946c 9470 9474 9477 947a 947f
9482 9485 9488 9489 948e 948f 1 9491
9496 949a 949e 94a1 94a6 94ab 94ae 94b2
94b3 94b8 94bb 94c0 94c1 94c6 94c9 94ce
94cf 94d4 94d7 94db 94dc 94e1 94e4 94e9
94ea 94ef 94f2 94f6 94fa 94fd 9500 9501
9503 9504 9509 950a 950f 9511 9515 9518
951a 951e 9520 952c 952e 9530 9531 9536
953a 953c 9548 954a 954e 9551 9554 9555
955a 955e 9562 9566 9569 956d 9571 9575
9579 957d 9581 9585 9589 958d 9591 9595
9596 9598 959c 95a0 95a4 95a8 95ac 95b0
95b4 95b8 95bc 95c0 95c4 95c8 95cc 95d8
95dc 95e0 95e3 95e7 95eb 95ed 95f1 95f5
95f9 95fc 9600 9604 9606 9607 960c 1
9610 9614 9618 961b 961f 9623 9627 962b
962e 9632 9636 9639 963c 9641 9644 9647
964a 964b 9650 9651 1 9653 9658 965c
9660 9663 9668 966d 9670 9674 9675 967a
967d 9682 9683 9688 968b 9690 9691 9696
9699 969d 969e 96a3 96a6 96ab 96ac 96b1
96b4 96b8 96bc 96bf 96c2 96c3 96c5 96c6
96cb 96cc 96d1 96d3 96d7 96da 96dc 96e0
96e2 96ee 96f0 96f2 96f3 96f8 96fc 96fe
970a 970c 9710 9714 9717 971b 971e 9722
9725 9726 972b 972e 9732 9735 9739 973d
9741 9745 9749 974d 9751 9755 9759 975d
9761 9765 9769 9775 9779 977d 9780 9784
9788 978a 978e 9792 9796 9799 979d 97a1
97a3 97a4 97a9 1 97ad 97b1 97b5 97b8
97bc 97c0 97c4 97c8 97cb 97cf 97d3 97d6
97d9 97de 97e1 97e4 97e7 97e8 97ed 97ee
1 97f0 97f5 97f9 97fd 9800 9805 980a
980d 9811 9812 9817 981a 981f 9820 9825
9828 982d 982e 9833 9836 983a 983b 9840
9843 9848 9849 984e 9851 9855 9859 985c
985f 9860 9862 9863 9868 9869 986e 9870
9874 9877 9879 987d 987f 988b 988d 988f
9890 9895 9899 989b 98a7 98a9 98ad 98b1
98b4 98b8 98bb 98bf 98c2 98c3 98c8 98cb
98cf 98d3 98d7 98da 98db 98dd 98e1 98e5
98e8 98e9 98eb 98ee 98f2 98f5 98f9 98fc
98fd 9902 9906 9909 990d 9911 9915 9919
991d 9921 9925 9929 992d 9939 993d 9942
9946 9949 994a 994f 9953 9957 995a 995d
9961 9963 9967 996b 996e 9971 9975 9977
997b 997f 9982 9984 9988 998c 9990 9993
9997 999b 999d 999e 99a3 1 99a7 99ab
99af 99b2 99b6 99ba 99be 99c2 99c5 99c9
99cd 99d0 99d3 99d8 99db 99de 99e1 99e2
99e7 99e8 1 99ea 99ef 99f3 99f7 99fa
99ff 9a04 9a07 9a0b 9a0c 9a11 9a14 9a19
9a1a 9a1f 9a22 9a27 9a28 9a2d 9a30 9a34
9a35 9a3a 9a3d 9a42 9a43 9a48 9a4b 9a4f
9a53 9a56 9a59 9a5a 9a5c 9a5d 9a62 9a63
9a68 9a6a 9a6e 9a71 9a73 9a77 9a79 9a85
9a87 9a89 9a8a 9a8f 9a93 9a95 9aa1 9aa3
9aa7 9aa9 9aad 9ab1 9ab4 9ab5 9ab7 9abb
9abe 9ac2 9ac5 9ac6 9acb 9acf 9ad3 9ad6
9ada 9ade 9ae1 9ae2 9ae4 9ae8 9aec 9aef
9af3 9af4 9af6 9afa 9afe 9b02 9b06 9b0a
9b0e 9b12 9b16 9b1a 9b1e 9b22 9b26 9b2a
9b2e 9b3a 9b3e 9b43 9b47 9b4a 9b4b 9b50
9b54 9b58 9b5b 9b5e 9b62 9b64 9b68 9b6c
9b6f 9b72 9b76 9b78 9b7c 9b80 9b83 9b85
9b89 9b8d 9b91 9b94 9b98 9b9c 9b9e 9b9f
9ba4 1 9ba8 9bac 9bb0 9bb3 9bb7 9bbb
9bbf 9bc3 9bc6 9bca 9bce 9bd1 9bd4 9bd9
9bdc 9bdf 9be2 9be3 9be8 9be9 1 9beb
9bf0 9bf4 9bf8 9bfb 9c00 9c05 9c08 9c0c
9c0d 9c12 9c15 9c1a 9c1b 9c20 9c23 9c28
9c29 9c2e 9c31 9c35 9c36 9c3b 9c3e 9c43
9c44 9c49 9c4c 9c50 9c54 9c57 9c5a 9c5b
9c5d 9c5e 9c63 9c64 9c69 9c6b 9c6f 9c72
9c74 9c78 9c7a 9c86 9c88 9c8a 9c8b 9c90
9c94 9c96 9ca2 9ca4 9ca6 9caa 9cae 9cb2
9cb6 9cba 9cbe 9cc2 9cc6 9cca 9cce 9cd2
9cd6 9cda 9cde 9ce2 9ce6 9cea 9cf6 9cfa
9cff 9d03 9d06 9d07 9d0c 9d10 9d14 9d17
9d1a 9d1e 9d20 9d24 9d28 9d2b 9d2e 9d32
9d34 9d38 9d3c 9d3f 9d41 9d45 9d49 9d4d
9d50 9d54 9d58 9d5a 9d5b 9d60 1 9d64
9d68 9d6c 9d6f 9d73 9d77 9d7b 9d7f 9d82
9d86 9d8a 9d8d 9d90 9d95 9d98 9d9b 9d9e
9d9f 9da4 9da5 1 9da7 9dac 9db0 9db4
9db7 9dbc 9dc1 9dc4 9dc8 9dc9 9dce 9dd1
9dd6 9dd7 9ddc 9ddf 9de4 9de5 9dea 9ded
9df1 9df2 9df7 9dfa 9dff 9e00 9e05 9e08
9e0c 9e10 9e13 9e16 9e17 9e19 9e1a 9e1f
9e20 9e25 9e27 9e2b 9e2e 9e30 9e34 9e36
9e42 9e44 9e46 9e47 9e4c 9e50 9e52 9e5e
9e60 9e62 9e66 9e6a 9e6d 9e71 9e75 9e78
9e7c 9e7f 9e83 9e86 9e87 9e8c 9e8f 9e93
9e97 9e9a 9e9b 9e9d 9ea0 9ea3 9ea4 9ea9
1 9eac 9eb1 9eb5 9eb9 9ebd 9ec9 9ecd
9ed2 9ed6 9ed9 9eda 9edf 9ee3 9ee7 9eea
9eed 9ef1 9ef3 9ef7 9efb 9efe 9f01 9f05
9f07 9f0b 9f0f 9f12 9f14 9f18 9f1c 9f20
9f23 9f27 9f2b 9f2d 9f2e 9f33 1 9f37
9f3b 9f3f 9f42 9f46 9f4a 9f4e 9f52 9f55
9f59 9f5d 9f60 9f63 9f68 9f6b 9f6e 9f71
9f72 9f77 9f78 1 9f7a 9f7f 9f83 9f87
9f8a 9f8f 9f94 9f97 9f9b 9f9c 9fa1 9fa4
9fa9 9faa 9faf 9fb2 9fb7 9fb8 9fbd 9fc0
9fc4 9fc5 9fca 9fcd 9fd2 9fd3 9fd8 9fdb
9fdf 9fe3 9fe6 9fe9 9fea 9fec 9fed 9ff2
9ff3 9ff8 9ffa 9ffe a001 a003 a007 a009
a015 a017 a019 a01a a01f a023 a025 a031
a033 a035 a039 a03c a03e a042 a046 a04a
a04e a052 a056 a05a a05e a062 a066 a06a
a06e a072 a076 a07a a07e a082 a086 a08a
a08e a092 a096 a09a a09e a0a2 a0a6 a0aa
a0ae a0b2 a0b6 a0ba a0be a0c2 a0c6 a0d2
a0d6 a0da a0dd a0e1 a0e5 a0e7 a0eb a0ef
a0f3 a0f6 a0fa a0fe a100 a101 a106 1
a10a a10e a112 a115 a119 a11d a121 a125
a128 a12c a130 a133 a136 a13b a13e a141
a144 a145 a14a a14b 1 a14d a152 a156
a15a a15d a162 a167 a16a a16e a16f a174
a177 a17c a17d a182 a185 a18a a18b a190
a193 a197 a198 a19d a1a0 a1a5 a1a6 a1ab
a1ae a1b2 a1b6 a1b9 a1bc a1bd a1bf a1c0
a1c5 a1c6 a1cb a1cd a1d1 a1d4 a1d6 a1da
a1dc a1e8 a1ea a1ec a1ed a1f2 a1f6 a1f8
a204 a206 a20a a20e a211 a215 a218 a21c
a21f a220 a225 a228 a22c a22f a230 a235
a238 1 a23b a240 a244 a248 a24b a24f
a253 a256 a257 a259 a25d a261 a264 a268
a269 a26b a26f a273 a277 a27b a287 a28b
a290 a294 a297 a298 a29d a2a1 a2a5 a2a8
a2ab a2af a2b1 a2b5 a2b9 a2bc a2bf a2c3
a2c5 a2c9 a2cd a2d0 a2d2 a2d6 a2da a2de
a2e1 a2e5 a2e9 a2eb a2ec a2f1 1 a2f5
a2f9 a2fd a300 a304 a308 a30c a310 a313
a317 a31b a31e a321 a326 a329 a32c a32f
a330 a335 a336 1 a338 a33d a341 a345
a348 a34d a352 a355 a359 a35a a35f a362
a367 a368 a36d a370 a375 a376 a37b a37e
a382 a383 a388 a38b a390 a391 a396 a399
a39d a3a1 a3a4 a3a7 a3a8 a3aa a3ab a3b0
a3b1 a3b6 a3b8 a3bc a3bf a3c1 a3c5 a3c7
a3d3 a3d5 a3d7 a3d8 a3dd a3e1 a3e3 a3ef
a3f1 a3f5 a3f9 a3fd a401 a405 a409 a40d
a411 a415 a419 a41d a429 a42d a432 a436
a439 a43a a43f a443 a447 a44a a44d a451
a453 a457 a45b a45e a461 a465 a467 a46b
a46f a472 a474 a478 a47c a480 a483 a487
a48b a48d a48e a493 1 a497 a49b a49f
a4a2 a4a6 a4aa a4ae a4b2 a4b5 a4b9 a4bd
a4c0 a4c3 a4c8 a4cb a4ce a4d1 a4d2 a4d7
a4d8 1 a4da a4df a4e3 a4e7 a4ea a4ef
a4f4 a4f7 a4fb a4fc a501 a504 a509 a50a
a50f a512 a517 a518 a51d a520 a524 a525
a52a a52d a532 a533 a538 a53b a53f a543
a546 a549 a54a a54c a54d a552 a553 a558
a55a a55e a561 a563 a567 a569 a575 a577
a579 a57a a57f a583 a585 a591 a593 a597
a59b a59f a5a3 a5a7 a5ab a5af a5b3 a5bf
a5c3 a5c8 a5cc a5cf a5d0 a5d5 a5d9 a5dd
a5e0 a5e3 a5e7 a5e9 a5ed a5f1 a5f4 a5f7
a5fb a5fd a601 a605 a608 a60a a60e a612
a616 a619 a61d a621 a623 a624 a629 1
a62d a631 a635 a638 a63c a640 a644 a648
a64b a64f a653 a656 a659 a65e a661 a664
a667 a668 a66d a66e 1 a670 a675 a679
a67d a680 a685 a68a a68d a691 a692 a697
a69a a69f a6a0 a6a5 a6a8 a6ad a6ae a6b3
a6b6 a6ba a6bb a6c0 a6c3 a6c8 a6c9 a6ce
a6d1 a6d5 a6d9 a6dc a6df a6e0 a6e2 a6e3
a6e8 a6e9 a6ee a6f0 a6f4 a6f7 a6f9 a6fd
a6ff a70b a70d a70f a710 a715 a719 a71b
a727 a729 a72b a72f a733 a737 a73b a73f
a743 a747 a74b a757 a75b a760 a764 a767
a768 a76d a771 a775 a778 a77b a77f a781
a785 a789 a78c a78f a793 a795 a799 a79d
a7a0 a7a2 a7a6 a7aa a7ae a7b1 a7b5 a7b9
a7bb a7bc a7c1 1 a7c5 a7c9 a7cd a7d0
a7d4 a7d8 a7dc a7e0 a7e3 a7e7 a7eb a7ee
a7f1 a7f6 a7f9 a7fc a7ff a800 a805 a806
1 a808 a80d a811 a815 a818 a81d a822
a825 a829 a82a a82f a832 a837 a838 a83d
a840 a845 a846 a84b a84e a852 a853 a858
a85b a860 a861 a866 a869 a86d a871 a874
a877 a878 a87a a87b a880 a881 a886 a888
a88c a88f a891 a895 a897 a8a3 a8a5 a8a7
a8a8 a8ad a8b1 a8b3 a8bf a8c1 a8c5 a8c9
a8cd a8d1 a8d5 a8d9 a8e5 a8e9 a8ee a8f2
a8f5 a8f6 a8fb a8ff a903 a906 a909 a90d
a90f a913 a917 a91a a91d a921 a923 a927
a92b a92e a930 a934 a938 a93c a93f a943
a947 a949 a94a a94f 1 a953 a957 a95b
a95e a962 a966 a96a a96e a971 a975 a979
a97c a97f a984 a987 a98a a98d a98e a993
a994 1 a996 a99b a99f a9a3 a9a6 a9ab
a9b0 a9b3 a9b7 a9b8 a9bd a9c0 a9c5 a9c6
a9cb a9ce a9d3 a9d4 a9d9 a9dc a9e0 a9e1
a9e6 a9e9 a9ee a9ef a9f4 a9f7 a9fb a9ff
aa02 aa05 aa06 aa08 aa09 aa0e aa0f aa14
aa16 aa1a aa1d aa1f aa23 aa25 aa31 aa33
aa35 aa36 aa3b aa3f aa41 aa4d aa4f aa51
aa55 aa59 aa5c aa5e aa62 aa66 aa69 aa6d
aa71 aa75 aa79 aa7d aa89 aa8d aa92 aa96
aa99 aa9a aa9f aaa3 aaa7 aaaa aaad aab1
aab3 aab7 aabb aabe aac1 aac5 aac7 aacb
aacf aad2 aad4 aad8 aadc aae0 aae3 aae7
aaeb aaed aaee aaf3 1 aaf7 aafb aaff
ab02 ab06 ab0a ab0e ab12 ab15 ab19 ab1d
ab20 ab23 ab28 ab2b ab2e ab31 ab32 ab37
ab38 1 ab3a ab3f ab43 ab47 ab4a ab4f
ab54 ab57 ab5b ab5c ab61 ab64 ab69 ab6a
ab6f ab72 ab77 ab78 ab7d ab80 ab84 ab85
ab8a ab8d ab92 ab93 ab98 ab9b ab9f aba3
aba6 aba9 abaa abac abad abb2 abb3 abb8
abba abbe abc1 abc3 abc7 abc9 abd5 abd7
abd9 abda abdf abe3 abe5 abf1 abf3 abf5
abf9 abfc ac00 ac04 ac08 ac0c ac18 ac1c
ac21 ac25 ac28 ac29 ac2e ac32 ac36 ac39
ac3c ac40 ac42 ac46 ac4a ac4d ac50 ac54
ac56 ac5a ac5e ac61 ac63 ac67 ac6b ac6f
ac72 ac76 ac7a ac7c ac7d ac82 1 ac86
ac8a ac8e ac91 ac95 ac99 ac9d aca1 aca4
aca8 acac acaf acb2 acb7 acba acbd acc0
acc1 acc6 acc7 1 acc9 acce acd2 acd6
acd9 acde ace3 ace6 acea aceb acf0 acf3
acf8 acf9 acfe ad01 ad06 ad07 ad0c ad0f
ad13 ad14 ad19 ad1c ad21 ad22 ad27 ad2a
ad2e ad32 ad35 ad38 ad39 ad3b ad3c ad41
ad42 ad47 ad49 ad4d ad50 ad52 ad56 ad58
ad64 ad66 ad68 ad69 ad6e ad72 ad74 ad80
ad82 ad86 ad8a ad8e ad9a ad9e ada3 ada7
adaa adab adb0 adb4 adb8 adbb adbe adc2
adc4 adc8 adcc adcf add2 add6 add8 addc
ade0 ade3 ade5 ade9 aded adf1 adf4 adf8
adfc adfe adff ae04 1 ae08 ae0c ae10
ae13 ae17 ae1b ae1f ae23 ae26 ae2a ae2e
ae31 ae34 ae39 ae3c ae3f ae42 ae43 ae48
ae49 1 ae4b ae50 ae54 ae58 ae5b ae60
ae65 ae68 ae6c ae6d ae72 ae75 ae7a ae7b
ae80 ae83 ae88 ae89 ae8e ae91 ae95 ae96
ae9b ae9e aea3 aea4 aea9 aeac aeb0 aeb4
aeb7 aeba aebb aebd aebe aec3 aec4 aec9
aecb aecf aed2 aed4 aed8 aeda aee6 aee8
aeea aeeb aef0 aef4 aef6 af02 af04 af08
af0c af10 af14 af18 af24 af28 af2d af31
af34 af35 af3a af3e af42 af45 af48 af4c
af4e af52 af56 af59 af5c af60 af62 af66
af6a af6d af6f af73 af77 af7b af7e af82
af86 af88 af89 af8e 1 af92 af96 af9a
af9d afa1 afa5 afa9 afad afb0 afb4 afb8
afbb afbe afc3 afc6 afc9 afcc afcd afd2
afd3 1 afd5 afda afde afe2 afe5 afea
afef aff2 aff6 aff7 affc afff b004 b005
b00a b00d b012 b013 b018 b01b b01f b020
b025 b028 b02d b02e b033 b036 b03a b03e
b041 b044 b045 b047 b048 b04d b04e b053
b055 b059 b05c b05e b062 b064 b070 b072
b074 b075 b07a b07e b080 b08c b08e b092
b096 b099 b09c b09d b09f b0a2 b0a7 b0a8
b0ad b0b1 b0b4 b0b8 b0ba b0be b0c1 b0c5
b0c9 b0cd b0cf b0d3 b0d7 b0da b0de b0e2
b0e5 b0e6 b0e8 b0eb b0ee b0ef b0f4 b0f8
b0fc b0ff b100 b102 b105 b108 b109 b10e
b111 b115 b118 b119 b11e b121 1 b124
b129 b12d b131 b135 b139 b13d b141 b145
b151 b155 b159 b15c b160 b164 b166 b16a
b16e b172 b175 b179 b17d b17f b180 b185
1 b189 b18d b191 b194 b198 b19c b1a0
b1a4 b1a7 b1ab b1af b1b2 b1b5 b1ba b1bd
b1c0 b1c3 b1c4 b1c9 b1ca 1 b1cc b1d1
b1d5 b1d9 b1dc b1e1 b1e6 b1e9 b1ed b1ee
b1f3 b1f6 b1fb b1fc b201 b204 b209 b20a
b20f b212 b216 b217 b21c b21f b224 b225
b22a b22d b231 b235 b238 b23b b23c b23e
b23f b244 b245 b24a b24c b250 b253 b255
b259 b25b b267 b269 b26b b26c b271 b275
b277 b283 b285 b289 b28d b290 b294 b297
b29b b29e b29f b2a4 b2a7 b2ab b2af b2b2
b2b3 b2b5 b2b8 b2bb b2bc b2c1 1 b2c4
b2c9 b2cd b2d1 b2d5 b2d9 b2dd b2e9 b2ed
b2f2 b2f6 b2f9 b2fa b2ff b303 b307 b30a
b30d b311 b313 b317 b31b b31e b321 b325
b327 b32b b32f b332 b334 b338 b33c b340
b343 b347 b34b b34d b34e b353 1 b357
b35b b35f b362 b366 b36a b36e b372 b375
b379 b37d b380 b383 b388 b38b b38e b391
b392 b397 b398 1 b39a b39f b3a3 b3a7
b3aa b3af b3b4 b3b7 b3bb b3bc b3c1 b3c4
b3c9 b3ca b3cf b3d2 b3d7 b3d8 b3dd b3e0
b3e4 b3e5 b3ea b3ed b3f2 b3f3 b3f8 b3fb
b3ff b403 b406 b409 b40a b40c b40d b412
b413 b418 b41a b41e b421 b423 b427 b429
b435 b437 b439 b43a b43f b443 b445 b451
b453 b457 b459 b45d b461 b464 b468 b46b
b46f b472 b473 b478 b47b b47f b483 b486
b487 b489 b48c b48f b490 b495 1 b498
b49d b4a1 b4a5 b4aa b4ac b4b0 b4b4 b4b7
b4bb b4bf b4c1 b4c5 b4c9 b4cd b4d0 b4d4
b4d8 b4da b4db b4e0 1 b4e4 b4e8 b4ec
b4ef b4f3 b4f7 b4fb b4ff b502 b506 b50a
b50d b510 b515 b518 b51b b51e b51f b524
b525 1 b527 b52c b530 b534 b537 b53c
b541 b544 b548 b549 b54e b551 b556 b557
b55c b55f b564 b565 b56a b56d b571 b572
b577 b57a b57f b580 b585 b588 b58c b590
b593 b596 b597 b599 b59a b59f b5a0 b5a5
b5a7 b5ab b5ae b5b0 b5b4 b5b6 b5c2 b5c4
b5c6 b5c7 b5cc b5d0 b5d2 b5de b5e0 b5e4
b5e8 b5eb b5ef b5f3 b5f6 b5f9 b5fe b601
b604 b607 b608 b60d b60e 1 b610 b615
b619 b61d b620 b625 b62a b62d b631 b632
b637 b63a b63f b640 b645 b648 b64d b64e
b653 b656 b65a b65e b662 b666 b669 b66a
b66c b671 b672 b674 b675 b67a b67d b682
b683 b688 b68b b690 b691 b696 b699 b69d
b69e b6a3 b6a6 b6ab b6ac b6b1 b6b2 b6b7
b6b9 b6bd b6c0 b6c4 b6c8 b6cb b6cf b6d3
b6d6 b6d9 b6de b6e1 b6e4 b6e7 b6e8 b6ed
b6ee 1 b6f0 b6f5 b6f9 b6fd b700 b705
b70a b70d b711 b712 b717 b718 b71d b71f
b723 b726 b72a b72e b731 b735 b739 b73c
b740 b744 b745 b74a b74c b750 b754 b757
b759 b75d b760 b764 b768 b76b b76c b76e
b772 b775 b779 b77c b77d b782 b786 b78a
b78d b78e b790 b794 b797 b79b b79e b79f
1 b7a4 b7a9 b7ad b7b1 b7b6 b7bb b7bf
b7c3 b7c7 b7ca b7cd b7d1 b7d5 b7d9 b7dc
b7dd b7df b7e2 b7e5 b7e6 b7eb b7ef b7f3
b7f6 b7f7 b7f9 b7fc b7ff b800 1 b805
b80a b80e b812 b816 b81a b81e b822 b826
b82a b82e b832 b836 b83a b83e b842 b846
b84a b856 b85a b85f b863 b866 b867 b86c
b870 b874 b877 b87a b87e b880 b884 b888
b88b b88e b892 b894 b898 b89c b89f b8a1
b8a5 b8a9 b8ad b8b0 b8b4 b8b8 b8ba b8bb
b8c0 1 b8c4 b8c8 b8cc b8cf b8d3 b8d7
b8db b8df b8e2 b8e6 b8ea b8ed b8f0 b8f5
b8f8 b8fb b8fe b8ff b904 b905 1 b907
b90c b910 b914 b917 b91c b921 b924 b928
b929 b92e b931 b936 b937 b93c b93f b944
b945 b94a b94d b951 b952 b957 b95a b95f
b960 b965 b968 b96c b970 b973 b976 b977
b979 b97a b97f b980 b985 b987 b98b b98e
b990 b994 b996 b9a2 b9a4 b9a6 b9a7 b9ac
b9b0 b9b2 b9be b9c0 b9c2 b9c6 b9ca b9ce
b9d2 b9d6 b9da b9de b9e2 b9e6 b9ea b9ee
b9f2 b9f6 b9fa b9fe ba02 ba06 ba0a ba0e
ba12 ba16 ba1a ba1e ba22 ba26 ba2a ba2e
ba32 ba3e ba42 ba47 ba4b ba4e ba4f ba54
ba58 ba5c ba5f ba62 ba66 ba68 ba6c ba70
ba73 ba76 ba7a ba7c ba80 ba84 ba87 ba89
ba8d ba91 ba95 ba98 ba9c baa0 baa2 baa3
baa8 1 baac bab0 bab4 bab7 babb babf
bac3 bac7 baca bace bad2 bad5 bad8 badd
bae0 bae3 bae6 bae7 baec baed 1 baef
baf4 baf8 bafc baff bb04 bb09 bb0c bb10
bb11 bb16 bb19 bb1e bb1f bb24 bb27 bb2c
bb2d bb32 bb35 bb39 bb3a bb3f bb42 bb47
bb48 bb4d bb50 bb54 bb58 bb5b bb5e bb5f
bb61 bb62 bb67 bb68 bb6d bb6f bb73 bb76
bb78 bb7c bb7e bb8a bb8c bb8e bb8f bb94
bb98 bb9a bba6 bba8 bbaa bbae bbb2 bbb5
bbb9 bbbd bbc0 bbc4 bbc7 bbcb bbce bbcf
bbd4 bbd7 bbdb bbde bbe2 bbe6 bbea bbee
bbf2 bbf6 bbfa bbfe bc0a bc0e bc12 bc15
bc19 bc1d bc1f bc23 bc27 bc2b bc2e bc32
bc36 bc38 bc39 bc3e 1 bc42 bc46 bc4a
bc4d bc51 bc55 bc59 bc5d bc60 bc64 bc68
bc6b bc6e bc73 bc76 bc79 bc7c bc7d bc82
bc83 1 bc85 bc8a bc8e bc92 bc95 bc9a
bc9f bca2 bca6 bca7 bcac bcaf bcb4 bcb5
bcba bcbd bcc2 bcc3 bcc8 bccb bccf bcd0
bcd5 bcd8 bcdd bcde bce3 bce6 bcea bcee
bcf1 bcf4 bcf5 bcf7 bcf8 bcfd bcfe bd03
bd05 bd09 bd0c bd0e bd12 bd14 bd20 bd22
bd24 bd25 bd2a bd2e bd30 bd3c bd3e bd42
bd46 bd49 bd4a bd4c bd4f bd52 bd53 bd58
bd5c bd62 bd64 bd68 bd6c bd70 bd74 bd78
bd84 bd88 bd8d bd91 bd94 bd95 bd9a bd9e
bda2 bda5 bda8 bdac bdae bdb2 bdb6 bdb9
bdbc bdc0 bdc2 bdc6 bdca bdcd bdcf bdd3
bdd7 bddb bdde bde2 bde6 bde8 bde9 bdee
1 bdf2 bdf6 bdfa bdfd be01 be05 be09
be0d be10 be14 be18 be1b be1e be23 be26
be29 be2c be2d be32 be33 1 be35 be3a
be3e be42 be45 be4a be4f be52 be56 be57
be5c be5f be64 be65 be6a be6d be72 be73
be78 be7b be7f be80 be85 be88 be8d be8e
be93 be96 be9a be9e bea1 bea4 bea5 bea7
bea8 bead beae beb3 beb5 beb9 bebc bebe
bec2 bec4 bed0 bed2 bed4 bed5 beda bede
bee0 beec beee bef2 bef6 befa befe bf02
bf03 bf05 bf08 bf09 bf0b bf0e bf12 bf16
bf1a bf1b bf1d bf20 bf21 bf23 bf24 bf29
bf2c bf2f bf32 bf33 bf38 bf39 bf3b bf3f
bf43 bf47 bf4b bf4f bf53 bf57 bf5b bf5f
bf63 bf6f bf73 bf77 bf7a bf7e bf82 bf84
bf88 bf8c bf90 bf93 bf97 bf9b bf9d bf9e
bfa3 1 bfa7 bfab bfaf bfb2 bfb6 bfba
bfbe bfc2 bfc5 bfc9 bfcd bfd0 bfd3 bfd8
bfdb bfde bfe1 bfe2 bfe7 bfe8 1 bfea
bfef bff3 bff7 bffa bfff c004 c007 c00b
c00c c011 c014 c019 c01a c01f c022 c027
c028 c02d c030 c034 c035 c03a c03d c042
c043 c048 c04b c04f c053 c056 c059 c05a
c05c c05d c062 c063 c068 c06a c06e c071
c073 c077 c079 c085 c087 c089 c08a c08f
c093 c095 c0a1 c0a3 c0a7 c0ab c0ae c0af
c0b1 c0b5 c0b8 c0bc c0bf c0c0 c0c2 c0c3
c0c8 c0cc c0d0 c0d3 c0d7 c0db c0de c0df
c0e1 c0e5 c0e6 c0eb c0ed c0f1 c0f4 c0f8
c0fc c100 c104 c108 c10c c110 c114 c118
c11c c120 c124 c128 c12c c130 c134 c138
c13c c140 c144 c148 c14c c158 c15c c161
c165 c168 c169 c16e c172 c176 c179 c17c
c180 c182 c186 c18a c18d c190 c194 c196
c19a c19e c1a1 c1a3 c1a7 c1ab c1af c1b2
c1b6 c1ba c1bc c1bd c1c2 1 c1c6 c1ca
c1ce c1d1 c1d5 c1d9 c1dd c1e1 c1e4 c1e8
c1ec c1ef c1f2 c1f7 c1fa c1fd c200 c201
c206 c207 1 c209 c20e c212 c216 c219
c21e c223 c226 c22a c22b c230 c233 c238
c239 c23e c241 c246 c247 c24c c24f c253
c254 c259 c25c c261 c262 c267 c26a c26e
c272 c275 c278 c279 c27b c27c c281 c282
c287 c289 c28d c290 c292 c296 c298 c2a4
c2a6 c2a8 c2a9 c2ae c2b2 c2b4 c2c0 c2c2
c2c4 c2c8 c2cc c2cf c2d3 c2d7 c2db c2df
c2e3 c2e7 c2eb c2ef c2f3 c2f7 c2fb c2ff
c303 c307 c30b c30f c313 c317 c31b c31f
c323 c327 c32b c32f c333 c337 c33b c33f
c343 c347 c34b c357 c35b c360 c364 c367
c368 c36d c371 c375 c378 c37b c37f c381
c385 c389 c38c c38f c393 c395 c399 c39d
c3a0 c3a2 c3a6 c3aa c3ae c3b1 c3b5 c3b9
c3bb c3bc c3c1 1 c3c5 c3c9 c3cd c3d0
c3d4 c3d8 c3dc c3e0 c3e3 c3e7 c3eb c3ee
c3f1 c3f6 c3f9 c3fc c3ff c400 c405 c406
1 c408 c40d c411 c415 c418 c41d c422
c425 c429 c42a c42f c432 c437 c438 c43d
c440 c445 c446 c44b c44e c452 c453 c458
c45b c460 c461 c466 c469 c46d c471 c474
c477 c478 c47a c47b c480 c481 c486 c488
c48c c48f c491 c495 c497 c4a3 c4a5 c4a7
c4a8 c4ad c4b1 c4b3 c4bf c4c1 c4c5 c4c9
c4cd c4d1 c4d5 c4d6 c4d8 c4db c4dc c4de
c4e1 c4e5 c4e9 c4ed c4ee c4f0 c4f3 c4f4
c4f6 c4f7 c4fc c4ff c502 c505 c506 c50b
c50c c50e c512 c516 c51a c51e c521 c525
c529 c52c c52d c52f c533 c537 c53a c53b
c53d c541 c545 c549 c54d c551 c555 c559
c55d c560 c561 c563 c567 c56b c56e c56f
c571 c572 c574 c578 c57a c57e c584 c586
c58a c58e c591 c593 c597 c59c c5a0 c5a4
c5a7 c5aa c5ab c5b0 c5b4 c5b8 c5bb c5bc
c5be c5c1 c5c4 c5c5 c5ca c5ce c5d2 c5d6
c5da c5de c5e1 c5e2 c5e4 c5e7 c5ea c5eb
c5f0 c5f4 c5f8 c5fb c5fc c5fe c601 c604
c605 1 c60a c60f c613 c617 c61a c61b
c61d c620 c623 c624 1 c629 c62e c632
c635 c639 c63d c641 c645 c648 c649 c64b
c64f c651 c655 c658 c65c c660 c664 c668
c66c c670 c674 c678 c67c c680 c684 c688
c694 c698 c69d c6a1 c6a4 c6a5 c6aa c6ae
c6b2 c6b5 c6b8 c6bc c6be c6c2 c6c6 c6c9
c6cc c6d0 c6d2 c6d6 c6da c6dd c6df c6e3
c6e7 c6eb c6ee c6f2 c6f6 c6f8 c6f9 c6fe
1 c702 c706 c70a c70d c711 c715 c719
c71d c720 c724 c728 c72b c72e c733 c736
c739 c73c c73d c742 c743 1 c745 c74a
c74e c752 c755 c75a c75f c762 c766 c767
c76c c76f c774 c775 c77a c77d c782 c783
c788 c78b c78f c790 c795 c798 c79d c79e
c7a3 c7a6 c7aa c7ae c7b1 c7b4 c7b5 c7b7
c7b8 c7bd c7be c7c3 c7c5 c7c9 c7cc c7ce
c7d2 c7d4 c7e0 c7e2 c7e4 c7e5 c7ea c7ee
c7f0 c7fc c7fe c800 c804 c808 c80c c810
c814 c818 c81c c820 c824 c828 c82c c830
c834 c838 c83c c840 c844 c848 c84c c850
c854 c858 c85c c860 c864 c868 c86c c870
c874 c878 c87b c87c c87e c882 c886 c889
c88a c88c c88f c892 c895 c896 c89b c89e
c8a2 c8a6 c8a9 c8aa c8ac c8b0 c8b3 c8b7
c8ba c8bb c8bd c8be c8c3 c8c7 c8cb c8ce
c8cf c8d1 c8d5 c8d8 c8dc c8df c8e0 c8e2
c8e3 1 c8e8 c8ed 1 c8f0 c8f5 c8f9
c8fd c900 c901 c903 c906 c909 c90a c90f
c913 c917 c91b c91f c923 c927 c92b c92f
c933 c937 c93b c93f c943 c947 c94b c94f
c953 c957 c95b c95f c963 c967 c96b c96f
c973 c977 c97b c97f c983 c987 c98b c98f
c993 c997 c99b c99f c9a3 c9af c9b3 c9b8
c9bc c9bf c9c0 c9c5 c9c9 c9cd c9d0 c9d3
c9d7 c9d9 c9dd c9e1 c9e4 c9e7 c9eb c9ed
c9f1 c9f5 c9f8 c9fa c9fe ca02 ca06 ca09
ca0d ca11 ca13 ca14 ca19 1 ca1d ca21
ca25 ca28 ca2c ca30 ca34 ca38 ca3b ca3f
ca43 ca46 ca49 ca4e ca51 ca54 ca57 ca58
ca5d ca5e 1 ca60 ca65 ca69 ca6d ca70
ca75 ca7a ca7d ca81 ca82 ca87 ca8a ca8f
ca90 ca95 ca98 ca9d ca9e caa3 caa6 caaa
caab cab0 cab3 cab8 cab9 cabe cac1 cac5
cac9 cacc cacf cad0 cad2 cad3 cad8 cad9
cade cae0 cae4 cae7 cae9 caed caef cafb
cafd caff cb00 cb05 cb09 cb0b cb17 cb19
cb1b cb1f cb23 cb27 cb2b cb2f cb33 cb37
cb3b cb3f cb43 cb47 cb4b cb4f cb53 cb57
cb5b cb5f cb63 cb67 cb6b cb6f cb73 cb77
cb7b cb7f cb83 cb87 cb8b cb8f cb93 cb97
cb9b cb9f cba3 cba7 cbab cbaf cbb3 cbb7
cbc3 cbc7 cbcc cbd0 cbd3 cbd4 cbd9 cbdd
cbe1 cbe4 cbe7 cbeb cbed cbf1 cbf5 cbf8
cbfb cbff cc01 cc05 cc09 cc0c cc0e cc12
cc16 cc1a cc1d cc21 cc25 cc27 cc28 cc2d
1 cc31 cc35 cc39 cc3c cc40 cc44 cc48
cc4c cc4f cc53 cc57 cc5a cc5d cc62 cc65
cc68 cc6b cc6c cc71 cc72 1 cc74 cc79
cc7d cc81 cc84 cc89 cc8e cc91 cc95 cc96
cc9b cc9e cca3 cca4 cca9 ccac ccb1 ccb2
ccb7 ccba ccbe ccbf ccc4 ccc7 cccc cccd
ccd2 ccd5 ccd9 ccdd cce0 cce3 cce4 cce6
cce7 ccec cced ccf2 ccf4 ccf8 ccfb ccfd
cd01 cd03 cd0f cd11 cd13 cd14 cd19 cd1d
cd1f cd2b cd2d cd2f cd33 cd37 cd3a cd3c
cd40 cd44 cd48 cd4c cd50 cd54 cd58 cd5c
cd60 cd64 cd68 cd6c cd70 cd74 cd78 cd7c
cd80 cd84 cd88 cd8c cd90 cd94 cd98 cd9c
cda0 cda4 cda8 cdac cdb0 cdb4 cdb8 cdbc
cdc0 cdcc cdd0 cdd5 cdd9 cddc cddd cde2
cde6 cdea cded cdf0 cdf4 cdf6 cdfa cdfe
ce01 ce04 ce08 ce0a ce0e ce12 ce15 ce17
ce1b ce1f ce23 ce26 ce2a ce2e ce30 ce31
ce36 1 ce3a ce3e ce42 ce45 ce49 ce4d
ce51 ce55 ce58 ce5c ce60 ce63 ce66 ce6b
ce6e ce71 ce74 ce75 ce7a ce7b 1 ce7d
ce82 ce86 ce8a ce8d ce92 ce97 ce9a ce9e
ce9f cea4 cea7 ceac cead ceb2 ceb5 ceba
cebb cec0 cec3 cec7 cec8 cecd ced0 ced5
ced6 cedb cede cee2 cee6 cee9 ceec ceed
ceef cef0 cef5 cef6 cefb cefd cf01 cf04
cf06 cf0a cf0c cf18 cf1a cf1c cf1d cf22
cf26 cf28 cf34 cf36 cf38 cf3c cf40 cf43
cf47 cf4b cf4e cf4f cf51 cf54 cf57 cf58
cf5d cf60 cf64 cf68 cf6b cf6c cf6e cf71
cf74 cf75 cf7a 1 cf7d cf82 cf86 cf89
cf8d cf91 cf93 cf97 cf9b cf9e cf9f cfa1
cfa4 cfa7 cfa8 cfad cfb1 cfb5 cfb9 cfbc
cfbd cfbf cfc3 cfc5 cfc9 cfcd cfd0 cfd2
cfd6 cfda cfdd cfe1 cfe5 cfe9 cfed cff1
cff5 cff8 cff9 cffb cfff d003 d006 d007
d009 d00d d011 d014 d015 d017 d01b d01f
d022 d023 d025 d029 d02d d030 d031 d033
d037 d03b d03e d03f d041 d045 d049 d04c
d04d d04f d053 d057 d05a d05b d05d d061
d065 d069 d06a d06c d070 d074 d078 d07b
d07c d07e d082 d085 d089 d08c d08d d092
d096 d09a d09f d0a1 d0a5 d0a9 d0ac d0b0
d0b4 d0b6 d0ba d0be d0c2 d0c5 d0c9 d0cd
d0cf d0d0 d0d5 1 d0d9 d0dd d0e1 d0e4
d0e8 d0ec d0f0 d0f4 d0f7 d0fb d0ff d102
d105 d10a d10d d110 d113 d114 d119 d11a
1 d11c d121 d125 d129 d12c d131 d136
d139 d13d d13e d143 d146 d14b d14c d151
d154 d159 d15a d15f d162 d166 d167 d16c
d16f d174 d175 d17a d17d d181 d185 d188
d18b d18c d18e d18f d194 d195 d19a d19c
d1a0 d1a3 d1a5 d1a9 d1ab d1b7 d1b9 d1bb
d1bc d1c1 d1c5 d1c7 d1d3 d1d5 d1d9 d1dd
d1e0 d1e4 d1e8 d1eb d1ee d1f3 d1f6 d1f9
d1fc d1fd d202 d203 1 d205 d20a d20e
d212 d215 d21a d21f d222 d226 d227 d22c
d22f d234 d235 d23a d23d d242 d243 d248
d24b d24f d253 d257 d25b d25e d25f d261
d266 d267 d269 d26a d26f d270 d275 d277
d27b d27e d282 d286 d289 d28d d291 d294
d297 d29c d29f d2a2 d2a5 d2a6 d2ab d2ac
1 d2ae d2b3 d2b7 d2bb d2be d2c3 d2c8
d2cb d2cf d2d0 d2d5 d2d6 d2db d2dd d2e1
d2e4 d2e8 d2ec d2ef d2f3 d2f7 d2fa d2fe
d2ff d304 d308 d30a d30e d312 d315 d316
d318 d31b d31e d31f d324 d328 d32c d331
d333 d337 d33b d33e d342 d346 d348 d34c
d350 d354 d357 d35b d35f d361 d362 d367
1 d36b d36f d373 d376 d37a d37e d382
d386 d389 d38d d391 d394 d397 d39c d39f
d3a2 d3a5 d3a6 d3ab d3ac 1 d3ae d3b3
d3b7 d3bb d3be d3c3 d3c8 d3cb d3cf d3d0
d3d5 d3d8 d3dd d3de d3e3 d3e6 d3eb d3ec
d3f1 d3f4 d3f8 d3f9 d3fe d401 d406 d407
d40c d40f d413 d417 d41a d41d d41e d420
d421 d426 d427 d42c d42e d432 d435 d437
d43b d43d d449 d44b d44d d44e d453 d457
d459 d465 d467 d46b d46f d472 d476 d47a
d47d d480 d485 d488 d48b d48e d48f d494
d495 1 d497 d49c d4a0 d4a4 d4a7 d4ac
d4b1 d4b4 d4b8 d4b9 d4be d4c1 d4c6 d4c7
d4cc d4cf d4d4 d4d5 d4da d4dd d4e1 d4e5
d4e9 d4ea d4ec d4f1 d4f2 d4f4 d4f5 d4fa
d4fd d502 d503 d508 d50b d510 d511 d516
d519 d51d d51e d523 d526 d52b d52c d531
d532 d537 d539 d53d d540 d544 d548 d54b
d54f d553 d556 d559 d55e d561 d564 d567
d568 d56d d56e 1 d570 d575 d579 d57d
d580 d585 d58a d58d d591 d592 d597 d598
d59d d59f d5a3 d5a6 d5aa d5ae d5b1 d5b5
d5b9 d5bc d5bd d5bf d5c3 d5c7 d5c8 d5cd
d5cf d5d3 d5d7 d5da d5dc d5e0 d5e4 d5e7
d5e8 d5ea d5ed d5f0 d5f1 d5f6 d5fa d5fe
d601 d602 d604 d607 d60a d60b 1 d610
d615 d619 d61d d620 d621 d623 d626 d629
d62a 1 d62f d634 d638 d63b d63f d643
d647 d64b d64e d64f d651 d655 d657 d65b
d65e d662 d666 d669 d66a d66c d66f d672
d673 d678 d67b d67f d683 d686 d687 d689
d68d d690 d694 d697 d698 d69a d69b d6a0
1 d6a3 d6a8 d6ac d6b0 d6b4 d6b7 d6b8
d6ba d6be d6c0 d6c4 d6c8 d6cc d6d0 d6d3
d6d4 d6d6 d6d9 d6dd d6e1 d6e4 d6e5 d6e7
d6e8 d6ed d6ee d6f0 d6f4 d6f6 d6fa d6fe
d701 d705 d709 d70c d70d d70f d712 d715
d716 d71b d71f d723 d727 d72a d72b d72d
d730 d733 d734 d739 d73d d73f d743 d747
d74b d74f d753 d756 d757 d759 d75a d75c
d75f d762 d763 d768 d769 d76b d76f d771
d775 d779 d77c d780 d784 d787 d788 d78a
d78d d790 d791 d796 d79a d79e d7a2 d7a6
d7aa d7ae d7b2 d7b6 d7ba d7be d7c2 d7c6
d7d2 d7d6 d7db d7df d7e2 d7e3 d7e8 d7ec
d7f0 d7f3 d7f6 d7fa d7fc d800 d804 d807
d80a d80e d810 d814 d818 d81b d81d d821
d825 d829 d82c d830 d834 d836 d837 d83c
1 d840 d844 d848 d84b d84f d853 d857
d85b d85e d862 d866 d869 d86c d871 d874
d877 d87a d87b d880 d881 1 d883 d888
d88c d890 d893 d898 d89d d8a0 d8a4 d8a5
d8aa d8ad d8b2 d8b3 d8b8 d8bb d8c0 d8c1
d8c6 d8c9 d8cd d8ce d8d3 d8d6 d8db d8dc
d8e1 d8e4 d8e8 d8ec d8ef d8f2 d8f3 d8f5
d8f6 d8fb d8fc d901 d903 d907 d90a d90c
d910 d912 d91e d920 d922 d923 d928 d92c
d92e d93a d93c d93e d942 d946 d94a d94e
d952 d956 d95a d95e d962 d966 d96a d96e
d972 d976 d97a d97e d982 d986 d98a d98e
d992 d996 d99a d99e d9a2 d9a6 d9aa d9ae
d9b2 d9b6 d9ba d9be d9c2 d9ce d9d2 d9d7
d9db d9de d9df d9e4 d9e8 d9ec d9ef d9f2
d9f6 d9f8 d9fc da00 da03 da06 da0a da0c
da10 da14 da17 da19 da1d da21 da25 da28
da2c da30 da32 da33 da38 1 da3c da40
da44 da47 da4b da4f da53 da57 da5a da5e
da62 da65 da68 da6d da70 da73 da76 da77
da7c da7d 1 da7f da84 da88 da8c da8f
da94 da99 da9c daa0 daa1 daa6 daa9 daae
daaf dab4 dab7 dabc dabd dac2 dac5 dac9
daca dacf dad2 dad7 dad8 dadd dae0 dae4
dae8 daeb daee daef daf1 daf2 daf7 daf8
dafd daff db03 db06 db08 db0c db0e db1a
db1c db1e db1f db24 db28 db2a db36 db38
db3a db3e db42 db45 db47 db4b db4f db52
db56 db59 db5d db61 db65 db68 db69 db6b
db6f db72 db76 db79 db7a db7f db83 db86
db8a db8c db90 db93 db97 db99 db9d dba1
dba4 dba8 dbac dbaf dbb0 dbb2 dbb5 dbb8
dbb9 dbbe dbc2 dbc6 dbca dbcd dbd1 dbd3
dbd7 dbdb dbdf dbe2 dbe6 dbea dbed dbee
dbf0 dbf4 dbf8 dbfb dbfc dbfe dc02 dc04
dc08 dc0c dc0f dc13 dc16 dc1a dc1e dc22
dc25 dc26 dc28 dc2b dc2e dc2f dc34 dc38
dc3c dc3f dc40 dc42 dc45 dc48 dc49 dc4e
dc52 dc56 dc5a dc5e dc61 dc62 dc64 dc67
dc6b dc6f dc72 dc73 dc75 dc76 dc7b dc7e
dc81 dc84 dc85 dc8a dc8d dc90 dc93 dc94
dc99 dc9a dc9c dca0 dca4 dca8 dcab dcac
dcae dcb2 dcb5 dcb9 dcbc dcbd dcbf dcc0
dcc5 dcc9 dccd dcd1 dcd4 dcd5 dcd7 dcdb
dcdf dce3 dce7 dceb dcee dcef dcf1 dcf4
dcf7 dcf8 dcfd dd00 dd03 dd07 dd0b dd0e
dd0f dd11 dd12 dd17 dd1a dd1d dd1e dd23
dd24 dd26 dd2a dd2c dd30 dd33 dd37 dd39
dd3d dd41 dd44 dd45 dd47 dd4b dd4e dd52
dd55 dd56 dd58 dd59 dd5e dd62 dd66 dd6a
dd6d dd6e dd70 dd74 dd76 dd7a dd7e dd81
dd83 dd87 dd8a dd8e dd92 dd96 dd9a dd9e
dda2 dda6 ddaa ddae ddb2 ddb6 ddba ddbe
ddc2 ddc6 ddca ddce ddd2 ddd6 ddda ddde
dde2 dde6 ddea ddee ddf2 ddf6 ddfa ddfe
de02 de05 de08 de0b de0e de11 de12 de14
de18 de1c de1f de22 de23 de28 de2c de30
de35 de37 de3b de3f de42 de46 de4a de4c
de50 de54 de58 de5b de5f de63 de65 de66
de6b 1 de6f de73 de77 de7a de7e de82
de86 de8a de8d de91 de95 de98 de9b dea0
dea3 dea6 dea9 deaa deaf deb0 1 deb2
deb7 debb debf dec2 dec7 decc decf ded3
ded4 ded9 dedc dee1 dee2 dee7 deea deef
def0 def5 def8 defc defd df02 df05 df0a
df0b df10 df13 df17 df1b df1e df21 df22
df24 df25 df2a df2b df30 df32 df36 df39
df3b df3f df41 df4d df4f df51 df52 df57
df5b df5d df69 df6b df6f df73 df76 df7a
df7e df81 df84 df89 df8c df8f df92 df93
df98 df99 1 df9b dfa0 dfa4 dfa8 dfab
dfb0 dfb5 dfb8 dfbc dfbd dfc2 dfc5 dfca
dfcb dfd0 dfd3 dfd8 dfd9 dfde dfe1 dfe5
dfe9 dfed dff1 dff4 dff5 dff7 dffc dffd
dfff e000 e005 e008 e00d e00e e013 e016
e01b e01c e021 e024 e028 e029 e02e e031
e036 e037 e03c e03d e042 e044 e048 e04b
e04f e053 e056 e05a e05e e061 e064 e069
e06c e06f e072 e073 e078 e079 1 e07b
e080 e084 e088 e08b e090 e095 e098 e09c
e09d e0a2 e0a3 e0a8 e0aa e0ae e0b1 e0b5
e0b9 e0bc e0c0 e0c4 e0c7 e0cb e0cf e0d0
e0d5 e0d9 e0db e0df e0e2 e0e5 e0e6 e0eb
e0ef e0f3 e0f8 e0fa e0fe e102 e105 e109
e10d e10f e113 e117 e11b e11e e122 e126
e128 e129 e12e 1 e132 e136 e13a e13d
e141 e145 e149 e14d e150 e154 e158 e15b
e15e e163 e166 e169 e16c e16d e172 e173
1 e175 e17a e17e e182 e185 e18a e18f
e192 e196 e197 e19c e19f e1a4 e1a5 e1aa
e1ad e1b2 e1b3 e1b8 e1bb e1bf e1c0 e1c5
e1c8 e1cd e1ce e1d3 e1d6 e1da e1de e1e1
e1e4 e1e5 e1e7 e1e8 e1ed e1ee e1f3 e1f5
e1f9 e1fc e1fe e202 e204 e210 e212 e214
e215 e21a e21e e220 e22c e22e e232 e236
e239 e23d e241 e244 e247 e24c e24f e252
e255 e256 e25b e25c 1 e25e e263 e267
e26b e26e e273 e278 e27b e27f e280 e285
e288 e28d e28e e293 e296 e29b e29c e2a1
e2a4 e2a8 e2ac e2b0 e2b4 e2b7 e2b8 e2ba
e2bf e2c0 e2c2 e2c3 e2c8 e2cb e2d0 e2d1
e2d6 e2d9 e2de e2df e2e4 e2e7 e2eb e2ec
e2f1 e2f4 e2f9 e2fa e2ff e300 e305 e307
e30b e30e e312 e316 e319 e31d e321 e324
e327 e32c e32f e332 e335 e336 e33b e33c
1 e33e e343 e347 e34b e34e e353 e358
e35b e35f e360 e365 e366 e36b e36d e371
e374 e378 e37c e37f e383 e387 e38a e38e
e392 e393 e398 e39a e39e e3a2 e3a5 e3a7
e3ab e3af e3b2 e3b6 e3ba e3be e3c2 e3c6
e3ca e3ce e3da e3de e3e3 e3e7 e3ea e3eb
e3f0 e3f4 e3f8 e3fb e3fe e402 e404 e408
e40c e40f e412 e416 e418 e41c e420 e423
e425 e429 e42d e431 e434 e438 e43c e43e
e43f e444 1 e448 e44c e450 e453 e457
e45b e45f e463 e466 e46a e46e e471 e474
e479 e47c e47f e482 e483 e488 e489 1
e48b e490 e494 e498 e49b e4a0 e4a5 e4a8
e4ac e4ad e4b2 e4b5 e4ba e4bb e4c0 e4c3
e4c8 e4c9 e4ce e4d1 e4d5 e4d6 e4db e4de
e4e3 e4e4 e4e9 e4ec e4f0 e4f4 e4f7 e4fa
e4fb e4fd e4fe e503 e504 e509 e50b e50f
e512 e514 e518 e51a e526 e528 e52a e52b
e530 e534 e536 e542 e544 e548 e54c e550
e554 e558 e55c e560 e564 e568 e56c e570
e574 e578 e57c e580 e584 e588 e58c e590
e594 e598 e59c e5a0 e5a4 e5b0 e5b4 e5b9
e5bd e5c0 e5c1 e5c6 e5ca e5ce e5d1 e5d4
e5d8 e5da e5de e5e2 e5e5 e5e8 e5ec e5ee
e5f2 e5f6 e5f9 e5fb e5ff e603 e607 e60a
e60e e612 e614 e615 e61a 1 e61e e622
e626 e629 e62d e631 e635 e639 e63c e640
e644 e647 e64a e64f e652 e655 e658 e659
e65e e65f 1 e661 e666 e66a e66e e671
e676 e67b e67e e682 e683 e688 e68b e690
e691 e696 e699 e69e e69f e6a4 e6a7 e6ab
e6ac e6b1 e6b4 e6b9 e6ba e6bf e6c2 e6c6
e6ca e6cd e6d0 e6d1 e6d3 e6d4 e6d9 e6da
e6df e6e1 e6e5 e6e8 e6ea e6ee e6f0 e6fc
e6fe e700 e701 e706 e70a e70c e718 e71a
e71e e722 e726 e72a e72e e732 e736 e73a
e73e e742 e746 e752 e756 e75b e75f e762
e763 e768 e76c e770 e773 e776 e77a e77c
e780 e784 e787 e78a e78e e790 e794 e798
e79b e79d e7a1 e7a5 e7a9 e7ac e7b0 e7b4
e7b6 e7b7 e7bc 1 e7c0 e7c4 e7c8 e7cb
e7cf e7d3 e7d7 e7db e7de e7e2 e7e6 e7e9
e7ec e7f1 e7f4 e7f7 e7fa e7fb e800 e801
1 e803 e808 e80c e810 e813 e818 e81d
e820 e824 e825 e82a e82d e832 e833 e838
e83b e840 e841 e846 e849 e84d e84e e853
e856 e85b e85c e861 e864 e868 e86c e86f
e872 e873 e875 e876 e87b e87c e881 e883
e887 e88a e88c e890 e892 e89e e8a0 e8a2
e8a3 e8a8 e8ac e8ae e8ba e8bc e8c0 e8c4
e8c8 e8cc e8d0 e8d4 e8d8 e8dc e8e0 e8e4
e8e8 e8f4 e8f8 e8fd e901 e904 e905 e90a
e90e e912 e915 e918 e91c e91e e922 e926
e929 e92c e930 e932 e936 e93a e93d e93f
e943 e947 e94b e94e e952 e956 e958 e959
e95e 1 e962 e966 e96a e96d e971 e975
e979 e97d e980 e984 e988 e98b e98e e993
e996 e999 e99c e99d e9a2 e9a3 1 e9a5
e9aa e9ae e9b2 e9b5 e9ba e9bf e9c2 e9c6
e9c7 e9cc e9cf e9d4 e9d5 e9da e9dd e9e2
e9e3 e9e8 e9eb e9ef e9f0 e9f5 e9f8 e9fd
e9fe ea03 ea06 ea0a ea0e ea11 ea14 ea15
ea17 ea18 ea1d ea1e ea23 ea25 ea29 ea2c
ea2e ea32 ea34 ea40 ea42 ea44 ea45 ea4a
ea4e ea50 ea5c ea5e ea62 ea66 ea6a ea6d
ea6e ea70 ea73 ea76 ea77 ea7c ea80 ea84
ea88 ea8c ea8f ea90 ea92 ea95 ea99 ea9d
eaa0 eaa1 eaa3 eaa4 eaa9 eaad eab1 eab6
eaba eabe eac2 eac6 eaca eace eacf ead1
ead5 ead9 eade eae2 eae6 eaea eaee eaf2
eaf6 eaf7 eaf9 eafd eb01 eb05 eb09 eb0d
eb11 eb15 eb19 eb25 eb29 eb2e eb32 eb35
eb36 eb3b eb3f eb43 eb46 eb49 eb4d eb4f
eb53 eb57 eb5a eb5d eb61 eb63 eb67 eb6b
eb6e eb70 eb74 eb78 eb7c eb7f eb83 eb87
eb89 eb8a eb8f 1 eb93 eb97 eb9b eb9e
eba2 eba6 ebaa ebae ebb1 ebb5 ebb9 ebbc
ebbf ebc4 ebc7 ebca ebcd ebce ebd3 ebd4
1 ebd6 ebdb ebdf ebe3 ebe6 ebeb ebf0
ebf3 ebf7 ebf8 ebfd ec00 ec05 ec06 ec0b
ec0e ec13 ec14 ec19 ec1c ec20 ec21 ec26
ec29 ec2e ec2f ec34 ec37 ec3b ec3f ec42
ec45 ec46 ec48 ec49 ec4e ec4f ec54 ec56
ec5a ec5d ec5f ec63 ec65 ec71 ec73 ec75
ec76 ec7b ec7f ec81 ec8d ec8f ec93 ec97
ec9a ec9b ec9d eca0 eca3 eca4 eca9 ecac
ecb0 ecb4 ecb7 ecb8 ecba ecbd ecc0 ecc1
ecc6 1 ecc9 ecce ecd2 ecd6 ecda ecde
ece2 ece6 ecea ecee ecf2 ecf6 ecfa ecfe
ed02 ed06 ed0a ed0e ed12 ed1e ed22 ed27
ed2b ed2e ed2f ed34 ed38 ed3c ed3f ed42
ed46 ed48 ed4c ed50 ed53 ed56 ed5a ed5c
ed60 ed64 ed67 ed69 ed6d ed71 ed75 ed78
ed7c ed80 ed82 ed83 ed88 1 ed8c ed90
ed94 ed97 ed9b ed9f eda3 eda7 edaa edae
edb2 edb5 edb8 edbd edc0 edc3 edc6 edc7
edcc edcd 1 edcf edd4 edd8 eddc eddf
ede4 ede9 edec edf0 edf1 edf6 edf9 edfe
edff ee04 ee07 ee0c ee0d ee12 ee15 ee19
ee1a ee1f ee22 ee27 ee28 ee2d ee30 ee34
ee38 ee3b ee3e ee3f ee41 ee42 ee47 ee48
ee4d ee4f ee53 ee56 ee58 ee5c ee5e ee6a
ee6c ee6e ee6f ee74 ee78 ee7a ee86 ee88
ee8c ee8e ee92 ee96 ee99 ee9a ee9c ee9f
eea2 eea3 eea8 eeac eeb0 eeb4 eeb8 eebc
eec0 eec4 eec8 eecc eed0 eed4 eed8 eedc
eee8 eeec eef1 eef5 eef8 eef9 eefe ef02
ef06 ef09 ef0c ef10 ef12 ef16 ef1a ef1d
ef20 ef24 ef26 ef2a ef2e ef31 ef33 ef37
ef3b ef3f ef42 ef46 ef4a ef4c ef4d ef52
1 ef56 ef5a ef5e ef61 ef65 ef69 ef6d
ef71 ef74 ef78 ef7c ef7f ef82 ef87 ef8a
ef8d ef90 ef91 ef96 ef97 1 ef99 ef9e
efa2 efa6 efa9 efae efb3 efb6 efba efbb
efc0 efc3 efc8 efc9 efce efd1 efd6 efd7
efdc efdf efe3 efe4 efe9 efec eff1 eff2
eff7 effa effe f002 f005 f008 f009 f00b
f00c f011 f012 f017 f019 f01d f020 f022
f026 f028 f034 f036 f038 f039 f03e f042
f044 f050 f052 f056 f05a f05e f061 f062
f064 f068 f06c f06e f072 f076 f07a f07d
f07e f080 f083 f086 f087 f08c f090 f094
f098 f09c f0a0 f0a4 f0a8 f0ac f0b0 f0b4
f0b8 f0bc f0c0 f0cc f0d0 f0d5 f0d9 f0dc
f0dd f0e2 f0e6 f0ea f0ed f0f0 f0f4 f0f6
f0fa f0fe f101 f104 f108 f10a f10e f112
f115 f117 f11b f11f f123 f126 f12a f12e
f130 f131 f136 1 f13a f13e f142 f145
f149 f14d f151 f155 f158 f15c f160 f163
f166 f16b f16e f171 f174 f175 f17a f17b
1 f17d f182 f186 f18a f18d f192 f197
f19a f19e f19f f1a4 f1a7 f1ac f1ad f1b2
f1b5 f1ba f1bb f1c0 f1c3 f1c7 f1c8 f1cd
f1d0 f1d5 f1d6 f1db f1de f1e2 f1e6 f1e9
f1ec f1ed f1ef f1f0 f1f5 f1f6 f1fb f1fd
f201 f204 f206 f20a f20c f218 f21a f21c
f21d f222 f226 f228 f234 f236 f23a f23e
f242 f245 f246 f248 f24c f24e f252 f256
f25a f25e f262 f266 f26a f26e f272 f276
f282 f286 f28b f28f f292 f293 f298 f29c
f2a0 f2a3 f2a6 f2aa f2ac f2b0 f2b4 f2b7
f2ba f2be f2c0 f2c4 f2c8 f2cb f2cd f2d1
f2d5 f2d9 f2dc f2e0 f2e4 f2e6 f2e7 f2ec
1 f2f0 f2f4 f2f8 f2fb f2ff f303 f307
f30b f30e f312 f316 f319 f31c f321 f324
f327 f32a f32b f330 f331 1 f333 f338
f33c f340 f343 f348 f34d f350 f354 f355
f35a f35d f362 f363 f368 f36b f370 f371
f376 f379 f37d f37e f383 f386 f38b f38c
f391 f394 f398 f39c f39f f3a2 f3a3 f3a5
f3a6 f3ab f3ac f3b1 f3b3 f3b7 f3ba f3bc
f3c0 f3c2 f3ce f3d0 f3d2 f3d3 f3d8 f3dc
f3de f3ea f3ec f3f0 f3f4 f3f8 f3fb f3fc
f3fe f402 f406 f40a f40e f411 f412 f414
f418 f41a f41e f422 f425 f427 f42b f42e
f430 f434 f438 f43b f43f f443 f446 f44a
f44e f452 f456 f457 f459 f45d f465 f467
f468 f46b f46d f471 f478 f47c f480 f485
f487 f48b f48f f492 f496 f49a f49c f4a0
f4a4 f4a8 f4ab f4af f4b3 f4b5 f4b6 f4bb
1 f4bf f4c3 f4c7 f4ca f4ce f4d2 f4d6
f4da f4dd f4e1 f4e5 f4e8 f4eb f4f0 f4f3
f4f6 f4f9 f4fa f4ff f500 1 f502 f507
f50b f50f f512 f517 f51c f51f f523 f524
f529 f52c f531 f532 f537 f53a f53f f540
f545 f548 f54c f54d f552 f555 f55a f55b
f560 f563 f567 f56b f56e f571 f572 f574
f575 f57a f57b f580 f582 f586 f589 f58b
f58f f591 f59d f59f f5a1 f5a2 f5a7 f5ab
f5ad f5b9 f5bb f5bf f5c2 f5c6 f5ca f5ce
f5d1 f5d2 f5d4 f5d7 f5da f5db f5e0 f5e4
f5e8 f5ec f5f0 f5f4 f5f7 f5f8 f5fa f5fe
f601 f605 f608 f609 f60b f60c f611 f615
f619 f61d f620 f621 f623 f626 f62a f62e
f631 f632 f634 f635 f63a f63e f642 f646
f649 f64a f64c f64f f652 f653 f658 f65b
f65f f663 f666 f667 f669 f66c f66f f670
f675 1 f678 f67d f681 f684 f685 f68a
f68d 1 f690 f695 f699 f69d f6a1 f6a5
f6a9 f6ad f6b1 f6b5 f6b9 f6bd f6c1 f6c5
f6c9 f6cd f6d1 f6d5 f6d9 f6dd f6e1 f6e5
f6e9 f6ed f6f1 f6f5 f6f9 f6fd f700 f701
f703 f706 f709 f70a f70f f712 f716 f71a
f71d f71e f720 f723 f726 f727 f72c 1
f72f f734 f738 f73b f73f f743 f745 f749
f74d f750 f751 f753 f756 f759 f75a f75f
f763 f767 f76b f76e f76f f771 f775 f777
f77b f77f f782 f786 f78a f78e f792 f796
f79a f79d f79e f7a0 f7a4 f7a8 f7ab f7ac
f7ae f7b2 f7b6 f7b9 f7ba f7bc f7c0 f7c4
f7c7 f7c8 f7ca f7ce f7d2 f7d5 f7d6 f7d8
f7dc f7e0 f7e3 f7e4 f7e6 f7ea f7ee f7f1
f7f2 f7f4 f7f8 f7fc f7ff f800 f802 f806
f80a f80e f80f f811 f815 f819 f81d f820
f821 f823 f827 f82a f82e f831 f832 f837
f83b f83f f842 f846 f84a f84d f850 f855
f858 f85b f85e f85f f864 f865 1 f867
f86c f870 f874 f877 f87c f881 f884 f888
f889 f88e f891 f896 f897 f89c f89f f8a4
f8a5 f8aa f8ad f8b1 f8b5 f8b9 f8bd f8c0
f8c1 f8c3 f8c8 f8c9 f8cb f8cc f8d1 f8d2
f8d7 f8d9 f8dd f8e0 f8e4 f8e8 f8eb f8ef
f8f3 f8f6 f8f9 f8fe f901 f904 f907 f908
f90d f90e 1 f910 f915 f919 f91d f920
f925 f92a f92d f931 f932 f937 f938 f93d
f93f f943 f946 f94a f94e f951 f955 f959
f95c f960 f961 f966 f96a f96c f970 f974
f977 f978 f97a f97d f980 f981 f986 f98a
f98e f991 f995 f999 f99c f99f f9a4 f9a7
f9aa f9ad f9ae f9b3 f9b4 1 f9b6 f9bb
f9bf f9c3 f9c6 f9cb f9d0 f9d3 f9d7 f9d8
f9dd f9e0 f9e5 f9e6 f9eb f9ee f9f3 f9f4
f9f9 f9fc fa00 fa04 fa08 fa09 fa0b fa10
fa11 fa13 fa14 fa19 fa1c fa21 fa22 fa27
fa2a fa2f fa30 fa35 fa38 fa3c fa3d fa42
fa45 fa4a fa4b fa50 fa51 fa56 fa58 fa5c
fa5f fa63 fa67 fa6a fa6e fa72 fa75 fa78
fa7d fa80 fa83 fa86 fa87 fa8c fa8d 1
fa8f fa94 fa98 fa9c fa9f faa4 faa9 faac
fab0 fab1 fab6 fab7 fabc fabe fac2 fac5
fac9 facd fad0 fad4 fad8 fadb fadc fade
fae2 fae6 fae7 faec faee faf2 faf6 faf9
fafd fb01 fb06 fb0b fb0f fb13 fb17 fb1a
fb1d fb21 fb25 fb29 fb2d fb31 fb35 fb39
fb3d fb41 fb45 fb49 fb55 fb59 fb5e fb62
fb65 fb66 fb6b fb6f fb73 fb76 fb79 fb7d
fb7f fb83 fb87 fb8a fb8d fb91 fb93 fb97
fb9b fb9e fba0 fba4 fba8 fbac fbaf fbb3
fbb7 fbb9 fbba fbbf 1 fbc3 fbc7 fbcb
fbce fbd2 fbd6 fbda fbde fbe1 fbe5 fbe9
fbec fbef fbf4 fbf7 fbfa fbfd fbfe fc03
fc04 1 fc06 fc0b fc0f fc13 fc16 fc1b
fc20 fc23 fc27 fc28 fc2d fc30 fc35 fc36
fc3b fc3e fc43 fc44 fc49 fc4c fc50 fc51
fc56 fc59 fc5e fc5f fc64 fc67 fc6b fc6f
fc72 fc75 fc76 fc78 fc79 fc7e fc7f fc84
fc86 fc8a fc8d fc8f fc93 fc95 fca1 fca3
fca5 fca6 fcab fcaf fcb1 fcbd fcbf fcc3
fcc8 fccc fcd0 fcd3 fcd7 fcdb fcde fce2
fce6 fce9 fced fcf1 fcf4 fcf8 fcfc fd00
fd03 fd04 fd06 fd09 fd0c fd0d fd12 fd16
fd1a fd1e fd21 fd25 fd29 fd2c fd2d fd2f
fd33 fd37 fd3a fd3b fd3d fd41 fd45 fd48
fd4c fd4e fd52 fd55 fd59 fd5b fd5f fd63
fd66 fd6a fd6d fd71 fd75 fd79 fd7d fd81
fd85 fd89 fd8d fd91 fd95 fd99 fd9d fda1
fda5 fda9 fdad fdb1 fdb5 fdb9 fdbd fdc1
fdc5 fdc9 fdcd fdd1 fdd5 fdd9 fddd fde1
fde5 fde9 fdec fdef fdf2 fdf5 fdf8 fdf9
fdfb fdff fe03 fe06 fe09 fe0a fe0f fe13
fe17 fe1a fe1e fe22 fe25 fe28 fe2d fe30
fe33 fe36 fe37 fe3c fe3d 1 fe3f fe44
fe48 fe4c fe4f fe54 fe59 fe5c fe60 fe61
fe66 fe69 fe6e fe6f fe74 fe77 fe7c fe7d
fe82 fe85 fe89 fe8d fe91 fe95 fe98 fe99
fe9b fea0 fea1 fea3 fea4 fea9 feac feb1
feb2 feb7 feba febf fec0 fec5 fec8 fecc
fecd fed2 fed5 feda fedb fee0 fee1 fee6
fee8 feec feef fef3 fef7 fefa fefe ff02
ff05 ff08 ff0d ff10 ff13 ff16 ff17 ff1c
ff1d 1 ff1f ff24 ff28 ff2c ff2f ff34
ff39 ff3c ff40 ff41 ff46 ff47 ff4c ff4e
ff52 ff55 ff59 ff5d ff60 ff64 ff68 ff6b
ff6f ff73 ff74 ff79 ff7d ff7f ff83 ff86
ff89 ff8a ff8f ff93 ff97 ff9a ff9e ffa2
ffa5 ffa8 ffad ffb0 ffb3 ffb6 ffb7 ffbc
ffbd 1 ffbf ffc4 ffc8 ffcc ffcf ffd4
ffd9 ffdc ffe0 ffe1 ffe6 ffe9 ffee ffef
fff4 fff7 fffc fffd 10002 10005 10009 1000d
10011 10015 10018 10019 1001b 10020 10021 10023
10024 10029 1002c 10031 10032 10037 1003a 1003f
10040 10045 10048 1004c 1004d 10052 10055 1005a
1005b 10060 10061 10066 10068 1006c 1006f 10073
10077 1007a 1007e 10082 10085 10088 1008d 10090
10093 10096 10097 1009c 1009d 1 1009f 100a4
100a8 100ac 100af 100b4 100b9 100bc 100c0 100c1
100c6 100c7 100cc 100ce 100d2 100d5 100d9 100dd
100e0 100e4 100e8 100eb 100ef 100f3 100f4 100f9
100fb 100ff 10103 10107 1010b 1010f 10113 10117
1011b 1011f 10123 10127 1012b 1012f 10133 10137
1013b 1013f 10143 10147 1014b 1014f 10153 10157
1015b 1015f 10163 10167 1016b 1016f 1017b 1017f
10184 10188 1018b 1018c 10191 10195 10199 1019c
1019f 101a3 101a5 101a9 101ad 101b0 101b3 101b7
101b9 101bd 101c1 101c4 101c6 101ca 101ce 101d2
101d5 101d9 101dd 101df 101e0 101e5 1 101e9
101ed 101f1 101f4 101f8 101fc 10200 10204 10207
1020b 1020f 10212 10215 1021a 1021d 10220 10223
10224 10229 1022a 1 1022c 10231 10235 10239
1023c 10241 10246 10249 1024d 1024e 10253 10256
1025b 1025c 10261 10264 10269 1026a 1026f 10272
10276 10277 1027c 1027f 10284 10285 1028a 1028d
10291 10295 10298 1029b 1029c 1029e 1029f 102a4
102a5 102aa 102ac 102b0 102b3 102b5 102b9 102bb
102c7 102c9 102cb 102cc 102d1 102d5 102d7 102e3
102e5 102e7 102eb 102ef 102f2 102f4 102f8 102fb
102ff 10301 10305 10308 1030b 1030c 10311 10315
10319 1031c 1031d 1031f 10322 10325 10326 1
1032b 10330 10334 10337 10338 1033d 1 10340
10345 10349 1034d 10351 10355 10359 1035d 10361
1036d 10371 10376 1037a 1037d 1037e 10383 10387
1038b 1038e 10391 10395 10397 1039b 1039f 103a2
103a5 103a9 103ab 103af 103b3 103b6 103b8 103bc
103c0 103c4 103c7 103cb 103cf 103d1 103d2 103d7
1 103db 103df 103e3 103e6 103ea 103ee 103f2
103f6 103f9 103fd 10401 10404 10407 1040c 1040f
10412 10415 10416 1041b 1041c 1 1041e 10423
10427 1042b 1042e 10433 10438 1043b 1043f 10440
10445 10448 1044d 1044e 10453 10456 1045b 1045c
10461 10464 10468 10469 1046e 10471 10476 10477
1047c 1047f 10483 10487 1048a 1048d 1048e 10490
10491 10496 10497 1049c 1049e 104a2 104a5 104a7
104ab 104ad 104b9 104bb 104bd 104be 104c3 104c7
104c9 104d5 104d7 104d9 104dd 104e1 104e4 104e8
104ec 104f0 104f4 104f8 104fc 10500 10504 10510
10514 10518 1051b 1051f 10523 10525 10529 1052d
10531 10534 10538 1053c 1053e 1053f 10544 1
10548 1054c 10550 10553 10557 1055b 1055f 10563
10566 1056a 1056e 10571 10574 10579 1057c 1057f
10582 10583 10588 10589 1 1058b 10590 10594
10598 1059b 105a0 105a5 105a8 105ac 105ad 105b2
105b5 105ba 105bb 105c0 105c3 105c8 105c9 105ce
105d1 105d5 105d6 105db 105de 105e3 105e4 105e9
105ec 105f0 105f4 105f7 105fa 105fb 105fd 105fe
10603 10604 10609 1060b 1060f 10612 10614 10618
1061a 10626 10628 1062a 1062b 10630 10634 10636
10642 10644 10648 1064c 1064f 10650 10652 10655
10658 10659 1065e 10662 10666 1066a 1066e 10672
10676 1067a 1067e 10682 1068e 10692 10697 1069b
1069e 1069f 106a4 106a8 106ac 106af 106b2 106b6
106b8 106bc 106c0 106c3 106c6 106ca 106cc 106d0
106d4 106d7 106d9 106dd 106e1 106e5 106e8 106ec
106f0 106f2 106f3 106f8 1 106fc 10700 10704
10707 1070b 1070f 10713 10717 1071a 1071e 10722
10725 10728 1072d 10730 10733 10736 10737 1073c
1073d 1 1073f 10744 10748 1074c 1074f 10754
10759 1075c 10760 10761 10766 10769 1076e 1076f
10774 10777 1077c 1077d 10782 10785 10789 1078a
1078f 10792 10797 10798 1079d 107a0 107a4 107a8
107ab 107ae 107af 107b1 107b2 107b7 107b8 107bd
107bf 107c3 107c6 107c8 107cc 107ce 107da 107dc
107de 107df 107e4 107e8 107ea 107f6 107f8 107fa
107fe 10801 10803 10807 1080a 1080e 10811 10815
10819 1081c 1081d 10822 10825 10829 1082d 10831
10835 10839 1083d 10841 10845 10849 10855 10859
1085e 10862 10865 10866 1086b 1086f 10873 10876
10879 1087d 1087f 10883 10887 1088a 1088d 10891
10893 10897 1089b 1089e 108a0 108a4 108a8 108ac
108af 108b3 108b7 108b9 108ba 108bf 1 108c3
108c7 108cb 108ce 108d2 108d6 108da 108de 108e1
108e5 108e9 108ec 108ef 108f4 108f7 108fa 108fd
108fe 10903 10904 1 10906 1090b 1090f 10913
10916 1091b 10920 10923 10927 10928 1092d 10930
10935 10936 1093b 1093e 10943 10944 10949 1094c
10950 10951 10956 10959 1095e 1095f 10964 10967
1096b 1096f 10972 10975 10976 10978 10979 1097e
1097f 10984 10986 1098a 1098d 1098f 10993 10995
109a1 109a3 109a5 109a6 109ab 109af 109b1 109bd
109bf 109c3 109c7 109ca 109cb 109cd 109d0 109d3
109d4 109d9 109dd 109e1 109e5 109e9 109ed 109f1
109f5 10a01 10a05 10a09 10a0c 10a10 10a14 10a16
10a1a 10a1e 10a22 10a25 10a29 10a2d 10a2f 10a30
10a35 1 10a39 10a3d 10a41 10a44 10a48 10a4c
10a50 10a54 10a57 10a5b 10a5f 10a62 10a65 10a6a
10a6d 10a70 10a73 10a74 10a79 10a7a 1 10a7c
10a81 10a85 10a89 10a8c 10a91 10a96 10a99 10a9d
10a9e 10aa3 10aa6 10aab 10aac 10ab1 10ab4 10ab9
10aba 10abf 10ac2 10ac6 10ac7 10acc 10acf 10ad4
10ad5 10ada 10add 10ae1 10ae5 10ae8 10aeb 10aec
10aee 10aef 10af4 10af5 10afa 10afc 10b00 10b03
10b05 10b09 10b0b 10b17 10b19 10b1b 10b1c 10b21
10b25 10b27 10b33 10b35 10b39 10b3d 10b40 10b41
10b43 10b46 10b49 10b4a 10b4f 10b53 10b57 10b5b
10b5f 10b63 10b67 10b6b 10b6f 10b7b 10b7f 10b84
10b88 10b8b 10b8c 10b91 10b95 10b99 10b9c 10b9f
10ba3 10ba5 10ba9 10bad 10bb0 10bb3 10bb7 10bb9
10bbd 10bc1 10bc4 10bc6 10bca 10bce 10bd2 10bd5
10bd9 10bdd 10bdf 10be0 10be5 1 10be9 10bed
10bf1 10bf4 10bf8 10bfc 10c00 10c04 10c07 10c0b
10c0f 10c12 10c15 10c1a 10c1d 10c20 10c23 10c24
10c29 10c2a 1 10c2c 10c31 10c35 10c39 10c3c
10c41 10c46 10c49 10c4d 10c4e 10c53 10c56 10c5b
10c5c 10c61 10c64 10c69 10c6a 10c6f 10c72 10c76
10c77 10c7c 10c7f 10c84 10c85 10c8a 10c8d 10c91
10c95 10c98 10c9b 10c9c 10c9e 10c9f 10ca4 10ca5
10caa 10cac 10cb0 10cb3 10cb5 10cb9 10cbb 10cc7
10cc9 10ccb 10ccc 10cd1 10cd5 10cd7 10ce3 10ce5
10ce9 10ced 10cf1 10cf5 10cf9 10d05 10d09 10d0e
10d12 10d15 10d16 10d1b 10d1f 10d23 10d26 10d29
10d2d 10d2f 10d33 10d37 10d3a 10d3d 10d41 10d43
10d47 10d4b 10d4e 10d50 10d54 10d58 10d5c 10d5f
10d63 10d67 10d69 10d6a 10d6f 1 10d73 10d77
10d7b 10d7e 10d82 10d86 10d8a 10d8e 10d91 10d95
10d99 10d9c 10d9f 10da4 10da7 10daa 10dad 10dae
10db3 10db4 1 10db6 10dbb 10dbf 10dc3 10dc6
10dcb 10dd0 10dd3 10dd7 10dd8 10ddd 10de0 10de5
10de6 10deb 10dee 10df3 10df4 10df9 10dfc 10e00
10e01 10e06 10e09 10e0e 10e0f 10e14 10e17 10e1b
10e1f 10e22 10e25 10e26 10e28 10e29 10e2e 10e2f
10e34 10e36 10e3a 10e3d 10e3f 10e43 10e45 10e51
10e53 10e55 10e56 10e5b 10e5f 10e61 10e6d 10e6f
10e71 10e75 10e78 10e7a 10e7e 10e81 10e85 10e89
10e8c 10e8d 10e8f 10e92 10e95 10e96 10e9b 10e9f
10ea2 10ea6 10eaa 10eae 10eb2 10eb6 10eba 10ebd
10ec0 10ec1 10ec3 10ec7 10ecb 10ecf 10ed3 10ed7
10edb 10edf 10ee3 10ee7 10eeb 10eef 10ef3 10ef7
10efb 10eff 10f03 10f07 10f0b 10f0f 10f13 10f17
10f1b 10f1f 10f23 10f27 10f2b 10f37 10f3b 10f3f
10f42 10f46 10f4a 10f4c 10f50 10f54 10f58 10f5b
10f5f 10f63 10f65 10f66 10f6b 1 10f6f 10f73
10f77 10f7a 10f7e 10f82 10f86 10f8a 10f8d 10f91
10f95 10f98 10f9b 10fa0 10fa3 10fa6 10fa9 10faa
10faf 10fb0 1 10fb2 10fb7 10fbb 10fbf 10fc2
10fc7 10fcc 10fcf 10fd3 10fd4 10fd9 10fdc 10fe1
10fe2 10fe7 10fea 10fef 10ff0 10ff5 10ff8 10ffc
10ffd 11002 11005 1100a 1100b 11010 11013 11017
1101b 1101e 11021 11022 11024 11025 1102a 1102b
11030 11032 11036 11039 1103b 1103f 11041 1104d
1104f 11051 11052 11057 1105b 1105d 11069 1106b
1106f 11073 11076 1107a 1107d 11081 11084 11085
1108a 1108d 11091 11095 11098 11099 1109b 1109e
110a1 110a2 110a7 110ab 110af 110b3 110b7 110bb
110bf 110c3 110c7 110cb 110cf 110d3 110d7 110db
110df 110e3 110ef 110f3 110f8 110fc 110ff 11100
11105 11109 1110d 11110 11113 11117 11119 1111d
11121 11124 11127 1112b 1112d 11131 11135 11138
1113a 1113e 11142 11146 11149 1114d 11151 11153
11154 11159 1 1115d 11161 11165 11168 1116c
11170 11174 11178 1117b 1117f 11183 11186 11189
1118e 11191 11194 11197 11198 1119d 1119e 1
111a0 111a5 111a9 111ad 111b0 111b5 111ba 111bd
111c1 111c2 111c7 111ca 111cf 111d0 111d5 111d8
111dd 111de 111e3 111e6 111ea 111eb 111f0 111f3
111f8 111f9 111fe 11201 11205 11209 1120c 1120f
11210 11212 11213 11218 11219 1121e 11220 11224
11227 11229 1122d 1122f 1123b 1123d 1123f 11240
11245 11249 1124b 11257 11259 1125b 1125f 11263
11267 1126b 1126f 11273 11277 1127b 1127f 11283
11287 1128b 1128f 11293 11297 1129b 1129f 112ab
112af 112b4 112b8 112bb 112bc 112c1 112c5 112c9
112cc 112cf 112d3 112d5 112d9 112dd 112e0 112e3
112e7 112e9 112ed 112f1 112f4 112f6 112fa 112fe
11302 11305 11309 1130d 1130f 11310 11315 1
11319 1131d 11321 11324 11328 1132c 11330 11334
11337 1133b 1133f 11342 11345 1134a 1134d 11350
11353 11354 11359 1135a 1 1135c 11361 11365
11369 1136c 11371 11376 11379 1137d 1137e 11383
11386 1138b 1138c 11391 11394 11399 1139a 1139f
113a2 113a6 113a7 113ac 113af 113b4 113b5 113ba
113bd 113c1 113c5 113c8 113cb 113cc 113ce 113cf
113d4 113d5 113da 113dc 113e0 113e3 113e5 113e9
113eb 113f7 113f9 113fb 113fc 11401 11405 11407
11413 11415 11417 1141b 1141f 11422 11426 1142a
1142d 11430 11431 11433 11436 1143b 1143c 11441
11444 11448 1144b 1144f 11453 11457 1145a 1145e
11462 11466 1146a 1146e 11472 11476 1147a 1147e
11482 11486 11487 11489 1148d 1148f 11493 11496
11498 1149c 1149f 114a3 114a6 114a7 114ac 114af
114b2 114b6 114ba 114bd 114c1 114c5 114c6 114c8
114cb 114ce 114cf 114d4 1 114d7 114dc 114e0
114e3 114e7 114e9 114ed 114f0 114f2 114f6 114f9
114fb 114ff 11502 11506 11509 1150a 1150f 11512
11516 11519 1151d 11521 11525 11529 1152d 11531
11534 11537 11538 1153a 1153e 11542 11546 1154a
1154e 11552 11556 1155a 1155e 11562 11566 1156a
1156e 11572 11576 1157a 1157e 11582 11586 1158a
1158e 11592 11596 1159a 1159e 115a2 115ae 115b2
115b6 115b9 115bd 115c1 115c3 115c7 115cb 115cf
115d2 115d6 115da 115dc 115dd 115e2 1 115e6
115ea 115ee 115f1 115f5 115f9 115fd 11601 11604
11608 1160c 1160f 11612 11617 1161a 1161d 11620
11621 11626 11627 1 11629 1162e 11632 11636
11639 1163e 11643 11646 1164a 1164b 11650 11653
11658 11659 1165e 11661 11666 11667 1166c 1166f
11673 11674 11679 1167c 11681 11682 11687 1168a
1168e 11692 11695 11698 11699 1169b 1169c 116a1
116a2 116a7 116a9 116ad 116b0 116b2 116b6 116b8
116c4 116c6 116c8 116c9 116ce 116d2 116d4 116e0
116e2 116e6 116ea 116ed 116ee 116f0 116f3 116f6
116f7 116fc 11700 11704 11708 1170c 11710 11714
11718 1171c 11720 11724 11728 1172c 11730 11734
11738 11744 11748 1174d 11751 11754 11755 1175a
1175e 11762 11765 11768 1176c 1176e 11772 11776
11779 1177c 11780 11782 11786 1178a 1178d 1178f
11793 11797 1179b 1179e 117a2 117a6 117a8 117a9
117ae 1 117b2 117b6 117ba 117bd 117c1 117c5
117c9 117cd 117d0 117d4 117d8 117db 117de 117e3
117e6 117e9 117ec 117ed 117f2 117f3 1 117f5
117fa 117fe 11802 11805 1180a 1180f 11812 11816
11817 1181c 1181f 11824 11825 1182a 1182d 11832
11833 11838 1183b 1183f 11840 11845 11848 1184d
1184e 11853 11856 1185a 1185e 11861 11864 11865
11867 11868 1186d 1186e 11873 11875 11879 1187c
1187e 11882 11884 11890 11892 11894 11895 1189a
1189e 118a0 118ac 118ae 118b0 118b4 118b8 118bc
118c0 118c4 118c8 118cc 118d0 118d4 118d8 118dc
118e0 118e4 118e8 118ec 118f0 118f4 11900 11904
11909 1190d 11910 11911 11916 1191a 1191e 11921
11924 11928 1192a 1192e 11932 11935 11938 1193c
1193e 11942 11946 11949 1194b 1194f 11953 11957
1195a 1195e 11962 11964 11965 1196a 1 1196e
11972 11976 11979 1197d 11981 11985 11989 1198c
11990 11994 11997 1199a 1199f 119a2 119a5 119a8
119a9 119ae 119af 1 119b1 119b6 119ba 119be
119c1 119c6 119cb 119ce 119d2 119d3 119d8 119db
119e0 119e1 119e6 119e9 119ee 119ef 119f4 119f7
119fb 119fc 11a01 11a04 11a09 11a0a 11a0f 11a12
11a16 11a1a 11a1d 11a20 11a21 11a23 11a24 11a29
11a2a 11a2f 11a31 11a35 11a38 11a3a 11a3e 11a40
11a4c 11a4e 11a50 11a51 11a56 11a5a 11a5c 11a68
11a6a 11a6c 11a70 11a74 11a77 11a7b 11a7f 11a82
11a85 11a86 11a88 11a8b 11a90 11a91 11a96 11a99
11a9d 11aa1 11aa4 11aa5 11aa7 11aaa 11aad 11aae
11ab3 1 11ab6 11abb 11abf 11ac2 11ac6 11aca
11ace 11ad1 11ad5 11ad9 11add 11ae1 11ae5 11ae9
11aed 11af1 11af5 11af9 11afd 11afe 11b00 11b04
11b06 11b0a 11b0d 11b0f 11b13 11b16 11b1a 11b1e
11b22 11b23 11b25 11b29 11b2d 11b31 11b34 11b37
11b3a 11b3b 11b40 11b44 11b48 11b4b 11b4e 11b52
11b54 11b58 11b5b 11b5f 11b63 11b66 11b6a 11b6e
11b71 11b74 11b79 11b7c 11b7f 11b82 11b83 11b88
11b89 1 11b8b 11b90 11b94 11b98 11b9b 11ba0
11ba5 11ba8 11bac 11bad 11bb2 11bb5 11bba 11bbb
11bc0 11bc3 11bc8 11bc9 11bce 11bd1 11bd5 11bd9
11bdd 11be1 11be4 11be5 11be7 11bec 11bed 11bef
11bf0 11bf5 11bf8 11bfd 11bfe 11c03 11c06 11c0b
11c0c 11c11 11c14 11c18 11c19 11c1e 11c21 11c26
11c27 11c2c 11c2d 11c32 11c34 11c38 11c3b 11c3f
11c43 11c46 11c4a 11c4e 11c51 11c55 11c59 11c5a
11c5f 11c61 11c65 11c69 11c6c 11c70 11c74 11c77
11c7b 11c7f 11c82 11c85 11c8a 11c8d 11c90 11c93
11c94 11c99 11c9a 1 11c9c 11ca1 11ca5 11ca9
11cac 11cb1 11cb6 11cb9 11cbd 11cbe 11cc3 11cc4
11cc9 11ccd 11cd1 11cd4 11cd9 11cde 11ce1 11ce5
11ce9 11cec 11ced 11cf2 11cf5 11cfa 11cfb 11d00
11d03 11d07 11d0b 11d0e 11d0f 11d14 11d15 11d1a
11d1c 11d20 11d23 11d27 11d2b 11d2f 11d33 11d37
11d3b 11d3f 11d43 11d47 11d53 11d58 11d5c 11d60
11d64 11d68 11d6a 11d6b 11d70 1 11d74 11d78
11d7c 11d7f 11d83 11d87 11d8b 11d8f 11d92 11d96
11d9a 11d9d 11da0 11da5 11da8 11dab 11dae 11daf
11db4 11db5 1 11db7 11dbc 11dc0 11dc4 11dc7
11dcc 11dd1 11dd4 11dd8 11dd9 11dde 11ddf 11de4
11de8 11dec 11def 11df4 11df9 11dfc 11e00 11e01
11e06 11e09 11e0e 11e0f 11e14 11e17 11e1b 11e1f
11e22 11e25 11e26 11e28 11e29 11e2e 11e2f 11e34
11e36 11e3a 11e3d 11e41 11e45 11e49 11e4d 11e51
11e55 11e59 11e65 11e6a 11e6e 11e72 11e76 11e7a
11e7c 11e80 11e82 11e8e 11e90 11e92 11e93 11e98
11e9c 11e9e 11eaa 11eae 11eb0 11eb1 11eba 
5217
2
0 1 a 6 d :3 6 14 :3 6
10 :3 6 14 :3 6 15 :3 6 10 :3 6
e :3 6 11 :3 6 c :3 6 b :3 6
11 :3 6 11 :3 6 1d :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 c 10 f c 20 :2 29 c
:2 4 9 12 11 :2 9 :2 4 12 1b
1a :2 12 :2 4 f 18 17 :2 f :2 4
10 19 18 :2 10 :2 4 14 1d 1c
:2 14 :2 4 18 21 20 :2 18 :2 4 18
21 20 :2 18 :2 4 18 21 20 :2 18
:2 4 18 21 20 :2 18 :2 4 e 17
16 :2 e :2 4 d 16 15 :2 d :2 4
11 1a 19 :2 11 :2 4 11 1a 19
:2 11 :2 4 :3 11 :2 4 :3 12 :2 4 :3 14 :2 4
:3 15 :2 4 f 18 17 :2 f :2 4 f
18 17 :2 f :2 4 :3 10 :2 4 :3 e :2 4
:3 f :2 4 f 18 17 :2 f :2 4 b
14 13 :2 b :2 4 :3 f :2 4 :3 10 :2 4
:3 12 :2 4 :3 13 :2 4 e 17 16 :2 e
:2 4 10 19 18 :2 10 :2 4 9 12
11 :2 9 :2 4 13 1c 1b :2 13 :2 4
11 1a 19 :2 11 :2 4 :2 14 23 14
:2 4 :2 12 21 12 :2 4 :2 c 1b c
:2 4 :2 d 1c d :2 4 :2 a 19 a
:2 4 :2 b 1a b :2 4 :2 e 1d e
:2 4 :2 c 1b c :2 4 :2 b 1a b
:2 4 :2 11 20 11 :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 10 1f 10
:2 4 :2 d 1c d :2 4 :2 f 1e f
:2 4 :2 10 1f 10 :2 4 :2 e 1d e
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 f 1e f
:2 4 :2 f 1e f :2 4 :2 b 1a b
:2 4 :2 c 1b c :2 4 :2 c 1b c
:2 4 :2 10 1f 10 :2 4 :2 16 25 16
:2 4 :2 f 19 f :2 4 :2 f 19 f
:2 4 :2 10 1a 10 :2 4 :2 10 1a 10
:2 4 :2 13 1d 13 :2 4 :2 12 21 12
:2 4 :2 19 28 19 :2 4 :2 19 28 19
:2 4 :2 19 28 19 :2 4 :2 f 1e f
:2 4 :2 11 20 11 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 :2 10 1f 10
:2 4 10 19 18 :2 10 :2 4 11 1a
19 :2 11 :2 4 :2 14 1e 14 :2 4 :2 f
1e f :2 4 14 1d 1c :2 14 :2 4
:2 17 26 17 :2 4 17 20 1f :2 17
:2 4 13 1c 1b :2 13 :2 4 :2 13 22
13 :2 4 :2 14 23 14 :2 4 :3 9 :2 4
:3 9 :2 4 :2 f 19 f :2 4 :2 f 19
f :2 4 :2 f 1e f :2 4 :2 f 1e
f :2 4 :2 f 1e f :2 4 :2 16 25
16 :2 4 :2 11 20 11 :2 4 :2 11 20
11 :2 4 :2 15 24 15 :2 4 :2 10 1f
10 :2 4 :2 14 23 14 :2 4 14 1d
1c :2 14 :2 4 14 1d 1c :2 14 :2 4
18 21 20 :2 18 :2 4 :2 d 25 d
:2 4 :2 d 26 30 39 44 :2 30 :2 26
25 d :2 4 :2 10 28 10 :2 4 :2 b
23 b :2 4 :3 10 :2 4 :3 e 4 7
e 0 :2 7 11 24 11 22 2f
a :6 7 e 0 :2 7 11 1f 11
22 2f 40 4e 5b :2 a :6 7 e
0 :2 7 11 13 26 28 3b 3d
46 48 56 58 66 68 a c
1b 23 2a 2c 44 4c 53 55
6e 70 85 87 a1 a3 b9 bb
a c 23 25 2f 31 42 44
52 54 a c 16 18 20 22
2a 2c 37 39 f 17 1a 2f
32 43 10 12 1f 30 32 40
51 53 e 10 24 26 3c 3e
4b 4d e 10 21 2a 32 3b
49 52 60 69 77 80 8d 96
a7 b0 c3 cc e1 ea 105 10e
126 12f 140 149 15b 164 17c 185
198 1a1 1c2 1c4 1ce 13 15 a
:5 7 4 e 17 :3 e 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 56 5c 5f :2 56 6d
85 8 :2 6d d 10 :2 6d 17 1a
:2 6d b e :2 6d 13 16 :2 6d 1b
1e :2 6d 2c 2f :2 6d b e :2 6d
13 16 :2 6d 1b 1e :2 6d 28 2b
:2 6d b e :2 6d 13 16 :2 6d 1b
1e :2 6d 2c 2f :2 6d b e :2 6d
13 16 :2 6d 1b 1e :2 6d 2d 30
:2 6d b e :2 6d 13 16 1f 27
:2 1f 33 :2 16 :2 6d b e :2 6d 13
16 1f 27 :2 1f 31 :2 16 :2 6d b
e :2 6d 13 16 1f 27 :2 1f 34
:2 16 :2 6d b e :2 6d 13 16 1f
27 :2 1f 2f :2 16 :2 6d b e :2 6d
13 16 1f 27 :2 1f 2e :2 16 :2 6d
b e :2 6d 13 16 1f 27 :2 1f
34 :2 16 :2 6d b e :2 6d 13 16
1f 27 :2 1f 34 :2 16 :2 6d b e
:2 6d 13 16 1f 27 :2 1f 40 :2 16
:2 6d b e :2 6d 13 16 1f 27
:2 1f 33 :2 16 :2 6d b e :2 6d 13
16 :2 6d 1b 1e :2 6d 2a 2d :2 6d
32 35 :2 6d :2 7 4c :2 4 7 :2 11
23 :2 2d 39 3c 4e 51 52 :2 4e
:2 23 :3 7 :2 d 12 1e 5f 62 :2 1e
:2 7 55 :3 4 11 :2 4 14 :2 4 10
:2 4 12 :2 4 12 :2 4 12 :2 4 12
19 22 2e :2 19 32 :2 3b :2 12 4
8 11 1d :2 8 22 20 :2 2b :2 20
7 40 e 1a :2 40 1f 1d :2 28
:2 1d 3f :3 7 15 7 3e :3 4 13
:2 4 14 :2 4 12 :2 4 14 :2 4 15
:2 4 15 :2 4 16 :2 4 9 :3 4 a
16 :2 4 7 e :2 7 :2 10 1c 7
14 7 :2 10 1c 7 :5 4 f :2 18
4 7 d :3 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 55 58 59 :2 55 :2 29 :3 d
:2 13 18 24 65 68 :2 24 75 78
:2 24 7c 7f :2 24 8b 8e :2 24 96
99 :2 24 a5 a8 af b8 bb :2 a8
:2 24 :2 d 5c :2 a :2 7 :4 13 :2 7 4
:3 1 7 10 19 :2 7 1c 1e :2 1c
a :2 14 26 :2 30 3c 40 52 55
56 :2 52 :2 26 :3 a :2 10 15 21 62
65 :2 21 72 75 :2 21 79 7c :2 21
86 89 92 9a :2 a3 :2 92 b6 :2 89
:2 21 be c1 :2 21 c9 cc :2 21 d1
d4 :2 21 dd e0 :2 21 :2 a 59 :2 7
a :2 14 26 :2 30 3c 3f 51 54
55 :2 51 :2 26 :3 a :2 10 15 21 62
65 :2 21 :2 a 58 :3 7 :2 12 26 :2 2f
41 4b :2 7 22 :2 4 e 17 1d
29 38 47 c 17 1f 2d 3e
4f c 1a 27 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 55 58 59 :2 55 :2 29
:3 d :2 13 18 24 65 68 :2 24 75
78 :2 24 7c 7f :2 24 8b 8e :2 24
96 99 :2 24 a5 a8 af b8 bb
:2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 a :2 14 26 :2 30 3c 40 52
55 56 :2 52 :2 26 :3 a :2 10 15 21
62 65 :2 21 72 75 :2 21 79 7c
:2 21 86 89 92 9a :2 a3 :2 92 b6
:2 89 :2 21 be c1 :2 21 c9 cc :2 21
d1 d4 :2 21 de e1 :2 21 :2 a 59
:2 7 a :2 14 26 :2 30 3c 3f 51
54 55 :2 51 :2 26 :3 a :2 10 15 21
62 65 :2 21 :2 a 58 :3 7 :2 12 26
:2 2f 41 4c :2 7 35 :3 4 12 4
e 1e c d 1a :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 7 10 1c :2 7 1f
21 :2 1f a :2 14 26 :2 30 3c 40
52 55 56 :2 52 :2 26 :3 a :2 10 15
21 62 65 :2 21 72 75 :2 21 79
7c :2 21 86 89 92 9a :2 a3 :2 92
b9 :2 89 :2 21 c1 c4 :2 21 cc cf
:2 21 d4 d7 :2 21 e4 e7 :2 21 :2 a
59 :2 7 a :2 14 26 :2 30 3c 3f
51 54 55 :2 51 :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 58 :3 7 :2 12
26 :2 2f 44 52 :2 7 23 :2 4 e
11 24 27 4a 53 56 6c 75
78 90 93 9d a0 ad b8 c2
c5 c 14 22 2d 39 45 54
c 14 17 1c 2b 31 34 42
45 56 59 66 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 55 58 59 :2 55 :2 29
:3 d :2 13 18 24 65 68 :2 24 75
78 :2 24 7c 7f :2 24 8b 8e :2 24
96 99 :2 24 a5 a8 af b8 bb
:2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 a :2 14 26 :2 30 3c 40 52
55 56 :2 52 :2 26 :3 a :2 10 15 21
62 65 :2 21 72 75 :2 21 79 7c
:2 21 86 89 92 9a :2 a3 :2 92 b6
:2 89 :2 21 be c1 :2 21 c9 cc :2 21
d1 d4 :2 21 de e1 :2 21 :2 a 59
:2 7 a :2 14 26 :2 30 3c 3f 51
54 55 :2 51 :2 26 :3 a :2 10 15 21
62 65 :2 21 :2 a 58 :3 7 :2 12 26
:2 2f 41 4c :2 7 35 :2 4 e 18
2b 37 49 59 67 :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 8 :2 11 1c 1a :2 25
:2 1a 7 a :2 14 26 :2 30 3c 40
52 55 56 :2 52 :2 26 :3 a :2 10 15
21 62 65 :2 21 72 75 :2 21 79
7c :2 21 86 89 92 9a :2 a3 :2 92
b6 :2 89 :2 21 be c1 :2 21 c9 cc
:2 21 d1 d4 :2 21 dd e0 :2 21 :2 a
59 :2 7 a :2 14 26 :2 30 3c 3f
51 54 55 :2 51 :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 58 :3 7 :2 12
26 :2 2f 41 4b :2 7 35 :2 4 e
1b 2a 39 46 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 55 58 59 :2 55 :2 29
:3 d :2 13 18 24 65 68 :2 24 75
78 :2 24 7c 7f :2 24 8b 8e :2 24
96 99 :2 24 a5 a8 af b8 bb
:2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 7 :2 12 19 24 :2 7 34
36 :2 34 7 14 7 38 :2 4 8
:2 11 1c 1a :2 25 :2 1a 7 a :2 14
26 :2 30 3c 40 52 55 56 :2 52
:2 26 :3 a :2 10 15 21 62 65 :2 21
72 75 :2 21 79 7c :2 21 86 89
92 9a :2 a3 :2 92 b6 :2 89 :2 21 be
c1 :2 21 c9 cc :2 21 d1 d4 :2 21
e1 e4 :2 21 :2 a 59 :2 7 a :2 14
26 :2 30 3c 3f 51 54 55 :2 51
:2 26 :3 a :2 10 15 21 62 65 :2 21
:2 a 58 :3 7 :2 12 26 :2 2f 41 4f
:2 7 35 :3 4 1c :2 4 1c 23 2c
42 :2 23 46 :2 1c :2 4 12 19 22
38 :2 19 3c :2 12 :2 4 1c 23 2c
42 :2 23 46 :2 1c 4 e 14 2c
c d 1a 2b 39 45 53 64
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 55
58 59 :2 55 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 8b 8e :2 24 96 99 :2 24 a5
a8 af b8 bb :2 a8 :2 24 :2 d 5c
:2 a :2 7 :4 13 :2 7 4 :3 1 e 14
2c c d 1a 2b 35 46 54
65 :2 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
55 58 59 :2 55 :2 29 :3 d :2 13 18
24 65 68 :2 24 75 78 :2 24 7c
7f :2 24 8b 8e :2 24 96 99 :2 24
a5 a8 af b8 bb :2 a8 :2 24 :2 d
5c :2 a :2 7 :4 13 :2 7 4 :3 1 7
10 13 :2 10 a 13 1f :2 a 22
24 :2 22 14 24 35 58 13 20
31 3b 4c 5a :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5b 5e 5f :2 5b :2 2f
:3 13 :2 19 1e 2a 6b 6e :2 2a 7b
7e :2 2a 82 85 :2 2a 91 94 :2 2a
9c 9f :2 2a ab ae b5 be c1
:2 ae :2 2a :2 13 62 :2 10 :2 d :4 19 :2 d
a :3 26 11 1a 27 :2 11 2a 2d
:2 2a :4 d 1b d 17 27 37 5a
16 23 34 3f 4e 5c :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 61 62
:2 5e :2 32 :3 16 :2 1c 21 2d 6e 71
:2 2d 7e 81 :2 2d 85 88 :2 2d 94
97 :2 2d 9f a2 :2 2d ae b1 b8
c1 c4 :2 b1 :2 2d :2 16 65 :2 13 :2 10
:4 1c :2 10 d :3 2f 10 19 25 :2 10
28 2b :2 28 13 :2 1d 2f :2 39 45
49 5b 5e 5f :2 5b :2 2f :3 13 :2 19
1e 2a 6b 6e :2 2a 7b 7e :2 2a
82 85 :2 2a 8f 92 9b a3 :2 ac
:2 9b cd :2 92 :2 2a d5 d8 :2 2a e0
e3 :2 2a e8 eb :2 2a f4 f7 :2 2a
:2 13 62 :2 10 13 :2 1d 2f :2 39 45
48 5a 5d 5e :2 5a :2 2f :3 13 :2 19
1e 2a 6b 6e :2 2a :2 13 61 :3 10
:2 1b 2f :2 38 58 18 :2 10 2d :2 d
2f :2 a 26 :2 7 4 15 a 18
21 2c :2 18 :2 a 30 33 :2 30 3a
43 4f :2 3a 52 54 :2 52 59 a
16 :2 59 19 1b :2 19 :2 3a 39 :2 a
7 15 7 11 21 31 54 10
1d 2e 3c 49 e :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 58 5b 5c :2 58
:2 2c :3 10 :2 16 1b 27 68 6b :2 27
78 7b :2 27 7f 82 :2 27 8e 91
:2 27 99 9c :2 27 a8 ab b2 bb
be :2 ab :2 27 :2 10 5f :2 d :2 a :4 16
:2 a 7 :3 1e a 13 1f :2 a 22
24 :2 22 d :2 17 29 :2 33 3f 43
55 58 59 :2 55 :2 29 :3 d :2 13 18
24 65 68 :2 24 75 78 :2 24 7c
7f :2 24 89 8c 95 9d :2 a6 :2 95
c7 :2 8c :2 24 cf d2 :2 24 da dd
:2 24 e2 e5 :2 24 ee f1 :2 24 :2 d
5c :2 a d :2 17 29 :2 33 3f 42
54 57 58 :2 54 :2 29 :3 d :2 13 18
24 65 68 :2 24 :2 d 5b :3 a :2 15
29 :2 32 52 12 :2 a 26 :2 7 1e
15 :3 4 12 :2 4 13 :2 4 17 :2 4
1b :2 4 1b :2 4 14 :2 4 9 :3 4
a 14 :2 4 7 c :2 7 :2 10 1c
7 12 7 :2 10 1c 7 :4 4 8
:2 11 1c 1a :2 25 :2 1a :2 7 15 7
35 7 15 7 :4 4 7 d :3 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 55 58
59 :2 55 :2 29 :3 d :2 13 18 24 65
68 :2 24 75 78 :2 24 7c 7f :2 24
8b 8e :2 24 96 99 :2 24 a5 a8
af b8 bb :2 a8 :2 24 :2 d 5c :2 a
:2 7 :4 13 :2 7 4 :3 1 7 10 1c
:2 7 1f 21 :2 1f a 13 1f :2 a
22 24 :2 22 a 18 a 26 :2 7
23 :2 4 e 21 32 43 c d
1a b 1b b 19 :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 8 :2 11 1c 1a :2 25
:2 1a 7 3d 46 52 :2 3d 55 58
:2 55 :3 39 :3 7 1a :2 7 :3 1a 7 11
1e 2f 38 f 10 1d :2 e 1c
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 58
5b 5c :2 58 :2 2c :3 10 :2 16 1b 27
69 6c :2 27 79 7c :2 27 80 83
:2 27 8f 92 :2 27 9a 9d :2 27 a9
ac b3 bc bf :2 ac :2 27 :2 10 5f
:2 d :2 a :4 16 :2 a 7 :3 5a b :2 14
1f 1d :2 28 :2 1d :2 a 20 :2 29 30
39 42 :2 30 46 :2 4f :2 20 a 38
a 1d 2b 2e 37 3f :2 2e 43
:2 4c 24 :2 1d :2 a 20 :2 29 a :5 7
1a :2 7 19 :2 7 1a 31 3f 49
51 2d 41 52 :2 1a :2 7 17 20
29 31 :2 20 :2 17 7 16 2b 3e
4a 56 a 19 26 32 3f 4c
a 14 12 23 31 3f a 16
20 2e 42 56 a 17 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
58 5b 5c :2 58 :2 2c :3 10 :2 16 1b
27 69 6c :2 27 79 7c :2 27 80
83 :2 27 8f 92 :2 27 9a 9d :2 27
a9 ac b3 bc bf :2 ac :2 27 :2 10
5f :2 d :2 a :4 16 :2 a 7 :3 5a 11
23 37 46 53 :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5b 5c :2 58 :2 2c
:3 10 :2 16 1b 27 69 6c :2 27 79
7c :2 27 80 83 :2 27 8f 92 :2 27
9a 9d :2 27 a9 ac b3 bc bf
:2 ac :2 27 :2 10 5f :2 d :2 a :4 16 :2 a
7 :3 5a a :2 15 1c 2a :2 a 35
37 :2 35 a 15 a 39 14 1a
32 3f 13 20 31 3c 11 1f
30 48 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5e 5f :2 5b :2 2f :3 13 :2 19
1e 2a 6c 6f :2 2a 7c 7f :2 2a
83 86 :2 2a 92 95 :2 2a 9d a0
:2 2a ac af b6 bf c2 :2 af :2 2a
:2 13 62 :2 10 :2 d :4 19 :2 d a :7 7
a 13 1c :2 a 1f 21 :2 1f 14
20 2f 38 46 56 13 20 31
3e d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5b 5e 5f :2 5b :2 2f
:3 13 :2 19 1e 2a 6c 6f :2 2a 7c
7f :2 2a 83 86 :2 2a 92 95 :2 2a
9d a0 :2 2a ac af b6 bf c2
:2 af :2 2a :2 13 62 :2 10 :2 d :4 19 :2 d
a :3 23 14 20 12 19 27 44
12 19 28 2f 49 12 22 13
20 31 3e d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5e 5f
:2 5b :2 2f :3 13 :2 19 1e 2a 6c 6f
:2 2a 7c 7f :2 2a 83 86 :2 2a 92
95 :2 2a 9d a0 :2 2a ac af b6
bf c2 :2 af :2 2a :2 13 62 :2 10 :2 d
:4 19 :2 d a :4 23 14 20 12 19
27 44 12 19 28 2f 49 12
22 13 20 31 3e d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5b
5e 5f :2 5b :2 2f :3 13 :2 19 1e 2a
6c 6f :2 2a 7c 7f :2 2a 83 86
:2 2a 92 95 :2 2a 9d a0 :2 2a ac
af b6 bf c2 :2 af :2 2a :2 13 62
:2 10 :2 d :4 19 :2 d a :7 7 4 5a
b :2 14 1f 1d :2 28 :2 1d a 7
15 7 11 28 f 10 24 38
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 58
5b 5c :2 58 :2 2c :3 10 :2 16 1b 27
69 6c :2 27 79 7c :2 27 80 83
:2 27 8f 92 :2 27 9a 9d :2 27 a9
ac b3 bc bf :2 ac :2 27 :2 10 5f
:2 d :2 a :4 16 :2 a 7 :3 38 b :2 14
1f 1d :2 28 :2 1d a 14 2b 12
13 27 3b :2 d :2 16 22 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5e 5f :2 5b :2 2f :3 13
:2 19 1e 2a 6c 6f :2 2a 7c 7f
:2 2a 83 86 :2 2a 92 95 :2 2a 9d
a0 :2 2a ac af b6 bf c2 :2 af
:2 2a :2 13 62 :2 10 :2 d :4 19 :2 d a
:3 38 e :2 17 22 20 :2 2b :2 20 :2 d
1b d 3b :2 a 38 :2 7 e 17
23 :2 e 26 29 :2 26 :3 a d 16
1f :2 d 24 22 :2 2d :2 22 d 20
2e 31 3a 42 :2 31 46 :2 4f 24
:2 20 d 17 30 3d 10 1e 27
34 42 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 61
62 :2 5e :2 32 :3 16 :2 1c 21 2d 6f
72 :2 2d 7f 82 :2 2d 86 89 :2 2d
95 98 :2 2d a0 a3 :2 2d af b2
b9 c2 c5 :2 b2 :2 2d :2 16 65 :2 13
:2 10 :4 1c :2 10 d :3 3c d 20 36
:2 20 d a 3c 11 18 21 2a
:2 18 2e :2 37 :2 11 10 48 45 :2 51
:2 45 17 30 3d 10 1c 25 2c
39 42 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 61
62 :2 5e :2 32 :3 16 :2 1c 21 2d 6f
72 :2 2d 7f 82 :2 2d 86 89 :2 2d
95 98 :2 2d a0 a3 :2 2d af b2
b9 c2 c5 :2 b2 :2 2d :2 16 65 :2 13
:2 10 :4 1c :2 10 d :3 5d d 20 36
:2 20 d a 5d 3c 11 18 21
2a :2 18 2e :2 37 :2 11 10 4a 47
:2 53 :2 47 17 30 3d 10 1c 25
2c 39 42 16 2a 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5e
61 62 :2 5e :2 32 :3 16 :2 1c 21 2d
6f 72 :2 2d 7f 82 :2 2d 86 89
:2 2d 95 98 :2 2d a0 a3 :2 2d af
b2 b9 c2 c5 :2 b2 :2 2d :2 16 65
:2 13 :2 10 :4 1c :2 10 d :3 61 d 20
36 :2 20 d 61 3c :2 a 2b :2 7
38 5a :2 4 18 28 2b c 1d
28 32 35 :2 c 16 19 1e 2d
33 36 44 47 56 59 d 19
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 55
58 59 :2 55 :2 29 :3 d :2 13 18 24
66 69 :2 24 76 79 :2 24 7d 80
:2 24 8c 8f :2 24 97 9a :2 24 a6
a9 b0 b9 bc :2 a9 :2 24 :2 d 5c
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1d 1a :2 26 :2 1a :2 7 19 7 36
:3 4 13 :2 4 14 :2 4 15 :2 4 :3 17
4 8 11 27 :2 8 2a 2c :2 2a
7 33 3c 52 :2 33 55 57 :2 55
32 :3 7 1a 2b 39 43 4f 5c
27 34 40 4d 59 :2 1a 7 a
13 29 :2 a 2c 2e :2 2c a 18
21 2d :2 18 30 32 3b 4b :2 32
:2 18 :2 a 19 22 2f :2 19 32 34
3d 4d :2 34 :2 19 a 30 :2 7 a
13 29 :2 a 2c 2e :2 2c a 18
21 2d :2 18 30 32 3b 4b :2 32
:2 18 :2 a 19 22 2f :2 19 32 34
3d 4d :2 34 :2 19 a 30 :2 7 5a
:3 4 10 :2 4 f 4 e 12 26
c d 1a :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 55 58 59 :2 55 :2 29 :3 d
:2 13 18 24 66 69 :2 24 76 79
:2 24 7d 80 :2 24 8c 8f :2 24 97
9a :2 24 a6 a9 b0 b9 bc :2 a9
:2 24 :2 d 5c :2 a :2 7 :4 13 :2 7 4
:3 1 4 1b 4 e 21 2f 44
c d 1a 2b 35 b 19 2a
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 55
58 59 :2 55 :2 29 :3 d :2 13 18 24
66 69 :2 24 76 79 :2 24 7d 80
:2 24 8c 8f :2 24 97 9a :2 24 a6
a9 b0 b9 bc :2 a9 :2 24 :2 d 5c
:2 a :2 7 :4 13 :2 7 4 :3 1 e 28
4a 56 c 22 2f :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 66 69 :2 24
76 79 :2 24 7d 80 :2 24 8c 8f
:2 24 97 9a :2 24 a6 a9 b0 b9
bc :2 a9 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 b :2 16 1d 2b :2 b
36 39 :2 36 :3 7 :4 b :2 a 19 a
14 26 34 3c 43 5b 63 6a
83 8d d 1b 29 32 3d 47
4f 57 12 18 2a 35 41 4d
d 19 25 30 41 49 52 5a
12 13 27 :2 d :2 16 22 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5e 5f :2 5b :2 2f :3 13
:2 19 1e 2a 6c 6f :2 2a 7c 7f
:2 2a 83 86 :2 2a 92 95 :2 2a 9d
a0 :2 2a ac af b6 bf c2 :2 af
:2 2a :2 13 62 :2 10 :2 d :4 19 :2 d a
:3 2c e :2 17 22 20 :2 2b :2 20 d
:4 41 40 3f :3 d 1d 1e :2 1d :2 d
:2 16 22 39 47 55 2f 3a 46
52 2f 3d 50 :2 22 d 63 :3 a
1f a d 16 22 :2 d 25 27
:2 25 10 19 24 :2 10 2a 27 33
3f :2 2a :2 27 45 4e 56 :2 45 5c
59 27 30 :2 5c :2 59 :2 10 13 1a
23 2f :2 1a 33 :2 3c :2 13 49 4c
:2 49 16 :2 20 32 :2 3c 48 4c 5e
62 63 :2 5e :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d 80 83 :2 2d 87 8a
:2 2d 94 97 a0 a8 :2 b1 :2 a0 c9
:2 97 :2 2d d1 d4 :2 2d dc df :2 2d
e4 e7 :2 2d f0 f3 :2 2d :2 16 66
:2 13 16 :2 20 32 :2 3c 48 4b 5d
61 62 :2 5d :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d :2 16 65 :3 13 :2 1e 32
:2 3b 52 5c :2 13 4e 13 28 13
16 1f 2b :2 16 2e 30 :2 2e 16
29 16 32 :2 13 :4 10 33 :3 d 19
:2 d 1d :2 d 1e :2 d 17 :2 d 1d
:2 d 18 :2 d 17 :2 d 1a :2 d 1a
d 29 :2 a e :2 17 22 20 :2 2b
:2 20 :2 d 1c :2 d 1a d :4 11 10
13 1a 2a 2d :2 13 30 32 :2 30
13 23 24 :2 23 :2 13 :2 1c 28 3f
4d 5b 2f 3a 46 52 2f 3d
50 :2 28 13 36 :2 10 1a 2d 35
3c 4f 59 6a 13 1d 25 30
3f 4e 18 25 30 3c 4f 13
1b 23 2e 3f 50 18 19 2d
:2 13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 61
65 66 :2 61 :2 35 :3 19 :2 1f 24 30
73 76 :2 30 83 86 :2 30 8a 8d
:2 30 99 9c :2 30 a4 a7 :2 30 b3
b6 bd c6 c9 :2 b6 :2 30 :2 19 69
:2 16 :2 13 :4 1f :2 13 10 :3 32 14 :2 1d
28 26 :2 31 :2 26 13 16 1f 2a
:2 16 30 2d 39 45 :2 30 :2 2d 4b
54 5c :2 4b 62 5f 27 30 :2 62
:2 5f :2 16 19 :2 23 35 :2 3f 4b 4f
61 65 66 :2 61 :2 35 :3 19 :2 1f 24
30 73 76 :2 30 83 86 :2 30 8a
8d :2 30 97 9a a3 ab :2 b4 :2 a3
cc :2 9a :2 30 d4 d7 :2 30 df e2
:2 30 e7 ea :2 30 f3 f6 :2 30 :2 19
69 :2 16 19 :2 23 35 :2 3f 4b 4e
60 64 65 :2 60 :2 35 :3 19 :2 1f 24
30 73 76 :2 30 :2 19 68 :3 16 :2 21
35 :2 3e 55 5f :2 16 33 :3 13 2c
33 3f 42 :2 2c 45 47 :2 45 50
:2 27 57 :2 22 13 16 1f 2b :2 16
2e 31 :2 2e 16 21 :2 16 25 16
19 22 2e :2 19 31 34 :2 31 1c
25 31 :2 1c 34 37 :2 34 26 2a
3a 24 25 32 23 38 50 5c
:2 1f :2 28 34 1f 1c 24 22 :2 2b
37 22 32 :2 1f :2 24 22 :2 2b 37
22 25 :2 2f 41 :2 4b 57 5b 6d
71 72 :2 6d :2 41 :3 25 :2 2b 30 3c
7f 82 :2 3c 8f 92 :2 3c 96 99
:2 3c a5 a8 :2 3c b0 b3 :2 3c bf
c2 c9 d2 d5 :2 c2 :2 3c :2 25 75
:2 22 :2 1f :4 2b :2 1f 1c :4 39 26 2a
3a 24 25 32 43 51 :2 1f :2 28
34 1f 1c 24 22 :2 2b 37 22
32 :2 1f :2 24 22 :2 2b 37 22 25
:2 2f 41 :2 4b 57 5b 6d 71 72
:2 6d :2 41 :3 25 :2 2b 30 3c 7f 82
:2 3c 8f 92 :2 3c 96 99 :2 3c a5
a8 :2 3c b0 b3 :2 3c bf c2 c9
d2 d5 :2 c2 :2 3c :2 25 75 :2 22 :2 1f
:4 2b :2 1f 1c :7 19 36 :2 16 19 22
2e :2 19 31 34 :2 31 28 3f 4c
20 35 4d 59 1c 23 1f 2b
:3 29 1f :2 28 34 1f 30 1f :2 28
34 1f :4 1c 19 21 1f :2 28 34
1f 2f :2 1c :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 6a 6e
6f :2 6a :2 3e :3 22 :2 28 2d 39 7c
7f :2 39 8c 8f :2 39 93 96 :2 39
a2 a5 :2 39 ad b0 :2 39 bc bf
c6 cf d2 :2 bf :2 39 :2 22 72 :2 1f
:2 1c :4 28 :2 1c 19 :4 36 28 42 4f
60 6e 1c 23 1f 2b :3 29 1f
:2 28 34 1f 30 1f :2 28 34 1f
:4 1c 19 21 1f :2 28 34 1f 2f
:2 1c :2 21 1f :2 28 34 1f 22 :2 2c
3e :2 48 54 58 6a 6e 6f :2 6a
:2 3e :3 22 :2 28 2d 39 7c 7f :2 39
8c 8f :2 39 93 96 :2 39 a2 a5
:2 39 ad b0 :2 39 bc bf c6 cf
d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c :4 28
:2 1c 19 :3 16 28 43 57 1c 23
1f 2b :3 29 1f :2 28 34 1f 30
1f :2 28 34 1f :4 1c 19 21 1f
:2 28 34 1f 2f :2 1c :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
6a 6e 6f :2 6a :2 3e :3 22 :2 28 2d
39 7c 7f :2 39 8c 8f :2 39 93
96 :2 39 a2 a5 :2 39 ad b0 :2 39
bc bf c6 cf d2 :2 bf :2 39 :2 22
72 :2 1f :2 1c :4 28 :2 1c 19 :3 16 28
3f 53 1c 23 1f 2b :3 29 1f
:2 28 34 1f 30 1f :2 28 34 1f
:4 1c 19 21 1f :2 28 34 1f 2f
:2 1c :2 21 1f :2 28 34 1f 22 :2 2c
3e :2 48 54 58 6a 6e 6f :2 6a
:2 3e :3 22 :2 28 2d 39 7c 7f :2 39
8c 8f :2 39 93 96 :2 39 a2 a5
:2 39 ad b0 :2 39 bc bf c6 cf
d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c :4 28
:2 1c 19 :3 16 28 3f 4c 5d 71
1c 23 1f 2b :3 29 1f :2 28 34
1f 30 1f :2 28 34 1f :4 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6a 6e 6f :2 6a :2 3e :3 22
:2 28 2d 39 7c 7f :2 39 8c 8f
:2 39 93 96 :2 39 a2 a5 :2 39 ad
b0 :2 39 bc bf c6 cf d2 :2 bf
:2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c 19
:7 16 33 :2 13 41 :2 10 d 32 17
20 2c :2 17 2f 32 :2 2f :3 13 38
41 4d :2 38 50 53 :2 50 :3 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 91 94
9d a5 :2 ae :2 9d cf :2 94 :2 2a d7
da :2 2a e2 e5 :2 2a ea ed :2 2a
f6 f9 :2 2a :2 13 63 :2 10 13 :2 1d
2f :2 39 45 48 5a 5e 5f :2 5a
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
:2 13 62 :3 10 :2 1b 2f :2 38 58 18
:2 10 55 32 :2 d 10 1c 1f :2 1c
10 27 10 14 1d 33 :2 14 36
38 :2 36 13 40 49 5f :2 40 62
64 :2 62 3f :2 13 16 1f 2b :2 16
2e 30 :2 2e 20 35 49 19 27
31 19 28 19 28 19 28 19
28 19 2f 4a 59 19 33 40
55 19 27 30 37 44 4d 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :4 32 20 35 49 19 27 31
19 28 19 28 19 28 19 28
19 2f 4a 59 19 33 40 55
19 36 43 5a 19 27 30 37
44 4d 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 67 6b
6c :2 67 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :7 13 10 67 16
1f 35 :2 16 38 3a :2 38 1d 32
46 16 24 2e 16 25 16 25
16 2c 47 56 16 30 3d 52
16 24 2d 34 41 4a 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:3 3c 10 3c 67 16 1f 35 :2 16
38 3a :2 38 16 1f 2b :2 16 2e
30 :2 2e 20 35 49 19 27 31
19 28 19 28 19 2f 4a 59
19 27 30 37 44 4d 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 67 6b 6c :2 67 :2 3b :3 1f
:2 25 2a 36 79 7c :2 36 89 8c
:2 36 90 93 :2 36 9f a2 :2 36 aa
ad :2 36 b9 bc c3 cc cf :2 bc
:2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19 16
:4 32 20 35 49 19 27 31 19
28 19 28 19 2f 4a 59 19
36 43 5a 19 27 30 37 44
4d 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 67 6b 6c
:2 67 :2 3b :3 1f :2 25 2a 36 79 7c
:2 36 89 8c :2 36 90 93 :2 36 9f
a2 :2 36 aa ad :2 36 b9 bc c3
cc cf :2 bc :2 36 :2 1f 6f :2 1c :2 19
:4 25 :2 19 16 :7 13 3c 67 1d 32
46 16 2c 47 56 16 24 2e
1c 30 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :7 10 1f 36 43 54 68
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 65 66 :2 61 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 83 86
:2 30 8a 8d :2 30 99 9c :2 30 a4
a7 :2 30 b3 b6 bd c6 c9 :2 b6
:2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13 10
:3 21 1f 3a 4e 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 65
66 :2 61 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 83 86 :2 30 8a 8d :2 30
99 9c :2 30 a4 a7 :2 30 b3 b6
bd c6 c9 :2 b6 :2 30 :2 19 69 :2 16
:2 13 :4 1f :2 13 10 :3 21 1f 39 46
57 65 13 1a 16 22 :3 20 16
:2 1f 2b 16 27 16 :2 1f 2b 16
:4 13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 65 66 :2 61
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
83 86 :2 30 8a 8d :2 30 99 9c
:2 30 a4 a7 :2 30 b3 b6 bd c6
c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f
:2 13 10 :4 21 :2 d 10 1a 1d :2 1a
13 1c 24 :2 13 27 29 :2 27 13
20 :2 29 13 2b 13 20 :2 29 30
39 44 :2 30 48 :2 51 :2 20 13 :5 10
1b 10 13 1c 28 :2 13 2b 2d
:2 2b 16 1f 29 :2 16 2e 2c 37
49 :2 2e :2 2c 16 22 2b 3d :2 22
16 4c :3 13 22 :2 13 1c 13 16
:2 1f 2a 3d :2 16 40 43 :2 40 16
22 16 45 16 22 16 :4 13 16
1f 2b :2 16 2e 30 :2 2e 16 20
16 32 :3 13 21 32 3e 4b 54
5d :2 4b 61 6a 72 :2 61 22 2b
37 :2 22 3b 44 4f :2 3b 53 20
2b :2 53 2f 38 46 :2 2f 4a 53
5e :2 4a 22 2b 37 :2 22 3b 43
4d :2 21 13 16 1f 2b :2 16 30
2e :2 39 :2 2e 19 :2 23 35 :2 3f 4b
4e 60 64 65 :2 60 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 97 9a a3 ab :2 b4
:2 a3 c5 :2 9a :2 30 :2 19 68 :2 16 19
:2 23 35 :2 3f 4b 4e 60 64 65
:2 60 :2 35 :3 19 :2 1f 24 30 73 76
:2 30 :2 19 68 :3 16 :2 21 37 :2 40 50
:2 16 13 48 19 22 2e :2 19 31
34 :2 31 19 :2 23 35 :2 3f 4b 4f
61 65 66 :2 61 :2 35 :3 19 :2 1f 24
30 73 76 :2 30 83 86 :2 30 8a
8d :2 30 97 9a a3 ab :2 a3 b8
:2 9a :2 30 c0 c3 :2 30 cb ce :2 30
d3 d6 :2 30 e3 e6 :2 30 :2 19 69
:2 16 19 :2 23 35 :2 3f 4b 4e 60
64 65 :2 60 :2 35 :3 19 :2 1f 24 30
73 76 :2 30 :2 19 68 :3 16 :2 21 35
3e 4a :2 35 4e 5c :2 16 36 48
:3 13 26 :2 13 1f 2b 40 4e 5c
66 1b 23 2f 3b 47 53 1b
2a 36 40 48 51 59 1b 27
33 40 4b 56 1b 25 30 3c
48 4b 4e 54 5a :2 1f 13 16
1f 21 :2 1f 19 :2 23 35 :2 3f 4b
4f 61 65 66 :2 61 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 97 9a a3 ab :2 b4
:2 a3 cb :2 9a :2 30 d3 d6 :2 30 de
e1 :2 30 e6 e9 :2 30 f2 f5 :2 30
:2 19 69 :2 16 19 :2 23 35 :2 3f 4b
4e 60 64 65 :2 60 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 :2 19 68 :3 16
:2 21 35 :2 3e 54 5e :2 16 13 25
19 22 25 :2 22 19 :2 23 35 :2 3f
4b 4f 61 65 66 :2 61 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 83 86
:2 30 8a 8d :2 30 97 9a a3 ab
:2 b4 :2 a3 cc :2 9a :2 30 d4 d7 :2 30
df e2 :2 30 e7 ea :2 30 fa fd
:2 30 :2 19 69 :2 16 19 :2 23 35 :2 3f
4b 4e 60 64 65 :2 60 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 :2 19 68
:3 16 :2 21 35 :2 3e 55 1e :2 16 27
25 16 24 :2 16 24 34 42 57
63 6c 77 :2 63 21 2a 34 :2 21
:2 24 16 :4 13 2f :2 10 1f :3 d 1b
:2 24 d 17 1b 2a 15 16 23
34 48 :2 10 :2 19 25 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 96 99 :2 2d a1 a4
:2 2d b0 b3 ba c3 c6 :2 b3 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :4 3b
:2 a 2c :3 7 12 7 3b :3 4 e
15 1c 1f :2 15 24 27 :2 e :2 4
1b :2 4 10 4 e 20 34 43
50 :2 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
55 59 5a :2 55 :2 29 :3 d :2 13 18
24 67 6a :2 24 77 7a :2 24 7e
81 :2 24 8d 90 :2 24 98 9b :2 24
a7 aa b1 ba bd :2 aa :2 24 :2 d
5d :2 a :2 7 :4 13 :2 7 4 :3 1 4
12 :2 4 12 :2 4 f :2 4 14 :2 4
9 :4 4 d 16 23 38 43 4b
55 7 15 1b 21 2e 7 1c
27 39 44 7 f 18 20 2b
:3 7 a e :2 a :2 13 1f a 14
a :2 13 1f a :4 7 b :2 14 20
1d :2 29 :2 1d :3 a 39 :3 7 16 7
a 13 1d :2 a 20 22 :2 20 a
1d 34 41 :2 1d a 19 34 48
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5f 60 :2 5b :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 93 96 :2 2a 9e
a1 :2 2a ad b0 b7 c0 c3 :2 b0
:2 2a :2 13 63 :2 10 :2 d :4 19 :2 d a
:3 24 19 30 44 d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
93 96 :2 2a 9e a1 :2 2a ad b0
b7 c0 c3 :2 b0 :2 2a :2 13 63 :2 10
:2 d :4 19 :2 d a :3 24 19 2b 3f
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5f 60 :2 5b :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 93 96 :2 2a 9e
a1 :2 2a ad b0 b7 c0 c3 :2 b0
:2 2a :2 13 63 :2 10 :2 d :4 19 :2 d a
:3 24 19 30 3d 4e 62 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5f 60 :2 5b :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a 7d 80 :2 2a 84
87 :2 2a 93 96 :2 2a 9e a1 :2 2a
ad b0 b7 c0 c3 :2 b0 :2 2a :2 13
63 :2 10 :2 d :4 19 :2 d a :3 24 19
35 49 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 93 96
:2 2a 9e a1 :2 2a ad b0 b7 c0
c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19
:2 d a :3 24 19 36 4a d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5f 60 :2 5b :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a 7d 80 :2 2a 84
87 :2 2a 93 96 :2 2a 9e a1 :2 2a
ad b0 b7 c0 c3 :2 b0 :2 2a :2 13
63 :2 10 :2 d :4 19 :2 d a :4 24 d
16 22 :2 d 25 27 :2 25 d 24
d 29 :2 a 14 2b 39 13 27
11 1e 11 1f d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
93 96 :2 2a 9e a1 :2 2a ad b0
b7 c0 c3 :2 b0 :2 2a :2 13 63 :2 10
:2 d :4 19 :2 d a :3 7 a 1a 1b
:2 1a :2 a :2 13 1f 36 44 4f 64
6a 2f 3b 47 2f 42 :2 1f a
14 27 35 4a 12 13 20 31
3b 49 57 11 :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5b 5f 60 :2 5b :2 2f
:3 13 :2 19 1e 2a 6d 70 :2 2a 7d
80 :2 2a 84 87 :2 2a 93 96 :2 2a
9e a1 :2 2a ad b0 b7 c0 c3
:2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19 :2 d
a :3 7 e :2 17 22 20 :2 2b :2 20
:2 d 1c d 17 2a 37 48 4e
5d 15 16 23 31 3f 4c :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 62
63 :2 5e :2 32 :3 16 :2 1c 21 2d 70
73 :2 2d 80 83 :2 2d 87 8a :2 2d
96 99 :2 2d a1 a4 :2 2d b0 b3
ba c3 c6 :2 b3 :2 2d :2 16 66 :2 13
:2 10 :4 1c :2 10 d :3 3b 11 :2 1a 25
23 :2 2e :2 23 10 14 1b 24 33
:2 1b 37 :2 40 :2 14 13 52 50 :2 5b
:2 50 13 1f 13 1d 16 24 16
25 16 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :3 69 10 69 16
1f 2e :2 16 33 31 :2 3c :2 31 13
26 34 37 40 48 :2 37 4c :2 55
24 :2 26 13 1d 16 25 2e 16
25 16 24 16 25 16 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:4 4b 69 1d 16 25 2e 35 43
4c 16 25 16 24 16 25 16
1c 30 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :7 10 14 :2 1d 28 26 :2 31
:2 26 13 46 4f 59 :2 46 5c 5e
:2 5c 45 :2 13 22 3d 51 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :4 61 :2 10
3e 1a 1d 30 37 3a 49 4f
52 18 1d 27 2f 33 48 19
1c 29 37 3a 47 4a 59 5c
17 1a 28 2b 1a 31 42 4b
4e 62 65 :2 13 :2 1c 28 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 65 66 :2 61 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 83 86
:2 30 8a 8d :2 30 99 9c :2 30 a4
a7 :2 30 b3 b6 bd c6 c9 :2 b6
:2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13 10
:3 d 14 :2 1d 28 26 :2 31 :2 26 13
:4 47 46 45 :3 13 26 34 37 40
48 :2 37 4c :2 55 24 :2 26 13 22
3d 51 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :3 5a 1d 36 44 4e 16
23 31 43 4f 1c 30 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :3 5a 1d
29 38 41 4f 55 1c 29 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :4 5a
1d 29 38 41 4f 5f 1c 29
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:3 10 1d 36 44 4e 1c 30 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :7 10
:4 d 1c 33 40 51 65 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 62 63 :2 5e :2 32 :3 16 :2 1c 21
2d 70 73 :2 2d 80 83 :2 2d 87
8a :2 2d 96 99 :2 2d a1 a4 :2 2d
b0 b3 ba c3 c6 :2 b3 :2 2d :2 16
66 :2 13 :2 10 :4 1c :2 10 d :4 3b d
1c d 1c 37 4b 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5e
62 63 :2 5e :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d 80 83 :2 2d 87 8a
:2 2d 96 99 :2 2d a1 a4 :2 2d b0
b3 ba c3 c6 :2 b3 :2 2d :2 16 66
:2 13 :2 10 :4 1c :2 10 d :3 a 1c 33
47 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 62 63 :2 5e :2 32
:3 16 :2 1c 21 2d 70 73 :2 2d 80
83 :2 2d 87 8a :2 2d 96 99 :2 2d
a1 a4 :2 2d b0 b3 ba c3 c6
:2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10
d :3 a 1c 33 40 51 65 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 96 99 :2 2d a1 a4
:2 2d b0 b3 ba c3 c6 :2 b3 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :3 a
10 17 23 26 :2 10 29 2b :2 29
10 1f 10 2f :3 d 24 d :4 a
d 16 20 :2 d 23 25 :2 23 11
1a 28 :2 11 2b 2d :2 2b 10 :4 36
35 34 :2 10 24 46 56 18 2a
38 43 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 61 65 66 :2 61 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 99 9c :2 30 a4 a7
:2 30 b3 b6 bd c6 c9 :2 b6 :2 30
:2 19 69 :2 16 :2 13 :4 1f :2 13 10 :3 51
14 :2 1d 28 26 :2 31 :2 26 13 46
4f 5d :2 46 60 62 :2 60 45 :2 13
1d 29 39 4c 57 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 64
68 69 :2 64 :2 38 :3 1c :2 22 27 33
76 79 :2 33 86 89 :2 33 8d 90
:2 33 9c 9f :2 33 a7 aa :2 33 b6
b9 c0 c9 cc :2 b9 :2 33 :2 1c 6c
:2 19 :2 16 :4 22 :2 16 13 :3 65 10 65
17 :2 20 2b 29 :2 34 :2 29 16 49
52 60 :2 49 63 65 :2 63 48 :3 16
1c :3 16 :2 1f 2b 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :3 68 16
:2 20 32 :2 3c 48 4c 5e 62 63
:2 5e :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 94
97 a0 a8 :2 b1 :2 a0 cc :2 97 :2 2d
d4 d7 :2 2d df e2 :2 2d e7 ea
:2 2d f4 f7 :2 2d :2 16 66 :2 13 16
:2 20 32 :2 3c 48 4b 5d 61 62
:2 5d :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d :2 16 65 :3 13 :2 1e 32 :2 3b 55
1b :2 13 68 65 :2 10 51 :2 d 10
19 26 :2 10 2b 29 :2 34 :2 29 49
13 20 :2 49 25 23 :2 2e :2 23 :3 10
18 22 :3 10 :2 19 25 10 13 1c
27 :2 13 2a 2c :2 2a 32 3b 43
:2 32 46 48 :2 46 :2 13 22 1d 1f
30 45 1c 1e 2b 38 3a 4b
53 5a 6c 74 7b 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 64
68 69 :2 64 :2 38 :3 1c :2 22 27 33
76 79 :2 33 86 89 :2 33 8d 90
:2 33 9c 9f :2 33 a7 aa :2 33 b6
b9 c0 c9 cc :2 b9 :2 33 :2 1c 6c
:2 19 :2 16 :4 22 :2 16 13 :4 4a 22 3c
3e 1b 30 33 44 1c 1e 2b
38 3a 4b 53 5a 6c 74 7b
1a 1e 2b 3c 40 54 1a 1c
27 2b 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :7 10 14 :2 1d 28 26 :2 31
:2 26 :2 13 21 13 1d 23 2e 32
41 4d 1b :2 16 :2 1f 2b 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:3 41 16 1f 2b :2 16 2e 30 :2 2e
1b 16 32 25 1f 2c 3d 51
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 67 6b 6c :2 67 :2 3b :3 1f
:2 25 2a 36 79 7c :2 36 89 8c
:2 36 90 93 :2 36 9f a2 :2 36 aa
ad :2 36 b9 bc c3 cc cf :2 bc
:2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19 16
:3 13 16 23 2a 33 3d :2 33 48
:2 2a 4b 4d 56 60 :2 56 6d :2 4d
:2 2a 29 71 73 :2 29 :2 23 16 20
2f 3e 4b 1e 1f 2c 3d 48
:2 19 :2 22 2e 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 67
6b 6c :2 67 :2 3b :3 1f :2 25 2a 36
79 7c :2 36 89 8c :2 36 90 93
:2 36 9f a2 :2 36 aa ad :2 36 b9
bc c3 cc cf :2 bc :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :3 13 19 22
2f :2 19 34 32 3d 48 :2 34 :2 32
19 :2 22 3b 44 4f :2 3b 53 :2 19
4b :2 16 25 :10 19 23 37 50 19
1e 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :7 13 1d 32 40 4a 16 38
56 16 2f 4d 5e 16 2f 4d
5e 16 2f 4d 5e 16 2f 4d
5e 16 25 2e 35 42 4b 1c
30 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 76 79 :2 33 86
89 :2 33 8d 90 :2 33 9c 9f :2 33
a7 aa :2 33 b6 b9 c0 c9 cc
:2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :3 41 13 26 2d 36 40 :2 36
4c :2 2d 4f 51 5a 64 :2 5a 70
:2 51 :2 2d 2c 24 26 :2 2c :2 26 :2 13
21 :2 2a 31 3a 4b :2 31 4f :2 58
:2 21 :2 13 26 36 44 59 65 24
2f :2 65 33 3c 46 :2 33 :2 26 13
41 18 13 :4 10 42 10 21 10
13 1c 1f :2 1c 16 1f 2c :2 16
2f 32 :2 2f 16 22 16 19 22
2a :2 19 2d 2f :2 2d 35 3e 4f
:2 35 52 55 :2 52 :2 19 5f 1c 2d
:2 5f 30 33 :2 30 :3 19 23 :2 19 23
2c 3d :2 23 19 35 :2 16 20 19
28 31 38 45 4e 60 66 6c
1f 33 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 67 6b 6c :2 67
:2 3b :3 1f :2 25 2a 36 79 7c :2 36
89 8c :2 36 90 93 :2 36 9f a2
:2 36 aa ad :2 36 b9 bc c3 cc
cf :2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25
:2 19 16 :4 34 16 22 :2 16 26 :2 16
27 :2 16 20 :2 16 26 :2 16 21 :2 16
20 :2 16 23 :2 16 23 16 1b 22
2b 37 :2 22 3b :2 44 :2 1b 1a 52
55 :2 52 19 5d 1c 27 :2 5d 2d
2a 36 42 :2 2d :2 2a 48 1c 24
:2 48 2a 27 33 3c :2 2a :2 27 :2 5d
5c :2 19 1c 25 2b :2 1c 2e 30
:2 2e 26 1f 2d 37 4a 29 47
1f 38 56 67 1f 38 56 67
1f 38 56 67 1f 38 56 67
1f 2e 37 3d 1f 2e 1f 2e
37 3e 4b 54 25 39 1f 26
22 2e :3 2c 22 :2 2b 37 22 33
22 :2 2b 37 22 :4 1f 1c 24 22
:2 2b 37 22 32 :2 1f :2 24 22 :2 2b
37 22 25 :2 2f 41 :2 4b 57 5b
6d 71 72 :2 6d :2 41 :3 25 :2 2b 30
3c 7f 82 :2 3c 8f 92 :2 3c 96
99 :2 3c a5 a8 :2 3c b0 b3 :2 3c
bf c2 c9 d2 d5 :2 c2 :2 3c :2 25
75 :2 22 :2 1f :4 2b :2 1f 1c :4 34 26
1f 2d 37 4a 29 47 1f 38
56 67 1f 38 56 67 1f 38
56 67 1f 38 56 67 1f 2e
37 3d 1f 2e 1f 2e 1f 2e
37 3e 4b 54 25 39 1f 26
22 2e :3 2c 22 :2 2b 37 22 33
22 :2 2b 37 22 :4 1f 1c 24 22
:2 2b 37 22 32 :2 1f :2 24 22 :2 2b
37 22 25 :2 2f 41 :2 4b 57 5b
6d 71 72 :2 6d :2 41 :3 25 :2 2b 30
3c 7f 82 :2 3c 8f 92 :2 3c 96
99 :2 3c a5 a8 :2 3c b0 b3 :2 3c
bf c2 c9 d2 d5 :2 c2 :2 3c :2 25
75 :2 22 :2 1f :4 2b :2 1f 1c :7 19 40
23 1c 2a 34 47 26 44 1c
35 53 64 1c 35 53 64 1c
35 53 64 1c 35 53 64 1c
2b 34 3b 48 51 63 69 22
36 1c 23 1f 2b :3 29 1f :2 28
34 1f 30 1f :2 28 34 1f :4 1c
19 21 1f :2 28 34 1f 2f :2 1c
:2 21 1f :2 28 34 1f 22 :2 2c 3e
:2 48 54 58 6a 6e 6f :2 6a :2 3e
:3 22 :2 28 2d 39 7c 7f :2 39 8c
8f :2 39 93 96 :2 39 a2 a5 :2 39
ad b0 :2 39 bc bf c6 cf d2
:2 bf :2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c
19 :7 16 1a 23 2e :2 1a 31 33
:2 31 19 3b 44 4c :2 3b 4f 52
:2 4f 3a :3 19 23 19 16 57 1c
25 2d :2 1c 30 32 :2 30 19 2c
35 3d :2 2c 19 36 57 :2 16 :5 13
21 32 3e 4b 54 5d :2 4b 61
6a 72 :2 61 22 2b 37 :2 22 3b
44 4f :2 3b 53 20 2b :2 53 2f
38 46 :2 2f 4a 53 5e :2 4a 22
2b 37 :2 22 3b 43 4d :2 21 13
16 1f 2b :2 16 30 2e :2 39 :2 2e
19 1f :3 19 :2 22 2e 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 67 6b 6c :2 67 :2 3b :3 1f :2 25
2a 36 79 7c :2 36 89 8c :2 36
90 93 :2 36 9f a2 :2 36 aa ad
:2 36 b9 bc c3 cc cf :2 bc :2 36
:2 1f 6f :2 1c :2 19 :4 25 :2 19 16 :3 48
19 :2 23 35 :2 3f 4b 4e 60 64
65 :2 60 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 83 86 :2 30 8a 8d :2 30
97 9a a3 ab :2 b4 :2 a3 c5 :2 9a
:2 30 :2 19 68 :2 16 19 :2 23 35 :2 3f
4b 4e 60 64 65 :2 60 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 :2 19 68
:3 16 :2 21 37 :2 40 50 :2 16 13 48
19 22 2e :2 19 31 34 :2 31 19
1f :3 19 :2 22 2e 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
67 6b 6c :2 67 :2 3b :3 1f :2 25 2a
36 79 7c :2 36 89 8c :2 36 90
93 :2 36 9f a2 :2 36 aa ad :2 36
b9 bc c3 cc cf :2 bc :2 36 :2 1f
6f :2 1c :2 19 :4 25 :2 19 16 :3 36 19
:2 23 35 :2 3f 4b 4f 61 65 66
:2 61 :2 35 :3 19 :2 1f 24 30 73 76
:2 30 83 86 :2 30 8a 8d :2 30 97
9a a3 ab :2 a3 b8 :2 9a :2 30 c0
c3 :2 30 cb ce :2 30 d3 d6 :2 30
e3 e6 :2 30 :2 19 69 :2 16 19 :2 23
35 :2 3f 4b 4e 60 64 65 :2 60
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
:2 19 68 :3 16 :2 21 35 3e 4a :2 35
4e 5c :2 16 36 48 :2 13 21 16
1f 27 :2 16 2a 2c :2 2a 32 3b
4c :2 32 4f 52 :2 4f :2 16 5c 19
2a :2 5c 2d 30 :2 2d :3 16 20 :2 16
20 29 3a :2 20 16 32 :2 13 17
20 2c :2 17 2f 31 :2 2f 16 38
41 4d :2 38 52 50 5b 66 :2 52
:2 50 37 :3 16 24 2d 38 :2 24 16
6a 16 24 2a 33 3f :2 2a 42
44 4d 58 :2 44 :2 2a :2 24 16 :4 13
16 1f 2b :2 16 2e 30 :2 2e 16
24 2d 39 :2 24 3c 3e :2 24 16
33 16 24 2a 34 3d 49 :2 34
:2 2a 4d 4f :2 2a :2 24 16 :4 13 16
1f 2c :2 16 2f 32 :2 2f 20 19
28 31 38 45 4e 60 66 6c
1f 33 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 67 6b 6c :2 67
:2 3b :3 1f :2 25 2a 36 79 7c :2 36
89 8c :2 36 90 93 :2 36 9f a2
:2 36 aa ad :2 36 b9 bc c3 cc
cf :2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25
:2 19 16 :4 34 20 19 27 31 44
23 41 19 32 50 61 19 32
50 61 19 32 50 61 19 32
50 61 19 28 31 38 45 4e
60 66 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 67 6b
6c :2 67 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :7 13 :5 10 19 10
13 1c 28 :2 13 2d 2b :2 36 :2 2b
13 1f 13 4b 13 1f 13 :4 10
13 1c 24 :2 13 27 29 :2 27 13
20 :2 29 13 2b 13 20 :2 29 30
39 44 :2 30 48 :2 51 :2 20 13 :5 10
20 10 13 1c 24 :2 13 27 29
:2 27 16 1f 27 :2 16 2a 2c :2 2a
16 24 2c 35 40 :2 2c 43 45
4e 56 :2 45 :2 2c 2b 5a 5c :2 2b
2a 66 68 :2 2a :2 24 16 19 22
33 :2 19 38 36 41 4d :2 38 :2 36
19 27 30 41 :2 27 :2 19 23 2a
33 3f :2 2a 42 44 :2 2a 29 4e
50 59 64 :2 50 :2 29 67 69 :2 29
:2 23 19 50 :2 16 13 30 19 22
33 :2 19 38 36 41 49 :2 38 :2 36
16 20 29 3a :2 20 16 4c 30
:2 13 2b :3 10 1c 28 3d 4b 56
60 1b 23 2f 3b 47 53 1b
2a 36 40 48 51 59 1b 27
33 40 4b 56 1b 25 30 3c
48 4b 4e 54 5a :2 1c 10 13
1c 1e :2 1c 16 1c :3 16 :2 1f 2b
16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :3 22 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 94 97 a0 a8 :2 b1
:2 a0 c8 :2 97 :2 2d d0 d3 :2 2d db
de :2 2d e3 e6 :2 2d ef f2 :2 2d
:2 16 66 :2 13 16 :2 20 32 :2 3c 48
4b 5d 61 62 :2 5d :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d :2 16 65 :3 13
:2 1e 32 :2 3b 51 5b :2 13 10 22
16 1f 22 :2 1f 16 1c :3 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 64 68 69
:2 64 :2 38 :3 1c :2 22 27 33 76 79
:2 33 86 89 :2 33 8d 90 :2 33 9c
9f :2 33 a7 aa :2 33 b6 b9 c0
c9 cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16
:4 22 :2 16 13 :3 24 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 94 97 a0 a8
:2 b1 :2 a0 c9 :2 97 :2 2d d1 d4 :2 2d
dc df :2 2d e4 e7 :2 2d f7 fa
:2 2d :2 16 66 :2 13 16 :2 20 32 :2 3c
48 4b 5d 61 62 :2 5d :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d :2 16 65
:3 13 :2 1e 32 :2 3b 52 1b :2 13 24
22 :2 10 :4 d 17 23 32 3a 47
67 72 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 62 63 :2 5e
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 96 99
:2 2d a1 a4 :2 2d b0 b3 ba c3
c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c
:2 10 d :3 27 1c 17 2c 2e 3a
3c 52 54 63 65 7a 7c 15
26 28 2d 36 3b 3d 4a 4c
5a 5c 69 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 62 63
:2 5e :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 96
99 :2 2d a1 a4 :2 2d b0 b3 ba
c3 c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10
:4 1c :2 10 d :3 27 1c 17 2c 35
4b 5a 6f 83 15 31 45 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 96 99 :2 2d a1 a4
:2 2d b0 b3 ba c3 c6 :2 b3 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :3 27
1c 17 2c 36 4c 5b 70 84
15 32 46 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 62 63
:2 5e :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 96
99 :2 2d a1 a4 :2 2d b0 b3 ba
c3 c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10
:4 1c :2 10 d :3 27 d 19 22 2c
:2 19 2f 31 :2 19 :2 d 18 21 2a
:2 18 2d 2f 38 42 :2 2f :2 18 :2 d
20 :2 d 20 3c 4a 58 :2 20 :2 d
20 :2 d 20 3c 4a 54 :2 20 d
17 27 35 16 23 34 48 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 96 99 :2 2d a1 a4
:2 2d b0 b3 ba c3 c6 :2 b3 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :3 27
11 1a 30 :2 11 33 35 :2 33 10
3d 46 5c :2 3d 5f 61 :2 5f 3c
:2 10 1a 31 3f 13 29 13 29
13 29 13 29 13 1e 2a 39
19 2d 13 1a 16 22 :3 20 16
:2 1f 2b 16 27 16 :2 1f 2b 16
:4 13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 65 66 :2 61
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
83 86 :2 30 8a 8d :2 30 99 9c
:2 30 a4 a7 :2 30 b3 b6 bd c6
c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f
:2 13 10 :3 64 d 64 13 1c 32
:2 13 35 37 :2 35 1a 31 3f 13
29 13 29 13 1e 2a 39 19
2d 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 99 9c :2 30
a4 a7 :2 30 b3 b6 bd c6 c9
:2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13
10 :3 39 10 1e 27 33 :2 1e 10
d 39 64 13 1c 32 :2 13 35
37 :2 35 1a 31 3f 13 29 13
29 13 1e 2a 39 19 2d 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 61 65 66 :2 61 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 99 9c :2 30 a4 a7
:2 30 b3 b6 bd c6 c9 :2 b6 :2 30
:2 19 69 :2 16 :2 13 :4 1f :2 13 10 :3 39
10 1e 27 33 :2 1e 10 39 64
1a 31 3f 13 1e 2a 39 19
2d 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 99 9c :2 30
a4 a7 :2 30 b3 b6 bd c6 c9
:2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13
10 :3 d 10 1e 27 33 :2 1e :2 10
1e 27 33 :2 1e 10 :4 d 27 :2 a
:5 7 :2 10 1c 32 40 4e :2 1c 7
9 7 :3 4 8 1 7 d :3 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 55 59
5a :2 55 :2 29 :3 d :2 13 18 24 67
6a :2 24 77 7a :2 24 7e 81 :2 24
8d 90 :2 24 98 9b :2 24 a7 aa
b1 ba bd :2 aa :2 24 :2 d 5d :2 a
:2 7 :4 13 :2 7 4 :3 1 4 f 4
7 10 1a :2 7 1d 1f :2 1d 7
13 7 a 13 1d :2 a 23 20
2c 35 :2 23 :2 20 a 16 1f 29
:2 16 2c 2e 37 40 :2 2e :2 16 a
e 17 21 :2 e 24 26 :2 24 d
2e 37 43 :2 2e 46 48 :2 46 2d
:2 d :4 16 15 14 :3 d 1d :2 d 1e
:2 d 17 :2 d 1d :2 d 18 :2 d 17
:2 d 1a :2 d 1a d 11 1a 25
:2 11 28 2a :2 28 10 32 3b 43
:2 32 46 49 :2 46 31 :3 10 1a 10
d 4e 13 1c 24 :2 13 27 29
:2 27 10 23 2c 34 :2 23 10 2d
4e :3 d 1b 2c 38 45 4e 57
:2 45 5b 64 6c :2 5b 22 2b 37
:2 22 3b 44 4f :2 3b 53 20 2b
:2 53 2f 38 46 :2 2f 4a 53 5e
:2 4a 22 2b 37 :2 22 3b 43 4d
:2 1b d 10 19 25 :2 10 2a 28
:2 33 :2 28 13 :2 1d 2f :2 39 45 48
5a 5e 5f :2 5a :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a 7d 80 :2 2a 84
87 :2 2a 91 94 9d a5 :2 ae :2 9d
bf :2 94 :2 2a :2 13 62 :2 10 13 :2 1d
2f :2 39 45 48 5a 5e 5f :2 5a
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
:2 13 62 :3 10 :2 1b 31 :2 3a 4a :2 10
d 42 13 1c 28 :2 13 2b 2e
:2 2b 13 :2 1d 2f :2 39 45 49 5b
5f 60 :2 5b :2 2f :3 13 :2 19 1e 2a
6d 70 :2 2a 7d 80 :2 2a 84 87
:2 2a 91 94 9d a5 :2 9d b2 :2 94
:2 2a ba bd :2 2a c5 c8 :2 2a cd
d0 :2 2a dd e0 :2 2a :2 13 63 :2 10
13 :2 1d 2f :2 39 45 48 5a 5e
5f :2 5a :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a :2 13 62 :3 10 :2 1b 2f 38
44 :2 2f 48 56 :2 10 30 42 :3 d
15 1f :3 d :2 16 22 d 1c 32
3c 40 15 16 23 34 40 19
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 96 99 :2 2d a1
a4 :2 2d b0 b3 ba c3 c6 :2 b3
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:3 38 d 1e :2 d 1c :2 d 19 :2 d
16 :2 d 17 d 10 19 21 :2 10
24 26 :2 24 10 1a :2 23 2a 33
3b :2 2a 3f :2 48 :2 1a :2 10 1d 10
28 10 1d 10 :5 d 20 :2 d 19
25 36 44 52 5c 1b 23 2f
3b 47 53 1b 2a 36 40 48
51 59 1b 27 33 40 4b 56
1b 25 30 3c 48 4b 4e 54
5a :2 19 d 10 19 1b :2 19 13
:2 1d 2f :2 39 45 49 5b 5f 60
:2 5b :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a 7d 80 :2 2a 84 87 :2 2a 91
94 9d a5 :2 ae :2 9d c5 :2 94 :2 2a
cd d0 :2 2a d8 db :2 2a e0 e3
:2 2a ec ef :2 2a :2 13 63 :2 10 13
:2 1d 2f :2 39 45 48 5a 5e 5f
:2 5a :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a :2 13 62 :3 10 :2 1b 2f :2 38 4e
58 :2 10 d 1f 13 1c 1f :2 1c
13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
91 94 9d a5 :2 ae :2 9d c6 :2 94
:2 2a ce d1 :2 2a d9 dc :2 2a e1
e4 :2 2a f4 f7 :2 2a :2 13 63 :2 10
13 :2 1d 2f :2 39 45 48 5a 5e
5f :2 5a :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a :2 13 62 :3 10 :2 1b 2f :2 38
4f 18 :2 10 21 1f 1a 2f 43
13 22 2c 13 2c 4a 58 6c
13 2c 4a 58 6c 13 2c 4a
58 6c 13 2c 4a 58 6c 19
2d 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 99 9c :2 30
a4 a7 :2 30 b3 b6 bd c6 c9
:2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13
10 :7 d 38 :2 a 7 38 d 16
19 :2 16 1f 28 34 :2 1f 37 39
:2 37 :2 d :4 40 3f :2 d 14 11 1d
13 20 31 45 d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
93 96 :2 2a 9e a1 :2 2a ad b0
b7 c0 c3 :2 b0 :2 2a :2 13 63 :2 10
:2 d :4 19 :2 d a :4 61 38 :2 7 11
1f 2c 10 1d 2e 3c 4d :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 58 5c
5d :2 58 :2 2c :3 10 :2 16 1b 27 6a
6d :2 27 7a 7d :2 27 81 84 :2 27
90 93 :2 27 9b 9e :2 27 aa ad
b4 bd c0 :2 ad :2 27 :2 10 60 :2 d
:2 a :4 16 :2 a 7 :3 21 a 13 1c
:2 a 1f 21 :2 1f 14 20 2f 37
44 13 20 31 3e d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5b
5f 60 :2 5b :2 2f :3 13 :2 19 1e 2a
6d 70 :2 2a 7d 80 :2 2a 84 87
:2 2a 93 96 :2 2a 9e a1 :2 2a ad
b0 b7 c0 c3 :2 b0 :2 2a :2 13 63
:2 10 :2 d :4 19 :2 d a :4 23 :2 7 21
:3 4 12 4 :4 8 7 11 1d 2b
34 3b 48 51 6a 77 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
58 5c 5d :2 58 :2 2c :3 10 :2 16 1b
27 6a 6d :2 27 7a 7d :2 27 81
84 :2 27 90 93 :2 27 9b 9e :2 27
aa ad b4 bd c0 :2 ad :2 27 :2 10
60 :2 d :2 a :4 16 :2 a 7 :3 29 a
13 1f :2 a 22 24 :2 22 14 22
2f 13 20 31 49 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 93 96
:2 2a 9e a1 :2 2a ad b0 b7 c0
c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19
:2 d a :3 26 d 16 1f :2 d 22
24 :2 22 1c 37 44 10 1d 2e
3c 4d 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 62 63 :2 5e
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 96 99
:2 2d a1 a4 :2 2d b0 b3 ba c3
c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c
:2 10 d :3 26 1c 36 43 54 62
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 96 99 :2 2d a1
a4 :2 2d b0 b3 ba c3 c6 :2 b3
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:4 26 :2 a 26 :2 7 a 13 1c :2 a
1f 21 :2 1f a 18 :2 a 1d 2d
3b 50 5c 5f :2 1d a 14 23
33 39 41 48 5f 67 6e 86
90 a1 af 12 1e 2b 35 40
4c 58 6b 77 12 29 3d :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
93 96 :2 2a 9e a1 :2 2a ad b0
b7 c0 c3 :2 b0 :2 2a :2 13 63 :2 10
:2 d :4 19 :2 d a :3 23 e :2 17 22
20 :2 2b :2 20 d 10 19 25 :2 10
28 2a :2 28 1a 13 2d 13 2e
13 2e 13 2d 3f 13 19 26
37 45 13 1a 16 22 :3 20 16
:2 1f 2b 16 27 16 :2 1f 2b 16
:4 13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 65 66 :2 61
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
83 86 :2 30 8a 8d :2 30 99 9c
:2 30 a4 a7 :2 30 b3 b6 bd c6
c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f
:2 13 10 :4 2c 1a 13 2d 13 2e
13 2e 13 2d 3f 13 30 42
19 26 37 45 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 65
66 :2 61 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 83 86 :2 30 8a 8d :2 30
99 9c :2 30 a4 a7 :2 30 b3 b6
bd c6 c9 :2 b6 :2 30 :2 19 69 :2 16
:2 13 :4 1f :2 13 10 :7 d 11 18 28
2b :2 11 2e 30 :2 2e :2 10 20 :2 10
:2 19 25 3c 4a 58 2f 3a 46
52 2f 3d 50 :2 25 10 35 :2 d
3b :2 a :4 f e d 36 :2 41 48
12 :2 36 27 29 :2 27 35 :3 d 1b
d 2c :2 a 23 :2 7 29 :2 4 :4 8
:2 7 15 :2 7 1a 2a 38 4d 59
5c :2 1a 7 11 20 30 36 3e
45 5c 64 6b 83 8d 9e ac
f 1b 28 32 3d 49 55 68
74 f 26 3a :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5c 5d :2 58 :2 2c
:3 10 :2 16 1b 27 6a 6d :2 27 7a
7d :2 27 81 84 :2 27 90 93 :2 27
9b 9e :2 27 aa ad b4 bd c0
:2 ad :2 27 :2 10 60 :2 d :2 a :4 16 :2 a
7 :3 29 a 13 1f :2 a 22 24
:2 22 14 d 28 d 28 d 28
d 29 3b d 13 20 31 3f
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5f 60 :2 5b :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 93 96 :2 2a 9e
a1 :2 2a ad b0 b7 c0 c3 :2 b0
:2 2a :2 13 63 :2 10 :2 d :4 19 :2 d a
:4 26 14 d 28 d 28 d 28
d 29 3b d 2a 3c 13 20
31 3f d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 93 96
:2 2a 9e a1 :2 2a ad b0 b7 c0
c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19
:2 d a :7 7 b 12 22 25 :2 b
28 2a :2 28 a 34 3d 49 :2 34
4c 4e :2 4c 33 :3 a 1a :2 a :2 13
1f 36 44 52 2f 3a 46 52
2f 3d 50 :2 1f a 51 :2 7 29
:3 4 17 21 :2 17 4 7 :2 10 19
1b :2 19 7 :2 10 1c 7 1f :2 4
7 :2 11 23 :2 2d 39 3c 4e 52
53 :2 4e :2 23 :3 7 :2 d 12 1e 61
64 :2 1e 71 74 :2 1e 78 7b :2 1e
85 88 91 99 :2 a2 :2 91 ad :2 88
:2 1e b5 b8 :2 1e c0 c3 :2 1e c8
cb :2 1e df e2 :2 1e :2 7 56 :3 4
:2 f 21 :2 2a 34 49 :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
52 56 57 :2 52 :2 26 :3 a :2 10 15
21 64 67 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 5a :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4f 53 54 :2 4f :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 57 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
5217
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:a 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :7 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :7 21 :5 22 :5 23
:5 24 :5 25 :7 26 :7 27
:5 28 :5 29 :5 2a :7 2b
:7 2c :5 2d :5 2e :5 2f
:5 30 :7 31 :7 32 :7 33
:7 34 :7 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :6 5a :6 5b
:6 5c :6 5d :6 5e :6 5f
:6 60 :7 61 :7 62 :6 63
:6 64 :7 65 :6 66 :7 67
:7 68 :6 69 :6 6a :5 6b
:5 6c :6 6d :6 6e :6 6f
:6 70 :6 71 :6 72 :6 73
:6 74 :6 75 :6 76 :6 77
:7 78 :7 79 :7 7a :6 7b
:e 7c :6 7d :6 7e :5 7f
:5 80 :2 82 0 :2 82
:2 83 :3 84 83 :5 82
:2 86 0 :2 86 :2 87
:6 88 89 87 :5 86
:2 8b 0 :2 8b :c 8c
:12 8d :a 8e :a 8f :6 90
:8 91 :8 92 :23 93 :2 94
8c :5 8b :7 96 :b 98
:11 99 9a :2 99 :2 9a
:2 99 :2 9a :2 99 :2 9b
:2 99 :2 9b :2 99 :2 9b
:2 99 :2 9b :2 99 :2 9c
:2 99 :2 9c :2 99 :2 9c
:2 99 :2 9c :2 99 :2 9d
:2 99 :2 9d :2 99 :2 9d
:2 99 :2 9d :2 99 :2 9e
:2 99 :2 9e :2 99 :2 9e
:2 99 :2 9e :2 99 :2 9f
:2 99 :9 9f :2 99 :2 a0
:2 99 :9 a0 :2 99 :2 a1
:2 99 :9 a1 :2 99 :2 a2
:2 99 :9 a2 :2 99 :2 a3
:2 99 :9 a3 :2 99 :2 a4
:2 99 :9 a4 :2 99 :2 a5
:2 99 :9 a5 :2 99 :2 a6
:2 99 :9 a6 :2 99 :2 a7
:2 99 :9 a7 :2 99 :2 a8
:2 99 :2 a8 :2 99 :2 a8
:2 99 :2 a8 :2 99 :2 a8
:4 99 :3 98 :11 ab :b ac
:3 ab :3 b3 :3 b4 :3 b5
:3 b6 :3 b7 :3 b8 :d b9
:d ba :2 bb :2 ba :6 bb
:3 ba :3 bc bb :2 ba
:3 bf :3 c0 :3 c2 :3 c3
:3 c5 :3 c7 :3 c8 :5 ca
:4 cc :3 cd :5 ce cd
:5 d0 cf :3 cd :5 d3
:4 d6 :5 d7 d5 d9
:5 da :3 d9 :2 db :5 dd
:11 de :24 df :3 de :2 dc
:6 db d8 :3 97 :9 e4
:11 e5 :30 e6 :3 e5 :11 e8
:b e9 :3 e8 :a eb :3 e4
:6 ef :6 f0 :3 f1 ef
:5 f2 ee f4 :5 f5
:3 f4 :2 f6 :5 f8 :11 f9
:24 fa :3 f9 :2 f7 :6 f6
f3 :3 97 :a 100 :11 101
:30 102 :3 101 :11 104 :b 105
:3 104 :a 107 :3 100 :3 10a
:2 10c 10d :2 10e 10c
:5 10f 10b 111 :5 112
:3 111 :2 113 :5 115 :11 116
:24 117 :3 116 :2 114 :6 113
110 :3 97 :9 11c :11 11d
:30 11e :3 11d :11 120 :b 121
:3 120 :a 123 :3 11c :12 127
:7 128 :c 129 127 :5 12a
126 12c :5 12d :3 12c
:2 12e :5 130 :11 131 :24 132
:3 131 :2 12f :6 12e 12b
:3 97 :a 137 :11 138 :30 139
:3 138 :11 13b :b 13c :3 13b
:a 13e :3 137 :8 142 :5 143
141 145 :5 146 :3 145
:2 147 :5 149 :11 14a :24 14b
:3 14a :2 148 :6 147 144
:3 97 :a 150 :11 151 :30 152
:3 151 :11 154 :b 155 :3 154
:a 157 :3 150 :6 15b :5 15c
15a 15e :5 15f :3 15e
:2 160 :5 162 :11 163 :24 164
:3 163 :2 161 :6 160 15d
:3 97 :b 169 :3 16a :3 169
:a 16d :11 16e :30 16f :3 16e
:11 171 :b 172 :3 171 :a 174
:3 16d :3 177 :b 184 :b 185
:b 186 :3 189 18a :7 18b
189 :5 18c 188 18e
:5 18f :3 18e :2 190 :5 192
:11 193 :24 194 :3 193 :2 191
:6 190 18d :3 97 :3 19a
19b :7 19c 19a :5 19d
199 19f :5 1a0 :3 19f
:2 1a1 :5 1a3 :11 1a4 :24 1a5
:3 1a4 :2 1a2 :6 1a1 19e
:3 97 :5 1aa :9 1ac :4 1af
:6 1b0 1af :5 1b1 1ae
1b3 :5 1b4 :3 1b3 :2 1b5
:5 1b7 :11 1b8 :24 1b9 :3 1b8
:2 1b6 :6 1b5 1b2 :3 1ac
:c 1be :3 1c0 :4 1c2 :6 1c3
1c2 :5 1c4 1c1 1c6
:5 1c7 :3 1c6 :2 1c8 :5 1ca
:11 1cb :24 1cc :3 1cb :2 1c9
:6 1c8 1c5 :3 1be :9 1d1
:11 1d2 :30 1d3 :3 1d2 :11 1d5
:b 1d6 :3 1d5 :7 1d8 1d9
:2 1d8 :3 1d1 :3 1be :3 1ac
1dd 1aa :16 1dd :2 1de
:2 1dd :4 1de :5 1dd :3 1e0
:4 1e2 :5 1e3 1e4 1e2
:5 1e5 1e1 1e7 :5 1e8
:3 1e7 :2 1e9 :5 1eb :11 1ec
:24 1ed :3 1ec :2 1ea :6 1e9
1e6 :3 1de :9 1f2 :11 1f3
:30 1f4 :3 1f3 :11 1f6 :b 1f7
:3 1f6 :7 1f9 1fa :2 1f9
:3 1f2 1de :3 1aa :3 1fe
:3 1ff :3 200 :3 201 :3 202
:3 203 :5 20b :4 20d :3 20e
:5 20f 20e :5 211 210
:3 20e :a 214 :3 215 214
:3 217 216 :3 214 :4 21b
:5 21c 21a 21e :5 21f
:3 21e :2 220 :5 222 :11 223
:24 224 :3 223 :2 221 :6 220
21d :3 97 :9 229 :9 22a
:3 22b :3 22a :3 229 :4 230
231 :2 232 :2 233 :2 234
230 :5 235 22f 237
:5 238 :3 237 :2 239 :5 23b
:11 23c :24 23d :3 23c :2 23a
:6 239 236 :3 97 :18 242
:3 243 :5 244 :4 247 248
:2 249 24a :2 24b 247
:5 24c 246 24e :5 24f
:3 24e :2 250 :5 252 :11 253
:24 254 :3 253 :2 251 :6 250
24d :3 242 :a 259 :f 25a
259 :b 25c 25d :3 25c
:5 25e 25b :3 259 :3 260
:3 261 :6 263 :3 264 :3 263
:a 266 :5 268 :6 269 :2 26a
:4 26b :6 26c :2 26d 268
:6 26e :5 26f 26e :5 271
270 :3 26e 267 274
:5 275 :3 274 :2 276 :5 278
:11 279 :24 27a :3 279 :2 277
:6 276 273 :3 242 :6 280
:5 281 27f 283 :5 284
:3 283 :2 285 :5 287 :11 288
:24 289 :3 288 :2 286 :6 285
282 :3 242 :b 28e :3 28f
28e :4 292 :4 293 :4 294
292 :5 295 291 297
:5 298 :3 297 :2 299 :5 29b
:11 29c :24 29d :3 29c :2 29a
:6 299 296 :4 290 :3 28e
:9 2a3 :6 2a6 :4 2a7 2a6
:6 2a8 :5 2a9 2a8 :5 2ab
2aa :3 2a8 2a5 2ae
:5 2af :3 2ae :2 2b0 :5 2b2
:11 2b3 :24 2b4 :3 2b3 :2 2b1
:6 2b0 2ad :3 2a3 :2 2bb
:4 2bd :5 2c0 :2 2c1 :4 2c4
2bb :6 2c5 :5 2c6 2c5
:5 2c8 2c7 :3 2c5 2ba
2cb :5 2cc :3 2cb :2 2cd
:5 2cf :11 2d0 :24 2d1 :3 2d0
:2 2ce :6 2cd 2ca :4 2a3
:2 2d8 :4 2da :5 2dd :2 2de
:4 2e1 2d8 :6 2e2 :5 2e3
2e2 :5 2e5 2e4 :3 2e2
2d7 2e8 :5 2e9 :3 2e8
:2 2ea :5 2ec :11 2ed :24 2ee
:3 2ed :2 2eb :6 2ea 2e7
:4 2d5 :3 2a3 2f3 242
:a 2f3 :3 2f5 :2 2f7 2f8
:3 2f9 2f7 :5 2fa 2f6
2fc :5 2fd :3 2fc :2 2fe
:5 300 :11 301 :24 302 :3 301
:2 2ff :6 2fe 2fb :3 2f3
:a 307 :2 309 30a :3 30b
309 :5 30c 308 30e
:5 30f :3 30e :2 310 :5 312
:11 313 :24 314 :3 313 :2 311
:6 310 30d :3 307 :a 318
:3 319 :3 318 :3 307 :c 31d
:b 31e :b 31f 320 :3 31f
:3 322 :5 323 :2 324 322
:6 325 :5 326 325 :5 328
327 :3 325 321 32b
:5 32c :3 32b :2 32d :5 32f
:11 330 :24 331 :3 330 :2 32e
:6 32d 32a :3 31e :6 336
337 31e :12 337 :3 339
:6 33a :2 33b 339 :6 33c
:5 33d 33c :5 33f 33e
:3 33c 338 342 :5 343
:3 342 :2 344 :5 346 :11 347
:24 348 :3 347 :2 345 :6 344
341 :3 337 :6 34d 34e
337 31e :12 34e :3 350
:6 351 :2 352 350 :6 353
:5 354 353 :5 356 355
:3 353 34f 359 :5 35a
:3 359 :2 35b :5 35d :11 35e
:24 35f :3 35e :2 35c :6 35b
358 :3 34e :6 364 34e
:3 31e :3 31d 2f3 :3 242
:3 36a :5 36b 36c :b 36d
:2 36e 36a :5 36f 369
371 :5 372 :3 371 :2 373
:5 375 :11 376 :24 377 :3 376
:2 374 :6 373 370 :3 97
:a 37c :3 37d :3 37c :3 380
:3 381 :3 382 :5 384 :16 386
:7 387 :5 388 :3 387 :9 38a
:f 38b :f 38c :3 38a :9 38f
:f 390 :f 391 :3 38f :3 386
:3 395 :3 396 :3 398 399
:2 39a 398 :5 39b 397
39d :5 39e :3 39d :2 39f
:5 3a1 :11 3a2 :24 3a3 :3 3a2
:2 3a0 :6 39f 39c :3 97
:3 3a9 :4 3ab 3ac :4 3ad
:3 3ae 3ab :5 3af 3aa
3b1 :5 3b2 :3 3b1 :2 3b3
:5 3b5 :11 3b6 :24 3b7 :3 3b6
:2 3b4 :6 3b3 3b0 :3 97
:4 3bd :3 3be 3bd :5 3bf
3bc 3c1 :5 3c2 :3 3c1
:2 3c3 :5 3c5 :11 3c6 :24 3c7
:3 3c6 :2 3c4 :6 3c3 3c0
:3 97 :e 3cc :5 3ce :3 3cf
:a 3d1 :8 3d2 :6 3d3 :8 3d4
3d5 :2 3d6 3d1 :5 3d7
3d0 3d9 :5 3da :3 3d9
:2 3db :5 3dd :11 3de :24 3df
:3 3de :2 3dc :6 3db 3d8
:3 3ce :12 3e3 :6 3e4 :7 3e5
:4 3e6 :3 3e7 :3 3e5 :3 3e3
:3 3ea :9 3eb :14 3ec :2 3ed
:6 3ec :f 3ee :11 3ef :30 3f0
:3 3ef :11 3f2 :b 3f3 :3 3f2
:a 3f5 3ee :3 3f7 :9 3f9
:3 3fa :3 3f9 3f6 :3 3ee
3ed :2 3ec :3 3ff :3 400
:3 401 :3 402 :3 404 :3 406
:3 407 :3 408 :3 409 :3 3eb
:a 40c :3 40e :3 40f :5 411
:a 412 :6 413 :7 414 :4 415
:3 416 :3 414 :3 412 :7 41a
:6 41b :5 41c :6 41d 41e
:2 41f 41a :5 420 419
422 :5 423 :3 422 :2 424
:5 426 :11 427 :24 428 :3 427
:2 425 :6 424 421 :3 411
:a 42d :14 42f :2 430 :6 42f
:11 432 :30 433 :3 432 :11 435
:b 436 :3 435 :a 438 430
:2 42f :12 43b :9 43c :3 43e
:3 43f :9 441 :9 442 :3 444
445 :2 446 :4 447 444
:5 448 443 44a :5 44b
:3 44a :2 44c :5 44e :11 44f
:24 450 :3 44f :2 44d :6 44c
449 :4 442 :3 456 457
:4 458 456 :5 459 455
45b :5 45c :3 45b :2 45d
:5 45f :11 460 :24 461 :3 460
:2 45e :6 45d 45a :4 454
:3 442 :3 441 :9 468 :3 46a
:4 46b 46a :6 46c :5 46d
46c :5 46f 46e :3 46c
469 472 :5 473 :3 472
:2 474 :5 476 :11 477 :24 478
:3 477 :2 475 :6 474 471
:4 468 :6 47e :6 47f :5 480
47f :5 482 481 :3 47f
47d 485 :5 486 :3 485
:2 487 :5 489 :11 48a :24 48b
:3 48a :2 488 :6 487 484
:3 47c :4 491 :6 492 :5 493
492 :5 495 494 :3 492
490 498 :5 499 :3 498
:2 49a :5 49c :11 49d :24 49e
:3 49d :2 49b :6 49a 497
:3 47c :4 4a4 :6 4a5 :5 4a6
4a5 :5 4a8 4a7 :3 4a5
4a3 4ab :5 4ac :3 4ab
:2 4ad :5 4af :11 4b0 :24 4b1
:3 4b0 :2 4ae :6 4ad 4aa
:3 47c :6 4b7 :6 4b8 :5 4b9
4b8 :5 4bb 4ba :3 4b8
4b6 4be :5 4bf :3 4be
:2 4c0 :5 4c2 :11 4c3 :24 4c4
:3 4c3 :2 4c1 :6 4c0 4bd
:4 47c :3 468 :3 43c :3 42d
4cf 411 :17 4cf :11 4d0
:30 4d1 :3 4d0 :11 4d3 :b 4d4
:3 4d3 :7 4d6 4d7 :2 4d6
4cf :3 411 :5 4da :3 4db
:16 4dc :9 4dd :3 4df :3 4e0
:2 4e1 :2 4e2 :2 4e3 :2 4e4
:4 4e5 :4 4e6 :6 4e7 :2 4e8
4df :6 4e9 :5 4ea 4e9
:5 4ec 4eb :3 4e9 4de
4ef :5 4f0 :3 4ef :2 4f1
:5 4f3 :11 4f4 :24 4f5 :3 4f4
:2 4f2 :6 4f1 4ee :4 4dd
:3 4fb :3 4fc :2 4fd :2 4fe
:2 4ff :2 500 :4 501 :4 502
:4 503 :6 504 :2 505 4fb
:6 506 :5 507 506 :5 509
508 :3 506 4fa 50c
:5 50d :3 50c :2 50e :5 510
:11 511 :24 512 :3 511 :2 50f
:6 50e 50b :4 4f9 :3 4dd
517 4dc :9 517 :3 519
:3 51a :2 51b :2 51c :4 51d
:4 51e :6 51f :2 520 519
:6 521 :5 522 521 :5 524
523 :3 521 518 527
:5 528 :3 527 :2 529 :5 52b
:11 52c :24 52d :3 52c :2 52a
:6 529 526 :3 517 531
517 4dc :9 531 :9 532
:3 534 :3 535 :2 536 :2 537
:4 538 :6 539 :2 53a 534
:6 53b :5 53c 53b :5 53e
53d :3 53b 533 541
:5 542 :3 541 :2 543 :5 545
:11 546 :24 547 :3 546 :2 544
:6 543 540 :4 532 :3 54d
:3 54e :2 54f :2 550 :4 551
:4 552 :6 553 :2 554 54d
:6 555 :5 556 555 :5 558
557 :3 555 54c 55b
:5 55c :3 55b :2 55d :5 55f
:11 560 :24 561 :3 560 :2 55e
:6 55d 55a :4 54b :3 532
531 4dc :3 568 :4 569
:3 56a :2 56b 568 :6 56c
:5 56d 56c :5 56f 56e
:3 56c 567 572 :5 573
:3 572 :2 574 :5 576 :11 577
:24 578 :3 577 :2 575 :6 574
571 :4 566 :3 4dc :6 57f
:6 580 :5 581 580 :5 583
582 :3 580 57e 586
:5 587 :3 586 :2 588 :5 58a
:11 58b :24 58c :3 58b :2 589
:6 588 585 :3 4da :4 592
:6 593 :5 594 593 :5 596
595 :3 593 591 599
:5 59a :3 599 :2 59b :5 59d
:11 59e :24 59f :3 59e :2 59c
:6 59b 598 :3 4da :6 5a5
:6 5a6 :5 5a7 5a6 :5 5a9
5a8 :3 5a6 5a4 5ac
:5 5ad :3 5ac :2 5ae :5 5b0
:11 5b1 :24 5b2 :3 5b1 :2 5af
:6 5ae 5ab :6 4da :5 5b8
:9 5b9 :5 5ba 5b9 :f 5bc
5bb :3 5b9 :3 5bf :9 5c1
:d 5c2 :7 5c3 :3 5c2 :3 5c6
:3 5c7 :b 5c8 :3 5c9 5c8
:3 5cb 5ca :3 5c8 :9 5ce
:3 5cf :3 5ce :e 5d2 :b 5d3
:2 5d4 :2 5d3 :a 5d4 :8 5d5
:3 5d2 :b 5d7 :11 5d8 :20 5d9
:3 5d8 :11 5db :b 5dc :3 5db
:9 5de 5df 5d7 :9 5df
:11 5e0 :2e 5e1 :3 5e0 :11 5e3
:b 5e4 :3 5e3 :c 5e6 5df
:3 5d7 :3 5ea :7 5eb :6 5ec
:7 5ed :6 5ee :9 5ef :3 5eb
:5 5f1 :11 5f2 :30 5f3 :3 5f2
:11 5f5 :b 5f6 :3 5f5 :a 5f8
5f9 5f1 :5 5f9 :11 5fa
:30 5fb :3 5fa :11 5fd :b 5fe
:3 5fd :7 600 601 :2 600
5f9 5f1 :3 603 :a 604
:5 605 :3 604 602 :3 5f1
:3 5c1 :3 5b8 :5 609 :3 60b
60c :4 60d 60b :5 60e
60a 610 :5 611 :3 610
:2 612 :5 614 :11 615 :24 616
:3 615 :2 613 :6 612 60f
:6 40c :3 3ce :3 61d :3 3cc
:c 620 :3 621 :3 622 :6 626
:5 627 625 629 :5 62a
:3 629 :2 62b :5 62d :11 62e
:24 62f :3 62e :2 62c :6 62b
628 :3 97 :3 634 :3 635
:3 636 :3 644 :5 648 64a
:7 64b :5 64c :5 64d :5 64e
:3 64b :3 64f :5 650 64f
:5 652 651 :3 64f :a 655
:2 656 :3 655 :3 658 :9 65a
:7 65b :4 65e :6 65f :5 660
65f :5 662 661 :3 65f
65d 665 :5 666 :3 665
:2 667 :5 669 :11 66a :24 66b
:3 66a :2 668 :6 667 664
:3 65a :4 671 :6 672 :5 673
672 :5 675 674 :3 672
670 678 :5 679 :3 678
:2 67a :5 67c :11 67d :24 67e
:3 67d :2 67b :6 67a 677
:3 65a :4 684 :6 685 :5 686
685 :5 688 687 :3 685
683 68b :5 68c :3 68b
:2 68d :5 68f :11 690 :24 691
:3 690 :2 68e :6 68d 68a
:3 65a :6 697 :6 698 :5 699
698 :5 69b 69a :3 698
696 69e :5 69f :3 69e
:2 6a0 :5 6a2 :11 6a3 :24 6a4
:3 6a3 :2 6a1 :6 6a0 69d
:3 65a :4 6aa :6 6ab :5 6ac
6ab :5 6ae 6ad :3 6ab
6a9 6b1 :5 6b2 :3 6b1
:2 6b3 :5 6b5 :11 6b6 :24 6b7
:3 6b6 :2 6b4 :6 6b3 6b0
:3 65a :4 6bd :6 6be :5 6bf
6be :5 6c1 6c0 :3 6be
6bc 6c4 :5 6c5 :3 6c4
:2 6c6 :5 6c8 :11 6c9 :24 6ca
:3 6c9 :2 6c7 :6 6c6 6c3
:4 65a :9 6cf :3 6d0 :3 6cf
:3 6d3 :2 6d4 :2 6d5 :2 6d6
6d3 :6 6d7 :5 6d8 6d7
:5 6da 6d9 :3 6d7 6d2
6dd :5 6de :3 6dd :2 6df
:5 6e1 :11 6e2 :24 6e3 :3 6e2
:2 6e0 :6 6df 6dc :3 6ce
:6 6e8 :9 6e9 :3 6ea :2 6eb
:3 6e9 :4 6ee 6ef :6 6f0
6f1 6ee :5 6f2 6ed
6f4 :5 6f5 :3 6f4 :2 6f6
:5 6f8 :11 6f9 :24 6fa :3 6f9
:2 6f7 :6 6f6 6f3 :3 6ce
:a 6ff :3 700 :6 704 705
:5 706 704 :5 707 703
709 :5 70a :3 709 :2 70b
:5 70d :11 70e :24 70f :3 70e
:2 70c :6 70b 708 :3 6ff
:a 714 :12 715 :3 716 718
:2 719 :2 71a 71b :2 71c
718 :6 71d :5 71e 71d
:5 720 71f :3 71d 717
723 :5 724 :3 723 :2 725
:5 727 :11 728 :24 729 :3 728
:2 726 :6 725 722 :3 715
72d 715 :b 72d :b 72e
72f :3 72e 732 :3 733
:2 734 :2 735 :2 736 737
:2 738 732 :6 739 :5 73a
739 :5 73c 73b :3 739
731 73f :5 740 :3 73f
:2 741 :5 743 :11 744 :24 745
:3 744 :2 742 :6 741 73e
:4 72d 715 74b :6 74c
:2 74d :2 74e :2 74f 750
:2 751 74b :6 752 :5 753
752 :5 755 754 :3 752
74a 758 :5 759 :3 758
:2 75a :5 75c :11 75d :24 75e
:3 75d :2 75b :6 75a 757
:4 749 :3 715 :16 764 :4 766
:6 767 :5 768 767 :5 76a
769 :3 767 765 76d
:5 76e :3 76d :2 76f :5 771
:11 772 :24 773 :3 772 :2 770
:6 76f 76c :6 764 714
:8 77a :6 77b :9 77c :4 77d
:7 77e 77a :5 77f 779
781 :5 782 :3 781 :2 783
:5 785 :11 786 :24 787 :3 786
:2 784 :6 783 780 :3 778
:12 78c :b 78d 78e :3 78d
:4 791 :6 792 :5 793 792
:5 795 794 :3 792 790
798 :5 799 :3 798 :2 79a
:5 79c :11 79d :24 79e :3 79d
:2 79b :6 79a 797 :3 78c
:4 7a4 :5 7a5 :2 7a6 7a4
:6 7a7 :5 7a8 7a7 :5 7aa
7a9 :3 7a7 7a3 7ad
:5 7ae :3 7ad :2 7af :5 7b1
:11 7b2 :24 7b3 :3 7b2 :2 7b0
:6 7af 7ac :3 78c :6 7b9
:2 7ba 7b9 :6 7bb :5 7bc
7bb :5 7be 7bd :3 7bb
7b8 7c1 :5 7c2 :3 7c1
:2 7c3 :5 7c5 :11 7c6 :24 7c7
:3 7c6 :2 7c4 :6 7c3 7c0
:4 78c :6 7cd :2 7ce 7cd
:6 7cf :5 7d0 7cf :5 7d2
7d1 :3 7cf 7cc 7d5
:5 7d6 :3 7d5 :2 7d7 :5 7d9
:11 7da :24 7db :3 7da :2 7d8
:6 7d7 7d4 :3 7cb :4 7e1
:2 7e2 7e1 :6 7e3 :5 7e4
7e3 :5 7e6 7e5 :3 7e3
7e0 7e9 :5 7ea :3 7e9
:2 7eb :5 7ed :11 7ee :24 7ef
:3 7ee :2 7ec :6 7eb 7e8
:4 7cb :3 78c 778 :3 714
:6 7f7 :6 7f8 :5 7f9 7f8
:5 7fb 7fa :3 7f8 7f6
7fe :5 7ff :3 7fe :2 800
:5 802 :11 803 :24 804 :3 803
:2 801 :6 800 7fd :4 6ff
:3 80a :4 80e :6 80f :5 810
80f :5 812 811 :3 80f
80d 815 :5 816 :3 815
:2 817 :5 819 :11 81a :24 81b
:3 81a :2 818 :6 817 814
:3 808 :4 821 :6 822 :5 823
822 :5 825 824 :3 822
820 828 :5 829 :3 828
:2 82a :5 82c :11 82d :24 82e
:3 82d :2 82b :6 82a 827
:3 808 :6 833 :6 834 :5 835
834 :5 837 836 :3 834
832 83a :5 83b :3 83a
:2 83c :5 83e :11 83f :24 840
:3 83f :2 83d :6 83c 839
:3 808 :a 845 :3 847 :3 845
:3 84a 808 :3 6ff :9 84d
:12 84e :3 850 :4 851 850
:5 852 84f 854 :5 855
:3 854 :2 856 :5 858 :11 859
:24 85a :3 859 :2 857 :6 856
853 :3 84e :16 85f :6 861
:6 862 :5 863 862 :5 865
864 :3 862 860 868
:5 869 :3 868 :2 86a :5 86c
:11 86d :24 86e :3 86d :2 86b
:6 86a 867 :3 85f 872
85f :16 872 :4 874 :5 875
873 877 :5 878 :3 877
:2 879 :5 87b :11 87c :24 87d
:3 87c :2 87a :6 879 876
:3 872 :11 882 :30 883 :3 882
:11 885 :b 886 :3 885 :7 888
889 :2 888 872 :3 85f
:3 84e :c 88d :2 88e :2 88d
:6 88e :2 88d :5 890 :5 891
:14 893 895 :4 896 :b 897
895 :6 898 :5 899 898
:5 89b 89a :3 898 894
89e :5 89f :3 89e :2 8a0
:5 8a2 :11 8a3 :24 8a4 :3 8a3
:2 8a1 :6 8a0 89d :4 893
:3 8aa :4 8ab :b 8ac :6 8ad
:4 8ae 8aa :6 8af :5 8b0
8af :5 8b2 8b1 :3 8af
8a9 8b5 :5 8b6 :3 8b5
:2 8b7 :5 8b9 :11 8ba :24 8bb
:3 8ba :2 8b8 :6 8b7 8b4
:4 8a8 :3 893 :a 8c1 :3 8c2
:6 8c4 8c5 8c4 :5 8c6
8c3 8c8 :5 8c9 :3 8c8
:2 8ca :5 8cc :11 8cd :24 8ce
:3 8cd :2 8cb :6 8ca 8c7
:3 8c1 :9 8d3 :2 8d4 8d3
8d7 :4 8d8 8d7 :6 8d9
:5 8da 8d9 :5 8dc 8db
:3 8d9 8d6 8df :5 8e0
:3 8df :2 8e1 :5 8e3 :11 8e4
:24 8e5 :3 8e4 :2 8e2 :6 8e1
8de :3 8d5 :1d 8ea :4 8ed
8ee :4 8ef 8ed :5 8f0
8ec 8f2 :5 8f3 :3 8f2
:2 8f4 :5 8f6 :11 8f7 :24 8f8
:3 8f7 :2 8f5 :6 8f4 8f1
:3 8d5 :d 8fd :b 8fe :3 8fd
902 903 904 905
906 907 908 909
90a 90b 90c 90e
90f 910 911 913
914 :3 915 917 918
902 :6 919 :5 91a 919
:5 91c 91b :3 919 901
91f :5 920 :3 91f :2 921
:5 923 :11 924 :24 925 :3 924
:2 922 :6 921 91e :4 8d5
:3 8d3 :4 92c :3 92d :4 92e
:4 92f :4 930 :4 931 :6 932
:2 933 92c :6 934 :5 935
934 :5 937 936 :3 934
92b 93a :5 93b :3 93a
:2 93c :5 93e :11 93f :24 940
:3 93f :2 93d :6 93c 939
:3 8c1 :16 945 :2 946 :5 945
:f 948 :6 949 :2 94a :2 949
:5 94a :3 949 8c1 :2 94c
94b :3 8c1 88e :3 94f
:5 951 :9 953 :3 954 :15 955
:2 956 :2 955 :4 956 :2 955
:3 957 :7 958 956 :2 955
95c :9 95d :2 95e 95c
:6 95f :5 960 95f :5 962
961 :3 95f 95b 965
:5 966 :3 965 :2 967 :5 969
:11 96a :24 96b :3 96a :2 968
:6 967 964 :4 953 :3 970
:3 971 :3 972 :3 973 :3 975
:3 977 :3 978 :3 979 :3 97a
:12 97c :2 97d :2 97c :9 97d
:2 97e :2 97d :8 97e :5 97c
:9 97f 981 :4 982 :2 983
:4 984 :4 985 :4 986 :4 987
:4 988 :2 989 :6 98a :2 98b
981 :6 98c :5 98d 98c
:5 98f 98e :3 98c 980
992 :5 993 :3 992 :2 994
:5 996 :11 997 :24 998 :3 997
:2 995 :6 994 991 :4 97f
99e :4 99f :2 9a0 :4 9a1
:4 9a2 :4 9a3 :4 9a4 :4 9a5
:2 9a6 :2 9a7 :6 9a8 :2 9a9
99e :6 9aa :5 9ab 9aa
:5 9ad 9ac :3 9aa 99d
9b0 :5 9b1 :3 9b0 :2 9b2
:5 9b4 :11 9b5 :24 9b6 :3 9b5
:2 9b3 :6 9b2 9af :4 99c
:3 97f 97e 9bd :4 9be
:2 9bf :4 9c0 :4 9c1 :4 9c2
:4 9c3 :8 9c4 :2 9c5 9bd
:6 9c6 :5 9c7 9c6 :5 9c9
9c8 :3 9c6 9bc 9cc
:5 9cd :3 9cc :2 9ce :5 9d0
:11 9d1 :24 9d2 :3 9d1 :2 9cf
:6 9ce 9cb :4 9bb :3 97c
:16 9d8 :3 9d9 9da 9d8
:9 9da :7 9db 9da :3 9d8
96f :3 953 :e 9df :b 9e0
:2 9e1 :2 9e0 :a 9e1 :8 9e2
:3 9df :b 9e4 :4 9e6 :5 9e7
9e5 9e9 :5 9ea :3 9e9
:2 9eb :5 9ed :11 9ee :24 9ef
:3 9ee :2 9ec :6 9eb 9e8
:3 9e4 :11 9f4 :20 9f5 :3 9f4
:11 9f7 :b 9f8 :3 9f7 :9 9fa
9fb 9e4 :9 9fb :4 9fd
:5 9fe 9fc a00 :5 a01
:3 a00 :2 a02 :5 a04 :11 a05
:24 a06 :3 a05 :2 a03 :6 a02
9ff :3 9fb :11 a0b :2e a0c
:3 a0b :11 a0e :b a0f :3 a0e
:c a11 9fb :3 9e4 951
:15 a17 :2 a18 :2 a17 :4 a18
:2 a17 :3 a19 :7 a1a a18
:2 a17 :1a a1d :7 a1e a1d
:12 a20 a1f :3 a1d :9 a23
:b a24 a23 :11 a26 a25
:3 a23 :9 a29 a2b :9 a2c
:2 a2d a2b :6 a2e :5 a2f
a2e :5 a31 a30 :3 a2e
a2a a34 :5 a35 :3 a34
:2 a36 :5 a38 :11 a39 :24 a3a
:3 a39 :2 a37 :6 a36 a33
:4 a29 a40 :4 a41 :2 a42
:4 a43 :4 a44 :4 a45 :4 a46
:8 a47 :2 a48 a40 :6 a49
:5 a4a a49 :5 a4c a4b
:3 a49 a3f a4f :5 a50
:3 a4f :2 a51 :5 a53 :11 a54
:24 a55 :3 a54 :2 a52 :6 a51
a4e :4 a3e :3 a29 a13
:3 951 :3 a5c :b a5e :3 a5f
a5e :3 a61 a60 :3 a5e
:9 a64 :5 a65 a64 :f a67
a66 :3 a64 :3 a6a :9 a6e
:9 a6f :1c a70 :d a71 :7 a72
:1b a73 :3 a71 a75 a6f
:d a75 :7 a76 a75 :3 a6f
:3 a6e :7 a7b :6 a7c :7 a7d
:6 a7e :9 a7f :3 a7b :5 a83
:4 a85 :5 a86 a84 a88
:5 a89 :3 a88 :2 a8a :5 a8c
:11 a8d :24 a8e :3 a8d :2 a8b
:6 a8a a87 :3 a83 :11 a93
:30 a94 :3 a93 :11 a96 :b a97
:3 a96 :a a99 a9a a83
:5 a9a :4 a9c :5 a9d a9b
a9f :5 aa0 :3 a9f :2 aa1
:5 aa3 :11 aa4 :24 aa5 :3 aa4
:2 aa2 :6 aa1 a9e :3 a9a
:11 aaa :30 aab :3 aaa :11 aad
:b aae :3 aad :7 ab0 ab1
:2 ab0 a9a :3 a83 94e
:3 88d :8 abb :6 abc :5 abd
abc :5 abf abe :3 abc
aba ac2 :5 ac3 :3 ac2
:2 ac4 :5 ac6 :11 ac7 :24 ac8
:3 ac7 :2 ac5 :6 ac4 ac1
:3 84d acf :b ad0 :c ad1
acf :6 ad2 :5 ad3 ad2
:5 ad5 ad4 :3 ad2 ace
ad8 :5 ad9 :3 ad8 :2 ada
:5 adc :11 add :24 ade :3 add
:2 adb :6 ada ad7 :3 84d
ae5 :7 ae6 :3 ae7 ae5
:6 ae8 :5 ae9 ae8 :5 aeb
aea :3 ae8 ae4 aee
:5 aef :3 aee :2 af0 :5 af2
:11 af3 :24 af4 :3 af3 :2 af1
:6 af0 aed :3 84d afa
:7 afb :3 afc afa :6 afd
:5 afe afd :5 b00 aff
:3 afd af9 b03 :5 b04
:3 b03 :2 b05 :5 b07 :11 b08
:24 b09 :3 b08 :2 b06 :6 b05
b02 :3 84d :b b0e :f b0f
:3 b11 :8 b12 :3 b14 :8 b15
:3 b18 :4 b19 b18 :6 b1a
:5 b1b b1a :5 b1d b1c
:3 b1a b17 b20 :5 b21
:3 b20 :2 b22 :5 b24 :11 b25
:24 b26 :3 b25 :2 b23 :6 b22
b1f :3 84d :16 b2c :3 b2e
:2 b2f :2 b30 :2 b31 :2 b32
:4 b33 :2 b34 b2e :6 b35
:5 b36 b35 :5 b38 b37
:3 b35 b2d b3b :5 b3c
:3 b3b :2 b3d :5 b3f :11 b40
:24 b41 :3 b40 :2 b3e :6 b3d
b3a :3 b2c b45 b2c
:9 b45 :3 b47 :2 b48 :2 b49
:4 b4a :2 b4b b47 :6 b4c
:5 b4d b4c :5 b4f b4e
:3 b4c b46 b52 :5 b53
:3 b52 :2 b54 :5 b56 :11 b57
:24 b58 :3 b57 :2 b55 :6 b54
b51 :3 b45 :7 b5d b5e
b45 b2c :9 b5e :3 b60
:2 b61 :2 b62 :4 b63 :2 b64
b60 :6 b65 :5 b66 b65
:5 b68 b67 :3 b65 b5f
b6b :5 b6c :3 b6b :2 b6d
:5 b6f :11 b70 :24 b71 :3 b70
:2 b6e :6 b6d b6a :3 b5e
:7 b76 b5e b2c :3 b79
:4 b7a :2 b7b b79 :6 b7c
:5 b7d b7c :5 b7f b7e
:3 b7c b78 b82 :5 b83
:3 b82 :2 b84 :5 b86 :11 b87
:24 b88 :3 b87 :2 b85 :6 b84
b81 :3 b77 :7 b8d :7 b8e
b77 :3 b2c :3 84d 6ce
:3 65a :a b93 b94 b95
:3 64a b96 97 :4 b9a
:5 b9b b99 b9d :5 b9e
:3 b9d :2 b9f :5 ba1 :11 ba2
:24 ba3 :3 ba2 :2 ba0 :6 b9f
b9c :3 97 :3 ba9 :9 baa
:3 bab :d bae :f baf :16 bb1
:6 bb2 :2 bb1 :3 bb3 :3 bb4
:3 bb5 :3 bb7 :3 bb9 :3 bba
:3 bbb :3 bbc :16 bbe :3 bbf
bc0 bbe :9 bc0 :7 bc1
bc0 :3 bbe :e bc4 :b bc5
:2 bc6 :2 bc5 :a bc6 :8 bc7
:3 bc4 :b bc9 :11 bca :20 bcb
:3 bca :11 bcd :b bce :3 bcd
:9 bd0 bd1 bc9 :9 bd1
:11 bd2 :2e bd3 :3 bd2 :11 bd5
:b bd6 :3 bd5 :c bd8 bd1
:3 bc9 :5 bdc :5 bdd :4 be0
be1 :4 be2 be3 be0
:6 be4 :5 be5 be4 :5 be7
be6 :3 be4 bdf bea
:5 beb :3 bea :2 bec :5 bee
:11 bef :24 bf0 :3 bef :2 bed
:6 bec be9 :3 bb2 :3 bf5
:3 bf6 :3 bf7 :3 bf8 :3 bf9
:9 bfb :f bfc :3 bfd bfb
:3 bff bfe :3 bfb :3 c03
:7 c04 :6 c05 :7 c06 :6 c07
:9 c08 :3 c04 :5 c0c :11 c0d
:30 c0e :3 c0d :11 c10 :b c11
:3 c10 :a c13 c14 c0c
:5 c14 :11 c15 :30 c16 :3 c15
:11 c18 :b c19 :3 c18 :7 c1b
c1c :2 c1b c14 c0c
:3 c1f :3 c20 :5 c21 :5 c22
:5 c23 :5 c24 :2 c25 c1f
:6 c26 :5 c27 c26 :5 c29
c28 :3 c26 c1e c2c
:5 c2d :3 c2c :2 c2e :5 c30
:11 c31 :24 c32 :3 c31 :2 c2f
:6 c2e c2b :4 c1d :3 c0c
bb2 :2 bb1 c38 bae
:17 c38 c3a :2 c3b :4 c3c
c3a :6 c3d :5 c3e c3d
:5 c40 c3f :3 c3d c39
c43 :5 c44 :3 c43 :2 c45
:5 c47 :11 c48 :24 c49 :3 c48
:2 c46 :6 c45 c42 :4 c38
:3 bae :3 c50 :5 c51 c50
:5 c52 c4f c54 :5 c55
:3 c54 :2 c56 :5 c58 :11 c59
:24 c5a :3 c59 :2 c57 :6 c56
c53 :3 baa :9 c60 :5 c62
:4 c63 c62 :6 c64 :5 c65
c64 :5 c67 c66 :3 c64
c61 c6a :5 c6b :3 c6a
:2 c6c :5 c6e :11 c6f :24 c70
:3 c6f :2 c6d :6 c6c c69
:6 c60 :3 baa :3 c77 :5 c7a
:a c7c :6 c7d :5 c7e c7d
:5 c80 c7f :3 c7d c7b
c83 :5 c84 :3 c83 :2 c85
:5 c87 :11 c88 :24 c89 :3 c88
:2 c86 :6 c85 c82 :3 c7a
:9 c8f :3 c91 :4 c92 c91
:5 c93 c90 c95 :5 c96
:3 c95 :2 c97 :5 c99 :11 c9a
:24 c9b :3 c9a :2 c98 :6 c97
c94 :3 c8f :9 ca1 :3 ca3
:5 ca4 ca3 :6 ca5 :5 ca6
ca5 :5 ca8 ca7 :3 ca5
ca2 cab :5 cac :3 cab
:2 cad :5 caf :11 cb0 :24 cb1
:3 cb0 :2 cae :6 cad caa
:3 ca1 :6 cb7 :6 cb8 :5 cb9
cb8 :5 cbb cba :3 cb8
cb6 cbe :5 cbf :3 cbe
:2 cc0 :5 cc2 :11 cc3 :24 cc4
:3 cc3 :2 cc1 :6 cc0 cbd
:6 ca1 :3 c8f :9 ccb :3 ccd
:a cce :d cd1 :9 cd2 :3 cd3
cd1 :5 cd4 cd0 cd6
:5 cd7 :3 cd6 :2 cd8 :5 cda
:11 cdb :24 cdc :3 cdb :2 cd9
:6 cd8 cd5 :3 ccb :a ce0
:9 ce1 ce3 :2 ce4 :2 ce5
:2 ce6 :3 ce7 ce8 :4 ce9
ce3 :6 cea :5 ceb cea
:5 ced cec :3 cea ce2
cf0 :5 cf1 :3 cf0 :2 cf2
:5 cf4 :11 cf5 :24 cf6 :3 cf5
:2 cf3 :6 cf2 cef :4 ce1
cfc :2 cfd :2 cfe :2 cff
:3 d00 :3 d01 :4 d02 cfc
:6 d03 :5 d04 d03 :5 d06
d05 :3 d03 cfb d09
:5 d0a :3 d09 :2 d0b :5 d0d
:11 d0e :24 d0f :3 d0e :2 d0c
:6 d0b d08 :4 cfa :3 ce1
:b d16 :3 d17 :7 d18 :4 d19
:3 d1a :3 d18 :3 d16 :3 ce0
:a d1e d1f :2 d1e :4 d1f
:3 d1e :3 d20 d1f :2 d1e
:3 ccb :3 c7a :5 d25 :3 d27
:a d28 :d d2b :9 d2c :3 d2d
d2b :5 d2e d2a d30
:5 d31 :3 d30 :2 d32 :5 d34
:11 d35 :24 d36 :3 d35 :2 d33
:6 d32 d2f :3 d25 :9 d3c
d3e :2 d3f :2 d40 :2 d41
:3 d42 d43 :4 d44 d3e
:6 d45 :5 d46 d45 :5 d48
d47 :3 d45 d3d d4b
:5 d4c :3 d4b :2 d4d :5 d4f
:11 d50 :24 d51 :3 d50 :2 d4e
:6 d4d d4a :4 d3c d57
:2 d58 :2 d59 :2 d5a :3 d5b
:3 d5c :4 d5d d57 :6 d5e
:5 d5f d5e :5 d61 d60
:3 d5e d56 d64 :5 d65
:3 d64 :2 d66 :5 d68 :11 d69
:24 d6a :3 d69 :2 d67 :6 d66
d63 :4 d55 :3 d3c :17 d70
:3 d71 :7 d72 :4 d73 :3 d74
:3 d72 :3 d70 :3 d25 :6 d78
:7 d7b :5 d7c :3 d7b :11 d80
:30 d81 :3 d80 :a d83 97
:3 d86 :11 d87 :b d88 :17 d89
:3 d87 :2 d8b :3 d8c :3 d8d
d8e d8c d8b d8c
:3 d8f :3 d86 :2 d90 :5 d92
:11 d93 :b d94 :18 d95 :3 d93
:2 d97 d98 :3 d99 d9a
d98 d97 d98 :3 d9b
:2 d91 :6 d90 d85 :7 1

11ebc
4
:3 0 1 :3 0 2
:a 0 5212 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 7
:7 0 11 10 :3 0
4 :3 0 8 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 9 :7 0 19
18 :3 0 a :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 a :3 0 c
:7 0 21 20 :3 0
a :3 0 d :7 0
25 24 :3 0 19
ee 0 17 a
:3 0 e :7 0 29
28 :3 0 a :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b a :3 0 10
:7 0 31 30 :3 0
a :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f a :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 5212 2 44
:2 0 1d :2 0 33
18 :3 0 19 :2 0
31 47 49 2
:5 0 1a :3 0 1b
:3 0 4b 4c 0
4f 4a 4d 5210
0 17 :6 0 1d
:2 0 37 4 :3 0
35 51 53 :6 0
56 54 0 5210
0 1c :6 0 1d
:2 0 3b 4 :3 0
39 58 5a :6 0
5d 5b 0 5210
0 1e :6 0 1d
:2 0 3f 4 :3 0
3d 5f 61 :6 0
64 62 0 5210
0 1f :6 0 1d
:2 0 43 4 :3 0
41 66 68 :6 0
6b 69 0 5210
0 20 :6 0 1d
:2 0 47 4 :3 0
45 6d 6f :6 0
72 70 0 5210
0 21 :6 0 1d
:2 0 4b 4 :3 0
49 74 76 :6 0
79 77 0 5210
0 22 :6 0 1d
:2 0 4f 4 :3 0
4d 7b 7d :6 0
80 7e 0 5210
0 23 :6 0 1d
:2 0 53 4 :3 0
51 82 84 :6 0
87 85 0 5210
0 24 :6 0 1d
:2 0 57 4 :3 0
55 89 8b :6 0
8e 8c 0 5210
0 25 :6 0 1d
:2 0 5b 4 :3 0
59 90 92 :6 0
95 93 0 5210
0 26 :6 0 1d
:2 0 5f 4 :3 0
5d 97 99 :6 0
9c 9a 0 5210
0 27 :6 0 1d
:2 0 63 4 :3 0
61 9e a0 :6 0
a3 a1 0 5210
0 28 :6 0 69
2f5 0 67 4
:3 0 65 a5 a7
:6 0 aa a8 0
5210 0 29 :6 0
6d 329 0 6b
2b :3 0 ac :7 0
af ad 0 5210
0 2a :6 0 2b
:3 0 b1 :7 0 b4
b2 0 5210 0
2c :6 0 30 :2 0
6f 2b :3 0 b6
:7 0 b9 b7 0
5210 0 2d :6 0
2b :3 0 bb :7 0
be bc 0 5210
0 2e :6 0 30
:2 0 73 4 :3 0
71 c0 c2 :6 0
c5 c3 0 5210
0 2f :6 0 79
397 0 77 4
:3 0 75 c7 c9
:6 0 cc ca 0
5210 0 31 :6 0
7d 3cb 0 7b
33 :3 0 ce :7 0
d1 cf 0 5210
0 32 :6 0 33
:3 0 d3 :7 0 d6
d4 0 5210 0
34 :6 0 38 :2 0
81 33 :3 0 d8
:7 0 db d9 0
5210 0 35 :6 0
4 :3 0 30 :2 0
7f dd df :6 0
e2 e0 0 5210
0 36 :6 0 87
420 0 85 4
:3 0 83 e4 e6
:6 0 e9 e7 0
5210 0 37 :6 0
8b 454 0 89
2b :3 0 eb :7 0
ee ec 0 5210
0 39 :6 0 2b
:3 0 f0 :7 0 f3
f1 0 5210 0
3a :6 0 1d :2 0
8d 2b :3 0 f5
:7 0 f8 f6 0
5210 0 3b :6 0
2b :3 0 fa :7 0
fd fb 0 5210
0 3c :6 0 3f
:2 0 91 4 :3 0
8f ff 101 :6 0
104 102 0 5210
0 3d :6 0 3f
:2 0 95 4 :3 0
93 106 108 :6 0
10b 109 0 5210
0 3e :6 0 3f
:2 0 99 4 :3 0
97 10d 10f :6 0
112 110 0 5210
0 40 :6 0 43
:2 0 9d 4 :3 0
9b 114 116 :6 0
119 117 0 5210
0 41 :6 0 45
:2 0 a1 4 :3 0
9f 11b 11d :6 0
120 11e 0 5210
0 42 :6 0 45
:2 0 a3 a :3 0
122 :7 0 126 123
124 5210 0 44
:6 0 45 :2 0 a5
a :3 0 128 :7 0
12c 129 12a 5210
0 46 :6 0 45
:2 0 a7 a :3 0
12e :7 0 132 12f
130 5210 0 47
:6 0 45 :2 0 a9
a :3 0 134 :7 0
138 135 136 5210
0 48 :6 0 45
:2 0 ab a :3 0
13a :7 0 13e 13b
13c 5210 0 49
:6 0 45 :2 0 ad
a :3 0 140 :7 0
144 141 142 5210
0 4a :6 0 45
:2 0 af a :3 0
146 :7 0 14a 147
148 5210 0 4b
:6 0 45 :2 0 b1
a :3 0 14c :7 0
150 14d 14e 5210
0 4c :6 0 45
:2 0 b3 a :3 0
152 :7 0 156 153
154 5210 0 4d
:6 0 45 :2 0 b5
a :3 0 158 :7 0
15c 159 15a 5210
0 4e :6 0 45
:2 0 b7 a :3 0
15e :7 0 162 15f
160 5210 0 4f
:6 0 45 :2 0 b9
a :3 0 164 :7 0
168 165 166 5210
0 50 :6 0 45
:2 0 bb a :3 0
16a :7 0 16e 16b
16c 5210 0 51
:6 0 45 :2 0 bd
a :3 0 170 :7 0
174 171 172 5210
0 52 :6 0 45
:2 0 bf a :3 0
176 :7 0 17a 177
178 5210 0 53
:6 0 45 :2 0 c1
a :3 0 17c :7 0
180 17d 17e 5210
0 54 :6 0 45
:2 0 c3 a :3 0
182 :7 0 186 183
184 5210 0 55
:6 0 45 :2 0 c5
a :3 0 188 :7 0
18c 189 18a 5210
0 56 :6 0 45
:2 0 c7 a :3 0
18e :7 0 192 18f
190 5210 0 57
:6 0 45 :2 0 c9
a :3 0 194 :7 0
198 195 196 5210
0 58 :6 0 45
:2 0 cb a :3 0
19a :7 0 19e 19b
19c 5210 0 59
:6 0 45 :2 0 cd
a :3 0 1a0 :7 0
1a4 1a1 1a2 5210
0 5a :6 0 45
:2 0 cf a :3 0
1a6 :7 0 1aa 1a7
1a8 5210 0 5b
:6 0 45 :2 0 d1
a :3 0 1ac :7 0
1b0 1ad 1ae 5210
0 5c :6 0 45
:2 0 d3 a :3 0
1b2 :7 0 1b6 1b3
1b4 5210 0 5d
:6 0 45 :2 0 d5
a :3 0 1b8 :7 0
1bc 1b9 1ba 5210
0 5e :6 0 45
:2 0 d7 a :3 0
1be :7 0 1c2 1bf
1c0 5210 0 5f
:6 0 45 :2 0 d9
a :3 0 1c4 :7 0
1c8 1c5 1c6 5210
0 60 :6 0 45
:2 0 db a :3 0
1ca :7 0 1ce 1cb
1cc 5210 0 61
:6 0 45 :2 0 dd
63 :3 0 1d0 :7 0
1d4 1d1 1d2 5210
0 62 :6 0 45
:2 0 df 63 :3 0
1d6 :7 0 1da 1d7
1d8 5210 0 64
:6 0 45 :2 0 e1
63 :3 0 1dc :7 0
1e0 1dd 1de 5210
0 65 :6 0 45
:2 0 e3 63 :3 0
1e2 :7 0 1e6 1e3
1e4 5210 0 66
:6 0 45 :2 0 e5
63 :3 0 1e8 :7 0
1ec 1e9 1ea 5210
0 67 :6 0 45
:2 0 e7 a :3 0
1ee :7 0 1f2 1ef
1f0 5210 0 68
:6 0 45 :2 0 e9
a :3 0 1f4 :7 0
1f8 1f5 1f6 5210
0 69 :6 0 45
:2 0 eb a :3 0
1fa :7 0 1fe 1fb
1fc 5210 0 6a
:6 0 45 :2 0 ed
a :3 0 200 :7 0
204 201 202 5210
0 6b :6 0 45
:2 0 ef a :3 0
206 :7 0 20a 207
208 5210 0 6c
:6 0 45 :2 0 f1
a :3 0 20c :7 0
210 20d 20e 5210
0 6d :6 0 45
:2 0 f3 a :3 0
212 :7 0 216 213
214 5210 0 6e
:6 0 45 :2 0 f5
a :3 0 218 :7 0
21c 219 21a 5210
0 6f :6 0 72
:2 0 f7 a :3 0
21e :7 0 222 21f
220 5210 0 70
:6 0 72 :2 0 fb
4 :3 0 f9 224
226 :6 0 229 227
0 5210 0 71
:6 0 45 :2 0 ff
4 :3 0 fd 22b
22d :6 0 230 22e
0 5210 0 73
:6 0 45 :2 0 101
63 :3 0 232 :7 0
236 233 234 5210
0 74 :6 0 30
:2 0 103 a :3 0
238 :7 0 23c 239
23a 5210 0 75
:6 0 45 :2 0 107
4 :3 0 105 23e
240 :6 0 243 241
0 5210 0 76
:6 0 1d :2 0 109
a :3 0 245 :7 0
249 246 247 5210
0 77 :6 0 30
:2 0 10d 4 :3 0
10b 24b 24d :6 0
250 24e 0 5210
0 78 :6 0 45
:2 0 111 4 :3 0
10f 252 254 :6 0
257 255 0 5210
0 79 :6 0 45
:2 0 113 a :3 0
259 :7 0 25d 25a
25b 5210 0 7a
:6 0 117 aea 0
115 a :3 0 25f
:7 0 263 260 261
5210 0 7b :6 0
45 :2 0 119 33
:3 0 265 :7 0 268
266 0 5210 0
7c :6 0 33 :3 0
26a :7 0 26d 26b
0 5210 0 7d
:6 0 45 :2 0 11b
63 :3 0 26f :7 0
273 270 271 5210
0 7e :6 0 45
:2 0 11d 63 :3 0
275 :7 0 279 276
277 5210 0 7f
:6 0 45 :2 0 11f
a :3 0 27b :7 0
27f 27c 27d 5210
0 80 :6 0 45
:2 0 121 a :3 0
281 :7 0 285 282
283 5210 0 81
:6 0 45 :2 0 123
a :3 0 287 :7 0
28b 288 289 5210
0 82 :6 0 45
:2 0 125 a :3 0
28d :7 0 291 28e
28f 5210 0 83
:6 0 45 :2 0 127
a :3 0 293 :7 0
297 294 295 5210
0 84 :6 0 45
:2 0 129 a :3 0
299 :7 0 29d 29a
29b 5210 0 85
:6 0 45 :2 0 12b
a :3 0 29f :7 0
2a3 2a0 2a1 5210
0 86 :6 0 45
:2 0 12d a :3 0
2a5 :7 0 2a9 2a6
2a7 5210 0 87
:6 0 1d :2 0 12f
a :3 0 2ab :7 0
2af 2ac 2ad 5210
0 88 :6 0 1d
:2 0 133 4 :3 0
131 2b1 2b3 :6 0
2b6 2b4 0 5210
0 89 :6 0 1d
:2 0 137 4 :3 0
135 2b8 2ba :6 0
2bd 2bb 0 5210
0 8a :6 0 45
:2 0 13b 4 :3 0
139 2bf 2c1 :6 0
2c4 2c2 0 5210
0 8b :6 0 45
:2 0 13d a :3 0
2c6 0 2 :5 0
2ca 2c7 2c8 5210
0 8c :6 0 45
:2 0 144 a :3 0
2cc 0 2 :5 0
8e :3 0 8f :3 0
4b :3 0 13f 2cf
2d2 142 2ce 2d4
2d5 :2 0 2d8 2cd
2d6 5210 0 8d
:6 0 45 :2 0 146
a :3 0 2da 0
2 :5 0 2de 2db
2dc 5210 0 90
:6 0 14a d2e 0
148 a :3 0 2e0
0 2 :5 0 2e4
2e1 2e2 5210 0
91 :9 0 14c a
:3 0 2e6 :7 0 2e9
2e7 0 5210 0
92 :6 0 a :3 0
2eb :7 0 2ee 2ec
0 5210 0 93
:6 0 94 :3 0 95
:a 0 2 2fa :4 0
2f0 2f3 0 2f1
:3 0 96 :3 0 97
:3 0 98 :3 0 99
:3 0 27 :4 0 9a
1 :8 0 2fb 2f0
2f3 2fc 0 5210
14e 2fc 2fe 2fb
2fd :6 0 2fa :7 0
2fc 94 :3 0 9b
:a 0 3 30e :5 0
300 303 0 301
:3 0 9c :3 0 9d
:3 0 98 :3 0 9e
:3 0 28 :3 0 9f
:3 0 27 :3 0 a0
:3 0 a1 :4 0 a2
1 :8 0 30f 300
303 310 0 5210
150 310 312 30f
311 :6 0 30e :7 0
310 94 :3 0 a3
:a 0 4 386 :5 0
314 317 0 315
:3 0 a4 :3 0 a5
:3 0 a6 :3 0 a7
:3 0 a6 :3 0 a8
:3 0 a4 :3 0 a9
:3 0 a6 :3 0 aa
:3 0 a6 :3 0 ab
:3 0 a6 :3 0 ac
:3 0 ad :3 0 ae
:3 0 a6 :3 0 ac
:3 0 ad :3 0 ae
:3 0 a6 :3 0 af
:3 0 b0 :3 0 b1
:3 0 a6 :3 0 b2
:3 0 b0 :3 0 b2
:3 0 a6 :3 0 b2
:3 0 a6 :3 0 a1
:3 0 a6 :3 0 b3
:3 0 a6 :3 0 b4
:3 0 a6 :3 0 b5
:3 0 a6 :3 0 b6
:3 0 a6 :3 0 b7
:3 0 a6 :3 0 b8
:3 0 a6 :3 0 b9
:3 0 a6 :3 0 ba
:3 0 a6 :3 0 bb
:3 0 bc :3 0 b0
:3 0 bd :3 0 a4
:3 0 9d :3 0 a6
:3 0 a4 :3 0 9e
:3 0 28 :3 0 a4
:3 0 9f :3 0 29
:3 0 a4 :3 0 a0
:3 0 a6 :3 0 a5
:3 0 a4 :3 0 a5
:3 0 a4 :3 0 99
:3 0 b0 :3 0 99
:3 0 a4 :3 0 a9
:3 0 1a :3 0 be
:3 0 1a :3 0 bf
:3 0 1a :3 0 c0
:3 0 1a :3 0 c1
:3 0 1a :3 0 c2
:3 0 1a :3 0 c3
:3 0 1a :3 0 c4
:3 0 1a :3 0 c5
:3 0 1a :3 0 c6
:3 0 1a :3 0 c7
:3 0 1a :3 0 c8
:3 0 1a :3 0 c9
:3 0 1a :3 0 ca
:3 0 1a :3 0 cb
:3 0 1a :3 0 cc
:3 0 b0 :3 0 cd
:3 0 37 :3 0 a6
:3 0 ac :4 0 ce
1 :8 0 387 314
317 388 0 5210
152 388 38a 387
389 :6 0 386 :7 0
388 392 393 0
154 15 :3 0 16
:2 0 4 38c 38d
0 38e :7 0 391
38f 0 5210 0
cf :6 0 d0 :3 0
d1 :3 0 d0 :3 0
d2 :3 0 395 396
0 2 :4 0 156
397 399 394 39b
39a :2 0 d3 :3 0
d4 :3 0 39d 39e
0 d5 :4 0 d0
:3 0 d6 :3 0 3a1
3a2 0 2 :4 0
158 3a3 3a5 d7
:4 0 d8 :2 0 d9
:3 0 15a 3a8 3aa
:3 0 da :4 0 d8
:2 0 db :4 0 15d
3ad 3af :3 0 d8
:2 0 3 :3 0 160
3b1 3b3 :3 0 d8
:2 0 db :4 0 163
3b5 3b7 :3 0 d8
:2 0 dc :4 0 166
3b9 3bb :3 0 d8
:2 0 db :4 0 169
3bd 3bf :3 0 d8
:2 0 5 :3 0 16c
3c1 3c3 :3 0 d8
:2 0 db :4 0 16f
3c5 3c7 :3 0 d8
:2 0 dc :4 0 172
3c9 3cb :3 0 d8
:2 0 db :4 0 175
3cd 3cf :3 0 d8
:2 0 6 :3 0 178
3d1 3d3 :3 0 d8
:2 0 db :4 0 17b
3d5 3d7 :3 0 d8
:2 0 dc :4 0 17e
3d9 3db :3 0 d8
:2 0 db :4 0 181
3dd 3df :3 0 d8
:2 0 7 :3 0 184
3e1 3e3 :3 0 d8
:2 0 db :4 0 187
3e5 3e7 :3 0 d8
:2 0 dc :4 0 18a
3e9 3eb :3 0 d8
:2 0 db :4 0 18d
3ed 3ef :3 0 d8
:2 0 8 :3 0 190
3f1 3f3 :3 0 d8
:2 0 db :4 0 193
3f5 3f7 :3 0 d8
:2 0 dc :4 0 196
3f9 3fb :3 0 d8
:2 0 8f :3 0 dd
:3 0 9 :3 0 199
3ff 401 de :4 0
19b 3fe 404 19e
3fd 406 :3 0 d8
:2 0 dc :4 0 1a1
408 40a :3 0 d8
:2 0 8f :3 0 dd
:3 0 b :3 0 1a4
40e 410 de :4 0
1a6 40d 413 1a9
40c 415 :3 0 d8
:2 0 dc :4 0 1ac
417 419 :3 0 d8
:2 0 8f :3 0 dd
:3 0 c :3 0 1af
41d 41f de :4 0
1b1 41c 422 1b4
41b 424 :3 0 d8
:2 0 dc :4 0 1b7
426 428 :3 0 d8
:2 0 8f :3 0 dd
:3 0 d :3 0 1ba
42c 42e de :4 0
1bc 42b 431 1bf
42a 433 :3 0 d8
:2 0 dc :4 0 1c2
435 437 :3 0 d8
:2 0 8f :3 0 dd
:3 0 e :3 0 1c5
43b 43d de :4 0
1c7 43a 440 1ca
439 442 :3 0 d8
:2 0 dc :4 0 1cd
444 446 :3 0 d8
:2 0 8f :3 0 dd
:3 0 f :3 0 1d0
44a 44c de :4 0
1d2 449 44f 1d5
448 451 :3 0 d8
:2 0 dc :4 0 1d8
453 455 :3 0 d8
:2 0 8f :3 0 dd
:3 0 10 :3 0 1db
459 45b de :4 0
1dd 458 45e 1e0
457 460 :3 0 d8
:2 0 dc :4 0 1e3
462 464 :3 0 d8
:2 0 8f :3 0 dd
:3 0 11 :3 0 1e6
468 46a de :4 0
1e8 467 46d 1eb
466 46f :3 0 d8
:2 0 dc :4 0 1ee
471 473 :3 0 d8
:2 0 8f :3 0 dd
:3 0 12 :3 0 1f1
477 479 de :4 0
1f3 476 47c 1f6
475 47e :3 0 d8
:2 0 dc :4 0 1f9
480 482 :3 0 d8
:2 0 db :4 0 1fc
484 486 :3 0 d8
:2 0 13 :3 0 1ff
488 48a :3 0 d8
:2 0 db :4 0 202
48c 48e :3 0 d8
:2 0 df :4 0 205
490 492 :3 0 208
39f 494 :2 0 496
20d 497 39c 496
0 498 20f 0
5170 d0 :3 0 d1
:3 0 499 49a 0
d0 :3 0 e0 :3 0
49c 49d 0 30
:2 0 2 :4 0 e1
:2 0 e2 :2 0 30
:2 0 211 4a2 4a4
:3 0 214 49e 4a6
49b 4a8 4a7 :2 0
d3 :3 0 e3 :3 0
4aa 4ab 0 d5
:4 0 e4 :4 0 d8
:2 0 d9 :3 0 218
4af 4b1 :3 0 21b
4ac 4b3 :2 0 4b5
21e 4b6 4a9 4b5
0 4b7 220 0
5170 26 :3 0 3
:3 0 4b8 4b9 0
5170 29 :3 0 5
:3 0 4bb 4bc 0
5170 27 :3 0 6
:3 0 4be 4bf 0
5170 1f :3 0 13
:3 0 4c1 4c2 0
5170 39 :3 0 7
:3 0 4c4 4c5 0
5170 5b :3 0 11
:3 0 4c7 4c8 0
5170 5b :3 0 e5
:3 0 8f :3 0 5b
:3 0 45 :2 0 222
4cc 4cf 1a :3 0
e6 :3 0 4d1 4d2
0 225 4cb 4d4
4ca 4d5 0 5170
8f :3 0 5b :3 0
45 :2 0 228 4d7
4da 1a :3 0 e7
:2 0 e8 :3 0 4dc
4de 0 22d 4dd
4e0 :3 0 4e1 :2 0
8f :3 0 5b :3 0
45 :2 0 230 4e3
4e6 1a :3 0 e7
:2 0 e9 :3 0 4e8
4ea 0 235 4e9
4ec :3 0 4ed :2 0
4e2 4ef 4ee :2 0
5b :3 0 ea :2 0
4f1 4f2 0 4f4
238 4f5 4f0 4f4
0 4f6 23a 0
5170 3a :3 0 39
:3 0 4f7 4f8 0
5170 42 :3 0 eb
:4 0 4fa 4fb 0
5170 31 :3 0 eb
:4 0 4fd 4fe 0
5170 4e :3 0 45
:2 0 500 501 0
5170 2c :3 0 eb
:4 0 503 504 0
5170 3b :4 0 506
507 0 5170 3c
:4 0 509 50a 0
5170 ec :3 0 95
:4 0 50f :2 0 5170
50d 510 :3 0 95
:3 0 5f :4 0 514
:2 0 5170 511 512
:3 0 95 :3 0 ed
:3 0 515 516 :3 0
15 :3 0 ee :3 0
518 519 0 45
:2 0 51a 51b 0
51d 23c 524 15
:3 0 ee :3 0 51e
51f 0 ef :2 0
520 521 0 523
23e 525 517 51d
0 526 0 523
0 526 240 0
5170 5f :3 0 15
:3 0 ee :3 0 528
529 0 527 52a
0 5170 f0 :3 0
95 :4 0 52f :2 0
535 52d 0 15
:3 0 ee :3 0 530
531 0 f1 :3 0
532 533 0 535
243 588 f2 :3 0
15 :3 0 ee :3 0
537 538 0 f1
:3 0 539 53a 0
53c 246 53e 248
53d 53c :2 0 586
f3 :3 0 15 :3 0
ee :3 0 541 542
0 f1 :3 0 543
544 0 57e d0
:3 0 d1 :3 0 546
547 0 d0 :3 0
e0 :3 0 549 54a
0 f4 :2 0 2
:4 0 f5 :2 0 e2
:2 0 30 :2 0 24a
54f 551 :3 0 24d
54b 553 548 555
554 :2 0 d3 :3 0
e3 :3 0 557 558
0 d5 :4 0 f6
:4 0 d8 :2 0 d9
:3 0 251 55c 55e
:3 0 d8 :2 0 f7
:4 0 254 560 562
:3 0 d8 :2 0 f8
:4 0 257 564 566
:3 0 d8 :2 0 f1
:3 0 25a 568 56a
:3 0 d8 :2 0 f9
:4 0 25d 56c 56e
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 260
571 575 264 570
577 :3 0 267 559
579 :2 0 57b 26a
57c 556 57b 0
57d 26c 0 57e
26e 581 :3 0 581
0 581 580 57e
57f :6 0 583 5
:3 0 271 585 273
584 583 :2 0 586
275 :2 0 588 0
588 587 535 586
:6 0 5170 1 :3 0
8f :3 0 5f :3 0
45 :2 0 278 58a
58d e7 :2 0 ef
:2 0 27d 58f 591
:3 0 d0 :3 0 d1
:3 0 593 594 0
d0 :3 0 e0 :3 0
596 597 0 1d
:2 0 2 :4 0 fc
:2 0 e2 :2 0 30
:2 0 280 59c 59e
:3 0 283 598 5a0
595 5a2 5a1 :2 0
d3 :3 0 e3 :3 0
5a4 5a5 0 d5
:4 0 fd :4 0 d8
:2 0 d9 :3 0 287
5a9 5ab :3 0 d8
:2 0 f7 :4 0 28a
5ad 5af :3 0 d8
:2 0 fe :4 0 28d
5b1 5b3 :3 0 d8
:2 0 8f :3 0 dd
:3 0 1a :3 0 ff
:3 0 5b8 5b9 0
290 5b7 5bb de
:4 0 292 5b6 5be
295 5b5 5c0 :3 0
d8 :2 0 100 :4 0
298 5c2 5c4 :3 0
d8 :2 0 db :4 0
29b 5c6 5c8 :3 0
d8 :2 0 27 :3 0
29e 5ca 5cc :3 0
d8 :2 0 db :4 0
2a1 5ce 5d0 :3 0
2a4 5a6 5d2 :2 0
5d4 2a7 5d5 5a3
5d4 0 5d6 2a9
0 600 d0 :3 0
d1 :3 0 5d7 5d8
0 d0 :3 0 e0
:3 0 5da 5db 0
30 :2 0 2 :4 0
101 :2 0 e2 :2 0
30 :2 0 2ab 5e0
5e2 :3 0 2ae 5dc
5e4 5d9 5e6 5e5
:2 0 d3 :3 0 e3
:3 0 5e8 5e9 0
d5 :4 0 102 :4 0
d8 :2 0 d9 :3 0
2b2 5ed 5ef :3 0
2b5 5ea 5f1 :2 0
5f3 2b8 5f4 5e7
5f3 0 5f5 2ba
0 600 103 :3 0
104 :3 0 5f6 5f7
0 1a :3 0 ff
:3 0 5f9 5fa 0
27 :3 0 105 :3 0
2bc 5f8 5fe :2 0
600 2c0 601 592
600 0 602 2c4
0 5170 106 :3 0
cd :3 0 9e :3 0
107 :3 0 108 :3 0
109 :3 0 4b :3 0
37 :3 0 28 :3 0
89 :3 0 8a :3 0
52 :3 0 bc :3 0
99 :3 0 26 :4 0
10a 1 :8 0 618
15 :3 0 ee :3 0
613 614 0 f1
:3 0 615 616 0
618 2c6 66b f2
:3 0 15 :3 0 ee
:3 0 61a 61b 0
f1 :3 0 61c 61d
0 61f 2c9 621
2cb 620 61f :2 0
669 f3 :3 0 15
:3 0 ee :3 0 624
625 0 f1 :3 0
626 627 0 661
d0 :3 0 d1 :3 0
629 62a 0 d0
:3 0 e0 :3 0 62c
62d 0 f4 :2 0
2 :4 0 10b :2 0
e2 :2 0 30 :2 0
2cd 632 634 :3 0
2d0 62e 636 62b
638 637 :2 0 d3
:3 0 e3 :3 0 63a
63b 0 d5 :4 0
10c :4 0 d8 :2 0
d9 :3 0 2d4 63f
641 :3 0 d8 :2 0
f7 :4 0 2d7 643
645 :3 0 d8 :2 0
f8 :4 0 2da 647
649 :3 0 d8 :2 0
f1 :3 0 2dd 64b
64d :3 0 d8 :2 0
f9 :4 0 2e0 64f
651 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2e3 654 658 2e7
653 65a :3 0 2ea
63c 65c :2 0 65e
2ed 65f 639 65e
0 660 2ef 0
661 2f1 664 :3 0
664 0 664 663
661 662 :6 0 666
7 :3 0 2f4 668
2f6 667 666 :2 0
669 2f8 :2 0 66b
0 66b 66a 618
669 :6 0 5170 1
:3 0 15 :3 0 ee
:3 0 66d 66e 0
15 :3 0 e7 :2 0
10d :3 0 670 672
0 2fd 671 674
:3 0 675 :2 0 d0
:3 0 d1 :3 0 677
678 0 d0 :3 0
e0 :3 0 67a 67b
0 1d :2 0 2
:4 0 10e :2 0 e2
:2 0 30 :2 0 300
680 682 :3 0 303
67c 684 679 686
685 :2 0 d3 :3 0
e3 :3 0 688 689
0 d5 :4 0 10f
:4 0 d8 :2 0 d9
:3 0 307 68d 68f
:3 0 d8 :2 0 f7
:4 0 30a 691 693
:3 0 d8 :2 0 fe
:4 0 30d 695 697
:3 0 d8 :2 0 8f
:3 0 dd :3 0 1a
:3 0 ff :3 0 69c
69d 0 310 69b
69f de :4 0 312
69a 6a2 315 699
6a4 :3 0 d8 :2 0
100 :4 0 318 6a6
6a8 :3 0 d8 :2 0
db :4 0 31b 6aa
6ac :3 0 d8 :2 0
26 :3 0 31e 6ae
6b0 :3 0 d8 :2 0
db :4 0 321 6b2
6b4 :3 0 324 68a
6b6 :2 0 6b8 327
6b9 687 6b8 0
6ba 329 0 6e4
d0 :3 0 d1 :3 0
6bb 6bc 0 d0
:3 0 e0 :3 0 6be
6bf 0 30 :2 0
2 :4 0 110 :2 0
e2 :2 0 30 :2 0
32b 6c4 6c6 :3 0
32e 6c0 6c8 6bd
6ca 6c9 :2 0 d3
:3 0 e3 :3 0 6cc
6cd 0 d5 :4 0
111 :4 0 d8 :2 0
d9 :3 0 332 6d1
6d3 :3 0 335 6ce
6d5 :2 0 6d7 338
6d8 6cb 6d7 0
6d9 33a 0 6e4
103 :3 0 104 :3 0
6da 6db 0 1a
:3 0 ff :3 0 6dd
6de 0 26 :3 0
105 :3 0 33c 6dc
6e2 :2 0 6e4 340
6e5 676 6e4 0
6e6 344 0 5170
75 :3 0 45 :2 0
6e7 6e8 0 5170
112 :3 0 75 :3 0
113 :3 0 9e :3 0
28 :4 0 114 1
:8 0 6f5 15 :3 0
ee :3 0 6f0 6f1
0 f1 :3 0 6f2
6f3 0 6f5 346
748 f2 :3 0 15
:3 0 ee :3 0 6f7
6f8 0 f1 :3 0
6f9 6fa 0 6fc
349 6fe 34b 6fd
6fc :2 0 746 f3
:3 0 15 :3 0 ee
:3 0 701 702 0
f1 :3 0 703 704
0 73e d0 :3 0
d1 :3 0 706 707
0 d0 :3 0 e0
:3 0 709 70a 0
f4 :2 0 2 :4 0
115 :2 0 e2 :2 0
30 :2 0 34d 70f
711 :3 0 350 70b
713 708 715 714
:2 0 d3 :3 0 e3
:3 0 717 718 0
d5 :4 0 116 :4 0
d8 :2 0 d9 :3 0
354 71c 71e :3 0
d8 :2 0 f7 :4 0
357 720 722 :3 0
d8 :2 0 f8 :4 0
35a 724 726 :3 0
d8 :2 0 f1 :3 0
35d 728 72a :3 0
d8 :2 0 f9 :4 0
360 72c 72e :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 363 731
735 367 730 737
:3 0 36a 719 739
:2 0 73b 36d 73c
716 73b 0 73d
36f 0 73e 371
741 :3 0 741 0
741 740 73e 73f
:6 0 743 9 :3 0
374 745 376 744
743 :2 0 746 378
:2 0 748 0 748
747 6f5 746 :6 0
5170 1 :3 0 8f
:3 0 75 :3 0 45
:2 0 37b 74a 74d
117 :2 0 45 :2 0
380 74f 751 :3 0
d0 :3 0 d1 :3 0
753 754 0 d0
:3 0 e0 :3 0 756
757 0 1d :2 0
2 :4 0 118 :2 0
e2 :2 0 30 :2 0
383 75c 75e :3 0
386 758 760 755
762 761 :2 0 d3
:3 0 e3 :3 0 764
765 0 d5 :4 0
119 :4 0 d8 :2 0
d9 :3 0 38a 769
76b :3 0 d8 :2 0
f7 :4 0 38d 76d
76f :3 0 d8 :2 0
fe :4 0 390 771
773 :3 0 d8 :2 0
8f :3 0 dd :3 0
1a :3 0 11a :3 0
778 779 0 393
777 77b de :4 0
395 776 77e 398
775 780 :3 0 d8
:2 0 100 :4 0 39b
782 784 :3 0 d8
:2 0 db :4 0 39e
786 788 :3 0 d8
:2 0 28 :3 0 3a1
78a 78c :3 0 d8
:2 0 db :4 0 3a4
78e 790 :3 0 3a7
766 792 :2 0 794
3aa 795 763 794
0 796 3ac 0
7c0 d0 :3 0 d1
:3 0 797 798 0
d0 :3 0 e0 :3 0
79a 79b 0 30
:2 0 2 :4 0 11b
:2 0 e2 :2 0 30
:2 0 3ae 7a0 7a2
:3 0 3b1 79c 7a4
799 7a6 7a5 :2 0
d3 :3 0 e3 :3 0
7a8 7a9 0 d5
:4 0 11c :4 0 d8
:2 0 d9 :3 0 3b5
7ad 7af :3 0 3b8
7aa 7b1 :2 0 7b3
3bb 7b4 7a7 7b3
0 7b5 3bd 0
7c0 103 :3 0 104
:3 0 7b6 7b7 0
1a :3 0 11a :3 0
7b9 7ba 0 28
:3 0 105 :3 0 3bf
7b8 7be :2 0 7c0
3c3 7c1 752 7c0
0 7c2 3c7 0
5170 11d :3 0 106
:3 0 11d :3 0 11e
:3 0 8f :3 0 11d
:3 0 11f :3 0 8f
:3 0 11d :3 0 120
:3 0 11d :3 0 121
:3 0 11d :3 0 122
:3 0 123 :3 0 124
:3 0 125 :3 0 126
:3 0 4a :3 0 6e
:3 0 58 :3 0 59
:3 0 5c :3 0 68
:3 0 67 :3 0 bc
:3 0 11d :3 0 127
:3 0 128 :3 0 125
:3 0 11d :3 0 122
:3 0 125 :3 0 99
:3 0 11d :3 0 99
:3 0 28 :4 0 129
1 :8 0 7ee 15
:3 0 ee :3 0 7e9
7ea 0 f1 :3 0
7eb 7ec 0 7ee
3c9 841 f2 :3 0
15 :3 0 ee :3 0
7f0 7f1 0 f1
:3 0 7f2 7f3 0
7f5 3cc 7f7 3ce
7f6 7f5 :2 0 83f
f3 :3 0 15 :3 0
ee :3 0 7fa 7fb
0 f1 :3 0 7fc
7fd 0 837 d0
:3 0 d1 :3 0 7ff
800 0 d0 :3 0
e0 :3 0 802 803
0 f4 :2 0 2
:4 0 12a :2 0 e2
:2 0 30 :2 0 3d0
808 80a :3 0 3d3
804 80c 801 80e
80d :2 0 d3 :3 0
e3 :3 0 810 811
0 d5 :4 0 12b
:4 0 d8 :2 0 d9
:3 0 3d7 815 817
:3 0 d8 :2 0 f7
:4 0 3da 819 81b
:3 0 d8 :2 0 f8
:4 0 3dd 81d 81f
:3 0 d8 :2 0 f1
:3 0 3e0 821 823
:3 0 d8 :2 0 f9
:4 0 3e3 825 827
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 3e6
82a 82e 3ea 829
830 :3 0 3ed 812
832 :2 0 834 3f0
835 80f 834 0
836 3f2 0 837
3f4 83a :3 0 83a
0 83a 839 837
838 :6 0 83c b
:3 0 3f7 83e 3f9
83d 83c :2 0 83f
3fb :2 0 841 0
841 840 7ee 83f
:6 0 5170 1 :3 0
15 :3 0 ee :3 0
843 844 0 15
:3 0 e7 :2 0 10d
:3 0 846 848 0
400 847 84a :3 0
84b :2 0 d0 :3 0
d1 :3 0 84d 84e
0 d0 :3 0 e0
:3 0 850 851 0
1d :2 0 2 :4 0
12c :2 0 e2 :2 0
30 :2 0 403 856
858 :3 0 406 852
85a 84f 85c 85b
:2 0 d3 :3 0 e3
:3 0 85e 85f 0
d5 :4 0 12d :4 0
d8 :2 0 d9 :3 0
40a 863 865 :3 0
d8 :2 0 f7 :4 0
40d 867 869 :3 0
d8 :2 0 fe :4 0
410 86b 86d :3 0
d8 :2 0 8f :3 0
dd :3 0 1a :3 0
ff :3 0 872 873
0 413 871 875
de :4 0 415 870
878 418 86f 87a
:3 0 d8 :2 0 100
:4 0 41b 87c 87e
:3 0 d8 :2 0 db
:4 0 41e 880 882
:3 0 d8 :2 0 26
:3 0 421 884 886
:3 0 d8 :2 0 db
:4 0 424 888 88a
:3 0 427 860 88c
:2 0 88e 42a 88f
85d 88e 0 890
42c 0 8ba d0
:3 0 d1 :3 0 891
892 0 d0 :3 0
e0 :3 0 894 895
0 30 :2 0 2
:4 0 12e :2 0 e2
:2 0 30 :2 0 42e
89a 89c :3 0 431
896 89e 893 8a0
89f :2 0 d3 :3 0
e3 :3 0 8a2 8a3
0 d5 :4 0 12f
:4 0 d8 :2 0 d9
:3 0 435 8a7 8a9
:3 0 438 8a4 8ab
:2 0 8ad 43b 8ae
8a1 8ad 0 8af
43d 0 8ba 103
:3 0 104 :3 0 8b0
8b1 0 1a :3 0
ff :3 0 8b3 8b4
0 26 :3 0 105
:3 0 43f 8b2 8b8
:2 0 8ba 443 8bb
84c 8ba 0 8bc
447 0 5170 130
:3 0 131 :3 0 3e
:3 0 42 :3 0 132
:3 0 9f :3 0 27
:4 0 133 1 :8 0
8ca 15 :3 0 ee
:3 0 8c5 8c6 0
f1 :3 0 8c7 8c8
0 8ca 449 91d
f2 :3 0 15 :3 0
ee :3 0 8cc 8cd
0 f1 :3 0 8ce
8cf 0 8d1 44c
8d3 44e 8d2 8d1
:2 0 91b f3 :3 0
15 :3 0 ee :3 0
8d6 8d7 0 f1
:3 0 8d8 8d9 0
913 d0 :3 0 d1
:3 0 8db 8dc 0
d0 :3 0 e0 :3 0
8de 8df 0 f4
:2 0 2 :4 0 134
:2 0 e2 :2 0 30
:2 0 450 8e4 8e6
:3 0 453 8e0 8e8
8dd 8ea 8e9 :2 0
d3 :3 0 e3 :3 0
8ec 8ed 0 d5
:4 0 135 :4 0 d8
:2 0 d9 :3 0 457
8f1 8f3 :3 0 d8
:2 0 f7 :4 0 45a
8f5 8f7 :3 0 d8
:2 0 f8 :4 0 45d
8f9 8fb :3 0 d8
:2 0 f1 :3 0 460
8fd 8ff :3 0 d8
:2 0 f9 :4 0 463
901 903 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 466 906 90a
46a 905 90c :3 0
46d 8ee 90e :2 0
910 470 911 8eb
910 0 912 472
0 913 474 916
:3 0 916 0 916
915 913 914 :6 0
918 d :3 0 477
91a 479 919 918
:2 0 91b 47b :2 0
91d 0 91d 91c
8ca 91b :6 0 5170
1 :3 0 15 :3 0
ee :3 0 91f 920
0 15 :3 0 e7
:2 0 10d :3 0 922
924 0 480 923
926 :3 0 927 :2 0
d0 :3 0 d1 :3 0
929 92a 0 d0
:3 0 e0 :3 0 92c
92d 0 1d :2 0
2 :4 0 136 :2 0
e2 :2 0 30 :2 0
483 932 934 :3 0
486 92e 936 92b
938 937 :2 0 d3
:3 0 e3 :3 0 93a
93b 0 d5 :4 0
137 :4 0 d8 :2 0
d9 :3 0 48a 93f
941 :3 0 d8 :2 0
f7 :4 0 48d 943
945 :3 0 d8 :2 0
fe :4 0 490 947
949 :3 0 d8 :2 0
8f :3 0 dd :3 0
1a :3 0 ff :3 0
94e 94f 0 493
94d 951 de :4 0
495 94c 954 498
94b 956 :3 0 d8
:2 0 100 :4 0 49b
958 95a :3 0 d8
:2 0 db :4 0 49e
95c 95e :3 0 d8
:2 0 27 :3 0 4a1
960 962 :3 0 d8
:2 0 db :4 0 4a4
964 966 :3 0 4a7
93c 968 :2 0 96a
4aa 96b 939 96a
0 96c 4ac 0
996 d0 :3 0 d1
:3 0 96d 96e 0
d0 :3 0 e0 :3 0
970 971 0 30
:2 0 2 :4 0 138
:2 0 e2 :2 0 30
:2 0 4ae 976 978
:3 0 4b1 972 97a
96f 97c 97b :2 0
d3 :3 0 e3 :3 0
97e 97f 0 d5
:4 0 139 :4 0 d8
:2 0 d9 :3 0 4b5
983 985 :3 0 4b8
980 987 :2 0 989
4bb 98a 97d 989
0 98b 4bd 0
996 103 :3 0 104
:3 0 98c 98d 0
1a :3 0 ff :3 0
98f 990 0 27
:3 0 105 :3 0 4bf
98e 994 :2 0 996
4c3 997 928 996
0 998 4c7 0
5170 13a :3 0 3d
:3 0 13b :3 0 13c
:3 0 29 :4 0 13d
1 :8 0 9a4 15
:3 0 ee :3 0 99f
9a0 0 f1 :3 0
9a1 9a2 0 9a4
4c9 9f7 f2 :3 0
15 :3 0 ee :3 0
9a6 9a7 0 f1
:3 0 9a8 9a9 0
9ab 4cc 9ad 4ce
9ac 9ab :2 0 9f5
f3 :3 0 15 :3 0
ee :3 0 9b0 9b1
0 f1 :3 0 9b2
9b3 0 9ed d0
:3 0 d1 :3 0 9b5
9b6 0 d0 :3 0
e0 :3 0 9b8 9b9
0 f4 :2 0 2
:4 0 13e :2 0 e2
:2 0 30 :2 0 4d0
9be 9c0 :3 0 4d3
9ba 9c2 9b7 9c4
9c3 :2 0 d3 :3 0
e3 :3 0 9c6 9c7
0 d5 :4 0 13f
:4 0 d8 :2 0 d9
:3 0 4d7 9cb 9cd
:3 0 d8 :2 0 f7
:4 0 4da 9cf 9d1
:3 0 d8 :2 0 f8
:4 0 4dd 9d3 9d5
:3 0 d8 :2 0 f1
:3 0 4e0 9d7 9d9
:3 0 d8 :2 0 f9
:4 0 4e3 9db 9dd
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 4e6
9e0 9e4 4ea 9df
9e6 :3 0 4ed 9c8
9e8 :2 0 9ea 4f0
9eb 9c5 9ea 0
9ec 4f2 0 9ed
4f4 9f0 :3 0 9f0
0 9f0 9ef 9ed
9ee :6 0 9f2 f
:3 0 4f7 9f4 4f9
9f3 9f2 :2 0 9f5
4fb :2 0 9f7 0
9f7 9f6 9a4 9f5
:6 0 5170 1 :3 0
123 :3 0 140 :3 0
9f9 9fa 0 3d
:3 0 141 :4 0 4fe
9fb 9fe e7 :2 0
45 :2 0 503 a00
a02 :3 0 3d :3 0
eb :4 0 a04 a05
0 a07 506 a08
a03 a07 0 a09
508 0 5170 15
:3 0 ee :3 0 a0a
a0b 0 15 :3 0
e7 :2 0 10d :3 0
a0d a0f 0 50c
a0e a11 :3 0 a12
:2 0 d0 :3 0 d1
:3 0 a14 a15 0
d0 :3 0 e0 :3 0
a17 a18 0 1d
:2 0 2 :4 0 142
:2 0 e2 :2 0 30
:2 0 50f a1d a1f
:3 0 512 a19 a21
a16 a23 a22 :2 0
d3 :3 0 e3 :3 0
a25 a26 0 d5
:4 0 143 :4 0 d8
:2 0 d9 :3 0 516
a2a a2c :3 0 d8
:2 0 f7 :4 0 519
a2e a30 :3 0 d8
:2 0 fe :4 0 51c
a32 a34 :3 0 d8
:2 0 8f :3 0 dd
:3 0 1a :3 0 ff
:3 0 a39 a3a 0
51f a38 a3c de
:4 0 521 a37 a3f
524 a36 a41 :3 0
d8 :2 0 100 :4 0
527 a43 a45 :3 0
d8 :2 0 db :4 0
52a a47 a49 :3 0
d8 :2 0 29 :3 0
52d a4b a4d :3 0
d8 :2 0 db :4 0
530 a4f a51 :3 0
533 a27 a53 :2 0
a55 536 a56 a24
a55 0 a57 538
0 a81 d0 :3 0
d1 :3 0 a58 a59
0 d0 :3 0 e0
:3 0 a5b a5c 0
30 :2 0 2 :4 0
144 :2 0 e2 :2 0
30 :2 0 53a a61
a63 :3 0 53d a5d
a65 a5a a67 a66
:2 0 d3 :3 0 e3
:3 0 a69 a6a 0
d5 :4 0 145 :4 0
d8 :2 0 d9 :3 0
541 a6e a70 :3 0
544 a6b a72 :2 0
a74 547 a75 a68
a74 0 a76 549
0 a81 103 :3 0
104 :3 0 a77 a78
0 1a :3 0 ff
:3 0 a7a a7b 0
29 :3 0 105 :3 0
54b a79 a7f :2 0
a81 54f a82 a13
a81 0 a83 553
0 5170 69 :3 0
12 :3 0 a84 a85
0 5170 6b :3 0
e5 :3 0 8f :3 0
69 :3 0 45 :2 0
555 a89 a8c ea
:2 0 558 a88 a8f
a87 a90 0 5170
6c :3 0 e5 :3 0
8f :3 0 69 :3 0
45 :2 0 55b a94
a97 146 :2 0 55e
a93 a9a a92 a9b
0 5170 6a :3 0
e5 :3 0 8f :3 0
69 :3 0 45 :2 0
561 a9f aa2 30
:2 0 564 a9e aa5
a9d aa6 0 5170
147 :3 0 a7 :3 0
81 :3 0 9d :3 0
9e :3 0 28 :3 0
9e :3 0 a8 :3 0
9f :3 0 29 :3 0
a0 :4 0 148 1
:8 0 ab9 15 :3 0
ee :3 0 ab4 ab5
0 f1 :3 0 ab6
ab7 0 ab9 567
b0c f2 :3 0 15
:3 0 ee :3 0 abb
abc 0 f1 :3 0
abd abe 0 ac0
56a ac2 56c ac1
ac0 :2 0 b0a f3
:3 0 15 :3 0 ee
:3 0 ac5 ac6 0
f1 :3 0 ac7 ac8
0 b02 d0 :3 0
d1 :3 0 aca acb
0 d0 :3 0 e0
:3 0 acd ace 0
f4 :2 0 2 :4 0
149 :2 0 e2 :2 0
30 :2 0 56e ad3
ad5 :3 0 571 acf
ad7 acc ad9 ad8
:2 0 d3 :3 0 e3
:3 0 adb adc 0
d5 :4 0 14a :4 0
d8 :2 0 d9 :3 0
575 ae0 ae2 :3 0
d8 :2 0 f7 :4 0
578 ae4 ae6 :3 0
d8 :2 0 f8 :4 0
57b ae8 aea :3 0
d8 :2 0 f1 :3 0
57e aec aee :3 0
d8 :2 0 f9 :4 0
581 af0 af2 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 584 af5
af9 588 af4 afb
:3 0 58b add afd
:2 0 aff 58e b00
ada aff 0 b01
590 0 b02 592
b05 :3 0 b05 0
b05 b04 b02 b03
:6 0 b07 11 :3 0
595 b09 597 b08
b07 :2 0 b0a 599
:2 0 b0c 0 b0c
b0b ab9 b0a :6 0
5170 1 :3 0 147
:3 0 a7 :3 0 80
:3 0 9d :3 0 9e
:3 0 28 :3 0 a8
:3 0 28 :3 0 9f
:3 0 29 :3 0 a0
:4 0 14b 1 :8 0
b1f 15 :3 0 ee
:3 0 b1a b1b 0
f1 :3 0 b1c b1d
0 b1f 59c b72
f2 :3 0 15 :3 0
ee :3 0 b21 b22
0 f1 :3 0 b23
b24 0 b26 59f
b28 5a1 b27 b26
:2 0 b70 f3 :3 0
15 :3 0 ee :3 0
b2b b2c 0 f1
:3 0 b2d b2e 0
b68 d0 :3 0 d1
:3 0 b30 b31 0
d0 :3 0 e0 :3 0
b33 b34 0 f4
:2 0 2 :4 0 14c
:2 0 e2 :2 0 30
:2 0 5a3 b39 b3b
:3 0 5a6 b35 b3d
b32 b3f b3e :2 0
d3 :3 0 e3 :3 0
b41 b42 0 d5
:4 0 14d :4 0 d8
:2 0 d9 :3 0 5aa
b46 b48 :3 0 d8
:2 0 f7 :4 0 5ad
b4a b4c :3 0 d8
:2 0 f8 :4 0 5b0
b4e b50 :3 0 d8
:2 0 f1 :3 0 5b3
b52 b54 :3 0 d8
:2 0 f9 :4 0 5b6
b56 b58 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 5b9 b5b b5f
5bd b5a b61 :3 0
5c0 b43 b63 :2 0
b65 5c3 b66 b40
b65 0 b67 5c5
0 b68 5c7 b6b
:3 0 b6b 0 b6b
b6a b68 b69 :6 0
b6d 13 :3 0 5ca
b6f 5cc b6e b6d
:2 0 b70 5ce :2 0
b72 0 b72 b71
b1f b70 :6 0 5170
1 :3 0 8d :3 0
14e :2 0 45 :2 0
5d3 b75 b77 :3 0
8f :3 0 6c :3 0
45 :2 0 5d6 b79
b7c e7 :2 0 45
:2 0 5db b7e b80
:3 0 147 :3 0 70
:3 0 14f :3 0 9d
:3 0 9e :3 0 28
:3 0 a8 :3 0 28
:3 0 9f :3 0 27
:4 0 150 1 :8 0
b92 15 :3 0 ee
:3 0 b8d b8e 0
f1 :3 0 b8f b90
0 b92 5de be5
f2 :3 0 15 :3 0
ee :3 0 b94 b95
0 f1 :3 0 b96
b97 0 b99 5e1
b9b 5e3 b9a b99
:2 0 be3 f3 :3 0
15 :3 0 ee :3 0
b9e b9f 0 f1
:3 0 ba0 ba1 0
bdb d0 :3 0 d1
:3 0 ba3 ba4 0
d0 :3 0 e0 :3 0
ba6 ba7 0 f4
:2 0 2 :4 0 151
:2 0 e2 :2 0 30
:2 0 5e5 bac bae
:3 0 5e8 ba8 bb0
ba5 bb2 bb1 :2 0
d3 :3 0 e3 :3 0
bb4 bb5 0 d5
:4 0 152 :4 0 d8
:2 0 d9 :3 0 5ec
bb9 bbb :3 0 d8
:2 0 f7 :4 0 5ef
bbd bbf :3 0 d8
:2 0 f8 :4 0 5f2
bc1 bc3 :3 0 d8
:2 0 f1 :3 0 5f5
bc5 bc7 :3 0 d8
:2 0 f9 :4 0 5f8
bc9 bcb :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 5fb bce bd2
5ff bcd bd4 :3 0
602 bb6 bd6 :2 0
bd8 605 bd9 bb3
bd8 0 bda 607
0 bdb 609 bde
:3 0 bde 0 bde
bdd bdb bdc :6 0
be0 15 :3 0 60c
be2 60e be1 be0
:2 0 be3 610 :2 0
be5 0 be5 be4
b92 be3 :6 0 cd7
1 :3 0 8f :3 0
70 :3 0 45 :2 0
613 be7 bea 14e
:2 0 45 :2 0 618
bec bee :3 0 153
:2 0 61b bf0 bf1
:3 0 75 :3 0 45
:2 0 bf3 bf4 0
cd4 147 :3 0 75
:3 0 14f :3 0 9d
:3 0 9e :3 0 28
:3 0 a8 :3 0 9e
:3 0 9f :3 0 27
:4 0 154 1 :8 0
c06 15 :3 0 ee
:3 0 c01 c02 0
f1 :3 0 c03 c04
0 c06 61d c59
f2 :3 0 15 :3 0
ee :3 0 c08 c09
0 f1 :3 0 c0a
c0b 0 c0d 620
c0f 622 c0e c0d
:2 0 c57 f3 :3 0
15 :3 0 ee :3 0
c12 c13 0 f1
:3 0 c14 c15 0
c4f d0 :3 0 d1
:3 0 c17 c18 0
d0 :3 0 e0 :3 0
c1a c1b 0 f4
:2 0 2 :4 0 155
:2 0 e2 :2 0 30
:2 0 624 c20 c22
:3 0 627 c1c c24
c19 c26 c25 :2 0
d3 :3 0 e3 :3 0
c28 c29 0 d5
:4 0 156 :4 0 d8
:2 0 d9 :3 0 62b
c2d c2f :3 0 d8
:2 0 f7 :4 0 62e
c31 c33 :3 0 d8
:2 0 f8 :4 0 631
c35 c37 :3 0 d8
:2 0 f1 :3 0 634
c39 c3b :3 0 d8
:2 0 f9 :4 0 637
c3d c3f :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 63a c42 c46
63e c41 c48 :3 0
641 c2a c4a :2 0
c4c 644 c4d c27
c4c 0 c4e 646
0 c4f 648 c52
:3 0 c52 0 c52
c51 c4f c50 :6 0
c54 17 :3 0 64b
c56 64d c55 c54
:2 0 c57 64f :2 0
c59 0 c59 c58
c06 c57 :6 0 cd4
1 :3 0 8f :3 0
75 :3 0 45 :2 0
652 c5b c5e 14e
:2 0 45 :2 0 657
c60 c62 :3 0 d0
:3 0 d1 :3 0 c64
c65 0 d0 :3 0
e0 :3 0 c67 c68
0 1d :2 0 2
:4 0 157 :2 0 e2
:2 0 30 :2 0 65a
c6d c6f :3 0 65d
c69 c71 c66 c73
c72 :2 0 d3 :3 0
e3 :3 0 c75 c76
0 d5 :4 0 158
:4 0 d8 :2 0 d9
:3 0 661 c7a c7c
:3 0 d8 :2 0 f7
:4 0 664 c7e c80
:3 0 d8 :2 0 fe
:4 0 667 c82 c84
:3 0 d8 :2 0 8f
:3 0 dd :3 0 1a
:3 0 159 :3 0 c89
c8a 0 66a c88
c8c de :4 0 66c
c87 c8f 66f c86
c91 :3 0 d8 :2 0
100 :4 0 672 c93
c95 :3 0 d8 :2 0
db :4 0 675 c97
c99 :3 0 d8 :2 0
27 :3 0 678 c9b
c9d :3 0 d8 :2 0
db :4 0 67b c9f
ca1 :3 0 67e c77
ca3 :2 0 ca5 681
ca6 c74 ca5 0
ca7 683 0 cd1
d0 :3 0 d1 :3 0
ca8 ca9 0 d0
:3 0 e0 :3 0 cab
cac 0 30 :2 0
2 :4 0 15a :2 0
e2 :2 0 30 :2 0
685 cb1 cb3 :3 0
688 cad cb5 caa
cb7 cb6 :2 0 d3
:3 0 e3 :3 0 cb9
cba 0 d5 :4 0
15b :4 0 d8 :2 0
d9 :3 0 68c cbe
cc0 :3 0 68f cbb
cc2 :2 0 cc4 692
cc5 cb8 cc4 0
cc6 694 0 cd1
103 :3 0 104 :3 0
cc7 cc8 0 1a
:3 0 159 :3 0 cca
ccb 0 27 :3 0
105 :3 0 696 cc9
ccf :2 0 cd1 69a
cd2 c63 cd1 0
cd3 69e 0 cd4
6a0 cd5 bf2 cd4
0 cd6 6a4 0
cd7 6a6 cd8 b81
cd7 0 cd9 6a9
0 cdb 15c :3 0
6ab de2 15d :3 0
8f :3 0 4b :3 0
45 :2 0 6ad cdd
ce0 6b0 cdc ce2
14e :2 0 45 :2 0
6b4 ce4 ce6 :3 0
8f :3 0 6c :3 0
45 :2 0 6b7 ce8
ceb e7 :2 0 45
:2 0 6bc ced cef
:3 0 8f :3 0 81
:3 0 45 :2 0 6bf
cf1 cf4 e7 :2 0
45 :2 0 6c4 cf6
cf8 :3 0 cf0 cfa
cf9 :2 0 cfb :2 0
ce7 cfd cfc :2 0
75 :3 0 45 :2 0
cff d00 0 de0
147 :3 0 75 :3 0
14f :3 0 9d :3 0
9e :3 0 28 :3 0
9f :3 0 27 :3 0
a0 :3 0 a1 :4 0
15e 1 :8 0 d12
15 :3 0 ee :3 0
d0d d0e 0 f1
:3 0 d0f d10 0
d12 6c7 d65 f2
:3 0 15 :3 0 ee
:3 0 d14 d15 0
f1 :3 0 d16 d17
0 d19 6ca d1b
6cc d1a d19 :2 0
d63 f3 :3 0 15
:3 0 ee :3 0 d1e
d1f 0 f1 :3 0
d20 d21 0 d5b
d0 :3 0 d1 :3 0
d23 d24 0 d0
:3 0 e0 :3 0 d26
d27 0 f4 :2 0
2 :4 0 15f :2 0
e2 :2 0 30 :2 0
6ce d2c d2e :3 0
6d1 d28 d30 d25
d32 d31 :2 0 d3
:3 0 e3 :3 0 d34
d35 0 d5 :4 0
160 :4 0 d8 :2 0
d9 :3 0 6d5 d39
d3b :3 0 d8 :2 0
f7 :4 0 6d8 d3d
d3f :3 0 d8 :2 0
f8 :4 0 6db d41
d43 :3 0 d8 :2 0
f1 :3 0 6de d45
d47 :3 0 d8 :2 0
f9 :4 0 6e1 d49
d4b :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
6e4 d4e d52 6e8
d4d d54 :3 0 6eb
d36 d56 :2 0 d58
6ee d59 d33 d58
0 d5a 6f0 0
d5b 6f2 d5e :3 0
d5e 0 d5e d5d
d5b d5c :6 0 d60
19 :3 0 6f5 d62
6f7 d61 d60 :2 0
d63 6f9 :2 0 d65
0 d65 d64 d12
d63 :6 0 de0 1
:3 0 8f :3 0 75
:3 0 45 :2 0 6fc
d67 d6a 117 :2 0
45 :2 0 701 d6c
d6e :3 0 d0 :3 0
d1 :3 0 d70 d71
0 d0 :3 0 e0
:3 0 d73 d74 0
1d :2 0 2 :4 0
161 :2 0 e2 :2 0
30 :2 0 704 d79
d7b :3 0 707 d75
d7d d72 d7f d7e
:2 0 d3 :3 0 e3
:3 0 d81 d82 0
d5 :4 0 162 :4 0
d8 :2 0 d9 :3 0
70b d86 d88 :3 0
d8 :2 0 f7 :4 0
70e d8a d8c :3 0
d8 :2 0 fe :4 0
711 d8e d90 :3 0
d8 :2 0 8f :3 0
dd :3 0 1a :3 0
159 :3 0 d95 d96
0 714 d94 d98
de :4 0 716 d93
d9b 719 d92 d9d
:3 0 d8 :2 0 100
:4 0 71c d9f da1
:3 0 d8 :2 0 db
:4 0 71f da3 da5
:3 0 d8 :2 0 27
:3 0 722 da7 da9
:3 0 d8 :2 0 db
:4 0 725 dab dad
:3 0 728 d83 daf
:2 0 db1 72b db2
d80 db1 0 db3
72d 0 ddd d0
:3 0 d1 :3 0 db4
db5 0 d0 :3 0
e0 :3 0 db7 db8
0 30 :2 0 2
:4 0 163 :2 0 e2
:2 0 30 :2 0 72f
dbd dbf :3 0 732
db9 dc1 db6 dc3
dc2 :2 0 d3 :3 0
e3 :3 0 dc5 dc6
0 d5 :4 0 164
:4 0 d8 :2 0 d9
:3 0 736 dca dcc
:3 0 739 dc7 dce
:2 0 dd0 73c dd1
dc4 dd0 0 dd2
73e 0 ddd 103
:3 0 104 :3 0 dd3
dd4 0 1a :3 0
159 :3 0 dd6 dd7
0 27 :3 0 105
:3 0 740 dd5 ddb
:2 0 ddd 744 dde
d6f ddd 0 ddf
748 0 de0 74a
de1 cfe de0 0
de3 b78 cdb 0
de3 74e 0 5170
36 :3 0 45 :4 0
de4 de5 0 5170
20 :3 0 eb :4 0
de7 de8 0 5170
21 :3 0 eb :4 0
dea deb 0 5170
23 :4 0 ded dee
0 5170 8b :4 0
df0 df1 0 5170
2a :4 0 df3 df4
0 5170 ec :3 0
9b :4 0 df9 :2 0
5170 df7 dfa :3 0
9b :3 0 5f :4 0
dfe :2 0 5170 dfb
dfc :3 0 9b :3 0
ed :3 0 dff e00
:3 0 15 :3 0 ee
:3 0 e02 e03 0
45 :2 0 e04 e05
0 e07 751 e0e
15 :3 0 ee :3 0
e08 e09 0 ef
:2 0 e0a e0b 0
e0d 753 e0f e01
e07 0 e10 0
e0d 0 e10 755
0 5170 15 :3 0
ee :3 0 e11 e12
0 15 :3 0 e7
:2 0 165 :3 0 e14
e16 0 75a e15
e18 :3 0 e19 :2 0
55 :3 0 45 :2 0
e1b e1c 0 e1e
75d e23 55 :3 0
146 :2 0 e1f e20
0 e22 75f e24
e1a e1e 0 e25
0 e22 0 e25
761 0 5170 f0
:3 0 9b :4 0 e29
:2 0 e2f e27 0
15 :3 0 ee :3 0
e2a e2b 0 f1
:3 0 e2c e2d 0
e2f 764 e82 f2
:3 0 15 :3 0 ee
:3 0 e31 e32 0
f1 :3 0 e33 e34
0 e36 767 e38
769 e37 e36 :2 0
e80 f3 :3 0 15
:3 0 ee :3 0 e3b
e3c 0 f1 :3 0
e3d e3e 0 e78
d0 :3 0 d1 :3 0
e40 e41 0 d0
:3 0 e0 :3 0 e43
e44 0 f4 :2 0
2 :4 0 166 :2 0
e2 :2 0 30 :2 0
76b e49 e4b :3 0
76e e45 e4d e42
e4f e4e :2 0 d3
:3 0 e3 :3 0 e51
e52 0 d5 :4 0
167 :4 0 d8 :2 0
d9 :3 0 772 e56
e58 :3 0 d8 :2 0
f7 :4 0 775 e5a
e5c :3 0 d8 :2 0
f8 :4 0 778 e5e
e60 :3 0 d8 :2 0
f1 :3 0 77b e62
e64 :3 0 d8 :2 0
f9 :4 0 77e e66
e68 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
781 e6b e6f 785
e6a e71 :3 0 788
e53 e73 :2 0 e75
78b e76 e50 e75
0 e77 78d 0
e78 78f e7b :3 0
e7b 0 e7b e7a
e78 e79 :6 0 e7d
1b :3 0 792 e7f
794 e7e e7d :2 0
e80 796 :2 0 e82
0 e82 e81 e2f
e80 :6 0 5170 1
:3 0 8f :3 0 55
:3 0 45 :2 0 799
e84 e87 e7 :2 0
146 :2 0 79e e89
e8b :3 0 8f :3 0
6c :3 0 45 :2 0
7a1 e8d e90 e7
:2 0 146 :2 0 7a6
e92 e94 :3 0 55
:3 0 45 :2 0 e96
e97 0 e99 7a9
e9a e95 e99 0
e9b 7ab 0 e9c
7ad e9d e8c e9c
0 e9e 7af 0
5170 a5 :3 0 168
:3 0 21 :3 0 5e
:3 0 bd :3 0 99
:3 0 28 :3 0 a0
:3 0 36 :3 0 9f
:3 0 27 :4 0 169
1 :8 0 eb0 15
:3 0 ee :3 0 eab
eac 0 f1 :3 0
ead eae 0 eb0
7b1 f03 f2 :3 0
15 :3 0 ee :3 0
eb2 eb3 0 f1
:3 0 eb4 eb5 0
eb7 7b4 eb9 7b6
eb8 eb7 :2 0 f01
f3 :3 0 15 :3 0
ee :3 0 ebc ebd
0 f1 :3 0 ebe
ebf 0 ef9 d0
:3 0 d1 :3 0 ec1
ec2 0 d0 :3 0
e0 :3 0 ec4 ec5
0 f4 :2 0 2
:4 0 16a :2 0 e2
:2 0 30 :2 0 7b8
eca ecc :3 0 7bb
ec6 ece ec3 ed0
ecf :2 0 d3 :3 0
e3 :3 0 ed2 ed3
0 d5 :4 0 16b
:4 0 d8 :2 0 d9
:3 0 7bf ed7 ed9
:3 0 d8 :2 0 f7
:4 0 7c2 edb edd
:3 0 d8 :2 0 f8
:4 0 7c5 edf ee1
:3 0 d8 :2 0 f1
:3 0 7c8 ee3 ee5
:3 0 d8 :2 0 f9
:4 0 7cb ee7 ee9
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 7ce
eec ef0 7d2 eeb
ef2 :3 0 7d5 ed4
ef4 :2 0 ef6 7d8
ef7 ed1 ef6 0
ef8 7da 0 ef9
7dc efc :3 0 efc
0 efc efb ef9
efa :6 0 efe 1d
:3 0 7df f00 7e1
eff efe :2 0 f01
7e3 :2 0 f03 0
f03 f02 eb0 f01
:6 0 5170 1 :3 0
15 :3 0 ee :3 0
f05 f06 0 15
:3 0 e7 :2 0 10d
:3 0 f08 f0a 0
7e8 f09 f0c :3 0
f0d :2 0 8f :3 0
6c :3 0 45 :2 0
7eb f0f f12 14e
:2 0 45 :2 0 7f0
f14 f16 :3 0 153
:2 0 7f3 f18 f19
:3 0 f0e f1b f1a
:2 0 21 :3 0 eb
:4 0 f1d f1e 0
12b2 21 :3 0 16c
:4 0 f21 f22 :3 0
f20 f23 0 12b2
168 :3 0 16d :3 0
5e :3 0 78 :3 0
bd :3 0 99 :3 0
28 :3 0 a0 :3 0
9f :3 0 29 :4 0
16e 1 :8 0 f35
15 :3 0 ee :3 0
f30 f31 0 f1
:3 0 f32 f33 0
f35 7f5 f88 f2
:3 0 15 :3 0 ee
:3 0 f37 f38 0
f1 :3 0 f39 f3a
0 f3c 7f8 f3e
7fa f3d f3c :2 0
f86 f3 :3 0 15
:3 0 ee :3 0 f41
f42 0 f1 :3 0
f43 f44 0 f7e
d0 :3 0 d1 :3 0
f46 f47 0 d0
:3 0 e0 :3 0 f49
f4a 0 f4 :2 0
2 :4 0 16f :2 0
e2 :2 0 30 :2 0
7fc f4f f51 :3 0
7ff f4b f53 f48
f55 f54 :2 0 d3
:3 0 e3 :3 0 f57
f58 0 d5 :4 0
170 :4 0 d8 :2 0
d9 :3 0 803 f5c
f5e :3 0 d8 :2 0
f7 :4 0 806 f60
f62 :3 0 d8 :2 0
f8 :4 0 809 f64
f66 :3 0 d8 :2 0
f1 :3 0 80c f68
f6a :3 0 d8 :2 0
f9 :4 0 80f f6c
f6e :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
812 f71 f75 816
f70 f77 :3 0 819
f59 f79 :2 0 f7b
81c f7c f56 f7b
0 f7d 81e 0
f7e 820 f81 :3 0
f81 0 f81 f80
f7e f7f :6 0 f83
1f :3 0 823 f85
825 f84 f83 :2 0
f86 827 :2 0 f88
0 f88 f87 f35
f86 :6 0 12b2 1
:3 0 15 :3 0 ee
:3 0 f8a f8b 0
15 :3 0 e7 :2 0
165 :3 0 f8d f8f
0 82c f8e f91
:3 0 f92 :2 0 77
:3 0 171 :3 0 172
:3 0 f95 f96 0
8f :3 0 5e :3 0
45 :2 0 82f f98
f9b 1a :3 0 173
:3 0 f9d f9e 0
832 f97 fa0 f94
fa1 0 fa3 835
fb9 7b :3 0 174
:3 0 45 :2 0 8f
:3 0 4a :3 0 45
:2 0 837 fa7 faa
1a :3 0 175 :3 0
fac fad 0 78
:3 0 83a fa5 fb0
fa4 fb1 0 fb8
77 :3 0 1a :3 0
173 :3 0 fb4 fb5
0 fb3 fb6 0
fb8 83f fba f93
fa3 0 fbb 0
fb8 0 fbb 842
0 12b2 76 :3 0
45 :4 0 fbc fbd
0 12b2 7a :3 0
30 :2 0 fbf fc0
0 12b2 7b :3 0
176 :3 0 28 :3 0
27 :3 0 4a :3 0
77 :3 0 78 :3 0
76 :3 0 7a :3 0
845 fc3 fcb fc2
fcc 0 12b2 85
:3 0 177 :3 0 8f
:3 0 4a :3 0 45
:2 0 84d fd0 fd3
850 fcf fd5 fce
fd6 0 12b2 bd
:3 0 a5 :3 0 9e
:3 0 99 :3 0 a9
:3 0 a0 :3 0 9f
:3 0 13c :3 0 168
:3 0 16d :3 0 178
:3 0 179 :3 0 17a
:3 0 21 :3 0 28
:3 0 28 :3 0 4a
:3 0 36 :3 0 27
:3 0 29 :3 0 77
:3 0 78 :3 0 85
:3 0 13 :3 0 d9
:4 0 17b 1 :8 0
1007 ed :4 0 ff2
:3 0 105 :3 0 e7
:2 0 854 ff5 ff6
:3 0 15 :3 0 ee
:3 0 ff8 ff9 0
45 :2 0 ffa ffb
0 ffd 857 1004
15 :3 0 ee :3 0
ffe fff 0 ef
:2 0 1000 1001 0
1003 859 1005 ff7
ffd 0 1006 0
1003 0 1006 85b
0 1007 85e 105a
f2 :3 0 15 :3 0
ee :3 0 1009 100a
0 f1 :3 0 100b
100c 0 100e 861
1010 863 100f 100e
:2 0 1058 f3 :3 0
15 :3 0 ee :3 0
1013 1014 0 f1
:3 0 1015 1016 0
1050 d0 :3 0 d1
:3 0 1018 1019 0
d0 :3 0 e0 :3 0
101b 101c 0 f4
:2 0 2 :4 0 17c
:2 0 e2 :2 0 30
:2 0 865 1021 1023
:3 0 868 101d 1025
101a 1027 1026 :2 0
d3 :3 0 e3 :3 0
1029 102a 0 d5
:4 0 17d :4 0 d8
:2 0 d9 :3 0 86c
102e 1030 :3 0 d8
:2 0 f7 :4 0 86f
1032 1034 :3 0 d8
:2 0 f8 :4 0 872
1036 1038 :3 0 d8
:2 0 f1 :3 0 875
103a 103c :3 0 d8
:2 0 f9 :4 0 878
103e 1040 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 87b 1043 1047
87f 1042 1049 :3 0
882 102b 104b :2 0
104d 885 104e 1028
104d 0 104f 887
0 1050 889 1053
:3 0 1053 0 1053
1052 1050 1051 :6 0
1055 21 :3 0 88c
1057 88e 1056 1055
:2 0 1058 890 :2 0
105a 0 105a 1059
1007 1058 :6 0 12b2
1 :3 0 17e :3 0
41 :3 0 13b :3 0
13c :3 0 29 :4 0
17f 1 :8 0 1067
15 :3 0 ee :3 0
1062 1063 0 f1
:3 0 1064 1065 0
1067 893 10ba f2
:3 0 15 :3 0 ee
:3 0 1069 106a 0
f1 :3 0 106b 106c
0 106e 896 1070
898 106f 106e :2 0
10b8 f3 :3 0 15
:3 0 ee :3 0 1073
1074 0 f1 :3 0
1075 1076 0 10b0
d0 :3 0 d1 :3 0
1078 1079 0 d0
:3 0 e0 :3 0 107b
107c 0 f4 :2 0
2 :4 0 180 :2 0
e2 :2 0 30 :2 0
89a 1081 1083 :3 0
89d 107d 1085 107a
1087 1086 :2 0 d3
:3 0 e3 :3 0 1089
108a 0 d5 :4 0
181 :4 0 d8 :2 0
d9 :3 0 8a1 108e
1090 :3 0 d8 :2 0
f7 :4 0 8a4 1092
1094 :3 0 d8 :2 0
f8 :4 0 8a7 1096
1098 :3 0 d8 :2 0
f1 :3 0 8aa 109a
109c :3 0 d8 :2 0
f9 :4 0 8ad 109e
10a0 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
8b0 10a3 10a7 8b4
10a2 10a9 :3 0 8b7
108b 10ab :2 0 10ad
8ba 10ae 1088 10ad
0 10af 8bc 0
10b0 8be 10b3 :3 0
10b3 0 10b3 10b2
10b0 10b1 :6 0 10b5
23 :3 0 8c1 10b7
8c3 10b6 10b5 :2 0
10b8 8c5 :2 0 10ba
0 10ba 10b9 1067
10b8 :6 0 12b2 1
:3 0 123 :3 0 140
:3 0 10bc 10bd 0
28 :3 0 26 :3 0
8c8 10be 10c1 e7
:2 0 45 :2 0 8cd
10c3 10c5 :3 0 4c
:3 0 45 :2 0 10c7
10c8 0 10ca 8d0
1133 147 :3 0 a7
:3 0 4c :3 0 9d
:3 0 9e :3 0 28
:3 0 a8 :3 0 26
:3 0 9f :3 0 29
:3 0 a0 :3 0 182
:4 0 183 1 :8 0
10dd 15 :3 0 ee
:3 0 10d8 10d9 0
f1 :3 0 10da 10db
0 10dd 8d2 1130
f2 :3 0 15 :3 0
ee :3 0 10df 10e0
0 f1 :3 0 10e1
10e2 0 10e4 8d5
10e6 8d7 10e5 10e4
:2 0 112e f3 :3 0
15 :3 0 ee :3 0
10e9 10ea 0 f1
:3 0 10eb 10ec 0
1126 d0 :3 0 d1
:3 0 10ee 10ef 0
d0 :3 0 e0 :3 0
10f1 10f2 0 f4
:2 0 2 :4 0 184
:2 0 e2 :2 0 30
:2 0 8d9 10f7 10f9
:3 0 8dc 10f3 10fb
10f0 10fd 10fc :2 0
d3 :3 0 e3 :3 0
10ff 1100 0 d5
:4 0 185 :4 0 d8
:2 0 d9 :3 0 8e0
1104 1106 :3 0 d8
:2 0 f7 :4 0 8e3
1108 110a :3 0 d8
:2 0 f8 :4 0 8e6
110c 110e :3 0 d8
:2 0 f1 :3 0 8e9
1110 1112 :3 0 d8
:2 0 f9 :4 0 8ec
1114 1116 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 8ef 1119 111d
8f3 1118 111f :3 0
8f6 1101 1121 :2 0
1123 8f9 1124 10fe
1123 0 1125 8fb
0 1126 8fd 1129
:3 0 1129 0 1129
1128 1126 1127 :6 0
112b 25 :3 0 900
112d 902 112c 112b
:2 0 112e 904 :2 0
1130 0 1130 112f
10dd 112e :6 0 1132
1 :3 0 907 1134
10c6 10ca 0 1135
0 1132 0 1135
909 0 12b2 8f
:3 0 4c :3 0 45
:2 0 90c 1136 1139
e7 :2 0 45 :2 0
911 113b 113d :3 0
bc :3 0 186 :3 0
187 :3 0 186 :3 0
41 :3 0 3e :3 0
99 :3 0 28 :3 0
9e :3 0 28 :4 0
188 1 :8 0 115f
ed :4 0 114a :3 0
105 :3 0 e7 :2 0
916 114d 114e :3 0
15 :3 0 ee :3 0
1150 1151 0 45
:2 0 1152 1153 0
1155 919 115c 15
:3 0 ee :3 0 1156
1157 0 ef :2 0
1158 1159 0 115b
91b 115d 114f 1155
0 115e 0 115b
0 115e 91d 0
115f 920 11b2 f2
:3 0 15 :3 0 ee
:3 0 1161 1162 0
f1 :3 0 1163 1164
0 1166 923 1168
925 1167 1166 :2 0
11b0 f3 :3 0 15
:3 0 ee :3 0 116b
116c 0 f1 :3 0
116d 116e 0 11a8
d0 :3 0 d1 :3 0
1170 1171 0 d0
:3 0 e0 :3 0 1173
1174 0 f4 :2 0
2 :4 0 189 :2 0
e2 :2 0 30 :2 0
927 1179 117b :3 0
92a 1175 117d 1172
117f 117e :2 0 d3
:3 0 e3 :3 0 1181
1182 0 d5 :4 0
18a :4 0 d8 :2 0
d9 :3 0 92e 1186
1188 :3 0 d8 :2 0
f7 :4 0 931 118a
118c :3 0 d8 :2 0
f8 :4 0 934 118e
1190 :3 0 d8 :2 0
f1 :3 0 937 1192
1194 :3 0 d8 :2 0
f9 :4 0 93a 1196
1198 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
93d 119b 119f 941
119a 11a1 :3 0 944
1183 11a3 :2 0 11a5
947 11a6 1180 11a5
0 11a7 949 0
11a8 94b 11ab :3 0
11ab 0 11ab 11aa
11a8 11a9 :6 0 11ad
27 :3 0 94e 11af
950 11ae 11ad :2 0
11b0 952 :2 0 11b2
0 11b2 11b1 115f
11b0 :6 0 1230 1
:3 0 bc :3 0 186
:3 0 18b :3 0 186
:3 0 3e :3 0 186
:3 0 18c :3 0 3e
:3 0 18c :3 0 186
:3 0 186 :3 0 186
:3 0 3e :3 0 9e
:3 0 28 :3 0 99
:3 0 28 :4 0 18d
1 :8 0 11db ed
:4 0 11c6 :3 0 105
:3 0 e7 :2 0 957
11c9 11ca :3 0 15
:3 0 ee :3 0 11cc
11cd 0 45 :2 0
11ce 11cf 0 11d1
95a 11d8 15 :3 0
ee :3 0 11d2 11d3
0 ef :2 0 11d4
11d5 0 11d7 95c
11d9 11cb 11d1 0
11da 0 11d7 0
11da 95e 0 11db
961 122e f2 :3 0
15 :3 0 ee :3 0
11dd 11de 0 f1
:3 0 11df 11e0 0
11e2 964 11e4 966
11e3 11e2 :2 0 122c
f3 :3 0 15 :3 0
ee :3 0 11e7 11e8
0 f1 :3 0 11e9
11ea 0 1224 d0
:3 0 d1 :3 0 11ec
11ed 0 d0 :3 0
e0 :3 0 11ef 11f0
0 f4 :2 0 2
:4 0 18e :2 0 e2
:2 0 30 :2 0 968
11f5 11f7 :3 0 96b
11f1 11f9 11ee 11fb
11fa :2 0 d3 :3 0
e3 :3 0 11fd 11fe
0 d5 :4 0 18f
:4 0 d8 :2 0 d9
:3 0 96f 1202 1204
:3 0 d8 :2 0 f7
:4 0 972 1206 1208
:3 0 d8 :2 0 f8
:4 0 975 120a 120c
:3 0 d8 :2 0 f1
:3 0 978 120e 1210
:3 0 d8 :2 0 f9
:4 0 97b 1212 1214
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 97e
1217 121b 982 1216
121d :3 0 985 11ff
121f :2 0 1221 988
1222 11fc 1221 0
1223 98a 0 1224
98c 1227 :3 0 1227
0 1227 1226 1224
1225 :6 0 1229 29
:3 0 98f 122b 991
122a 1229 :2 0 122c
993 :2 0 122e 0
122e 122d 11db 122c
:6 0 1230 1 :3 0
996 12ae bc :3 0
186 :3 0 18b :3 0
186 :3 0 3e :3 0
186 :3 0 18c :3 0
3e :3 0 18c :3 0
186 :3 0 186 :3 0
186 :3 0 3e :3 0
9e :3 0 28 :3 0
99 :3 0 28 :4 0
18d 1 :8 0 1258
ed :4 0 1243 :3 0
105 :3 0 e7 :2 0
99b 1246 1247 :3 0
15 :3 0 ee :3 0
1249 124a 0 45
:2 0 124b 124c 0
124e 99e 1255 15
:3 0 ee :3 0 124f
1250 0 ef :2 0
1251 1252 0 1254
9a0 1256 1248 124e
0 1257 0 1254
0 1257 9a2 0
1258 9a5 12ab f2
:3 0 15 :3 0 ee
:3 0 125a 125b 0
f1 :3 0 125c 125d
0 125f 9a8 1261
9aa 1260 125f :2 0
12a9 f3 :3 0 15
:3 0 ee :3 0 1264
1265 0 f1 :3 0
1266 1267 0 12a1
d0 :3 0 d1 :3 0
1269 126a 0 d0
:3 0 e0 :3 0 126c
126d 0 f4 :2 0
2 :4 0 190 :2 0
e2 :2 0 30 :2 0
9ac 1272 1274 :3 0
9af 126e 1276 126b
1278 1277 :2 0 d3
:3 0 e3 :3 0 127a
127b 0 d5 :4 0
191 :4 0 d8 :2 0
d9 :3 0 9b3 127f
1281 :3 0 d8 :2 0
f7 :4 0 9b6 1283
1285 :3 0 d8 :2 0
f8 :4 0 9b9 1287
1289 :3 0 d8 :2 0
f1 :3 0 9bc 128b
128d :3 0 d8 :2 0
f9 :4 0 9bf 128f
1291 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
9c2 1294 1298 9c6
1293 129a :3 0 9c9
127c 129c :2 0 129e
9cc 129f 1279 129e
0 12a0 9ce 0
12a1 9d0 12a4 :3 0
12a4 0 12a4 12a3
12a1 12a2 :6 0 12a6
2b :3 0 9d3 12a8
9d5 12a7 12a6 :2 0
12a9 9d7 :2 0 12ab
0 12ab 12aa 1258
12a9 :6 0 12ad 1
:3 0 9da 12af 113e
1230 0 12b0 0
12ad 0 12b0 9dc
0 12b2 15c :3 0
9df 156a 15 :3 0
ee :3 0 12b3 12b4
0 15 :3 0 e7
:2 0 165 :3 0 12b6
12b8 0 9ee 12b7
12ba :3 0 12bb :2 0
2f :3 0 45 :4 0
12bd 12be 0 1568
a7 :3 0 23 :3 0
9d :3 0 a5 :3 0
21 :3 0 182 :4 0
192 1 :8 0 12cc
15 :3 0 ee :3 0
12c7 12c8 0 f1
:3 0 12c9 12ca 0
12cc 9f1 131f f2
:3 0 15 :3 0 ee
:3 0 12ce 12cf 0
f1 :3 0 12d0 12d1
0 12d3 9f4 12d5
9f6 12d4 12d3 :2 0
131d f3 :3 0 15
:3 0 ee :3 0 12d8
12d9 0 f1 :3 0
12da 12db 0 1315
d0 :3 0 d1 :3 0
12dd 12de 0 d0
:3 0 e0 :3 0 12e0
12e1 0 f4 :2 0
2 :4 0 193 :2 0
e2 :2 0 30 :2 0
9f8 12e6 12e8 :3 0
9fb 12e2 12ea 12df
12ec 12eb :2 0 d3
:3 0 e3 :3 0 12ee
12ef 0 d5 :4 0
194 :4 0 d8 :2 0
d9 :3 0 9ff 12f3
12f5 :3 0 d8 :2 0
f7 :4 0 a02 12f7
12f9 :3 0 d8 :2 0
f8 :4 0 a05 12fb
12fd :3 0 d8 :2 0
f1 :3 0 a08 12ff
1301 :3 0 d8 :2 0
f9 :4 0 a0b 1303
1305 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
a0e 1308 130c a12
1307 130e :3 0 a15
12f0 1310 :2 0 1312
a18 1313 12ed 1312
0 1314 a1a 0
1315 a1c 1318 :3 0
1318 0 1318 1317
1315 1316 :6 0 131a
2d :3 0 a1f 131c
a21 131b 131a :2 0
131d a23 :2 0 131f
0 131f 131e 12cc
131d :6 0 1568 1
:3 0 15 :3 0 ee
:3 0 1321 1322 0
15 :3 0 e7 :2 0
10d :3 0 1324 1326
0 a28 1325 1328
:3 0 1329 :2 0 a7
:3 0 23 :3 0 9d
:3 0 a5 :3 0 21
:3 0 182 :4 0 195
1 :8 0 1337 15
:3 0 ee :3 0 1332
1333 0 f1 :3 0
1334 1335 0 1337
a2b 138a f2 :3 0
15 :3 0 ee :3 0
1339 133a 0 f1
:3 0 133b 133c 0
133e a2e 1340 a30
133f 133e :2 0 1388
f3 :3 0 15 :3 0
ee :3 0 1343 1344
0 f1 :3 0 1345
1346 0 1380 d0
:3 0 d1 :3 0 1348
1349 0 d0 :3 0
e0 :3 0 134b 134c
0 f4 :2 0 2
:4 0 196 :2 0 e2
:2 0 30 :2 0 a32
1351 1353 :3 0 a35
134d 1355 134a 1357
1356 :2 0 d3 :3 0
e3 :3 0 1359 135a
0 d5 :4 0 197
:4 0 d8 :2 0 d9
:3 0 a39 135e 1360
:3 0 d8 :2 0 f7
:4 0 a3c 1362 1364
:3 0 d8 :2 0 f8
:4 0 a3f 1366 1368
:3 0 d8 :2 0 f1
:3 0 a42 136a 136c
:3 0 d8 :2 0 f9
:4 0 a45 136e 1370
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 a48
1373 1377 a4c 1372
1379 :3 0 a4f 135b
137b :2 0 137d a52
137e 1358 137d 0
137f a54 0 1380
a56 1383 :3 0 1383
0 1383 1382 1380
1381 :6 0 1385 2f
:3 0 a59 1387 a5b
1386 1385 :2 0 1388
a5d :2 0 138a 0
138a 1389 1337 1388
:6 0 139c 1 :3 0
15 :3 0 ee :3 0
138c 138d 0 15
:3 0 e7 :2 0 165
:3 0 138f 1391 0
a62 1390 1393 :3 0
1394 :2 0 2f :3 0
146 :4 0 1396 1397
0 1399 a65 139a
1395 1399 0 139b
a67 0 139c a69
139d 132a 139c 0
139e a6c 0 1568
8f :3 0 6c :3 0
45 :2 0 a6e 139f
13a2 14e :2 0 45
:2 0 a73 13a4 13a6
:3 0 153 :2 0 a76
13a8 13a9 :3 0 8f
:3 0 5e :3 0 45
:2 0 a78 13ab 13ae
1a :3 0 e7 :2 0
198 :3 0 13b0 13b2
0 a7d 13b1 13b4
:3 0 7b :3 0 174
:3 0 45 :2 0 8f
:3 0 4a :3 0 45
:2 0 a80 13b9 13bc
1a :3 0 175 :3 0
13be 13bf 0 78
:3 0 a83 13b7 13c2
13b6 13c3 0 1441
bd :3 0 13c :3 0
29 :3 0 168 :3 0
1a :3 0 173 :3 0
16d :3 0 78 :3 0
a5 :3 0 21 :4 0
199 1 :8 0 13e5
ed :4 0 13d0 :3 0
105 :3 0 e7 :2 0
a8a 13d3 13d4 :3 0
15 :3 0 ee :3 0
13d6 13d7 0 45
:2 0 13d8 13d9 0
13db a8d 13e2 15
:3 0 ee :3 0 13dc
13dd 0 ef :2 0
13de 13df 0 13e1
a8f 13e3 13d5 13db
0 13e4 0 13e1
0 13e4 a91 0
13e5 a94 1438 f2
:3 0 15 :3 0 ee
:3 0 13e7 13e8 0
f1 :3 0 13e9 13ea
0 13ec a97 13ee
a99 13ed 13ec :2 0
1436 f3 :3 0 15
:3 0 ee :3 0 13f1
13f2 0 f1 :3 0
13f3 13f4 0 142e
d0 :3 0 d1 :3 0
13f6 13f7 0 d0
:3 0 e0 :3 0 13f9
13fa 0 f4 :2 0
2 :4 0 19a :2 0
e2 :2 0 30 :2 0
a9b 13ff 1401 :3 0
a9e 13fb 1403 13f8
1405 1404 :2 0 d3
:3 0 e3 :3 0 1407
1408 0 d5 :4 0
19b :4 0 d8 :2 0
d9 :3 0 aa2 140c
140e :3 0 d8 :2 0
f7 :4 0 aa5 1410
1412 :3 0 d8 :2 0
f8 :4 0 aa8 1414
1416 :3 0 d8 :2 0
f1 :3 0 aab 1418
141a :3 0 d8 :2 0
f9 :4 0 aae 141c
141e :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
ab1 1421 1425 ab5
1420 1427 :3 0 ab8
1409 1429 :2 0 142b
abb 142c 1406 142b
0 142d abd 0
142e abf 1431 :3 0
1431 0 1431 1430
142e 142f :6 0 1433
31 :3 0 ac2 1435
ac4 1434 1433 :2 0
1436 ac6 :2 0 1438
0 1438 1437 13e5
1436 :6 0 1441 1
:3 0 7b :3 0 19c
:3 0 21 :3 0 ac9
143b 143d 143a 143e
0 1441 15c :3 0
acb 1563 e5 :3 0
8f :3 0 5e :3 0
45 :2 0 acf 1443
1446 1a :3 0 173
:3 0 1448 1449 0
ad2 1442 144b 144c
:2 0 1a :3 0 14e
:2 0 173 :3 0 144e
1450 0 ad7 144f
1452 :3 0 bd :3 0
13c :3 0 29 :3 0
168 :3 0 19d :3 0
172 :3 0 168 :3 0
1a :3 0 173 :3 0
a5 :3 0 21 :4 0
19e 1 :8 0 1475
ed :4 0 1460 :3 0
105 :3 0 e7 :2 0
adc 1463 1464 :3 0
15 :3 0 ee :3 0
1466 1467 0 45
:2 0 1468 1469 0
146b adf 1472 15
:3 0 ee :3 0 146c
146d 0 ef :2 0
146e 146f 0 1471
ae1 1473 1465 146b
0 1474 0 1471
0 1474 ae3 0
1475 ae6 14c8 f2
:3 0 15 :3 0 ee
:3 0 1477 1478 0
f1 :3 0 1479 147a
0 147c ae9 147e
aeb 147d 147c :2 0
14c6 f3 :3 0 15
:3 0 ee :3 0 1481
1482 0 f1 :3 0
1483 1484 0 14be
d0 :3 0 d1 :3 0
1486 1487 0 d0
:3 0 e0 :3 0 1489
148a 0 f4 :2 0
2 :4 0 19f :2 0
e2 :2 0 30 :2 0
aed 148f 1491 :3 0
af0 148b 1493 1488
1495 1494 :2 0 d3
:3 0 e3 :3 0 1497
1498 0 d5 :4 0
1a0 :4 0 d8 :2 0
d9 :3 0 af4 149c
149e :3 0 d8 :2 0
f7 :4 0 af7 14a0
14a2 :3 0 d8 :2 0
f8 :4 0 afa 14a4
14a6 :3 0 d8 :2 0
f1 :3 0 afd 14a8
14aa :3 0 d8 :2 0
f9 :4 0 b00 14ac
14ae :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
b03 14b1 14b5 b07
14b0 14b7 :3 0 b0a
1499 14b9 :2 0 14bb
b0d 14bc 1496 14bb
0 14bd b0f 0
14be b11 14c1 :3 0
14c1 0 14c1 14c0
14be 14bf :6 0 14c3
33 :3 0 b14 14c5
b16 14c4 14c3 :2 0
14c6 b18 :2 0 14c8
0 14c8 14c7 1475
14c6 :6 0 14d1 1
:3 0 7b :3 0 19c
:3 0 21 :3 0 b1b
14cb 14cd 14ca 14ce
0 14d1 15c :3 0
b1d 14d2 1453 14d1
0 1564 e5 :3 0
8f :3 0 5e :3 0
45 :2 0 b20 14d4
14d7 1a :3 0 1a1
:3 0 14d9 14da 0
b23 14d3 14dc 14dd
:2 0 1a :3 0 14e
:2 0 1a1 :3 0 14df
14e1 0 b28 14e0
14e3 :3 0 bd :3 0
13c :3 0 29 :3 0
168 :3 0 19d :3 0
172 :3 0 168 :3 0
1a :3 0 1a1 :3 0
a5 :3 0 21 :4 0
1a2 1 :8 0 1506
ed :4 0 14f1 :3 0
105 :3 0 e7 :2 0
b2d 14f4 14f5 :3 0
15 :3 0 ee :3 0
14f7 14f8 0 45
:2 0 14f9 14fa 0
14fc b30 1503 15
:3 0 ee :3 0 14fd
14fe 0 ef :2 0
14ff 1500 0 1502
b32 1504 14f6 14fc
0 1505 0 1502
0 1505 b34 0
1506 b37 1559 f2
:3 0 15 :3 0 ee
:3 0 1508 1509 0
f1 :3 0 150a 150b
0 150d b3a 150f
b3c 150e 150d :2 0
1557 f3 :3 0 15
:3 0 ee :3 0 1512
1513 0 f1 :3 0
1514 1515 0 154f
d0 :3 0 d1 :3 0
1517 1518 0 d0
:3 0 e0 :3 0 151a
151b 0 f4 :2 0
2 :4 0 1a3 :2 0
e2 :2 0 30 :2 0
b3e 1520 1522 :3 0
b41 151c 1524 1519
1526 1525 :2 0 d3
:3 0 e3 :3 0 1528
1529 0 d5 :4 0
1a4 :4 0 d8 :2 0
d9 :3 0 b45 152d
152f :3 0 d8 :2 0
f7 :4 0 b48 1531
1533 :3 0 d8 :2 0
f8 :4 0 b4b 1535
1537 :3 0 d8 :2 0
f1 :3 0 b4e 1539
153b :3 0 d8 :2 0
f9 :4 0 b51 153d
153f :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
b54 1542 1546 b58
1541 1548 :3 0 b5b
152a 154a :2 0 154c
b5e 154d 1527 154c
0 154e b60 0
154f b62 1552 :3 0
1552 0 1552 1551
154f 1550 :6 0 1554
35 :3 0 b65 1556
b67 1555 1554 :2 0
1557 b69 :2 0 1559
0 1559 1558 1506
1557 :6 0 1561 1
:3 0 7b :3 0 19c
:3 0 21 :3 0 b6c
155c 155e 155b 155f
0 1561 b6e 1562
14e4 1561 0 1564
13b5 1441 0 1564
b71 0 1565 b75
1566 13aa 1565 0
1567 b77 0 1568
b79 1569 12bc 1568
0 156b f1c 12b2
0 156b b7e 0
5170 68 :3 0 1a5
:3 0 122 :3 0 67
:3 0 123 :3 0 124
:3 0 125 :3 0 126
:3 0 67 :3 0 132
:3 0 1a5 :3 0 127
:3 0 128 :3 0 125
:3 0 1a5 :3 0 122
:3 0 125 :3 0 99
:3 0 1a5 :3 0 122
:3 0 9f :3 0 27
:4 0 1a6 1 :8 0
1588 15 :3 0 ee
:3 0 1583 1584 0
f1 :3 0 1585 1586
0 1588 b81 15db
f2 :3 0 15 :3 0
ee :3 0 158a 158b
0 f1 :3 0 158c
158d 0 158f b84
1591 b86 1590 158f
:2 0 15d9 f3 :3 0
15 :3 0 ee :3 0
1594 1595 0 f1
:3 0 1596 1597 0
15d1 d0 :3 0 d1
:3 0 1599 159a 0
d0 :3 0 e0 :3 0
159c 159d 0 f4
:2 0 2 :4 0 1a7
:2 0 e2 :2 0 30
:2 0 b88 15a2 15a4
:3 0 b8b 159e 15a6
159b 15a8 15a7 :2 0
d3 :3 0 e3 :3 0
15aa 15ab 0 d5
:4 0 1a8 :4 0 d8
:2 0 d9 :3 0 b8f
15af 15b1 :3 0 d8
:2 0 f7 :4 0 b92
15b3 15b5 :3 0 d8
:2 0 f8 :4 0 b95
15b7 15b9 :3 0 d8
:2 0 f1 :3 0 b98
15bb 15bd :3 0 d8
:2 0 f9 :4 0 b9b
15bf 15c1 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 b9e 15c4 15c8
ba2 15c3 15ca :3 0
ba5 15ac 15cc :2 0
15ce ba8 15cf 15a9
15ce 0 15d0 baa
0 15d1 bac 15d4
:3 0 15d4 0 15d4
15d3 15d1 15d2 :6 0
15d6 37 :3 0 baf
15d8 bb1 15d7 15d6
:2 0 15d9 bb3 :2 0
15db 0 15db 15da
1588 15d9 :6 0 5170
1 :3 0 15 :3 0
ee :3 0 15dd 15de
0 15 :3 0 14e
:2 0 165 :3 0 15e0
15e2 0 bb8 15e1
15e4 :3 0 15e5 :2 0
67 :3 0 1a9 :2 0
15e7 15e8 0 15ea
bbb 15eb 15e6 15ea
0 15ec bbd 0
5170 71 :3 0 eb
:4 0 15ed 15ee 0
5170 73 :3 0 eb
:4 0 15f0 15f1 0
5170 2c :3 0 eb
:4 0 15f3 15f4 0
5170 7b :3 0 1aa
:4 0 15f7 15f8 :3 0
15f6 15f9 0 5170
8f :3 0 6a :3 0
45 :2 0 bbf 15fb
15fe e7 :2 0 45
:2 0 bc4 1600 1602
:3 0 1603 :2 0 8f
:3 0 6b :3 0 45
:2 0 bc7 1605 1608
e7 :2 0 45 :2 0
bcc 160a 160c :3 0
160d :2 0 1604 160f
160e :2 0 7b :3 0
1ab :3 0 28 :3 0
27 :3 0 36 :3 0
71 :3 0 73 :3 0
90 :3 0 62 :3 0
65 :3 0 64 :3 0
66 :3 0 bcf 1612
161d 1611 161e 0
1674 8f :3 0 6b
:3 0 45 :2 0 bda
1620 1623 e7 :2 0
45 :2 0 bdf 1625
1627 :3 0 62 :3 0
8f :3 0 62 :3 0
45 :2 0 be2 162a
162d 1ac :2 0 8f
:3 0 67 :3 0 45
:2 0 be5 1630 1633
be8 162f 1635 :3 0
1629 1636 0 1647
65 :3 0 8f :3 0
65 :3 0 45 :2 0
beb 1639 163c 1ac
:2 0 8f :3 0 67
:3 0 45 :2 0 bee
163f 1642 bf1 163e
1644 :3 0 1638 1645
0 1647 bf4 1648
1628 1647 0 1649
bf7 0 1674 8f
:3 0 6a :3 0 45
:2 0 bf9 164a 164d
e7 :2 0 45 :2 0
bfe 164f 1651 :3 0
64 :3 0 8f :3 0
64 :3 0 45 :2 0
c01 1654 1657 1ac
:2 0 8f :3 0 67
:3 0 45 :2 0 c04
165a 165d c07 1659
165f :3 0 1653 1660
0 1671 66 :3 0
8f :3 0 66 :3 0
45 :2 0 c0a 1663
1666 1ac :2 0 8f
:3 0 67 :3 0 45
:2 0 c0d 1669 166c
c10 1668 166e :3 0
1662 166f 0 1671
c13 1672 1652 1671
0 1673 c16 0
1674 c18 1675 1610
1674 0 1676 c1c
0 5170 54 :3 0
45 :2 0 1677 1678
0 5170 4c :3 0
45 :2 0 167a 167b
0 5170 1ad :3 0
96 :3 0 44 :3 0
97 :3 0 99 :3 0
27 :4 0 1ae 1
:8 0 1689 15 :3 0
ee :3 0 1684 1685
0 f1 :3 0 1686
1687 0 1689 c1e
16dc f2 :3 0 15
:3 0 ee :3 0 168b
168c 0 f1 :3 0
168d 168e 0 1690
c21 1692 c23 1691
1690 :2 0 16da f3
:3 0 15 :3 0 ee
:3 0 1695 1696 0
f1 :3 0 1697 1698
0 16d2 d0 :3 0
d1 :3 0 169a 169b
0 d0 :3 0 e0
:3 0 169d 169e 0
f4 :2 0 2 :4 0
1af :2 0 e2 :2 0
30 :2 0 c25 16a3
16a5 :3 0 c28 169f
16a7 169c 16a9 16a8
:2 0 d3 :3 0 e3
:3 0 16ab 16ac 0
d5 :4 0 1b0 :4 0
d8 :2 0 d9 :3 0
c2c 16b0 16b2 :3 0
d8 :2 0 f7 :4 0
c2f 16b4 16b6 :3 0
d8 :2 0 f8 :4 0
c32 16b8 16ba :3 0
d8 :2 0 f1 :3 0
c35 16bc 16be :3 0
d8 :2 0 f9 :4 0
c38 16c0 16c2 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 c3b 16c5
16c9 c3f 16c4 16cb
:3 0 c42 16ad 16cd
:2 0 16cf c45 16d0
16aa 16cf 0 16d1
c47 0 16d2 c49
16d5 :3 0 16d5 0
16d5 16d4 16d2 16d3
:6 0 16d7 39 :3 0
c4c 16d9 c4e 16d8
16d7 :2 0 16da c50
:2 0 16dc 0 16dc
16db 1689 16da :6 0
5170 1 :3 0 8b
:4 0 16de 16df 0
5170 a7 :3 0 b3
:3 0 8b :3 0 82
:3 0 9d :3 0 9e
:3 0 28 :3 0 a8
:3 0 28 :3 0 9f
:3 0 29 :3 0 a0
:4 0 1b1 1 :8 0
16f3 15 :3 0 ee
:3 0 16ee 16ef 0
f1 :3 0 16f0 16f1
0 16f3 c53 1746
f2 :3 0 15 :3 0
ee :3 0 16f5 16f6
0 f1 :3 0 16f7
16f8 0 16fa c56
16fc c58 16fb 16fa
:2 0 1744 f3 :3 0
15 :3 0 ee :3 0
16ff 1700 0 f1
:3 0 1701 1702 0
173c d0 :3 0 d1
:3 0 1704 1705 0
d0 :3 0 e0 :3 0
1707 1708 0 f4
:2 0 2 :4 0 1b2
:2 0 e2 :2 0 30
:2 0 c5a 170d 170f
:3 0 c5d 1709 1711
1706 1713 1712 :2 0
d3 :3 0 e3 :3 0
1715 1716 0 d5
:4 0 1b3 :4 0 d8
:2 0 d9 :3 0 c61
171a 171c :3 0 d8
:2 0 f7 :4 0 c64
171e 1720 :3 0 d8
:2 0 f8 :4 0 c67
1722 1724 :3 0 d8
:2 0 f1 :3 0 c6a
1726 1728 :3 0 d8
:2 0 f9 :4 0 c6d
172a 172c :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 c70 172f 1733
c74 172e 1735 :3 0
c77 1717 1737 :2 0
1739 c7a 173a 1714
1739 0 173b c7c
0 173c c7e 173f
:3 0 173f 0 173f
173e 173c 173d :6 0
1741 3b :3 0 c81
1743 c83 1742 1741
:2 0 1744 c85 :2 0
1746 0 1746 1745
16f3 1744 :6 0 5170
1 :3 0 1b4 :3 0
1b5 :3 0 82 :3 0
79 :3 0 113 :3 0
9e :3 0 28 :4 0
1b6 1 :8 0 1755
15 :3 0 ee :3 0
1750 1751 0 f1
:3 0 1752 1753 0
1755 c88 17a8 f2
:3 0 15 :3 0 ee
:3 0 1757 1758 0
f1 :3 0 1759 175a
0 175c c8b 175e
c8d 175d 175c :2 0
17a6 f3 :3 0 15
:3 0 ee :3 0 1761
1762 0 f1 :3 0
1763 1764 0 179e
d0 :3 0 d1 :3 0
1766 1767 0 d0
:3 0 e0 :3 0 1769
176a 0 f4 :2 0
2 :4 0 1b7 :2 0
e2 :2 0 30 :2 0
c8f 176f 1771 :3 0
c92 176b 1773 1768
1775 1774 :2 0 d3
:3 0 e3 :3 0 1777
1778 0 d5 :4 0
1b8 :4 0 d8 :2 0
d9 :3 0 c96 177c
177e :3 0 d8 :2 0
f7 :4 0 c99 1780
1782 :3 0 d8 :2 0
f8 :4 0 c9c 1784
1786 :3 0 d8 :2 0
f1 :3 0 c9f 1788
178a :3 0 d8 :2 0
f9 :4 0 ca2 178c
178e :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
ca5 1791 1795 ca9
1790 1797 :3 0 cac
1779 1799 :2 0 179b
caf 179c 1776 179b
0 179d cb1 0
179e cb3 17a1 :3 0
17a1 0 17a1 17a0
179e 179f :6 0 17a3
3d :3 0 cb6 17a5
cb8 17a4 17a3 :2 0
17a6 cba :2 0 17a8
0 17a8 17a7 1755
17a6 :6 0 5170 1
:3 0 123 :3 0 140
:3 0 17aa 17ab 0
28 :3 0 26 :3 0
cbd 17ac 17af 14e
:2 0 45 :2 0 cc2
17b1 17b3 :3 0 153
:2 0 cc5 17b5 17b6
:3 0 8b :3 0 1b9
:2 0 cc7 17b9 17ba
:3 0 17bb :2 0 53
:3 0 45 :2 0 17bd
17be 0 263f a5
:3 0 aa :3 0 ad
:3 0 ae :3 0 ac
:3 0 ad :3 0 ae
:3 0 af :3 0 b3
:3 0 b4 :3 0 b5
:3 0 b6 :3 0 a8
:3 0 ab :3 0 b7
:3 0 b8 :3 0 b9
:3 0 ba :3 0 1c
:3 0 86 :3 0 34
:3 0 35 :3 0 82
:3 0 83 :3 0 7e
:3 0 7f :3 0 26
:3 0 88 :3 0 4d
:3 0 4f :3 0 50
:3 0 51 :3 0 9d
:3 0 a7 :3 0 8b
:4 0 1ba 1 :8 0
17e9 15 :3 0 ee
:3 0 17e4 17e5 0
f1 :3 0 17e6 17e7
0 17e9 cc9 183c
f2 :3 0 15 :3 0
ee :3 0 17eb 17ec
0 f1 :3 0 17ed
17ee 0 17f0 ccc
17f2 cce 17f1 17f0
:2 0 183a f3 :3 0
15 :3 0 ee :3 0
17f5 17f6 0 f1
:3 0 17f7 17f8 0
1832 d0 :3 0 d1
:3 0 17fa 17fb 0
d0 :3 0 e0 :3 0
17fd 17fe 0 f4
:2 0 2 :4 0 1bb
:2 0 e2 :2 0 30
:2 0 cd0 1803 1805
:3 0 cd3 17ff 1807
17fc 1809 1808 :2 0
d3 :3 0 e3 :3 0
180b 180c 0 d5
:4 0 1bc :4 0 d8
:2 0 d9 :3 0 cd7
1810 1812 :3 0 d8
:2 0 f7 :4 0 cda
1814 1816 :3 0 d8
:2 0 f8 :4 0 cdd
1818 181a :3 0 d8
:2 0 f1 :3 0 ce0
181c 181e :3 0 d8
:2 0 f9 :4 0 ce3
1820 1822 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 ce6 1825 1829
cea 1824 182b :3 0
ced 180d 182d :2 0
182f cf0 1830 180a
182f 0 1831 cf2
0 1832 cf4 1835
:3 0 1835 0 1835
1834 1832 1833 :6 0
1837 3f :3 0 cf7
1839 cf9 1838 1837
:2 0 183a cfb :2 0
183c 0 183c 183b
17e9 183a :6 0 263f
1 :3 0 15 :3 0
ee :3 0 183e 183f
0 15 :3 0 e7
:2 0 165 :3 0 1841
1843 0 d00 1842
1845 :3 0 1846 :2 0
8b :3 0 1b9 :2 0
d03 1849 184a :3 0
184b :2 0 184c :2 0
1847 184e 184d :2 0
84 :3 0 1bd :2 0
30 :2 0 d05 1851
1853 :3 0 1850 1854
0 1867 15 :3 0
ee :3 0 1856 1857
0 1be :3 0 28
:3 0 28 :3 0 8b
:3 0 34 :3 0 35
:3 0 7e :3 0 7f
:3 0 84 :3 0 83
:3 0 82 :3 0 d07
1859 1864 1858 1865
0 1867 d12 1868
184f 1867 0 1869
d15 0 263f 61
:3 0 45 :2 0 186a
186b 0 263f 8f
:3 0 80 :3 0 45
:2 0 d17 186d 1870
e7 :2 0 30 :2 0
d1c 1872 1874 :3 0
8f :3 0 51 :3 0
45 :2 0 d1f 1876
1879 8f :3 0 14e
:2 0 f :3 0 45
:2 0 d22 187b 187f
d27 187c 1881 :3 0
8f :3 0 4d :3 0
45 :2 0 d2a 1883
1886 8f :3 0 14e
:2 0 b :3 0 45
:2 0 d2d 1888 188c
d32 1889 188e :3 0
1882 1890 188f :2 0
e5 :3 0 8f :3 0
c :3 0 45 :2 0
d35 1893 1896 1a
:3 0 1bf :3 0 1898
1899 0 d38 1892
189b 14e :2 0 45
:2 0 d3d 189d 189f
:3 0 d0 :3 0 d1
:3 0 18a1 18a2 0
d0 :3 0 e0 :3 0
18a4 18a5 0 1d
:2 0 2 :4 0 1c0
:2 0 e2 :2 0 30
:2 0 d40 18aa 18ac
:3 0 d43 18a6 18ae
18a3 18b0 18af :2 0
d3 :3 0 e3 :3 0
18b2 18b3 0 d5
:4 0 1c1 :4 0 d8
:2 0 d9 :3 0 d47
18b7 18b9 :3 0 d8
:2 0 f7 :4 0 d4a
18bb 18bd :3 0 d8
:2 0 fe :4 0 d4d
18bf 18c1 :3 0 d8
:2 0 8f :3 0 dd
:3 0 1a :3 0 1c2
:3 0 18c6 18c7 0
d50 18c5 18c9 de
:4 0 d52 18c4 18cc
d55 18c3 18ce :3 0
d8 :2 0 100 :4 0
d58 18d0 18d2 :3 0
d8 :2 0 db :4 0
d5b 18d4 18d6 :3 0
d8 :2 0 27 :3 0
d5e 18d8 18da :3 0
d8 :2 0 db :4 0
d61 18dc 18de :3 0
d64 18b4 18e0 :2 0
18e2 d67 18e3 18b1
18e2 0 18e4 d69
0 190e d0 :3 0
d1 :3 0 18e5 18e6
0 d0 :3 0 e0
:3 0 18e8 18e9 0
30 :2 0 2 :4 0
1c3 :2 0 e2 :2 0
30 :2 0 d6b 18ee
18f0 :3 0 d6e 18ea
18f2 18e7 18f4 18f3
:2 0 d3 :3 0 e3
:3 0 18f6 18f7 0
d5 :4 0 1c4 :4 0
d8 :2 0 d9 :3 0
d72 18fb 18fd :3 0
d75 18f8 18ff :2 0
1901 d78 1902 18f5
1901 0 1903 d7a
0 190e 103 :3 0
104 :3 0 1904 1905
0 1a :3 0 1c2
:3 0 1907 1908 0
27 :3 0 105 :3 0
d7c 1906 190c :2 0
190e d80 1922 61
:3 0 30 :2 0 190f
1910 0 1921 8f
:3 0 f :3 0 45
:2 0 d84 1912 1915
e7 :2 0 45 :2 0
d89 1917 1919 :3 0
88 :3 0 45 :2 0
191b 191c 0 191e
d8c 191f 191a 191e
0 1920 d8e 0
1921 d90 1923 18a0
190e 0 1924 0
1921 0 1924 d93
0 1925 d96 1926
1891 1925 0 1927
d98 0 1943 48
:3 0 9 :3 0 1928
1929 0 1943 2a
:3 0 7 :3 0 192b
192c 0 1943 2c
:3 0 8 :3 0 192e
192f 0 1943 4d
:3 0 b :3 0 1931
1932 0 1943 4e
:3 0 10 :3 0 1934
1935 0 1943 4f
:3 0 d :3 0 1937
1938 0 1943 50
:3 0 e :3 0 193a
193b 0 1943 57
:3 0 c :3 0 193d
193e 0 1943 51
:3 0 f :3 0 1940
1941 0 1943 d9a
1944 1875 1943 0
1945 da5 0 263f
15 :3 0 ee :3 0
1946 1947 0 15
:3 0 e7 :2 0 165
:3 0 1949 194b 0
da9 194a 194d :3 0
194e :2 0 92 :3 0
30 :2 0 1950 1951
0 263c 93 :3 0
30 :2 0 1953 1954
0 263c 23 :3 0
1b9 :2 0 dac 1957
1958 :3 0 1959 :2 0
ae :3 0 79 :3 0
30 :2 0 30 :2 0
dae 195b 195f e7
:2 0 1c5 :4 0 db4
1961 1963 :3 0 84
:3 0 1bd :2 0 30
:2 0 db7 1966 1968
:3 0 1965 1969 0
197c 15 :3 0 ee
:3 0 196b 196c 0
1be :3 0 28 :3 0
28 :3 0 23 :3 0
34 :3 0 35 :3 0
7e :3 0 7f :3 0
84 :3 0 83 :3 0
82 :3 0 db9 196e
1979 196d 197a 0
197c dc4 197d 1964
197c 0 197e dc7
0 1dd1 a5 :3 0
ad :3 0 ae :3 0
1c6 :3 0 b3 :3 0
b4 :3 0 aa :3 0
b7 :3 0 b9 :3 0
ba :3 0 107 :3 0
108 :3 0 178 :3 0
20 :3 0 34 :3 0
82 :3 0 83 :3 0
86 :3 0 4d :3 0
50 :3 0 51 :3 0
89 :3 0 8a :3 0
85 :3 0 9d :3 0
a7 :3 0 23 :4 0
1c7 1 :8 0 19a0
15 :3 0 ee :3 0
199b 199c 0 f1
:3 0 199d 199e 0
19a0 dc9 19f3 f2
:3 0 15 :3 0 ee
:3 0 19a2 19a3 0
f1 :3 0 19a4 19a5
0 19a7 dcc 19a9
dce 19a8 19a7 :2 0
19f1 f3 :3 0 15
:3 0 ee :3 0 19ac
19ad 0 f1 :3 0
19ae 19af 0 19e9
d0 :3 0 d1 :3 0
19b1 19b2 0 d0
:3 0 e0 :3 0 19b4
19b5 0 f4 :2 0
2 :4 0 1c8 :2 0
e2 :2 0 30 :2 0
dd0 19ba 19bc :3 0
dd3 19b6 19be 19b3
19c0 19bf :2 0 d3
:3 0 e3 :3 0 19c2
19c3 0 d5 :4 0
1c9 :4 0 d8 :2 0
d9 :3 0 dd7 19c7
19c9 :3 0 d8 :2 0
f7 :4 0 dda 19cb
19cd :3 0 d8 :2 0
f8 :4 0 ddd 19cf
19d1 :3 0 d8 :2 0
f1 :3 0 de0 19d3
19d5 :3 0 d8 :2 0
f9 :4 0 de3 19d7
19d9 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
de6 19dc 19e0 dea
19db 19e2 :3 0 ded
19c4 19e4 :2 0 19e6
df0 19e7 19c1 19e6
0 19e8 df2 0
19e9 df4 19ec :3 0
19ec 0 19ec 19eb
19e9 19ea :6 0 19ee
41 :3 0 df7 19f0
df9 19ef 19ee :2 0
19f1 dfb :2 0 19f3
0 19f3 19f2 19a0
19f1 :6 0 1dd1 1
:3 0 15 :3 0 ee
:3 0 19f5 19f6 0
15 :3 0 e7 :2 0
165 :3 0 19f8 19fa
0 e00 19f9 19fc
:3 0 19fd :2 0 8f
:3 0 51 :3 0 45
:2 0 e03 19ff 1a02
8f :3 0 14e :2 0
f :3 0 45 :2 0
e06 1a04 1a08 e0b
1a05 1a0a :3 0 8f
:3 0 4d :3 0 45
:2 0 e0e 1a0c 1a0f
8f :3 0 14e :2 0
b :3 0 45 :2 0
e11 1a11 1a15 e16
1a12 1a17 :3 0 1a0b
1a19 1a18 :2 0 d0
:3 0 d1 :3 0 1a1b
1a1c 0 d0 :3 0
e0 :3 0 1a1e 1a1f
0 1d :2 0 2
:4 0 1ca :2 0 e2
:2 0 30 :2 0 e19
1a24 1a26 :3 0 e1c
1a20 1a28 1a1d 1a2a
1a29 :2 0 d3 :3 0
e3 :3 0 1a2c 1a2d
0 d5 :4 0 1cb
:4 0 d8 :2 0 d9
:3 0 e20 1a31 1a33
:3 0 d8 :2 0 f7
:4 0 e23 1a35 1a37
:3 0 d8 :2 0 fe
:4 0 e26 1a39 1a3b
:3 0 d8 :2 0 8f
:3 0 dd :3 0 1a
:3 0 1c2 :3 0 1a40
1a41 0 e29 1a3f
1a43 de :4 0 e2b
1a3e 1a46 e2e 1a3d
1a48 :3 0 d8 :2 0
100 :4 0 e31 1a4a
1a4c :3 0 d8 :2 0
db :4 0 e34 1a4e
1a50 :3 0 d8 :2 0
27 :3 0 e37 1a52
1a54 :3 0 d8 :2 0
db :4 0 e3a 1a56
1a58 :3 0 e3d 1a2e
1a5a :2 0 1a5c e40
1a5d 1a2b 1a5c 0
1a5e e42 0 1a88
d0 :3 0 d1 :3 0
1a5f 1a60 0 d0
:3 0 e0 :3 0 1a62
1a63 0 30 :2 0
2 :4 0 1cc :2 0
e2 :2 0 30 :2 0
e44 1a68 1a6a :3 0
e47 1a64 1a6c 1a61
1a6e 1a6d :2 0 d3
:3 0 e3 :3 0 1a70
1a71 0 d5 :4 0
1cd :4 0 d8 :2 0
d9 :3 0 e4b 1a75
1a77 :3 0 e4e 1a72
1a79 :2 0 1a7b e51
1a7c 1a6f 1a7b 0
1a7d e53 0 1a88
103 :3 0 104 :3 0
1a7e 1a7f 0 1a
:3 0 1c2 :3 0 1a81
1a82 0 27 :3 0
105 :3 0 e55 1a80
1a86 :2 0 1a88 e59
1a89 1a1a 1a88 0
1a8a e5d 0 1dcd
53 :3 0 ae :3 0
2f :3 0 30 :2 0
30 :2 0 e5f 1a8c
1a90 e7 :2 0 146
:4 0 e65 1a92 1a94
:3 0 146 :2 0 e68
1a97 1a96 45 :3 0
1a99 0 e6a :2 0
1a8b 1a9b 0 1dcd
8f :3 0 80 :3 0
45 :2 0 e6d 1a9d
1aa0 14e :2 0 45
:2 0 e72 1aa2 1aa4
:3 0 5f :3 0 30
:2 0 1aa6 1aa7 0
1dca 92 :3 0 45
:2 0 1aa9 1aaa 0
1dca 8f :3 0 81
:3 0 45 :2 0 e75
1aac 1aaf 14e :2 0
45 :2 0 e7a 1ab1
1ab3 :3 0 8f :3 0
6c :3 0 45 :2 0
e7d 1ab5 1ab8 14e
:2 0 45 :2 0 e82
1aba 1abc :3 0 1ce
:3 0 1cf :3 0 86
:3 0 1d0 :3 0 9e
:3 0 28 :3 0 a7
:3 0 8b :3 0 1d1
:3 0 8b :4 0 1d2
1 :8 0 1ace 15
:3 0 ee :3 0 1ac9
1aca 0 f1 :3 0
1acb 1acc 0 1ace
e85 1b21 f2 :3 0
15 :3 0 ee :3 0
1ad0 1ad1 0 f1
:3 0 1ad2 1ad3 0
1ad5 e88 1ad7 e8a
1ad6 1ad5 :2 0 1b1f
f3 :3 0 15 :3 0
ee :3 0 1ada 1adb
0 f1 :3 0 1adc
1add 0 1b17 d0
:3 0 d1 :3 0 1adf
1ae0 0 d0 :3 0
e0 :3 0 1ae2 1ae3
0 f4 :2 0 2
:4 0 1d3 :2 0 e2
:2 0 30 :2 0 e8c
1ae8 1aea :3 0 e8f
1ae4 1aec 1ae1 1aee
1aed :2 0 d3 :3 0
e3 :3 0 1af0 1af1
0 d5 :4 0 1d4
:4 0 d8 :2 0 d9
:3 0 e93 1af5 1af7
:3 0 d8 :2 0 f7
:4 0 e96 1af9 1afb
:3 0 d8 :2 0 f8
:4 0 e99 1afd 1aff
:3 0 d8 :2 0 f1
:3 0 e9c 1b01 1b03
:3 0 d8 :2 0 f9
:4 0 e9f 1b05 1b07
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 ea2
1b0a 1b0e ea6 1b09
1b10 :3 0 ea9 1af2
1b12 :2 0 1b14 eac
1b15 1aef 1b14 0
1b16 eae 0 1b17
eb0 1b1a :3 0 1b1a
0 1b1a 1b19 1b17
1b18 :6 0 1b1c 43
:3 0 eb3 1b1e eb5
1b1d 1b1c :2 0 1b1f
eb7 :2 0 1b21 0
1b21 1b20 1ace 1b1f
:6 0 1b23 1 :3 0
eba 1b88 1ce :3 0
1cf :3 0 86 :3 0
1d0 :3 0 9e :3 0
28 :3 0 9f :3 0
29 :4 0 1d5 1
:8 0 1b32 15 :3 0
ee :3 0 1b2d 1b2e
0 f1 :3 0 1b2f
1b30 0 1b32 ebc
1b85 f2 :3 0 15
:3 0 ee :3 0 1b34
1b35 0 f1 :3 0
1b36 1b37 0 1b39
ebf 1b3b ec1 1b3a
1b39 :2 0 1b83 f3
:3 0 15 :3 0 ee
:3 0 1b3e 1b3f 0
f1 :3 0 1b40 1b41
0 1b7b d0 :3 0
d1 :3 0 1b43 1b44
0 d0 :3 0 e0
:3 0 1b46 1b47 0
f4 :2 0 2 :4 0
1d6 :2 0 e2 :2 0
30 :2 0 ec3 1b4c
1b4e :3 0 ec6 1b48
1b50 1b45 1b52 1b51
:2 0 d3 :3 0 e3
:3 0 1b54 1b55 0
d5 :4 0 1d7 :4 0
d8 :2 0 d9 :3 0
eca 1b59 1b5b :3 0
d8 :2 0 f7 :4 0
ecd 1b5d 1b5f :3 0
d8 :2 0 f8 :4 0
ed0 1b61 1b63 :3 0
d8 :2 0 f1 :3 0
ed3 1b65 1b67 :3 0
d8 :2 0 f9 :4 0
ed6 1b69 1b6b :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 ed9 1b6e
1b72 edd 1b6d 1b74
:3 0 ee0 1b56 1b76
:2 0 1b78 ee3 1b79
1b53 1b78 0 1b7a
ee5 0 1b7b ee7
1b7e :3 0 1b7e 0
1b7e 1b7d 1b7b 1b7c
:6 0 1b80 45 :3 0
eea 1b82 eec 1b81
1b80 :2 0 1b83 eee
:2 0 1b85 0 1b85
1b84 1b32 1b83 :6 0
1b87 1 :3 0 ef1
1b89 1abd 1b23 0
1b8a 0 1b87 0
1b8a ef3 0 1b8b
ef6 1b8c 1ab4 1b8b
0 1b8d ef8 0
1dca 8f :3 0 6c
:3 0 45 :2 0 efa
1b8e 1b91 14e :2 0
45 :2 0 eff 1b93
1b95 :3 0 1d0 :3 0
9e :3 0 28 :3 0
a7 :3 0 8b :3 0
1d1 :3 0 8b :4 0
1d8 1 :8 0 1bb4
ed :4 0 1b9f :3 0
105 :3 0 e7 :2 0
f04 1ba2 1ba3 :3 0
15 :3 0 ee :3 0
1ba5 1ba6 0 45
:2 0 1ba7 1ba8 0
1baa f07 1bb1 15
:3 0 ee :3 0 1bab
1bac 0 ef :2 0
1bad 1bae 0 1bb0
f09 1bb2 1ba4 1baa
0 1bb3 0 1bb0
0 1bb3 f0b 0
1bb4 f0e 1c07 f2
:3 0 15 :3 0 ee
:3 0 1bb6 1bb7 0
f1 :3 0 1bb8 1bb9
0 1bbb f11 1bbd
f13 1bbc 1bbb :2 0
1c05 f3 :3 0 15
:3 0 ee :3 0 1bc0
1bc1 0 f1 :3 0
1bc2 1bc3 0 1bfd
d0 :3 0 d1 :3 0
1bc5 1bc6 0 d0
:3 0 e0 :3 0 1bc8
1bc9 0 f4 :2 0
2 :4 0 1d9 :2 0
e2 :2 0 30 :2 0
f15 1bce 1bd0 :3 0
f18 1bca 1bd2 1bc7
1bd4 1bd3 :2 0 d3
:3 0 e3 :3 0 1bd6
1bd7 0 d5 :4 0
1da :4 0 d8 :2 0
d9 :3 0 f1c 1bdb
1bdd :3 0 d8 :2 0
f7 :4 0 f1f 1bdf
1be1 :3 0 d8 :2 0
f8 :4 0 f22 1be3
1be5 :3 0 d8 :2 0
f1 :3 0 f25 1be7
1be9 :3 0 d8 :2 0
f9 :4 0 f28 1beb
1bed :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
f2b 1bf0 1bf4 f2f
1bef 1bf6 :3 0 f32
1bd8 1bf8 :2 0 1bfa
f35 1bfb 1bd5 1bfa
0 1bfc f37 0
1bfd f39 1c00 :3 0
1c00 0 1c00 1bff
1bfd 1bfe :6 0 1c02
47 :3 0 f3c 1c04
f3e 1c03 1c02 :2 0
1c05 f40 :2 0 1c07
0 1c07 1c06 1bb4
1c05 :6 0 1c09 1
:3 0 f43 1dc7 1db
:3 0 9e :3 0 28
:3 0 9f :3 0 29
:4 0 1dc 1 :8 0
1c25 ed :4 0 1c10
:3 0 105 :3 0 e7
:2 0 f47 1c13 1c14
:3 0 15 :3 0 ee
:3 0 1c16 1c17 0
45 :2 0 1c18 1c19
0 1c1b f4a 1c22
15 :3 0 ee :3 0
1c1c 1c1d 0 ef
:2 0 1c1e 1c1f 0
1c21 f4c 1c23 1c15
1c1b 0 1c24 0
1c21 0 1c24 f4e
0 1c25 f51 1c78
f2 :3 0 15 :3 0
ee :3 0 1c27 1c28
0 f1 :3 0 1c29
1c2a 0 1c2c f54
1c2e f56 1c2d 1c2c
:2 0 1c76 f3 :3 0
15 :3 0 ee :3 0
1c31 1c32 0 f1
:3 0 1c33 1c34 0
1c6e d0 :3 0 d1
:3 0 1c36 1c37 0
d0 :3 0 e0 :3 0
1c39 1c3a 0 f4
:2 0 2 :4 0 1dd
:2 0 e2 :2 0 30
:2 0 f58 1c3f 1c41
:3 0 f5b 1c3b 1c43
1c38 1c45 1c44 :2 0
d3 :3 0 e3 :3 0
1c47 1c48 0 d5
:4 0 1de :4 0 d8
:2 0 d9 :3 0 f5f
1c4c 1c4e :3 0 d8
:2 0 f7 :4 0 f62
1c50 1c52 :3 0 d8
:2 0 f8 :4 0 f65
1c54 1c56 :3 0 d8
:2 0 f1 :3 0 f68
1c58 1c5a :3 0 d8
:2 0 f9 :4 0 f6b
1c5c 1c5e :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 f6e 1c61 1c65
f72 1c60 1c67 :3 0
f75 1c49 1c69 :2 0
1c6b f78 1c6c 1c46
1c6b 0 1c6d f7a
0 1c6e f7c 1c71
:3 0 1c71 0 1c71
1c70 1c6e 1c6f :6 0
1c73 49 :3 0 f7f
1c75 f81 1c74 1c73
:2 0 1c76 f83 :2 0
1c78 0 1c78 1c77
1c25 1c76 :6 0 1dc6
1 :3 0 bd :3 0
a5 :3 0 1c :4 0
1df 1 :8 0 1c93
ed :4 0 1c7e :3 0
105 :3 0 e7 :2 0
f88 1c81 1c82 :3 0
15 :3 0 ee :3 0
1c84 1c85 0 45
:2 0 1c86 1c87 0
1c89 f8b 1c90 15
:3 0 ee :3 0 1c8a
1c8b 0 ef :2 0
1c8c 1c8d 0 1c8f
f8d 1c91 1c83 1c89
0 1c92 0 1c8f
0 1c92 f8f 0
1c93 f92 1ce6 f2
:3 0 15 :3 0 ee
:3 0 1c95 1c96 0
f1 :3 0 1c97 1c98
0 1c9a f95 1c9c
f97 1c9b 1c9a :2 0
1ce4 f3 :3 0 15
:3 0 ee :3 0 1c9f
1ca0 0 f1 :3 0
1ca1 1ca2 0 1cdc
d0 :3 0 d1 :3 0
1ca4 1ca5 0 d0
:3 0 e0 :3 0 1ca7
1ca8 0 f4 :2 0
2 :4 0 1e0 :2 0
e2 :2 0 30 :2 0
f99 1cad 1caf :3 0
f9c 1ca9 1cb1 1ca6
1cb3 1cb2 :2 0 d3
:3 0 e3 :3 0 1cb5
1cb6 0 d5 :4 0
1e1 :4 0 d8 :2 0
d9 :3 0 fa0 1cba
1cbc :3 0 d8 :2 0
f7 :4 0 fa3 1cbe
1cc0 :3 0 d8 :2 0
f8 :4 0 fa6 1cc2
1cc4 :3 0 d8 :2 0
f1 :3 0 fa9 1cc6
1cc8 :3 0 d8 :2 0
f9 :4 0 fac 1cca
1ccc :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
faf 1ccf 1cd3 fb3
1cce 1cd5 :3 0 fb6
1cb7 1cd7 :2 0 1cd9
fb9 1cda 1cb4 1cd9
0 1cdb fbb 0
1cdc fbd 1cdf :3 0
1cdf 0 1cdf 1cde
1cdc 1cdd :6 0 1ce1
4b :3 0 fc0 1ce3
fc2 1ce2 1ce1 :2 0
1ce4 fc4 :2 0 1ce6
0 1ce6 1ce5 1c93
1ce4 :6 0 1dc6 1
:3 0 9d :3 0 a7
:3 0 8b :4 0 1e2
1 :8 0 1d01 ed
:4 0 1cec :3 0 105
:3 0 e7 :2 0 fc9
1cef 1cf0 :3 0 15
:3 0 ee :3 0 1cf2
1cf3 0 45 :2 0
1cf4 1cf5 0 1cf7
fcc 1cfe 15 :3 0
ee :3 0 1cf8 1cf9
0 ef :2 0 1cfa
1cfb 0 1cfd fce
1cff 1cf1 1cf7 0
1d00 0 1cfd 0
1d00 fd0 0 1d01
fd3 1d54 f2 :3 0
15 :3 0 ee :3 0
1d03 1d04 0 f1
:3 0 1d05 1d06 0
1d08 fd6 1d0a fd8
1d09 1d08 :2 0 1d52
f3 :3 0 15 :3 0
ee :3 0 1d0d 1d0e
0 f1 :3 0 1d0f
1d10 0 1d4a d0
:3 0 d1 :3 0 1d12
1d13 0 d0 :3 0
e0 :3 0 1d15 1d16
0 f4 :2 0 2
:4 0 1e3 :2 0 e2
:2 0 30 :2 0 fda
1d1b 1d1d :3 0 fdd
1d17 1d1f 1d14 1d21
1d20 :2 0 d3 :3 0
e3 :3 0 1d23 1d24
0 d5 :4 0 1e4
:4 0 d8 :2 0 d9
:3 0 fe1 1d28 1d2a
:3 0 d8 :2 0 f7
:4 0 fe4 1d2c 1d2e
:3 0 d8 :2 0 f8
:4 0 fe7 1d30 1d32
:3 0 d8 :2 0 f1
:3 0 fea 1d34 1d36
:3 0 d8 :2 0 f9
:4 0 fed 1d38 1d3a
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 ff0
1d3d 1d41 ff4 1d3c
1d43 :3 0 ff7 1d25
1d45 :2 0 1d47 ffa
1d48 1d22 1d47 0
1d49 ffc 0 1d4a
ffe 1d4d :3 0 1d4d
0 1d4d 1d4c 1d4a
1d4b :6 0 1d4f 4d
:3 0 1001 1d51 1003
1d50 1d4f :2 0 1d52
1005 :2 0 1d54 0
1d54 1d53 1d01 1d52
:6 0 1dc6 1 :3 0
1d0 :3 0 9e :3 0
28 :3 0 a7 :3 0
8b :4 0 1e5 1
:8 0 1d71 ed :4 0
1d5c :3 0 105 :3 0
e7 :2 0 100a 1d5f
1d60 :3 0 15 :3 0
ee :3 0 1d62 1d63
0 45 :2 0 1d64
1d65 0 1d67 100d
1d6e 15 :3 0 ee
:3 0 1d68 1d69 0
ef :2 0 1d6a 1d6b
0 1d6d 100f 1d6f
1d61 1d67 0 1d70
0 1d6d 0 1d70
1011 0 1d71 1014
1dc4 f2 :3 0 15
:3 0 ee :3 0 1d73
1d74 0 f1 :3 0
1d75 1d76 0 1d78
1017 1d7a 1019 1d79
1d78 :2 0 1dc2 f3
:3 0 15 :3 0 ee
:3 0 1d7d 1d7e 0
f1 :3 0 1d7f 1d80
0 1dba d0 :3 0
d1 :3 0 1d82 1d83
0 d0 :3 0 e0
:3 0 1d85 1d86 0
f4 :2 0 2 :4 0
1e6 :2 0 e2 :2 0
30 :2 0 101b 1d8b
1d8d :3 0 101e 1d87
1d8f 1d84 1d91 1d90
:2 0 d3 :3 0 e3
:3 0 1d93 1d94 0
d5 :4 0 1e7 :4 0
d8 :2 0 d9 :3 0
1022 1d98 1d9a :3 0
d8 :2 0 f7 :4 0
1025 1d9c 1d9e :3 0
d8 :2 0 f8 :4 0
1028 1da0 1da2 :3 0
d8 :2 0 f1 :3 0
102b 1da4 1da6 :3 0
d8 :2 0 f9 :4 0
102e 1da8 1daa :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 1031 1dad
1db1 1035 1dac 1db3
:3 0 1038 1d95 1db5
:2 0 1db7 103b 1db8
1d92 1db7 0 1db9
103d 0 1dba 103f
1dbd :3 0 1dbd 0
1dbd 1dbc 1dba 1dbb
:6 0 1dbf 4f :3 0
1042 1dc1 1044 1dc0
1dbf :2 0 1dc2 1046
:2 0 1dc4 0 1dc4
1dc3 1d71 1dc2 :6 0
1dc6 1 :3 0 1049
1dc8 1b96 1c09 0
1dc9 0 1dc6 0
1dc9 104e 0 1dca
1051 1dcb 1aa5 1dca
0 1dcc 1056 0
1dcd 1058 1dce 19fe
1dcd 0 1dcf 105c
0 1dd1 15c :3 0
105e 1e58 8f :3 0
55 :3 0 45 :2 0
1062 1dd2 1dd5 14e
:2 0 45 :2 0 1067
1dd7 1dd9 :3 0 153
:2 0 106a 1ddb 1ddc
:3 0 8f :3 0 6c
:3 0 45 :2 0 106c
1dde 1de1 14e :2 0
45 :2 0 1071 1de3
1de5 :3 0 1ddd 1de7
1de6 :2 0 d0 :3 0
d1 :3 0 1de9 1dea
0 d0 :3 0 e0
:3 0 1dec 1ded 0
1d :2 0 2 :4 0
1e8 :2 0 e2 :2 0
30 :2 0 1074 1df2
1df4 :3 0 1077 1dee
1df6 1deb 1df8 1df7
:2 0 d3 :3 0 e3
:3 0 1dfa 1dfb 0
d5 :4 0 1e9 :4 0
d8 :2 0 d9 :3 0
107b 1dff 1e01 :3 0
d8 :2 0 f7 :4 0
107e 1e03 1e05 :3 0
d8 :2 0 fe :4 0
1081 1e07 1e09 :3 0
d8 :2 0 8f :3 0
dd :3 0 1a :3 0
159 :3 0 1e0e 1e0f
0 1084 1e0d 1e11
de :4 0 1086 1e0c
1e14 1089 1e0b 1e16
:3 0 d8 :2 0 100
:4 0 108c 1e18 1e1a
:3 0 d8 :2 0 db
:4 0 108f 1e1c 1e1e
:3 0 d8 :2 0 27
:3 0 1092 1e20 1e22
:3 0 d8 :2 0 db
:4 0 1095 1e24 1e26
:3 0 1098 1dfc 1e28
:2 0 1e2a 109b 1e2b
1df9 1e2a 0 1e2c
109d 0 1e56 d0
:3 0 d1 :3 0 1e2d
1e2e 0 d0 :3 0
e0 :3 0 1e30 1e31
0 30 :2 0 2
:4 0 1ea :2 0 e2
:2 0 30 :2 0 109f
1e36 1e38 :3 0 10a2
1e32 1e3a 1e2f 1e3c
1e3b :2 0 d3 :3 0
e3 :3 0 1e3e 1e3f
0 d5 :4 0 1eb
:4 0 d8 :2 0 d9
:3 0 10a6 1e43 1e45
:3 0 10a9 1e40 1e47
:2 0 1e49 10ac 1e4a
1e3d 1e49 0 1e4b
10ae 0 1e56 103
:3 0 104 :3 0 1e4c
1e4d 0 1a :3 0
159 :3 0 1e4f 1e50
0 27 :3 0 105
:3 0 10b0 1e4e 1e54
:2 0 1e56 10b4 1e57
1de8 1e56 0 1e59
195a 1dd1 0 1e59
10b8 0 263c 92
:3 0 14e :2 0 45
:2 0 10bd 1e5b 1e5d
:3 0 23 :3 0 8b
:3 0 1e5f 1e60 0
2317 8f :3 0 6b
:3 0 45 :2 0 10c0
1e62 1e65 e7 :2 0
45 :2 0 10c5 1e67
1e69 :3 0 1e6a :2 0
8f :3 0 6a :3 0
45 :2 0 10c8 1e6c
1e6f e7 :2 0 45
:2 0 10cd 1e71 1e73
:3 0 1e74 :2 0 1e6b
1e76 1e75 :2 0 8f
:3 0 82 :3 0 45
:2 0 10d0 1e78 1e7b
e7 :2 0 45 :2 0
10d5 1e7d 1e7f :3 0
9d :3 0 a5 :3 0
21 :3 0 9f :3 0
27 :3 0 a0 :3 0
b5 :3 0 62 :3 0
1ec :3 0 65 :3 0
b6 :3 0 64 :3 0
1ed :3 0 66 :3 0
ab :3 0 61 :3 0
ab :3 0 88 :3 0
1ee :3 0 aa :3 0
1ef :3 0 62 :3 0
1f0 :3 0 19d :3 0
172 :3 0 1f0 :3 0
1a :3 0 1f1 :3 0
a7 :3 0 23 :4 0
1f2 1 :8 0 1eb5
ed :4 0 1ea0 :3 0
105 :3 0 e7 :2 0
10da 1ea3 1ea4 :3 0
15 :3 0 ee :3 0
1ea6 1ea7 0 45
:2 0 1ea8 1ea9 0
1eab 10dd 1eb2 15
:3 0 ee :3 0 1eac
1ead 0 ef :2 0
1eae 1eaf 0 1eb1
10df 1eb3 1ea5 1eab
0 1eb4 0 1eb1
0 1eb4 10e1 0
1eb5 10e4 1f08 f2
:3 0 15 :3 0 ee
:3 0 1eb7 1eb8 0
f1 :3 0 1eb9 1eba
0 1ebc 10e7 1ebe
10e9 1ebd 1ebc :2 0
1f06 f3 :3 0 15
:3 0 ee :3 0 1ec1
1ec2 0 f1 :3 0
1ec3 1ec4 0 1efe
d0 :3 0 d1 :3 0
1ec6 1ec7 0 d0
:3 0 e0 :3 0 1ec9
1eca 0 f4 :2 0
2 :4 0 1f3 :2 0
e2 :2 0 30 :2 0
10eb 1ecf 1ed1 :3 0
10ee 1ecb 1ed3 1ec8
1ed5 1ed4 :2 0 d3
:3 0 e3 :3 0 1ed7
1ed8 0 d5 :4 0
1f4 :4 0 d8 :2 0
d9 :3 0 10f2 1edc
1ede :3 0 d8 :2 0
f7 :4 0 10f5 1ee0
1ee2 :3 0 d8 :2 0
f8 :4 0 10f8 1ee4
1ee6 :3 0 d8 :2 0
f1 :3 0 10fb 1ee8
1eea :3 0 d8 :2 0
f9 :4 0 10fe 1eec
1eee :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1101 1ef1 1ef5 1105
1ef0 1ef7 :3 0 1108
1ed9 1ef9 :2 0 1efb
110b 1efc 1ed6 1efb
0 1efd 110d 0
1efe 110f 1f01 :3 0
1f01 0 1f01 1f00
1efe 1eff :6 0 1f03
51 :3 0 1112 1f05
1114 1f04 1f03 :2 0
1f06 1116 :2 0 1f08
0 1f08 1f07 1eb5
1f06 :6 0 1f0a 1
:3 0 1119 1f99 9d
:3 0 a5 :3 0 21
:3 0 9f :3 0 27
:3 0 a0 :3 0 b5
:3 0 62 :3 0 1ec
:3 0 65 :3 0 b6
:3 0 64 :3 0 1ed
:3 0 66 :3 0 ab
:3 0 61 :3 0 ab
:3 0 88 :3 0 1ee
:3 0 aa :3 0 1ef
:3 0 62 :3 0 1f5
:3 0 aa :3 0 aa
:3 0 64 :3 0 1f0
:3 0 19d :3 0 172
:3 0 1f0 :3 0 1a
:3 0 1f1 :3 0 a7
:3 0 23 :4 0 1f6
1 :8 0 1f43 ed
:4 0 1f2e :3 0 105
:3 0 e7 :2 0 111d
1f31 1f32 :3 0 15
:3 0 ee :3 0 1f34
1f35 0 45 :2 0
1f36 1f37 0 1f39
1120 1f40 15 :3 0
ee :3 0 1f3a 1f3b
0 ef :2 0 1f3c
1f3d 0 1f3f 1122
1f41 1f33 1f39 0
1f42 0 1f3f 0
1f42 1124 0 1f43
1127 1f96 f2 :3 0
15 :3 0 ee :3 0
1f45 1f46 0 f1
:3 0 1f47 1f48 0
1f4a 112a 1f4c 112c
1f4b 1f4a :2 0 1f94
f3 :3 0 15 :3 0
ee :3 0 1f4f 1f50
0 f1 :3 0 1f51
1f52 0 1f8c d0
:3 0 d1 :3 0 1f54
1f55 0 d0 :3 0
e0 :3 0 1f57 1f58
0 f4 :2 0 2
:4 0 1f7 :2 0 e2
:2 0 30 :2 0 112e
1f5d 1f5f :3 0 1131
1f59 1f61 1f56 1f63
1f62 :2 0 d3 :3 0
e3 :3 0 1f65 1f66
0 d5 :4 0 1f8
:4 0 d8 :2 0 d9
:3 0 1135 1f6a 1f6c
:3 0 d8 :2 0 f7
:4 0 1138 1f6e 1f70
:3 0 d8 :2 0 f8
:4 0 113b 1f72 1f74
:3 0 d8 :2 0 f1
:3 0 113e 1f76 1f78
:3 0 d8 :2 0 f9
:4 0 1141 1f7a 1f7c
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1144
1f7f 1f83 1148 1f7e
1f85 :3 0 114b 1f67
1f87 :2 0 1f89 114e
1f8a 1f64 1f89 0
1f8b 1150 0 1f8c
1152 1f8f :3 0 1f8f
0 1f8f 1f8e 1f8c
1f8d :6 0 1f91 53
:3 0 1155 1f93 1157
1f92 1f91 :2 0 1f94
1159 :2 0 1f96 0
1f96 1f95 1f43 1f94
:6 0 1f98 1 :3 0
115c 1f9a 1e80 1f0a
0 1f9b 0 1f98
0 1f9b 115e 0
1f9d 15c :3 0 1161
21c6 8f :3 0 6b
:3 0 45 :2 0 1163
1f9e 1fa1 e7 :2 0
45 :2 0 1168 1fa3
1fa5 :3 0 9d :3 0
a5 :3 0 21 :3 0
9f :3 0 27 :3 0
a0 :3 0 b5 :3 0
62 :3 0 1ec :3 0
65 :3 0 ab :3 0
61 :3 0 ab :3 0
88 :3 0 1ee :3 0
aa :3 0 1ef :3 0
62 :3 0 1f0 :3 0
19d :3 0 172 :3 0
1f0 :3 0 1a :3 0
1f1 :3 0 a7 :3 0
23 :4 0 1f9 1
:8 0 1fd7 ed :4 0
1fc2 :3 0 105 :3 0
e7 :2 0 116d 1fc5
1fc6 :3 0 15 :3 0
ee :3 0 1fc8 1fc9
0 45 :2 0 1fca
1fcb 0 1fcd 1170
1fd4 15 :3 0 ee
:3 0 1fce 1fcf 0
ef :2 0 1fd0 1fd1
0 1fd3 1172 1fd5
1fc7 1fcd 0 1fd6
0 1fd3 0 1fd6
1174 0 1fd7 1177
202a f2 :3 0 15
:3 0 ee :3 0 1fd9
1fda 0 f1 :3 0
1fdb 1fdc 0 1fde
117a 1fe0 117c 1fdf
1fde :2 0 2028 f3
:3 0 15 :3 0 ee
:3 0 1fe3 1fe4 0
f1 :3 0 1fe5 1fe6
0 2020 d0 :3 0
d1 :3 0 1fe8 1fe9
0 d0 :3 0 e0
:3 0 1feb 1fec 0
f4 :2 0 2 :4 0
1fa :2 0 e2 :2 0
30 :2 0 117e 1ff1
1ff3 :3 0 1181 1fed
1ff5 1fea 1ff7 1ff6
:2 0 d3 :3 0 e3
:3 0 1ff9 1ffa 0
d5 :4 0 1fb :4 0
d8 :2 0 d9 :3 0
1185 1ffe 2000 :3 0
d8 :2 0 f7 :4 0
1188 2002 2004 :3 0
d8 :2 0 f8 :4 0
118b 2006 2008 :3 0
d8 :2 0 f1 :3 0
118e 200a 200c :3 0
d8 :2 0 f9 :4 0
1191 200e 2010 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 1194 2013
2017 1198 2012 2019
:3 0 119b 1ffb 201b
:2 0 201d 119e 201e
1ff8 201d 0 201f
11a0 0 2020 11a2
2023 :3 0 2023 0
2023 2022 2020 2021
:6 0 2025 55 :3 0
11a5 2027 11a7 2026
2025 :2 0 2028 11a9
:2 0 202a 0 202a
2029 1fd7 2028 :6 0
202d 1 :3 0 15c
:3 0 11ac 202e 1fa6
202d 0 21c8 8f
:3 0 6a :3 0 45
:2 0 11ae 202f 2032
e7 :2 0 45 :2 0
11b3 2034 2036 :3 0
8f :3 0 82 :3 0
45 :2 0 11b6 2038
203b e7 :2 0 45
:2 0 11bb 203d 203f
:3 0 9d :3 0 a5
:3 0 21 :3 0 9f
:3 0 27 :3 0 a0
:3 0 b6 :3 0 64
:3 0 1ed :3 0 66
:3 0 ab :3 0 61
:3 0 ab :3 0 88
:3 0 1f0 :3 0 19d
:3 0 172 :3 0 1f0
:3 0 1a :3 0 1f1
:3 0 a7 :3 0 23
:4 0 1fc 1 :8 0
206d ed :4 0 2058
:3 0 105 :3 0 e7
:2 0 11c0 205b 205c
:3 0 15 :3 0 ee
:3 0 205e 205f 0
45 :2 0 2060 2061
0 2063 11c3 206a
15 :3 0 ee :3 0
2064 2065 0 ef
:2 0 2066 2067 0
2069 11c5 206b 205d
2063 0 206c 0
2069 0 206c 11c7
0 206d 11ca 20c0
f2 :3 0 15 :3 0
ee :3 0 206f 2070
0 f1 :3 0 2071
2072 0 2074 11cd
2076 11cf 2075 2074
:2 0 20be f3 :3 0
15 :3 0 ee :3 0
2079 207a 0 f1
:3 0 207b 207c 0
20b6 d0 :3 0 d1
:3 0 207e 207f 0
d0 :3 0 e0 :3 0
2081 2082 0 f4
:2 0 2 :4 0 1fd
:2 0 e2 :2 0 30
:2 0 11d1 2087 2089
:3 0 11d4 2083 208b
2080 208d 208c :2 0
d3 :3 0 e3 :3 0
208f 2090 0 d5
:4 0 1fe :4 0 d8
:2 0 d9 :3 0 11d8
2094 2096 :3 0 d8
:2 0 f7 :4 0 11db
2098 209a :3 0 d8
:2 0 f8 :4 0 11de
209c 209e :3 0 d8
:2 0 f1 :3 0 11e1
20a0 20a2 :3 0 d8
:2 0 f9 :4 0 11e4
20a4 20a6 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 11e7 20a9 20ad
11eb 20a8 20af :3 0
11ee 2091 20b1 :2 0
20b3 11f1 20b4 208e
20b3 0 20b5 11f3
0 20b6 11f5 20b9
:3 0 20b9 0 20b9
20b8 20b6 20b7 :6 0
20bb 57 :3 0 11f8
20bd 11fa 20bc 20bb
:2 0 20be 11fc :2 0
20c0 0 20c0 20bf
206d 20be :6 0 20c2
1 :3 0 11ff 2149
9d :3 0 a5 :3 0
21 :3 0 9f :3 0
27 :3 0 a0 :3 0
b6 :3 0 64 :3 0
1ed :3 0 66 :3 0
ab :3 0 61 :3 0
ab :3 0 88 :3 0
1f5 :3 0 aa :3 0
aa :3 0 64 :3 0
1f0 :3 0 19d :3 0
172 :3 0 1f0 :3 0
1a :3 0 1f1 :3 0
a7 :3 0 23 :4 0
1ff 1 :8 0 20f3
ed :4 0 20de :3 0
105 :3 0 e7 :2 0
1203 20e1 20e2 :3 0
15 :3 0 ee :3 0
20e4 20e5 0 45
:2 0 20e6 20e7 0
20e9 1206 20f0 15
:3 0 ee :3 0 20ea
20eb 0 ef :2 0
20ec 20ed 0 20ef
1208 20f1 20e3 20e9
0 20f2 0 20ef
0 20f2 120a 0
20f3 120d 2146 f2
:3 0 15 :3 0 ee
:3 0 20f5 20f6 0
f1 :3 0 20f7 20f8
0 20fa 1210 20fc
1212 20fb 20fa :2 0
2144 f3 :3 0 15
:3 0 ee :3 0 20ff
2100 0 f1 :3 0
2101 2102 0 213c
d0 :3 0 d1 :3 0
2104 2105 0 d0
:3 0 e0 :3 0 2107
2108 0 f4 :2 0
2 :4 0 200 :2 0
e2 :2 0 30 :2 0
1214 210d 210f :3 0
1217 2109 2111 2106
2113 2112 :2 0 d3
:3 0 e3 :3 0 2115
2116 0 d5 :4 0
201 :4 0 d8 :2 0
d9 :3 0 121b 211a
211c :3 0 d8 :2 0
f7 :4 0 121e 211e
2120 :3 0 d8 :2 0
f8 :4 0 1221 2122
2124 :3 0 d8 :2 0
f1 :3 0 1224 2126
2128 :3 0 d8 :2 0
f9 :4 0 1227 212a
212c :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
122a 212f 2133 122e
212e 2135 :3 0 1231
2117 2137 :2 0 2139
1234 213a 2114 2139
0 213b 1236 0
213c 1238 213f :3 0
213f 0 213f 213e
213c 213d :6 0 2141
59 :3 0 123b 2143
123d 2142 2141 :2 0
2144 123f :2 0 2146
0 2146 2145 20f3
2144 :6 0 2148 1
:3 0 1242 214a 2040
20c2 0 214b 0
2148 0 214b 1244
0 214c 1247 214d
2037 214c 0 21c8
9d :3 0 a5 :3 0
21 :3 0 ab :3 0
61 :3 0 ab :3 0
88 :3 0 9f :3 0
27 :3 0 a0 :3 0
a7 :3 0 23 :4 0
202 1 :8 0 2170
ed :4 0 215b :3 0
105 :3 0 e7 :2 0
124b 215e 215f :3 0
15 :3 0 ee :3 0
2161 2162 0 45
:2 0 2163 2164 0
2166 124e 216d 15
:3 0 ee :3 0 2167
2168 0 ef :2 0
2169 216a 0 216c
1250 216e 2160 2166
0 216f 0 216c
0 216f 1252 0
2170 1255 21c3 f2
:3 0 15 :3 0 ee
:3 0 2172 2173 0
f1 :3 0 2174 2175
0 2177 1258 2179
125a 2178 2177 :2 0
21c1 f3 :3 0 15
:3 0 ee :3 0 217c
217d 0 f1 :3 0
217e 217f 0 21b9
d0 :3 0 d1 :3 0
2181 2182 0 d0
:3 0 e0 :3 0 2184
2185 0 f4 :2 0
2 :4 0 203 :2 0
e2 :2 0 30 :2 0
125c 218a 218c :3 0
125f 2186 218e 2183
2190 218f :2 0 d3
:3 0 e3 :3 0 2192
2193 0 d5 :4 0
204 :4 0 d8 :2 0
d9 :3 0 1263 2197
2199 :3 0 d8 :2 0
f7 :4 0 1266 219b
219d :3 0 d8 :2 0
f8 :4 0 1269 219f
21a1 :3 0 d8 :2 0
f1 :3 0 126c 21a3
21a5 :3 0 d8 :2 0
f9 :4 0 126f 21a7
21a9 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1272 21ac 21b0 1276
21ab 21b2 :3 0 1279
2194 21b4 :2 0 21b6
127c 21b7 2191 21b6
0 21b8 127e 0
21b9 1280 21bc :3 0
21bc 0 21bc 21bb
21b9 21ba :6 0 21be
5b :3 0 1283 21c0
1285 21bf 21be :2 0
21c1 1287 :2 0 21c3
0 21c3 21c2 2170
21c1 :6 0 21c5 1
:3 0 128a 21c7 1e77
1f9d 0 21c8 0
21c5 0 21c8 128c
0 2317 1d0 :3 0
9e :3 0 28 :3 0
a7 :3 0 23 :4 0
205 1 :8 0 21e4
ed :4 0 21cf :3 0
105 :3 0 e7 :2 0
1293 21d2 21d3 :3 0
15 :3 0 ee :3 0
21d5 21d6 0 45
:2 0 21d7 21d8 0
21da 1296 21e1 15
:3 0 ee :3 0 21db
21dc 0 ef :2 0
21dd 21de 0 21e0
1298 21e2 21d4 21da
0 21e3 0 21e0
0 21e3 129a 0
21e4 129d 2237 f2
:3 0 15 :3 0 ee
:3 0 21e6 21e7 0
f1 :3 0 21e8 21e9
0 21eb 12a0 21ed
12a2 21ec 21eb :2 0
2235 f3 :3 0 15
:3 0 ee :3 0 21f0
21f1 0 f1 :3 0
21f2 21f3 0 222d
d0 :3 0 d1 :3 0
21f5 21f6 0 d0
:3 0 e0 :3 0 21f8
21f9 0 f4 :2 0
2 :4 0 206 :2 0
e2 :2 0 30 :2 0
12a4 21fe 2200 :3 0
12a7 21fa 2202 21f7
2204 2203 :2 0 d3
:3 0 e3 :3 0 2206
2207 0 d5 :4 0
207 :4 0 d8 :2 0
d9 :3 0 12ab 220b
220d :3 0 d8 :2 0
f7 :4 0 12ae 220f
2211 :3 0 d8 :2 0
f8 :4 0 12b1 2213
2215 :3 0 d8 :2 0
f1 :3 0 12b4 2217
2219 :3 0 d8 :2 0
f9 :4 0 12b7 221b
221d :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
12ba 2220 2224 12be
221f 2226 :3 0 12c1
2208 2228 :2 0 222a
12c4 222b 2205 222a
0 222c 12c6 0
222d 12c8 2230 :3 0
2230 0 2230 222f
222d 222e :6 0 2232
5d :3 0 12cb 2234
12cd 2233 2232 :2 0
2235 12cf :2 0 2237
0 2237 2236 21e4
2235 :6 0 2317 1
:3 0 bd :3 0 a5
:3 0 1c :4 0 1df
1 :8 0 2252 ed
:4 0 223d :3 0 105
:3 0 e7 :2 0 12d4
2240 2241 :3 0 15
:3 0 ee :3 0 2243
2244 0 45 :2 0
2245 2246 0 2248
12d7 224f 15 :3 0
ee :3 0 2249 224a
0 ef :2 0 224b
224c 0 224e 12d9
2250 2242 2248 0
2251 0 224e 0
2251 12db 0 2252
12de 22a5 f2 :3 0
15 :3 0 ee :3 0
2254 2255 0 f1
:3 0 2256 2257 0
2259 12e1 225b 12e3
225a 2259 :2 0 22a3
f3 :3 0 15 :3 0
ee :3 0 225e 225f
0 f1 :3 0 2260
2261 0 229b d0
:3 0 d1 :3 0 2263
2264 0 d0 :3 0
e0 :3 0 2266 2267
0 f4 :2 0 2
:4 0 208 :2 0 e2
:2 0 30 :2 0 12e5
226c 226e :3 0 12e8
2268 2270 2265 2272
2271 :2 0 d3 :3 0
e3 :3 0 2274 2275
0 d5 :4 0 209
:4 0 d8 :2 0 d9
:3 0 12ec 2279 227b
:3 0 d8 :2 0 f7
:4 0 12ef 227d 227f
:3 0 d8 :2 0 f8
:4 0 12f2 2281 2283
:3 0 d8 :2 0 f1
:3 0 12f5 2285 2287
:3 0 d8 :2 0 f9
:4 0 12f8 2289 228b
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 12fb
228e 2292 12ff 228d
2294 :3 0 1302 2276
2296 :2 0 2298 1305
2299 2273 2298 0
229a 1307 0 229b
1309 229e :3 0 229e
0 229e 229d 229b
229c :6 0 22a0 5f
:3 0 130c 22a2 130e
22a1 22a0 :2 0 22a3
1310 :2 0 22a5 0
22a5 22a4 2252 22a3
:6 0 2317 1 :3 0
1db :3 0 9e :3 0
28 :3 0 9f :3 0
29 :4 0 1dc 1
:8 0 22c2 ed :4 0
22ad :3 0 105 :3 0
e7 :2 0 1315 22b0
22b1 :3 0 15 :3 0
ee :3 0 22b3 22b4
0 45 :2 0 22b5
22b6 0 22b8 1318
22bf 15 :3 0 ee
:3 0 22b9 22ba 0
ef :2 0 22bb 22bc
0 22be 131a 22c0
22b2 22b8 0 22c1
0 22be 0 22c1
131c 0 22c2 131f
2315 f2 :3 0 15
:3 0 ee :3 0 22c4
22c5 0 f1 :3 0
22c6 22c7 0 22c9
1322 22cb 1324 22ca
22c9 :2 0 2313 f3
:3 0 15 :3 0 ee
:3 0 22ce 22cf 0
f1 :3 0 22d0 22d1
0 230b d0 :3 0
d1 :3 0 22d3 22d4
0 d0 :3 0 e0
:3 0 22d6 22d7 0
f4 :2 0 2 :4 0
20a :2 0 e2 :2 0
30 :2 0 1326 22dc
22de :3 0 1329 22d8
22e0 22d5 22e2 22e1
:2 0 d3 :3 0 e3
:3 0 22e4 22e5 0
d5 :4 0 20b :4 0
d8 :2 0 d9 :3 0
132d 22e9 22eb :3 0
d8 :2 0 f7 :4 0
1330 22ed 22ef :3 0
d8 :2 0 f8 :4 0
1333 22f1 22f3 :3 0
d8 :2 0 f1 :3 0
1336 22f5 22f7 :3 0
d8 :2 0 f9 :4 0
1339 22f9 22fb :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 133c 22fe
2302 1340 22fd 2304
:3 0 1343 22e6 2306
:2 0 2308 1346 2309
22e3 2308 0 230a
1348 0 230b 134a
230e :3 0 230e 0
230e 230d 230b 230c
:6 0 2310 61 :3 0
134d 2312 134f 2311
2310 :2 0 2313 1351
:2 0 2315 0 2315
2314 22c2 2313 :6 0
2317 1 :3 0 1354
2318 1e5e 2317 0
2319 135a 0 263c
93 :3 0 14e :2 0
45 :2 0 135e 231b
231d :3 0 8f :3 0
4d :3 0 45 :2 0
1361 231f 2322 e7
:2 0 45 :2 0 1366
2324 2326 :3 0 57
:3 0 1a :3 0 20c
:3 0 2329 232a 0
2328 232b 0 232d
1369 233e 57 :3 0
171 :3 0 172 :3 0
232f 2330 0 8f
:3 0 57 :3 0 45
:2 0 136b 2332 2335
1a :3 0 20c :3 0
2337 2338 0 136e
2331 233a 232e 233b
0 233d 1371 233f
2327 232d 0 2340
0 233d 0 2340
1373 0 25d1 5f
:3 0 30 :2 0 2341
2342 0 25d1 8f
:3 0 80 :3 0 45
:2 0 1376 2344 2347
e7 :2 0 30 :2 0
137b 2349 234b :3 0
8f :3 0 48 :3 0
45 :2 0 137e 234d
2350 8f :3 0 20d
:2 0 86 :3 0 45
:2 0 1381 2352 2356
1386 2353 2358 :3 0
48 :3 0 8f :3 0
86 :3 0 45 :2 0
1389 235b 235e 235a
235f 0 2361 138c
2362 2359 2361 0
2363 138e 0 25ce
53 :3 0 45 :2 0
2364 2365 0 25ce
49 :3 0 45 :2 0
2367 2368 0 25ce
171 :3 0 20e :3 0
236a 236b 0 61
:3 0 30 :2 0 1390
236c 236f 14e :2 0
45 :2 0 1395 2371
2373 :3 0 5a :3 0
146 :2 0 2375 2376
0 2378 1398 237d
5a :3 0 30 :2 0
2379 237a 0 237c
139a 237e 2374 2378
0 237f 0 237c
0 237f 139c 0
25ce 8f :3 0 f
:3 0 45 :2 0 139f
2380 2383 e7 :2 0
45 :2 0 13a4 2385
2387 :3 0 4d :3 0
45 :2 0 2389 238a
0 238c 13a7 238d
2388 238c 0 238e
13a9 0 25ce 75
:3 0 20f :3 0 39
:3 0 3a :3 0 8f
:3 0 4f :3 0 45
:2 0 13ab 2393 2396
8f :3 0 50 :3 0
45 :2 0 13ae 2398
239b 8f :3 0 5b
:3 0 45 :2 0 13b1
239d 23a0 8f :3 0
57 :3 0 45 :2 0
13b4 23a2 23a5 8f
:3 0 51 :3 0 45
:2 0 13b7 23a7 23aa
8f :3 0 4e :3 0
45 :2 0 13ba 23ac
23af 8f :3 0 58
:3 0 45 :2 0 13bd
23b1 23b4 8f :3 0
59 :3 0 45 :2 0
13c0 23b6 23b9 4d
:3 0 48 :3 0 52
:3 0 13c3 2390 23be
238f 23bf 0 25ce
8f :3 0 75 :3 0
45 :2 0 13d1 23c1
23c4 1a :3 0 e7
:2 0 210 :3 0 23c6
23c8 0 13d6 23c7
23ca :3 0 d0 :3 0
d1 :3 0 23cc 23cd
0 d0 :3 0 e0
:3 0 23cf 23d0 0
211 :2 0 2 :4 0
212 :2 0 e2 :2 0
30 :2 0 13d9 23d5
23d7 :3 0 13dc 23d1
23d9 23ce 23db 23da
:2 0 d3 :3 0 e3
:3 0 23dd 23de 0
d5 :4 0 213 :4 0
d8 :2 0 d9 :3 0
13e0 23e2 23e4 :3 0
d8 :2 0 f7 :4 0
13e3 23e6 23e8 :3 0
d8 :2 0 fe :4 0
13e6 23ea 23ec :3 0
d8 :2 0 8f :3 0
dd :3 0 1a :3 0
210 :3 0 23f1 23f2
0 13e9 23f0 23f4
de :4 0 13eb 23ef
23f7 13ee 23ee 23f9
:3 0 13f1 23df 23fb
:2 0 23fd 13f4 23fe
23dc 23fd 0 23ff
13f6 0 2429 d0
:3 0 d1 :3 0 2400
2401 0 d0 :3 0
e0 :3 0 2403 2404
0 30 :2 0 2
:4 0 214 :2 0 e2
:2 0 30 :2 0 13f8
2409 240b :3 0 13fb
2405 240d 2402 240f
240e :2 0 d3 :3 0
e3 :3 0 2411 2412
0 d5 :4 0 215
:4 0 d8 :2 0 d9
:3 0 13ff 2416 2418
:3 0 1402 2413 241a
:2 0 241c 1405 241d
2410 241c 0 241e
1407 0 2429 103
:3 0 216 :3 0 241f
2420 0 1a :3 0
210 :3 0 2422 2423
0 105 :3 0 1409
2421 2426 :2 0 2429
15c :3 0 140c 24a2
8f :3 0 75 :3 0
45 :2 0 1410 242a
242d 14e :2 0 45
:2 0 1415 242f 2431
:3 0 d0 :3 0 d1
:3 0 2433 2434 0
d0 :3 0 e0 :3 0
2436 2437 0 1d
:2 0 2 :4 0 217
:2 0 e2 :2 0 30
:2 0 1418 243c 243e
:3 0 141b 2438 2440
2435 2442 2441 :2 0
d3 :3 0 e3 :3 0
2444 2445 0 d5
:4 0 218 :4 0 d8
:2 0 d9 :3 0 141f
2449 244b :3 0 d8
:2 0 f7 :4 0 1422
244d 244f :3 0 d8
:2 0 fe :4 0 1425
2451 2453 :3 0 d8
:2 0 8f :3 0 dd
:3 0 75 :3 0 1428
2457 2459 de :4 0
142a 2456 245c 142d
2455 245e :3 0 d8
:2 0 100 :4 0 1430
2460 2462 :3 0 d8
:2 0 db :4 0 1433
2464 2466 :3 0 d8
:2 0 28 :3 0 1436
2468 246a :3 0 d8
:2 0 db :4 0 1439
246c 246e :3 0 143c
2446 2470 :2 0 2472
143f 2473 2443 2472
0 2474 1441 0
24a0 d0 :3 0 d1
:3 0 2475 2476 0
d0 :3 0 e0 :3 0
2478 2479 0 30
:2 0 2 :4 0 219
:2 0 e2 :2 0 30
:2 0 1443 247e 2480
:3 0 1446 247a 2482
2477 2484 2483 :2 0
d3 :3 0 e3 :3 0
2486 2487 0 d5
:4 0 21a :4 0 d8
:2 0 d9 :3 0 144a
248b 248d :3 0 144d
2488 248f :2 0 2491
1450 2492 2485 2491
0 2493 1452 0
24a0 103 :3 0 104
:3 0 2494 2495 0
8f :3 0 75 :3 0
45 :2 0 1454 2497
249a 28 :3 0 105
:3 0 1457 2496 249e
:2 0 24a0 145b 24a1
2432 24a0 0 24a3
23cb 2429 0 24a3
145f 0 25ce 74
:3 0 21b :2 0 24a4
24a5 0 25ce 8c
:3 0 21c :3 0 23
:3 0 28 :3 0 28
:3 0 27 :3 0 74
:3 0 4a :3 0 31
:3 0 31 :3 0 31
:3 0 31 :3 0 2a
:3 0 2c :3 0 52
:3 0 48 :3 0 4d
:3 0 4f :3 0 50
:3 0 49 :3 0 5b
:3 0 36 :3 0 53
:3 0 57 :3 0 51
:3 0 4e :3 0 5a
:3 0 58 :3 0 5c
:3 0 1f :3 0 45
:2 0 45 :2 0 21b
:2 0 21b :2 0 45
:2 0 1462 24a8 24ca
24a7 24cb 0 25ce
8c :3 0 e7 :2 0
21d :2 0 1486 24ce
24d0 :3 0 d0 :3 0
d1 :3 0 24d2 24d3
0 d0 :3 0 e0
:3 0 24d5 24d6 0
1d :2 0 2 :4 0
21e :2 0 e2 :2 0
30 :2 0 1489 24db
24dd :3 0 148c 24d7
24df 24d4 24e1 24e0
:2 0 d3 :3 0 e3
:3 0 24e3 24e4 0
d5 :4 0 21f :4 0
d8 :2 0 d9 :3 0
1490 24e8 24ea :3 0
d8 :2 0 f7 :4 0
1493 24ec 24ee :3 0
d8 :2 0 fe :4 0
1496 24f0 24f2 :3 0
d8 :2 0 8f :3 0
dd :3 0 1a :3 0
220 :3 0 24f7 24f8
0 1499 24f6 24fa
de :4 0 149b 24f5
24fd 149e 24f4 24ff
:3 0 d8 :2 0 100
:4 0 14a1 2501 2503
:3 0 d8 :2 0 db
:4 0 14a4 2505 2507
:3 0 d8 :2 0 27
:3 0 14a7 2509 250b
:3 0 d8 :2 0 db
:4 0 14aa 250d 250f
:3 0 14ad 24e5 2511
:2 0 2513 14b0 2514
24e2 2513 0 2515
14b2 0 2540 d0
:3 0 d1 :3 0 2516
2517 0 d0 :3 0
e0 :3 0 2519 251a
0 30 :2 0 2
:4 0 221 :2 0 e2
:2 0 30 :2 0 14b4
251f 2521 :3 0 14b7
251b 2523 2518 2525
2524 :2 0 d3 :3 0
e3 :3 0 2527 2528
0 d5 :4 0 222
:4 0 d8 :2 0 d9
:3 0 14bb 252c 252e
:3 0 14be 2529 2530
:2 0 2532 14c1 2533
2526 2532 0 2534
14c3 0 2540 103
:3 0 104 :3 0 2535
2536 0 1a :3 0
220 :3 0 2538 2539
0 27 :3 0 105
:3 0 14c5 2537 253d
:2 0 2540 15c :3 0
14c9 25cb 8c :3 0
14e :2 0 45 :2 0
14cf 2542 2544 :3 0
d0 :3 0 d1 :3 0
2546 2547 0 d0
:3 0 e0 :3 0 2549
254a 0 1d :2 0
2 :4 0 223 :2 0
e2 :2 0 30 :2 0
14d2 254f 2551 :3 0
14d5 254b 2553 2548
2555 2554 :2 0 d3
:3 0 e3 :3 0 2557
2558 0 d5 :4 0
224 :4 0 d8 :2 0
d9 :3 0 14d9 255c
255e :3 0 d8 :2 0
f7 :4 0 14dc 2560
2562 :3 0 d8 :2 0
fe :4 0 14df 2564
2566 :3 0 d8 :2 0
8f :3 0 dd :3 0
1a :3 0 1c2 :3 0
256b 256c 0 14e2
256a 256e de :4 0
14e4 2569 2571 14e7
2568 2573 :3 0 d8
:2 0 100 :4 0 14ea
2575 2577 :3 0 d8
:2 0 db :4 0 14ed
2579 257b :3 0 d8
:2 0 21 :3 0 14f0
257d 257f :3 0 d8
:2 0 db :4 0 14f3
2581 2583 :3 0 14f6
2559 2585 :2 0 2587
14f9 2588 2556 2587
0 2589 14fb 0
25b3 d0 :3 0 d1
:3 0 258a 258b 0
d0 :3 0 e0 :3 0
258d 258e 0 30
:2 0 2 :4 0 225
:2 0 e2 :2 0 30
:2 0 14fd 2593 2595
:3 0 1500 258f 2597
258c 2599 2598 :2 0
d3 :3 0 e3 :3 0
259b 259c 0 d5
:4 0 226 :4 0 d8
:2 0 d9 :3 0 1504
25a0 25a2 :3 0 1507
259d 25a4 :2 0 25a6
150a 25a7 259a 25a6
0 25a8 150c 0
25b3 103 :3 0 104
:3 0 25a9 25aa 0
1a :3 0 1c2 :3 0
25ac 25ad 0 21
:3 0 105 :3 0 150e
25ab 25b1 :2 0 25b3
1512 25b4 2545 25b3
0 25cd 75 :3 0
ea :2 0 25b5 25b6
0 25ca 75 :3 0
227 :3 0 28 :3 0
23 :3 0 75 :3 0
8f :3 0 58 :3 0
45 :2 0 1516 25bd
25c0 8f :3 0 48
:3 0 45 :2 0 1519
25c2 25c5 151c 25b9
25c7 25b8 25c8 0
25ca 1522 25cc 24d1
2540 0 25cd 0
25ca 0 25cd 1525
0 25ce 1529 25cf
234c 25ce 0 25d0
1534 0 25d1 1536
25d2 231e 25d1 0
25d3 153a 0 263c
5b :3 0 1a :3 0
e9 :3 0 25d5 25d6
0 25d4 25d7 0
263c 1ad :3 0 228
:3 0 2a :3 0 1d0
:3 0 9e :3 0 28
:3 0 a7 :3 0 23
:4 0 229 1 :8 0
25e7 15 :3 0 ee
:3 0 25e2 25e3 0
f1 :3 0 25e4 25e5
0 25e7 153c 263a
f2 :3 0 15 :3 0
ee :3 0 25e9 25ea
0 f1 :3 0 25eb
25ec 0 25ee 153f
25f0 1541 25ef 25ee
:2 0 2638 f3 :3 0
15 :3 0 ee :3 0
25f3 25f4 0 f1
:3 0 25f5 25f6 0
2630 d0 :3 0 d1
:3 0 25f8 25f9 0
d0 :3 0 e0 :3 0
25fb 25fc 0 f4
:2 0 2 :4 0 22a
:2 0 e2 :2 0 30
:2 0 1543 2601 2603
:3 0 1546 25fd 2605
25fa 2607 2606 :2 0
d3 :3 0 e3 :3 0
2609 260a 0 d5
:4 0 22b :4 0 d8
:2 0 d9 :3 0 154a
260e 2610 :3 0 d8
:2 0 f7 :4 0 154d
2612 2614 :3 0 d8
:2 0 f8 :4 0 1550
2616 2618 :3 0 d8
:2 0 f1 :3 0 1553
261a 261c :3 0 d8
:2 0 f9 :4 0 1556
261e 2620 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 1559 2623 2627
155d 2622 2629 :3 0
1560 260b 262b :2 0
262d 1563 262e 2608
262d 0 262f 1565
0 2630 1567 2633
:3 0 2633 0 2633
2632 2630 2631 :6 0
2635 63 :3 0 156a
2637 156c 2636 2635
:2 0 2638 156e :2 0
263a 0 263a 2639
25e7 2638 :6 0 263c
1 :3 0 1571 263d
194f 263c 0 263e
1579 0 263f 157b
2640 17bc 263f 0
2641 1582 0 2645
4c :3 0 45 :2 0
2642 2643 0 2645
1584 2646 17b7 2645
0 2647 1587 0
5170 37 :3 0 ae
:3 0 37 :3 0 d8
:2 0 22c :4 0 1589
264b 264d :3 0 30
:2 0 38 :2 0 158c
2649 2651 2648 2652
0 5170 22 :3 0
eb :4 0 2654 2655
0 5170 48 :3 0
9 :3 0 2657 2658
0 5170 17e :3 0
41 :3 0 13b :3 0
13c :3 0 29 :4 0
17f 1 :8 0 2665
15 :3 0 ee :3 0
2660 2661 0 f1
:3 0 2662 2663 0
2665 1590 26b8 f2
:3 0 15 :3 0 ee
:3 0 2667 2668 0
f1 :3 0 2669 266a
0 266c 1593 266e
1595 266d 266c :2 0
26b6 f3 :3 0 15
:3 0 ee :3 0 2671
2672 0 f1 :3 0
2673 2674 0 26ae
d0 :3 0 d1 :3 0
2676 2677 0 d0
:3 0 e0 :3 0 2679
267a 0 f4 :2 0
2 :4 0 22d :2 0
e2 :2 0 30 :2 0
1597 267f 2681 :3 0
159a 267b 2683 2678
2685 2684 :2 0 d3
:3 0 e3 :3 0 2687
2688 0 d5 :4 0
22e :4 0 d8 :2 0
d9 :3 0 159e 268c
268e :3 0 d8 :2 0
f7 :4 0 15a1 2690
2692 :3 0 d8 :2 0
f8 :4 0 15a4 2694
2696 :3 0 d8 :2 0
f1 :3 0 15a7 2698
269a :3 0 d8 :2 0
f9 :4 0 15aa 269c
269e :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
15ad 26a1 26a5 15b1
26a0 26a7 :3 0 15b4
2689 26a9 :2 0 26ab
15b7 26ac 2686 26ab
0 26ad 15b9 0
26ae 15bb 26b1 :3 0
26b1 0 26b1 26b0
26ae 26af :6 0 26b3
65 :3 0 15be 26b5
15c0 26b4 26b3 :2 0
26b6 15c2 :2 0 26b8
0 26b8 26b7 2665
26b6 :6 0 5170 1
:3 0 7e :3 0 21b
:2 0 26ba 26bb 0
5170 7f :3 0 21b
:2 0 26bd 26be 0
5170 4c :3 0 45
:2 0 26c0 26c1 0
5170 2a :3 0 39
:3 0 26c3 26c4 0
5170 ec :3 0 a3
:4 0 26c9 :2 0 5170
26c7 26ca :3 0 22f
:3 0 a3 :3 0 20
:3 0 22 :3 0 26
:3 0 4a :3 0 48
:3 0 88 :3 0 2a
:3 0 7c :3 0 7d
:3 0 87 :3 0 52
:3 0 25 :3 0 82
:3 0 83 :3 0 7e
:3 0 7f :3 0 4d
:3 0 4f :3 0 50
:3 0 51 :3 0 57
:4 0 26e3 :2 0 45d1
26cc 26e4 :3 0 15c5
:3 0 a3 :3 0 ed
:3 0 26e5 26e6 :3 0
15 :3 0 ee :3 0
26e8 26e9 0 45
:2 0 26ea 26eb 0
26ed 15db 26f4 15
:3 0 ee :3 0 26ee
26ef 0 ef :2 0
26f0 26f1 0 26f3
15dd 26f5 26e7 26ed
0 26f6 0 26f3
0 26f6 15df 0
45d1 15 :3 0 ee
:3 0 26f7 26f8 0
15 :3 0 14e :2 0
165 :3 0 26fa 26fc
0 15e4 26fb 26fe
:3 0 26ff :2 0 230
:8 0 2703 15e7 2704
2700 2703 0 2705
15e9 0 45d1 53
:3 0 45 :2 0 2706
2707 0 45d1 8f
:3 0 48 :3 0 45
:2 0 15eb 2709 270c
e7 :2 0 45 :2 0
15f0 270e 2710 :3 0
7b :3 0 231 :3 0
20 :3 0 45 :2 0
15f3 2713 2716 2712
2717 0 29af bd
:3 0 a5 :3 0 20
:4 0 232 1 :8 0
2732 ed :4 0 271d
:3 0 105 :3 0 e7
:2 0 15f8 2720 2721
:3 0 15 :3 0 ee
:3 0 2723 2724 0
45 :2 0 2725 2726
0 2728 15fb 272f
15 :3 0 ee :3 0
2729 272a 0 ef
:2 0 272b 272c 0
272e 15fd 2730 2722
2728 0 2731 0
272e 0 2731 15ff
0 2732 1602 2785
f2 :3 0 15 :3 0
ee :3 0 2734 2735
0 f1 :3 0 2736
2737 0 2739 1605
273b 1607 273a 2739
:2 0 2783 f3 :3 0
15 :3 0 ee :3 0
273e 273f 0 f1
:3 0 2740 2741 0
277b d0 :3 0 d1
:3 0 2743 2744 0
d0 :3 0 e0 :3 0
2746 2747 0 f4
:2 0 2 :4 0 233
:2 0 e2 :2 0 30
:2 0 1609 274c 274e
:3 0 160c 2748 2750
2745 2752 2751 :2 0
d3 :3 0 e3 :3 0
2754 2755 0 d5
:4 0 234 :4 0 d8
:2 0 d9 :3 0 1610
2759 275b :3 0 d8
:2 0 f7 :4 0 1613
275d 275f :3 0 d8
:2 0 f8 :4 0 1616
2761 2763 :3 0 d8
:2 0 f1 :3 0 1619
2765 2767 :3 0 d8
:2 0 f9 :4 0 161c
2769 276b :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 161f 276e 2772
1623 276d 2774 :3 0
1626 2756 2776 :2 0
2778 1629 2779 2753
2778 0 277a 162b
0 277b 162d 277e
:3 0 277e 0 277e
277d 277b 277c :6 0
2780 68 :3 0 1630
2782 1632 2781 2780
:2 0 2783 1634 :2 0
2785 0 2785 2784
2732 2783 :6 0 29af
67 :3 0 9d :3 0
a7 :3 0 22 :4 0
235 1 :8 0 27a0
ed :4 0 278b :3 0
105 :3 0 e7 :2 0
1639 278e 278f :3 0
15 :3 0 ee :3 0
2791 2792 0 45
:2 0 2793 2794 0
2796 163c 279d 15
:3 0 ee :3 0 2797
2798 0 ef :2 0
2799 279a 0 279c
163e 279e 2790 2796
0 279f 0 279c
0 279f 1640 0
27a0 1643 27f3 f2
:3 0 15 :3 0 ee
:3 0 27a2 27a3 0
f1 :3 0 27a4 27a5
0 27a7 1646 27a9
1648 27a8 27a7 :2 0
27f1 f3 :3 0 15
:3 0 ee :3 0 27ac
27ad 0 f1 :3 0
27ae 27af 0 27e9
d0 :3 0 d1 :3 0
27b1 27b2 0 d0
:3 0 e0 :3 0 27b4
27b5 0 f4 :2 0
2 :4 0 236 :2 0
e2 :2 0 30 :2 0
164a 27ba 27bc :3 0
164d 27b6 27be 27b3
27c0 27bf :2 0 d3
:3 0 e3 :3 0 27c2
27c3 0 d5 :4 0
237 :4 0 d8 :2 0
d9 :3 0 1651 27c7
27c9 :3 0 d8 :2 0
f7 :4 0 1654 27cb
27cd :3 0 d8 :2 0
f8 :4 0 1657 27cf
27d1 :3 0 d8 :2 0
f1 :3 0 165a 27d3
27d5 :3 0 d8 :2 0
f9 :4 0 165d 27d7
27d9 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1660 27dc 27e0 1664
27db 27e2 :3 0 1667
27c4 27e4 :2 0 27e6
166a 27e7 27c1 27e6
0 27e8 166c 0
27e9 166e 27ec :3 0
27ec 0 27ec 27eb
27e9 27ea :6 0 27ee
6a :3 0 1671 27f0
1673 27ef 27ee :2 0
27f1 1675 :2 0 27f3
0 27f3 27f2 27a0
27f1 :6 0 29af 67
:3 0 238 :3 0 a7
:3 0 22 :4 0 239
1 :8 0 280e ed
:4 0 27f9 :3 0 105
:3 0 e7 :2 0 167a
27fc 27fd :3 0 15
:3 0 ee :3 0 27ff
2800 0 45 :2 0
2801 2802 0 2804
167d 280b 15 :3 0
ee :3 0 2805 2806
0 ef :2 0 2807
2808 0 280a 167f
280c 27fe 2804 0
280d 0 280a 0
280d 1681 0 280e
1684 2861 f2 :3 0
15 :3 0 ee :3 0
2810 2811 0 f1
:3 0 2812 2813 0
2815 1687 2817 1689
2816 2815 :2 0 285f
f3 :3 0 15 :3 0
ee :3 0 281a 281b
0 f1 :3 0 281c
281d 0 2857 d0
:3 0 d1 :3 0 281f
2820 0 d0 :3 0
e0 :3 0 2822 2823
0 f4 :2 0 2
:4 0 23a :2 0 e2
:2 0 30 :2 0 168b
2828 282a :3 0 168e
2824 282c 2821 282e
282d :2 0 d3 :3 0
e3 :3 0 2830 2831
0 d5 :4 0 23b
:4 0 d8 :2 0 d9
:3 0 1692 2835 2837
:3 0 d8 :2 0 f7
:4 0 1695 2839 283b
:3 0 d8 :2 0 f8
:4 0 1698 283d 283f
:3 0 d8 :2 0 f1
:3 0 169b 2841 2843
:3 0 d8 :2 0 f9
:4 0 169e 2845 2847
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 16a1
284a 284e 16a5 2849
2850 :3 0 16a8 2832
2852 :2 0 2854 16ab
2855 282f 2854 0
2856 16ad 0 2857
16af 285a :3 0 285a
0 285a 2859 2857
2858 :6 0 285c 6c
:3 0 16b2 285e 16b4
285d 285c :2 0 285f
16b6 :2 0 2861 0
2861 2860 280e 285f
:6 0 29af 67 :3 0
1d0 :3 0 9e :3 0
28 :3 0 a7 :3 0
22 :4 0 23c 1
:8 0 287e ed :4 0
2869 :3 0 105 :3 0
e7 :2 0 16bb 286c
286d :3 0 15 :3 0
ee :3 0 286f 2870
0 45 :2 0 2871
2872 0 2874 16be
287b 15 :3 0 ee
:3 0 2875 2876 0
ef :2 0 2877 2878
0 287a 16c0 287c
286e 2874 0 287d
0 287a 0 287d
16c2 0 287e 16c5
28d1 f2 :3 0 15
:3 0 ee :3 0 2880
2881 0 f1 :3 0
2882 2883 0 2885
16c8 2887 16ca 2886
2885 :2 0 28cf f3
:3 0 15 :3 0 ee
:3 0 288a 288b 0
f1 :3 0 288c 288d
0 28c7 d0 :3 0
d1 :3 0 288f 2890
0 d0 :3 0 e0
:3 0 2892 2893 0
f4 :2 0 2 :4 0
23d :2 0 e2 :2 0
30 :2 0 16cc 2898
289a :3 0 16cf 2894
289c 2891 289e 289d
:2 0 d3 :3 0 e3
:3 0 28a0 28a1 0
d5 :4 0 23e :4 0
d8 :2 0 d9 :3 0
16d3 28a5 28a7 :3 0
d8 :2 0 f7 :4 0
16d6 28a9 28ab :3 0
d8 :2 0 f8 :4 0
16d9 28ad 28af :3 0
d8 :2 0 f1 :3 0
16dc 28b1 28b3 :3 0
d8 :2 0 f9 :4 0
16df 28b5 28b7 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 16e2 28ba
28be 16e6 28b9 28c0
:3 0 16e9 28a2 28c2
:2 0 28c4 16ec 28c5
289f 28c4 0 28c6
16ee 0 28c7 16f0
28ca :3 0 28ca 0
28ca 28c9 28c7 28c8
:6 0 28cc 6e :3 0
16f3 28ce 16f5 28cd
28cc :2 0 28cf 16f7
:2 0 28d1 0 28d1
28d0 287e 28cf :6 0
29af 67 :3 0 23f
:3 0 a5 :3 0 22
:4 0 240 1 :8 0
28ec ed :4 0 28d7
:3 0 105 :3 0 e7
:2 0 16fc 28da 28db
:3 0 15 :3 0 ee
:3 0 28dd 28de 0
45 :2 0 28df 28e0
0 28e2 16ff 28e9
15 :3 0 ee :3 0
28e3 28e4 0 ef
:2 0 28e5 28e6 0
28e8 1701 28ea 28dc
28e2 0 28eb 0
28e8 0 28eb 1703
0 28ec 1706 293f
f2 :3 0 15 :3 0
ee :3 0 28ee 28ef
0 f1 :3 0 28f0
28f1 0 28f3 1709
28f5 170b 28f4 28f3
:2 0 293d f3 :3 0
15 :3 0 ee :3 0
28f8 28f9 0 f1
:3 0 28fa 28fb 0
2935 d0 :3 0 d1
:3 0 28fd 28fe 0
d0 :3 0 e0 :3 0
2900 2901 0 f4
:2 0 2 :4 0 241
:2 0 e2 :2 0 30
:2 0 170d 2906 2908
:3 0 1710 2902 290a
28ff 290c 290b :2 0
d3 :3 0 e3 :3 0
290e 290f 0 d5
:4 0 242 :4 0 d8
:2 0 d9 :3 0 1714
2913 2915 :3 0 d8
:2 0 f7 :4 0 1717
2917 2919 :3 0 d8
:2 0 f8 :4 0 171a
291b 291d :3 0 d8
:2 0 f1 :3 0 171d
291f 2921 :3 0 d8
:2 0 f9 :4 0 1720
2923 2925 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 1723 2928 292c
1727 2927 292e :3 0
172a 2910 2930 :2 0
2932 172d 2933 290d
2932 0 2934 172f
0 2935 1731 2938
:3 0 2938 0 2938
2937 2935 2936 :6 0
293a 70 :3 0 1734
293c 1736 293b 293a
:2 0 293d 1738 :2 0
293f 0 293f 293e
28ec 293d :6 0 29af
67 :3 0 243 :3 0
a5 :3 0 22 :4 0
244 1 :8 0 295a
ed :4 0 2945 :3 0
105 :3 0 e7 :2 0
173d 2948 2949 :3 0
15 :3 0 ee :3 0
294b 294c 0 45
:2 0 294d 294e 0
2950 1740 2957 15
:3 0 ee :3 0 2951
2952 0 ef :2 0
2953 2954 0 2956
1742 2958 294a 2950
0 2959 0 2956
0 2959 1744 0
295a 1747 29ad f2
:3 0 15 :3 0 ee
:3 0 295c 295d 0
f1 :3 0 295e 295f
0 2961 174a 2963
174c 2962 2961 :2 0
29ab f3 :3 0 15
:3 0 ee :3 0 2966
2967 0 f1 :3 0
2968 2969 0 29a3
d0 :3 0 d1 :3 0
296b 296c 0 d0
:3 0 e0 :3 0 296e
296f 0 f4 :2 0
2 :4 0 245 :2 0
e2 :2 0 30 :2 0
174e 2974 2976 :3 0
1751 2970 2978 296d
297a 2979 :2 0 d3
:3 0 e3 :3 0 297c
297d 0 d5 :4 0
246 :4 0 d8 :2 0
d9 :3 0 1755 2981
2983 :3 0 d8 :2 0
f7 :4 0 1758 2985
2987 :3 0 d8 :2 0
f8 :4 0 175b 2989
298b :3 0 d8 :2 0
f1 :3 0 175e 298d
298f :3 0 d8 :2 0
f9 :4 0 1761 2991
2993 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1764 2996 299a 1768
2995 299c :3 0 176b
297e 299e :2 0 29a0
176e 29a1 297b 29a0
0 29a2 1770 0
29a3 1772 29a6 :3 0
29a6 0 29a6 29a5
29a3 29a4 :6 0 29a8
72 :3 0 1775 29aa
1777 29a9 29a8 :2 0
29ab 1779 :2 0 29ad
0 29ad 29ac 295a
29ab :6 0 29af 67
:3 0 177c 45c0 8f
:3 0 55 :3 0 45
:2 0 1784 29b0 29b3
e7 :2 0 45 :2 0
1789 29b5 29b7 :3 0
23 :3 0 22 :3 0
29b9 29ba 0 29bc
178c 29bd 29b8 29bc
0 29be 178e 0
45bf 247 :3 0 9f
:3 0 27 :3 0 a7
:3 0 22 :3 0 9e
:3 0 28 :3 0 9f
:3 0 29 :4 0 248
1 :8 0 29de ed
:4 0 29c9 :3 0 105
:3 0 e7 :2 0 1792
29cc 29cd :3 0 15
:3 0 ee :3 0 29cf
29d0 0 45 :2 0
29d1 29d2 0 29d4
1795 29db 15 :3 0
ee :3 0 29d5 29d6
0 ef :2 0 29d7
29d8 0 29da 1797
29dc 29ce 29d4 0
29dd 0 29da 0
29dd 1799 0 29de
179c 2a31 f2 :3 0
15 :3 0 ee :3 0
29e0 29e1 0 f1
:3 0 29e2 29e3 0
29e5 179f 29e7 17a1
29e6 29e5 :2 0 2a2f
f3 :3 0 15 :3 0
ee :3 0 29ea 29eb
0 f1 :3 0 29ec
29ed 0 2a27 d0
:3 0 d1 :3 0 29ef
29f0 0 d0 :3 0
e0 :3 0 29f2 29f3
0 f4 :2 0 2
:4 0 249 :2 0 e2
:2 0 30 :2 0 17a3
29f8 29fa :3 0 17a6
29f4 29fc 29f1 29fe
29fd :2 0 d3 :3 0
e3 :3 0 2a00 2a01
0 d5 :4 0 24a
:4 0 d8 :2 0 d9
:3 0 17aa 2a05 2a07
:3 0 d8 :2 0 f7
:4 0 17ad 2a09 2a0b
:3 0 d8 :2 0 f8
:4 0 17b0 2a0d 2a0f
:3 0 d8 :2 0 f1
:3 0 17b3 2a11 2a13
:3 0 d8 :2 0 f9
:4 0 17b6 2a15 2a17
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 17b9
2a1a 2a1e 17bd 2a19
2a20 :3 0 17c0 2a02
2a22 :2 0 2a24 17c3
2a25 29ff 2a24 0
2a26 17c5 0 2a27
17c7 2a2a :3 0 2a2a
0 2a2a 2a29 2a27
2a28 :6 0 2a2c 74
:3 0 17ca 2a2e 17cc
2a2d 2a2c :2 0 2a2f
17ce :2 0 2a31 0
2a31 2a30 29de 2a2f
:6 0 45bf 67 :3 0
84 :3 0 1bd :2 0
30 :2 0 17d1 2a34
2a36 :3 0 2a33 2a37
0 45bf 15 :3 0
ee :3 0 2a39 2a3a
0 1be :3 0 28
:3 0 26 :3 0 22
:3 0 7c :3 0 7d
:3 0 7e :3 0 7f
:3 0 84 :3 0 83
:3 0 82 :3 0 17d3
2a3c 2a47 2a3b 2a48
0 45bf a7 :3 0
182 :3 0 24 :3 0
2f :3 0 9d :3 0
9e :3 0 28 :3 0
a8 :3 0 26 :3 0
9f :3 0 27 :3 0
a0 :4 0 24b 1
:8 0 2a5c 15 :3 0
ee :3 0 2a57 2a58
0 f1 :3 0 2a59
2a5a 0 2a5c 17de
2aaf f2 :3 0 15
:3 0 ee :3 0 2a5e
2a5f 0 f1 :3 0
2a60 2a61 0 2a63
17e1 2a65 17e3 2a64
2a63 :2 0 2aad f3
:3 0 15 :3 0 ee
:3 0 2a68 2a69 0
f1 :3 0 2a6a 2a6b
0 2aa5 d0 :3 0
d1 :3 0 2a6d 2a6e
0 d0 :3 0 e0
:3 0 2a70 2a71 0
f4 :2 0 2 :4 0
24c :2 0 e2 :2 0
30 :2 0 17e5 2a76
2a78 :3 0 17e8 2a72
2a7a 2a6f 2a7c 2a7b
:2 0 d3 :3 0 e3
:3 0 2a7e 2a7f 0
d5 :4 0 24d :4 0
d8 :2 0 d9 :3 0
17ec 2a83 2a85 :3 0
d8 :2 0 f7 :4 0
17ef 2a87 2a89 :3 0
d8 :2 0 f8 :4 0
17f2 2a8b 2a8d :3 0
d8 :2 0 f1 :3 0
17f5 2a8f 2a91 :3 0
d8 :2 0 f9 :4 0
17f8 2a93 2a95 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 17fb 2a98
2a9c 17ff 2a97 2a9e
:3 0 1802 2a80 2aa0
:2 0 2aa2 1805 2aa3
2a7d 2aa2 0 2aa4
1807 0 2aa5 1809
2aa8 :3 0 2aa8 0
2aa8 2aa7 2aa5 2aa6
:6 0 2aaa 76 :3 0
180c 2aac 180e 2aab
2aaa :2 0 2aad 1810
:2 0 2aaf 0 2aaf
2aae 2a5c 2aad :6 0
45bf 67 :3 0 15
:3 0 ee :3 0 2ab1
2ab2 0 15 :3 0
e7 :2 0 10d :3 0
2ab4 2ab6 0 1815
2ab5 2ab8 :3 0 2ab9
:2 0 70 :3 0 45
:2 0 2abb 2abc 0
30a6 a5 :3 0 168
:3 0 16d :3 0 1c
:3 0 46 :3 0 1e
:3 0 bd :3 0 99
:3 0 26 :3 0 9f
:3 0 27 :3 0 a0
:4 0 24e 1 :8 0
2ad0 15 :3 0 ee
:3 0 2acb 2acc 0
f1 :3 0 2acd 2ace
0 2ad0 1818 2b23
f2 :3 0 15 :3 0
ee :3 0 2ad2 2ad3
0 f1 :3 0 2ad4
2ad5 0 2ad7 181b
2ad9 181d 2ad8 2ad7
:2 0 2b21 f3 :3 0
15 :3 0 ee :3 0
2adc 2add 0 f1
:3 0 2ade 2adf 0
2b19 d0 :3 0 d1
:3 0 2ae1 2ae2 0
d0 :3 0 e0 :3 0
2ae4 2ae5 0 f4
:2 0 2 :4 0 24f
:2 0 e2 :2 0 30
:2 0 181f 2aea 2aec
:3 0 1822 2ae6 2aee
2ae3 2af0 2aef :2 0
d3 :3 0 e3 :3 0
2af2 2af3 0 d5
:4 0 250 :4 0 d8
:2 0 d9 :3 0 1826
2af7 2af9 :3 0 d8
:2 0 f7 :4 0 1829
2afb 2afd :3 0 d8
:2 0 f8 :4 0 182c
2aff 2b01 :3 0 d8
:2 0 f1 :3 0 182f
2b03 2b05 :3 0 d8
:2 0 f9 :4 0 1832
2b07 2b09 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 1835 2b0c 2b10
1839 2b0b 2b12 :3 0
183c 2af4 2b14 :2 0
2b16 183f 2b17 2af1
2b16 0 2b18 1841
0 2b19 1843 2b1c
:3 0 2b1c 0 2b1c
2b1b 2b19 2b1a :6 0
2b1e 78 :3 0 1846
2b20 1848 2b1f 2b1e
:2 0 2b21 184a :2 0
2b23 0 2b23 2b22
2ad0 2b21 :6 0 30a6
67 :3 0 15 :3 0
ee :3 0 2b25 2b26
0 15 :3 0 e7
:2 0 165 :3 0 2b28
2b2a 0 184f 2b29
2b2c :3 0 2b2d :2 0
e5 :3 0 8f :3 0
46 :3 0 45 :2 0
1852 2b30 2b33 1a
:3 0 1a1 :3 0 2b35
2b36 0 1855 2b2f
2b38 2b39 :2 0 1a
:3 0 e7 :2 0 1a1
:3 0 2b3b 2b3d 0
185a 2b3c 2b3f :3 0
48 :3 0 45 :2 0
2b41 2b42 0 2bb8
bd :3 0 13c :3 0
29 :3 0 9f :3 0
27 :3 0 a0 :3 0
a5 :3 0 20 :4 0
251 1 :8 0 2b62
ed :4 0 2b4d :3 0
105 :3 0 e7 :2 0
185f 2b50 2b51 :3 0
15 :3 0 ee :3 0
2b53 2b54 0 45
:2 0 2b55 2b56 0
2b58 1862 2b5f 15
:3 0 ee :3 0 2b59
2b5a 0 ef :2 0
2b5b 2b5c 0 2b5e
1864 2b60 2b52 2b58
0 2b61 0 2b5e
0 2b61 1866 0
2b62 1869 2bb5 f2
:3 0 15 :3 0 ee
:3 0 2b64 2b65 0
f1 :3 0 2b66 2b67
0 2b69 186c 2b6b
186e 2b6a 2b69 :2 0
2bb3 f3 :3 0 15
:3 0 ee :3 0 2b6e
2b6f 0 f1 :3 0
2b70 2b71 0 2bab
d0 :3 0 d1 :3 0
2b73 2b74 0 d0
:3 0 e0 :3 0 2b76
2b77 0 f4 :2 0
2 :4 0 252 :2 0
e2 :2 0 30 :2 0
1870 2b7c 2b7e :3 0
1873 2b78 2b80 2b75
2b82 2b81 :2 0 d3
:3 0 e3 :3 0 2b84
2b85 0 d5 :4 0
253 :4 0 d8 :2 0
d9 :3 0 1877 2b89
2b8b :3 0 d8 :2 0
f7 :4 0 187a 2b8d
2b8f :3 0 d8 :2 0
f8 :4 0 187d 2b91
2b93 :3 0 d8 :2 0
f1 :3 0 1880 2b95
2b97 :3 0 d8 :2 0
f9 :4 0 1883 2b99
2b9b :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1886 2b9e 2ba2 188a
2b9d 2ba4 :3 0 188d
2b86 2ba6 :2 0 2ba8
1890 2ba9 2b83 2ba8
0 2baa 1892 0
2bab 1894 2bae :3 0
2bae 0 2bae 2bad
2bab 2bac :6 0 2bb0
7a :3 0 1897 2bb2
1899 2bb1 2bb0 :2 0
2bb3 189b :2 0 2bb5
0 2bb5 2bb4 2b62
2bb3 :6 0 2bb8 67
:3 0 15c :3 0 189e
2cc9 8f :3 0 46
:3 0 45 :2 0 18a1
2bb9 2bbc 1a :3 0
e7 :2 0 198 :3 0
2bbe 2bc0 0 18a6
2bbf 2bc2 :3 0 7b
:3 0 174 :3 0 45
:2 0 8f :3 0 4a
:3 0 45 :2 0 18a9
2bc7 2bca 1a :3 0
175 :3 0 2bcc 2bcd
0 78 :3 0 18ac
2bc5 2bd0 2bc4 2bd1
0 2c4b bd :3 0
168 :3 0 1a :3 0
1a1 :3 0 16d :3 0
78 :3 0 13c :3 0
29 :3 0 9f :3 0
27 :3 0 a0 :3 0
a5 :3 0 20 :4 0
254 1 :8 0 2bf6
ed :4 0 2be1 :3 0
105 :3 0 e7 :2 0
18b3 2be4 2be5 :3 0
15 :3 0 ee :3 0
2be7 2be8 0 45
:2 0 2be9 2bea 0
2bec 18b6 2bf3 15
:3 0 ee :3 0 2bed
2bee 0 ef :2 0
2bef 2bf0 0 2bf2
18b8 2bf4 2be6 2bec
0 2bf5 0 2bf2
0 2bf5 18ba 0
2bf6 18bd 2c49 f2
:3 0 15 :3 0 ee
:3 0 2bf8 2bf9 0
f1 :3 0 2bfa 2bfb
0 2bfd 18c0 2bff
18c2 2bfe 2bfd :2 0
2c47 f3 :3 0 15
:3 0 ee :3 0 2c02
2c03 0 f1 :3 0
2c04 2c05 0 2c3f
d0 :3 0 d1 :3 0
2c07 2c08 0 d0
:3 0 e0 :3 0 2c0a
2c0b 0 f4 :2 0
2 :4 0 255 :2 0
e2 :2 0 30 :2 0
18c4 2c10 2c12 :3 0
18c7 2c0c 2c14 2c09
2c16 2c15 :2 0 d3
:3 0 e3 :3 0 2c18
2c19 0 d5 :4 0
256 :4 0 d8 :2 0
d9 :3 0 18cb 2c1d
2c1f :3 0 d8 :2 0
f7 :4 0 18ce 2c21
2c23 :3 0 d8 :2 0
f8 :4 0 18d1 2c25
2c27 :3 0 d8 :2 0
f1 :3 0 18d4 2c29
2c2b :3 0 d8 :2 0
f9 :4 0 18d7 2c2d
2c2f :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
18da 2c32 2c36 18de
2c31 2c38 :3 0 18e1
2c1a 2c3a :2 0 2c3c
18e4 2c3d 2c17 2c3c
0 2c3e 18e6 0
2c3f 18e8 2c42 :3 0
2c42 0 2c42 2c41
2c3f 2c40 :6 0 2c44
7c :3 0 18eb 2c46
18ed 2c45 2c44 :2 0
2c47 18ef :2 0 2c49
0 2c49 2c48 2bf6
2c47 :6 0 2c4b 67
:3 0 18f2 2c4c 2bc3
2c4b 0 2ccb bd
:3 0 168 :3 0 19d
:3 0 172 :3 0 46
:3 0 1a :3 0 1a1
:3 0 16d :3 0 1e
:3 0 13c :3 0 29
:3 0 9f :3 0 27
:3 0 a0 :3 0 a5
:3 0 20 :4 0 257
1 :8 0 2c73 ed
:4 0 2c5e :3 0 105
:3 0 e7 :2 0 18f7
2c61 2c62 :3 0 15
:3 0 ee :3 0 2c64
2c65 0 45 :2 0
2c66 2c67 0 2c69
18fa 2c70 15 :3 0
ee :3 0 2c6a 2c6b
0 ef :2 0 2c6c
2c6d 0 2c6f 18fc
2c71 2c63 2c69 0
2c72 0 2c6f 0
2c72 18fe 0 2c73
1901 2cc6 f2 :3 0
15 :3 0 ee :3 0
2c75 2c76 0 f1
:3 0 2c77 2c78 0
2c7a 1904 2c7c 1906
2c7b 2c7a :2 0 2cc4
f3 :3 0 15 :3 0
ee :3 0 2c7f 2c80
0 f1 :3 0 2c81
2c82 0 2cbc d0
:3 0 d1 :3 0 2c84
2c85 0 d0 :3 0
e0 :3 0 2c87 2c88
0 f4 :2 0 2
:4 0 258 :2 0 e2
:2 0 30 :2 0 1908
2c8d 2c8f :3 0 190b
2c89 2c91 2c86 2c93
2c92 :2 0 d3 :3 0
e3 :3 0 2c95 2c96
0 d5 :4 0 259
:4 0 d8 :2 0 d9
:3 0 190f 2c9a 2c9c
:3 0 d8 :2 0 f7
:4 0 1912 2c9e 2ca0
:3 0 d8 :2 0 f8
:4 0 1915 2ca2 2ca4
:3 0 d8 :2 0 f1
:3 0 1918 2ca6 2ca8
:3 0 d8 :2 0 f9
:4 0 191b 2caa 2cac
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 191e
2caf 2cb3 1922 2cae
2cb5 :3 0 1925 2c97
2cb7 :2 0 2cb9 1928
2cba 2c94 2cb9 0
2cbb 192a 0 2cbc
192c 2cbf :3 0 2cbf
0 2cbf 2cbe 2cbc
2cbd :6 0 2cc1 7e
:3 0 192f 2cc3 1931
2cc2 2cc1 :2 0 2cc4
1933 :2 0 2cc6 0
2cc6 2cc5 2c73 2cc4
:6 0 2cc8 67 :3 0
1936 2cca 2b40 2bb8
0 2ccb 0 2cc8
0 2ccb 1938 0
2d53 15 :3 0 ee
:3 0 2ccc 2ccd 0
15 :3 0 e7 :2 0
165 :3 0 2ccf 2cd1
0 193e 2cd0 2cd3
:3 0 2cd4 :2 0 8f
:3 0 48 :3 0 45
:2 0 1941 2cd6 2cd9
117 :2 0 45 :2 0
1946 2cdb 2cdd :3 0
2cde :2 0 2cd5 2ce0
2cdf :2 0 bd :3 0
a5 :3 0 1c :4 0
1df 1 :8 0 2cfb
ed :4 0 2ce6 :3 0
105 :3 0 e7 :2 0
194b 2ce9 2cea :3 0
15 :3 0 ee :3 0
2cec 2ced 0 45
:2 0 2cee 2cef 0
2cf1 194e 2cf8 15
:3 0 ee :3 0 2cf2
2cf3 0 ef :2 0
2cf4 2cf5 0 2cf7
1950 2cf9 2ceb 2cf1
0 2cfa 0 2cf7
0 2cfa 1952 0
2cfb 1955 2d4e f2
:3 0 15 :3 0 ee
:3 0 2cfd 2cfe 0
f1 :3 0 2cff 2d00
0 2d02 1958 2d04
195a 2d03 2d02 :2 0
2d4c f3 :3 0 15
:3 0 ee :3 0 2d07
2d08 0 f1 :3 0
2d09 2d0a 0 2d44
d0 :3 0 d1 :3 0
2d0c 2d0d 0 d0
:3 0 e0 :3 0 2d0f
2d10 0 f4 :2 0
2 :4 0 25a :2 0
e2 :2 0 30 :2 0
195c 2d15 2d17 :3 0
195f 2d11 2d19 2d0e
2d1b 2d1a :2 0 d3
:3 0 e3 :3 0 2d1d
2d1e 0 d5 :4 0
25b :4 0 d8 :2 0
d9 :3 0 1963 2d22
2d24 :3 0 d8 :2 0
f7 :4 0 1966 2d26
2d28 :3 0 d8 :2 0
f8 :4 0 1969 2d2a
2d2c :3 0 d8 :2 0
f1 :3 0 196c 2d2e
2d30 :3 0 d8 :2 0
f9 :4 0 196f 2d32
2d34 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1972 2d37 2d3b 1976
2d36 2d3d :3 0 1979
2d1f 2d3f :2 0 2d41
197c 2d42 2d1c 2d41
0 2d43 197e 0
2d44 1980 2d47 :3 0
2d47 0 2d47 2d46
2d44 2d45 :6 0 2d49
80 :3 0 1983 2d4b
1985 2d4a 2d49 :2 0
2d4c 1987 :2 0 2d4e
0 2d4e 2d4d 2cfb
2d4c :6 0 2d50 67
:3 0 198a 2d51 2ce1
2d50 0 2d52 198c
0 2d53 198e 3033
25c :3 0 a5 :3 0
ae :3 0 11d :3 0
186 :3 0 18b :3 0
11d :3 0 186 :3 0
1c :3 0 40 :3 0
bc :3 0 11d :3 0
bd :3 0 25c :3 0
11d :3 0 99 :3 0
26 :3 0 11d :3 0
99 :3 0 25c :3 0
99 :3 0 25c :3 0
168 :3 0 25c :3 0
9f :3 0 11d :3 0
25d :3 0 a7 :3 0
9d :3 0 25e :3 0
25e :3 0 a5 :3 0
25c :3 0 a5 :4 0
25f 1 :8 0 2d7c
15 :3 0 ee :3 0
2d77 2d78 0 f1
:3 0 2d79 2d7a 0
2d7c 1991 2dcf f2
:3 0 15 :3 0 ee
:3 0 2d7e 2d7f 0
f1 :3 0 2d80 2d81
0 2d83 1994 2d85
1996 2d84 2d83 :2 0
2dcd f3 :3 0 15
:3 0 ee :3 0 2d88
2d89 0 f1 :3 0
2d8a 2d8b 0 2dc5
d0 :3 0 d1 :3 0
2d8d 2d8e 0 d0
:3 0 e0 :3 0 2d90
2d91 0 f4 :2 0
2 :4 0 260 :2 0
e2 :2 0 30 :2 0
1998 2d96 2d98 :3 0
199b 2d92 2d9a 2d8f
2d9c 2d9b :2 0 d3
:3 0 e3 :3 0 2d9e
2d9f 0 d5 :4 0
261 :4 0 d8 :2 0
d9 :3 0 199f 2da3
2da5 :3 0 d8 :2 0
f7 :4 0 19a2 2da7
2da9 :3 0 d8 :2 0
f8 :4 0 19a5 2dab
2dad :3 0 d8 :2 0
f1 :3 0 19a8 2daf
2db1 :3 0 d8 :2 0
f9 :4 0 19ab 2db3
2db5 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
19ae 2db8 2dbc 19b2
2db7 2dbe :3 0 19b5
2da0 2dc0 :2 0 2dc2
19b8 2dc3 2d9d 2dc2
0 2dc4 19ba 0
2dc5 19bc 2dc8 :3 0
2dc8 0 2dc8 2dc7
2dc5 2dc6 :6 0 2dca
82 :3 0 19bf 2dcc
19c1 2dcb 2dca :2 0
2dcd 19c3 :2 0 2dcf
0 2dcf 2dce 2d7c
2dcd :6 0 3032 67
:3 0 15 :3 0 ee
:3 0 2dd1 2dd2 0
15 :3 0 e7 :2 0
165 :3 0 2dd4 2dd6
0 19c8 2dd5 2dd8
:3 0 2dd9 :2 0 1c
:3 0 1b9 :2 0 19cb
2ddc 2ddd :3 0 2dde
:2 0 2ddf :2 0 2dda
2de1 2de0 :2 0 7b
:3 0 174 :3 0 45
:2 0 8f :3 0 4a
:3 0 45 :2 0 19cd
2de6 2de9 1a :3 0
262 :3 0 2deb 2dec
0 78 :3 0 19d0
2de4 2def 2de3 2df0
0 2f49 bd :3 0
a5 :3 0 1c :4 0
1df 1 :8 0 2e0b
ed :4 0 2df6 :3 0
105 :3 0 e7 :2 0
19d7 2df9 2dfa :3 0
15 :3 0 ee :3 0
2dfc 2dfd 0 45
:2 0 2dfe 2dff 0
2e01 19da 2e08 15
:3 0 ee :3 0 2e02
2e03 0 ef :2 0
2e04 2e05 0 2e07
19dc 2e09 2dfb 2e01
0 2e0a 0 2e07
0 2e0a 19de 0
2e0b 19e1 2e5e f2
:3 0 15 :3 0 ee
:3 0 2e0d 2e0e 0
f1 :3 0 2e0f 2e10
0 2e12 19e4 2e14
19e6 2e13 2e12 :2 0
2e5c f3 :3 0 15
:3 0 ee :3 0 2e17
2e18 0 f1 :3 0
2e19 2e1a 0 2e54
d0 :3 0 d1 :3 0
2e1c 2e1d 0 d0
:3 0 e0 :3 0 2e1f
2e20 0 f4 :2 0
2 :4 0 263 :2 0
e2 :2 0 30 :2 0
19e8 2e25 2e27 :3 0
19eb 2e21 2e29 2e1e
2e2b 2e2a :2 0 d3
:3 0 e3 :3 0 2e2d
2e2e 0 d5 :4 0
264 :4 0 d8 :2 0
d9 :3 0 19ef 2e32
2e34 :3 0 d8 :2 0
f7 :4 0 19f2 2e36
2e38 :3 0 d8 :2 0
f8 :4 0 19f5 2e3a
2e3c :3 0 d8 :2 0
f1 :3 0 19f8 2e3e
2e40 :3 0 d8 :2 0
f9 :4 0 19fb 2e42
2e44 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
19fe 2e47 2e4b 1a02
2e46 2e4d :3 0 1a05
2e2f 2e4f :2 0 2e51
1a08 2e52 2e2c 2e51
0 2e53 1a0a 0
2e54 1a0c 2e57 :3 0
2e57 0 2e57 2e56
2e54 2e55 :6 0 2e59
84 :3 0 1a0f 2e5b
1a11 2e5a 2e59 :2 0
2e5c 1a13 :2 0 2e5e
0 2e5e 2e5d 2e0b
2e5c :6 0 2f49 67
:3 0 bd :3 0 9f
:3 0 27 :3 0 a0
:3 0 13c :3 0 29
:3 0 168 :3 0 16d
:3 0 78 :3 0 a5
:3 0 20 :4 0 265
1 :8 0 2e81 ed
:4 0 2e6c :3 0 105
:3 0 e7 :2 0 1a18
2e6f 2e70 :3 0 15
:3 0 ee :3 0 2e72
2e73 0 45 :2 0
2e74 2e75 0 2e77
1a1b 2e7e 15 :3 0
ee :3 0 2e78 2e79
0 ef :2 0 2e7a
2e7b 0 2e7d 1a1d
2e7f 2e71 2e77 0
2e80 0 2e7d 0
2e80 1a1f 0 2e81
1a22 2ed4 f2 :3 0
15 :3 0 ee :3 0
2e83 2e84 0 f1
:3 0 2e85 2e86 0
2e88 1a25 2e8a 1a27
2e89 2e88 :2 0 2ed2
f3 :3 0 15 :3 0
ee :3 0 2e8d 2e8e
0 f1 :3 0 2e8f
2e90 0 2eca d0
:3 0 d1 :3 0 2e92
2e93 0 d0 :3 0
e0 :3 0 2e95 2e96
0 f4 :2 0 2
:4 0 266 :2 0 e2
:2 0 30 :2 0 1a29
2e9b 2e9d :3 0 1a2c
2e97 2e9f 2e94 2ea1
2ea0 :2 0 d3 :3 0
e3 :3 0 2ea3 2ea4
0 d5 :4 0 267
:4 0 d8 :2 0 d9
:3 0 1a30 2ea8 2eaa
:3 0 d8 :2 0 f7
:4 0 1a33 2eac 2eae
:3 0 d8 :2 0 f8
:4 0 1a36 2eb0 2eb2
:3 0 d8 :2 0 f1
:3 0 1a39 2eb4 2eb6
:3 0 d8 :2 0 f9
:4 0 1a3c 2eb8 2eba
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1a3f
2ebd 2ec1 1a43 2ebc
2ec3 :3 0 1a46 2ea5
2ec5 :2 0 2ec7 1a49
2ec8 2ea2 2ec7 0
2ec9 1a4b 0 2eca
1a4d 2ecd :3 0 2ecd
0 2ecd 2ecc 2eca
2ecb :6 0 2ecf 86
:3 0 1a50 2ed1 1a52
2ed0 2ecf :2 0 2ed2
1a54 :2 0 2ed4 0
2ed4 2ed3 2e81 2ed2
:6 0 2f49 67 :3 0
bc :3 0 186 :3 0
187 :3 0 186 :3 0
40 :3 0 3e :3 0
99 :3 0 26 :4 0
268 1 :8 0 2ef4
ed :4 0 2edf :3 0
105 :3 0 e7 :2 0
1a59 2ee2 2ee3 :3 0
15 :3 0 ee :3 0
2ee5 2ee6 0 45
:2 0 2ee7 2ee8 0
2eea 1a5c 2ef1 15
:3 0 ee :3 0 2eeb
2eec 0 ef :2 0
2eed 2eee 0 2ef0
1a5e 2ef2 2ee4 2eea
0 2ef3 0 2ef0
0 2ef3 1a60 0
2ef4 1a63 2f47 f2
:3 0 15 :3 0 ee
:3 0 2ef6 2ef7 0
f1 :3 0 2ef8 2ef9
0 2efb 1a66 2efd
1a68 2efc 2efb :2 0
2f45 f3 :3 0 15
:3 0 ee :3 0 2f00
2f01 0 f1 :3 0
2f02 2f03 0 2f3d
d0 :3 0 d1 :3 0
2f05 2f06 0 d0
:3 0 e0 :3 0 2f08
2f09 0 f4 :2 0
2 :4 0 269 :2 0
e2 :2 0 30 :2 0
1a6a 2f0e 2f10 :3 0
1a6d 2f0a 2f12 2f07
2f14 2f13 :2 0 d3
:3 0 e3 :3 0 2f16
2f17 0 d5 :4 0
26a :4 0 d8 :2 0
d9 :3 0 1a71 2f1b
2f1d :3 0 d8 :2 0
f7 :4 0 1a74 2f1f
2f21 :3 0 d8 :2 0
f8 :4 0 1a77 2f23
2f25 :3 0 d8 :2 0
f1 :3 0 1a7a 2f27
2f29 :3 0 d8 :2 0
f9 :4 0 1a7d 2f2b
2f2d :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1a80 2f30 2f34 1a84
2f2f 2f36 :3 0 1a87
2f18 2f38 :2 0 2f3a
1a8a 2f3b 2f15 2f3a
0 2f3c 1a8c 0
2f3d 1a8e 2f40 :3 0
2f40 0 2f40 2f3f
2f3d 2f3e :6 0 2f42
88 :3 0 1a91 2f44
1a93 2f43 2f42 :2 0
2f45 1a95 :2 0 2f47
0 2f47 2f46 2ef4
2f45 :6 0 2f49 67
:3 0 1a98 302f bc
:3 0 186 :3 0 187
:3 0 186 :3 0 41
:3 0 3e :3 0 99
:3 0 26 :4 0 26b
1 :8 0 2f68 ed
:4 0 2f53 :3 0 105
:3 0 e7 :2 0 1a9f
2f56 2f57 :3 0 15
:3 0 ee :3 0 2f59
2f5a 0 45 :2 0
2f5b 2f5c 0 2f5e
1aa2 2f65 15 :3 0
ee :3 0 2f5f 2f60
0 ef :2 0 2f61
2f62 0 2f64 1aa4
2f66 2f58 2f5e 0
2f67 0 2f64 0
2f67 1aa6 0 2f68
1aa9 2fbb f2 :3 0
15 :3 0 ee :3 0
2f6a 2f6b 0 f1
:3 0 2f6c 2f6d 0
2f6f 1aac 2f71 1aae
2f70 2f6f :2 0 2fb9
f3 :3 0 15 :3 0
ee :3 0 2f74 2f75
0 f1 :3 0 2f76
2f77 0 2fb1 d0
:3 0 d1 :3 0 2f79
2f7a 0 d0 :3 0
e0 :3 0 2f7c 2f7d
0 f4 :2 0 2
:4 0 26c :2 0 e2
:2 0 30 :2 0 1ab0
2f82 2f84 :3 0 1ab3
2f7e 2f86 2f7b 2f88
2f87 :2 0 d3 :3 0
e3 :3 0 2f8a 2f8b
0 d5 :4 0 26d
:4 0 d8 :2 0 d9
:3 0 1ab7 2f8f 2f91
:3 0 d8 :2 0 f7
:4 0 1aba 2f93 2f95
:3 0 d8 :2 0 f8
:4 0 1abd 2f97 2f99
:3 0 d8 :2 0 f1
:3 0 1ac0 2f9b 2f9d
:3 0 d8 :2 0 f9
:4 0 1ac3 2f9f 2fa1
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1ac6
2fa4 2fa8 1aca 2fa3
2faa :3 0 1acd 2f8c
2fac :2 0 2fae 1ad0
2faf 2f89 2fae 0
2fb0 1ad2 0 2fb1
1ad4 2fb4 :3 0 2fb4
0 2fb4 2fb3 2fb1
2fb2 :6 0 2fb6 8a
:3 0 1ad7 2fb8 1ad9
2fb7 2fb6 :2 0 2fb9
1adb :2 0 2fbb 0
2fbb 2fba 2f68 2fb9
:6 0 302e 67 :3 0
bd :3 0 9f :3 0
27 :3 0 a0 :3 0
a5 :3 0 20 :4 0
26e 1 :8 0 2fd9
ed :4 0 2fc4 :3 0
105 :3 0 e7 :2 0
1ae0 2fc7 2fc8 :3 0
15 :3 0 ee :3 0
2fca 2fcb 0 45
:2 0 2fcc 2fcd 0
2fcf 1ae3 2fd6 15
:3 0 ee :3 0 2fd0
2fd1 0 ef :2 0
2fd2 2fd3 0 2fd5
1ae5 2fd7 2fc9 2fcf
0 2fd8 0 2fd5
0 2fd8 1ae7 0
2fd9 1aea 302c f2
:3 0 15 :3 0 ee
:3 0 2fdb 2fdc 0
f1 :3 0 2fdd 2fde
0 2fe0 1aed 2fe2
1aef 2fe1 2fe0 :2 0
302a f3 :3 0 15
:3 0 ee :3 0 2fe5
2fe6 0 f1 :3 0
2fe7 2fe8 0 3022
d0 :3 0 d1 :3 0
2fea 2feb 0 d0
:3 0 e0 :3 0 2fed
2fee 0 f4 :2 0
2 :4 0 26f :2 0
e2 :2 0 30 :2 0
1af1 2ff3 2ff5 :3 0
1af4 2fef 2ff7 2fec
2ff9 2ff8 :2 0 d3
:3 0 e3 :3 0 2ffb
2ffc 0 d5 :4 0
270 :4 0 d8 :2 0
d9 :3 0 1af8 3000
3002 :3 0 d8 :2 0
f7 :4 0 1afb 3004
3006 :3 0 d8 :2 0
f8 :4 0 1afe 3008
300a :3 0 d8 :2 0
f1 :3 0 1b01 300c
300e :3 0 d8 :2 0
f9 :4 0 1b04 3010
3012 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1b07 3015 3019 1b0b
3014 301b :3 0 1b0e
2ffd 301d :2 0 301f
1b11 3020 2ffa 301f
0 3021 1b13 0
3022 1b15 3025 :3 0
3025 0 3025 3024
3022 3023 :6 0 3027
8c :3 0 1b18 3029
1b1a 3028 3027 :2 0
302a 1b1c :2 0 302c
0 302c 302b 2fd9
302a :6 0 302e 67
:3 0 1b1f 3030 2de2
2f49 0 3031 0
302e 0 3031 1b22
0 3032 1b25 3034
2b2e 2d53 0 3035
0 3032 0 3035
1b28 0 30a6 1d0
:3 0 9e :3 0 28
:3 0 a7 :3 0 22
:4 0 23c 1 :8 0
3051 ed :4 0 303c
:3 0 105 :3 0 e7
:2 0 1b2d 303f 3040
:3 0 15 :3 0 ee
:3 0 3042 3043 0
45 :2 0 3044 3045
0 3047 1b30 304e
15 :3 0 ee :3 0
3048 3049 0 ef
:2 0 304a 304b 0
304d 1b32 304f 3041
3047 0 3050 0
304d 0 3050 1b34
0 3051 1b37 30a4
f2 :3 0 15 :3 0
ee :3 0 3053 3054
0 f1 :3 0 3055
3056 0 3058 1b3a
305a 1b3c 3059 3058
:2 0 30a2 f3 :3 0
15 :3 0 ee :3 0
305d 305e 0 f1
:3 0 305f 3060 0
309a d0 :3 0 d1
:3 0 3062 3063 0
d0 :3 0 e0 :3 0
3065 3066 0 f4
:2 0 2 :4 0 271
:2 0 e2 :2 0 30
:2 0 1b3e 306b 306d
:3 0 1b41 3067 306f
3064 3071 3070 :2 0
d3 :3 0 e3 :3 0
3073 3074 0 d5
:4 0 272 :4 0 d8
:2 0 d9 :3 0 1b45
3078 307a :3 0 d8
:2 0 f7 :4 0 1b48
307c 307e :3 0 d8
:2 0 f8 :4 0 1b4b
3080 3082 :3 0 d8
:2 0 f1 :3 0 1b4e
3084 3086 :3 0 d8
:2 0 f9 :4 0 1b51
3088 308a :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 1b54 308d 3091
1b58 308c 3093 :3 0
1b5b 3075 3095 :2 0
3097 1b5e 3098 3072
3097 0 3099 1b60
0 309a 1b62 309d
:3 0 309d 0 309d
309c 309a 309b :6 0
309f 8e :3 0 1b65
30a1 1b67 30a0 309f
:2 0 30a2 1b69 :2 0
30a4 0 30a4 30a3
3051 30a2 :6 0 30a6
67 :3 0 1b6c 320a
70 :3 0 30 :2 0
30a7 30a8 0 3209
bd :3 0 a5 :3 0
20 :4 0 232 1
:8 0 30c3 ed :4 0
30ae :3 0 105 :3 0
e7 :2 0 1b73 30b1
30b2 :3 0 15 :3 0
ee :3 0 30b4 30b5
0 45 :2 0 30b6
30b7 0 30b9 1b76
30c0 15 :3 0 ee
:3 0 30ba 30bb 0
ef :2 0 30bc 30bd
0 30bf 1b78 30c1
30b3 30b9 0 30c2
0 30bf 0 30c2
1b7a 0 30c3 1b7d
3116 f2 :3 0 15
:3 0 ee :3 0 30c5
30c6 0 f1 :3 0
30c7 30c8 0 30ca
1b80 30cc 1b82 30cb
30ca :2 0 3114 f3
:3 0 15 :3 0 ee
:3 0 30cf 30d0 0
f1 :3 0 30d1 30d2
0 310c d0 :3 0
d1 :3 0 30d4 30d5
0 d0 :3 0 e0
:3 0 30d7 30d8 0
f4 :2 0 2 :4 0
273 :2 0 e2 :2 0
30 :2 0 1b84 30dd
30df :3 0 1b87 30d9
30e1 30d6 30e3 30e2
:2 0 d3 :3 0 e3
:3 0 30e5 30e6 0
d5 :4 0 274 :4 0
d8 :2 0 d9 :3 0
1b8b 30ea 30ec :3 0
d8 :2 0 f7 :4 0
1b8e 30ee 30f0 :3 0
d8 :2 0 f8 :4 0
1b91 30f2 30f4 :3 0
d8 :2 0 f1 :3 0
1b94 30f6 30f8 :3 0
d8 :2 0 f9 :4 0
1b97 30fa 30fc :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 1b9a 30ff
3103 1b9e 30fe 3105
:3 0 1ba1 30e7 3107
:2 0 3109 1ba4 310a
30e4 3109 0 310b
1ba6 0 310c 1ba8
310f :3 0 310f 0
310f 310e 310c 310d
:6 0 3111 90 :3 0
1bab 3113 1bad 3112
3111 :2 0 3114 1baf
:2 0 3116 0 3116
3115 30c3 3114 :6 0
3209 67 :3 0 9d
:3 0 a7 :3 0 22
:4 0 235 1 :8 0
3131 ed :4 0 311c
:3 0 105 :3 0 e7
:2 0 1bb4 311f 3120
:3 0 15 :3 0 ee
:3 0 3122 3123 0
45 :2 0 3124 3125
0 3127 1bb7 312e
15 :3 0 ee :3 0
3128 3129 0 ef
:2 0 312a 312b 0
312d 1bb9 312f 3121
3127 0 3130 0
312d 0 3130 1bbb
0 3131 1bbe 3184
f2 :3 0 15 :3 0
ee :3 0 3133 3134
0 f1 :3 0 3135
3136 0 3138 1bc1
313a 1bc3 3139 3138
:2 0 3182 f3 :3 0
15 :3 0 ee :3 0
313d 313e 0 f1
:3 0 313f 3140 0
317a d0 :3 0 d1
:3 0 3142 3143 0
d0 :3 0 e0 :3 0
3145 3146 0 f4
:2 0 2 :4 0 275
:2 0 e2 :2 0 30
:2 0 1bc5 314b 314d
:3 0 1bc8 3147 314f
3144 3151 3150 :2 0
d3 :3 0 e3 :3 0
3153 3154 0 d5
:4 0 276 :4 0 d8
:2 0 d9 :3 0 1bcc
3158 315a :3 0 d8
:2 0 f7 :4 0 1bcf
315c 315e :3 0 d8
:2 0 f8 :4 0 1bd2
3160 3162 :3 0 d8
:2 0 f1 :3 0 1bd5
3164 3166 :3 0 d8
:2 0 f9 :4 0 1bd8
3168 316a :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 1bdb 316d 3171
1bdf 316c 3173 :3 0
1be2 3155 3175 :2 0
3177 1be5 3178 3152
3177 0 3179 1be7
0 317a 1be9 317d
:3 0 317d 0 317d
317c 317a 317b :6 0
317f 92 :3 0 1bec
3181 1bee 3180 317f
:2 0 3182 1bf0 :2 0
3184 0 3184 3183
3131 3182 :6 0 3209
67 :3 0 1d0 :3 0
9e :3 0 28 :3 0
a7 :3 0 22 :4 0
23c 1 :8 0 31a1
ed :4 0 318c :3 0
105 :3 0 e7 :2 0
1bf5 318f 3190 :3 0
15 :3 0 ee :3 0
3192 3193 0 45
:2 0 3194 3195 0
3197 1bf8 319e 15
:3 0 ee :3 0 3198
3199 0 ef :2 0
319a 319b 0 319d
1bfa 319f 3191 3197
0 31a0 0 319d
0 31a0 1bfc 0
31a1 1bff 31f4 f2
:3 0 15 :3 0 ee
:3 0 31a3 31a4 0
f1 :3 0 31a5 31a6
0 31a8 1c02 31aa
1c04 31a9 31a8 :2 0
31f2 f3 :3 0 15
:3 0 ee :3 0 31ad
31ae 0 f1 :3 0
31af 31b0 0 31ea
d0 :3 0 d1 :3 0
31b2 31b3 0 d0
:3 0 e0 :3 0 31b5
31b6 0 f4 :2 0
2 :4 0 277 :2 0
e2 :2 0 30 :2 0
1c06 31bb 31bd :3 0
1c09 31b7 31bf 31b4
31c1 31c0 :2 0 d3
:3 0 e3 :3 0 31c3
31c4 0 d5 :4 0
278 :4 0 d8 :2 0
d9 :3 0 1c0d 31c8
31ca :3 0 d8 :2 0
f7 :4 0 1c10 31cc
31ce :3 0 d8 :2 0
f8 :4 0 1c13 31d0
31d2 :3 0 d8 :2 0
f1 :3 0 1c16 31d4
31d6 :3 0 d8 :2 0
f9 :4 0 1c19 31d8
31da :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1c1c 31dd 31e1 1c20
31dc 31e3 :3 0 1c23
31c5 31e5 :2 0 31e7
1c26 31e8 31c2 31e7
0 31e9 1c28 0
31ea 1c2a 31ed :3 0
31ed 0 31ed 31ec
31ea 31eb :6 0 31ef
94 :3 0 1c2d 31f1
1c2f 31f0 31ef :2 0
31f2 1c31 :2 0 31f4
0 31f4 31f3 31a1
31f2 :6 0 3209 67
:3 0 ae :3 0 2f
:3 0 30 :2 0 30
:2 0 1c34 31f6 31fa
e7 :2 0 146 :4 0
1c3a 31fc 31fe :3 0
53 :3 0 146 :2 0
3200 3201 0 3203
1c3d 3204 31ff 3203
0 3205 1c3f 0
3209 22 :3 0 24
:3 0 3206 3207 0
3209 1c41 320b 2aba
30a6 0 320c 0
3209 0 320c 1c48
0 45bf 8f :3 0
48 :3 0 45 :2 0
1c4b 320d 3210 117
:2 0 45 :2 0 1c50
3212 3214 :3 0 8f
:3 0 6e :3 0 45
:2 0 1c53 3216 3219
e7 :2 0 30 :2 0
1c58 321b 321d :3 0
321e :2 0 42 :3 0
1b9 :2 0 1c5b 3221
3222 :3 0 3223 :2 0
3224 :2 0 321f 3226
3225 :2 0 131 :3 0
131 :3 0 42 :3 0
6d :3 0 bc :3 0
99 :3 0 26 :4 0
279 1 :8 0 3235
15 :3 0 ee :3 0
3230 3231 0 f1
:3 0 3232 3233 0
3235 1c5d 3288 f2
:3 0 15 :3 0 ee
:3 0 3237 3238 0
f1 :3 0 3239 323a
0 323c 1c60 323e
1c62 323d 323c :2 0
3286 f3 :3 0 15
:3 0 ee :3 0 3241
3242 0 f1 :3 0
3243 3244 0 327e
d0 :3 0 d1 :3 0
3246 3247 0 d0
:3 0 e0 :3 0 3249
324a 0 f4 :2 0
2 :4 0 27a :2 0
e2 :2 0 30 :2 0
1c64 324f 3251 :3 0
1c67 324b 3253 3248
3255 3254 :2 0 d3
:3 0 e3 :3 0 3257
3258 0 d5 :4 0
27b :4 0 d8 :2 0
d9 :3 0 1c6b 325c
325e :3 0 d8 :2 0
f7 :4 0 1c6e 3260
3262 :3 0 d8 :2 0
f8 :4 0 1c71 3264
3266 :3 0 d8 :2 0
f1 :3 0 1c74 3268
326a :3 0 d8 :2 0
f9 :4 0 1c77 326c
326e :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1c7a 3271 3275 1c7e
3270 3277 :3 0 1c81
3259 3279 :2 0 327b
1c84 327c 3256 327b
0 327d 1c86 0
327e 1c88 3281 :3 0
3281 0 3281 3280
327e 327f :6 0 3283
96 :3 0 1c8b 3285
1c8d 3284 3283 :2 0
3286 1c8f :2 0 3288
0 3288 3287 3235
3286 :6 0 33f7 67
:3 0 15 :3 0 ee
:3 0 328a 328b 0
15 :3 0 e7 :2 0
165 :3 0 328d 328f
0 1c94 328e 3291
:3 0 3292 :2 0 8f
:3 0 6d :3 0 45
:2 0 1c97 3294 3297
e7 :2 0 45 :2 0
1c9c 3299 329b :3 0
329c :2 0 3293 329e
329d :2 0 bc :3 0
131 :3 0 42 :3 0
99 :3 0 26 :4 0
27c 1 :8 0 32bb
ed :4 0 32a6 :3 0
105 :3 0 e7 :2 0
1ca1 32a9 32aa :3 0
15 :3 0 ee :3 0
32ac 32ad 0 45
:2 0 32ae 32af 0
32b1 1ca4 32b8 15
:3 0 ee :3 0 32b2
32b3 0 ef :2 0
32b4 32b5 0 32b7
1ca6 32b9 32ab 32b1
0 32ba 0 32b7
0 32ba 1ca8 0
32bb 1cab 330e f2
:3 0 15 :3 0 ee
:3 0 32bd 32be 0
f1 :3 0 32bf 32c0
0 32c2 1cae 32c4
1cb0 32c3 32c2 :2 0
330c f3 :3 0 15
:3 0 ee :3 0 32c7
32c8 0 f1 :3 0
32c9 32ca 0 3304
d0 :3 0 d1 :3 0
32cc 32cd 0 d0
:3 0 e0 :3 0 32cf
32d0 0 f4 :2 0
2 :4 0 27d :2 0
e2 :2 0 30 :2 0
1cb2 32d5 32d7 :3 0
1cb5 32d1 32d9 32ce
32db 32da :2 0 d3
:3 0 e3 :3 0 32dd
32de 0 d5 :4 0
27e :4 0 d8 :2 0
d9 :3 0 1cb9 32e2
32e4 :3 0 d8 :2 0
f7 :4 0 1cbc 32e6
32e8 :3 0 d8 :2 0
f8 :4 0 1cbf 32ea
32ec :3 0 d8 :2 0
f1 :3 0 1cc2 32ee
32f0 :3 0 d8 :2 0
f9 :4 0 1cc5 32f2
32f4 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1cc8 32f7 32fb 1ccc
32f6 32fd :3 0 1ccf
32df 32ff :2 0 3301
1cd2 3302 32dc 3301
0 3303 1cd4 0
3304 1cd6 3307 :3 0
3307 0 3307 3306
3304 3305 :6 0 3309
98 :3 0 1cd9 330b
1cdb 330a 3309 :2 0
330c 1cdd :2 0 330e
0 330e 330d 32bb
330c :6 0 3311 67
:3 0 15c :3 0 1ce0
33f5 15 :3 0 ee
:3 0 3312 3313 0
15 :3 0 e7 :2 0
165 :3 0 3315 3317
0 1ce4 3316 3319
:3 0 331a :2 0 8f
:3 0 6d :3 0 45
:2 0 1ce7 331c 331f
e7 :2 0 146 :2 0
1cec 3321 3323 :3 0
3324 :2 0 331b 3326
3325 :2 0 f0 :3 0
a3 :4 0 332b :2 0
3331 3329 0 15
:3 0 ee :3 0 332c
332d 0 f1 :3 0
332e 332f 0 3331
1cef 3384 f2 :3 0
15 :3 0 ee :3 0
3333 3334 0 f1
:3 0 3335 3336 0
3338 1cf2 333a 1cf4
3339 3338 :2 0 3382
f3 :3 0 15 :3 0
ee :3 0 333d 333e
0 f1 :3 0 333f
3340 0 337a d0
:3 0 d1 :3 0 3342
3343 0 d0 :3 0
e0 :3 0 3345 3346
0 f4 :2 0 2
:4 0 27f :2 0 e2
:2 0 30 :2 0 1cf6
334b 334d :3 0 1cf9
3347 334f 3344 3351
3350 :2 0 d3 :3 0
e3 :3 0 3353 3354
0 d5 :4 0 280
:4 0 d8 :2 0 d9
:3 0 1cfd 3358 335a
:3 0 d8 :2 0 f7
:4 0 1d00 335c 335e
:3 0 d8 :2 0 f8
:4 0 1d03 3360 3362
:3 0 d8 :2 0 f1
:3 0 1d06 3364 3366
:3 0 d8 :2 0 f9
:4 0 1d09 3368 336a
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1d0c
336d 3371 1d10 336c
3373 :3 0 1d13 3355
3375 :2 0 3377 1d16
3378 3352 3377 0
3379 1d18 0 337a
1d1a 337d :3 0 337d
0 337d 337c 337a
337b :6 0 337f 9a
:3 0 1d1d 3381 1d1f
3380 337f :2 0 3382
1d21 :2 0 3384 0
3384 3383 3331 3382
:6 0 33f3 67 :3 0
d0 :3 0 d1 :3 0
3386 3387 0 d0
:3 0 e0 :3 0 3389
338a 0 1d :2 0
2 :4 0 281 :2 0
e2 :2 0 30 :2 0
1d24 338f 3391 :3 0
1d27 338b 3393 3388
3395 3394 :2 0 d3
:3 0 e3 :3 0 3397
3398 0 d5 :4 0
282 :4 0 d8 :2 0
d9 :3 0 1d2b 339c
339e :3 0 d8 :2 0
f7 :4 0 1d2e 33a0
33a2 :3 0 d8 :2 0
fe :4 0 1d31 33a4
33a6 :3 0 d8 :2 0
8f :3 0 dd :3 0
1a :3 0 283 :3 0
33ab 33ac 0 1d34
33aa 33ae de :4 0
1d36 33a9 33b1 1d39
33a8 33b3 :3 0 d8
:2 0 100 :4 0 1d3c
33b5 33b7 :3 0 d8
:2 0 db :4 0 1d3f
33b9 33bb :3 0 d8
:2 0 26 :3 0 1d42
33bd 33bf :3 0 d8
:2 0 db :4 0 1d45
33c1 33c3 :3 0 1d48
3399 33c5 :2 0 33c7
1d4b 33c8 3396 33c7
0 33c9 1d4d 0
33f3 d0 :3 0 d1
:3 0 33ca 33cb 0
d0 :3 0 e0 :3 0
33cd 33ce 0 30
:2 0 2 :4 0 284
:2 0 e2 :2 0 30
:2 0 1d4f 33d3 33d5
:3 0 1d52 33cf 33d7
33cc 33d9 33d8 :2 0
d3 :3 0 e3 :3 0
33db 33dc 0 d5
:4 0 285 :4 0 d8
:2 0 d9 :3 0 1d56
33e0 33e2 :3 0 1d59
33dd 33e4 :2 0 33e6
1d5c 33e7 33da 33e6
0 33e8 1d5e 0
33f3 103 :3 0 104
:3 0 33e9 33ea 0
1a :3 0 283 :3 0
33ec 33ed 0 26
:3 0 105 :3 0 1d60
33eb 33f1 :2 0 33f3
1d64 33f4 3327 33f3
0 33f6 329f 3311
0 33f6 1d69 0
33f7 1d6c 33f8 3227
33f7 0 33f9 1d6f
0 45bc 8f :3 0
87 :3 0 45 :2 0
1d71 33fa 33fd 1a
:3 0 e7 :2 0 286
:3 0 33ff 3401 0
1d76 3400 3403 :3 0
8f :3 0 87 :3 0
45 :2 0 1d79 3405
3408 1a :3 0 e7
:2 0 287 :3 0 340a
340c 0 1d7e 340b
340e :3 0 3404 3410
340f :2 0 288 :3 0
289 :3 0 28a :4 0
3414 :4 0 3415 :2 0
3812 15 :3 0 ee
:3 0 3417 3418 0
45 :2 0 3419 341a
0 3812 8f :3 0
51 :3 0 45 :2 0
1d81 341c 341f e7
:2 0 45 :2 0 1d86
3421 3423 :3 0 8f
:3 0 4d :3 0 45
:2 0 1d89 3425 3428
e7 :2 0 45 :2 0
1d8e 342a 342c :3 0
3424 342e 342d :2 0
28b :3 0 a4 :3 0
228 :3 0 97 :3 0
a4 :3 0 a4 :3 0
99 :3 0 27 :3 0
a4 :3 0 228 :3 0
ad :3 0 ae :3 0
7c :3 0 ad :3 0
ae :3 0 7d :4 0
28c 1 :8 0 3456
ed :4 0 3441 :3 0
105 :3 0 e7 :2 0
1d93 3444 3445 :3 0
15 :3 0 ee :3 0
3447 3448 0 45
:2 0 3449 344a 0
344c 1d96 3453 15
:3 0 ee :3 0 344d
344e 0 ef :2 0
344f 3450 0 3452
1d98 3454 3446 344c
0 3455 0 3452
0 3455 1d9a 0
3456 1d9d 34a9 f2
:3 0 15 :3 0 ee
:3 0 3458 3459 0
f1 :3 0 345a 345b
0 345d 1da0 345f
1da2 345e 345d :2 0
34a7 f3 :3 0 15
:3 0 ee :3 0 3462
3463 0 f1 :3 0
3464 3465 0 349f
d0 :3 0 d1 :3 0
3467 3468 0 d0
:3 0 e0 :3 0 346a
346b 0 f4 :2 0
2 :4 0 28d :2 0
e2 :2 0 30 :2 0
1da4 3470 3472 :3 0
1da7 346c 3474 3469
3476 3475 :2 0 d3
:3 0 e3 :3 0 3478
3479 0 d5 :4 0
28e :4 0 d8 :2 0
d9 :3 0 1dab 347d
347f :3 0 d8 :2 0
f7 :4 0 1dae 3481
3483 :3 0 d8 :2 0
f8 :4 0 1db1 3485
3487 :3 0 d8 :2 0
f1 :3 0 1db4 3489
348b :3 0 d8 :2 0
f9 :4 0 1db7 348d
348f :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1dba 3492 3496 1dbe
3491 3498 :3 0 1dc1
347a 349a :2 0 349c
1dc4 349d 3477 349c
0 349e 1dc6 0
349f 1dc8 34a2 :3 0
34a2 0 34a2 34a1
349f 34a0 :6 0 34a4
9c :3 0 1dcb 34a6
1dcd 34a5 34a4 :2 0
34a7 1dcf :2 0 34a9
0 34a9 34a8 3456
34a7 :6 0 34ab 67
:3 0 1dd2 3534 28b
:3 0 a4 :3 0 228
:3 0 97 :3 0 a4
:3 0 1d0 :3 0 28f
:3 0 a4 :3 0 99
:3 0 27 :3 0 a4
:3 0 228 :3 0 ad
:3 0 ae :3 0 7c
:3 0 ad :3 0 ae
:3 0 7d :3 0 28f
:3 0 9e :3 0 28
:3 0 28f :3 0 a7
:3 0 22 :3 0 a4
:3 0 228 :3 0 28f
:3 0 228 :4 0 290
1 :8 0 34de ed
:4 0 34c9 :3 0 105
:3 0 e7 :2 0 1dd6
34cc 34cd :3 0 15
:3 0 ee :3 0 34cf
34d0 0 45 :2 0
34d1 34d2 0 34d4
1dd9 34db 15 :3 0
ee :3 0 34d5 34d6
0 ef :2 0 34d7
34d8 0 34da 1ddb
34dc 34ce 34d4 0
34dd 0 34da 0
34dd 1ddd 0 34de
1de0 3531 f2 :3 0
15 :3 0 ee :3 0
34e0 34e1 0 f1
:3 0 34e2 34e3 0
34e5 1de3 34e7 1de5
34e6 34e5 :2 0 352f
f3 :3 0 15 :3 0
ee :3 0 34ea 34eb
0 f1 :3 0 34ec
34ed 0 3527 d0
:3 0 d1 :3 0 34ef
34f0 0 d0 :3 0
e0 :3 0 34f2 34f3
0 f4 :2 0 2
:4 0 291 :2 0 e2
:2 0 30 :2 0 1de7
34f8 34fa :3 0 1dea
34f4 34fc 34f1 34fe
34fd :2 0 d3 :3 0
e3 :3 0 3500 3501
0 d5 :4 0 292
:4 0 d8 :2 0 d9
:3 0 1dee 3505 3507
:3 0 d8 :2 0 f7
:4 0 1df1 3509 350b
:3 0 d8 :2 0 f8
:4 0 1df4 350d 350f
:3 0 d8 :2 0 f1
:3 0 1df7 3511 3513
:3 0 d8 :2 0 f9
:4 0 1dfa 3515 3517
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1dfd
351a 351e 1e01 3519
3520 :3 0 1e04 3502
3522 :2 0 3524 1e07
3525 34ff 3524 0
3526 1e09 0 3527
1e0b 352a :3 0 352a
0 352a 3529 3527
3528 :6 0 352c 9e
:3 0 1e0e 352e 1e10
352d 352c :2 0 352f
1e12 :2 0 3531 0
3531 3530 34de 352f
:6 0 3533 67 :3 0
1e15 3535 342f 34ab
0 3536 0 3533
0 3536 1e17 0
3812 15 :3 0 ee
:3 0 3537 3538 0
15 :3 0 e7 :2 0
165 :3 0 353a 353c
0 1e1c 353b 353e
:3 0 353f :2 0 75
:3 0 45 :2 0 3541
3542 0 380b 147
:3 0 228 :3 0 293
:3 0 228 :3 0 75
:3 0 32 :3 0 28b
:4 0 294 1 :8 0
3551 15 :3 0 ee
:3 0 354c 354d 0
f1 :3 0 354e 354f
0 3551 1e1f 35a4
f2 :3 0 15 :3 0
ee :3 0 3553 3554
0 f1 :3 0 3555
3556 0 3558 1e22
355a 1e24 3559 3558
:2 0 35a2 f3 :3 0
15 :3 0 ee :3 0
355d 355e 0 f1
:3 0 355f 3560 0
359a d0 :3 0 d1
:3 0 3562 3563 0
d0 :3 0 e0 :3 0
3565 3566 0 f4
:2 0 2 :4 0 295
:2 0 e2 :2 0 30
:2 0 1e26 356b 356d
:3 0 1e29 3567 356f
3564 3571 3570 :2 0
d3 :3 0 e3 :3 0
3573 3574 0 d5
:4 0 296 :4 0 d8
:2 0 d9 :3 0 1e2d
3578 357a :3 0 d8
:2 0 f7 :4 0 1e30
357c 357e :3 0 d8
:2 0 f8 :4 0 1e33
3580 3582 :3 0 d8
:2 0 f1 :3 0 1e36
3584 3586 :3 0 d8
:2 0 f9 :4 0 1e39
3588 358a :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 1e3c 358d 3591
1e40 358c 3593 :3 0
1e43 3575 3595 :2 0
3597 1e46 3598 3572
3597 0 3599 1e48
0 359a 1e4a 359d
:3 0 359d 0 359d
359c 359a 359b :6 0
359f a0 :3 0 1e4d
35a1 1e4f 35a0 359f
:2 0 35a2 1e51 :2 0
35a4 0 35a4 35a3
3551 35a2 :6 0 380b
67 :3 0 8f :3 0
75 :3 0 45 :2 0
1e54 35a6 35a9 e7
:2 0 45 :2 0 1e59
35ab 35ad :3 0 297
:3 0 35af :4 0 35b1
1e5c 3740 1d0 :3 0
9e :3 0 28 :3 0
a7 :3 0 22 :4 0
298 1 :8 0 35cd
ed :4 0 35b8 :3 0
105 :3 0 e7 :2 0
1e60 35bb 35bc :3 0
15 :3 0 ee :3 0
35be 35bf 0 45
:2 0 35c0 35c1 0
35c3 1e63 35ca 15
:3 0 ee :3 0 35c4
35c5 0 ef :2 0
35c6 35c7 0 35c9
1e65 35cb 35bd 35c3
0 35cc 0 35c9
0 35cc 1e67 0
35cd 1e6a 3620 f2
:3 0 15 :3 0 ee
:3 0 35cf 35d0 0
f1 :3 0 35d1 35d2
0 35d4 1e6d 35d6
1e6f 35d5 35d4 :2 0
361e f3 :3 0 15
:3 0 ee :3 0 35d9
35da 0 f1 :3 0
35db 35dc 0 3616
d0 :3 0 d1 :3 0
35de 35df 0 d0
:3 0 e0 :3 0 35e1
35e2 0 f4 :2 0
2 :4 0 299 :2 0
e2 :2 0 30 :2 0
1e71 35e7 35e9 :3 0
1e74 35e3 35eb 35e0
35ed 35ec :2 0 d3
:3 0 e3 :3 0 35ef
35f0 0 d5 :4 0
29a :4 0 d8 :2 0
d9 :3 0 1e78 35f4
35f6 :3 0 d8 :2 0
f7 :4 0 1e7b 35f8
35fa :3 0 d8 :2 0
f8 :4 0 1e7e 35fc
35fe :3 0 d8 :2 0
f1 :3 0 1e81 3600
3602 :3 0 d8 :2 0
f9 :4 0 1e84 3604
3606 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1e87 3609 360d 1e8b
3608 360f :3 0 1e8e
35f1 3611 :2 0 3613
1e91 3614 35ee 3613
0 3615 1e93 0
3616 1e95 3619 :3 0
3619 0 3619 3618
3616 3617 :6 0 361b
a2 :3 0 1e98 361d
1e9a 361c 361b :2 0
361e 1e9c :2 0 3620
0 3620 361f 35cd
361e :6 0 373f 67
:3 0 6f :3 0 29b
:3 0 8f :3 0 29c
:3 0 48 :3 0 1e9f
3625 3627 45 :2 0
1ea1 3624 362a 29d
:2 0 8f :3 0 29c
:3 0 75 :3 0 1ea4
362e 3630 45 :2 0
1ea6 362d 3633 1ea9
362c 3635 :3 0 3636
:2 0 e2 :2 0 29e
:2 0 1eac 3638 363a
:3 0 1eaf 3623 363c
3622 363d 0 373f
96 :3 0 29f :3 0
60 :3 0 17 :3 0
97 :3 0 99 :3 0
28 :3 0 228 :3 0
32 :4 0 2a0 1
:8 0 364e 15 :3 0
ee :3 0 3649 364a
0 f1 :3 0 364b
364c 0 364e 1eb1
36a1 f2 :3 0 15
:3 0 ee :3 0 3650
3651 0 f1 :3 0
3652 3653 0 3655
1eb4 3657 1eb6 3656
3655 :2 0 369f f3
:3 0 15 :3 0 ee
:3 0 365a 365b 0
f1 :3 0 365c 365d
0 3697 d0 :3 0
d1 :3 0 365f 3660
0 d0 :3 0 e0
:3 0 3662 3663 0
f4 :2 0 2 :4 0
2a1 :2 0 e2 :2 0
30 :2 0 1eb8 3668
366a :3 0 1ebb 3664
366c 3661 366e 366d
:2 0 d3 :3 0 e3
:3 0 3670 3671 0
d5 :4 0 2a2 :4 0
d8 :2 0 d9 :3 0
1ebf 3675 3677 :3 0
d8 :2 0 f7 :4 0
1ec2 3679 367b :3 0
d8 :2 0 f8 :4 0
1ec5 367d 367f :3 0
d8 :2 0 f1 :3 0
1ec8 3681 3683 :3 0
d8 :2 0 f9 :4 0
1ecb 3685 3687 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 1ece 368a
368e 1ed2 3689 3690
:3 0 1ed5 3672 3692
:2 0 3694 1ed8 3695
366f 3694 0 3696
1eda 0 3697 1edc
369a :3 0 369a 0
369a 3699 3697 3698
:6 0 369c a4 :3 0
1edf 369e 1ee1 369d
369c :2 0 369f 1ee3
:2 0 36a1 0 36a1
36a0 364e 369f :6 0
373f 67 :3 0 8f
:3 0 60 :3 0 45
:2 0 1ee6 36a3 36a6
8f :3 0 117 :2 0
6f :3 0 45 :2 0
1ee9 36a8 36ac 1eee
36a9 36ae :3 0 19d
:3 0 2a3 :3 0 36b0
36b1 0 8f :3 0
6f :3 0 45 :2 0
1ef1 36b3 36b6 17
:3 0 1ef4 36b2 36b9
:2 0 36bb 1ef7 36bc
36af 36bb 0 36bd
1ef9 0 373f 1d0
:3 0 9e :3 0 9f
:3 0 a7 :3 0 228
:3 0 182 :3 0 1cf
:3 0 29f :3 0 1d1
:3 0 2a4 :3 0 a8
:3 0 28 :3 0 27
:3 0 22 :3 0 228
:3 0 6f :3 0 17
:3 0 55 :3 0 22
:3 0 23 :3 0 26
:3 0 28b :4 0 2a5
1 :8 0 36ea ed
:4 0 36d5 :3 0 105
:3 0 e7 :2 0 1efd
36d8 36d9 :3 0 15
:3 0 ee :3 0 36db
36dc 0 45 :2 0
36dd 36de 0 36e0
1f00 36e7 15 :3 0
ee :3 0 36e1 36e2
0 ef :2 0 36e3
36e4 0 36e6 1f02
36e8 36da 36e0 0
36e9 0 36e6 0
36e9 1f04 0 36ea
1f07 373d f2 :3 0
15 :3 0 ee :3 0
36ec 36ed 0 f1
:3 0 36ee 36ef 0
36f1 1f0a 36f3 1f0c
36f2 36f1 :2 0 373b
f3 :3 0 15 :3 0
ee :3 0 36f6 36f7
0 f1 :3 0 36f8
36f9 0 3733 d0
:3 0 d1 :3 0 36fb
36fc 0 d0 :3 0
e0 :3 0 36fe 36ff
0 f4 :2 0 2
:4 0 2a6 :2 0 e2
:2 0 30 :2 0 1f0e
3704 3706 :3 0 1f11
3700 3708 36fd 370a
3709 :2 0 d3 :3 0
e3 :3 0 370c 370d
0 d5 :4 0 2a7
:4 0 d8 :2 0 d9
:3 0 1f15 3711 3713
:3 0 d8 :2 0 f7
:4 0 1f18 3715 3717
:3 0 d8 :2 0 f8
:4 0 1f1b 3719 371b
:3 0 d8 :2 0 f1
:3 0 1f1e 371d 371f
:3 0 d8 :2 0 f9
:4 0 1f21 3721 3723
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1f24
3726 372a 1f28 3725
372c :3 0 1f2b 370e
372e :2 0 3730 1f2e
3731 370b 3730 0
3732 1f30 0 3733
1f32 3736 :3 0 3736
0 3736 3735 3733
3734 :6 0 3738 a6
:3 0 1f35 373a 1f37
3739 3738 :2 0 373b
1f39 :2 0 373d 0
373d 373c 36ea 373b
:6 0 373f 67 :3 0
1f3c 3741 35ae 35b1
0 3742 0 373f
0 3742 1f42 0
380b 9d :3 0 9f
:3 0 27 :3 0 a0
:3 0 a1 :3 0 55
:3 0 23 :3 0 b5
:3 0 6b :3 0 62
:3 0 b5 :3 0 1ec
:3 0 6b :3 0 65
:3 0 1ec :3 0 b6
:3 0 6a :3 0 64
:3 0 b6 :3 0 1ed
:3 0 6a :3 0 66
:3 0 1ed :3 0 1f0
:3 0 19d :3 0 172
:3 0 1f0 :3 0 1a
:3 0 1f1 :3 0 a7
:3 0 22 :4 0 2a8
1 :8 0 3778 ed
:4 0 3763 :3 0 105
:3 0 e7 :2 0 1f47
3766 3767 :3 0 15
:3 0 ee :3 0 3769
376a 0 45 :2 0
376b 376c 0 376e
1f4a 3775 15 :3 0
ee :3 0 376f 3770
0 ef :2 0 3771
3772 0 3774 1f4c
3776 3768 376e 0
3777 0 3774 0
3777 1f4e 0 3778
1f51 37cb f2 :3 0
15 :3 0 ee :3 0
377a 377b 0 f1
:3 0 377c 377d 0
377f 1f54 3781 1f56
3780 377f :2 0 37c9
f3 :3 0 15 :3 0
ee :3 0 3784 3785
0 f1 :3 0 3786
3787 0 37c1 d0
:3 0 d1 :3 0 3789
378a 0 d0 :3 0
e0 :3 0 378c 378d
0 f4 :2 0 2
:4 0 2a9 :2 0 e2
:2 0 30 :2 0 1f58
3792 3794 :3 0 1f5b
378e 3796 378b 3798
3797 :2 0 d3 :3 0
e3 :3 0 379a 379b
0 d5 :4 0 2aa
:4 0 d8 :2 0 d9
:3 0 1f5f 379f 37a1
:3 0 d8 :2 0 f7
:4 0 1f62 37a3 37a5
:3 0 d8 :2 0 f8
:4 0 1f65 37a7 37a9
:3 0 d8 :2 0 f1
:3 0 1f68 37ab 37ad
:3 0 d8 :2 0 f9
:4 0 1f6b 37af 37b1
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1f6e
37b4 37b8 1f72 37b3
37ba :3 0 1f75 379c
37bc :2 0 37be 1f78
37bf 3799 37be 0
37c0 1f7a 0 37c1
1f7c 37c4 :3 0 37c4
0 37c4 37c3 37c1
37c2 :6 0 37c6 a8
:3 0 1f7f 37c8 1f81
37c7 37c6 :2 0 37c9
1f83 :2 0 37cb 0
37cb 37ca 3778 37c9
:6 0 380b 67 :3 0
88 :3 0 29b :3 0
8f :3 0 29c :3 0
6f :3 0 1f86 37d0
37d2 45 :2 0 1f88
37cf 37d5 29d :2 0
8f :3 0 29c :3 0
58 :3 0 1f8b 37d9
37db 45 :2 0 1f8d
37d8 37de 1f90 37d7
37e0 :3 0 37e1 :2 0
1ac :2 0 2ab :2 0
1f93 37e3 37e5 :3 0
1f96 37ce 37e7 37cd
37e8 0 380b 75
:3 0 171 :3 0 172
:3 0 37eb 37ec 0
8f :3 0 88 :3 0
45 :2 0 1f98 37ee
37f1 1a :3 0 2ac
:3 0 37f3 37f4 0
1f9b 37ed 37f6 37ea
37f7 0 380b 7b
:3 0 227 :3 0 28
:3 0 22 :3 0 75
:3 0 8f :3 0 58
:3 0 45 :2 0 1f9e
37fe 3801 8f :3 0
48 :3 0 45 :2 0
1fa1 3803 3806 1fa4
37fa 3808 37f9 3809
0 380b 1faa 380f
297 :3 0 380c :4 0
380e 1fb2 3810 3540
380b 0 3811 0
380e 0 3811 1fb4
0 3812 1fb7 4107
2c :3 0 eb :4 0
3813 3814 0 4106
8d :3 0 14e :2 0
45 :2 0 1fbe 3817
3819 :3 0 8f :3 0
70 :3 0 45 :2 0
1fc1 381b 381e 14e
:2 0 45 :2 0 1fc6
3820 3822 :3 0 48
:3 0 9 :3 0 3824
3825 0 38ca 8f
:3 0 4d :3 0 45
:2 0 1fc9 3827 382a
e7 :2 0 45 :2 0
1fce 382c 382e :3 0
8f :3 0 88 :3 0
45 :2 0 1fd1 3830
3833 14e :2 0 2ad
:2 0 1fd6 3835 3837
:3 0 382f 3839 3838
:2 0 8f :3 0 88
:3 0 45 :2 0 1fd9
383b 383e 14e :2 0
45 :2 0 1fde 3840
3842 :3 0 383a 3844
3843 :2 0 50 :3 0
ef :2 0 3846 3847
0 3850 4d :3 0
8f :3 0 88 :3 0
45 :2 0 1fe1 384a
384d 3849 384e 0
3850 1fe4 3851 3845
3850 0 3852 1fe7
0 38ca 9d :3 0
1f0 :3 0 19d :3 0
172 :3 0 1f0 :3 0
1a :3 0 1f1 :3 0
2ae :3 0 2ae :3 0
48 :3 0 a7 :3 0
22 :4 0 2af 1
:8 0 3875 ed :4 0
3860 :3 0 105 :3 0
e7 :2 0 1feb 3863
3864 :3 0 15 :3 0
ee :3 0 3866 3867
0 45 :2 0 3868
3869 0 386b 1fee
3872 15 :3 0 ee
:3 0 386c 386d 0
ef :2 0 386e 386f
0 3871 1ff0 3873
3865 386b 0 3874
0 3871 0 3874
1ff2 0 3875 1ff5
38c8 f2 :3 0 15
:3 0 ee :3 0 3877
3878 0 f1 :3 0
3879 387a 0 387c
1ff8 387e 1ffa 387d
387c :2 0 38c6 f3
:3 0 15 :3 0 ee
:3 0 3881 3882 0
f1 :3 0 3883 3884
0 38be d0 :3 0
d1 :3 0 3886 3887
0 d0 :3 0 e0
:3 0 3889 388a 0
f4 :2 0 2 :4 0
2b0 :2 0 e2 :2 0
30 :2 0 1ffc 388f
3891 :3 0 1fff 388b
3893 3888 3895 3894
:2 0 d3 :3 0 e3
:3 0 3897 3898 0
d5 :4 0 2b1 :4 0
d8 :2 0 d9 :3 0
2003 389c 389e :3 0
d8 :2 0 f7 :4 0
2006 38a0 38a2 :3 0
d8 :2 0 f8 :4 0
2009 38a4 38a6 :3 0
d8 :2 0 f1 :3 0
200c 38a8 38aa :3 0
d8 :2 0 f9 :4 0
200f 38ac 38ae :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 2012 38b1
38b5 2016 38b0 38b7
:3 0 2019 3899 38b9
:2 0 38bb 201c 38bc
3896 38bb 0 38bd
201e 0 38be 2020
38c1 :3 0 38c1 0
38c1 38c0 38be 38bf
:6 0 38c3 aa :3 0
2023 38c5 2025 38c4
38c3 :2 0 38c6 2027
:2 0 38c8 0 38c8
38c7 3875 38c6 :6 0
38ca 67 :3 0 202a
3b07 48 :3 0 9
:3 0 38cb 38cc 0
3b06 2a :3 0 7
:3 0 38ce 38cf 0
3b06 2c :3 0 8
:3 0 38d1 38d2 0
3b06 4d :3 0 b
:3 0 38d4 38d5 0
3b06 4e :3 0 10
:3 0 38d7 38d8 0
3b06 4f :3 0 d
:3 0 38da 38db 0
3b06 50 :3 0 e
:3 0 38dd 38de 0
3b06 57 :3 0 c
:3 0 38e0 38e1 0
3b06 51 :3 0 f
:3 0 38e3 38e4 0
3b06 e5 :3 0 8f
:3 0 c :3 0 45
:2 0 202e 38e7 38ea
1a :3 0 1bf :3 0
38ec 38ed 0 2031
38e6 38ef 38f0 :2 0
14e :2 0 45 :2 0
2036 38f2 38f4 :3 0
38f5 :2 0 8f :3 0
51 :3 0 45 :2 0
2039 38f7 38fa 8f
:3 0 14e :2 0 f
:3 0 45 :2 0 203c
38fc 3900 2041 38fd
3902 :3 0 8f :3 0
4d :3 0 45 :2 0
2044 3904 3907 8f
:3 0 14e :2 0 b
:3 0 45 :2 0 2047
3909 390d 204c 390a
390f :3 0 3903 3911
3910 :2 0 3912 :2 0
38f6 3914 3913 :2 0
8f :3 0 e :3 0
45 :2 0 204f 3916
3919 e7 :2 0 ef
:2 0 2054 391b 391d
:3 0 9d :3 0 9f
:3 0 27 :3 0 a0
:3 0 a1 :3 0 55
:3 0 23 :3 0 b5
:3 0 6b :3 0 62
:3 0 b5 :3 0 1ec
:3 0 6b :3 0 65
:3 0 1ec :3 0 b6
:3 0 6a :3 0 64
:3 0 b6 :3 0 1ed
:3 0 6a :3 0 66
:3 0 1ed :3 0 ab
:3 0 b :3 0 2ae
:3 0 48 :3 0 ba
:3 0 f :3 0 1f0
:3 0 19d :3 0 172
:3 0 1f0 :3 0 1a
:3 0 1f1 :3 0 a7
:3 0 22 :4 0 2b2
1 :8 0 395a ed
:4 0 3945 :3 0 105
:3 0 e7 :2 0 2059
3948 3949 :3 0 15
:3 0 ee :3 0 394b
394c 0 45 :2 0
394d 394e 0 3950
205c 3957 15 :3 0
ee :3 0 3951 3952
0 ef :2 0 3953
3954 0 3956 205e
3958 394a 3950 0
3959 0 3956 0
3959 2060 0 395a
2063 39ad f2 :3 0
15 :3 0 ee :3 0
395c 395d 0 f1
:3 0 395e 395f 0
3961 2066 3963 2068
3962 3961 :2 0 39ab
f3 :3 0 15 :3 0
ee :3 0 3966 3967
0 f1 :3 0 3968
3969 0 39a3 d0
:3 0 d1 :3 0 396b
396c 0 d0 :3 0
e0 :3 0 396e 396f
0 f4 :2 0 2
:4 0 2b3 :2 0 e2
:2 0 30 :2 0 206a
3974 3976 :3 0 206d
3970 3978 396d 397a
3979 :2 0 d3 :3 0
e3 :3 0 397c 397d
0 d5 :4 0 2b4
:4 0 d8 :2 0 d9
:3 0 2071 3981 3983
:3 0 d8 :2 0 f7
:4 0 2074 3985 3987
:3 0 d8 :2 0 f8
:4 0 2077 3989 398b
:3 0 d8 :2 0 f1
:3 0 207a 398d 398f
:3 0 d8 :2 0 f9
:4 0 207d 3991 3993
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 2080
3996 399a 2084 3995
399c :3 0 2087 397e
399e :2 0 39a0 208a
39a1 397b 39a0 0
39a2 208c 0 39a3
208e 39a6 :3 0 39a6
0 39a6 39a5 39a3
39a4 :6 0 39a8 ac
:3 0 2091 39aa 2093
39a9 39a8 :2 0 39ab
2095 :2 0 39ad 0
39ad 39ac 395a 39ab
:6 0 39af 67 :3 0
2098 3a43 9d :3 0
9f :3 0 27 :3 0
a0 :3 0 a1 :3 0
55 :3 0 23 :3 0
b5 :3 0 6b :3 0
62 :3 0 b5 :3 0
1ec :3 0 6b :3 0
65 :3 0 1ec :3 0
b6 :3 0 6a :3 0
64 :3 0 b6 :3 0
1ed :3 0 6a :3 0
66 :3 0 1ed :3 0
b7 :3 0 b :3 0
2ae :3 0 48 :3 0
b9 :3 0 e :3 0
ba :3 0 f :3 0
1f0 :3 0 19d :3 0
172 :3 0 1f0 :3 0
1a :3 0 1f1 :3 0
a7 :3 0 22 :4 0
2b5 1 :8 0 39ed
ed :4 0 39d8 :3 0
105 :3 0 e7 :2 0
209c 39db 39dc :3 0
15 :3 0 ee :3 0
39de 39df 0 45
:2 0 39e0 39e1 0
39e3 209f 39ea 15
:3 0 ee :3 0 39e4
39e5 0 ef :2 0
39e6 39e7 0 39e9
20a1 39eb 39dd 39e3
0 39ec 0 39e9
0 39ec 20a3 0
39ed 20a6 3a40 f2
:3 0 15 :3 0 ee
:3 0 39ef 39f0 0
f1 :3 0 39f1 39f2
0 39f4 20a9 39f6
20ab 39f5 39f4 :2 0
3a3e f3 :3 0 15
:3 0 ee :3 0 39f9
39fa 0 f1 :3 0
39fb 39fc 0 3a36
d0 :3 0 d1 :3 0
39fe 39ff 0 d0
:3 0 e0 :3 0 3a01
3a02 0 f4 :2 0
2 :4 0 2b6 :2 0
e2 :2 0 30 :2 0
20ad 3a07 3a09 :3 0
20b0 3a03 3a0b 3a00
3a0d 3a0c :2 0 d3
:3 0 e3 :3 0 3a0f
3a10 0 d5 :4 0
2b7 :4 0 d8 :2 0
d9 :3 0 20b4 3a14
3a16 :3 0 d8 :2 0
f7 :4 0 20b7 3a18
3a1a :3 0 d8 :2 0
f8 :4 0 20ba 3a1c
3a1e :3 0 d8 :2 0
f1 :3 0 20bd 3a20
3a22 :3 0 d8 :2 0
f9 :4 0 20c0 3a24
3a26 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
20c3 3a29 3a2d 20c7
3a28 3a2f :3 0 20ca
3a11 3a31 :2 0 3a33
20cd 3a34 3a0e 3a33
0 3a35 20cf 0
3a36 20d1 3a39 :3 0
3a39 0 3a39 3a38
3a36 3a37 :6 0 3a3b
ae :3 0 20d4 3a3d
20d6 3a3c 3a3b :2 0
3a3e 20d8 :2 0 3a40
0 3a40 3a3f 39ed
3a3e :6 0 3a42 67
:3 0 20db 3a44 391e
39af 0 3a45 0
3a42 0 3a45 20dd
0 3a46 20e0 3ad4
9d :3 0 9f :3 0
27 :3 0 a0 :3 0
a1 :3 0 55 :3 0
23 :3 0 b5 :3 0
6b :3 0 62 :3 0
b5 :3 0 1ec :3 0
6b :3 0 65 :3 0
1ec :3 0 b6 :3 0
6a :3 0 64 :3 0
b6 :3 0 1ed :3 0
6a :3 0 66 :3 0
1ed :3 0 1f0 :3 0
19d :3 0 172 :3 0
1f0 :3 0 1a :3 0
1f1 :3 0 2ae :3 0
48 :3 0 a7 :3 0
22 :4 0 2b8 1
:8 0 3a7e ed :4 0
3a69 :3 0 105 :3 0
e7 :2 0 20e4 3a6c
3a6d :3 0 15 :3 0
ee :3 0 3a6f 3a70
0 45 :2 0 3a71
3a72 0 3a74 20e7
3a7b 15 :3 0 ee
:3 0 3a75 3a76 0
ef :2 0 3a77 3a78
0 3a7a 20e9 3a7c
3a6e 3a74 0 3a7d
0 3a7a 0 3a7d
20eb 0 3a7e 20ee
3ad1 f2 :3 0 15
:3 0 ee :3 0 3a80
3a81 0 f1 :3 0
3a82 3a83 0 3a85
20f1 3a87 20f3 3a86
3a85 :2 0 3acf f3
:3 0 15 :3 0 ee
:3 0 3a8a 3a8b 0
f1 :3 0 3a8c 3a8d
0 3ac7 d0 :3 0
d1 :3 0 3a8f 3a90
0 d0 :3 0 e0
:3 0 3a92 3a93 0
f4 :2 0 2 :4 0
2b9 :2 0 e2 :2 0
30 :2 0 20f5 3a98
3a9a :3 0 20f8 3a94
3a9c 3a91 3a9e 3a9d
:2 0 d3 :3 0 e3
:3 0 3aa0 3aa1 0
d5 :4 0 2ba :4 0
d8 :2 0 d9 :3 0
20fc 3aa5 3aa7 :3 0
d8 :2 0 f7 :4 0
20ff 3aa9 3aab :3 0
d8 :2 0 f8 :4 0
2102 3aad 3aaf :3 0
d8 :2 0 f1 :3 0
2105 3ab1 3ab3 :3 0
d8 :2 0 f9 :4 0
2108 3ab5 3ab7 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 210b 3aba
3abe 210f 3ab9 3ac0
:3 0 2112 3aa2 3ac2
:2 0 3ac4 2115 3ac5
3a9f 3ac4 0 3ac6
2117 0 3ac7 2119
3aca :3 0 3aca 0
3aca 3ac9 3ac7 3ac8
:6 0 3acc b0 :3 0
211c 3ace 211e 3acd
3acc :2 0 3acf 2120
:2 0 3ad1 0 3ad1
3ad0 3a7e 3acf :6 0
3ad3 67 :3 0 2123
3ad5 3915 3a46 0
3ad6 0 3ad3 0
3ad6 2125 0 3b06
8f :3 0 51 :3 0
45 :2 0 2128 3ad7
3ada e7 :2 0 45
:2 0 212d 3adc 3ade
:3 0 3adf :2 0 8f
:3 0 50 :3 0 45
:2 0 2130 3ae1 3ae4
14e :2 0 ef :2 0
2135 3ae6 3ae8 :3 0
3ae9 :2 0 3ae0 3aeb
3aea :2 0 4d :3 0
45 :2 0 3aed 3aee
0 3af1 15c :3 0
2138 3b04 8f :3 0
50 :3 0 45 :2 0
213a 3af2 3af5 e7
:2 0 ef :2 0 213f
3af7 3af9 :3 0 88
:3 0 8f :3 0 4d
:3 0 45 :2 0 2142
3afc 3aff 3afb 3b00
0 3b02 2145 3b03
3afa 3b02 0 3b05
3aec 3af1 0 3b05
2147 0 3b06 214a
3b08 3823 38ca 0
3b09 0 3b06 0
3b09 2156 0 3cdb
75 :3 0 20f :3 0
39 :3 0 3a :3 0
8f :3 0 4f :3 0
45 :2 0 2159 3b0e
3b11 8f :3 0 50
:3 0 45 :2 0 215c
3b13 3b16 8f :3 0
5b :3 0 45 :2 0
215f 3b18 3b1b 8f
:3 0 57 :3 0 45
:2 0 2162 3b1d 3b20
8f :3 0 51 :3 0
45 :2 0 2165 3b22
3b25 8f :3 0 4e
:3 0 45 :2 0 2168
3b27 3b2a 8f :3 0
58 :3 0 45 :2 0
216b 3b2c 3b2f 8f
:3 0 59 :3 0 45
:2 0 216e 3b31 3b34
4d :3 0 48 :3 0
52 :3 0 2171 3b0b
3b39 3b0a 3b3a 0
3cdb 8f :3 0 75
:3 0 45 :2 0 217f
3b3c 3b3f 1a :3 0
e7 :2 0 210 :3 0
3b41 3b43 0 2184
3b42 3b45 :3 0 f0
:3 0 a3 :4 0 3b4a
:2 0 3b50 3b48 0
15 :3 0 ee :3 0
3b4b 3b4c 0 f1
:3 0 3b4d 3b4e 0
3b50 2187 3ba3 f2
:3 0 15 :3 0 ee
:3 0 3b52 3b53 0
f1 :3 0 3b54 3b55
0 3b57 218a 3b59
218c 3b58 3b57 :2 0
3ba1 f3 :3 0 15
:3 0 ee :3 0 3b5c
3b5d 0 f1 :3 0
3b5e 3b5f 0 3b99
d0 :3 0 d1 :3 0
3b61 3b62 0 d0
:3 0 e0 :3 0 3b64
3b65 0 f4 :2 0
2 :4 0 2bb :2 0
e2 :2 0 30 :2 0
218e 3b6a 3b6c :3 0
2191 3b66 3b6e 3b63
3b70 3b6f :2 0 d3
:3 0 e3 :3 0 3b72
3b73 0 d5 :4 0
2bc :4 0 d8 :2 0
d9 :3 0 2195 3b77
3b79 :3 0 d8 :2 0
f7 :4 0 2198 3b7b
3b7d :3 0 d8 :2 0
f8 :4 0 219b 3b7f
3b81 :3 0 d8 :2 0
f1 :3 0 219e 3b83
3b85 :3 0 d8 :2 0
f9 :4 0 21a1 3b87
3b89 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
21a4 3b8c 3b90 21a8
3b8b 3b92 :3 0 21ab
3b74 3b94 :2 0 3b96
21ae 3b97 3b71 3b96
0 3b98 21b0 0
3b99 21b2 3b9c :3 0
3b9c 0 3b9c 3b9b
3b99 3b9a :6 0 3b9e
b2 :3 0 21b5 3ba0
21b7 3b9f 3b9e :2 0
3ba1 21b9 :2 0 3ba3
0 3ba3 3ba2 3b50
3ba1 :6 0 3c02 67
:3 0 d0 :3 0 d1
:3 0 3ba5 3ba6 0
d0 :3 0 e0 :3 0
3ba8 3ba9 0 211
:2 0 2 :4 0 2bd
:2 0 e2 :2 0 30
:2 0 21bc 3bae 3bb0
:3 0 21bf 3baa 3bb2
3ba7 3bb4 3bb3 :2 0
d3 :3 0 e3 :3 0
3bb6 3bb7 0 d5
:4 0 2be :4 0 d8
:2 0 d9 :3 0 21c3
3bbb 3bbd :3 0 d8
:2 0 f7 :4 0 21c6
3bbf 3bc1 :3 0 d8
:2 0 fe :4 0 21c9
3bc3 3bc5 :3 0 d8
:2 0 8f :3 0 dd
:3 0 1a :3 0 210
:3 0 3bca 3bcb 0
21cc 3bc9 3bcd de
:4 0 21ce 3bc8 3bd0
21d1 3bc7 3bd2 :3 0
21d4 3bb8 3bd4 :2 0
3bd6 21d7 3bd7 3bb5
3bd6 0 3bd8 21d9
0 3c02 d0 :3 0
d1 :3 0 3bd9 3bda
0 d0 :3 0 e0
:3 0 3bdc 3bdd 0
30 :2 0 2 :4 0
2bf :2 0 e2 :2 0
30 :2 0 21db 3be2
3be4 :3 0 21de 3bde
3be6 3bdb 3be8 3be7
:2 0 d3 :3 0 e3
:3 0 3bea 3beb 0
d5 :4 0 2c0 :4 0
d8 :2 0 d9 :3 0
21e2 3bef 3bf1 :3 0
21e5 3bec 3bf3 :2 0
3bf5 21e8 3bf6 3be9
3bf5 0 3bf7 21ea
0 3c02 103 :3 0
216 :3 0 3bf8 3bf9
0 1a :3 0 210
:3 0 3bfb 3bfc 0
105 :3 0 21ec 3bfa
3bff :2 0 3c02 15c
:3 0 21ef 3cd9 8f
:3 0 75 :3 0 45
:2 0 21f4 3c03 3c06
14e :2 0 45 :2 0
21f9 3c08 3c0a :3 0
f0 :3 0 a3 :4 0
3c0f :2 0 3c15 3c0d
0 15 :3 0 ee
:3 0 3c10 3c11 0
f1 :3 0 3c12 3c13
0 3c15 21fc 3c68
f2 :3 0 15 :3 0
ee :3 0 3c17 3c18
0 f1 :3 0 3c19
3c1a 0 3c1c 21ff
3c1e 2201 3c1d 3c1c
:2 0 3c66 f3 :3 0
15 :3 0 ee :3 0
3c21 3c22 0 f1
:3 0 3c23 3c24 0
3c5e d0 :3 0 d1
:3 0 3c26 3c27 0
d0 :3 0 e0 :3 0
3c29 3c2a 0 f4
:2 0 2 :4 0 2c1
:2 0 e2 :2 0 30
:2 0 2203 3c2f 3c31
:3 0 2206 3c2b 3c33
3c28 3c35 3c34 :2 0
d3 :3 0 e3 :3 0
3c37 3c38 0 d5
:4 0 2c2 :4 0 d8
:2 0 d9 :3 0 220a
3c3c 3c3e :3 0 d8
:2 0 f7 :4 0 220d
3c40 3c42 :3 0 d8
:2 0 f8 :4 0 2210
3c44 3c46 :3 0 d8
:2 0 f1 :3 0 2213
3c48 3c4a :3 0 d8
:2 0 f9 :4 0 2216
3c4c 3c4e :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2219 3c51 3c55
221d 3c50 3c57 :3 0
2220 3c39 3c59 :2 0
3c5b 2223 3c5c 3c36
3c5b 0 3c5d 2225
0 3c5e 2227 3c61
:3 0 3c61 0 3c61
3c60 3c5e 3c5f :6 0
3c63 b4 :3 0 222a
3c65 222c 3c64 3c63
:2 0 3c66 222e :2 0
3c68 0 3c68 3c67
3c15 3c66 :6 0 3cd7
67 :3 0 d0 :3 0
d1 :3 0 3c6a 3c6b
0 d0 :3 0 e0
:3 0 3c6d 3c6e 0
1d :2 0 2 :4 0
2c3 :2 0 e2 :2 0
30 :2 0 2231 3c73
3c75 :3 0 2234 3c6f
3c77 3c6c 3c79 3c78
:2 0 d3 :3 0 e3
:3 0 3c7b 3c7c 0
d5 :4 0 2c4 :4 0
d8 :2 0 d9 :3 0
2238 3c80 3c82 :3 0
d8 :2 0 f7 :4 0
223b 3c84 3c86 :3 0
d8 :2 0 fe :4 0
223e 3c88 3c8a :3 0
d8 :2 0 8f :3 0
dd :3 0 75 :3 0
2241 3c8e 3c90 de
:4 0 2243 3c8d 3c93
2246 3c8c 3c95 :3 0
d8 :2 0 100 :4 0
2249 3c97 3c99 :3 0
d8 :2 0 db :4 0
224c 3c9b 3c9d :3 0
d8 :2 0 28 :3 0
224f 3c9f 3ca1 :3 0
d8 :2 0 db :4 0
2252 3ca3 3ca5 :3 0
2255 3c7d 3ca7 :2 0
3ca9 2258 3caa 3c7a
3ca9 0 3cab 225a
0 3cd7 d0 :3 0
d1 :3 0 3cac 3cad
0 d0 :3 0 e0
:3 0 3caf 3cb0 0
30 :2 0 2 :4 0
2c5 :2 0 e2 :2 0
30 :2 0 225c 3cb5
3cb7 :3 0 225f 3cb1
3cb9 3cae 3cbb 3cba
:2 0 d3 :3 0 e3
:3 0 3cbd 3cbe 0
d5 :4 0 2c6 :4 0
d8 :2 0 d9 :3 0
2263 3cc2 3cc4 :3 0
2266 3cbf 3cc6 :2 0
3cc8 2269 3cc9 3cbc
3cc8 0 3cca 226b
0 3cd7 103 :3 0
104 :3 0 3ccb 3ccc
0 8f :3 0 75
:3 0 45 :2 0 226d
3cce 3cd1 28 :3 0
105 :3 0 2270 3ccd
3cd5 :2 0 3cd7 2274
3cd8 3c0b 3cd7 0
3cda 3b46 3c02 0
3cda 2279 0 3cdb
227c 3e7c 8f :3 0
4d :3 0 45 :2 0
2280 3cdc 3cdf e7
:2 0 45 :2 0 2285
3ce1 3ce3 :3 0 8f
:3 0 88 :3 0 45
:2 0 2288 3ce5 3ce8
14e :2 0 2ad :2 0
228d 3cea 3cec :3 0
3ce4 3cee 3ced :2 0
8f :3 0 88 :3 0
45 :2 0 2290 3cf0
3cf3 14e :2 0 45
:2 0 2295 3cf5 3cf7
:3 0 3cef 3cf9 3cf8
:2 0 50 :3 0 ef
:2 0 3cfb 3cfc 0
3d05 4d :3 0 8f
:3 0 88 :3 0 45
:2 0 2298 3cff 3d02
3cfe 3d03 0 3d05
229b 3d06 3cfa 3d05
0 3d07 229e 0
3e7b 8f :3 0 52
:3 0 45 :2 0 22a0
3d08 3d0b e7 :2 0
45 :2 0 22a5 3d0d
3d0f :3 0 3d10 :2 0
8f :3 0 52 :3 0
45 :2 0 22a8 3d12
3d15 8f :3 0 20d
:2 0 58 :3 0 45
:2 0 22ab 3d17 3d1b
22b0 3d18 3d1d :3 0
3d1e :2 0 3d11 3d20
3d1f :2 0 52 :3 0
8f :3 0 58 :3 0
45 :2 0 22b3 3d23
3d26 3d22 3d27 0
3d29 22b6 3d3d 52
:3 0 29b :3 0 8f
:3 0 52 :3 0 45
:2 0 22b8 3d2c 3d2f
29d :2 0 8f :3 0
58 :3 0 45 :2 0
22bb 3d32 3d35 22be
3d31 3d37 :3 0 22c1
3d2b 3d39 3d2a 3d3a
0 3d3c 22c3 3d3e
3d21 3d29 0 3d3f
0 3d3c 0 3d3f
22c5 0 3e7b 8f
:3 0 52 :3 0 45
:2 0 22c8 3d40 3d43
20d :2 0 2c7 :2 0
22cd 3d45 3d47 :3 0
52 :3 0 8f :3 0
52 :3 0 45 :2 0
22d0 3d4a 3d4d 1ac
:2 0 43 :2 0 22d3
3d4f 3d51 :3 0 3d49
3d52 0 3d54 22d6
3d67 52 :3 0 29b
:3 0 29c :3 0 8f
:3 0 52 :3 0 45
:2 0 22d8 3d58 3d5b
22db 3d57 3d5d 1ac
:2 0 2c8 :2 0 22dd
3d5f 3d61 :3 0 22e0
3d56 3d63 3d55 3d64
0 3d66 22e2 3d68
3d48 3d54 0 3d69
0 3d66 0 3d69
22e4 0 3e7b 8f
:3 0 70 :3 0 45
:2 0 22e7 3d6a 3d6d
14e :2 0 45 :2 0
22ec 3d6f 3d71 :3 0
9d :3 0 1f0 :3 0
19d :3 0 172 :3 0
1f0 :3 0 1a :3 0
1f1 :3 0 2ae :3 0
2ae :3 0 48 :3 0
a7 :3 0 22 :4 0
2af 1 :8 0 3d95
ed :4 0 3d80 :3 0
105 :3 0 e7 :2 0
22f1 3d83 3d84 :3 0
15 :3 0 ee :3 0
3d86 3d87 0 45
:2 0 3d88 3d89 0
3d8b 22f4 3d92 15
:3 0 ee :3 0 3d8c
3d8d 0 ef :2 0
3d8e 3d8f 0 3d91
22f6 3d93 3d85 3d8b
0 3d94 0 3d91
0 3d94 22f8 0
3d95 22fb 3de8 f2
:3 0 15 :3 0 ee
:3 0 3d97 3d98 0
f1 :3 0 3d99 3d9a
0 3d9c 22fe 3d9e
2300 3d9d 3d9c :2 0
3de6 f3 :3 0 15
:3 0 ee :3 0 3da1
3da2 0 f1 :3 0
3da3 3da4 0 3dde
d0 :3 0 d1 :3 0
3da6 3da7 0 d0
:3 0 e0 :3 0 3da9
3daa 0 f4 :2 0
2 :4 0 2c9 :2 0
e2 :2 0 30 :2 0
2302 3daf 3db1 :3 0
2305 3dab 3db3 3da8
3db5 3db4 :2 0 d3
:3 0 e3 :3 0 3db7
3db8 0 d5 :4 0
2ca :4 0 d8 :2 0
d9 :3 0 2309 3dbc
3dbe :3 0 d8 :2 0
f7 :4 0 230c 3dc0
3dc2 :3 0 d8 :2 0
f8 :4 0 230f 3dc4
3dc6 :3 0 d8 :2 0
f1 :3 0 2312 3dc8
3dca :3 0 d8 :2 0
f9 :4 0 2315 3dcc
3dce :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2318 3dd1 3dd5 231c
3dd0 3dd7 :3 0 231f
3db9 3dd9 :2 0 3ddb
2322 3ddc 3db6 3ddb
0 3ddd 2324 0
3dde 2326 3de1 :3 0
3de1 0 3de1 3de0
3dde 3ddf :6 0 3de3
b6 :3 0 2329 3de5
232b 3de4 3de3 :2 0
3de6 232d :2 0 3de8
0 3de8 3de7 3d95
3de6 :6 0 3dea 67
:3 0 2330 3e78 9d
:3 0 9f :3 0 27
:3 0 a0 :3 0 a1
:3 0 55 :3 0 23
:3 0 b5 :3 0 6b
:3 0 62 :3 0 b5
:3 0 1ec :3 0 6b
:3 0 65 :3 0 1ec
:3 0 b6 :3 0 6a
:3 0 64 :3 0 b6
:3 0 1ed :3 0 6a
:3 0 66 :3 0 1ed
:3 0 1f0 :3 0 19d
:3 0 172 :3 0 1f0
:3 0 1a :3 0 1f1
:3 0 2ae :3 0 48
:3 0 a7 :3 0 22
:4 0 2cb 1 :8 0
3e22 ed :4 0 3e0d
:3 0 105 :3 0 e7
:2 0 2334 3e10 3e11
:3 0 15 :3 0 ee
:3 0 3e13 3e14 0
45 :2 0 3e15 3e16
0 3e18 2337 3e1f
15 :3 0 ee :3 0
3e19 3e1a 0 ef
:2 0 3e1b 3e1c 0
3e1e 2339 3e20 3e12
3e18 0 3e21 0
3e1e 0 3e21 233b
0 3e22 233e 3e75
f2 :3 0 15 :3 0
ee :3 0 3e24 3e25
0 f1 :3 0 3e26
3e27 0 3e29 2341
3e2b 2343 3e2a 3e29
:2 0 3e73 f3 :3 0
15 :3 0 ee :3 0
3e2e 3e2f 0 f1
:3 0 3e30 3e31 0
3e6b d0 :3 0 d1
:3 0 3e33 3e34 0
d0 :3 0 e0 :3 0
3e36 3e37 0 f4
:2 0 2 :4 0 2cc
:2 0 e2 :2 0 30
:2 0 2345 3e3c 3e3e
:3 0 2348 3e38 3e40
3e35 3e42 3e41 :2 0
d3 :3 0 e3 :3 0
3e44 3e45 0 d5
:4 0 2cd :4 0 d8
:2 0 d9 :3 0 234c
3e49 3e4b :3 0 d8
:2 0 f7 :4 0 234f
3e4d 3e4f :3 0 d8
:2 0 f8 :4 0 2352
3e51 3e53 :3 0 d8
:2 0 f1 :3 0 2355
3e55 3e57 :3 0 d8
:2 0 f9 :4 0 2358
3e59 3e5b :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 235b 3e5e 3e62
235f 3e5d 3e64 :3 0
2362 3e46 3e66 :2 0
3e68 2365 3e69 3e43
3e68 0 3e6a 2367
0 3e6b 2369 3e6e
:3 0 3e6e 0 3e6e
3e6d 3e6b 3e6c :6 0
3e70 b8 :3 0 236c
3e72 236e 3e71 3e70
:2 0 3e73 2370 :2 0
3e75 0 3e75 3e74
3e22 3e73 :6 0 3e77
67 :3 0 2373 3e79
3d72 3dea 0 3e7a
0 3e77 0 3e7a
2375 0 3e7b 2378
3e7d 381a 3cdb 0
3e7e 0 3e7b 0
3e7e 237d 0 4106
49 :3 0 45 :2 0
3e7f 3e80 0 4106
8f :3 0 5b :3 0
45 :2 0 2380 3e82
3e85 1a :3 0 e7
:2 0 e9 :3 0 3e87
3e89 0 2385 3e88
3e8b :3 0 5a :3 0
2ce :2 0 3e8d 3e8e
0 3e90 2388 3e95
5a :3 0 30 :2 0
3e91 3e92 0 3e94
238a 3e96 3e8c 3e90
0 3e97 0 3e94
0 3e97 238c 0
4106 8f :3 0 4d
:3 0 45 :2 0 238f
3e98 3e9b e7 :2 0
45 :2 0 2394 3e9d
3e9f :3 0 57 :3 0
1a :3 0 20c :3 0
3ea2 3ea3 0 3ea1
3ea4 0 3ea6 2397
3eb7 57 :3 0 171
:3 0 172 :3 0 3ea8
3ea9 0 8f :3 0
57 :3 0 45 :2 0
2399 3eab 3eae 1a
:3 0 20c :3 0 3eb0
3eb1 0 239c 3eaa
3eb3 3ea7 3eb4 0
3eb6 239f 3eb8 3ea0
3ea6 0 3eb9 0
3eb6 0 3eb9 23a1
0 4106 4e :3 0
45 :2 0 3eba 3ebb
0 4106 8f :3 0
4d :3 0 45 :2 0
23a4 3ebd 3ec0 117
:2 0 45 :2 0 23a9
3ec2 3ec4 :3 0 8f
:3 0 50 :3 0 45
:2 0 23ac 3ec6 3ec9
e7 :2 0 ef :2 0
23b1 3ecb 3ecd :3 0
75 :3 0 29b :3 0
8f :3 0 58 :3 0
45 :2 0 23b4 3ed1
3ed4 1ac :2 0 8f
:3 0 4d :3 0 45
:2 0 23b7 3ed7 3eda
23ba 3ed6 3edc :3 0
3edd :2 0 29d :2 0
2ab :2 0 23bd 3edf
3ee1 :3 0 3ee2 :2 0
e2 :2 0 29e :2 0
23c0 3ee4 3ee6 :3 0
23c3 3ed0 3ee8 3ecf
3ee9 0 3f1e 8f
:3 0 44 :3 0 45
:2 0 23c5 3eeb 3eee
8f :3 0 20d :2 0
75 :3 0 45 :2 0
23c8 3ef0 3ef4 23cd
3ef1 3ef6 :3 0 75
:3 0 8f :3 0 44
:3 0 45 :2 0 23d0
3ef9 3efc 3ef8 3efd
0 3f1a 4d :3 0
29b :3 0 8f :3 0
75 :3 0 45 :2 0
23d3 3f01 3f04 1ac
:2 0 2ab :2 0 23d6
3f06 3f08 :3 0 3f09
:2 0 29d :2 0 8f
:3 0 58 :3 0 45
:2 0 23d9 3f0c 3f0f
23dc 3f0b 3f11 :3 0
e2 :2 0 29e :2 0
23df 3f13 3f15 :3 0
23e2 3f00 3f17 3eff
3f18 0 3f1a 23e4
3f1b 3ef7 3f1a 0
3f1c 23e7 0 3f1e
15c :3 0 23e9 3f35
8f :3 0 44 :3 0
45 :2 0 23ec 3f1f
3f22 8f :3 0 20d
:2 0 4d :3 0 45
:2 0 23ef 3f24 3f28
23f4 3f25 3f2a :3 0
4d :3 0 8f :3 0
44 :3 0 45 :2 0
23f7 3f2d 3f30 3f2c
3f31 0 3f33 23fa
3f34 3f2b 3f33 0
3f36 3ece 3f1e 0
3f36 23fc 0 3f37
23ff 3f38 3ec5 3f37
0 3f39 2401 0
4106 8c :3 0 21c
:3 0 22 :3 0 28
:3 0 26 :3 0 27
:3 0 74 :3 0 4a
:3 0 31 :3 0 31
:3 0 31 :3 0 31
:3 0 2a :3 0 2c
:3 0 52 :3 0 48
:3 0 4d :3 0 4f
:3 0 50 :3 0 49
:3 0 5b :3 0 36
:3 0 53 :3 0 57
:3 0 51 :3 0 4e
:3 0 5a :3 0 58
:3 0 5c :3 0 1f
:3 0 45 :2 0 45
:2 0 21b :2 0 21b
:2 0 45 :2 0 2403
3f3b 3f5d 3f3a 3f5e
0 4106 8c :3 0
e7 :2 0 21d :2 0
2427 3f61 3f63 :3 0
f0 :3 0 a3 :4 0
3f68 :2 0 3f6e 3f66
0 15 :3 0 ee
:3 0 3f69 3f6a 0
f1 :3 0 3f6b 3f6c
0 3f6e 242a 3fc1
f2 :3 0 15 :3 0
ee :3 0 3f70 3f71
0 f1 :3 0 3f72
3f73 0 3f75 242d
3f77 242f 3f76 3f75
:2 0 3fbf f3 :3 0
15 :3 0 ee :3 0
3f7a 3f7b 0 f1
:3 0 3f7c 3f7d 0
3fb7 d0 :3 0 d1
:3 0 3f7f 3f80 0
d0 :3 0 e0 :3 0
3f82 3f83 0 f4
:2 0 2 :4 0 2cf
:2 0 e2 :2 0 30
:2 0 2431 3f88 3f8a
:3 0 2434 3f84 3f8c
3f81 3f8e 3f8d :2 0
d3 :3 0 e3 :3 0
3f90 3f91 0 d5
:4 0 2d0 :4 0 d8
:2 0 d9 :3 0 2438
3f95 3f97 :3 0 d8
:2 0 f7 :4 0 243b
3f99 3f9b :3 0 d8
:2 0 f8 :4 0 243e
3f9d 3f9f :3 0 d8
:2 0 f1 :3 0 2441
3fa1 3fa3 :3 0 d8
:2 0 f9 :4 0 2444
3fa5 3fa7 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2447 3faa 3fae
244b 3fa9 3fb0 :3 0
244e 3f92 3fb2 :2 0
3fb4 2451 3fb5 3f8f
3fb4 0 3fb6 2453
0 3fb7 2455 3fba
:3 0 3fba 0 3fba
3fb9 3fb7 3fb8 :6 0
3fbc ba :3 0 2458
3fbe 245a 3fbd 3fbc
:2 0 3fbf 245c :2 0
3fc1 0 3fc1 3fc0
3f6e 3fbf :6 0 4031
67 :3 0 d0 :3 0
d1 :3 0 3fc3 3fc4
0 d0 :3 0 e0
:3 0 3fc6 3fc7 0
1d :2 0 2 :4 0
2d1 :2 0 e2 :2 0
30 :2 0 245f 3fcc
3fce :3 0 2462 3fc8
3fd0 3fc5 3fd2 3fd1
:2 0 d3 :3 0 e3
:3 0 3fd4 3fd5 0
d5 :4 0 2d2 :4 0
d8 :2 0 d9 :3 0
2466 3fd9 3fdb :3 0
d8 :2 0 f7 :4 0
2469 3fdd 3fdf :3 0
d8 :2 0 fe :4 0
246c 3fe1 3fe3 :3 0
d8 :2 0 8f :3 0
dd :3 0 1a :3 0
220 :3 0 3fe8 3fe9
0 246f 3fe7 3feb
de :4 0 2471 3fe6
3fee 2474 3fe5 3ff0
:3 0 d8 :2 0 100
:4 0 2477 3ff2 3ff4
:3 0 d8 :2 0 db
:4 0 247a 3ff6 3ff8
:3 0 d8 :2 0 27
:3 0 247d 3ffa 3ffc
:3 0 d8 :2 0 db
:4 0 2480 3ffe 4000
:3 0 2483 3fd6 4002
:2 0 4004 2486 4005
3fd3 4004 0 4006
2488 0 4031 d0
:3 0 d1 :3 0 4007
4008 0 d0 :3 0
e0 :3 0 400a 400b
0 30 :2 0 2
:4 0 2d3 :2 0 e2
:2 0 30 :2 0 248a
4010 4012 :3 0 248d
400c 4014 4009 4016
4015 :2 0 d3 :3 0
e3 :3 0 4018 4019
0 d5 :4 0 2d4
:4 0 d8 :2 0 d9
:3 0 2491 401d 401f
:3 0 2494 401a 4021
:2 0 4023 2497 4024
4017 4023 0 4025
2499 0 4031 103
:3 0 104 :3 0 4026
4027 0 1a :3 0
220 :3 0 4029 402a
0 27 :3 0 105
:3 0 249b 4028 402e
:2 0 4031 15c :3 0
249f 4104 8c :3 0
14e :2 0 45 :2 0
24a6 4033 4035 :3 0
f0 :3 0 a3 :4 0
403a :2 0 4040 4038
0 15 :3 0 ee
:3 0 403b 403c 0
f1 :3 0 403d 403e
0 4040 24a9 4093
f2 :3 0 15 :3 0
ee :3 0 4042 4043
0 f1 :3 0 4044
4045 0 4047 24ac
4049 24ae 4048 4047
:2 0 4091 f3 :3 0
15 :3 0 ee :3 0
404c 404d 0 f1
:3 0 404e 404f 0
4089 d0 :3 0 d1
:3 0 4051 4052 0
d0 :3 0 e0 :3 0
4054 4055 0 f4
:2 0 2 :4 0 2d5
:2 0 e2 :2 0 30
:2 0 24b0 405a 405c
:3 0 24b3 4056 405e
4053 4060 405f :2 0
d3 :3 0 e3 :3 0
4062 4063 0 d5
:4 0 2d6 :4 0 d8
:2 0 d9 :3 0 24b7
4067 4069 :3 0 d8
:2 0 f7 :4 0 24ba
406b 406d :3 0 d8
:2 0 f8 :4 0 24bd
406f 4071 :3 0 d8
:2 0 f1 :3 0 24c0
4073 4075 :3 0 d8
:2 0 f9 :4 0 24c3
4077 4079 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 24c6 407c 4080
24ca 407b 4082 :3 0
24cd 4064 4084 :2 0
4086 24d0 4087 4061
4086 0 4088 24d2
0 4089 24d4 408c
:3 0 408c 0 408c
408b 4089 408a :6 0
408e bc :3 0 24d7
4090 24d9 408f 408e
:2 0 4091 24db :2 0
4093 0 4093 4092
4040 4091 :6 0 4102
67 :3 0 d0 :3 0
d1 :3 0 4095 4096
0 d0 :3 0 e0
:3 0 4098 4099 0
1d :2 0 2 :4 0
2d7 :2 0 e2 :2 0
30 :2 0 24de 409e
40a0 :3 0 24e1 409a
40a2 4097 40a4 40a3
:2 0 d3 :3 0 e3
:3 0 40a6 40a7 0
d5 :4 0 2d8 :4 0
d8 :2 0 d9 :3 0
24e5 40ab 40ad :3 0
d8 :2 0 f7 :4 0
24e8 40af 40b1 :3 0
d8 :2 0 fe :4 0
24eb 40b3 40b5 :3 0
d8 :2 0 8f :3 0
dd :3 0 1a :3 0
1c2 :3 0 40ba 40bb
0 24ee 40b9 40bd
de :4 0 24f0 40b8
40c0 24f3 40b7 40c2
:3 0 d8 :2 0 100
:4 0 24f6 40c4 40c6
:3 0 d8 :2 0 db
:4 0 24f9 40c8 40ca
:3 0 d8 :2 0 21
:3 0 24fc 40cc 40ce
:3 0 d8 :2 0 db
:4 0 24ff 40d0 40d2
:3 0 2502 40a8 40d4
:2 0 40d6 2505 40d7
40a5 40d6 0 40d8
2507 0 4102 d0
:3 0 d1 :3 0 40d9
40da 0 d0 :3 0
e0 :3 0 40dc 40dd
0 30 :2 0 2
:4 0 2d9 :2 0 e2
:2 0 30 :2 0 2509
40e2 40e4 :3 0 250c
40de 40e6 40db 40e8
40e7 :2 0 d3 :3 0
e3 :3 0 40ea 40eb
0 d5 :4 0 2da
:4 0 d8 :2 0 d9
:3 0 2510 40ef 40f1
:3 0 2513 40ec 40f3
:2 0 40f5 2516 40f6
40e9 40f5 0 40f7
2518 0 4102 103
:3 0 104 :3 0 40f8
40f9 0 1a :3 0
1c2 :3 0 40fb 40fc
0 21 :3 0 105
:3 0 251a 40fa 4100
:2 0 4102 251e 4103
4036 4102 0 4105
3f64 4031 0 4105
2523 0 4106 2526
4108 3411 3812 0
4109 0 4106 0
4109 2530 0 45bc
bc :3 0 186 :3 0
187 :3 0 186 :3 0
41 :3 0 99 :3 0
26 :4 0 2db 1
:8 0 4127 ed :4 0
4112 :3 0 105 :3 0
e7 :2 0 2535 4115
4116 :3 0 15 :3 0
ee :3 0 4118 4119
0 45 :2 0 411a
411b 0 411d 2538
4124 15 :3 0 ee
:3 0 411e 411f 0
ef :2 0 4120 4121
0 4123 253a 4125
4117 411d 0 4126
0 4123 0 4126
253c 0 4127 253f
417a f2 :3 0 15
:3 0 ee :3 0 4129
412a 0 f1 :3 0
412b 412c 0 412e
2542 4130 2544 412f
412e :2 0 4178 f3
:3 0 15 :3 0 ee
:3 0 4133 4134 0
f1 :3 0 4135 4136
0 4170 d0 :3 0
d1 :3 0 4138 4139
0 d0 :3 0 e0
:3 0 413b 413c 0
f4 :2 0 2 :4 0
2dc :2 0 e2 :2 0
30 :2 0 2546 4141
4143 :3 0 2549 413d
4145 413a 4147 4146
:2 0 d3 :3 0 e3
:3 0 4149 414a 0
d5 :4 0 2dd :4 0
d8 :2 0 d9 :3 0
254d 414e 4150 :3 0
d8 :2 0 f7 :4 0
2550 4152 4154 :3 0
d8 :2 0 f8 :4 0
2553 4156 4158 :3 0
d8 :2 0 f1 :3 0
2556 415a 415c :3 0
d8 :2 0 f9 :4 0
2559 415e 4160 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 255c 4163
4167 2560 4162 4169
:3 0 2563 414b 416b
:2 0 416d 2566 416e
4148 416d 0 416f
2568 0 4170 256a
4173 :3 0 4173 0
4173 4172 4170 4171
:6 0 4175 be :3 0
256d 4177 256f 4176
4175 :2 0 4178 2571
:2 0 417a 0 417a
4179 4127 4178 :6 0
45bc 67 :3 0 23f
:3 0 22 :3 0 2de
:3 0 99 :3 0 2de
:3 0 2df :3 0 2de
:3 0 2e0 :3 0 2de
:3 0 2e1 :3 0 2de
:3 0 2e2 :3 0 2e3
:3 0 2de :3 0 127
:3 0 13b :3 0 2e4
:3 0 2de :3 0 99
:3 0 2e4 :3 0 13a
:3 0 2e4 :3 0 13c
:3 0 29 :4 0 2e5
1 :8 0 41aa ed
:4 0 4195 :3 0 105
:3 0 e7 :2 0 2576
4198 4199 :3 0 15
:3 0 ee :3 0 419b
419c 0 45 :2 0
419d 419e 0 41a0
2579 41a7 15 :3 0
ee :3 0 41a1 41a2
0 ef :2 0 41a3
41a4 0 41a6 257b
41a8 419a 41a0 0
41a9 0 41a6 0
41a9 257d 0 41aa
2580 41fd f2 :3 0
15 :3 0 ee :3 0
41ac 41ad 0 f1
:3 0 41ae 41af 0
41b1 2583 41b3 2585
41b2 41b1 :2 0 41fb
f3 :3 0 15 :3 0
ee :3 0 41b6 41b7
0 f1 :3 0 41b8
41b9 0 41f3 d0
:3 0 d1 :3 0 41bb
41bc 0 d0 :3 0
e0 :3 0 41be 41bf
0 f4 :2 0 2
:4 0 2e6 :2 0 e2
:2 0 30 :2 0 2587
41c4 41c6 :3 0 258a
41c0 41c8 41bd 41ca
41c9 :2 0 d3 :3 0
e3 :3 0 41cc 41cd
0 d5 :4 0 2e7
:4 0 d8 :2 0 d9
:3 0 258e 41d1 41d3
:3 0 d8 :2 0 f7
:4 0 2591 41d5 41d7
:3 0 d8 :2 0 f8
:4 0 2594 41d9 41db
:3 0 d8 :2 0 f1
:3 0 2597 41dd 41df
:3 0 d8 :2 0 f9
:4 0 259a 41e1 41e3
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 259d
41e6 41ea 25a1 41e5
41ec :3 0 25a4 41ce
41ee :2 0 41f0 25a7
41f1 41cb 41f0 0
41f2 25a9 0 41f3
25ab 41f6 :3 0 41f6
0 41f6 41f5 41f3
41f4 :6 0 41f8 c0
:3 0 25ae 41fa 25b0
41f9 41f8 :2 0 41fb
25b2 :2 0 41fd 0
41fd 41fc 41aa 41fb
:6 0 45bc 67 :3 0
23f :3 0 22 :3 0
13a :3 0 2df :3 0
2e0 :3 0 2e1 :3 0
2e2 :3 0 2e8 :3 0
23f :3 0 a5 :3 0
29 :4 0 2e9 1
:8 0 4220 ed :4 0
420b :3 0 105 :3 0
e7 :2 0 25b7 420e
420f :3 0 15 :3 0
ee :3 0 4211 4212
0 45 :2 0 4213
4214 0 4216 25ba
421d 15 :3 0 ee
:3 0 4217 4218 0
ef :2 0 4219 421a
0 421c 25bc 421e
4210 4216 0 421f
0 421c 0 421f
25be 0 4220 25c1
4273 f2 :3 0 15
:3 0 ee :3 0 4222
4223 0 f1 :3 0
4224 4225 0 4227
25c4 4229 25c6 4228
4227 :2 0 4271 f3
:3 0 15 :3 0 ee
:3 0 422c 422d 0
f1 :3 0 422e 422f
0 4269 d0 :3 0
d1 :3 0 4231 4232
0 d0 :3 0 e0
:3 0 4234 4235 0
f4 :2 0 2 :4 0
2ea :2 0 e2 :2 0
30 :2 0 25c8 423a
423c :3 0 25cb 4236
423e 4233 4240 423f
:2 0 d3 :3 0 e3
:3 0 4242 4243 0
d5 :4 0 2eb :4 0
d8 :2 0 d9 :3 0
25cf 4247 4249 :3 0
d8 :2 0 f7 :4 0
25d2 424b 424d :3 0
d8 :2 0 f8 :4 0
25d5 424f 4251 :3 0
d8 :2 0 f1 :3 0
25d8 4253 4255 :3 0
d8 :2 0 f9 :4 0
25db 4257 4259 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 25de 425c
4260 25e2 425b 4262
:3 0 25e5 4244 4264
:2 0 4266 25e8 4267
4241 4266 0 4268
25ea 0 4269 25ec
426c :3 0 426c 0
426c 426b 4269 426a
:6 0 426e c2 :3 0
25ef 4270 25f1 426f
426e :2 0 4271 25f3
:2 0 4273 0 4273
4272 4220 4271 :6 0
45bc 67 :3 0 243
:3 0 22 :3 0 2ec
:3 0 2df :3 0 2e0
:3 0 2e1 :3 0 2e2
:3 0 2ed :3 0 243
:3 0 a5 :3 0 29
:4 0 2ee 1 :8 0
4296 ed :4 0 4281
:3 0 105 :3 0 e7
:2 0 25f8 4284 4285
:3 0 15 :3 0 ee
:3 0 4287 4288 0
45 :2 0 4289 428a
0 428c 25fb 4293
15 :3 0 ee :3 0
428d 428e 0 ef
:2 0 428f 4290 0
4292 25fd 4294 4286
428c 0 4295 0
4292 0 4295 25ff
0 4296 2602 42e9
f2 :3 0 15 :3 0
ee :3 0 4298 4299
0 f1 :3 0 429a
429b 0 429d 2605
429f 2607 429e 429d
:2 0 42e7 f3 :3 0
15 :3 0 ee :3 0
42a2 42a3 0 f1
:3 0 42a4 42a5 0
42df d0 :3 0 d1
:3 0 42a7 42a8 0
d0 :3 0 e0 :3 0
42aa 42ab 0 f4
:2 0 2 :4 0 2ef
:2 0 e2 :2 0 30
:2 0 2609 42b0 42b2
:3 0 260c 42ac 42b4
42a9 42b6 42b5 :2 0
d3 :3 0 e3 :3 0
42b8 42b9 0 d5
:4 0 2f0 :4 0 d8
:2 0 d9 :3 0 2610
42bd 42bf :3 0 d8
:2 0 f7 :4 0 2613
42c1 42c3 :3 0 d8
:2 0 f8 :4 0 2616
42c5 42c7 :3 0 d8
:2 0 f1 :3 0 2619
42c9 42cb :3 0 d8
:2 0 f9 :4 0 261c
42cd 42cf :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 261f 42d2 42d6
2623 42d1 42d8 :3 0
2626 42ba 42da :2 0
42dc 2629 42dd 42b7
42dc 0 42de 262b
0 42df 262d 42e2
:3 0 42e2 0 42e2
42e1 42df 42e0 :6 0
42e4 c4 :3 0 2630
42e6 2632 42e5 42e4
:2 0 42e7 2634 :2 0
42e9 0 42e9 42e8
4296 42e7 :6 0 45bc
67 :3 0 54 :3 0
8f :3 0 54 :3 0
45 :2 0 2637 42ec
42ef e2 :2 0 30
:2 0 263a 42f1 42f3
:3 0 42eb 42f4 0
45bc 4c :3 0 8f
:3 0 4c :3 0 45
:2 0 263d 42f7 42fa
e2 :2 0 8f :3 0
48 :3 0 45 :2 0
2640 42fd 4300 2643
42fc 4302 :3 0 42f6
4303 0 45bc 76
:3 0 30 :4 0 4305
4306 0 45bc 7b
:3 0 2f1 :3 0 28
:3 0 29 :3 0 76
:3 0 2646 4309 430d
4308 430e 0 45bc
76 :3 0 45 :4 0
4310 4311 0 45bc
7b :3 0 2f1 :3 0
28 :3 0 27 :3 0
76 :3 0 264a 4314
4318 4313 4319 0
45bc 238 :3 0 9f
:3 0 27 :3 0 9e
:3 0 28 :3 0 a7
:3 0 22 :4 0 2f2
1 :8 0 4338 ed
:4 0 4323 :3 0 105
:3 0 e7 :2 0 2650
4326 4327 :3 0 15
:3 0 ee :3 0 4329
432a 0 45 :2 0
432b 432c 0 432e
2653 4335 15 :3 0
ee :3 0 432f 4330
0 ef :2 0 4331
4332 0 4334 2655
4336 4328 432e 0
4337 0 4334 0
4337 2657 0 4338
265a 438b f2 :3 0
15 :3 0 ee :3 0
433a 433b 0 f1
:3 0 433c 433d 0
433f 265d 4341 265f
4340 433f :2 0 4389
f3 :3 0 15 :3 0
ee :3 0 4344 4345
0 f1 :3 0 4346
4347 0 4381 d0
:3 0 d1 :3 0 4349
434a 0 d0 :3 0
e0 :3 0 434c 434d
0 f4 :2 0 2
:4 0 2f3 :2 0 e2
:2 0 30 :2 0 2661
4352 4354 :3 0 2664
434e 4356 434b 4358
4357 :2 0 d3 :3 0
e3 :3 0 435a 435b
0 d5 :4 0 2f4
:4 0 d8 :2 0 d9
:3 0 2668 435f 4361
:3 0 d8 :2 0 f7
:4 0 266b 4363 4365
:3 0 d8 :2 0 f8
:4 0 266e 4367 4369
:3 0 d8 :2 0 f1
:3 0 2671 436b 436d
:3 0 d8 :2 0 f9
:4 0 2674 436f 4371
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 2677
4374 4378 267b 4373
437a :3 0 267e 435c
437c :2 0 437e 2681
437f 4359 437e 0
4380 2683 0 4381
2685 4384 :3 0 4384
0 4384 4383 4381
4382 :6 0 4386 c6
:3 0 2688 4388 268a
4387 4386 :2 0 4389
268c :2 0 438b 0
438b 438a 4338 4389
:6 0 45bc 67 :3 0
8f :3 0 6b :3 0
45 :2 0 268f 438d
4390 e7 :2 0 45
:2 0 2694 4392 4394
:3 0 4395 :2 0 8f
:3 0 6a :3 0 45
:2 0 2697 4397 439a
e7 :2 0 45 :2 0
269c 439c 439e :3 0
439f :2 0 4396 43a1
43a0 :2 0 247 :3 0
9f :3 0 27 :3 0
2f5 :3 0 62 :3 0
2f6 :3 0 65 :3 0
2f7 :3 0 64 :3 0
2f8 :3 0 66 :3 0
179 :3 0 1f :3 0
17a :3 0 d9 :3 0
a7 :3 0 1c :4 0
2f9 1 :8 0 43ca
ed :4 0 43b5 :3 0
105 :3 0 e7 :2 0
26a1 43b8 43b9 :3 0
15 :3 0 ee :3 0
43bb 43bc 0 45
:2 0 43bd 43be 0
43c0 26a4 43c7 15
:3 0 ee :3 0 43c1
43c2 0 ef :2 0
43c3 43c4 0 43c6
26a6 43c8 43ba 43c0
0 43c9 0 43c6
0 43c9 26a8 0
43ca 26ab 441d f2
:3 0 15 :3 0 ee
:3 0 43cc 43cd 0
f1 :3 0 43ce 43cf
0 43d1 26ae 43d3
26b0 43d2 43d1 :2 0
441b f3 :3 0 15
:3 0 ee :3 0 43d6
43d7 0 f1 :3 0
43d8 43d9 0 4413
d0 :3 0 d1 :3 0
43db 43dc 0 d0
:3 0 e0 :3 0 43de
43df 0 f4 :2 0
2 :4 0 2fa :2 0
e2 :2 0 30 :2 0
26b2 43e4 43e6 :3 0
26b5 43e0 43e8 43dd
43ea 43e9 :2 0 d3
:3 0 e3 :3 0 43ec
43ed 0 d5 :4 0
2fb :4 0 d8 :2 0
d9 :3 0 26b9 43f1
43f3 :3 0 d8 :2 0
f7 :4 0 26bc 43f5
43f7 :3 0 d8 :2 0
f8 :4 0 26bf 43f9
43fb :3 0 d8 :2 0
f1 :3 0 26c2 43fd
43ff :3 0 d8 :2 0
f9 :4 0 26c5 4401
4403 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
26c8 4406 440a 26cc
4405 440c :3 0 26cf
43ee 440e :2 0 4410
26d2 4411 43eb 4410
0 4412 26d4 0
4413 26d6 4416 :3 0
4416 0 4416 4415
4413 4414 :6 0 4418
c8 :3 0 26d9 441a
26db 4419 4418 :2 0
441b 26dd :2 0 441d
0 441d 441c 43ca
441b :6 0 4420 67
:3 0 15c :3 0 26e0
45b9 8f :3 0 6b
:3 0 45 :2 0 26e2
4421 4424 e7 :2 0
45 :2 0 26e7 4426
4428 :3 0 247 :3 0
9f :3 0 27 :3 0
2f5 :3 0 62 :3 0
2f6 :3 0 65 :3 0
179 :3 0 1f :3 0
17a :3 0 d9 :3 0
a7 :3 0 1c :4 0
2fc 1 :8 0 444d
ed :4 0 4438 :3 0
105 :3 0 e7 :2 0
26ec 443b 443c :3 0
15 :3 0 ee :3 0
443e 443f 0 45
:2 0 4440 4441 0
4443 26ef 444a 15
:3 0 ee :3 0 4444
4445 0 ef :2 0
4446 4447 0 4449
26f1 444b 443d 4443
0 444c 0 4449
0 444c 26f3 0
444d 26f6 44a0 f2
:3 0 15 :3 0 ee
:3 0 444f 4450 0
f1 :3 0 4451 4452
0 4454 26f9 4456
26fb 4455 4454 :2 0
449e f3 :3 0 15
:3 0 ee :3 0 4459
445a 0 f1 :3 0
445b 445c 0 4496
d0 :3 0 d1 :3 0
445e 445f 0 d0
:3 0 e0 :3 0 4461
4462 0 f4 :2 0
2 :4 0 2fd :2 0
e2 :2 0 30 :2 0
26fd 4467 4469 :3 0
2700 4463 446b 4460
446d 446c :2 0 d3
:3 0 e3 :3 0 446f
4470 0 d5 :4 0
2fe :4 0 d8 :2 0
d9 :3 0 2704 4474
4476 :3 0 d8 :2 0
f7 :4 0 2707 4478
447a :3 0 d8 :2 0
f8 :4 0 270a 447c
447e :3 0 d8 :2 0
f1 :3 0 270d 4480
4482 :3 0 d8 :2 0
f9 :4 0 2710 4484
4486 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2713 4489 448d 2717
4488 448f :3 0 271a
4471 4491 :2 0 4493
271d 4494 446e 4493
0 4495 271f 0
4496 2721 4499 :3 0
4499 0 4499 4498
4496 4497 :6 0 449b
ca :3 0 2724 449d
2726 449c 449b :2 0
449e 2728 :2 0 44a0
0 44a0 449f 444d
449e :6 0 44aa 67
:3 0 64 :3 0 8f
:3 0 7f :3 0 45
:2 0 272b 44a3 44a6
44a2 44a7 0 44aa
15c :3 0 272e 44ab
4429 44aa 0 45bb
8f :3 0 6a :3 0
45 :2 0 2731 44ac
44af e7 :2 0 45
:2 0 2736 44b1 44b3
:3 0 247 :3 0 9f
:3 0 27 :3 0 2f7
:3 0 64 :3 0 2f8
:3 0 66 :3 0 179
:3 0 1f :3 0 17a
:3 0 d9 :3 0 a7
:3 0 1c :4 0 2ff
1 :8 0 44d8 ed
:4 0 44c3 :3 0 105
:3 0 e7 :2 0 273b
44c6 44c7 :3 0 15
:3 0 ee :3 0 44c9
44ca 0 45 :2 0
44cb 44cc 0 44ce
273e 44d5 15 :3 0
ee :3 0 44cf 44d0
0 ef :2 0 44d1
44d2 0 44d4 2740
44d6 44c8 44ce 0
44d7 0 44d4 0
44d7 2742 0 44d8
2745 452b f2 :3 0
15 :3 0 ee :3 0
44da 44db 0 f1
:3 0 44dc 44dd 0
44df 2748 44e1 274a
44e0 44df :2 0 4529
f3 :3 0 15 :3 0
ee :3 0 44e4 44e5
0 f1 :3 0 44e6
44e7 0 4521 d0
:3 0 d1 :3 0 44e9
44ea 0 d0 :3 0
e0 :3 0 44ec 44ed
0 f4 :2 0 2
:4 0 300 :2 0 e2
:2 0 30 :2 0 274c
44f2 44f4 :3 0 274f
44ee 44f6 44eb 44f8
44f7 :2 0 d3 :3 0
e3 :3 0 44fa 44fb
0 d5 :4 0 301
:4 0 d8 :2 0 d9
:3 0 2753 44ff 4501
:3 0 d8 :2 0 f7
:4 0 2756 4503 4505
:3 0 d8 :2 0 f8
:4 0 2759 4507 4509
:3 0 d8 :2 0 f1
:3 0 275c 450b 450d
:3 0 d8 :2 0 f9
:4 0 275f 450f 4511
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 2762
4514 4518 2766 4513
451a :3 0 2769 44fc
451c :2 0 451e 276c
451f 44f9 451e 0
4520 276e 0 4521
2770 4524 :3 0 4524
0 4524 4523 4521
4522 :6 0 4526 cc
:3 0 2773 4528 2775
4527 4526 :2 0 4529
2777 :2 0 452b 0
452b 452a 44d8 4529
:6 0 4534 67 :3 0
62 :3 0 8f :3 0
7e :3 0 45 :2 0
277a 452e 4531 452d
4532 0 4534 277d
4535 44b4 4534 0
45bb 247 :3 0 9f
:3 0 27 :3 0 179
:3 0 1f :3 0 17a
:3 0 d9 :3 0 a7
:3 0 1c :4 0 302
1 :8 0 4555 ed
:4 0 4540 :3 0 105
:3 0 e7 :2 0 2782
4543 4544 :3 0 15
:3 0 ee :3 0 4546
4547 0 45 :2 0
4548 4549 0 454b
2785 4552 15 :3 0
ee :3 0 454c 454d
0 ef :2 0 454e
454f 0 4551 2787
4553 4545 454b 0
4554 0 4551 0
4554 2789 0 4555
278c 45a8 f2 :3 0
15 :3 0 ee :3 0
4557 4558 0 f1
:3 0 4559 455a 0
455c 278f 455e 2791
455d 455c :2 0 45a6
f3 :3 0 15 :3 0
ee :3 0 4561 4562
0 f1 :3 0 4563
4564 0 459e d0
:3 0 d1 :3 0 4566
4567 0 d0 :3 0
e0 :3 0 4569 456a
0 f4 :2 0 2
:4 0 303 :2 0 e2
:2 0 30 :2 0 2793
456f 4571 :3 0 2796
456b 4573 4568 4575
4574 :2 0 d3 :3 0
e3 :3 0 4577 4578
0 d5 :4 0 304
:4 0 d8 :2 0 d9
:3 0 279a 457c 457e
:3 0 d8 :2 0 f7
:4 0 279d 4580 4582
:3 0 d8 :2 0 f8
:4 0 27a0 4584 4586
:3 0 d8 :2 0 f1
:3 0 27a3 4588 458a
:3 0 d8 :2 0 f9
:4 0 27a6 458c 458e
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 27a9
4591 4595 27ad 4590
4597 :3 0 27b0 4579
4599 :2 0 459b 27b3
459c 4576 459b 0
459d 27b5 0 459e
27b7 45a1 :3 0 45a1
0 45a1 45a0 459e
459f :6 0 45a3 ce
:3 0 27ba 45a5 27bc
45a4 45a3 :2 0 45a6
27be :2 0 45a8 0
45a8 45a7 4555 45a6
:6 0 45b8 67 :3 0
62 :3 0 8f :3 0
7e :3 0 45 :2 0
27c1 45ab 45ae 45aa
45af 0 45b8 64
:3 0 8f :3 0 7f
:3 0 45 :2 0 27c4
45b2 45b5 45b1 45b6
0 45b8 27c7 45ba
43a2 4420 0 45bb
0 45b8 0 45bb
27cb 0 45bc 27d0
45bd 3215 45bc 0
45be 27df 0 45bf
27e1 45c1 2711 29af
0 45c2 0 45bf
0 45c2 27e9 0
45d1 15 :3 0 ee
:3 0 45c3 45c4 0
305 :3 0 28 :3 0
29 :3 0 1f :3 0
27ec 45c6 45ca 45c5
45cb 0 45d1 297
:5 0 45cf d0 0
45d0 27f0 45cf 45ce
45d1 27f2 45d3 22f
:4 0 45d1 :4 0 5170
f0 :3 0 a3 :4 0
45d7 :2 0 45dd 45d5
0 15 :3 0 ee
:3 0 45d8 45d9 0
f1 :3 0 45da 45db
0 45dd 27fa 4630
f2 :3 0 15 :3 0
ee :3 0 45df 45e0
0 f1 :3 0 45e1
45e2 0 45e4 27fd
45e6 27ff 45e5 45e4
:2 0 462e f3 :3 0
15 :3 0 ee :3 0
45e9 45ea 0 f1
:3 0 45eb 45ec 0
4626 d0 :3 0 d1
:3 0 45ee 45ef 0
d0 :3 0 e0 :3 0
45f1 45f2 0 f4
:2 0 2 :4 0 306
:2 0 e2 :2 0 30
:2 0 2801 45f7 45f9
:3 0 2804 45f3 45fb
45f0 45fd 45fc :2 0
d3 :3 0 e3 :3 0
45ff 4600 0 d5
:4 0 307 :4 0 d8
:2 0 d9 :3 0 2808
4604 4606 :3 0 d8
:2 0 f7 :4 0 280b
4608 460a :3 0 d8
:2 0 f8 :4 0 280e
460c 460e :3 0 d8
:2 0 f1 :3 0 2811
4610 4612 :3 0 d8
:2 0 f9 :4 0 2814
4614 4616 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2817 4619 461d
281b 4618 461f :3 0
281e 4601 4621 :2 0
4623 2821 4624 45fe
4623 0 4625 2823
0 4626 2825 4629
:3 0 4629 0 4629
4628 4626 4627 :6 0
462b d0 :3 0 2828
462d 282a 462c 462b
:2 0 462e 282c :2 0
4630 0 4630 462f
45dd 462e :6 0 5170
1 :3 0 5f :3 0
45 :2 0 4632 4633
0 5170 8f :3 0
54 :3 0 45 :2 0
282f 4635 4638 117
:2 0 45 :2 0 2834
463a 463c :3 0 48
:3 0 9 :3 0 463e
463f 0 4b99 8f
:3 0 48 :3 0 45
:2 0 2837 4641 4644
8f :3 0 308 :2 0
4c :3 0 45 :2 0
283a 4646 464a 283f
4647 464c :3 0 48
:3 0 8f :3 0 48
:3 0 45 :2 0 2842
464f 4652 1bd :2 0
8f :3 0 4c :3 0
45 :2 0 2845 4655
4658 2848 4654 465a
:3 0 464e 465b 0
4a28 8f :3 0 48
:3 0 45 :2 0 284b
465d 4660 117 :2 0
45 :2 0 2850 4662
4664 :3 0 4665 :2 0
8f :3 0 55 :3 0
45 :2 0 2853 4667
466a 117 :2 0 45
:2 0 2858 466c 466e
:3 0 466f :2 0 4666
4671 4670 :2 0 23
:3 0 1b9 :2 0 285b
4674 4675 :3 0 4676
:2 0 4677 :2 0 4672
4679 4678 :2 0 2a
:3 0 7 :3 0 467b
467c 0 4a24 2c
:3 0 8 :3 0 467e
467f 0 4a24 4d
:3 0 b :3 0 4681
4682 0 4a24 4e
:3 0 10 :3 0 4684
4685 0 4a24 4f
:3 0 d :3 0 4687
4688 0 4a24 50
:3 0 e :3 0 468a
468b 0 4a24 57
:3 0 c :3 0 468d
468e 0 4a24 51
:3 0 f :3 0 4690
4691 0 4a24 8f
:3 0 51 :3 0 45
:2 0 285d 4693 4696
e7 :2 0 45 :2 0
2862 4698 469a :3 0
469b :2 0 8f :3 0
50 :3 0 45 :2 0
2865 469d 46a0 14e
:2 0 ef :2 0 286a
46a2 46a4 :3 0 46a5
:2 0 469c 46a7 46a6
:2 0 4d :3 0 45
:2 0 46a9 46aa 0
46ad 15c :3 0 286d
46c0 8f :3 0 50
:3 0 45 :2 0 286f
46ae 46b1 e7 :2 0
ef :2 0 2874 46b3
46b5 :3 0 88 :3 0
8f :3 0 4d :3 0
45 :2 0 2877 46b8
46bb 46b7 46bc 0
46be 287a 46bf 46b6
46be 0 46c1 46a8
46ad 0 46c1 287c
0 4a24 75 :3 0
20f :3 0 39 :3 0
3a :3 0 8f :3 0
4f :3 0 45 :2 0
287f 46c6 46c9 8f
:3 0 50 :3 0 45
:2 0 2882 46cb 46ce
8f :3 0 5b :3 0
45 :2 0 2885 46d0
46d3 8f :3 0 57
:3 0 45 :2 0 2888
46d5 46d8 8f :3 0
51 :3 0 45 :2 0
288b 46da 46dd 8f
:3 0 4e :3 0 45
:2 0 288e 46df 46e2
8f :3 0 58 :3 0
45 :2 0 2891 46e4
46e7 8f :3 0 59
:3 0 45 :2 0 2894
46e9 46ec 4d :3 0
48 :3 0 52 :3 0
2897 46c3 46f1 46c2
46f2 0 4a24 8f
:3 0 75 :3 0 45
:2 0 28a5 46f4 46f7
1a :3 0 e7 :2 0
210 :3 0 46f9 46fb
0 28aa 46fa 46fd
:3 0 d0 :3 0 d1
:3 0 46ff 4700 0
d0 :3 0 e0 :3 0
4702 4703 0 211
:2 0 2 :4 0 309
:2 0 e2 :2 0 30
:2 0 28ad 4708 470a
:3 0 28b0 4704 470c
4701 470e 470d :2 0
d3 :3 0 e3 :3 0
4710 4711 0 d5
:4 0 30a :4 0 d8
:2 0 d9 :3 0 28b4
4715 4717 :3 0 d8
:2 0 f7 :4 0 28b7
4719 471b :3 0 d8
:2 0 fe :4 0 28ba
471d 471f :3 0 d8
:2 0 8f :3 0 dd
:3 0 1a :3 0 210
:3 0 4724 4725 0
28bd 4723 4727 de
:4 0 28bf 4722 472a
28c2 4721 472c :3 0
28c5 4712 472e :2 0
4730 28c8 4731 470f
4730 0 4732 28ca
0 475c d0 :3 0
d1 :3 0 4733 4734
0 d0 :3 0 e0
:3 0 4736 4737 0
30 :2 0 2 :4 0
30b :2 0 e2 :2 0
30 :2 0 28cc 473c
473e :3 0 28cf 4738
4740 4735 4742 4741
:2 0 d3 :3 0 e3
:3 0 4744 4745 0
d5 :4 0 30c :4 0
d8 :2 0 d9 :3 0
28d3 4749 474b :3 0
28d6 4746 474d :2 0
474f 28d9 4750 4743
474f 0 4751 28db
0 475c 103 :3 0
216 :3 0 4752 4753
0 1a :3 0 210
:3 0 4755 4756 0
105 :3 0 28dd 4754
4759 :2 0 475c 15c
:3 0 28e0 47d5 8f
:3 0 75 :3 0 45
:2 0 28e4 475d 4760
14e :2 0 45 :2 0
28e9 4762 4764 :3 0
d0 :3 0 d1 :3 0
4766 4767 0 d0
:3 0 e0 :3 0 4769
476a 0 1d :2 0
2 :4 0 30d :2 0
e2 :2 0 30 :2 0
28ec 476f 4771 :3 0
28ef 476b 4773 4768
4775 4774 :2 0 d3
:3 0 e3 :3 0 4777
4778 0 d5 :4 0
30e :4 0 d8 :2 0
d9 :3 0 28f3 477c
477e :3 0 d8 :2 0
f7 :4 0 28f6 4780
4782 :3 0 d8 :2 0
fe :4 0 28f9 4784
4786 :3 0 d8 :2 0
8f :3 0 dd :3 0
75 :3 0 28fc 478a
478c de :4 0 28fe
4789 478f 2901 4788
4791 :3 0 d8 :2 0
100 :4 0 2904 4793
4795 :3 0 d8 :2 0
db :4 0 2907 4797
4799 :3 0 d8 :2 0
28 :3 0 290a 479b
479d :3 0 d8 :2 0
db :4 0 290d 479f
47a1 :3 0 2910 4779
47a3 :2 0 47a5 2913
47a6 4776 47a5 0
47a7 2915 0 47d3
d0 :3 0 d1 :3 0
47a8 47a9 0 d0
:3 0 e0 :3 0 47ab
47ac 0 30 :2 0
2 :4 0 30f :2 0
e2 :2 0 30 :2 0
2917 47b1 47b3 :3 0
291a 47ad 47b5 47aa
47b7 47b6 :2 0 d3
:3 0 e3 :3 0 47b9
47ba 0 d5 :4 0
310 :4 0 d8 :2 0
d9 :3 0 291e 47be
47c0 :3 0 2921 47bb
47c2 :2 0 47c4 2924
47c5 47b8 47c4 0
47c6 2926 0 47d3
103 :3 0 104 :3 0
47c7 47c8 0 8f
:3 0 75 :3 0 45
:2 0 2928 47ca 47cd
28 :3 0 105 :3 0
292b 47c9 47d1 :2 0
47d3 292f 47d4 4765
47d3 0 47d6 46fe
475c 0 47d6 2933
0 4a24 288 :3 0
289 :3 0 311 :4 0
47d9 :4 0 47da :2 0
4a24 15 :3 0 ee
:3 0 47dc 47dd 0
45 :2 0 47de 47df
0 4a24 312 :3 0
228 :3 0 1ce :3 0
1cf :3 0 1d0 :3 0
9e :3 0 28 :3 0
1d1 :3 0 23 :3 0
228 :4 0 313 1
:8 0 4801 ed :4 0
47ec :3 0 105 :3 0
e7 :2 0 2938 47ef
47f0 :3 0 15 :3 0
ee :3 0 47f2 47f3
0 45 :2 0 47f4
47f5 0 47f7 293b
47fe 15 :3 0 ee
:3 0 47f8 47f9 0
ef :2 0 47fa 47fb
0 47fd 293d 47ff
47f1 47f7 0 4800
0 47fd 0 4800
293f 0 4801 2942
4854 f2 :3 0 15
:3 0 ee :3 0 4803
4804 0 f1 :3 0
4805 4806 0 4808
2945 480a 2947 4809
4808 :2 0 4852 f3
:3 0 15 :3 0 ee
:3 0 480d 480e 0
f1 :3 0 480f 4810
0 484a d0 :3 0
d1 :3 0 4812 4813
0 d0 :3 0 e0
:3 0 4815 4816 0
f4 :2 0 2 :4 0
314 :2 0 e2 :2 0
30 :2 0 2949 481b
481d :3 0 294c 4817
481f 4814 4821 4820
:2 0 d3 :3 0 e3
:3 0 4823 4824 0
d5 :4 0 315 :4 0
d8 :2 0 d9 :3 0
2950 4828 482a :3 0
d8 :2 0 f7 :4 0
2953 482c 482e :3 0
d8 :2 0 f8 :4 0
2956 4830 4832 :3 0
d8 :2 0 f1 :3 0
2959 4834 4836 :3 0
d8 :2 0 f9 :4 0
295c 4838 483a :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 295f 483d
4841 2963 483c 4843
:3 0 2966 4825 4845
:2 0 4847 2969 4848
4822 4847 0 4849
296b 0 484a 296d
484d :3 0 484d 0
484d 484c 484a 484b
:6 0 484f d2 :3 0
2970 4851 2972 4850
484f :2 0 4852 2974
:2 0 4854 0 4854
4853 4801 4852 :6 0
4a24 1 :3 0 2c
:3 0 eb :4 0 4856
4857 0 4a24 53
:3 0 45 :2 0 4859
485a 0 4a24 5a
:3 0 45 :2 0 485c
485d 0 4a24 49
:3 0 45 :2 0 485f
4860 0 4a24 4a
:3 0 30 :2 0 4862
4863 0 4a24 8f
:3 0 4d :3 0 45
:2 0 2977 4865 4868
117 :2 0 45 :2 0
297c 486a 486c :3 0
4d :3 0 171 :3 0
172 :3 0 486f 4870
0 8f :3 0 4d
:3 0 45 :2 0 297f
4872 4875 1a :3 0
2ac :3 0 4877 4878
0 2982 4871 487a
486e 487b 0 4880
57 :3 0 30 :2 0
487d 487e 0 4880
2985 4885 57 :3 0
45 :2 0 4881 4882
0 4884 2988 4886
486d 4880 0 4887
0 4884 0 4887
298a 0 4a24 74
:3 0 21b :2 0 4888
4889 0 4a24 8c
:3 0 21c :3 0 21
:3 0 28 :3 0 28
:3 0 27 :3 0 74
:3 0 4a :3 0 31
:3 0 31 :3 0 31
:3 0 31 :3 0 2a
:3 0 2c :3 0 52
:3 0 48 :3 0 4d
:3 0 4f :3 0 50
:3 0 49 :3 0 5b
:3 0 36 :3 0 53
:3 0 57 :3 0 51
:3 0 4e :3 0 5a
:3 0 58 :3 0 5c
:3 0 1f :3 0 45
:2 0 45 :2 0 21b
:2 0 21b :2 0 45
:2 0 298d 488c 48ae
488b 48af 0 4a24
8c :3 0 e7 :2 0
21d :2 0 29b1 48b2
48b4 :3 0 d0 :3 0
d1 :3 0 48b6 48b7
0 d0 :3 0 e0
:3 0 48b9 48ba 0
1d :2 0 2 :4 0
316 :2 0 e2 :2 0
30 :2 0 29b4 48bf
48c1 :3 0 29b7 48bb
48c3 48b8 48c5 48c4
:2 0 d3 :3 0 e3
:3 0 48c7 48c8 0
d5 :4 0 317 :4 0
d8 :2 0 d9 :3 0
29bb 48cc 48ce :3 0
d8 :2 0 f7 :4 0
29be 48d0 48d2 :3 0
d8 :2 0 fe :4 0
29c1 48d4 48d6 :3 0
d8 :2 0 8f :3 0
dd :3 0 1a :3 0
220 :3 0 48db 48dc
0 29c4 48da 48de
de :4 0 29c6 48d9
48e1 29c9 48d8 48e3
:3 0 d8 :2 0 100
:4 0 29cc 48e5 48e7
:3 0 d8 :2 0 db
:4 0 29cf 48e9 48eb
:3 0 d8 :2 0 27
:3 0 29d2 48ed 48ef
:3 0 d8 :2 0 db
:4 0 29d5 48f1 48f3
:3 0 29d8 48c9 48f5
:2 0 48f7 29db 48f8
48c6 48f7 0 48f9
29dd 0 4924 d0
:3 0 d1 :3 0 48fa
48fb 0 d0 :3 0
e0 :3 0 48fd 48fe
0 30 :2 0 2
:4 0 318 :2 0 e2
:2 0 30 :2 0 29df
4903 4905 :3 0 29e2
48ff 4907 48fc 4909
4908 :2 0 d3 :3 0
e3 :3 0 490b 490c
0 d5 :4 0 319
:4 0 d8 :2 0 d9
:3 0 29e6 4910 4912
:3 0 29e9 490d 4914
:2 0 4916 29ec 4917
490a 4916 0 4918
29ee 0 4924 103
:3 0 104 :3 0 4919
491a 0 1a :3 0
220 :3 0 491c 491d
0 27 :3 0 105
:3 0 29f0 491b 4921
:2 0 4924 15c :3 0
29f4 4a21 8c :3 0
14e :2 0 45 :2 0
29fa 4926 4928 :3 0
d0 :3 0 d1 :3 0
492a 492b 0 d0
:3 0 e0 :3 0 492d
492e 0 1d :2 0
2 :4 0 31a :2 0
e2 :2 0 30 :2 0
29fd 4933 4935 :3 0
2a00 492f 4937 492c
4939 4938 :2 0 d3
:3 0 e3 :3 0 493b
493c 0 d5 :4 0
31b :4 0 d8 :2 0
d9 :3 0 2a04 4940
4942 :3 0 d8 :2 0
f7 :4 0 2a07 4944
4946 :3 0 d8 :2 0
fe :4 0 2a0a 4948
494a :3 0 d8 :2 0
8f :3 0 dd :3 0
1a :3 0 1c2 :3 0
494f 4950 0 2a0d
494e 4952 de :4 0
2a0f 494d 4955 2a12
494c 4957 :3 0 d8
:2 0 100 :4 0 2a15
4959 495b :3 0 d8
:2 0 db :4 0 2a18
495d 495f :3 0 d8
:2 0 21 :3 0 2a1b
4961 4963 :3 0 d8
:2 0 db :4 0 2a1e
4965 4967 :3 0 2a21
493d 4969 :2 0 496b
2a24 496c 493a 496b
0 496d 2a26 0
4997 d0 :3 0 d1
:3 0 496e 496f 0
d0 :3 0 e0 :3 0
4971 4972 0 30
:2 0 2 :4 0 31c
:2 0 e2 :2 0 30
:2 0 2a28 4977 4979
:3 0 2a2b 4973 497b
4970 497d 497c :2 0
d3 :3 0 e3 :3 0
497f 4980 0 d5
:4 0 31d :4 0 d8
:2 0 d9 :3 0 2a2f
4984 4986 :3 0 2a32
4981 4988 :2 0 498a
2a35 498b 497e 498a
0 498c 2a37 0
4997 103 :3 0 104
:3 0 498d 498e 0
1a :3 0 1c2 :3 0
4990 4991 0 21
:3 0 105 :3 0 2a39
498f 4995 :2 0 4997
2a3d 4998 4929 4997
0 4a23 9d :3 0
a5 :3 0 21 :3 0
9f :3 0 27 :3 0
a0 :3 0 b5 :3 0
6a :3 0 62 :3 0
67 :3 0 b5 :3 0
1ec :3 0 6a :3 0
65 :3 0 67 :3 0
1ec :3 0 b6 :3 0
6b :3 0 64 :3 0
67 :3 0 b6 :3 0
1ed :3 0 6b :3 0
66 :3 0 67 :3 0
1ed :3 0 a7 :3 0
23 :4 0 31e 1
:8 0 49cb ed :4 0
49b6 :3 0 105 :3 0
e7 :2 0 2a43 49b9
49ba :3 0 15 :3 0
ee :3 0 49bc 49bd
0 45 :2 0 49be
49bf 0 49c1 2a46
49c8 15 :3 0 ee
:3 0 49c2 49c3 0
ef :2 0 49c4 49c5
0 49c7 2a48 49c9
49bb 49c1 0 49ca
0 49c7 0 49ca
2a4a 0 49cb 2a4d
4a1e f2 :3 0 15
:3 0 ee :3 0 49cd
49ce 0 f1 :3 0
49cf 49d0 0 49d2
2a50 49d4 2a52 49d3
49d2 :2 0 4a1c f3
:3 0 15 :3 0 ee
:3 0 49d7 49d8 0
f1 :3 0 49d9 49da
0 4a14 d0 :3 0
d1 :3 0 49dc 49dd
0 d0 :3 0 e0
:3 0 49df 49e0 0
f4 :2 0 2 :4 0
31f :2 0 e2 :2 0
30 :2 0 2a54 49e5
49e7 :3 0 2a57 49e1
49e9 49de 49eb 49ea
:2 0 d3 :3 0 e3
:3 0 49ed 49ee 0
d5 :4 0 320 :4 0
d8 :2 0 d9 :3 0
2a5b 49f2 49f4 :3 0
d8 :2 0 f7 :4 0
2a5e 49f6 49f8 :3 0
d8 :2 0 f8 :4 0
2a61 49fa 49fc :3 0
d8 :2 0 f1 :3 0
2a64 49fe 4a00 :3 0
d8 :2 0 f9 :4 0
2a67 4a02 4a04 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 2a6a 4a07
4a0b 2a6e 4a06 4a0d
:3 0 2a71 49ef 4a0f
:2 0 4a11 2a74 4a12
49ec 4a11 0 4a13
2a76 0 4a14 2a78
4a17 :3 0 4a17 0
4a17 4a16 4a14 4a15
:6 0 4a19 d4 :3 0
2a7b 4a1b 2a7d 4a1a
4a19 :2 0 4a1c 2a7f
:2 0 4a1e 0 4a1e
4a1d 49cb 4a1c :6 0
4a20 1 :3 0 2a82
4a22 48b5 4924 0
4a23 0 4a20 0
4a23 2a84 0 4a24
2a88 4a25 467a 4a24
0 4a26 2aa0 0
4a28 15c :3 0 2aa2
4ab4 8d :3 0 14e
:2 0 45 :2 0 2aa7
4a2a 4a2c :3 0 8f
:3 0 55 :3 0 45
:2 0 2aaa 4a2e 4a31
117 :2 0 45 :2 0
2aaf 4a33 4a35 :3 0
4a2d 4a37 4a36 :2 0
23 :3 0 1b9 :2 0
2ab2 4a3a 4a3b :3 0
4a3c :2 0 4a38 4a3e
4a3d :2 0 1d0 :3 0
1d1 :3 0 23 :3 0
9e :3 0 28 :3 0
a7 :3 0 22 :4 0
321 1 :8 0 4a5d
ed :4 0 4a48 :3 0
105 :3 0 e7 :2 0
2ab6 4a4b 4a4c :3 0
15 :3 0 ee :3 0
4a4e 4a4f 0 45
:2 0 4a50 4a51 0
4a53 2ab9 4a5a 15
:3 0 ee :3 0 4a54
4a55 0 ef :2 0
4a56 4a57 0 4a59
2abb 4a5b 4a4d 4a53
0 4a5c 0 4a59
0 4a5c 2abd 0
4a5d 2ac0 4ab0 f2
:3 0 15 :3 0 ee
:3 0 4a5f 4a60 0
f1 :3 0 4a61 4a62
0 4a64 2ac3 4a66
2ac5 4a65 4a64 :2 0
4aae f3 :3 0 15
:3 0 ee :3 0 4a69
4a6a 0 f1 :3 0
4a6b 4a6c 0 4aa6
d0 :3 0 d1 :3 0
4a6e 4a6f 0 d0
:3 0 e0 :3 0 4a71
4a72 0 f4 :2 0
2 :4 0 322 :2 0
e2 :2 0 30 :2 0
2ac7 4a77 4a79 :3 0
2aca 4a73 4a7b 4a70
4a7d 4a7c :2 0 d3
:3 0 e3 :3 0 4a7f
4a80 0 d5 :4 0
323 :4 0 d8 :2 0
d9 :3 0 2ace 4a84
4a86 :3 0 d8 :2 0
f7 :4 0 2ad1 4a88
4a8a :3 0 d8 :2 0
f8 :4 0 2ad4 4a8c
4a8e :3 0 d8 :2 0
f1 :3 0 2ad7 4a90
4a92 :3 0 d8 :2 0
f9 :4 0 2ada 4a94
4a96 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2add 4a99 4a9d 2ae1
4a98 4a9f :3 0 2ae4
4a81 4aa1 :2 0 4aa3
2ae7 4aa4 4a7e 4aa3
0 4aa5 2ae9 0
4aa6 2aeb 4aa9 :3 0
4aa9 0 4aa9 4aa8
4aa6 4aa7 :6 0 4aab
d6 :3 0 2aee 4aad
2af0 4aac 4aab :2 0
4aae 2af2 :2 0 4ab0
0 4ab0 4aaf 4a5d
4aae :6 0 4ab2 1
:3 0 2af5 4ab3 4a3f
4ab2 0 4ab5 464d
4a28 0 4ab5 2af7
0 4b99 147 :3 0
5f :3 0 bd :3 0
99 :3 0 28 :3 0
9f :3 0 29 :3 0
a0 :4 0 324 1
:8 0 4ac4 15 :3 0
ee :3 0 4abf 4ac0
0 f1 :3 0 4ac1
4ac2 0 4ac4 2afa
4b17 f2 :3 0 15
:3 0 ee :3 0 4ac6
4ac7 0 f1 :3 0
4ac8 4ac9 0 4acb
2afd 4acd 2aff 4acc
4acb :2 0 4b15 f3
:3 0 15 :3 0 ee
:3 0 4ad0 4ad1 0
f1 :3 0 4ad2 4ad3
0 4b0d d0 :3 0
d1 :3 0 4ad5 4ad6
0 d0 :3 0 e0
:3 0 4ad8 4ad9 0
f4 :2 0 2 :4 0
325 :2 0 e2 :2 0
30 :2 0 2b01 4ade
4ae0 :3 0 2b04 4ada
4ae2 4ad7 4ae4 4ae3
:2 0 d3 :3 0 e3
:3 0 4ae6 4ae7 0
d5 :4 0 326 :4 0
d8 :2 0 d9 :3 0
2b08 4aeb 4aed :3 0
d8 :2 0 f7 :4 0
2b0b 4aef 4af1 :3 0
d8 :2 0 f8 :4 0
2b0e 4af3 4af5 :3 0
d8 :2 0 f1 :3 0
2b11 4af7 4af9 :3 0
d8 :2 0 f9 :4 0
2b14 4afb 4afd :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 2b17 4b00
4b04 2b1b 4aff 4b06
:3 0 2b1e 4ae8 4b08
:2 0 4b0a 2b21 4b0b
4ae5 4b0a 0 4b0c
2b23 0 4b0d 2b25
4b10 :3 0 4b10 0
4b10 4b0f 4b0d 4b0e
:6 0 4b12 d8 :3 0
2b28 4b14 2b2a 4b13
4b12 :2 0 4b15 2b2c
:2 0 4b17 0 4b17
4b16 4ac4 4b15 :6 0
4b99 1 :3 0 8f
:3 0 5f :3 0 45
:2 0 2b2f 4b19 4b1c
e7 :2 0 45 :2 0
2b34 4b1e 4b20 :3 0
bc :3 0 186 :3 0
187 :3 0 186 :3 0
41 :3 0 9e :3 0
28 :3 0 99 :3 0
28 :4 0 327 1
:8 0 4b41 ed :4 0
4b2c :3 0 105 :3 0
e7 :2 0 2b39 4b2f
4b30 :3 0 15 :3 0
ee :3 0 4b32 4b33
0 45 :2 0 4b34
4b35 0 4b37 2b3c
4b3e 15 :3 0 ee
:3 0 4b38 4b39 0
ef :2 0 4b3a 4b3b
0 4b3d 2b3e 4b3f
4b31 4b37 0 4b40
0 4b3d 0 4b40
2b40 0 4b41 2b43
4b94 f2 :3 0 15
:3 0 ee :3 0 4b43
4b44 0 f1 :3 0
4b45 4b46 0 4b48
2b46 4b4a 2b48 4b49
4b48 :2 0 4b92 f3
:3 0 15 :3 0 ee
:3 0 4b4d 4b4e 0
f1 :3 0 4b4f 4b50
0 4b8a d0 :3 0
d1 :3 0 4b52 4b53
0 d0 :3 0 e0
:3 0 4b55 4b56 0
f4 :2 0 2 :4 0
328 :2 0 e2 :2 0
30 :2 0 2b4a 4b5b
4b5d :3 0 2b4d 4b57
4b5f 4b54 4b61 4b60
:2 0 d3 :3 0 e3
:3 0 4b63 4b64 0
d5 :4 0 329 :4 0
d8 :2 0 d9 :3 0
2b51 4b68 4b6a :3 0
d8 :2 0 f7 :4 0
2b54 4b6c 4b6e :3 0
d8 :2 0 f8 :4 0
2b57 4b70 4b72 :3 0
d8 :2 0 f1 :3 0
2b5a 4b74 4b76 :3 0
d8 :2 0 f9 :4 0
2b5d 4b78 4b7a :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 2b60 4b7d
4b81 2b64 4b7c 4b83
:3 0 2b67 4b65 4b85
:2 0 4b87 2b6a 4b88
4b62 4b87 0 4b89
2b6c 0 4b8a 2b6e
4b8d :3 0 4b8d 0
4b8d 4b8c 4b8a 4b8b
:6 0 4b8f da :3 0
2b71 4b91 2b73 4b90
4b8f :2 0 4b92 2b75
:2 0 4b94 0 4b94
4b93 4b41 4b92 :6 0
4b96 1 :3 0 2b78
4b97 4b21 4b96 0
4b98 2b7a 0 4b99
2b7c 4b9a 463d 4b99
0 4b9b 2b81 0
5170 6c :3 0 45
:2 0 4b9c 4b9d 0
5170 8b :3 0 1b9
:2 0 2b83 4ba0 4ba1
:3 0 4ba2 :2 0 bc
:3 0 1f0 :3 0 19d
:3 0 172 :3 0 1f0
:3 0 1a :3 0 32a
:3 0 99 :3 0 28
:4 0 32b 1 :8 0
4bc3 ed :4 0 4bae
:3 0 105 :3 0 e7
:2 0 2b87 4bb1 4bb2
:3 0 15 :3 0 ee
:3 0 4bb4 4bb5 0
45 :2 0 4bb6 4bb7
0 4bb9 2b8a 4bc0
15 :3 0 ee :3 0
4bba 4bbb 0 ef
:2 0 4bbc 4bbd 0
4bbf 2b8c 4bc1 4bb3
4bb9 0 4bc2 0
4bbf 0 4bc2 2b8e
0 4bc3 2b91 4c16
f2 :3 0 15 :3 0
ee :3 0 4bc5 4bc6
0 f1 :3 0 4bc7
4bc8 0 4bca 2b94
4bcc 2b96 4bcb 4bca
:2 0 4c14 f3 :3 0
15 :3 0 ee :3 0
4bcf 4bd0 0 f1
:3 0 4bd1 4bd2 0
4c0c d0 :3 0 d1
:3 0 4bd4 4bd5 0
d0 :3 0 e0 :3 0
4bd7 4bd8 0 f4
:2 0 2 :4 0 32c
:2 0 e2 :2 0 30
:2 0 2b98 4bdd 4bdf
:3 0 2b9b 4bd9 4be1
4bd6 4be3 4be2 :2 0
d3 :3 0 e3 :3 0
4be5 4be6 0 d5
:4 0 32d :4 0 d8
:2 0 d9 :3 0 2b9f
4bea 4bec :3 0 d8
:2 0 f7 :4 0 2ba2
4bee 4bf0 :3 0 d8
:2 0 f8 :4 0 2ba5
4bf2 4bf4 :3 0 d8
:2 0 f1 :3 0 2ba8
4bf6 4bf8 :3 0 d8
:2 0 f9 :4 0 2bab
4bfa 4bfc :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2bae 4bff 4c03
2bb2 4bfe 4c05 :3 0
2bb5 4be7 4c07 :2 0
4c09 2bb8 4c0a 4be4
4c09 0 4c0b 2bba
0 4c0c 2bbc 4c0f
:3 0 4c0f 0 4c0f
4c0e 4c0c 4c0d :6 0
4c11 dc :3 0 2bbf
4c13 2bc1 4c12 4c11
:2 0 4c14 2bc3 :2 0
4c16 0 4c16 4c15
4bc3 4c14 :6 0 4f4f
1 :3 0 8f :3 0
55 :3 0 45 :2 0
2bc6 4c18 4c1b e7
:2 0 45 :2 0 2bcb
4c1d 4c1f :3 0 147
:3 0 5f :3 0 9d
:3 0 9e :3 0 28
:3 0 a1 :3 0 8b
:4 0 32e 1 :8 0
4c2e 15 :3 0 ee
:3 0 4c29 4c2a 0
f1 :3 0 4c2b 4c2c
0 4c2e 2bce 4c81
f2 :3 0 15 :3 0
ee :3 0 4c30 4c31
0 f1 :3 0 4c32
4c33 0 4c35 2bd1
4c37 2bd3 4c36 4c35
:2 0 4c7f f3 :3 0
15 :3 0 ee :3 0
4c3a 4c3b 0 f1
:3 0 4c3c 4c3d 0
4c77 d0 :3 0 d1
:3 0 4c3f 4c40 0
d0 :3 0 e0 :3 0
4c42 4c43 0 f4
:2 0 2 :4 0 32f
:2 0 e2 :2 0 30
:2 0 2bd5 4c48 4c4a
:3 0 2bd8 4c44 4c4c
4c41 4c4e 4c4d :2 0
d3 :3 0 e3 :3 0
4c50 4c51 0 d5
:4 0 330 :4 0 d8
:2 0 d9 :3 0 2bdc
4c55 4c57 :3 0 d8
:2 0 f7 :4 0 2bdf
4c59 4c5b :3 0 d8
:2 0 f8 :4 0 2be2
4c5d 4c5f :3 0 d8
:2 0 f1 :3 0 2be5
4c61 4c63 :3 0 d8
:2 0 f9 :4 0 2be8
4c65 4c67 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2beb 4c6a 4c6e
2bef 4c69 4c70 :3 0
2bf2 4c52 4c72 :2 0
4c74 2bf5 4c75 4c4f
4c74 0 4c76 2bf7
0 4c77 2bf9 4c7a
:3 0 4c7a 0 4c7a
4c79 4c77 4c78 :6 0
4c7c de :3 0 2bfc
4c7e 2bfe 4c7d 4c7c
:2 0 4c7f 2c00 :2 0
4c81 0 4c81 4c80
4c2e 4c7f :6 0 4d72
1 :3 0 8f :3 0
5f :3 0 45 :2 0
2c03 4c83 4c86 e7
:2 0 45 :2 0 2c08
4c88 4c8a :3 0 bd
:3 0 9e :3 0 28
:3 0 99 :3 0 28
:3 0 9f :3 0 29
:3 0 a0 :4 0 331
1 :8 0 4caa ed
:4 0 4c95 :3 0 105
:3 0 e7 :2 0 2c0d
4c98 4c99 :3 0 15
:3 0 ee :3 0 4c9b
4c9c 0 45 :2 0
4c9d 4c9e 0 4ca0
2c10 4ca7 15 :3 0
ee :3 0 4ca1 4ca2
0 ef :2 0 4ca3
4ca4 0 4ca6 2c12
4ca8 4c9a 4ca0 0
4ca9 0 4ca6 0
4ca9 2c14 0 4caa
2c17 4cfd f2 :3 0
15 :3 0 ee :3 0
4cac 4cad 0 f1
:3 0 4cae 4caf 0
4cb1 2c1a 4cb3 2c1c
4cb2 4cb1 :2 0 4cfb
f3 :3 0 15 :3 0
ee :3 0 4cb6 4cb7
0 f1 :3 0 4cb8
4cb9 0 4cf3 d0
:3 0 d1 :3 0 4cbb
4cbc 0 d0 :3 0
e0 :3 0 4cbe 4cbf
0 f4 :2 0 2
:4 0 332 :2 0 e2
:2 0 30 :2 0 2c1e
4cc4 4cc6 :3 0 2c21
4cc0 4cc8 4cbd 4cca
4cc9 :2 0 d3 :3 0
e3 :3 0 4ccc 4ccd
0 d5 :4 0 333
:4 0 d8 :2 0 d9
:3 0 2c25 4cd1 4cd3
:3 0 d8 :2 0 f7
:4 0 2c28 4cd5 4cd7
:3 0 d8 :2 0 f8
:4 0 2c2b 4cd9 4cdb
:3 0 d8 :2 0 f1
:3 0 2c2e 4cdd 4cdf
:3 0 d8 :2 0 f9
:4 0 2c31 4ce1 4ce3
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 2c34
4ce6 4cea 2c38 4ce5
4cec :3 0 2c3b 4cce
4cee :2 0 4cf0 2c3e
4cf1 4ccb 4cf0 0
4cf2 2c40 0 4cf3
2c42 4cf6 :3 0 4cf6
0 4cf6 4cf5 4cf3
4cf4 :6 0 4cf8 e0
:3 0 2c45 4cfa 2c47
4cf9 4cf8 :2 0 4cfb
2c49 :2 0 4cfd 0
4cfd 4cfc 4caa 4cfb
:6 0 4d6f 1 :3 0
1db :3 0 9e :3 0
28 :3 0 9f :3 0
29 :4 0 1dc 1
:8 0 4d1a ed :4 0
4d05 :3 0 105 :3 0
e7 :2 0 2c4e 4d08
4d09 :3 0 15 :3 0
ee :3 0 4d0b 4d0c
0 45 :2 0 4d0d
4d0e 0 4d10 2c51
4d17 15 :3 0 ee
:3 0 4d11 4d12 0
ef :2 0 4d13 4d14
0 4d16 2c53 4d18
4d0a 4d10 0 4d19
0 4d16 0 4d19
2c55 0 4d1a 2c58
4d6d f2 :3 0 15
:3 0 ee :3 0 4d1c
4d1d 0 f1 :3 0
4d1e 4d1f 0 4d21
2c5b 4d23 2c5d 4d22
4d21 :2 0 4d6b f3
:3 0 15 :3 0 ee
:3 0 4d26 4d27 0
f1 :3 0 4d28 4d29
0 4d63 d0 :3 0
d1 :3 0 4d2b 4d2c
0 d0 :3 0 e0
:3 0 4d2e 4d2f 0
f4 :2 0 2 :4 0
334 :2 0 e2 :2 0
30 :2 0 2c5f 4d34
4d36 :3 0 2c62 4d30
4d38 4d2d 4d3a 4d39
:2 0 d3 :3 0 e3
:3 0 4d3c 4d3d 0
d5 :4 0 335 :4 0
d8 :2 0 d9 :3 0
2c66 4d41 4d43 :3 0
d8 :2 0 f7 :4 0
2c69 4d45 4d47 :3 0
d8 :2 0 f8 :4 0
2c6c 4d49 4d4b :3 0
d8 :2 0 f1 :3 0
2c6f 4d4d 4d4f :3 0
d8 :2 0 f9 :4 0
2c72 4d51 4d53 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 2c75 4d56
4d5a 2c79 4d55 4d5c
:3 0 2c7c 4d3e 4d5e
:2 0 4d60 2c7f 4d61
4d3b 4d60 0 4d62
2c81 0 4d63 2c83
4d66 :3 0 4d66 0
4d66 4d65 4d63 4d64
:6 0 4d68 e2 :3 0
2c86 4d6a 2c88 4d69
4d68 :2 0 4d6b 2c8a
:2 0 4d6d 0 4d6d
4d6c 4d1a 4d6b :6 0
4d6f 1 :3 0 2c8d
4d70 4c8b 4d6f 0
4d71 2c90 0 4d72
2c92 4d73 4c20 4d72
0 4d74 2c95 0
4f4f 8f :3 0 5f
:3 0 45 :2 0 2c97
4d75 4d78 117 :2 0
45 :2 0 2c9c 4d7a
4d7c :3 0 75 :3 0
2ce :2 0 4d7e 4d7f
0 4f4c 7b :3 0
227 :3 0 28 :3 0
8b :3 0 75 :3 0
45 :2 0 45 :2 0
2c9f 4d82 4d88 4d81
4d89 0 4f4c ac
:3 0 af :3 0 336
:3 0 ad :3 0 ae
:3 0 337 :3 0 ad
:3 0 ae :3 0 338
:3 0 b3 :3 0 b4
:3 0 b5 :3 0 b6
:3 0 39 :3 0 3a
:3 0 48 :3 0 34
:3 0 35 :3 0 82
:3 0 83 :3 0 7e
:3 0 7f :3 0 9d
:3 0 a7 :3 0 8b
:4 0 339 1 :8 0
4daa 15 :3 0 ee
:3 0 4da5 4da6 0
f1 :3 0 4da7 4da8
0 4daa 2ca5 4dfd
f2 :3 0 15 :3 0
ee :3 0 4dac 4dad
0 f1 :3 0 4dae
4daf 0 4db1 2ca8
4db3 2caa 4db2 4db1
:2 0 4dfb f3 :3 0
15 :3 0 ee :3 0
4db6 4db7 0 f1
:3 0 4db8 4db9 0
4df3 d0 :3 0 d1
:3 0 4dbb 4dbc 0
d0 :3 0 e0 :3 0
4dbe 4dbf 0 f4
:2 0 2 :4 0 33a
:2 0 e2 :2 0 30
:2 0 2cac 4dc4 4dc6
:3 0 2caf 4dc0 4dc8
4dbd 4dca 4dc9 :2 0
d3 :3 0 e3 :3 0
4dcc 4dcd 0 d5
:4 0 33b :4 0 d8
:2 0 d9 :3 0 2cb3
4dd1 4dd3 :3 0 d8
:2 0 f7 :4 0 2cb6
4dd5 4dd7 :3 0 d8
:2 0 f8 :4 0 2cb9
4dd9 4ddb :3 0 d8
:2 0 f1 :3 0 2cbc
4ddd 4ddf :3 0 d8
:2 0 f9 :4 0 2cbf
4de1 4de3 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2cc2 4de6 4dea
2cc6 4de5 4dec :3 0
2cc9 4dce 4dee :2 0
4df0 2ccc 4df1 4dcb
4df0 0 4df2 2cce
0 4df3 2cd0 4df6
:3 0 4df6 0 4df6
4df5 4df3 4df4 :6 0
4df8 e4 :3 0 2cd3
4dfa 2cd5 4df9 4df8
:2 0 4dfb 2cd7 :2 0
4dfd 0 4dfd 4dfc
4daa 4dfb :6 0 4f4c
1 :3 0 15 :3 0
ee :3 0 4dff 4e00
0 15 :3 0 e7
:2 0 165 :3 0 4e02
4e04 0 2cdc 4e03
4e06 :3 0 4e07 :2 0
8f :3 0 82 :3 0
45 :2 0 2cdf 4e09
4e0c e7 :2 0 45
:2 0 2ce4 4e0e 4e10
:3 0 1db :3 0 33c
:3 0 39 :3 0 33d
:3 0 3a :3 0 33e
:3 0 48 :3 0 33f
:3 0 48 :3 0 7e
:3 0 340 :3 0 9e
:3 0 28 :3 0 9f
:3 0 29 :4 0 341
1 :8 0 4e37 ed
:4 0 4e22 :3 0 105
:3 0 e7 :2 0 2ce9
4e25 4e26 :3 0 15
:3 0 ee :3 0 4e28
4e29 0 45 :2 0
4e2a 4e2b 0 4e2d
2cec 4e34 15 :3 0
ee :3 0 4e2e 4e2f
0 ef :2 0 4e30
4e31 0 4e33 2cee
4e35 4e27 4e2d 0
4e36 0 4e33 0
4e36 2cf0 0 4e37
2cf3 4e8a f2 :3 0
15 :3 0 ee :3 0
4e39 4e3a 0 f1
:3 0 4e3b 4e3c 0
4e3e 2cf6 4e40 2cf8
4e3f 4e3e :2 0 4e88
f3 :3 0 15 :3 0
ee :3 0 4e43 4e44
0 f1 :3 0 4e45
4e46 0 4e80 d0
:3 0 d1 :3 0 4e48
4e49 0 d0 :3 0
e0 :3 0 4e4b 4e4c
0 f4 :2 0 2
:4 0 342 :2 0 e2
:2 0 30 :2 0 2cfa
4e51 4e53 :3 0 2cfd
4e4d 4e55 4e4a 4e57
4e56 :2 0 d3 :3 0
e3 :3 0 4e59 4e5a
0 d5 :4 0 343
:4 0 d8 :2 0 d9
:3 0 2d01 4e5e 4e60
:3 0 d8 :2 0 f7
:4 0 2d04 4e62 4e64
:3 0 d8 :2 0 f8
:4 0 2d07 4e66 4e68
:3 0 d8 :2 0 f1
:3 0 2d0a 4e6a 4e6c
:3 0 d8 :2 0 f9
:4 0 2d0d 4e6e 4e70
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 2d10
4e73 4e77 2d14 4e72
4e79 :3 0 2d17 4e5b
4e7b :2 0 4e7d 2d1a
4e7e 4e58 4e7d 0
4e7f 2d1c 0 4e80
2d1e 4e83 :3 0 4e83
0 4e83 4e82 4e80
4e81 :6 0 4e85 e6
:3 0 2d21 4e87 2d23
4e86 4e85 :2 0 4e88
2d25 :2 0 4e8a 0
4e8a 4e89 4e37 4e88
:6 0 4e8c 1 :3 0
2d28 4f0a 1db :3 0
33c :3 0 39 :3 0
33d :3 0 3a :3 0
33e :3 0 48 :3 0
33f :3 0 48 :3 0
7e :3 0 340 :3 0
48 :3 0 7f :3 0
9e :3 0 28 :3 0
9f :3 0 29 :4 0
344 1 :8 0 4eb4
ed :4 0 4e9f :3 0
105 :3 0 e7 :2 0
2d2c 4ea2 4ea3 :3 0
15 :3 0 ee :3 0
4ea5 4ea6 0 45
:2 0 4ea7 4ea8 0
4eaa 2d2f 4eb1 15
:3 0 ee :3 0 4eab
4eac 0 ef :2 0
4ead 4eae 0 4eb0
2d31 4eb2 4ea4 4eaa
0 4eb3 0 4eb0
0 4eb3 2d33 0
4eb4 2d36 4f07 f2
:3 0 15 :3 0 ee
:3 0 4eb6 4eb7 0
f1 :3 0 4eb8 4eb9
0 4ebb 2d39 4ebd
2d3b 4ebc 4ebb :2 0
4f05 f3 :3 0 15
:3 0 ee :3 0 4ec0
4ec1 0 f1 :3 0
4ec2 4ec3 0 4efd
d0 :3 0 d1 :3 0
4ec5 4ec6 0 d0
:3 0 e0 :3 0 4ec8
4ec9 0 f4 :2 0
2 :4 0 345 :2 0
e2 :2 0 30 :2 0
2d3d 4ece 4ed0 :3 0
2d40 4eca 4ed2 4ec7
4ed4 4ed3 :2 0 d3
:3 0 e3 :3 0 4ed6
4ed7 0 d5 :4 0
346 :4 0 d8 :2 0
d9 :3 0 2d44 4edb
4edd :3 0 d8 :2 0
f7 :4 0 2d47 4edf
4ee1 :3 0 d8 :2 0
f8 :4 0 2d4a 4ee3
4ee5 :3 0 d8 :2 0
f1 :3 0 2d4d 4ee7
4ee9 :3 0 d8 :2 0
f9 :4 0 2d50 4eeb
4eed :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2d53 4ef0 4ef4 2d57
4eef 4ef6 :3 0 2d5a
4ed8 4ef8 :2 0 4efa
2d5d 4efb 4ed5 4efa
0 4efc 2d5f 0
4efd 2d61 4f00 :3 0
4f00 0 4f00 4eff
4efd 4efe :6 0 4f02
e8 :3 0 2d64 4f04
2d66 4f03 4f02 :2 0
4f05 2d68 :2 0 4f07
0 4f07 4f06 4eb4
4f05 :6 0 4f09 1
:3 0 2d6b 4f0b 4e11
4e8c 0 4f0c 0
4f09 0 4f0c 2d6d
0 4f2f ae :3 0
79 :3 0 30 :2 0
30 :2 0 2d70 4f0d
4f11 e7 :2 0 1c5
:4 0 2d76 4f13 4f15
:3 0 4f16 :2 0 84
:3 0 45 :2 0 4f18
4f19 0 4f2c 15
:3 0 ee :3 0 4f1b
4f1c 0 1be :3 0
28 :3 0 28 :3 0
8b :3 0 34 :3 0
35 :3 0 7e :3 0
7f :3 0 84 :3 0
83 :3 0 82 :3 0
2d79 4f1e 4f29 4f1d
4f2a 0 4f2c 2d84
4f2d 4f17 4f2c 0
4f2e 2d87 0 4f2f
2d89 4f30 4e08 4f2f
0 4f31 2d8c 0
4f4c 23 :3 0 1b9
:2 0 2d8e 4f33 4f34
:3 0 4f35 :2 0 4f36
:2 0 123 :3 0 140
:3 0 4f38 4f39 0
8b :3 0 23 :3 0
2d90 4f3a 4f3d e7
:2 0 45 :2 0 2d95
4f3f 4f41 :3 0 4f42
:2 0 4f37 4f44 4f43
:2 0 6c :3 0 30
:2 0 4f46 4f47 0
4f49 2d98 4f4a 4f45
4f49 0 4f4b 2d9a
0 4f4c 2d9c 4f4d
4d7d 4f4c 0 4f4e
2da2 0 4f4f 2da4
4f50 4ba3 4f4f 0
4f51 2da8 0 5170
23 :3 0 1b9 :2 0
2daa 4f53 4f54 :3 0
4f55 :2 0 75 :3 0
2ce :2 0 4f57 4f58
0 510a 7b :3 0
227 :3 0 28 :3 0
23 :3 0 75 :3 0
45 :2 0 45 :2 0
2dac 4f5b 4f61 4f5a
4f62 0 510a ac
:3 0 af :3 0 336
:3 0 ad :3 0 ae
:3 0 337 :3 0 ad
:3 0 ae :3 0 338
:3 0 b3 :3 0 b4
:3 0 b5 :3 0 b6
:3 0 39 :3 0 3a
:3 0 48 :3 0 34
:3 0 35 :3 0 82
:3 0 83 :3 0 62
:3 0 64 :3 0 9d
:3 0 a7 :3 0 23
:4 0 347 1 :8 0
4f83 15 :3 0 ee
:3 0 4f7e 4f7f 0
f1 :3 0 4f80 4f81
0 4f83 2db2 4fd6
f2 :3 0 15 :3 0
ee :3 0 4f85 4f86
0 f1 :3 0 4f87
4f88 0 4f8a 2db5
4f8c 2db7 4f8b 4f8a
:2 0 4fd4 f3 :3 0
15 :3 0 ee :3 0
4f8f 4f90 0 f1
:3 0 4f91 4f92 0
4fcc d0 :3 0 d1
:3 0 4f94 4f95 0
d0 :3 0 e0 :3 0
4f97 4f98 0 f4
:2 0 2 :4 0 348
:2 0 e2 :2 0 30
:2 0 2db9 4f9d 4f9f
:3 0 2dbc 4f99 4fa1
4f96 4fa3 4fa2 :2 0
d3 :3 0 e3 :3 0
4fa5 4fa6 0 d5
:4 0 349 :4 0 d8
:2 0 d9 :3 0 2dc0
4faa 4fac :3 0 d8
:2 0 f7 :4 0 2dc3
4fae 4fb0 :3 0 d8
:2 0 f8 :4 0 2dc6
4fb2 4fb4 :3 0 d8
:2 0 f1 :3 0 2dc9
4fb6 4fb8 :3 0 d8
:2 0 f9 :4 0 2dcc
4fba 4fbc :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2dcf 4fbf 4fc3
2dd3 4fbe 4fc5 :3 0
2dd6 4fa7 4fc7 :2 0
4fc9 2dd9 4fca 4fa4
4fc9 0 4fcb 2ddb
0 4fcc 2ddd 4fcf
:3 0 4fcf 0 4fcf
4fce 4fcc 4fcd :6 0
4fd1 ea :3 0 2de0
4fd3 2de2 4fd2 4fd1
:2 0 4fd4 2de4 :2 0
4fd6 0 4fd6 4fd5
4f83 4fd4 :6 0 510a
1 :3 0 8f :3 0
82 :3 0 45 :2 0
2de7 4fd8 4fdb e7
:2 0 45 :2 0 2dec
4fdd 4fdf :3 0 1db
:3 0 33c :3 0 39
:3 0 33d :3 0 3a
:3 0 33e :3 0 48
:3 0 33f :3 0 48
:3 0 62 :3 0 340
:3 0 9e :3 0 28
:3 0 9f :3 0 27
:4 0 34a 1 :8 0
5006 ed :4 0 4ff1
:3 0 105 :3 0 e7
:2 0 2df1 4ff4 4ff5
:3 0 15 :3 0 ee
:3 0 4ff7 4ff8 0
45 :2 0 4ff9 4ffa
0 4ffc 2df4 5003
15 :3 0 ee :3 0
4ffd 4ffe 0 ef
:2 0 4fff 5000 0
5002 2df6 5004 4ff6
4ffc 0 5005 0
5002 0 5005 2df8
0 5006 2dfb 5059
f2 :3 0 15 :3 0
ee :3 0 5008 5009
0 f1 :3 0 500a
500b 0 500d 2dfe
500f 2e00 500e 500d
:2 0 5057 f3 :3 0
15 :3 0 ee :3 0
5012 5013 0 f1
:3 0 5014 5015 0
504f d0 :3 0 d1
:3 0 5017 5018 0
d0 :3 0 e0 :3 0
501a 501b 0 f4
:2 0 2 :4 0 34b
:2 0 e2 :2 0 30
:2 0 2e02 5020 5022
:3 0 2e05 501c 5024
5019 5026 5025 :2 0
d3 :3 0 e3 :3 0
5028 5029 0 d5
:4 0 34c :4 0 d8
:2 0 d9 :3 0 2e09
502d 502f :3 0 d8
:2 0 f7 :4 0 2e0c
5031 5033 :3 0 d8
:2 0 f8 :4 0 2e0f
5035 5037 :3 0 d8
:2 0 f1 :3 0 2e12
5039 503b :3 0 d8
:2 0 f9 :4 0 2e15
503d 503f :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2e18 5042 5046
2e1c 5041 5048 :3 0
2e1f 502a 504a :2 0
504c 2e22 504d 5027
504c 0 504e 2e24
0 504f 2e26 5052
:3 0 5052 0 5052
5051 504f 5050 :6 0
5054 ec :3 0 2e29
5056 2e2b 5055 5054
:2 0 5057 2e2d :2 0
5059 0 5059 5058
5006 5057 :6 0 505b
1 :3 0 2e30 50d9
1db :3 0 33c :3 0
39 :3 0 33d :3 0
3a :3 0 33e :3 0
48 :3 0 33f :3 0
48 :3 0 62 :3 0
340 :3 0 48 :3 0
64 :3 0 9e :3 0
28 :3 0 9f :3 0
27 :4 0 34d 1
:8 0 5083 ed :4 0
506e :3 0 105 :3 0
e7 :2 0 2e34 5071
5072 :3 0 15 :3 0
ee :3 0 5074 5075
0 45 :2 0 5076
5077 0 5079 2e37
5080 15 :3 0 ee
:3 0 507a 507b 0
ef :2 0 507c 507d
0 507f 2e39 5081
5073 5079 0 5082
0 507f 0 5082
2e3b 0 5083 2e3e
50d6 f2 :3 0 15
:3 0 ee :3 0 5085
5086 0 f1 :3 0
5087 5088 0 508a
2e41 508c 2e43 508b
508a :2 0 50d4 f3
:3 0 15 :3 0 ee
:3 0 508f 5090 0
f1 :3 0 5091 5092
0 50cc d0 :3 0
d1 :3 0 5094 5095
0 d0 :3 0 e0
:3 0 5097 5098 0
f4 :2 0 2 :4 0
34e :2 0 e2 :2 0
30 :2 0 2e45 509d
509f :3 0 2e48 5099
50a1 5096 50a3 50a2
:2 0 d3 :3 0 e3
:3 0 50a5 50a6 0
d5 :4 0 34f :4 0
d8 :2 0 d9 :3 0
2e4c 50aa 50ac :3 0
d8 :2 0 f7 :4 0
2e4f 50ae 50b0 :3 0
d8 :2 0 f8 :4 0
2e52 50b2 50b4 :3 0
d8 :2 0 f1 :3 0
2e55 50b6 50b8 :3 0
d8 :2 0 f9 :4 0
2e58 50ba 50bc :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 2e5b 50bf
50c3 2e5f 50be 50c5
:3 0 2e62 50a7 50c7
:2 0 50c9 2e65 50ca
50a4 50c9 0 50cb
2e67 0 50cc 2e69
50cf :3 0 50cf 0
50cf 50ce 50cc 50cd
:6 0 50d1 ee :3 0
2e6c 50d3 2e6e 50d2
50d1 :2 0 50d4 2e70
:2 0 50d6 0 50d6
50d5 5083 50d4 :6 0
50d8 1 :3 0 2e73
50da 4fe0 505b 0
50db 0 50d8 0
50db 2e75 0 510a
ae :3 0 79 :3 0
30 :2 0 30 :2 0
2e78 50dc 50e0 e7
:2 0 1c5 :4 0 2e7e
50e2 50e4 :3 0 50e5
:2 0 8f :3 0 6c
:3 0 45 :2 0 2e81
50e7 50ea e7 :2 0
45 :2 0 2e86 50ec
50ee :3 0 50ef :2 0
50e6 50f1 50f0 :2 0
84 :3 0 45 :2 0
50f3 50f4 0 5107
15 :3 0 ee :3 0
50f6 50f7 0 1be
:3 0 28 :3 0 28
:3 0 23 :3 0 34
:3 0 35 :3 0 62
:3 0 64 :3 0 84
:3 0 83 :3 0 82
:3 0 2e89 50f9 5104
50f8 5105 0 5107
2e94 5108 50f2 5107
0 5109 2e97 0
510a 2e99 510b 4f56
510a 0 510c 2e9f
0 5170 7b :3 0
350 :3 0 28 :3 0
2ea1 510e 5110 510d
5111 0 5170 15
:3 0 ee :3 0 5113
5114 0 e7 :2 0
ef :2 0 2ea5 5116
5118 :3 0 15 :3 0
ee :3 0 511a 511b
0 45 :2 0 511c
511d 0 511f 2ea8
5120 5119 511f 0
5121 2eaa 0 5170
d0 :3 0 d1 :3 0
5122 5123 0 d0
:3 0 e0 :3 0 5125
5126 0 ea :2 0
2 :4 0 351 :2 0
e2 :2 0 30 :2 0
2eac 512b 512d :3 0
2eaf 5127 512f 5124
5131 5130 :2 0 d3
:3 0 e3 :3 0 5133
5134 0 d5 :4 0
352 :4 0 d8 :2 0
d9 :3 0 2eb3 5138
513a :3 0 d8 :2 0
f7 :4 0 2eb6 513c
513e :3 0 d8 :2 0
fe :4 0 2eb9 5140
5142 :3 0 d8 :2 0
8f :3 0 dd :3 0
15 :3 0 ee :3 0
5147 5148 0 2ebc
5146 514a de :4 0
2ebe 5145 514d 2ec1
5144 514f :3 0 d8
:2 0 100 :4 0 2ec4
5151 5153 :3 0 d8
:2 0 db :4 0 2ec7
5155 5157 :3 0 d8
:2 0 23 :3 0 2eca
5159 515b :3 0 d8
:2 0 db :4 0 2ecd
515d 515f :3 0 2ed0
5135 5161 :2 0 5163
2ed3 5164 5132 5163
0 5165 2ed5 0
5170 103 :3 0 353
:3 0 5166 5167 0
15 :3 0 ee :3 0
5169 516a 0 23
:3 0 105 :3 0 2ed7
5168 516e :2 0 5170
2edb 5211 15 :3 0
354 :2 0 4 5171
5172 0 d0 :3 0
d1 :3 0 5174 5175
0 d0 :3 0 e0
:3 0 5177 5178 0
f4 :2 0 2 :4 0
355 :2 0 e2 :2 0
30 :2 0 2f36 517d
517f :3 0 2f39 5179
5181 5176 5183 5182
:2 0 d3 :3 0 e3
:3 0 5185 5186 0
d5 :4 0 356 :4 0
d8 :2 0 d9 :3 0
2f3d 518a 518c :3 0
2f40 5187 518e :2 0
51a7 d3 :3 0 e3
:3 0 5190 5191 0
d5 :4 0 357 :4 0
d8 :2 0 15 :3 0
358 :3 0 5196 5197
0 2f43 5195 5199
:3 0 d8 :2 0 100
:4 0 2f46 519b 519d
:3 0 d8 :2 0 15
:3 0 359 :3 0 51a0
51a1 0 2f49 519f
51a3 :3 0 2f4c 5192
51a5 :2 0 51a7 2f4f
51a8 5184 51a7 0
51a9 2f52 0 51b9
ec :3 0 cf :3 0
15 :3 0 358 :3 0
35a :3 0 15 :3 0
359 :3 0 35b :3 0
14f :4 0 35c 1
:a 0 51b5 :2 0 51b9
51ab 51b3 :2 0 14
:3 0 cf :3 0 51b7
:2 0 51b9 2f54 51bb
2f58 51ba 51b9 :2 0
520f f3 :3 0 15
:3 0 ee :3 0 51be
51bf 0 f1 :3 0
51c0 51c1 0 5207
d0 :3 0 d1 :3 0
51c3 51c4 0 d0
:3 0 e0 :3 0 51c6
51c7 0 f4 :2 0
2 :4 0 35d :2 0
e2 :2 0 30 :2 0
2f5a 51cc 51ce :3 0
2f5d 51c8 51d0 51c5
51d2 51d1 :2 0 d3
:3 0 e3 :3 0 51d4
51d5 0 d5 :4 0
35e :4 0 d8 :2 0
d9 :3 0 2f61 51d9
51db :3 0 2f64 51d6
51dd :2 0 51f7 d3
:3 0 e3 :3 0 51df
51e0 0 d5 :4 0
f8 :4 0 d8 :2 0
f1 :3 0 2f67 51e4
51e6 :3 0 d8 :2 0
f9 :4 0 2f6a 51e8
51ea :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2f6d 51ed 51f1 2f71
51ec 51f3 :3 0 2f74
51e1 51f5 :2 0 51f7
2f77 51f8 51d3 51f7
0 51f9 2f7a 0
5207 ec :3 0 cf
:3 0 35a :3 0 15
:3 0 359 :3 0 35b
:3 0 14f :4 0 35f
1 :a 0 5203 :2 0
5207 51fb 5201 :2 0
14 :3 0 cf :3 0
5205 :2 0 5207 2f7c
520a :3 0 520a 0
520a 5209 5207 5208
:6 0 520c 1 :3 0
2f81 520e 2f83 520d
520c :2 0 520f 2f85
:2 0 5211 2f88 5211
5210 5170 520f :6 0
5212 :2 0 2 44
5211 5215 :3 0 5214
5212 5216 :8 0 
2ffa
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
52 1 50 1
59 1 57 1
60 1 5e 1
67 1 65 1
6e 1 6c 1
75 1 73 1
7c 1 7a 1
83 1 81 1
8a 1 88 1
91 1 8f 1
98 1 96 1
9f 1 9d 1
a6 1 a4 1
ab 1 b0 1
b5 1 ba 1
c1 1 bf 1
c8 1 c6 1
cd 1 d2 1
d7 1 de 1
dc 1 e5 1
e3 1 ea 1
ef 1 f4 1
f9 1 100 1
fe 1 107 1
105 1 10e 1
10c 1 115 1
113 1 11c 1
11a 1 121 1
127 1 12d 1
133 1 139 1
13f 1 145 1
14b 1 151 1
157 1 15d 1
163 1 169 1
16f 1 175 1
17b 1 181 1
187 1 18d 1
193 1 199 1
19f 1 1a5 1
1ab 1 1b1 1
1b7 1 1bd 1
1c3 1 1c9 1
1cf 1 1d5 1
1db 1 1e1 1
1e7 1 1ed 1
1f3 1 1f9 1
1ff 1 205 1
20b 1 211 1
217 1 21d 1
225 1 223 1
22c 1 22a 1
231 1 237 1
23f 1 23d 1
244 1 24c 1
24a 1 253 1
251 1 258 1
25e 1 264 1
269 1 26e 1
274 1 27a 1
280 1 286 1
28c 1 292 1
298 1 29e 1
2a4 1 2aa 1
2b2 1 2b0 1
2b9 1 2b7 1
2c0 1 2be 1
2c5 2 2d0 2d1
1 2d3 1 2cb
1 2d9 1 2df
1 2e5 1 2ea
1 2f9 1 30d
1 385 1 38b
1 398 1 3a4
2 3a7 3a9 2
3ac 3ae 2 3b0
3b2 2 3b4 3b6
2 3b8 3ba 2
3bc 3be 2 3c0
3c2 2 3c4 3c6
2 3c8 3ca 2
3cc 3ce 2 3d0
3d2 2 3d4 3d6
2 3d8 3da 2
3dc 3de 2 3e0
3e2 2 3e4 3e6
2 3e8 3ea 2
3ec 3ee 2 3f0
3f2 2 3f4 3f6
2 3f8 3fa 1
400 2 402 403
2 3fc 405 2
407 409 1 40f
2 411 412 2
40b 414 2 416
418 1 41e 2
420 421 2 41a
423 2 425 427
1 42d 2 42f
430 2 429 432
2 434 436 1
43c 2 43e 43f
2 438 441 2
443 445 1 44b
2 44d 44e 2
447 450 2 452
454 1 45a 2
45c 45d 2 456
45f 2 461 463
1 469 2 46b
46c 2 465 46e
2 470 472 1
478 2 47a 47b
2 474 47d 2
47f 481 2 483
485 2 487 489
2 48b 48d 2
48f 491 4 3a0
3a6 3ab 493 1
495 1 497 2
4a1 4a3 3 49f
4a0 4a5 2 4ae
4b0 2 4ad 4b2
1 4b4 1 4b6
2 4cd 4ce 2
4d0 4d3 2 4d8
4d9 1 4df 2
4db 4df 2 4e4
4e5 1 4eb 2
4e7 4eb 1 4f3
1 4f5 1 51c
1 522 2 524
525 2 52e 534
1 53b 1 536
2 54e 550 3
54c 54d 552 2
55b 55d 2 55f
561 2 563 565
2 567 569 2
56b 56d 3 572
573 574 2 56f
576 2 55a 578
1 57a 1 57c
2 545 57d 1
581 1 540 2
53e 585 2 58b
58c 1 590 2
58e 590 2 59b
59d 3 599 59a
59f 2 5a8 5aa
2 5ac 5ae 2
5b0 5b2 1 5ba
2 5bc 5bd 2
5b4 5bf 2 5c1
5c3 2 5c5 5c7
2 5c9 5cb 2
5cd 5cf 2 5a7
5d1 1 5d3 1
5d5 2 5df 5e1
3 5dd 5de 5e3
2 5ec 5ee 2
5eb 5f0 1 5f2
1 5f4 3 5fb
5fc 5fd 3 5d6
5f5 5ff 1 601
2 612 617 1
61e 1 619 2
631 633 3 62f
630 635 2 63e
640 2 642 644
2 646 648 2
64a 64c 2 64e
650 3 655 656
657 2 652 659
2 63d 65b 1
65d 1 65f 2
628 660 1 664
1 623 2 621
668 1 673 2
66f 673 2 67f
681 3 67d 67e
683 2 68c 68e
2 690 692 2
694 696 1 69e
2 6a0 6a1 2
698 6a3 2 6a5
6a7 2 6a9 6ab
2 6ad 6af 2
6b1 6b3 2 68b
6b5 1 6b7 1
6b9 2 6c3 6c5
3 6c1 6c2 6c7
2 6d0 6d2 2
6cf 6d4 1 6d6
1 6d8 3 6df
6e0 6e1 3 6ba
6d9 6e3 1 6e5
2 6ef 6f4 1
6fb 1 6f6 2
70e 710 3 70c
70d 712 2 71b
71d 2 71f 721
2 723 725 2
727 729 2 72b
72d 3 732 733
734 2 72f 736
2 71a 738 1
73a 1 73c 2
705 73d 1 741
1 700 2 6fe
745 2 74b 74c
1 750 2 74e
750 2 75b 75d
3 759 75a 75f
2 768 76a 2
76c 76e 2 770
772 1 77a 2
77c 77d 2 774
77f 2 781 783
2 785 787 2
789 78b 2 78d
78f 2 767 791
1 793 1 795
2 79f 7a1 3
79d 79e 7a3 2
7ac 7ae 2 7ab
7b0 1 7b2 1
7b4 3 7bb 7bc
7bd 3 796 7b5
7bf 1 7c1 2
7e8 7ed 1 7f4
1 7ef 2 807
809 3 805 806
80b 2 814 816
2 818 81a 2
81c 81e 2 820
822 2 824 826
3 82b 82c 82d
2 828 82f 2
813 831 1 833
1 835 2 7fe
836 1 83a 1
7f9 2 7f7 83e
1 849 2 845
849 2 855 857
3 853 854 859
2 862 864 2
866 868 2 86a
86c 1 874 2
876 877 2 86e
879 2 87b 87d
2 87f 881 2
883 885 2 887
889 2 861 88b
1 88d 1 88f
2 899 89b 3
897 898 89d 2
8a6 8a8 2 8a5
8aa 1 8ac 1
8ae 3 8b5 8b6
8b7 3 890 8af
8b9 1 8bb 2
8c4 8c9 1 8d0
1 8cb 2 8e3
8e5 3 8e1 8e2
8e7 2 8f0 8f2
2 8f4 8f6 2
8f8 8fa 2 8fc
8fe 2 900 902
3 907 908 909
2 904 90b 2
8ef 90d 1 90f
1 911 2 8da
912 1 916 1
8d5 2 8d3 91a
1 925 2 921
925 2 931 933
3 92f 930 935
2 93e 940 2
942 944 2 946
948 1 950 2
952 953 2 94a
955 2 957 959
2 95b 95d 2
95f 961 2 963
965 2 93d 967
1 969 1 96b
2 975 977 3
973 974 979 2
982 984 2 981
986 1 988 1
98a 3 991 992
993 3 96c 98b
995 1 997 2
99e 9a3 1 9aa
1 9a5 2 9bd
9bf 3 9bb 9bc
9c1 2 9ca 9cc
2 9ce 9d0 2
9d2 9d4 2 9d6
9d8 2 9da 9dc
3 9e1 9e2 9e3
2 9de 9e5 2
9c9 9e7 1 9e9
1 9eb 2 9b4
9ec 1 9f0 1
9af 2 9ad 9f4
2 9fc 9fd 1
a01 2 9ff a01
1 a06 1 a08
1 a10 2 a0c
a10 2 a1c a1e
3 a1a a1b a20
2 a29 a2b 2
a2d a2f 2 a31
a33 1 a3b 2
a3d a3e 2 a35
a40 2 a42 a44
2 a46 a48 2
a4a a4c 2 a4e
a50 2 a28 a52
1 a54 1 a56
2 a60 a62 3
a5e a5f a64 2
a6d a6f 2 a6c
a71 1 a73 1
a75 3 a7c a7d
a7e 3 a57 a76
a80 1 a82 2
a8a a8b 2 a8d
a8e 2 a95 a96
2 a98 a99 2
aa0 aa1 2 aa3
aa4 2 ab3 ab8
1 abf 1 aba
2 ad2 ad4 3
ad0 ad1 ad6 2
adf ae1 2 ae3
ae5 2 ae7 ae9
2 aeb aed 2
aef af1 3 af6
af7 af8 2 af3
afa 2 ade afc
1 afe 1 b00
2 ac9 b01 1
b05 1 ac4 2
ac2 b09 2 b19
b1e 1 b25 1
b20 2 b38 b3a
3 b36 b37 b3c
2 b45 b47 2
b49 b4b 2 b4d
b4f 2 b51 b53
2 b55 b57 3
b5c b5d b5e 2
b59 b60 2 b44
b62 1 b64 1
b66 2 b2f b67
1 b6b 1 b2a
2 b28 b6f 1
b76 2 b74 b76
2 b7a b7b 1
b7f 2 b7d b7f
2 b8c b91 1
b98 1 b93 2
bab bad 3 ba9
baa baf 2 bb8
bba 2 bbc bbe
2 bc0 bc2 2
bc4 bc6 2 bc8
bca 3 bcf bd0
bd1 2 bcc bd3
2 bb7 bd5 1
bd7 1 bd9 2
ba2 bda 1 bde
1 b9d 2 b9b
be2 2 be8 be9
1 bed 2 beb
bed 1 bef 2
c00 c05 1 c0c
1 c07 2 c1f
c21 3 c1d c1e
c23 2 c2c c2e
2 c30 c32 2
c34 c36 2 c38
c3a 2 c3c c3e
3 c43 c44 c45
2 c40 c47 2
c2b c49 1 c4b
1 c4d 2 c16
c4e 1 c52 1
c11 2 c0f c56
2 c5c c5d 1
c61 2 c5f c61
2 c6c c6e 3
c6a c6b c70 2
c79 c7b 2 c7d
c7f 2 c81 c83
1 c8b 2 c8d
c8e 2 c85 c90
2 c92 c94 2
c96 c98 2 c9a
c9c 2 c9e ca0
2 c78 ca2 1
ca4 1 ca6 2
cb0 cb2 3 cae
caf cb4 2 cbd
cbf 2 cbc cc1
1 cc3 1 cc5
3 ccc ccd cce
3 ca7 cc6 cd0
1 cd2 3 bf5
c59 cd3 1 cd5
2 be5 cd6 1
cd8 1 cd9 2
cde cdf 1 ce1
1 ce5 2 ce3
ce5 2 ce9 cea
1 cee 2 cec
cee 2 cf2 cf3
1 cf7 2 cf5
cf7 2 d0c d11
1 d18 1 d13
2 d2b d2d 3
d29 d2a d2f 2
d38 d3a 2 d3c
d3e 2 d40 d42
2 d44 d46 2
d48 d4a 3 d4f
d50 d51 2 d4c
d53 2 d37 d55
1 d57 1 d59
2 d22 d5a 1
d5e 1 d1d 2
d1b d62 2 d68
d69 1 d6d 2
d6b d6d 2 d78
d7a 3 d76 d77
d7c 2 d85 d87
2 d89 d8b 2
d8d d8f 1 d97
2 d99 d9a 2
d91 d9c 2 d9e
da0 2 da2 da4
2 da6 da8 2
daa dac 2 d84
dae 1 db0 1
db2 2 dbc dbe
3 dba dbb dc0
2 dc9 dcb 2
dc8 dcd 1 dcf
1 dd1 3 dd8
dd9 dda 3 db3
dd2 ddc 1 dde
3 d01 d65 ddf
2 de2 de1 1
e06 1 e0c 2
e0e e0f 1 e17
2 e13 e17 1
e1d 1 e21 2
e23 e24 2 e28
e2e 1 e35 1
e30 2 e48 e4a
3 e46 e47 e4c
2 e55 e57 2
e59 e5b 2 e5d
e5f 2 e61 e63
2 e65 e67 3
e6c e6d e6e 2
e69 e70 2 e54
e72 1 e74 1
e76 2 e3f e77
1 e7b 1 e3a
2 e38 e7f 2
e85 e86 1 e8a
2 e88 e8a 2
e8e e8f 1 e93
2 e91 e93 1
e98 1 e9a 1
e9b 1 e9d 2
eaa eaf 1 eb6
1 eb1 2 ec9
ecb 3 ec7 ec8
ecd 2 ed6 ed8
2 eda edc 2
ede ee0 2 ee2
ee4 2 ee6 ee8
3 eed eee eef
2 eea ef1 2
ed5 ef3 1 ef5
1 ef7 2 ec0
ef8 1 efc 1
ebb 2 eb9 f00
1 f0b 2 f07
f0b 2 f10 f11
1 f15 2 f13
f15 1 f17 2
f2f f34 1 f3b
1 f36 2 f4e
f50 3 f4c f4d
f52 2 f5b f5d
2 f5f f61 2
f63 f65 2 f67
f69 2 f6b f6d
3 f72 f73 f74
2 f6f f76 2
f5a f78 1 f7a
1 f7c 2 f45
f7d 1 f81 1
f40 2 f3e f85
1 f90 2 f8c
f90 2 f99 f9a
2 f9c f9f 1
fa2 2 fa8 fa9
4 fa6 fab fae
faf 2 fb2 fb7
2 fb9 fba 7
fc4 fc5 fc6 fc7
fc8 fc9 fca 2
fd1 fd2 1 fd4
1 ff4 2 ff3
ff4 1 ffc 1
1002 2 1004 1005
2 ff1 1006 1
100d 1 1008 2
1020 1022 3 101e
101f 1024 2 102d
102f 2 1031 1033
2 1035 1037 2
1039 103b 2 103d
103f 3 1044 1045
1046 2 1041 1048
2 102c 104a 1
104c 1 104e 2
1017 104f 1 1053
1 1012 2 1010
1057 2 1061 1066
1 106d 1 1068
2 1080 1082 3
107e 107f 1084 2
108d 108f 2 1091
1093 2 1095 1097
2 1099 109b 2
109d 109f 3 10a4
10a5 10a6 2 10a1
10a8 2 108c 10aa
1 10ac 1 10ae
2 1077 10af 1
10b3 1 1072 2
1070 10b7 2 10bf
10c0 1 10c4 2
10c2 10c4 1 10c9
2 10d7 10dc 1
10e3 1 10de 2
10f6 10f8 3 10f4
10f5 10fa 2 1103
1105 2 1107 1109
2 110b 110d 2
110f 1111 2 1113
1115 3 111a 111b
111c 2 1117 111e
2 1102 1120 1
1122 1 1124 2
10ed 1125 1 1129
1 10e8 2 10e6
112d 1 1130 2
1133 1134 2 1137
1138 1 113c 2
113a 113c 1 114c
2 114b 114c 1
1154 1 115a 2
115c 115d 2 1149
115e 1 1165 1
1160 2 1178 117a
3 1176 1177 117c
2 1185 1187 2
1189 118b 2 118d
118f 2 1191 1193
2 1195 1197 3
119c 119d 119e 2
1199 11a0 2 1184
11a2 1 11a4 1
11a6 2 116f 11a7
1 11ab 1 116a
2 1168 11af 1
11c8 2 11c7 11c8
1 11d0 1 11d6
2 11d8 11d9 2
11c5 11da 1 11e1
1 11dc 2 11f4
11f6 3 11f2 11f3
11f8 2 1201 1203
2 1205 1207 2
1209 120b 2 120d
120f 2 1211 1213
3 1218 1219 121a
2 1215 121c 2
1200 121e 1 1220
1 1222 2 11eb
1223 1 1227 1
11e6 2 11e4 122b
2 11b2 122e 1
1245 2 1244 1245
1 124d 1 1253
2 1255 1256 2
1242 1257 1 125e
1 1259 2 1271
1273 3 126f 1270
1275 2 127e 1280
2 1282 1284 2
1286 1288 2 128a
128c 2 128e 1290
3 1295 1296 1297
2 1292 1299 2
127d 129b 1 129d
1 129f 2 1268
12a0 1 12a4 1
1263 2 1261 12a8
1 12ab 2 12ae
12af c f1f f24
f88 fbb fbe fc1
fcd fd7 105a 10ba
1135 12b0 1 12b9
2 12b5 12b9 2
12c6 12cb 1 12d2
1 12cd 2 12e5
12e7 3 12e3 12e4
12e9 2 12f2 12f4
2 12f6 12f8 2
12fa 12fc 2 12fe
1300 2 1302 1304
3 1309 130a 130b
2 1306 130d 2
12f1 130f 1 1311
1 1313 2 12dc
1314 1 1318 1
12d7 2 12d5 131c
1 1327 2 1323
1327 2 1331 1336
1 133d 1 1338
2 1350 1352 3
134e 134f 1354 2
135d 135f 2 1361
1363 2 1365 1367
2 1369 136b 2
136d 136f 3 1374
1375 1376 2 1371
1378 2 135c 137a
1 137c 1 137e
2 1347 137f 1
1383 1 1342 2
1340 1387 1 1392
2 138e 1392 1
1398 1 139a 2
138a 139b 1 139d
2 13a0 13a1 1
13a5 2 13a3 13a5
1 13a7 2 13ac
13ad 1 13b3 2
13af 13b3 2 13ba
13bb 4 13b8 13bd
13c0 13c1 1 13d2
2 13d1 13d2 1
13da 1 13e0 2
13e2 13e3 2 13cf
13e4 1 13eb 1
13e6 2 13fe 1400
3 13fc 13fd 1402
2 140b 140d 2
140f 1411 2 1413
1415 2 1417 1419
2 141b 141d 3
1422 1423 1424 2
141f 1426 2 140a
1428 1 142a 1
142c 2 13f5 142d
1 1431 1 13f0
2 13ee 1435 1
143c 3 13c4 1438
143f 2 1444 1445
2 1447 144a 1
1451 2 144d 1451
1 1462 2 1461
1462 1 146a 1
1470 2 1472 1473
2 145f 1474 1
147b 1 1476 2
148e 1490 3 148c
148d 1492 2 149b
149d 2 149f 14a1
2 14a3 14a5 2
14a7 14a9 2 14ab
14ad 3 14b2 14b3
14b4 2 14af 14b6
2 149a 14b8 1
14ba 1 14bc 2
1485 14bd 1 14c1
1 1480 2 147e
14c5 1 14cc 2
14c8 14cf 2 14d5
14d6 2 14d8 14db
1 14e2 2 14de
14e2 1 14f3 2
14f2 14f3 1 14fb
1 1501 2 1503
1504 2 14f0 1505
1 150c 1 1507
2 151f 1521 3
151d 151e 1523 2
152c 152e 2 1530
1532 2 1534 1536
2 1538 153a 2
153c 153e 3 1543
1544 1545 2 1540
1547 2 152b 1549
1 154b 1 154d
2 1516 154e 1
1552 1 1511 2
150f 1556 1 155d
2 1559 1560 3
1563 14d2 1562 1
1564 1 1566 4
12bf 131f 139e 1567
2 156a 1569 2
1582 1587 1 158e
1 1589 2 15a1
15a3 3 159f 15a0
15a5 2 15ae 15b0
2 15b2 15b4 2
15b6 15b8 2 15ba
15bc 2 15be 15c0
3 15c5 15c6 15c7
2 15c2 15c9 2
15ad 15cb 1 15cd
1 15cf 2 1598
15d0 1 15d4 1
1593 2 1591 15d8
1 15e3 2 15df
15e3 1 15e9 1
15eb 2 15fc 15fd
1 1601 2 15ff
1601 2 1606 1607
1 160b 2 1609
160b a 1613 1614
1615 1616 1617 1618
1619 161a 161b 161c
2 1621 1622 1
1626 2 1624 1626
2 162b 162c 2
1631 1632 2 162e
1634 2 163a 163b
2 1640 1641 2
163d 1643 2 1637
1646 1 1648 2
164b 164c 1 1650
2 164e 1650 2
1655 1656 2 165b
165c 2 1658 165e
2 1664 1665 2
166a 166b 2 1667
166d 2 1661 1670
1 1672 3 161f
1649 1673 1 1675
2 1683 1688 1
168f 1 168a 2
16a2 16a4 3 16a0
16a1 16a6 2 16af
16b1 2 16b3 16b5
2 16b7 16b9 2
16bb 16bd 2 16bf
16c1 3 16c6 16c7
16c8 2 16c3 16ca
2 16ae 16cc 1
16ce 1 16d0 2
1699 16d1 1 16d5
1 1694 2 1692
16d9 2 16ed 16f2
1 16f9 1 16f4
2 170c 170e 3
170a 170b 1710 2
1719 171b 2 171d
171f 2 1721 1723
2 1725 1727 2
1729 172b 3 1730
1731 1732 2 172d
1734 2 1718 1736
1 1738 1 173a
2 1703 173b 1
173f 1 16fe 2
16fc 1743 2 174f
1754 1 175b 1
1756 2 176e 1770
3 176c 176d 1772
2 177b 177d 2
177f 1781 2 1783
1785 2 1787 1789
2 178b 178d 3
1792 1793 1794 2
178f 1796 2 177a
1798 1 179a 1
179c 2 1765 179d
1 17a1 1 1760
2 175e 17a5 2
17ad 17ae 1 17b2
2 17b0 17b2 1
17b4 1 17b8 2
17e3 17e8 1 17ef
1 17ea 2 1802
1804 3 1800 1801
1806 2 180f 1811
2 1813 1815 2
1817 1819 2 181b
181d 2 181f 1821
3 1826 1827 1828
2 1823 182a 2
180e 182c 1 182e
1 1830 2 17f9
1831 1 1835 1
17f4 2 17f2 1839
1 1844 2 1840
1844 1 1848 1
1852 a 185a 185b
185c 185d 185e 185f
1860 1861 1862 1863
2 1855 1866 1
1868 2 186e 186f
1 1873 2 1871
1873 2 1877 1878
2 187d 187e 1
1880 2 187a 1880
2 1884 1885 2
188a 188b 1 188d
2 1887 188d 2
1894 1895 2 1897
189a 1 189e 2
189c 189e 2 18a9
18ab 3 18a7 18a8
18ad 2 18b6 18b8
2 18ba 18bc 2
18be 18c0 1 18c8
2 18ca 18cb 2
18c2 18cd 2 18cf
18d1 2 18d3 18d5
2 18d7 18d9 2
18db 18dd 2 18b5
18df 1 18e1 1
18e3 2 18ed 18ef
3 18eb 18ec 18f1
2 18fa 18fc 2
18f9 18fe 1 1900
1 1902 3 1909
190a 190b 3 18e4
1903 190d 2 1913
1914 1 1918 2
1916 1918 1 191d
1 191f 2 1911
1920 2 1922 1923
1 1924 1 1926
a 1927 192a 192d
1930 1933 1936 1939
193c 193f 1942 1
1944 1 194c 2
1948 194c 1 1956
3 195c 195d 195e
1 1962 2 1960
1962 1 1967 a
196f 1970 1971 1972
1973 1974 1975 1976
1977 1978 2 196a
197b 1 197d 2
199a 199f 1 19a6
1 19a1 2 19b9
19bb 3 19b7 19b8
19bd 2 19c6 19c8
2 19ca 19cc 2
19ce 19d0 2 19d2
19d4 2 19d6 19d8
3 19dd 19de 19df
2 19da 19e1 2
19c5 19e3 1 19e5
1 19e7 2 19b0
19e8 1 19ec 1
19ab 2 19a9 19f0
1 19fb 2 19f7
19fb 2 1a00 1a01
2 1a06 1a07 1
1a09 2 1a03 1a09
2 1a0d 1a0e 2
1a13 1a14 1 1a16
2 1a10 1a16 2
1a23 1a25 3 1a21
1a22 1a27 2 1a30
1a32 2 1a34 1a36
2 1a38 1a3a 1
1a42 2 1a44 1a45
2 1a3c 1a47 2
1a49 1a4b 2 1a4d
1a4f 2 1a51 1a53
2 1a55 1a57 2
1a2f 1a59 1 1a5b
1 1a5d 2 1a67
1a69 3 1a65 1a66
1a6b 2 1a74 1a76
2 1a73 1a78 1
1a7a 1 1a7c 3
1a83 1a84 1a85 3
1a5e 1a7d 1a87 1
1a89 3 1a8d 1a8e
1a8f 1 1a93 2
1a91 1a93 1 1a95
2 1a98 1a9a 2
1a9e 1a9f 1 1aa3
2 1aa1 1aa3 2
1aad 1aae 1 1ab2
2 1ab0 1ab2 2
1ab6 1ab7 1 1abb
2 1ab9 1abb 2
1ac8 1acd 1 1ad4
1 1acf 2 1ae7
1ae9 3 1ae5 1ae6
1aeb 2 1af4 1af6
2 1af8 1afa 2
1afc 1afe 2 1b00
1b02 2 1b04 1b06
3 1b0b 1b0c 1b0d
2 1b08 1b0f 2
1af3 1b11 1 1b13
1 1b15 2 1ade
1b16 1 1b1a 1
1ad9 2 1ad7 1b1e
1 1b21 2 1b2c
1b31 1 1b38 1
1b33 2 1b4b 1b4d
3 1b49 1b4a 1b4f
2 1b58 1b5a 2
1b5c 1b5e 2 1b60
1b62 2 1b64 1b66
2 1b68 1b6a 3
1b6f 1b70 1b71 2
1b6c 1b73 2 1b57
1b75 1 1b77 1
1b79 2 1b42 1b7a
1 1b7e 1 1b3d
2 1b3b 1b82 1
1b85 2 1b88 1b89
1 1b8a 1 1b8c
2 1b8f 1b90 1
1b94 2 1b92 1b94
1 1ba1 2 1ba0
1ba1 1 1ba9 1
1baf 2 1bb1 1bb2
2 1b9e 1bb3 1
1bba 1 1bb5 2
1bcd 1bcf 3 1bcb
1bcc 1bd1 2 1bda
1bdc 2 1bde 1be0
2 1be2 1be4 2
1be6 1be8 2 1bea
1bec 3 1bf1 1bf2
1bf3 2 1bee 1bf5
2 1bd9 1bf7 1
1bf9 1 1bfb 2
1bc4 1bfc 1 1c00
1 1bbf 2 1bbd
1c04 1 1c07 1
1c12 2 1c11 1c12
1 1c1a 1 1c20
2 1c22 1c23 2
1c0f 1c24 1 1c2b
1 1c26 2 1c3e
1c40 3 1c3c 1c3d
1c42 2 1c4b 1c4d
2 1c4f 1c51 2
1c53 1c55 2 1c57
1c59 2 1c5b 1c5d
3 1c62 1c63 1c64
2 1c5f 1c66 2
1c4a 1c68 1 1c6a
1 1c6c 2 1c35
1c6d 1 1c71 1
1c30 2 1c2e 1c75
1 1c80 2 1c7f
1c80 1 1c88 1
1c8e 2 1c90 1c91
2 1c7d 1c92 1
1c99 1 1c94 2
1cac 1cae 3 1caa
1cab 1cb0 2 1cb9
1cbb 2 1cbd 1cbf
2 1cc1 1cc3 2
1cc5 1cc7 2 1cc9
1ccb 3 1cd0 1cd1
1cd2 2 1ccd 1cd4
2 1cb8 1cd6 1
1cd8 1 1cda 2
1ca3 1cdb 1 1cdf
1 1c9e 2 1c9c
1ce3 1 1cee 2
1ced 1cee 1 1cf6
1 1cfc 2 1cfe
1cff 2 1ceb 1d00
1 1d07 1 1d02
2 1d1a 1d1c 3
1d18 1d19 1d1e 2
1d27 1d29 2 1d2b
1d2d 2 1d2f 1d31
2 1d33 1d35 2
1d37 1d39 3 1d3e
1d3f 1d40 2 1d3b
1d42 2 1d26 1d44
1 1d46 1 1d48
2 1d11 1d49 1
1d4d 1 1d0c 2
1d0a 1d51 1 1d5e
2 1d5d 1d5e 1
1d66 1 1d6c 2
1d6e 1d6f 2 1d5b
1d70 1 1d77 1
1d72 2 1d8a 1d8c
3 1d88 1d89 1d8e
2 1d97 1d99 2
1d9b 1d9d 2 1d9f
1da1 2 1da3 1da5
2 1da7 1da9 3
1dae 1daf 1db0 2
1dab 1db2 2 1d96
1db4 1 1db6 1
1db8 2 1d81 1db9
1 1dbd 1 1d7c
2 1d7a 1dc1 4
1c78 1ce6 1d54 1dc4
2 1dc7 1dc8 4
1aa8 1aab 1b8d 1dc9
1 1dcb 3 1a8a
1a9c 1dcc 1 1dce
3 197e 19f3 1dcf
2 1dd3 1dd4 1
1dd8 2 1dd6 1dd8
1 1dda 2 1ddf
1de0 1 1de4 2
1de2 1de4 2 1df1
1df3 3 1def 1df0
1df5 2 1dfe 1e00
2 1e02 1e04 2
1e06 1e08 1 1e10
2 1e12 1e13 2
1e0a 1e15 2 1e17
1e19 2 1e1b 1e1d
2 1e1f 1e21 2
1e23 1e25 2 1dfd
1e27 1 1e29 1
1e2b 2 1e35 1e37
3 1e33 1e34 1e39
2 1e42 1e44 2
1e41 1e46 1 1e48
1 1e4a 3 1e51
1e52 1e53 3 1e2c
1e4b 1e55 2 1e58
1e57 1 1e5c 2
1e5a 1e5c 2 1e63
1e64 1 1e68 2
1e66 1e68 2 1e6d
1e6e 1 1e72 2
1e70 1e72 2 1e79
1e7a 1 1e7e 2
1e7c 1e7e 1 1ea2
2 1ea1 1ea2 1
1eaa 1 1eb0 2
1eb2 1eb3 2 1e9f
1eb4 1 1ebb 1
1eb6 2 1ece 1ed0
3 1ecc 1ecd 1ed2
2 1edb 1edd 2
1edf 1ee1 2 1ee3
1ee5 2 1ee7 1ee9
2 1eeb 1eed 3
1ef2 1ef3 1ef4 2
1eef 1ef6 2 1eda
1ef8 1 1efa 1
1efc 2 1ec5 1efd
1 1f01 1 1ec0
2 1ebe 1f05 1
1f08 1 1f30 2
1f2f 1f30 1 1f38
1 1f3e 2 1f40
1f41 2 1f2d 1f42
1 1f49 1 1f44
2 1f5c 1f5e 3
1f5a 1f5b 1f60 2
1f69 1f6b 2 1f6d
1f6f 2 1f71 1f73
2 1f75 1f77 2
1f79 1f7b 3 1f80
1f81 1f82 2 1f7d
1f84 2 1f68 1f86
1 1f88 1 1f8a
2 1f53 1f8b 1
1f8f 1 1f4e 2
1f4c 1f93 1 1f96
2 1f99 1f9a 1
1f9b 2 1f9f 1fa0
1 1fa4 2 1fa2
1fa4 1 1fc4 2
1fc3 1fc4 1 1fcc
1 1fd2 2 1fd4
1fd5 2 1fc1 1fd6
1 1fdd 1 1fd8
2 1ff0 1ff2 3
1fee 1fef 1ff4 2
1ffd 1fff 2 2001
2003 2 2005 2007
2 2009 200b 2
200d 200f 3 2014
2015 2016 2 2011
2018 2 1ffc 201a
1 201c 1 201e
2 1fe7 201f 1
2023 1 1fe2 2
1fe0 2027 1 202a
2 2030 2031 1
2035 2 2033 2035
2 2039 203a 1
203e 2 203c 203e
1 205a 2 2059
205a 1 2062 1
2068 2 206a 206b
2 2057 206c 1
2073 1 206e 2
2086 2088 3 2084
2085 208a 2 2093
2095 2 2097 2099
2 209b 209d 2
209f 20a1 2 20a3
20a5 3 20aa 20ab
20ac 2 20a7 20ae
2 2092 20b0 1
20b2 1 20b4 2
207d 20b5 1 20b9
1 2078 2 2076
20bd 1 20c0 1
20e0 2 20df 20e0
1 20e8 1 20ee
2 20f0 20f1 2
20dd 20f2 1 20f9
1 20f4 2 210c
210e 3 210a 210b
2110 2 2119 211b
2 211d 211f 2
2121 2123 2 2125
2127 2 2129 212b
3 2130 2131 2132
2 212d 2134 2
2118 2136 1 2138
1 213a 2 2103
213b 1 213f 1
20fe 2 20fc 2143
1 2146 2 2149
214a 1 214b 1
215d 2 215c 215d
1 2165 1 216b
2 216d 216e 2
215a 216f 1 2176
1 2171 2 2189
218b 3 2187 2188
218d 2 2196 2198
2 219a 219c 2
219e 21a0 2 21a2
21a4 2 21a6 21a8
3 21ad 21ae 21af
2 21aa 21b1 2
2195 21b3 1 21b5
1 21b7 2 2180
21b8 1 21bc 1
217b 2 2179 21c0
1 21c3 4 21c6
202e 214d 21c7 1
21d1 2 21d0 21d1
1 21d9 1 21df
2 21e1 21e2 2
21ce 21e3 1 21ea
1 21e5 2 21fd
21ff 3 21fb 21fc
2201 2 220a 220c
2 220e 2210 2
2212 2214 2 2216
2218 2 221a 221c
3 2221 2222 2223
2 221e 2225 2
2209 2227 1 2229
1 222b 2 21f4
222c 1 2230 1
21ef 2 21ed 2234
1 223f 2 223e
223f 1 2247 1
224d 2 224f 2250
2 223c 2251 1
2258 1 2253 2
226b 226d 3 2269
226a 226f 2 2278
227a 2 227c 227e
2 2280 2282 2
2284 2286 2 2288
228a 3 228f 2290
2291 2 228c 2293
2 2277 2295 1
2297 1 2299 2
2262 229a 1 229e
1 225d 2 225b
22a2 1 22af 2
22ae 22af 1 22b7
1 22bd 2 22bf
22c0 2 22ac 22c1
1 22c8 1 22c3
2 22db 22dd 3
22d9 22da 22df 2
22e8 22ea 2 22ec
22ee 2 22f0 22f2
2 22f4 22f6 2
22f8 22fa 3 22ff
2300 2301 2 22fc
2303 2 22e7 2305
1 2307 1 2309
2 22d2 230a 1
230e 1 22cd 2
22cb 2312 5 1e61
21c8 2237 22a5 2315
1 2318 1 231c
2 231a 231c 2
2320 2321 1 2325
2 2323 2325 1
232c 2 2333 2334
2 2336 2339 1
233c 2 233e 233f
2 2345 2346 1
234a 2 2348 234a
2 234e 234f 2
2354 2355 1 2357
2 2351 2357 2
235c 235d 1 2360
1 2362 2 236d
236e 1 2372 2
2370 2372 1 2377
1 237b 2 237d
237e 2 2381 2382
1 2386 2 2384
2386 1 238b 1
238d 2 2394 2395
2 2399 239a 2
239e 239f 2 23a3
23a4 2 23a8 23a9
2 23ad 23ae 2
23b2 23b3 2 23b7
23b8 d 2391 2392
2397 239c 23a1 23a6
23ab 23b0 23b5 23ba
23bb 23bc 23bd 2
23c2 23c3 1 23c9
2 23c5 23c9 2
23d4 23d6 3 23d2
23d3 23d8 2 23e1
23e3 2 23e5 23e7
2 23e9 23eb 1
23f3 2 23f5 23f6
2 23ed 23f8 2
23e0 23fa 1 23fc
1 23fe 2 2408
240a 3 2406 2407
240c 2 2415 2417
2 2414 2419 1
241b 1 241d 2
2424 2425 3 23ff
241e 2427 2 242b
242c 1 2430 2
242e 2430 2 243b
243d 3 2439 243a
243f 2 2448 244a
2 244c 244e 2
2450 2452 1 2458
2 245a 245b 2
2454 245d 2 245f
2461 2 2463 2465
2 2467 2469 2
246b 246d 2 2447
246f 1 2471 1
2473 2 247d 247f
3 247b 247c 2481
2 248a 248c 2
2489 248e 1 2490
1 2492 2 2498
2499 3 249b 249c
249d 3 2474 2493
249f 2 24a2 24a1
21 24a9 24aa 24ab
24ac 24ad 24ae 24af
24b0 24b1 24b2 24b3
24b4 24b5 24b6 24b7
24b8 24b9 24ba 24bb
24bc 24bd 24be 24bf
24c0 24c1 24c2 24c3
24c4 24c5 24c6 24c7
24c8 24c9 1 24cf
2 24cd 24cf 2
24da 24dc 3 24d8
24d9 24de 2 24e7
24e9 2 24eb 24ed
2 24ef 24f1 1
24f9 2 24fb 24fc
2 24f3 24fe 2
2500 2502 2 2504
2506 2 2508 250a
2 250c 250e 2
24e6 2510 1 2512
1 2514 2 251e
2520 3 251c 251d
2522 2 252b 252d
2 252a 252f 1
2531 1 2533 3
253a 253b 253c 3
2515 2534 253e 1
2543 2 2541 2543
2 254e 2550 3
254c 254d 2552 2
255b 255d 2 255f
2561 2 2563 2565
1 256d 2 256f
2570 2 2567 2572
2 2574 2576 2
2578 257a 2 257c
257e 2 2580 2582
2 255a 2584 1
2586 1 2588 2
2592 2594 3 2590
2591 2596 2 259f
25a1 2 259e 25a3
1 25a5 1 25a7
3 25ae 25af 25b0
3 2589 25a8 25b2
2 25be 25bf 2
25c3 25c4 5 25ba
25bb 25bc 25c1 25c6
2 25b7 25c9 3
25cb 25b4 25cc a
2363 2366 2369 237f
238e 23c0 24a3 24a6
24cc 25cd 1 25cf
3 2340 2343 25d0
1 25d2 2 25e1
25e6 1 25ed 1
25e8 2 2600 2602
3 25fe 25ff 2604
2 260d 260f 2
2611 2613 2 2615
2617 2 2619 261b
2 261d 261f 3
2624 2625 2626 2
2621 2628 2 260c
262a 1 262c 1
262e 2 25f7 262f
1 2633 1 25f2
2 25f0 2637 7
1952 1955 1e59 2319
25d3 25d8 263a 1
263d 6 17bf 183c
1869 186c 1945 263e
1 2640 2 2641
2644 1 2646 2
264a 264c 3 264e
264f 2650 2 265f
2664 1 266b 1
2666 2 267e 2680
3 267c 267d 2682
2 268b 268d 2
268f 2691 2 2693
2695 2 2697 2699
2 269b 269d 3
26a2 26a3 26a4 2
269f 26a6 2 268a
26a8 1 26aa 1
26ac 2 2675 26ad
1 26b1 1 2670
2 266e 26b5 15
26cd 26ce 26cf 26d0
26d1 26d2 26d3 26d4
26d5 26d6 26d7 26d8
26d9 26da 26db 26dc
26dd 26de 26df 26e0
26e1 1 26ec 1
26f2 2 26f4 26f5
1 26fd 2 26f9
26fd 1 2702 1
2704 2 270a 270b
1 270f 2 270d
270f 2 2714 2715
1 271f 2 271e
271f 1 2727 1
272d 2 272f 2730
2 271c 2731 1
2738 1 2733 2
274b 274d 3 2749
274a 274f 2 2758
275a 2 275c 275e
2 2760 2762 2
2764 2766 2 2768
276a 3 276f 2770
2771 2 276c 2773
2 2757 2775 1
2777 1 2779 2
2742 277a 1 277e
1 273d 2 273b
2782 1 278d 2
278c 278d 1 2795
1 279b 2 279d
279e 2 278a 279f
1 27a6 1 27a1
2 27b9 27bb 3
27b7 27b8 27bd 2
27c6 27c8 2 27ca
27cc 2 27ce 27d0
2 27d2 27d4 2
27d6 27d8 3 27dd
27de 27df 2 27da
27e1 2 27c5 27e3
1 27e5 1 27e7
2 27b0 27e8 1
27ec 1 27ab 2
27a9 27f0 1 27fb
2 27fa 27fb 1
2803 1 2809 2
280b 280c 2 27f8
280d 1 2814 1
280f 2 2827 2829
3 2825 2826 282b
2 2834 2836 2
2838 283a 2 283c
283e 2 2840 2842
2 2844 2846 3
284b 284c 284d 2
2848 284f 2 2833
2851 1 2853 1
2855 2 281e 2856
1 285a 1 2819
2 2817 285e 1
286b 2 286a 286b
1 2873 1 2879
2 287b 287c 2
2868 287d 1 2884
1 287f 2 2897
2899 3 2895 2896
289b 2 28a4 28a6
2 28a8 28aa 2
28ac 28ae 2 28b0
28b2 2 28b4 28b6
3 28bb 28bc 28bd
2 28b8 28bf 2
28a3 28c1 1 28c3
1 28c5 2 288e
28c6 1 28ca 1
2889 2 2887 28ce
1 28d9 2 28d8
28d9 1 28e1 1
28e7 2 28e9 28ea
2 28d6 28eb 1
28f2 1 28ed 2
2905 2907 3 2903
2904 2909 2 2912
2914 2 2916 2918
2 291a 291c 2
291e 2920 2 2922
2924 3 2929 292a
292b 2 2926 292d
2 2911 292f 1
2931 1 2933 2
28fc 2934 1 2938
1 28f7 2 28f5
293c 1 2947 2
2946 2947 1 294f
1 2955 2 2957
2958 2 2944 2959
1 2960 1 295b
2 2973 2975 3
2971 2972 2977 2
2980 2982 2 2984
2986 2 2988 298a
2 298c 298e 2
2990 2992 3 2997
2998 2999 2 2994
299b 2 297f 299d
1 299f 1 29a1
2 296a 29a2 1
29a6 1 2965 2
2963 29aa 7 2718
2785 27f3 2861 28d1
293f 29ad 2 29b1
29b2 1 29b6 2
29b4 29b6 1 29bb
1 29bd 1 29cb
2 29ca 29cb 1
29d3 1 29d9 2
29db 29dc 2 29c8
29dd 1 29e4 1
29df 2 29f7 29f9
3 29f5 29f6 29fb
2 2a04 2a06 2
2a08 2a0a 2 2a0c
2a0e 2 2a10 2a12
2 2a14 2a16 3
2a1b 2a1c 2a1d 2
2a18 2a1f 2 2a03
2a21 1 2a23 1
2a25 2 29ee 2a26
1 2a2a 1 29e9
2 29e7 2a2e 1
2a35 a 2a3d 2a3e
2a3f 2a40 2a41 2a42
2a43 2a44 2a45 2a46
2 2a56 2a5b 1
2a62 1 2a5d 2
2a75 2a77 3 2a73
2a74 2a79 2 2a82
2a84 2 2a86 2a88
2 2a8a 2a8c 2
2a8e 2a90 2 2a92
2a94 3 2a99 2a9a
2a9b 2 2a96 2a9d
2 2a81 2a9f 1
2aa1 1 2aa3 2
2a6c 2aa4 1 2aa8
1 2a67 2 2a65
2aac 1 2ab7 2
2ab3 2ab7 2 2aca
2acf 1 2ad6 1
2ad1 2 2ae9 2aeb
3 2ae7 2ae8 2aed
2 2af6 2af8 2
2afa 2afc 2 2afe
2b00 2 2b02 2b04
2 2b06 2b08 3
2b0d 2b0e 2b0f 2
2b0a 2b11 2 2af5
2b13 1 2b15 1
2b17 2 2ae0 2b18
1 2b1c 1 2adb
2 2ad9 2b20 1
2b2b 2 2b27 2b2b
2 2b31 2b32 2
2b34 2b37 1 2b3e
2 2b3a 2b3e 1
2b4f 2 2b4e 2b4f
1 2b57 1 2b5d
2 2b5f 2b60 2
2b4c 2b61 1 2b68
1 2b63 2 2b7b
2b7d 3 2b79 2b7a
2b7f 2 2b88 2b8a
2 2b8c 2b8e 2
2b90 2b92 2 2b94
2b96 2 2b98 2b9a
3 2b9f 2ba0 2ba1
2 2b9c 2ba3 2
2b87 2ba5 1 2ba7
1 2ba9 2 2b72
2baa 1 2bae 1
2b6d 2 2b6b 2bb2
2 2b43 2bb5 2
2bba 2bbb 1 2bc1
2 2bbd 2bc1 2
2bc8 2bc9 4 2bc6
2bcb 2bce 2bcf 1
2be3 2 2be2 2be3
1 2beb 1 2bf1
2 2bf3 2bf4 2
2be0 2bf5 1 2bfc
1 2bf7 2 2c0f
2c11 3 2c0d 2c0e
2c13 2 2c1c 2c1e
2 2c20 2c22 2
2c24 2c26 2 2c28
2c2a 2 2c2c 2c2e
3 2c33 2c34 2c35
2 2c30 2c37 2
2c1b 2c39 1 2c3b
1 2c3d 2 2c06
2c3e 1 2c42 1
2c01 2 2bff 2c46
2 2bd2 2c49 1
2c60 2 2c5f 2c60
1 2c68 1 2c6e
2 2c70 2c71 2
2c5d 2c72 1 2c79
1 2c74 2 2c8c
2c8e 3 2c8a 2c8b
2c90 2 2c99 2c9b
2 2c9d 2c9f 2
2ca1 2ca3 2 2ca5
2ca7 2 2ca9 2cab
3 2cb0 2cb1 2cb2
2 2cad 2cb4 2
2c98 2cb6 1 2cb8
1 2cba 2 2c83
2cbb 1 2cbf 1
2c7e 2 2c7c 2cc3
1 2cc6 3 2cc9
2c4c 2cca 1 2cd2
2 2cce 2cd2 2
2cd7 2cd8 1 2cdc
2 2cda 2cdc 1
2ce8 2 2ce7 2ce8
1 2cf0 1 2cf6
2 2cf8 2cf9 2
2ce5 2cfa 1 2d01
1 2cfc 2 2d14
2d16 3 2d12 2d13
2d18 2 2d21 2d23
2 2d25 2d27 2
2d29 2d2b 2 2d2d
2d2f 2 2d31 2d33
3 2d38 2d39 2d3a
2 2d35 2d3c 2
2d20 2d3e 1 2d40
1 2d42 2 2d0b
2d43 1 2d47 1
2d06 2 2d04 2d4b
1 2d4e 1 2d51
2 2ccb 2d52 2
2d76 2d7b 1 2d82
1 2d7d 2 2d95
2d97 3 2d93 2d94
2d99 2 2da2 2da4
2 2da6 2da8 2
2daa 2dac 2 2dae
2db0 2 2db2 2db4
3 2db9 2dba 2dbb
2 2db6 2dbd 2
2da1 2dbf 1 2dc1
1 2dc3 2 2d8c
2dc4 1 2dc8 1
2d87 2 2d85 2dcc
1 2dd7 2 2dd3
2dd7 1 2ddb 2
2de7 2de8 4 2de5
2dea 2ded 2dee 1
2df8 2 2df7 2df8
1 2e00 1 2e06
2 2e08 2e09 2
2df5 2e0a 1 2e11
1 2e0c 2 2e24
2e26 3 2e22 2e23
2e28 2 2e31 2e33
2 2e35 2e37 2
2e39 2e3b 2 2e3d
2e3f 2 2e41 2e43
3 2e48 2e49 2e4a
2 2e45 2e4c 2
2e30 2e4e 1 2e50
1 2e52 2 2e1b
2e53 1 2e57 1
2e16 2 2e14 2e5b
1 2e6e 2 2e6d
2e6e 1 2e76 1
2e7c 2 2e7e 2e7f
2 2e6b 2e80 1
2e87 1 2e82 2
2e9a 2e9c 3 2e98
2e99 2e9e 2 2ea7
2ea9 2 2eab 2ead
2 2eaf 2eb1 2
2eb3 2eb5 2 2eb7
2eb9 3 2ebe 2ebf
2ec0 2 2ebb 2ec2
2 2ea6 2ec4 1
2ec6 1 2ec8 2
2e91 2ec9 1 2ecd
1 2e8c 2 2e8a
2ed1 1 2ee1 2
2ee0 2ee1 1 2ee9
1 2eef 2 2ef1
2ef2 2 2ede 2ef3
1 2efa 1 2ef5
2 2f0d 2f0f 3
2f0b 2f0c 2f11 2
2f1a 2f1c 2 2f1e
2f20 2 2f22 2f24
2 2f26 2f28 2
2f2a 2f2c 3 2f31
2f32 2f33 2 2f2e
2f35 2 2f19 2f37
1 2f39 1 2f3b
2 2f04 2f3c 1
2f40 1 2eff 2
2efd 2f44 4 2df1
2e5e 2ed4 2f47 1
2f55 2 2f54 2f55
1 2f5d 1 2f63
2 2f65 2f66 2
2f52 2f67 1 2f6e
1 2f69 2 2f81
2f83 3 2f7f 2f80
2f85 2 2f8e 2f90
2 2f92 2f94 2
2f96 2f98 2 2f9a
2f9c 2 2f9e 2fa0
3 2fa5 2fa6 2fa7
2 2fa2 2fa9 2
2f8d 2fab 1 2fad
1 2faf 2 2f78
2fb0 1 2fb4 1
2f73 2 2f71 2fb8
1 2fc6 2 2fc5
2fc6 1 2fce 1
2fd4 2 2fd6 2fd7
2 2fc3 2fd8 1
2fdf 1 2fda 2
2ff2 2ff4 3 2ff0
2ff1 2ff6 2 2fff
3001 2 3003 3005
2 3007 3009 2
300b 300d 2 300f
3011 3 3016 3017
3018 2 3013 301a
2 2ffe 301c 1
301e 1 3020 2
2fe9 3021 1 3025
1 2fe4 2 2fe2
3029 2 2fbb 302c
2 302f 3030 2
2dcf 3031 2 3033
3034 1 303e 2
303d 303e 1 3046
1 304c 2 304e
304f 2 303b 3050
1 3057 1 3052
2 306a 306c 3
3068 3069 306e 2
3077 3079 2 307b
307d 2 307f 3081
2 3083 3085 2
3087 3089 3 308e
308f 3090 2 308b
3092 2 3076 3094
1 3096 1 3098
2 3061 3099 1
309d 1 305c 2
305a 30a1 4 2abd
2b23 3035 30a4 1
30b0 2 30af 30b0
1 30b8 1 30be
2 30c0 30c1 2
30ad 30c2 1 30c9
1 30c4 2 30dc
30de 3 30da 30db
30e0 2 30e9 30eb
2 30ed 30ef 2
30f1 30f3 2 30f5
30f7 2 30f9 30fb
3 3100 3101 3102
2 30fd 3104 2
30e8 3106 1 3108
1 310a 2 30d3
310b 1 310f 1
30ce 2 30cc 3113
1 311e 2 311d
311e 1 3126 1
312c 2 312e 312f
2 311b 3130 1
3137 1 3132 2
314a 314c 3 3148
3149 314e 2 3157
3159 2 315b 315d
2 315f 3161 2
3163 3165 2 3167
3169 3 316e 316f
3170 2 316b 3172
2 3156 3174 1
3176 1 3178 2
3141 3179 1 317d
1 313c 2 313a
3181 1 318e 2
318d 318e 1 3196
1 319c 2 319e
319f 2 318b 31a0
1 31a7 1 31a2
2 31ba 31bc 3
31b8 31b9 31be 2
31c7 31c9 2 31cb
31cd 2 31cf 31d1
2 31d3 31d5 2
31d7 31d9 3 31de
31df 31e0 2 31db
31e2 2 31c6 31e4
1 31e6 1 31e8
2 31b1 31e9 1
31ed 1 31ac 2
31aa 31f1 3 31f7
31f8 31f9 1 31fd
2 31fb 31fd 1
3202 1 3204 6
30a9 3116 3184 31f4
3205 3208 2 320a
320b 2 320e 320f
1 3213 2 3211
3213 2 3217 3218
1 321c 2 321a
321c 1 3220 2
322f 3234 1 323b
1 3236 2 324e
3250 3 324c 324d
3252 2 325b 325d
2 325f 3261 2
3263 3265 2 3267
3269 2 326b 326d
3 3272 3273 3274
2 326f 3276 2
325a 3278 1 327a
1 327c 2 3245
327d 1 3281 1
3240 2 323e 3285
1 3290 2 328c
3290 2 3295 3296
1 329a 2 3298
329a 1 32a8 2
32a7 32a8 1 32b0
1 32b6 2 32b8
32b9 2 32a5 32ba
1 32c1 1 32bc
2 32d4 32d6 3
32d2 32d3 32d8 2
32e1 32e3 2 32e5
32e7 2 32e9 32eb
2 32ed 32ef 2
32f1 32f3 3 32f8
32f9 32fa 2 32f5
32fc 2 32e0 32fe
1 3300 1 3302
2 32cb 3303 1
3307 1 32c6 2
32c4 330b 1 330e
1 3318 2 3314
3318 2 331d 331e
1 3322 2 3320
3322 2 332a 3330
1 3337 1 3332
2 334a 334c 3
3348 3349 334e 2
3357 3359 2 335b
335d 2 335f 3361
2 3363 3365 2
3367 3369 3 336e
336f 3370 2 336b
3372 2 3356 3374
1 3376 1 3378
2 3341 3379 1
337d 1 333c 2
333a 3381 2 338e
3390 3 338c 338d
3392 2 339b 339d
2 339f 33a1 2
33a3 33a5 1 33ad
2 33af 33b0 2
33a7 33b2 2 33b4
33b6 2 33b8 33ba
2 33bc 33be 2
33c0 33c2 2 339a
33c4 1 33c6 1
33c8 2 33d2 33d4
3 33d0 33d1 33d6
2 33df 33e1 2
33de 33e3 1 33e5
1 33e7 3 33ee
33ef 33f0 4 3384
33c9 33e8 33f2 2
33f5 33f4 2 3288
33f6 1 33f8 2
33fb 33fc 1 3402
2 33fe 3402 2
3406 3407 1 340d
2 3409 340d 2
341d 341e 1 3422
2 3420 3422 2
3426 3427 1 342b
2 3429 342b 1
3443 2 3442 3443
1 344b 1 3451
2 3453 3454 2
3440 3455 1 345c
1 3457 2 346f
3471 3 346d 346e
3473 2 347c 347e
2 3480 3482 2
3484 3486 2 3488
348a 2 348c 348e
3 3493 3494 3495
2 3490 3497 2
347b 3499 1 349b
1 349d 2 3466
349e 1 34a2 1
3461 2 345f 34a6
1 34a9 1 34cb
2 34ca 34cb 1
34d3 1 34d9 2
34db 34dc 2 34c8
34dd 1 34e4 1
34df 2 34f7 34f9
3 34f5 34f6 34fb
2 3504 3506 2
3508 350a 2 350c
350e 2 3510 3512
2 3514 3516 3
351b 351c 351d 2
3518 351f 2 3503
3521 1 3523 1
3525 2 34ee 3526
1 352a 1 34e9
2 34e7 352e 1
3531 2 3534 3535
1 353d 2 3539
353d 2 354b 3550
1 3557 1 3552
2 356a 356c 3
3568 3569 356e 2
3577 3579 2 357b
357d 2 357f 3581
2 3583 3585 2
3587 3589 3 358e
358f 3590 2 358b
3592 2 3576 3594
1 3596 1 3598
2 3561 3599 1
359d 1 355c 2
355a 35a1 2 35a7
35a8 1 35ac 2
35aa 35ac 1 35b0
1 35ba 2 35b9
35ba 1 35c2 1
35c8 2 35ca 35cb
2 35b7 35cc 1
35d3 1 35ce 2
35e6 35e8 3 35e4
35e5 35ea 2 35f3
35f5 2 35f7 35f9
2 35fb 35fd 2
35ff 3601 2 3603
3605 3 360a 360b
360c 2 3607 360e
2 35f2 3610 1
3612 1 3614 2
35dd 3615 1 3619
1 35d8 2 35d6
361d 1 3626 2
3628 3629 1 362f
2 3631 3632 2
362b 3634 2 3637
3639 1 363b 2
3648 364d 1 3654
1 364f 2 3667
3669 3 3665 3666
366b 2 3674 3676
2 3678 367a 2
367c 367e 2 3680
3682 2 3684 3686
3 368b 368c 368d
2 3688 368f 2
3673 3691 1 3693
1 3695 2 365e
3696 1 369a 1
3659 2 3657 369e
2 36a4 36a5 2
36aa 36ab 1 36ad
2 36a7 36ad 2
36b4 36b5 2 36b7
36b8 1 36ba 1
36bc 1 36d7 2
36d6 36d7 1 36df
1 36e5 2 36e7
36e8 2 36d4 36e9
1 36f0 1 36eb
2 3703 3705 3
3701 3702 3707 2
3710 3712 2 3714
3716 2 3718 371a
2 371c 371e 2
3720 3722 3 3727
3728 3729 2 3724
372b 2 370f 372d
1 372f 1 3731
2 36fa 3732 1
3736 1 36f5 2
36f3 373a 5 3620
363e 36a1 36bd 373d
2 3740 3741 1
3765 2 3764 3765
1 376d 1 3773
2 3775 3776 2
3762 3777 1 377e
1 3779 2 3791
3793 3 378f 3790
3795 2 379e 37a0
2 37a2 37a4 2
37a6 37a8 2 37aa
37ac 2 37ae 37b0
3 37b5 37b6 37b7
2 37b2 37b9 2
379d 37bb 1 37bd
1 37bf 2 3788
37c0 1 37c4 1
3783 2 3781 37c8
1 37d1 2 37d3
37d4 1 37da 2
37dc 37dd 2 37d6
37df 2 37e2 37e4
1 37e6 2 37ef
37f0 2 37f2 37f5
2 37ff 3800 2
3804 3805 5 37fb
37fc 37fd 3802 3807
7 3543 35a4 3742
37cb 37e9 37f8 380a
1 380d 2 380f
3810 4 3416 341b
3536 3811 1 3818
2 3816 3818 2
381c 381d 1 3821
2 381f 3821 2
3828 3829 1 382d
2 382b 382d 2
3831 3832 1 3836
2 3834 3836 2
383c 383d 1 3841
2 383f 3841 2
384b 384c 2 3848
384f 1 3851 1
3862 2 3861 3862
1 386a 1 3870
2 3872 3873 2
385f 3874 1 387b
1 3876 2 388e
3890 3 388c 388d
3892 2 389b 389d
2 389f 38a1 2
38a3 38a5 2 38a7
38a9 2 38ab 38ad
3 38b2 38b3 38b4
2 38af 38b6 2
389a 38b8 1 38ba
1 38bc 2 3885
38bd 1 38c1 1
3880 2 387e 38c5
3 3826 3852 38c8
2 38e8 38e9 2
38eb 38ee 1 38f3
2 38f1 38f3 2
38f8 38f9 2 38fe
38ff 1 3901 2
38fb 3901 2 3905
3906 2 390b 390c
1 390e 2 3908
390e 2 3917 3918
1 391c 2 391a
391c 1 3947 2
3946 3947 1 394f
1 3955 2 3957
3958 2 3944 3959
1 3960 1 395b
2 3973 3975 3
3971 3972 3977 2
3980 3982 2 3984
3986 2 3988 398a
2 398c 398e 2
3990 3992 3 3997
3998 3999 2 3994
399b 2 397f 399d
1 399f 1 39a1
2 396a 39a2 1
39a6 1 3965 2
3963 39aa 1 39ad
1 39da 2 39d9
39da 1 39e2 1
39e8 2 39ea 39eb
2 39d7 39ec 1
39f3 1 39ee 2
3a06 3a08 3 3a04
3a05 3a0a 2 3a13
3a15 2 3a17 3a19
2 3a1b 3a1d 2
3a1f 3a21 2 3a23
3a25 3 3a2a 3a2b
3a2c 2 3a27 3a2e
2 3a12 3a30 1
3a32 1 3a34 2
39fd 3a35 1 3a39
1 39f8 2 39f6
3a3d 1 3a40 2
3a43 3a44 1 3a45
1 3a6b 2 3a6a
3a6b 1 3a73 1
3a79 2 3a7b 3a7c
2 3a68 3a7d 1
3a84 1 3a7f 2
3a97 3a99 3 3a95
3a96 3a9b 2 3aa4
3aa6 2 3aa8 3aaa
2 3aac 3aae 2
3ab0 3ab2 2 3ab4
3ab6 3 3abb 3abc
3abd 2 3ab8 3abf
2 3aa3 3ac1 1
3ac3 1 3ac5 2
3a8e 3ac6 1 3aca
1 3a89 2 3a87
3ace 1 3ad1 2
3ad4 3ad5 2 3ad8
3ad9 1 3add 2
3adb 3add 2 3ae2
3ae3 1 3ae7 2
3ae5 3ae7 1 3aef
2 3af3 3af4 1
3af8 2 3af6 3af8
2 3afd 3afe 1
3b01 2 3b04 3b03
b 38cd 38d0 38d3
38d6 38d9 38dc 38df
38e2 38e5 3ad6 3b05
2 3b07 3b08 2
3b0f 3b10 2 3b14
3b15 2 3b19 3b1a
2 3b1e 3b1f 2
3b23 3b24 2 3b28
3b29 2 3b2d 3b2e
2 3b32 3b33 d
3b0c 3b0d 3b12 3b17
3b1c 3b21 3b26 3b2b
3b30 3b35 3b36 3b37
3b38 2 3b3d 3b3e
1 3b44 2 3b40
3b44 2 3b49 3b4f
1 3b56 1 3b51
2 3b69 3b6b 3
3b67 3b68 3b6d 2
3b76 3b78 2 3b7a
3b7c 2 3b7e 3b80
2 3b82 3b84 2
3b86 3b88 3 3b8d
3b8e 3b8f 2 3b8a
3b91 2 3b75 3b93
1 3b95 1 3b97
2 3b60 3b98 1
3b9c 1 3b5b 2
3b59 3ba0 2 3bad
3baf 3 3bab 3bac
3bb1 2 3bba 3bbc
2 3bbe 3bc0 2
3bc2 3bc4 1 3bcc
2 3bce 3bcf 2
3bc6 3bd1 2 3bb9
3bd3 1 3bd5 1
3bd7 2 3be1 3be3
3 3bdf 3be0 3be5
2 3bee 3bf0 2
3bed 3bf2 1 3bf4
1 3bf6 2 3bfd
3bfe 4 3ba3 3bd8
3bf7 3c00 2 3c04
3c05 1 3c09 2
3c07 3c09 2 3c0e
3c14 1 3c1b 1
3c16 2 3c2e 3c30
3 3c2c 3c2d 3c32
2 3c3b 3c3d 2
3c3f 3c41 2 3c43
3c45 2 3c47 3c49
2 3c4b 3c4d 3
3c52 3c53 3c54 2
3c4f 3c56 2 3c3a
3c58 1 3c5a 1
3c5c 2 3c25 3c5d
1 3c61 1 3c20
2 3c1e 3c65 2
3c72 3c74 3 3c70
3c71 3c76 2 3c7f
3c81 2 3c83 3c85
2 3c87 3c89 1
3c8f 2 3c91 3c92
2 3c8b 3c94 2
3c96 3c98 2 3c9a
3c9c 2 3c9e 3ca0
2 3ca2 3ca4 2
3c7e 3ca6 1 3ca8
1 3caa 2 3cb4
3cb6 3 3cb2 3cb3
3cb8 2 3cc1 3cc3
2 3cc0 3cc5 1
3cc7 1 3cc9 2
3ccf 3cd0 3 3cd2
3cd3 3cd4 4 3c68
3cab 3cca 3cd6 2
3cd9 3cd8 3 3b09
3b3b 3cda 2 3cdd
3cde 1 3ce2 2
3ce0 3ce2 2 3ce6
3ce7 1 3ceb 2
3ce9 3ceb 2 3cf1
3cf2 1 3cf6 2
3cf4 3cf6 2 3d00
3d01 2 3cfd 3d04
1 3d06 2 3d09
3d0a 1 3d0e 2
3d0c 3d0e 2 3d13
3d14 2 3d19 3d1a
1 3d1c 2 3d16
3d1c 2 3d24 3d25
1 3d28 2 3d2d
3d2e 2 3d33 3d34
2 3d30 3d36 1
3d38 1 3d3b 2
3d3d 3d3e 2 3d41
3d42 1 3d46 2
3d44 3d46 2 3d4b
3d4c 2 3d4e 3d50
1 3d53 2 3d59
3d5a 1 3d5c 2
3d5e 3d60 1 3d62
1 3d65 2 3d67
3d68 2 3d6b 3d6c
1 3d70 2 3d6e
3d70 1 3d82 2
3d81 3d82 1 3d8a
1 3d90 2 3d92
3d93 2 3d7f 3d94
1 3d9b 1 3d96
2 3dae 3db0 3
3dac 3dad 3db2 2
3dbb 3dbd 2 3dbf
3dc1 2 3dc3 3dc5
2 3dc7 3dc9 2
3dcb 3dcd 3 3dd2
3dd3 3dd4 2 3dcf
3dd6 2 3dba 3dd8
1 3dda 1 3ddc
2 3da5 3ddd 1
3de1 1 3da0 2
3d9e 3de5 1 3de8
1 3e0f 2 3e0e
3e0f 1 3e17 1
3e1d 2 3e1f 3e20
2 3e0c 3e21 1
3e28 1 3e23 2
3e3b 3e3d 3 3e39
3e3a 3e3f 2 3e48
3e4a 2 3e4c 3e4e
2 3e50 3e52 2
3e54 3e56 2 3e58
3e5a 3 3e5f 3e60
3e61 2 3e5c 3e63
2 3e47 3e65 1
3e67 1 3e69 2
3e32 3e6a 1 3e6e
1 3e2d 2 3e2b
3e72 1 3e75 2
3e78 3e79 4 3d07
3d3f 3d69 3e7a 2
3e7c 3e7d 2 3e83
3e84 1 3e8a 2
3e86 3e8a 1 3e8f
1 3e93 2 3e95
3e96 2 3e99 3e9a
1 3e9e 2 3e9c
3e9e 1 3ea5 2
3eac 3ead 2 3eaf
3eb2 1 3eb5 2
3eb7 3eb8 2 3ebe
3ebf 1 3ec3 2
3ec1 3ec3 2 3ec7
3ec8 1 3ecc 2
3eca 3ecc 2 3ed2
3ed3 2 3ed8 3ed9
2 3ed5 3edb 2
3ede 3ee0 2 3ee3
3ee5 1 3ee7 2
3eec 3eed 2 3ef2
3ef3 1 3ef5 2
3eef 3ef5 2 3efa
3efb 2 3f02 3f03
2 3f05 3f07 2
3f0d 3f0e 2 3f0a
3f10 2 3f12 3f14
1 3f16 2 3efe
3f19 1 3f1b 2
3eea 3f1c 2 3f20
3f21 2 3f26 3f27
1 3f29 2 3f23
3f29 2 3f2e 3f2f
1 3f32 2 3f35
3f34 1 3f36 1
3f38 21 3f3c 3f3d
3f3e 3f3f 3f40 3f41
3f42 3f43 3f44 3f45
3f46 3f47 3f48 3f49
3f4a 3f4b 3f4c 3f4d
3f4e 3f4f 3f50 3f51
3f52 3f53 3f54 3f55
3f56 3f57 3f58 3f59
3f5a 3f5b 3f5c 1
3f62 2 3f60 3f62
2 3f67 3f6d 1
3f74 1 3f6f 2
3f87 3f89 3 3f85
3f86 3f8b 2 3f94
3f96 2 3f98 3f9a
2 3f9c 3f9e 2
3fa0 3fa2 2 3fa4
3fa6 3 3fab 3fac
3fad 2 3fa8 3faf
2 3f93 3fb1 1
3fb3 1 3fb5 2
3f7e 3fb6 1 3fba
1 3f79 2 3f77
3fbe 2 3fcb 3fcd
3 3fc9 3fca 3fcf
2 3fd8 3fda 2
3fdc 3fde 2 3fe0
3fe2 1 3fea 2
3fec 3fed 2 3fe4
3fef 2 3ff1 3ff3
2 3ff5 3ff7 2
3ff9 3ffb 2 3ffd
3fff 2 3fd7 4001
1 4003 1 4005
2 400f 4011 3
400d 400e 4013 2
401c 401e 2 401b
4020 1 4022 1
4024 3 402b 402c
402d 4 3fc1 4006
4025 402f 1 4034
2 4032 4034 2
4039 403f 1 4046
1 4041 2 4059
405b 3 4057 4058
405d 2 4066 4068
2 406a 406c 2
406e 4070 2 4072
4074 2 4076 4078
3 407d 407e 407f
2 407a 4081 2
4065 4083 1 4085
1 4087 2 4050
4088 1 408c 1
404b 2 4049 4090
2 409d 409f 3
409b 409c 40a1 2
40aa 40ac 2 40ae
40b0 2 40b2 40b4
1 40bc 2 40be
40bf 2 40b6 40c1
2 40c3 40c5 2
40c7 40c9 2 40cb
40cd 2 40cf 40d1
2 40a9 40d3 1
40d5 1 40d7 2
40e1 40e3 3 40df
40e0 40e5 2 40ee
40f0 2 40ed 40f2
1 40f4 1 40f6
3 40fd 40fe 40ff
4 4093 40d8 40f7
4101 2 4104 4103
9 3815 3e7e 3e81
3e97 3eb9 3ebc 3f39
3f5f 4105 2 4107
4108 1 4114 2
4113 4114 1 411c
1 4122 2 4124
4125 2 4111 4126
1 412d 1 4128
2 4140 4142 3
413e 413f 4144 2
414d 414f 2 4151
4153 2 4155 4157
2 4159 415b 2
415d 415f 3 4164
4165 4166 2 4161
4168 2 414c 416a
1 416c 1 416e
2 4137 416f 1
4173 1 4132 2
4130 4177 1 4197
2 4196 4197 1
419f 1 41a5 2
41a7 41a8 2 4194
41a9 1 41b0 1
41ab 2 41c3 41c5
3 41c1 41c2 41c7
2 41d0 41d2 2
41d4 41d6 2 41d8
41da 2 41dc 41de
2 41e0 41e2 3
41e7 41e8 41e9 2
41e4 41eb 2 41cf
41ed 1 41ef 1
41f1 2 41ba 41f2
1 41f6 1 41b5
2 41b3 41fa 1
420d 2 420c 420d
1 4215 1 421b
2 421d 421e 2
420a 421f 1 4226
1 4221 2 4239
423b 3 4237 4238
423d 2 4246 4248
2 424a 424c 2
424e 4250 2 4252
4254 2 4256 4258
3 425d 425e 425f
2 425a 4261 2
4245 4263 1 4265
1 4267 2 4230
4268 1 426c 1
422b 2 4229 4270
1 4283 2 4282
4283 1 428b 1
4291 2 4293 4294
2 4280 4295 1
429c 1 4297 2
42af 42b1 3 42ad
42ae 42b3 2 42bc
42be 2 42c0 42c2
2 42c4 42c6 2
42c8 42ca 2 42cc
42ce 3 42d3 42d4
42d5 2 42d0 42d7
2 42bb 42d9 1
42db 1 42dd 2
42a6 42de 1 42e2
1 42a1 2 429f
42e6 2 42ed 42ee
2 42f0 42f2 2
42f8 42f9 2 42fe
42ff 2 42fb 4301
3 430a 430b 430c
3 4315 4316 4317
1 4325 2 4324
4325 1 432d 1
4333 2 4335 4336
2 4322 4337 1
433e 1 4339 2
4351 4353 3 434f
4350 4355 2 435e
4360 2 4362 4364
2 4366 4368 2
436a 436c 2 436e
4370 3 4375 4376
4377 2 4372 4379
2 435d 437b 1
437d 1 437f 2
4348 4380 1 4384
1 4343 2 4341
4388 2 438e 438f
1 4393 2 4391
4393 2 4398 4399
1 439d 2 439b
439d 1 43b7 2
43b6 43b7 1 43bf
1 43c5 2 43c7
43c8 2 43b4 43c9
1 43d0 1 43cb
2 43e3 43e5 3
43e1 43e2 43e7 2
43f0 43f2 2 43f4
43f6 2 43f8 43fa
2 43fc 43fe 2
4400 4402 3 4407
4408 4409 2 4404
440b 2 43ef 440d
1 440f 1 4411
2 43da 4412 1
4416 1 43d5 2
43d3 441a 1 441d
2 4422 4423 1
4427 2 4425 4427
1 443a 2 4439
443a 1 4442 1
4448 2 444a 444b
2 4437 444c 1
4453 1 444e 2
4466 4468 3 4464
4465 446a 2 4473
4475 2 4477 4479
2 447b 447d 2
447f 4481 2 4483
4485 3 448a 448b
448c 2 4487 448e
2 4472 4490 1
4492 1 4494 2
445d 4495 1 4499
1 4458 2 4456
449d 2 44a4 44a5
2 44a0 44a8 2
44ad 44ae 1 44b2
2 44b0 44b2 1
44c5 2 44c4 44c5
1 44cd 1 44d3
2 44d5 44d6 2
44c2 44d7 1 44de
1 44d9 2 44f1
44f3 3 44ef 44f0
44f5 2 44fe 4500
2 4502 4504 2
4506 4508 2 450a
450c 2 450e 4510
3 4515 4516 4517
2 4512 4519 2
44fd 451b 1 451d
1 451f 2 44e8
4520 1 4524 1
44e3 2 44e1 4528
2 452f 4530 2
452b 4533 1 4542
2 4541 4542 1
454a 1 4550 2
4552 4553 2 453f
4554 1 455b 1
4556 2 456e 4570
3 456c 456d 4572
2 457b 457d 2
457f 4581 2 4583
4585 2 4587 4589
2 458b 458d 3
4592 4593 4594 2
458f 4596 2 457a
4598 1 459a 1
459c 2 4565 459d
1 45a1 1 4560
2 455e 45a5 2
45ac 45ad 2 45b3
45b4 3 45a8 45b0
45b7 4 45b9 44ab
4535 45ba e 33f9
4109 417a 41fd 4273
42e9 42f5 4304 4307
430f 4312 431a 438b
45bb 1 45bd 7
29be 2a31 2a38 2a49
2aaf 320c 45be 2
45c0 45c1 3 45c7
45c8 45c9 1 45cd
7 26e2 26f6 2705
2708 45c2 45cc 45d0
2 45d6 45dc 1
45e3 1 45de 2
45f6 45f8 3 45f4
45f5 45fa 2 4603
4605 2 4607 4609
2 460b 460d 2
460f 4611 2 4613
4615 3 461a 461b
461c 2 4617 461e
2 4602 4620 1
4622 1 4624 2
45ed 4625 1 4629
1 45e8 2 45e6
462d 2 4636 4637
1 463b 2 4639
463b 2 4642 4643
2 4648 4649 1
464b 2 4645 464b
2 4650 4651 2
4656 4657 2 4653
4659 2 465e 465f
1 4663 2 4661
4663 2 4668 4669
1 466d 2 466b
466d 1 4673 2
4694 4695 1 4699
2 4697 4699 2
469e 469f 1 46a3
2 46a1 46a3 1
46ab 2 46af 46b0
1 46b4 2 46b2
46b4 2 46b9 46ba
1 46bd 2 46c0
46bf 2 46c7 46c8
2 46cc 46cd 2
46d1 46d2 2 46d6
46d7 2 46db 46dc
2 46e0 46e1 2
46e5 46e6 2 46ea
46eb d 46c4 46c5
46ca 46cf 46d4 46d9
46de 46e3 46e8 46ed
46ee 46ef 46f0 2
46f5 46f6 1 46fc
2 46f8 46fc 2
4707 4709 3 4705
4706 470b 2 4714
4716 2 4718 471a
2 471c 471e 1
4726 2 4728 4729
2 4720 472b 2
4713 472d 1 472f
1 4731 2 473b
473d 3 4739 473a
473f 2 4748 474a
2 4747 474c 1
474e 1 4750 2
4757 4758 3 4732
4751 475a 2 475e
475f 1 4763 2
4761 4763 2 476e
4770 3 476c 476d
4772 2 477b 477d
2 477f 4781 2
4783 4785 1 478b
2 478d 478e 2
4787 4790 2 4792
4794 2 4796 4798
2 479a 479c 2
479e 47a0 2 477a
47a2 1 47a4 1
47a6 2 47b0 47b2
3 47ae 47af 47b4
2 47bd 47bf 2
47bc 47c1 1 47c3
1 47c5 2 47cb
47cc 3 47ce 47cf
47d0 3 47a7 47c6
47d2 2 47d5 47d4
1 47ee 2 47ed
47ee 1 47f6 1
47fc 2 47fe 47ff
2 47eb 4800 1
4807 1 4802 2
481a 481c 3 4818
4819 481e 2 4827
4829 2 482b 482d
2 482f 4831 2
4833 4835 2 4837
4839 3 483e 483f
4840 2 483b 4842
2 4826 4844 1
4846 1 4848 2
4811 4849 1 484d
1 480c 2 480a
4851 2 4866 4867
1 486b 2 4869
486b 2 4873 4874
2 4876 4879 2
487c 487f 1 4883
2 4885 4886 21
488d 488e 488f 4890
4891 4892 4893 4894
4895 4896 4897 4898
4899 489a 489b 489c
489d 489e 489f 48a0
48a1 48a2 48a3 48a4
48a5 48a6 48a7 48a8
48a9 48aa 48ab 48ac
48ad 1 48b3 2
48b1 48b3 2 48be
48c0 3 48bc 48bd
48c2 2 48cb 48cd
2 48cf 48d1 2
48d3 48d5 1 48dd
2 48df 48e0 2
48d7 48e2 2 48e4
48e6 2 48e8 48ea
2 48ec 48ee 2
48f0 48f2 2 48ca
48f4 1 48f6 1
48f8 2 4902 4904
3 4900 4901 4906
2 490f 4911 2
490e 4913 1 4915
1 4917 3 491e
491f 4920 3 48f9
4918 4922 1 4927
2 4925 4927 2
4932 4934 3 4930
4931 4936 2 493f
4941 2 4943 4945
2 4947 4949 1
4951 2 4953 4954
2 494b 4956 2
4958 495a 2 495c
495e 2 4960 4962
2 4964 4966 2
493e 4968 1 496a
1 496c 2 4976
4978 3 4974 4975
497a 2 4983 4985
2 4982 4987 1
4989 1 498b 3
4992 4993 4994 3
496d 498c 4996 1
49b8 2 49b7 49b8
1 49c0 1 49c6
2 49c8 49c9 2
49b5 49ca 1 49d1
1 49cc 2 49e4
49e6 3 49e2 49e3
49e8 2 49f1 49f3
2 49f5 49f7 2
49f9 49fb 2 49fd
49ff 2 4a01 4a03
3 4a08 4a09 4a0a
2 4a05 4a0c 2
49f0 4a0e 1 4a10
1 4a12 2 49db
4a13 1 4a17 1
49d6 2 49d4 4a1b
1 4a1e 3 4a21
4998 4a22 17 467d
4680 4683 4686 4689
468c 468f 4692 46c1
46f3 47d6 47db 47e0
4854 4858 485b 485e
4861 4864 4887 488a
48b0 4a23 1 4a25
2 465c 4a26 1
4a2b 2 4a29 4a2b
2 4a2f 4a30 1
4a34 2 4a32 4a34
1 4a39 1 4a4a
2 4a49 4a4a 1
4a52 1 4a58 2
4a5a 4a5b 2 4a47
4a5c 1 4a63 1
4a5e 2 4a76 4a78
3 4a74 4a75 4a7a
2 4a83 4a85 2
4a87 4a89 2 4a8b
4a8d 2 4a8f 4a91
2 4a93 4a95 3
4a9a 4a9b 4a9c 2
4a97 4a9e 2 4a82
4aa0 1 4aa2 1
4aa4 2 4a6d 4aa5
1 4aa9 1 4a68
2 4a66 4aad 1
4ab0 2 4ab4 4ab3
2 4abe 4ac3 1
4aca 1 4ac5 2
4add 4adf 3 4adb
4adc 4ae1 2 4aea
4aec 2 4aee 4af0
2 4af2 4af4 2
4af6 4af8 2 4afa
4afc 3 4b01 4b02
4b03 2 4afe 4b05
2 4ae9 4b07 1
4b09 1 4b0b 2
4ad4 4b0c 1 4b10
1 4acf 2 4acd
4b14 2 4b1a 4b1b
1 4b1f 2 4b1d
4b1f 1 4b2e 2
4b2d 4b2e 1 4b36
1 4b3c 2 4b3e
4b3f 2 4b2b 4b40
1 4b47 1 4b42
2 4b5a 4b5c 3
4b58 4b59 4b5e 2
4b67 4b69 2 4b6b
4b6d 2 4b6f 4b71
2 4b73 4b75 2
4b77 4b79 3 4b7e
4b7f 4b80 2 4b7b
4b82 2 4b66 4b84
1 4b86 1 4b88
2 4b51 4b89 1
4b8d 1 4b4c 2
4b4a 4b91 1 4b94
1 4b97 4 4640
4ab5 4b17 4b98 1
4b9a 1 4b9f 1
4bb0 2 4baf 4bb0
1 4bb8 1 4bbe
2 4bc0 4bc1 2
4bad 4bc2 1 4bc9
1 4bc4 2 4bdc
4bde 3 4bda 4bdb
4be0 2 4be9 4beb
2 4bed 4bef 2
4bf1 4bf3 2 4bf5
4bf7 2 4bf9 4bfb
3 4c00 4c01 4c02
2 4bfd 4c04 2
4be8 4c06 1 4c08
1 4c0a 2 4bd3
4c0b 1 4c0f 1
4bce 2 4bcc 4c13
2 4c19 4c1a 1
4c1e 2 4c1c 4c1e
2 4c28 4c2d 1
4c34 1 4c2f 2
4c47 4c49 3 4c45
4c46 4c4b 2 4c54
4c56 2 4c58 4c5a
2 4c5c 4c5e 2
4c60 4c62 2 4c64
4c66 3 4c6b 4c6c
4c6d 2 4c68 4c6f
2 4c53 4c71 1
4c73 1 4c75 2
4c3e 4c76 1 4c7a
1 4c39 2 4c37
4c7e 2 4c84 4c85
1 4c89 2 4c87
4c89 1 4c97 2
4c96 4c97 1 4c9f
1 4ca5 2 4ca7
4ca8 2 4c94 4ca9
1 4cb0 1 4cab
2 4cc3 4cc5 3
4cc1 4cc2 4cc7 2
4cd0 4cd2 2 4cd4
4cd6 2 4cd8 4cda
2 4cdc 4cde 2
4ce0 4ce2 3 4ce7
4ce8 4ce9 2 4ce4
4ceb 2 4ccf 4ced
1 4cef 1 4cf1
2 4cba 4cf2 1
4cf6 1 4cb5 2
4cb3 4cfa 1 4d07
2 4d06 4d07 1
4d0f 1 4d15 2
4d17 4d18 2 4d04
4d19 1 4d20 1
4d1b 2 4d33 4d35
3 4d31 4d32 4d37
2 4d40 4d42 2
4d44 4d46 2 4d48
4d4a 2 4d4c 4d4e
2 4d50 4d52 3
4d57 4d58 4d59 2
4d54 4d5b 2 4d3f
4d5d 1 4d5f 1
4d61 2 4d2a 4d62
1 4d66 1 4d25
2 4d23 4d6a 2
4cfd 4d6d 1 4d70
2 4c81 4d71 1
4d73 2 4d76 4d77
1 4d7b 2 4d79
4d7b 5 4d83 4d84
4d85 4d86 4d87 2
4da4 4da9 1 4db0
1 4dab 2 4dc3
4dc5 3 4dc1 4dc2
4dc7 2 4dd0 4dd2
2 4dd4 4dd6 2
4dd8 4dda 2 4ddc
4dde 2 4de0 4de2
3 4de7 4de8 4de9
2 4de4 4deb 2
4dcf 4ded 1 4def
1 4df1 2 4dba
4df2 1 4df6 1
4db5 2 4db3 4dfa
1 4e05 2 4e01
4e05 2 4e0a 4e0b
1 4e0f 2 4e0d
4e0f 1 4e24 2
4e23 4e24 1 4e2c
1 4e32 2 4e34
4e35 2 4e21 4e36
1 4e3d 1 4e38
2 4e50 4e52 3
4e4e 4e4f 4e54 2
4e5d 4e5f 2 4e61
4e63 2 4e65 4e67
2 4e69 4e6b 2
4e6d 4e6f 3 4e74
4e75 4e76 2 4e71
4e78 2 4e5c 4e7a
1 4e7c 1 4e7e
2 4e47 4e7f 1
4e83 1 4e42 2
4e40 4e87 1 4e8a
1 4ea1 2 4ea0
4ea1 1 4ea9 1
4eaf 2 4eb1 4eb2
2 4e9e 4eb3 1
4eba 1 4eb5 2
4ecd 4ecf 3 4ecb
4ecc 4ed1 2 4eda
4edc 2 4ede 4ee0
2 4ee2 4ee4 2
4ee6 4ee8 2 4eea
4eec 3 4ef1 4ef2
4ef3 2 4eee 4ef5
2 4ed9 4ef7 1
4ef9 1 4efb 2
4ec4 4efc 1 4f00
1 4ebf 2 4ebd
4f04 1 4f07 2
4f0a 4f0b 3 4f0e
4f0f 4f10 1 4f14
2 4f12 4f14 a
4f1f 4f20 4f21 4f22
4f23 4f24 4f25 4f26
4f27 4f28 2 4f1a
4f2b 1 4f2d 2
4f0c 4f2e 1 4f30
1 4f32 2 4f3b
4f3c 1 4f40 2
4f3e 4f40 1 4f48
1 4f4a 5 4d80
4d8a 4dfd 4f31 4f4b
1 4f4d 3 4c16
4d74 4f4e 1 4f50
1 4f52 5 4f5c
4f5d 4f5e 4f5f 4f60
2 4f7d 4f82 1
4f89 1 4f84 2
4f9c 4f9e 3 4f9a
4f9b 4fa0 2 4fa9
4fab 2 4fad 4faf
2 4fb1 4fb3 2
4fb5 4fb7 2 4fb9
4fbb 3 4fc0 4fc1
4fc2 2 4fbd 4fc4
2 4fa8 4fc6 1
4fc8 1 4fca 2
4f93 4fcb 1 4fcf
1 4f8e 2 4f8c
4fd3 2 4fd9 4fda
1 4fde 2 4fdc
4fde 1 4ff3 2
4ff2 4ff3 1 4ffb
1 5001 2 5003
5004 2 4ff0 5005
1 500c 1 5007
2 501f 5021 3
501d 501e 5023 2
502c 502e 2 5030
5032 2 5034 5036
2 5038 503a 2
503c 503e 3 5043
5044 5045 2 5040
5047 2 502b 5049
1 504b 1 504d
2 5016 504e 1
5052 1 5011 2
500f 5056 1 5059
1 5070 2 506f
5070 1 5078 1
507e 2 5080 5081
2 506d 5082 1
5089 1 5084 2
509c 509e 3 509a
509b 50a0 2 50a9
50ab 2 50ad 50af
2 50b1 50b3 2
50b5 50b7 2 50b9
50bb 3 50c0 50c1
50c2 2 50bd 50c4
2 50a8 50c6 1
50c8 1 50ca 2
5093 50cb 1 50cf
1 508e 2 508c
50d3 1 50d6 2
50d9 50da 3 50dd
50de 50df 1 50e3
2 50e1 50e3 2
50e8 50e9 1 50ed
2 50eb 50ed a
50fa 50fb 50fc 50fd
50fe 50ff 5100 5101
5102 5103 2 50f5
5106 1 5108 5
4f59 4f63 4fd6 50db
5109 1 510b 1
510f 1 5117 2
5115 5117 1 511e
1 5120 2 512a
512c 3 5128 5129
512e 2 5137 5139
2 513b 513d 2
513f 5141 1 5149
2 514b 514c 2
5143 514e 2 5150
5152 2 5154 5156
2 5158 515a 2
515c 515e 2 5136
5160 1 5162 1
5164 3 516b 516c
516d 5a 498 4b7
4ba 4bd 4c0 4c3
4c6 4c9 4d6 4f6
4f9 4fc 4ff 502
505 508 50b 50e
513 526 52b 588
602 66b 6e6 6e9
748 7c2 841 8bc
91d 998 9f7 a09
a83 a86 a91 a9c
aa7 b0c b72 de3
de6 de9 dec def
df2 df5 df8 dfd
e10 e25 e82 e9e
f03 156b 15db 15ec
15ef 15f2 15f5 15fa
1676 1679 167c 16dc
16e0 1746 17a8 2647
2653 2656 2659 26b8
26bc 26bf 26c2 26c5
26c8 45d3 4630 4634
4b9b 4b9e 4f51 510c
5112 5121 5165 516f
2 517c 517e 3
517a 517b 5180 2
5189 518b 2 5188
518d 2 5194 5198
2 519a 519c 2
519e 51a2 2 5193
51a4 2 518f 51a6
1 51a8 3 51a9
51b4 51b8 1 5173
2 51cb 51cd 3
51c9 51ca 51cf 2
51d8 51da 2 51d7
51dc 2 51e3 51e5
2 51e7 51e9 3
51ee 51ef 51f0 2
51eb 51f2 2 51e2
51f4 2 51de 51f6
1 51f8 4 51c2
51f9 5202 5206 1
520a 1 51bd 2
51bb 520e 71 4e
55 5c 63 6a
71 78 7f 86
8d 94 9b a2
a9 ae b3 b8
bd c4 cb d0
d5 da e1 e8
ed f2 f7 fc
103 10a 111 118
11f 125 12b 131
137 13d 143 149
14f 155 15b 161
167 16d 173 179
17f 185 18b 191
197 19d 1a3 1a9
1af 1b5 1bb 1c1
1c7 1cd 1d3 1d9
1df 1e5 1eb 1f1
1f7 1fd 203 209
20f 215 21b 221
228 22f 235 23b
242 248 24f 256
25c 262 267 26c
272 278 27e 284
28a 290 296 29c
2a2 2a8 2ae 2b5
2bc 2c3 2c9 2d7
2dd 2e3 2e8 2ed
2fa 30e 386 390

1
4
0 
5215
0
1
140
f0
82
0 1 1 1 1 5 1 7
1 9 1 b 1 d 1 f
1 11 1 13 1 15 1 17
1 19 1 1b 1 1d 1 1f
1 21 1 23 1 25 1 27
1 29 1 2b 1 2d 1 2f
1 31 1 33 1 35 1 37
1 39 1 3b 1 3d 1 3f
1 41 1 43 1 45 1 47
1 49 1 4b 1 4d 1 4f
1 51 1 53 1 55 1 57
1 59 1 5b 1 5d 1 5f
1 61 1 63 1 65 1 67
68 67 6a 67 6c 67 6e 67
70 67 72 67 74 67 76 67
78 67 7a 67 7c 67 7e 67
80 67 82 67 84 67 86 67
88 67 8a 67 8c 67 8e 67
90 67 92 67 94 67 96 67
98 67 9a 67 9c 67 9e 67
a0 67 a2 67 a4 67 a6 67
a8 67 aa 67 ac 67 ae 67
b0 67 b2 67 b4 67 b6 67
b8 67 ba 67 bc 67 be 67
c0 67 c2 67 c4 67 c6 67
c8 67 ca 67 cc 67 ce 1
d0 1 d2 1 d4 1 d6 1
d8 1 da 1 dc 1 de 1
e0 1 e2 1 e4 1 e6 1
e8 1 ea 1 ec 1 ee 1
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

274 1 0
3b 1 0
33 1 0
244 1 0
2c5 1 0
27a 1 0
37 1 0
f9 1 0
187 1 0
237 1 0
1a5 1 0
139 1 0
b0 1 0
73 1 0
251 1 0
2f 1 0
280 1 0
292 1 0
24a 1 0
7a 1 0
27 1 0
20b 1 0
b 1 0
181 1 0
88 1 0
23 1 0
2e5 1 0
1e7 1 0
dc 1 0
fe 1 0
81 1 0
45cd 67 d0
1bd 1 0
f4 1 0
2d9 1 0
1d5 1 0
1c3 1 0
65 1 0
23d 1 0
19f 1 0
1db 1 0
46 1 0
1b7 1 0
127 1 0
cd 1 0
314 1 4
25e 1 0
217 1 0
1f9 1 0
145 1 0
2aa 1 0
1b 1 0
163 1 0
300 1 3
22a 1 0
133 1 0
ea 1 0
b5 1 0
2f0 1 2
223 1 0
ab 1 0
17 1 0
21d 1 0
157 1 0
286 1 0
26e 1 0
57 1 0
3 1 0
1f3 1 0
29e 1 0
2 0 1
2cb 1 0
18d 1 0
2b0 1 0
113 1 0
2ea 1 0
269 1 0
ef 1 0
ba 1 0
258 1 0
14b 1 0
28c 1 0
199 1 0
12d 1 0
121 1 0
2b 1 0
2be 1 0
2b7 1 0
205 1 0
8f 1 0
50 1 0
e3 1 0
f 1 0
7 1 0
15d 1 0
151 1 0
2df 1 0
1ab 1 0
175 1 0
bf 1 0
211 1 0
1ed 1 0
a4 1 0
10c 1 0
2a4 1 0
298 1 0
1e1 1 0
13f 1 0
231 1 0
1c9 1 0
d2 1 0
9d 1 0
96 1 0
193 1 0
6c 1 0
1b1 1 0
1f 1 0
264 1 0
1ff 1 0
1cf 1 0
d7 1 0
105 1 0
16f 1 0
5e 1 0
11a 1 0
169 1 0
13 1 0
38b 1 0
17b 1 0
c6 1 0
0

/
SHOW ERRORS FUNCTION SP_A_RESTOPROF;
ALTER FUNCTION SP_A_RESTOPROF COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_RATES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_RATES ==
CREATE OR REPLACE FUNCTION SP_U_RATES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
5b
2 :e:
1FUNCTION:
1SP_U_RATES:
1ID:
1VARCHAR2:
1REG_COST:
1NUMBER:
1SPEC_COST:
1REG_RATE:
1SPEC_RATE:
1RATE_ADJUSTMENT001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_RES_ID:
1H_REG_COST:
10:
1H_REG_RATE:
1H_SPEC_COST:
1H_SPEC_RATE:
1H_RATE_ADJUSTMENT:
1H_FLAG:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_RATES(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
134:
1+:
1FPUT:
1               ENTER:: SP_U_RATES(35) :: cplan.sql(12945) :: :
1IS NULL:
139:
1        RETURN_ERROR:: SP_U_RATES(40) :: cplan.sql(12950) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1 ID:: :
142:
1                EXIT:: SP_U_RATES(43) :: cplan.sql(12953) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1SC_STATE:
1FC_U_RATES:
1=:
1100:
14:
166:
1       RETURN_STATUS:: SP_U_RATES(67) :: cplan.sql(12977) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
116:
173:
1           EXCEPTION:: SP_U_RATES(74) :: cplan.sql(12984) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
185:
1           EXCEPTION:: SP_U_RATES(86) :: cplan.sql(12996) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2a9
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c a0 51 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :9 a0 a5
b d :2 a0 6b 7e 51 b4 2e
:2 a0 6b 51 d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 a0 6b :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e :2 a0 6b b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :9 a0 12a e9 dd
:2 a0 65 b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c :7 a0 12a e9 dd :2 a0 65
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 68 4f 1d 17 b5 
2a9
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d 7c
a2 a6 aa ae b1 b5 d2 bd
c1 c4 c5 cd bc ef dd b9
e1 e2 ea dc 10b fa fe d9
106 f9 127 116 11a f6 122 115
143 132 136 112 13e 131 15f 14e
152 12e 15a 14d 17b 16a 16e 14a
176 169 197 186 18a 166 192 185
1b7 1a2 1a6 182 1aa 1b2 1a1 1be
1c2 19e 1c6 1ca 1ce 1d1 1d6 1d7
1 1d9 1de 1e2 1e6 1e9 1ee 1f2
1f6 1f9 1fe 1ff 201 206 209 20d
20e 213 218 21b 220 221 226 229
22d 22e 233 236 23b 23c 241 244
249 24a 24f 252 256 25a 25e 25f
261 266 267 269 26a 26f 272 277
278 27d 280 284 288 28c 28d 28f
294 295 297 298 29d 2a0 2a5 2a6
2ab 2ae 2b2 2b6 2ba 2bb 2bd 2c2
2c3 2c5 2c6 2cb 2ce 2d3 2d4 2d9
2dc 2e0 2e4 2e8 2e9 2eb 2f0 2f1
2f3 2f4 2f9 2fc 301 302 307 30a
30e 312 316 317 319 31e 31f 321
322 327 32a 32f 330 335 338 33d
33e 343 346 34a 34b 350 353 358
359 35e 361 366 367 36c 36d 372
374 378 37b 37f 383 386 38a 38e
391 394 399 39c 39f 3a2 3a3 3a8
3a9 1 3ab 3b0 3b4 3b8 3bb 3c0
3c5 3c8 3cc 3cd 3d2 3d3 3d8 3da
3de 3e1 3e5 3e8 3e9 3ee 3f1 3f5
3f9 3fc 400 404 407 40a 40f 412
415 418 419 41e 41f 1 421 426
42a 42e 431 436 43b 43e 442 443
448 44b 450 451 456 459 45e 45f
464 467 46b 46f 473 477 47a 47b
47d 482 483 485 486 48b 48e 493
494 499 49c 4a1 4a2 4a7 4aa 4ae
4af 4b4 4b7 4bc 4bd 4c2 4c3 4c8
4ca 4ce 4d1 4d5 4d9 4dc 4e0 4e4
4e7 4ea 4ef 4f2 4f5 4f8 4f9 4fe
4ff 1 501 506 50a 50e 511 516
51b 51e 522 523 528 529 52e 530
534 537 53b 53f 542 546 54a 54d
551 555 556 55b 55d 561 564 568
56b 56f 573 577 57b 57f 583 587
58b 58f 593 597 59b 59f 5a3 5a7
5ab 5af 5b3 5b7 5bb 5bf 5c3 5c7
5cb 5ce 5d2 5d6 5da 5de 5e2 5e6
5ea 5ee 5f2 5f3 5f5 5f9 5fd 601
604 607 60a 60b 610 614 618 61b
61e 622 624 628 62b 62f 633 636
63a 63e 641 644 649 64c 64f 652
653 658 659 1 65b 660 664 668
66b 670 675 678 67c 67d 682 685
68a 68b 690 693 698 699 69e 6a1
6a5 6a9 6ad 6b1 6b4 6b5 6b7 6bc
6bd 6bf 6c0 6c5 6c8 6cd 6ce 6d3
6d6 6db 6dc 6e1 6e4 6e8 6e9 6ee
6f1 6f6 6f7 6fc 6fd 702 704 708
70b 70f 713 716 71a 71e 721 725
729 72a 72f 731 735 739 73c 740
744 747 74b 74f 752 755 75a 75d
760 763 764 769 76a 1 76c 771
775 779 77c 781 786 789 78d 78e
793 794 799 79d 7a1 7a4 7a9 7ae
7b1 7b5 7b9 7bc 7bd 7c2 7c5 7ca
7cb 7d0 7d3 7d7 7db 7de 7df 7e4
7e5 7ea 7ec 7f0 7f3 7f7 7fb 7ff
803 807 80b 80f 813 817 823 828
82c 830 834 838 83a 83b 840 1
844 848 84c 84f 853 857 85b 85f
862 866 86a 86d 870 875 878 87b
87e 87f 884 885 1 887 88c 890
894 897 89c 8a1 8a4 8a8 8a9 8ae
8af 8b4 8b8 8bc 8bf 8c4 8c9 8cc
8d0 8d1 8d6 8d9 8de 8df 8e4 8e7
8eb 8ef 8f2 8f5 8f6 8f8 8f9 8fe
8ff 904 906 90a 90d 911 915 919
91d 921 925 929 935 93a 93e 942
946 94a 94c 950 952 95e 960 962
963 968 96c 96e 97a 97e 980 981
98a 
2a9
2
0 1 a 6 9 :3 6 f :3 6
10 :3 6 f :3 6 10 :3 6 19 :3 6
10 :2 6 1 3 a 13 a :2 1
4 9 12 11 :2 9 :2 4 d 16
15 :2 d :2 4 :2 f 19 f :2 4 :2 f
19 f :2 4 :2 10 1a 10 :2 4 :2 10
1a 10 :2 4 :2 16 25 16 :2 4 :2 b
1a b :2 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 52 58 5b :2 52
69 7d 8 :2 69 d 10 :2 69 13
16 :2 69 b e :2 69 13 16 1f
27 :2 1f 32 :2 16 :2 69 b e :2 69
13 16 1f 27 :2 1f 33 :2 16 :2 69
b e :2 69 13 16 1f 27 :2 1f
32 :2 16 :2 69 b e :2 69 13 16
1f 27 :2 1f 33 :2 16 :2 69 b e
:2 69 13 16 1f 27 :2 1f 3c :2 16
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 28 2b :2 69 30 33 :2 69
:2 7 48 :2 4 7 :2 11 23 :2 2d 39
3c 4a 4c 4d :2 4a :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 50 :2 4
:4 8 7 a :2 14 26 :2 30 3c 40
4e 50 51 :2 4e :2 26 :3 a :2 10 15
21 5e 61 :2 21 6e 71 :2 21 75
78 :2 21 82 85 8e 96 :2 9f :2 8e
b0 :2 85 :2 21 b8 bb :2 21 c3 c6
:2 21 cb ce :2 21 d1 d4 :2 21 :2 a
54 :2 7 a :2 14 26 :2 30 3c 3f
4d 4f 50 :2 4d :2 26 :3 a :2 10 15
21 5e 61 :2 21 :2 a 53 :3 7 :2 12
26 :2 2f 3f 43 :2 7 14 :3 4 e
:2 4 c :2 4 10 :2 4 12 :2 4 13
:2 4 12 :2 4 13 :2 4 19 :2 4 :2 d
19 24 2a 36 43 4f 23 36
40 :2 19 4 7 :2 10 19 1b :2 19
7 :2 10 1c 7 1f :2 4 7 :2 11
23 :2 2d 39 3c 4a 4c 4d :2 4a
:2 23 :3 7 :2 d 12 1e 5b 5e :2 1e
6b 6e :2 1e 72 75 :2 1e 7f 82
8b 93 :2 9c :2 8b a7 :2 82 :2 1e af
b2 :2 1e ba bd :2 1e c2 c5 :2 1e
c8 cb :2 1e :2 7 50 :3 4 :2 f 21
:2 2a 34 38 :2 4 1 9 12 9
a :2 14 26 :2 30 3c 40 4e 50
51 :2 4e :2 26 :3 a :2 10 15 21 5e
61 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 54 :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 4b 4d
4e :2 4b :2 23 :3 7 :2 d 12 1e 5b
5e :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 51 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
2a9
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 2 :4 a :2 1
:7 c :7 d :6 e :6 f
:6 10 :6 11 :6 12 :6 13
:7 15 :b 17 :11 18 19
:2 18 :2 19 :2 18 :2 19
:2 18 :2 1a :2 18 :9 1a
:2 18 :2 1b :2 18 :9 1b
:2 18 :2 1c :2 18 :9 1c
:2 18 :2 1d :2 18 :9 1d
:2 18 :2 1e :2 18 :9 1e
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :4 18 :3 17
:11 22 :b 23 :3 22 :5 26
:11 27 :30 28 :3 27 :11 2a
:b 2b :3 2a :a 2d :3 26
:3 30 :3 33 :3 34 :3 35
:3 36 :3 37 :3 38 :3 39
:9 3b :3 3c :3 3b :7 3e
:5 3f :3 3e :11 42 :30 43
:3 42 :a 45 16 :3 48
:11 49 :b 4a :17 4b :3 49
:2 4d :3 4e :3 4f 50
4e 4d 4e :3 51
:3 48 :2 52 :5 54 :11 55
:b 56 :18 57 :3 55 :2 59
5a :3 5b 5c 5a
59 5a :3 5d :2 53
:6 52 47 :7 1 
98c
4
:3 0 1 :3 0 2
:a 0 2a4 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d 7c 0
b 6 :3 0 8
:7 0 11 10 :3 0
6 :3 0 9 :7 0
15 14 :3 0 11
:2 0 f b :3 0
a :7 0 19 18
:3 0 4 :3 0 c
:7 0 1d 1c :3 0
d :3 0 e :3 0
f :2 0 4 21
22 0 1f 23
0 2a4 2 24
:2 0 11 :2 0 1b
4 :3 0 11 :2 0
19 27 29 :6 0
2c 2a 0 2a2
0 10 :6 0 14
:2 0 1f 4 :3 0
1d 2e 30 :6 0
33 31 0 2a2
0 12 :6 0 14
:2 0 21 6 :3 0
35 :7 0 39 36
37 2a2 0 13
:6 0 14 :2 0 23
6 :3 0 3b :7 0
3f 3c 3d 2a2
0 15 :6 0 14
:2 0 25 6 :3 0
41 :7 0 45 42
43 2a2 0 16
:6 0 14 :2 0 27
6 :3 0 47 :7 0
4b 48 49 2a2
0 17 :6 0 14
:2 0 29 b :3 0
4d :7 0 51 4e
4f 2a2 0 18
:6 0 59 5a 0
2b b :3 0 53
:7 0 57 54 55
2a2 0 19 :6 0
5f 60 0 2d
e :3 0 f :2 0
4 5b :7 0 5e
5c 0 2a2 0
1a :6 0 1b :3 0
1c :3 0 1b :3 0
1d :3 0 62 63
0 2 :4 0 2f
64 66 61 68
67 :2 0 1e :3 0
1f :3 0 6a 6b
0 20 :4 0 1b
:3 0 21 :3 0 6e
6f 0 2 :4 0
31 70 72 22
:4 0 23 :2 0 24
:3 0 33 75 77
:3 0 25 :4 0 23
:2 0 26 :4 0 36
7a 7c :3 0 23
:2 0 3 :3 0 39
7e 80 :3 0 23
:2 0 26 :4 0 3c
82 84 :3 0 23
:2 0 27 :4 0 3f
86 88 :3 0 23
:2 0 28 :3 0 29
:3 0 5 :3 0 42
8c 8e 2a :4 0
44 8b 91 47
8a 93 :3 0 23
:2 0 27 :4 0 4a
95 97 :3 0 23
:2 0 28 :3 0 29
:3 0 7 :3 0 4d
9b 9d 2a :4 0
4f 9a a0 52
99 a2 :3 0 23
:2 0 27 :4 0 55
a4 a6 :3 0 23
:2 0 28 :3 0 29
:3 0 8 :3 0 58
aa ac 2a :4 0
5a a9 af 5d
a8 b1 :3 0 23
:2 0 27 :4 0 60
b3 b5 :3 0 23
:2 0 28 :3 0 29
:3 0 9 :3 0 63
b9 bb 2a :4 0
65 b8 be 68
b7 c0 :3 0 23
:2 0 27 :4 0 6b
c2 c4 :3 0 23
:2 0 28 :3 0 29
:3 0 a :3 0 6e
c8 ca 2a :4 0
70 c7 cd 73
c6 cf :3 0 23
:2 0 27 :4 0 76
d1 d3 :3 0 23
:2 0 26 :4 0 79
d5 d7 :3 0 23
:2 0 c :3 0 7c
d9 db :3 0 23
:2 0 26 :4 0 7f
dd df :3 0 23
:2 0 2b :4 0 82
e1 e3 :3 0 85
6c e5 :2 0 e7
8a e8 69 e7
0 e9 8c 0
202 1b :3 0 1c
:3 0 ea eb 0
1b :3 0 2c :3 0
ed ee 0 2d
:2 0 2 :4 0 2e
:2 0 2f :2 0 2d
:2 0 8e f3 f5
:3 0 91 ef f7
ec f9 f8 :2 0
1e :3 0 30 :3 0
fb fc 0 20
:4 0 31 :4 0 23
:2 0 24 :3 0 95
100 102 :3 0 98
fd 104 :2 0 106
9b 107 fa 106
0 108 9d 0
202 3 :3 0 32
:2 0 9f 10a 10b
:3 0 10c :2 0 1b
:3 0 1c :3 0 10e
10f 0 1b :3 0
2c :3 0 111 112
0 11 :2 0 2
:4 0 33 :2 0 2f
:2 0 2d :2 0 a1
117 119 :3 0 a4
113 11b 110 11d
11c :2 0 1e :3 0
30 :3 0 11f 120
0 20 :4 0 34
:4 0 23 :2 0 24
:3 0 a8 124 126
:3 0 23 :2 0 35
:4 0 ab 128 12a
:3 0 23 :2 0 36
:4 0 ae 12c 12e
:3 0 23 :2 0 28
:3 0 29 :3 0 37
:3 0 38 :3 0 133
134 0 b1 132
136 2a :4 0 b3
131 139 b6 130
13b :3 0 23 :2 0
39 :4 0 b9 13d
13f :3 0 23 :2 0
26 :4 0 bc 141
143 :3 0 23 :2 0
3 :3 0 bf 145
147 :3 0 23 :2 0
26 :4 0 c2 149
14b :3 0 c5 121
14d :2 0 14f c8
150 11e 14f 0
151 ca 0 17b
1b :3 0 1c :3 0
152 153 0 1b
:3 0 2c :3 0 155
156 0 2d :2 0
2 :4 0 3a :2 0
2f :2 0 2d :2 0
cc 15b 15d :3 0
cf 157 15f 154
161 160 :2 0 1e
:3 0 30 :3 0 163
164 0 20 :4 0
3b :4 0 23 :2 0
24 :3 0 d3 168
16a :3 0 d6 165
16c :2 0 16e d9
16f 162 16e 0
170 db 0 17b
3c :3 0 3d :3 0
171 172 0 37
:3 0 38 :3 0 174
175 0 3 :3 0
3e :3 0 dd 173
179 :2 0 17b e1
17c 10d 17b 0
17d e5 0 202
19 :3 0 2d :2 0
17e 17f 0 202
10 :3 0 3 :3 0
181 182 0 202
12 :3 0 c :3 0
184 185 0 202
13 :3 0 5 :3 0
187 188 0 202
16 :3 0 7 :3 0
18a 18b 0 202
15 :3 0 8 :3 0
18d 18e 0 202
17 :3 0 9 :3 0
190 191 0 202
18 :3 0 a :3 0
193 194 0 202
e :3 0 3f :3 0
196 197 0 40
:3 0 10 :3 0 13
:3 0 16 :3 0 15
:3 0 17 :3 0 18
:3 0 12 :3 0 19
:3 0 e7 199 1a2
198 1a3 0 202
e :3 0 3f :3 0
1a5 1a6 0 41
:2 0 42 :2 0 f2
1a8 1aa :3 0 e
:3 0 3f :3 0 1ac
1ad 0 14 :2 0
1ae 1af 0 1b1
f5 1b2 1ab 1b1
0 1b3 f7 0
202 1b :3 0 1c
:3 0 1b4 1b5 0
1b :3 0 2c :3 0
1b7 1b8 0 43
:2 0 2 :4 0 44
:2 0 2f :2 0 2d
:2 0 f9 1bd 1bf
:3 0 fc 1b9 1c1
1b6 1c3 1c2 :2 0
1e :3 0 30 :3 0
1c5 1c6 0 20
:4 0 45 :4 0 23
:2 0 24 :3 0 100
1ca 1cc :3 0 23
:2 0 35 :4 0 103
1ce 1d0 :3 0 23
:2 0 36 :4 0 106
1d2 1d4 :3 0 23
:2 0 28 :3 0 29
:3 0 e :3 0 3f
:3 0 1d9 1da 0
109 1d8 1dc 2a
:4 0 10b 1d7 1df
10e 1d6 1e1 :3 0
23 :2 0 39 :4 0
111 1e3 1e5 :3 0
23 :2 0 26 :4 0
114 1e7 1e9 :3 0
23 :2 0 3 :3 0
117 1eb 1ed :3 0
23 :2 0 26 :4 0
11a 1ef 1f1 :3 0
11d 1c7 1f3 :2 0
1f5 120 1f6 1c4
1f5 0 1f7 122
0 202 3c :3 0
46 :3 0 1f8 1f9
0 e :3 0 3f
:3 0 1fb 1fc 0
3 :3 0 3e :3 0
124 1fa 200 :2 0
202 128 2a3 e
:3 0 47 :2 0 4
203 204 0 1b
:3 0 1c :3 0 206
207 0 1b :3 0
2c :3 0 209 20a
0 48 :2 0 2
:4 0 49 :2 0 2f
:2 0 2d :2 0 138
20f 211 :3 0 13b
20b 213 208 215
214 :2 0 1e :3 0
30 :3 0 217 218
0 20 :4 0 4a
:4 0 23 :2 0 24
:3 0 13f 21c 21e
:3 0 142 219 220
:2 0 239 1e :3 0
30 :3 0 222 223
0 20 :4 0 4b
:4 0 23 :2 0 e
:3 0 4c :3 0 228
229 0 145 227
22b :3 0 23 :2 0
39 :4 0 148 22d
22f :3 0 23 :2 0
e :3 0 4d :3 0
232 233 0 14b
231 235 :3 0 14e
224 237 :2 0 239
151 23a 216 239
0 23b 154 0
24b 4e :3 0 1a
:3 0 e :3 0 4c
:3 0 4f :3 0 e
:3 0 4d :3 0 3
:3 0 50 :4 0 51
1 :a 0 247 :2 0
24b 23d 245 :2 0
d :3 0 1a :3 0
249 :2 0 24b 156
24d 15a 24c 24b
:2 0 2a1 52 :3 0
e :3 0 3f :3 0
250 251 0 53
:3 0 252 253 0
299 1b :3 0 1c
:3 0 255 256 0
1b :3 0 2c :3 0
258 259 0 48
:2 0 2 :4 0 54
:2 0 2f :2 0 2d
:2 0 15c 25e 260
:3 0 15f 25a 262
257 264 263 :2 0
1e :3 0 30 :3 0
266 267 0 20
:4 0 55 :4 0 23
:2 0 24 :3 0 163
26b 26d :3 0 166
268 26f :2 0 289
1e :3 0 30 :3 0
271 272 0 20
:4 0 56 :4 0 23
:2 0 53 :3 0 169
276 278 :3 0 23
:2 0 57 :4 0 16c
27a 27c :3 0 23
:2 0 58 :3 0 59
:3 0 2d :2 0 5a
:2 0 16f 27f 283
173 27e 285 :3 0
176 273 287 :2 0
289 179 28a 265
289 0 28b 17c
0 299 4e :3 0
1a :3 0 4f :3 0
e :3 0 4d :3 0
3 :3 0 50 :4 0
5b 1 :a 0 295
:2 0 299 28d 293
:2 0 d :3 0 1a
:3 0 297 :2 0 299
17e 29c :3 0 29c
0 29c 29b 299
29a :6 0 29e 1
:3 0 183 2a0 185
29f 29e :2 0 2a1
187 :2 0 2a3 18a
2a3 2a2 202 2a1
:6 0 2a4 :2 0 2
24 2a3 2a7 :3 0
2a6 2a4 2a8 :8 0

194
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 7
6 a e 12
16 1a 1e 1
28 1 26 1
2f 1 2d 1
34 1 3a 1
40 1 46 1
4c 1 52 1
58 1 65 1
71 2 74 76
2 79 7b 2
7d 7f 2 81
83 2 85 87
1 8d 2 8f
90 2 89 92
2 94 96 1
9c 2 9e 9f
2 98 a1 2
a3 a5 1 ab
2 ad ae 2
a7 b0 2 b2
b4 1 ba 2
bc bd 2 b6
bf 2 c1 c3
1 c9 2 cb
cc 2 c5 ce
2 d0 d2 2
d4 d6 2 d8
da 2 dc de
2 e0 e2 4
6d 73 78 e4
1 e6 1 e8
2 f2 f4 3
f0 f1 f6 2
ff 101 2 fe
103 1 105 1
107 1 109 2
116 118 3 114
115 11a 2 123
125 2 127 129
2 12b 12d 1
135 2 137 138
2 12f 13a 2
13c 13e 2 140
142 2 144 146
2 148 14a 2
122 14c 1 14e
1 150 2 15a
15c 3 158 159
15e 2 167 169
2 166 16b 1
16d 1 16f 3
176 177 178 3
151 170 17a 1
17c 8 19a 19b
19c 19d 19e 19f
1a0 1a1 1 1a9
2 1a7 1a9 1
1b0 1 1b2 2
1bc 1be 3 1ba
1bb 1c0 2 1c9
1cb 2 1cd 1cf
2 1d1 1d3 1
1db 2 1dd 1de
2 1d5 1e0 2
1e2 1e4 2 1e6
1e8 2 1ea 1ec
2 1ee 1f0 2
1c8 1f2 1 1f4
1 1f6 3 1fd
1fe 1ff f e9
108 17d 180 183
186 189 18c 18f
192 195 1a4 1b3
1f7 201 2 20e
210 3 20c 20d
212 2 21b 21d
2 21a 21f 2
226 22a 2 22c
22e 2 230 234
2 225 236 2
221 238 1 23a
3 23b 246 24a
1 205 2 25d
25f 3 25b 25c
261 2 26a 26c
2 269 26e 2
275 277 2 279
27b 3 280 281
282 2 27d 284
2 274 286 2
270 288 1 28a
4 254 28b 294
298 1 29c 1
24f 2 24d 2a0
9 2b 32 38
3e 44 4a 50
56 5d 
1
4
0 
2a7
0
1
14
2
11
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
7 1 0
4c 1 0
3 1 0
13 1 0
1b 1 0
40 1 0
3a 1 0
f 1 0
26 1 0
b 1 0
2d 1 0
17 1 0
52 1 0
46 1 0
34 1 0
58 1 0
0

/
SHOW ERRORS FUNCTION SP_U_RATES;
ALTER FUNCTION SP_U_RATES COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_RATES_EDITED
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_RATES_EDITED ==
CREATE OR REPLACE FUNCTION SP_U_RATES_EDITED wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
73
2 :e:
1FUNCTION:
1SP_U_RATES_EDITED:
1ID:
1VARCHAR2:
1RATES_EDITED001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_RESOURCE_ID:
1H_REG_COST:
1NUMBER:
10:
1H_SPEC_COST:
1H_REG_RATE:
1H_SPEC_RATE:
1H_FLAG:
1H_OLD_REG_COST:
1H_OLD_REG_SALE:
1H_OLD_SPEC_COST:
1H_OLD_SPEC_RATE:
1H_RATE_ID:
1H_RATE_ADJUSTMENT:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_RATES_EDITED(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
131:
1+:
1FPUT:
1               ENTER:: SP_U_RATES_EDITED(32) :: cplan.sql(13052) :: :
1REGULAR_COST:
1REGULAR_RATE:
1SPECIAL_COST:
1SPECIAL_RATE:
1RATE_ADJUSTMENT:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT REGULAR_COST, REGULAR_RATE,:n      SPECIAL_COST, SPECIAL_RATE, RATE_AD+
1JUSTMENT:n      INTO   h_old_reg_cost, h_old_reg_sale ,:n      h_old_spec_cos+
1t,h_old_spec_rate, h_rate_adjustment:n      FROM TASK_ASSIGNMENTS:n      WHER+
1E TSK_ASSIGNMENT_ID = id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
153:
1           EXCEPTION:: SP_U_RATES_EDITED(54) :: cplan.sql(13074) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1RATE_ID:
1RESOURCES:
1RESOURCE_ID:
1SELECT RATE_ID INTO h_rate_id:n      FROM RESOURCES:n      WHERE RESOURCE_ID +
1= res_id001:
170:
1           EXCEPTION:: SP_U_RATES_EDITED(71) :: cplan.sql(13091) :: :
1REGULAR_SALE:
1SPECIAL_SALE:
1RATES:
1SELECT REGULAR_COST, REGULAR_SALE,:n      SPECIAL_COST, SPECIAL_SALE:n      I+
1NTO   h_reg_cost, h_reg_rate ,:n      h_spec_cost,h_spec_rate:n      FROM RAT+
1ES:n      WHERE RATE_ID = h_rate_id:
190:
1           EXCEPTION:: SP_U_RATES_EDITED(91) :: cplan.sql(13111) :: :
1RATES_EDITED:
1BITAND:
1UPDATE TASK_ASSIGNMENTS:n      SET RATES_EDITED = BITAND(RATES_EDITED,rates_e+
1dited001):n      WHERE TSK_ASSIGNMENT_ID = id:
1FOUND:
1TRUE:
1=:
1100:
1111:
1           EXCEPTION:: SP_U_RATES_EDITED(112) :: cplan.sql(13132) :: :
1>:
12:
1FC_U_RATES:
14:
1129:
1       RETURN_STATUS:: SP_U_RATES_EDITED(130) :: cplan.sql(13150) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1136:
1           EXCEPTION:: SP_U_RATES_EDITED(137) :: cplan.sql(13157) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1148:
1           EXCEPTION:: SP_U_RATES_EDITED(149) :: cplan.sql(13169) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
3b4
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d a0 51 d :d a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:b a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :7 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b 51 a5
b 5a 7e 51 b4 2e :2 a0 d
:2 a0 d b7 19 3c :3 a0 51 a5
b 51 a5 b 5a 7e 51 b4
2e :2 a0 d :2 a0 d b7 19 3c
:2 a0 6b :9 a0 a5 b d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 a0 6b :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e a5 57
b7 19 3c :9 a0 12a e9 dd :2 a0
65 b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c :7 a0 12a e9 dd :2 a0 65 b7
a4 b1 11 4f b7 a6 9 a4
b1 11 68 4f 1d 17 b5 
3b4
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 bf ae b2 8d
ba ad db ca ce aa d6 c9
f7 e6 ea c6 f2 e5 113 102
106 e2 10e 101 12f 11e 122 fe
12a 11d 14b 13a 13e 11a 146 139
167 156 15a 136 162 155 183 172
176 152 17e 171 19f 18e 192 16e
19a 18d 1bc 1aa 18a 1ae 1af 1b7
1a9 1d8 1c7 1cb 1a6 1d3 1c6 1f8
1e3 1e7 1c3 1eb 1f3 1e2 1ff 203
1df 207 20b 20f 212 217 218 1
21a 21f 223 227 22a 22f 233 237
23a 23f 240 242 247 24a 24e 24f
254 259 25c 261 262 267 26a 26e
26f 274 277 27c 27d 282 285 28a
28b 290 293 297 29b 29f 2a0 2a2
2a7 2a8 2aa 2ab 2b0 2b3 2b8 2b9
2be 2c1 2c6 2c7 2cc 2cf 2d3 2d4
2d9 2dc 2e1 2e2 2e7 2ea 2ef 2f0
2f5 2f6 2fb 2fd 301 304 308 30c
30f 313 317 31a 31d 322 325 328
32b 32c 331 332 1 334 339 33d
341 344 349 34e 351 355 356 35b
35c 361 363 367 36a 36e 372 376
37a 37d 381 385 389 38d 391 395
399 39d 3a1 3a5 3a9 3ad 3b1 3b5
3c1 3c5 3c9 3cc 3d0 3d4 3d6 3da
3de 3e2 3e5 3e9 3ed 3ef 3f0 3f5
1 3f9 3fd 401 404 408 40c 410
414 417 41b 41f 422 425 42a 42d
430 433 434 439 43a 1 43c 441
445 449 44c 451 456 459 45d 45e
463 466 46b 46c 471 474 479 47a
47f 482 486 487 48c 48f 494 495
49a 49d 4a1 4a5 4a8 4ab 4ac 4ae
4af 4b4 4b5 4ba 4bc 4c0 4c3 4c5
4c9 4cb 4d7 4d9 4db 4dc 4e1 4e5
4e7 4f3 4f5 4f9 4fd 501 505 509
515 519 51d 520 524 528 52a 52e
532 536 539 53d 541 543 544 549
1 54d 551 555 558 55c 560 564
568 56b 56f 573 576 579 57e 581
584 587 588 58d 58e 1 590 595
599 59d 5a0 5a5 5aa 5ad 5b1 5b2
5b7 5ba 5bf 5c0 5c5 5c8 5cd 5ce
5d3 5d6 5da 5db 5e0 5e3 5e8 5e9
5ee 5f1 5f5 5f9 5fc 5ff 600 602
603 608 609 60e 610 614 617 619
61d 61f 62b 62d 62f 630 635 639
63b 647 649 64d 651 655 659 65d
661 665 669 66d 671 675 681 685
689 68c 690 694 696 69a 69e 6a2
6a5 6a9 6ad 6af 6b0 6b5 1 6b9
6bd 6c1 6c4 6c8 6cc 6d0 6d4 6d7
6db 6df 6e2 6e5 6ea 6ed 6f0 6f3
6f4 6f9 6fa 1 6fc 701 705 709
70c 711 716 719 71d 71e 723 726
72b 72c 731 734 739 73a 73f 742
746 747 74c 74f 754 755 75a 75d
761 765 768 76b 76c 76e 76f 774
775 77a 77c 780 783 785 789 78b
797 799 79b 79c 7a1 7a5 7a7 7b3
7b5 7b9 7bd 7c1 7c5 7c9 7cd 7d1
7dd 7e1 7e6 7ea 7ed 7ee 7f3 7f7
7fb 7fe 801 805 807 80b 80f 812
815 819 81b 81f 823 826 828 82c
830 834 837 83b 83f 841 842 847
1 84b 84f 853 856 85a 85e 862
866 869 86d 871 874 877 87c 87f
882 885 886 88b 88c 1 88e 893
897 89b 89e 8a3 8a8 8ab 8af 8b0
8b5 8b8 8bd 8be 8c3 8c6 8cb 8cc
8d1 8d4 8d8 8d9 8de 8e1 8e6 8e7
8ec 8ef 8f3 8f7 8fa 8fd 8fe 900
901 906 907 90c 90e 912 915 917
91b 91d 929 92b 92d 92e 933 937
939 945 947 94b 94f 953 956 957
959 95c 95d 95f 962 965 968 969
96e 972 976 97a 97e 982 986 988
98c 98f 993 997 99b 99e 99f 9a1
9a4 9a5 9a7 9aa 9ad 9b0 9b1 9b6
9ba 9be 9c2 9c6 9ca 9ce 9d0 9d4
9d7 9db 9df 9e2 9e6 9ea 9ee 9f2
9f6 9fa 9fe a02 a06 a07 a09 a0d
a11 a15 a18 a1c a20 a23 a26 a2b
a2e a31 a34 a35 a3a a3b 1 a3d
a42 a46 a4a a4d a52 a57 a5a a5e
a5f a64 a67 a6c a6d a72 a75 a7a
a7b a80 a83 a87 a8b a8f a93 a96
a97 a99 a9e a9f aa1 aa2 aa7 aaa
aaf ab0 ab5 ab8 abd abe ac3 ac6
aca acb ad0 ad3 ad8 ad9 ade adf
ae4 ae6 aea aed af1 af5 af8 afc
b00 b03 b07 b0b b0c b11 b13 b17
b1b b1e b22 b26 b29 b2d b31 b34
b37 b3c b3f b42 b45 b46 b4b b4c
1 b4e b53 b57 b5b b5e b63 b68
b6b b6f b70 b75 b76 b7b b7f b83
b86 b8b b90 b93 b97 b9b b9e b9f
ba4 ba7 bac bad bb2 bb5 bb9 bbd
bc0 bc1 bc6 bc7 bcc bce bd2 bd5
bd9 bdd be1 be5 be9 bed bf1 bf5
bf9 c05 c0a c0e c12 c16 c1a c1c
c1d c22 1 c26 c2a c2e c31 c35
c39 c3d c41 c44 c48 c4c c4f c52
c57 c5a c5d c60 c61 c66 c67 1
c69 c6e c72 c76 c79 c7e c83 c86
c8a c8b c90 c91 c96 c9a c9e ca1
ca6 cab cae cb2 cb3 cb8 cbb cc0
cc1 cc6 cc9 ccd cd1 cd4 cd7 cd8
cda cdb ce0 ce1 ce6 ce8 cec cef
cf3 cf7 cfb cff d03 d07 d0b d17
d1c d20 d24 d28 d2c d2e d32 d34
d40 d42 d44 d45 d4a d4e d50 d5c
d60 d62 d63 d6c 
3b4
2
0 1 a 6 9 :3 6 16 :3 6
10 :2 6 1 3 a 13 a :2 1
4 9 12 11 :2 9 :2 4 12 1b
1a :2 12 :2 4 :2 f 19 f :2 4 :2 10
1a 10 :2 4 :2 f 19 f :2 4 :2 10
1a 10 :2 4 :2 b 1a b :2 4 :2 13
1d 13 :2 4 :2 13 1d 13 :2 4 :2 14
1e 14 :2 4 :2 14 1e 14 :2 4 e
17 16 :2 e :2 4 :2 16 25 16 :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 59 5f 62 :2 59 70 8b 8
:2 70 d 10 :2 70 13 16 :2 70 b
e :2 70 13 16 1f 27 :2 1f 39
:2 16 :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 28 2b :2 70 30 33
:2 70 :2 7 4f :2 4 7 :2 11 23 :2 2d
39 3c 51 53 54 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 57
:3 4 15 :2 4 e 4 e 1c 7
15 23 e 1e 7 17 28 c
d 21 :2 7 :2 10 1c 7 4 c
a :2 13 1f a 1a :2 7 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 58 5a 5b :2 58 :2 29 :3 d :2 13
18 24 68 6b :2 24 78 7b :2 24
7f 82 :2 24 8e 91 :2 24 99 9c
:2 24 a8 ab b2 bb be :2 ab :2 24
:2 d 5e :2 a :2 7 :4 13 :2 7 4 :3 1
e 1b c d 1b :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 58 5a 5b :2 58
:2 29 :3 d :2 13 18 24 68 6b :2 24
78 7b :2 24 7f 82 :2 24 8e 91
:2 24 99 9c :2 24 a8 ab b2 bb
be :2 ab :2 24 :2 d 5e :2 a :2 7 :4 13
:2 7 4 :3 1 e 1c 7 15 e
1a 7 13 c d 17 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 58 5a 5b
:2 58 :2 29 :3 d :2 13 18 24 68 6b
:2 24 78 7b :2 24 7f 82 :2 24 8e
91 :2 24 99 9c :2 24 a8 ab b2
bb be :2 ab :2 24 :2 d 5e :2 a :2 7
:4 13 :2 7 4 :3 1 e b 1a 21
2e d 21 7 e a 16 :3 14
a :2 13 1f a 1b a :2 13 1f
a :4 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 58 5b 5c
:2 58 :2 29 :3 d :2 13 18 24 69 6c
:2 24 79 7c :2 24 80 83 :2 24 8f
92 :2 24 9a 9d :2 24 a9 ac b3
bc bf :2 ac :2 24 :2 d 5f :2 a :2 7
:4 13 :2 7 4 :3 1 8 f 18 29
:2 f 2d :2 8 7 31 33 :2 31 7
19 :2 7 1a 7 35 :2 4 8 f
18 29 :2 f 2d :2 8 7 31 33
:2 31 7 19 :2 7 1a 7 35 :3 4
:2 d 19 24 2a 3a 4b 23 34
47 56 :2 19 4 7 :2 11 23 :2 2d
39 3c 51 54 55 :2 51 :2 23 :3 7
:2 d 12 1e 63 66 :2 1e 73 76
:2 1e 7a 7d :2 1e 87 8a 93 9b
:2 a4 :2 93 af :2 8a :2 1e b7 ba :2 1e
c2 c5 :2 1e ca cd :2 1e d0 d3
:2 1e :2 7 58 :3 4 :2 f 21 :2 2a 34
38 :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 55 58 59 :2 55
:2 26 :3 a :2 10 15 21 66 69 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
5c :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 52 55 56 :2 52
:2 23 :3 7 :2 d 12 1e 63 66 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 59 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
3b4
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :6 a :6 b
:6 c :6 d :6 e :6 f
:6 10 :6 11 :6 12 :7 13
:6 14 :7 16 :b 18 :11 19
1a :2 19 :2 1a :2 19
:2 1a :2 19 :2 1b :2 19
:9 1b :2 19 :2 1c :2 19
:2 1c :2 19 :2 1c :2 19
:2 1c :2 19 :2 1c :4 19
:3 18 :11 1f :b 20 :3 1f
:3 23 :3 25 :2 28 :3 29
:2 2a :3 2b 2c :2 2d
28 :5 2e 27 30
:5 31 :3 30 :2 32 :5 34
:11 35 :24 36 :3 35 :2 33
:6 32 2f :3 17 :2 3c
3d :2 3e 3c :5 3f
3b 41 :5 42 :3 41
:2 43 :5 45 :11 46 :24 47
:3 46 :2 44 :6 43 40
:3 17 :2 4d :2 4e :2 4f
:2 50 51 :2 52 4d
:5 53 4c 55 :5 56
:3 55 :2 57 :5 59 :11 5a
:24 5b :3 5a :2 58 :6 57
54 :3 17 61 :4 62
:2 63 61 :6 64 :5 65
64 :5 67 66 :3 64
60 6a :5 6b :3 6a
:2 6c :5 6e :11 6f :24 70
:3 6f :2 6d :6 6c 69
:3 17 :e 75 :3 76 :3 77
:3 75 :e 79 :3 7a :3 7b
:3 79 :8 7e :4 7f :3 7e
:11 81 :30 82 :3 81 :a 84
17 :3 87 :11 88 :b 89
:17 8a :3 88 :2 8c :3 8d
:3 8e 8f 8d 8c
8d :3 90 :3 87 :2 91
:5 93 :11 94 :b 95 :18 96
:3 94 :2 98 99 :3 9a
9b 99 98 99
:3 9c :2 92 :6 91 86
:7 1 
d6e
4
:3 0 1 :3 0 2
:a 0 3af 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 3af 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 3ad
0 b :6 0 10
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 3ad
0 d :6 0 10
:2 0 15 f :3 0
25 :7 0 29 26
27 3ad 0 e
:6 0 10 :2 0 17
f :3 0 2b :7 0
2f 2c 2d 3ad
0 11 :6 0 10
:2 0 19 f :3 0
31 :7 0 35 32
33 3ad 0 12
:6 0 10 :2 0 1b
f :3 0 37 :7 0
3b 38 39 3ad
0 13 :6 0 10
:2 0 1d 6 :3 0
3d :7 0 41 3e
3f 3ad 0 14
:6 0 10 :2 0 1f
f :3 0 43 :7 0
47 44 45 3ad
0 15 :6 0 10
:2 0 21 f :3 0
49 :7 0 4d 4a
4b 3ad 0 16
:6 0 10 :2 0 23
f :3 0 4f :7 0
53 50 51 3ad
0 17 :6 0 c
:2 0 25 f :3 0
55 :7 0 59 56
57 3ad 0 18
:6 0 10 :2 0 29
4 :3 0 27 5b
5d :6 0 60 5e
0 3ad 0 19
:6 0 68 69 0
2b 6 :3 0 62
:7 0 66 63 64
3ad 0 1a :6 0
6e 6f 0 2d
9 :3 0 a :2 0
4 6a :7 0 6d
6b 0 3ad 0
1b :6 0 1c :3 0
1d :3 0 1c :3 0
1e :3 0 71 72
0 2 :4 0 2f
73 75 70 77
76 :2 0 1f :3 0
20 :3 0 79 7a
0 21 :4 0 1c
:3 0 22 :3 0 7d
7e 0 2 :4 0
31 7f 81 23
:4 0 24 :2 0 25
:3 0 33 84 86
:3 0 26 :4 0 24
:2 0 27 :4 0 36
89 8b :3 0 24
:2 0 3 :3 0 39
8d 8f :3 0 24
:2 0 27 :4 0 3c
91 93 :3 0 24
:2 0 28 :4 0 3f
95 97 :3 0 24
:2 0 29 :3 0 2a
:3 0 5 :3 0 42
9b 9d 2b :4 0
44 9a a0 47
99 a2 :3 0 24
:2 0 28 :4 0 4a
a4 a6 :3 0 24
:2 0 27 :4 0 4d
a8 aa :3 0 24
:2 0 7 :3 0 50
ac ae :3 0 24
:2 0 27 :4 0 53
b0 b2 :3 0 24
:2 0 2c :4 0 56
b4 b6 :3 0 59
7b b8 :2 0 ba
5e bb 78 ba
0 bc 60 0
30d 1c :3 0 1d
:3 0 bd be 0
1c :3 0 2d :3 0
c0 c1 0 2e
:2 0 2 :4 0 2f
:2 0 30 :2 0 2e
:2 0 62 c6 c8
:3 0 65 c2 ca
bf cc cb :2 0
1f :3 0 31 :3 0
ce cf 0 21
:4 0 32 :4 0 24
:2 0 25 :3 0 69
d3 d5 :3 0 6c
d0 d7 :2 0 d9
6f da cd d9
0 db 71 0
30d d :3 0 7
:3 0 dc dd 0
30d 14 :3 0 10
:2 0 df e0 0
30d 33 :3 0 34
:3 0 35 :3 0 36
:3 0 37 :3 0 15
:3 0 16 :3 0 17
:3 0 18 :3 0 1a
:3 0 38 :3 0 39
:3 0 3 :4 0 3a
1 :8 0 f5 9
:3 0 3b :3 0 f0
f1 0 3c :3 0
f2 f3 0 f5
73 148 3d :3 0
9 :3 0 3b :3 0
f7 f8 0 3c
:3 0 f9 fa 0
fc 76 fe 78
fd fc :2 0 146
3e :3 0 9 :3 0
3b :3 0 101 102
0 3c :3 0 103
104 0 13e 1c
:3 0 1d :3 0 106
107 0 1c :3 0
2d :3 0 109 10a
0 3f :2 0 2
:4 0 40 :2 0 30
:2 0 2e :2 0 7a
10f 111 :3 0 7d
10b 113 108 115
114 :2 0 1f :3 0
31 :3 0 117 118
0 21 :4 0 41
:4 0 24 :2 0 25
:3 0 81 11c 11e
:3 0 24 :2 0 42
:4 0 84 120 122
:3 0 24 :2 0 43
:4 0 87 124 126
:3 0 24 :2 0 3c
:3 0 8a 128 12a
:3 0 24 :2 0 44
:4 0 8d 12c 12e
:3 0 24 :2 0 45
:3 0 46 :3 0 2e
:2 0 47 :2 0 90
131 135 94 130
137 :3 0 97 119
139 :2 0 13b 9a
13c 116 13b 0
13d 9c 0 13e
9e 141 :3 0 141
0 141 140 13e
13f :6 0 143 2
:3 0 a1 145 a3
144 143 :2 0 146
a5 :2 0 148 0
148 147 f5 146
:6 0 30d 1 :3 0
48 :3 0 19 :3 0
49 :3 0 4a :3 0
7 :4 0 4b 1
:8 0 155 9 :3 0
3b :3 0 150 151
0 3c :3 0 152
153 0 155 a8
1a8 3d :3 0 9
:3 0 3b :3 0 157
158 0 3c :3 0
159 15a 0 15c
ab 15e ad 15d
15c :2 0 1a6 3e
:3 0 9 :3 0 3b
:3 0 161 162 0
3c :3 0 163 164
0 19e 1c :3 0
1d :3 0 166 167
0 1c :3 0 2d
:3 0 169 16a 0
3f :2 0 2 :4 0
4c :2 0 30 :2 0
2e :2 0 af 16f
171 :3 0 b2 16b
173 168 175 174
:2 0 1f :3 0 31
:3 0 177 178 0
21 :4 0 4d :4 0
24 :2 0 25 :3 0
b6 17c 17e :3 0
24 :2 0 42 :4 0
b9 180 182 :3 0
24 :2 0 43 :4 0
bc 184 186 :3 0
24 :2 0 3c :3 0
bf 188 18a :3 0
24 :2 0 44 :4 0
c2 18c 18e :3 0
24 :2 0 45 :3 0
46 :3 0 2e :2 0
47 :2 0 c5 191
195 c9 190 197
:3 0 cc 179 199
:2 0 19b cf 19c
176 19b 0 19d
d1 0 19e d3
1a1 :3 0 1a1 0
1a1 1a0 19e 19f
:6 0 1a3 4 :3 0
d6 1a5 d8 1a4
1a3 :2 0 1a6 da
:2 0 1a8 0 1a8
1a7 155 1a6 :6 0
30d 1 :3 0 33
:3 0 4e :3 0 35
:3 0 4f :3 0 e
:3 0 12 :3 0 11
:3 0 13 :3 0 50
:3 0 48 :3 0 19
:4 0 51 1 :8 0
1bb 9 :3 0 3b
:3 0 1b6 1b7 0
3c :3 0 1b8 1b9
0 1bb dd 20e
3d :3 0 9 :3 0
3b :3 0 1bd 1be
0 3c :3 0 1bf
1c0 0 1c2 e0
1c4 e2 1c3 1c2
:2 0 20c 3e :3 0
9 :3 0 3b :3 0
1c7 1c8 0 3c
:3 0 1c9 1ca 0
204 1c :3 0 1d
:3 0 1cc 1cd 0
1c :3 0 2d :3 0
1cf 1d0 0 3f
:2 0 2 :4 0 52
:2 0 30 :2 0 2e
:2 0 e4 1d5 1d7
:3 0 e7 1d1 1d9
1ce 1db 1da :2 0
1f :3 0 31 :3 0
1dd 1de 0 21
:4 0 53 :4 0 24
:2 0 25 :3 0 eb
1e2 1e4 :3 0 24
:2 0 42 :4 0 ee
1e6 1e8 :3 0 24
:2 0 43 :4 0 f1
1ea 1ec :3 0 24
:2 0 3c :3 0 f4
1ee 1f0 :3 0 24
:2 0 44 :4 0 f7
1f2 1f4 :3 0 24
:2 0 45 :3 0 46
:3 0 2e :2 0 47
:2 0 fa 1f7 1fb
fe 1f6 1fd :3 0
101 1df 1ff :2 0
201 104 202 1dc
201 0 203 106
0 204 108 207
:3 0 207 0 207
206 204 205 :6 0
209 6 :3 0 10b
20b 10d 20a 209
:2 0 20c 10f :2 0
20e 0 20e 20d
1bb 20c :6 0 30d
1 :3 0 38 :3 0
54 :3 0 55 :3 0
54 :3 0 5 :3 0
39 :3 0 3 :4 0
56 1 :8 0 22d
57 :4 0 218 :3 0
58 :3 0 59 :2 0
114 21b 21c :3 0
9 :3 0 3b :3 0
21e 21f 0 10
:2 0 220 221 0
223 117 22a 9
:3 0 3b :3 0 224
225 0 5a :2 0
226 227 0 229
119 22b 21d 223
0 22c 0 229
0 22c 11b 0
22d 11e 280 3d
:3 0 9 :3 0 3b
:3 0 22f 230 0
3c :3 0 231 232
0 234 121 236
123 235 234 :2 0
27e 3e :3 0 9
:3 0 3b :3 0 239
23a 0 3c :3 0
23b 23c 0 276
1c :3 0 1d :3 0
23e 23f 0 1c
:3 0 2d :3 0 241
242 0 3f :2 0
2 :4 0 5b :2 0
30 :2 0 2e :2 0
125 247 249 :3 0
128 243 24b 240
24d 24c :2 0 1f
:3 0 31 :3 0 24f
250 0 21 :4 0
5c :4 0 24 :2 0
25 :3 0 12c 254
256 :3 0 24 :2 0
42 :4 0 12f 258
25a :3 0 24 :2 0
43 :4 0 132 25c
25e :3 0 24 :2 0
3c :3 0 135 260
262 :3 0 24 :2 0
44 :4 0 138 264
266 :3 0 24 :2 0
45 :3 0 46 :3 0
2e :2 0 47 :2 0
13b 269 26d 13f
268 26f :3 0 142
251 271 :2 0 273
145 274 24e 273
0 275 147 0
276 149 279 :3 0
279 0 279 278
276 277 :6 0 27b
8 :3 0 14c 27d
14e 27c 27b :2 0
27e 150 :2 0 280
0 280 27f 22d
27e :6 0 30d 1
:3 0 55 :3 0 29
:3 0 5 :3 0 10
:2 0 153 283 286
2e :2 0 156 282
289 28a :2 0 5d
:2 0 10 :2 0 15b
28c 28e :3 0 15
:3 0 e :3 0 290
291 0 296 17
:3 0 11 :3 0 293
294 0 296 15e
297 28f 296 0
298 161 0 30d
55 :3 0 29 :3 0
5 :3 0 10 :2 0
163 29a 29d 5e
:2 0 166 299 2a0
2a1 :2 0 5d :2 0
10 :2 0 16b 2a3
2a5 :3 0 16 :3 0
12 :3 0 2a7 2a8
0 2ad 18 :3 0
13 :3 0 2aa 2ab
0 2ad 16e 2ae
2a6 2ad 0 2af
171 0 30d 9
:3 0 3b :3 0 2b0
2b1 0 5f :3 0
b :3 0 15 :3 0
17 :3 0 16 :3 0
18 :3 0 1a :3 0
d :3 0 14 :3 0
173 2b3 2bc 2b2
2bd 0 30d 1c
:3 0 1d :3 0 2bf
2c0 0 1c :3 0
2d :3 0 2c2 2c3
0 60 :2 0 2
:4 0 61 :2 0 30
:2 0 2e :2 0 17c
2c8 2ca :3 0 17f
2c4 2cc 2c1 2ce
2cd :2 0 1f :3 0
31 :3 0 2d0 2d1
0 21 :4 0 62
:4 0 24 :2 0 25
:3 0 183 2d5 2d7
:3 0 24 :2 0 42
:4 0 186 2d9 2db
:3 0 24 :2 0 63
:4 0 189 2dd 2df
:3 0 24 :2 0 29
:3 0 2a :3 0 9
:3 0 3b :3 0 2e4
2e5 0 18c 2e3
2e7 2b :4 0 18e
2e2 2ea 191 2e1
2ec :3 0 24 :2 0
64 :4 0 194 2ee
2f0 :3 0 24 :2 0
27 :4 0 197 2f2
2f4 :3 0 24 :2 0
3 :3 0 19a 2f6
2f8 :3 0 24 :2 0
27 :4 0 19d 2fa
2fc :3 0 1a0 2d2
2fe :2 0 300 1a3
301 2cf 300 0
302 1a5 0 30d
65 :3 0 66 :3 0
303 304 0 9
:3 0 3b :3 0 306
307 0 3 :3 0
58 :3 0 1a7 305
30b :2 0 30d 1ab
3ae 9 :3 0 67
:2 0 4 30e 30f
0 1c :3 0 1d
:3 0 311 312 0
1c :3 0 2d :3 0
314 315 0 3f
:2 0 2 :4 0 68
:2 0 30 :2 0 2e
:2 0 1b9 31a 31c
:3 0 1bc 316 31e
313 320 31f :2 0
1f :3 0 31 :3 0
322 323 0 21
:4 0 69 :4 0 24
:2 0 25 :3 0 1c0
327 329 :3 0 1c3
324 32b :2 0 344
1f :3 0 31 :3 0
32d 32e 0 21
:4 0 6a :4 0 24
:2 0 9 :3 0 6b
:3 0 333 334 0
1c6 332 336 :3 0
24 :2 0 64 :4 0
1c9 338 33a :3 0
24 :2 0 9 :3 0
6c :3 0 33d 33e
0 1cc 33c 340
:3 0 1cf 32f 342
:2 0 344 1d2 345
321 344 0 346
1d5 0 356 6d
:3 0 1b :3 0 9
:3 0 6b :3 0 6e
:3 0 9 :3 0 6c
:3 0 3 :3 0 6f
:4 0 70 1 :a 0
352 :2 0 356 348
350 :2 0 8 :3 0
1b :3 0 354 :2 0
356 1d7 358 1db
357 356 :2 0 3ac
3e :3 0 9 :3 0
3b :3 0 35b 35c
0 3c :3 0 35d
35e 0 3a4 1c
:3 0 1d :3 0 360
361 0 1c :3 0
2d :3 0 363 364
0 3f :2 0 2
:4 0 71 :2 0 30
:2 0 2e :2 0 1dd
369 36b :3 0 1e0
365 36d 362 36f
36e :2 0 1f :3 0
31 :3 0 371 372
0 21 :4 0 72
:4 0 24 :2 0 25
:3 0 1e4 376 378
:3 0 1e7 373 37a
:2 0 394 1f :3 0
31 :3 0 37c 37d
0 21 :4 0 43
:4 0 24 :2 0 3c
:3 0 1ea 381 383
:3 0 24 :2 0 44
:4 0 1ed 385 387
:3 0 24 :2 0 45
:3 0 46 :3 0 2e
:2 0 47 :2 0 1f0
38a 38e 1f4 389
390 :3 0 1f7 37e
392 :2 0 394 1fa
395 370 394 0
396 1fd 0 3a4
6d :3 0 1b :3 0
6e :3 0 9 :3 0
6c :3 0 3 :3 0
6f :4 0 73 1
:a 0 3a0 :2 0 3a4
398 39e :2 0 8
:3 0 1b :3 0 3a2
:2 0 3a4 1ff 3a7
:3 0 3a7 0 3a7
3a6 3a4 3a5 :6 0
3a9 1 :3 0 204
3ab 206 3aa 3a9
:2 0 3ac 208 :2 0
3ae 20b 3ae 3ad
30d 3ac :6 0 3af
:2 0 2 14 3ae
3b2 :3 0 3b1 3af
3b3 :8 0 
21a
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
24 1 2a 1
30 1 36 1
3c 1 42 1
48 1 4e 1
54 1 5c 1
5a 1 61 1
67 1 74 1
80 2 83 85
2 88 8a 2
8c 8e 2 90
92 2 94 96
1 9c 2 9e
9f 2 98 a1
2 a3 a5 2
a7 a9 2 ab
ad 2 af b1
2 b3 b5 4
7c 82 87 b7
1 b9 1 bb
2 c5 c7 3
c3 c4 c9 2
d2 d4 2 d1
d6 1 d8 1
da 2 ef f4
1 fb 1 f6
2 10e 110 3
10c 10d 112 2
11b 11d 2 11f
121 2 123 125
2 127 129 2
12b 12d 3 132
133 134 2 12f
136 2 11a 138
1 13a 1 13c
2 105 13d 1
141 1 100 2
fe 145 2 14f
154 1 15b 1
156 2 16e 170
3 16c 16d 172
2 17b 17d 2
17f 181 2 183
185 2 187 189
2 18b 18d 3
192 193 194 2
18f 196 2 17a
198 1 19a 1
19c 2 165 19d
1 1a1 1 160
2 15e 1a5 2
1b5 1ba 1 1c1
1 1bc 2 1d4
1d6 3 1d2 1d3
1d8 2 1e1 1e3
2 1e5 1e7 2
1e9 1eb 2 1ed
1ef 2 1f1 1f3
3 1f8 1f9 1fa
2 1f5 1fc 2
1e0 1fe 1 200
1 202 2 1cb
203 1 207 1
1c6 2 1c4 20b
1 21a 2 219
21a 1 222 1
228 2 22a 22b
2 217 22c 1
233 1 22e 2
246 248 3 244
245 24a 2 253
255 2 257 259
2 25b 25d 2
25f 261 2 263
265 3 26a 26b
26c 2 267 26e
2 252 270 1
272 1 274 2
23d 275 1 279
1 238 2 236
27d 2 284 285
2 287 288 1
28d 2 28b 28d
2 292 295 1
297 2 29b 29c
2 29e 29f 1
2a4 2 2a2 2a4
2 2a9 2ac 1
2ae 8 2b4 2b5
2b6 2b7 2b8 2b9
2ba 2bb 2 2c7
2c9 3 2c5 2c6
2cb 2 2d4 2d6
2 2d8 2da 2
2dc 2de 1 2e6
2 2e8 2e9 2
2e0 2eb 2 2ed
2ef 2 2f1 2f3
2 2f5 2f7 2
2f9 2fb 2 2d3
2fd 1 2ff 1
301 3 308 309
30a d bc db
de e1 148 1a8
20e 280 298 2af
2be 302 30c 2
319 31b 3 317
318 31d 2 326
328 2 325 32a
2 331 335 2
337 339 2 33b
33f 2 330 341
2 32c 343 1
345 3 346 351
355 1 310 2
368 36a 3 366
367 36c 2 375
377 2 374 379
2 380 382 2
384 386 3 38b
38c 38d 2 388
38f 2 37f 391
2 37b 393 1
395 4 35f 396
39f 3a3 1 3a7
1 35a 2 358
3ab e 1b 22
28 2e 34 3a
40 46 4c 52
58 5f 65 6c

1
4
0 
3b2
0
1
14
a
12
0 1 2 1 4 1 6 1
8 1 0 0 0 0 0 0
0 0 0 0 
42 1 0
61 1 0
5a 1 0
1d 1 0
54 1 0
3 1 0
b 1 0
2a 1 0
30 1 0
2 0 1
48 1 0
4e 1 0
16 1 0
3c 1 0
36 1 0
7 1 0
24 1 0
67 1 0
0

/
SHOW ERRORS FUNCTION SP_U_RATES_EDITED;
ALTER FUNCTION SP_U_RATES_EDITED COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_TIMECODE2
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_TIMECODE2 ==
CREATE OR REPLACE FUNCTION SP_U_TIMECODE2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
55
2 :e:
1FUNCTION:
1SP_U_TIMECODE2:
1ASSIGN_ID:
1VARCHAR2:
1ID:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TEMP_SC_STATE:
1PLS_INTEGER:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_TIMECODE2(:
1':
1, :
1);:
1CHECK_TRACE:
11:
117:
1+:
1FPUT:
1               ENTER:: SP_U_TIMECODE2(18) :: cplan.sql(13211) :: :
1IS NULL:
18:
122:
1      RETURN_INVALID:: SP_U_TIMECODE2(23) :: cplan.sql(13216) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
125:
1                EXIT:: SP_U_TIMECODE2(26) :: cplan.sql(13219) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TASK_ASSIGNMENTS:
1TIMECODE2_ID:
1TSK_ASSIGNMENT_ID:
1UPDATE TASK_ASSIGNMENTS SET TIMECODE2_ID = id WHERE TSK_ASSIGNMENT_ID = assig+
1n_id:
1FOUND:
1=:
1SC_STATE:
1100:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
145:
1           EXCEPTION:: SP_U_TIMECODE2(46) :: cplan.sql(13239) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
14:
151:
1       RETURN_STATUS:: SP_U_TIMECODE2(52) :: cplan.sql(13245) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
158:
1           EXCEPTION:: SP_U_TIMECODE2(59) :: cplan.sql(13252) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
170:
1           EXCEPTION:: SP_U_TIMECODE2(71) :: cplan.sql(13264) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
250
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 a0 6b
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e a5 57 b7 19 3c :9 a0 12a
e9 dd :2 a0 65 b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c :7 a0 12a e9 dd
:2 a0 65 b7 a4 b1 11 4f b7
a6 9 a4 b1 11 68 4f 1d
17 b5 
250
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 71 5d 61 69 6c 5c
91 7c 80 59 84 8c 7b 98
9c 78 a0 a4 a8 ab b0 b1
1 b3 b8 bc c0 c3 c8 cc
d0 d3 d8 d9 db e0 e3 e7
e8 ed f2 f5 fa fb 100 103
107 108 10d 110 115 116 11b 11e
123 124 129 12c 131 132 137 13a
13e 13f 144 147 14c 14d 152 155
15a 15b 160 161 166 168 16c 16f
173 177 17a 17e 182 185 188 18d
190 193 196 197 19c 19d 1 19f
1a4 1a8 1ac 1af 1b4 1b9 1bc 1c0
1c1 1c6 1c7 1cc 1ce 1d2 1d5 1d9
1dc 1dd 1e2 1e5 1e8 1ec 1ef 1f0
1f5 1f8 1 1fb 200 204 208 20b
20f 213 216 219 21e 221 224 227
228 22d 22e 1 230 235 239 23d
240 245 24a 24d 251 252 257 25a
25f 260 265 268 26d 26e 273 276
27a 27e 282 286 289 28a 28c 291
292 294 295 29a 29b 2a0 2a2 2a6
2a9 2ad 2b1 2b4 2b8 2bc 2bf 2c2
2c7 2ca 2cd 2d0 2d1 2d6 2d7 1
2d9 2de 2e2 2e6 2e9 2ee 2f3 2f6
2fa 2fb 300 301 306 308 30c 30f
313 317 31a 31e 322 325 329 32a
32f 331 335 338 33c 340 344 348
34c 358 35c 361 365 368 369 36e
372 376 379 37c 380 382 386 38a
38d 390 394 396 39a 39e 3a1 3a3
3a7 3ab 3af 3b2 3b6 3ba 3bc 3bd
3c2 1 3c6 3ca 3ce 3d1 3d5 3d9
3dd 3e1 3e4 3e8 3ec 3ef 3f2 3f7
3fa 3fd 400 401 406 407 1 409
40e 412 416 419 41e 423 426 42a
42b 430 433 438 439 43e 441 446
447 44c 44f 453 454 459 45c 461
462 467 46a 46e 472 475 478 479
47b 47c 481 482 487 489 48d 490
492 496 498 4a4 4a6 4a8 4a9 4ae
4b2 4b4 4c0 4c2 4c6 4ca 4cd 4d1
4d5 4d8 4db 4e0 4e3 4e6 4e9 4ea
4ef 4f0 1 4f2 4f7 4fb 4ff 502
507 50c 50f 513 514 519 51c 521
522 527 52a 52f 530 535 538 53c
540 544 548 54b 54c 54e 553 554
556 557 55c 55f 564 565 56a 56d
572 573 578 57b 57f 580 585 588
58d 58e 593 594 599 59b 59f 5a2
5a6 5aa 5ad 5b1 5b5 5b8 5bc 5c0
5c1 5c6 5c8 5cc 5d0 5d3 5d7 5db
5de 5e2 5e6 5e9 5ec 5f1 5f4 5f7
5fa 5fb 600 601 1 603 608 60c
610 613 618 61d 620 624 625 62a
62b 630 634 638 63b 640 645 648
64c 650 653 654 659 65c 661 662
667 66a 66e 672 675 676 67b 67c
681 683 687 68a 68e 692 696 69a
69e 6a2 6a6 6aa 6ae 6ba 6bf 6c3
6c7 6cb 6cf 6d1 6d2 6d7 1 6db
6df 6e3 6e6 6ea 6ee 6f2 6f6 6f9
6fd 701 704 707 70c 70f 712 715
716 71b 71c 1 71e 723 727 72b
72e 733 738 73b 73f 740 745 746
74b 74f 753 756 75b 760 763 767
768 76d 770 775 776 77b 77e 782
786 789 78c 78d 78f 790 795 796
79b 79d 7a1 7a4 7a8 7ac 7b0 7b4
7b8 7bc 7c0 7cc 7d1 7d5 7d9 7dd
7e1 7e3 7e7 7e9 7f5 7f7 7f9 7fa
7ff 803 805 811 815 817 818 821 
250
2
0 1 a 6 10 :3 6 9 :2 6
1 3 a 13 a :2 1 4 :2 14
23 14 :2 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 56 5c 5f :2 56
6d 85 8 :2 6d d 10 :2 6d 1a
1d :2 6d b e :2 6d 13 16 :2 6d
1b 1e :2 6d 21 24 :2 6d 29 2c
:2 6d :2 7 4c :2 4 7 :2 11 23 :2 2d
39 3c 4e 50 51 :2 4e :2 23 :3 7
:2 d 12 1e 5f 62 :2 1e :2 7 54
:2 4 :4 9 8 7 :4 22 21 20 :2 7
a :2 14 26 :2 30 3c 3f 51 53
54 :2 51 :2 26 :3 a :2 10 15 21 62
65 :2 21 72 75 :2 21 79 7c :2 21
86 89 92 9a :2 a3 :2 92 b4 :2 89
:2 21 :2 a 57 :2 7 a :2 14 26 :2 30
3c 3f 51 53 54 :2 51 :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 :2 12 28 :2 31 41 :2 7 2f :2 4
e 23 32 3b 4f 7 e a
16 :3 14 a :2 13 1f a 1b a
:2 13 1f a :4 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 55
57 58 :2 55 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 8b 8e :2 24 96 99 :2 24 a5
a8 af b8 bb :2 a8 :2 24 :2 d 5b
:2 a :2 7 :4 13 :2 7 4 :3 1 7 :2 11
23 :2 2d 39 3c 4e 50 51 :2 4e
:2 23 :3 7 :2 d 12 1e 5f 62 :2 1e
6f 72 :2 1e 76 79 :2 1e 83 86
8f 97 :2 a0 :2 8f ab :2 86 :2 1e b3
b6 :2 1e be c1 :2 1e c6 c9 :2 1e
d3 d6 :2 1e :2 7 54 :3 4 :2 f 21
:2 2a 34 3f :2 4 1 9 12 9
a :2 14 26 :2 30 3c 40 52 54
55 :2 52 :2 26 :3 a :2 10 15 21 62
65 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 58 :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 4f 51
52 :2 4f :2 23 :3 7 :2 d 12 1e 5f
62 :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 55 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
250
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :6 7
:7 9 :b b :11 c d
:2 c :2 d :2 c :2 d
:2 c :2 e :2 c :2 e
:2 c :2 e :2 c :2 e
:2 c :2 e :4 c :3 b
:11 11 :b 12 :3 11 :e 15
:11 16 :20 17 :3 16 :11 19
:b 1a :3 19 :9 1c :3 15
:6 21 :6 22 :5 23 22
:5 25 24 :3 22 20
28 :5 29 :3 28 :2 2a
:5 2c :11 2d :24 2e :3 2d
:2 2b :6 2a 27 :3 a
:11 33 :30 34 :3 33 :a 36
a :3 39 :11 3a :b 3b
:17 3c :3 3a :2 3e :3 3f
:3 40 41 3f 3e
3f :3 42 :3 39 :2 43
:5 45 :11 46 :b 47 :18 48
:3 46 :2 4a 4b :3 4c
4d 4b 4a 4b
:3 4e :2 44 :6 43 38
:7 1 
823
4
:3 0 1 :3 0 2
:a 0 24b 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 4
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :3 0 8 :2 0
4 b f 0
24b 2 10 :2 0
19 1a 0 :2 a
:3 0 13 :7 0 b
:2 0 17 14 15
249 0 9 :6 0
1f 20 0 c
7 :3 0 8 :2 0
4 1b :7 0 1e
1c 0 249 0
c :6 0 d :3 0
e :3 0 d :3 0
f :3 0 22 23
0 2 :4 0 e
24 26 21 28
27 :2 0 10 :3 0
11 :3 0 2a 2b
0 12 :4 0 d
:3 0 13 :3 0 2e
2f 0 2 :4 0
10 30 32 14
:4 0 15 :2 0 16
:3 0 12 35 37
:3 0 17 :4 0 15
:2 0 18 :4 0 15
3a 3c :3 0 15
:2 0 3 :3 0 18
3e 40 :3 0 15
:2 0 18 :4 0 1b
42 44 :3 0 15
:2 0 19 :4 0 1e
46 48 :3 0 15
:2 0 18 :4 0 21
4a 4c :3 0 15
:2 0 5 :3 0 24
4e 50 :3 0 15
:2 0 18 :4 0 27
52 54 :3 0 15
:2 0 1a :4 0 2a
56 58 :3 0 2d
2c 5a :2 0 5c
32 5d 29 5c
0 5e 34 0
1a9 d :3 0 e
:3 0 5f 60 0
d :3 0 1b :3 0
62 63 0 1c
:2 0 2 :4 0 1d
:2 0 1e :2 0 1c
:2 0 36 68 6a
:3 0 39 64 6c
61 6e 6d :2 0
10 :3 0 1f :3 0
70 71 0 12
:4 0 20 :4 0 15
:2 0 16 :3 0 3d
75 77 :3 0 40
72 79 :2 0 7b
43 7c 6f 7b
0 7d 45 0
1a9 3 :3 0 21
:2 0 47 7f 80
:3 0 81 :2 0 82
:2 0 5 :3 0 21
:2 0 49 85 86
:3 0 87 :2 0 88
:2 0 83 8a 89
:2 0 d :3 0 e
:3 0 8c 8d 0
d :3 0 1b :3 0
8f 90 0 22
:2 0 2 :4 0 23
:2 0 1e :2 0 1c
:2 0 4b 95 97
:3 0 4e 91 99
8e 9b 9a :2 0
10 :3 0 1f :3 0
9d 9e 0 12
:4 0 24 :4 0 15
:2 0 16 :3 0 52
a2 a4 :3 0 15
:2 0 25 :4 0 55
a6 a8 :3 0 15
:2 0 26 :4 0 58
aa ac :3 0 15
:2 0 27 :3 0 28
:3 0 29 :3 0 2a
:3 0 b1 b2 0
5b b0 b4 2b
:4 0 5d af b7
60 ae b9 :3 0
63 9f bb :2 0
bd 66 be 9c
bd 0 bf 68
0 e8 d :3 0
e :3 0 c0 c1
0 d :3 0 1b
:3 0 c3 c4 0
1c :2 0 2 :4 0
2c :2 0 1e :2 0
1c :2 0 6a c9
cb :3 0 6d c5
cd c2 cf ce
:2 0 10 :3 0 1f
:3 0 d1 d2 0
12 :4 0 2d :4 0
15 :2 0 16 :3 0
71 d6 d8 :3 0
74 d3 da :2 0
dc 77 dd d0
dc 0 de 79
0 e8 2e :3 0
2f :3 0 df e0
0 29 :3 0 2a
:3 0 e2 e3 0
30 :3 0 7b e1
e6 :2 0 e8 7e
e9 8b e8 0
ea 82 0 1a9
31 :3 0 32 :3 0
5 :3 0 33 :3 0
3 :4 0 34 1
:8 0 106 35 :4 0
f1 :3 0 30 :3 0
36 :2 0 86 f4
f5 :3 0 7 :3 0
37 :3 0 f7 f8
0 b :2 0 f9
fa 0 fc 89
103 7 :3 0 37
:3 0 fd fe 0
38 :2 0 ff 100
0 102 8b 104
f6 fc 0 105
0 102 0 105
8d 0 106 90
159 39 :3 0 7
:3 0 37 :3 0 108
109 0 3a :3 0
10a 10b 0 10d
93 10f 95 10e
10d :2 0 157 3b
:3 0 7 :3 0 37
:3 0 112 113 0
3a :3 0 114 115
0 14f d :3 0
e :3 0 117 118
0 d :3 0 1b
:3 0 11a 11b 0
3c :2 0 2 :4 0
3d :2 0 1e :2 0
1c :2 0 97 120
122 :3 0 9a 11c
124 119 126 125
:2 0 10 :3 0 1f
:3 0 128 129 0
12 :4 0 3e :4 0
15 :2 0 16 :3 0
9e 12d 12f :3 0
15 :2 0 25 :4 0
a1 131 133 :3 0
15 :2 0 3f :4 0
a4 135 137 :3 0
15 :2 0 3a :3 0
a7 139 13b :3 0
15 :2 0 40 :4 0
aa 13d 13f :3 0
15 :2 0 41 :3 0
42 :3 0 1c :2 0
43 :2 0 ad 142
146 b1 141 148
:3 0 b4 12a 14a
:2 0 14c b7 14d
127 14c 0 14e
b9 0 14f bb
152 :3 0 152 0
152 151 14f 150
:6 0 154 2 :3 0
be 156 c0 155
154 :2 0 157 c2
:2 0 159 0 159
158 106 157 :6 0
1a9 1 :3 0 d
:3 0 e :3 0 15b
15c 0 d :3 0
1b :3 0 15e 15f
0 44 :2 0 2
:4 0 45 :2 0 1e
:2 0 1c :2 0 c5
164 166 :3 0 c8
160 168 15d 16a
169 :2 0 10 :3 0
1f :3 0 16c 16d
0 12 :4 0 46
:4 0 15 :2 0 16
:3 0 cc 171 173
:3 0 15 :2 0 25
:4 0 cf 175 177
:3 0 15 :2 0 26
:4 0 d2 179 17b
:3 0 15 :2 0 27
:3 0 28 :3 0 7
:3 0 37 :3 0 180
181 0 d5 17f
183 2b :4 0 d7
17e 186 da 17d
188 :3 0 15 :2 0
47 :4 0 dd 18a
18c :3 0 15 :2 0
18 :4 0 e0 18e
190 :3 0 15 :2 0
3 :3 0 e3 192
194 :3 0 15 :2 0
18 :4 0 e6 196
198 :3 0 e9 16e
19a :2 0 19c ec
19d 16b 19c 0
19e ee 0 1a9
2e :3 0 48 :3 0
19f 1a0 0 7
:3 0 37 :3 0 1a2
1a3 0 3 :3 0
30 :3 0 f0 1a1
1a7 :2 0 1a9 f4
24a 7 :3 0 49
:2 0 4 1aa 1ab
0 d :3 0 e
:3 0 1ad 1ae 0
d :3 0 1b :3 0
1b0 1b1 0 3c
:2 0 2 :4 0 4a
:2 0 1e :2 0 1c
:2 0 fb 1b6 1b8
:3 0 fe 1b2 1ba
1af 1bc 1bb :2 0
10 :3 0 1f :3 0
1be 1bf 0 12
:4 0 4b :4 0 15
:2 0 16 :3 0 102
1c3 1c5 :3 0 105
1c0 1c7 :2 0 1e0
10 :3 0 1f :3 0
1c9 1ca 0 12
:4 0 4c :4 0 15
:2 0 7 :3 0 4d
:3 0 1cf 1d0 0
108 1ce 1d2 :3 0
15 :2 0 47 :4 0
10b 1d4 1d6 :3 0
15 :2 0 7 :3 0
4e :3 0 1d9 1da
0 10e 1d8 1dc
:3 0 111 1cb 1de
:2 0 1e0 114 1e1
1bd 1e0 0 1e2
117 0 1f2 4f
:3 0 c :3 0 7
:3 0 4d :3 0 50
:3 0 7 :3 0 4e
:3 0 5 :3 0 51
:4 0 52 1 :a 0
1ee :2 0 1f2 1e4
1ec :2 0 6 :3 0
c :3 0 1f0 :2 0
1f2 119 1f4 11d
1f3 1f2 :2 0 248
3b :3 0 7 :3 0
37 :3 0 1f7 1f8
0 3a :3 0 1f9
1fa 0 240 d
:3 0 e :3 0 1fc
1fd 0 d :3 0
1b :3 0 1ff 200
0 3c :2 0 2
:4 0 53 :2 0 1e
:2 0 1c :2 0 11f
205 207 :3 0 122
201 209 1fe 20b
20a :2 0 10 :3 0
1f :3 0 20d 20e
0 12 :4 0 54
:4 0 15 :2 0 16
:3 0 126 212 214
:3 0 129 20f 216
:2 0 230 10 :3 0
1f :3 0 218 219
0 12 :4 0 3f
:4 0 15 :2 0 3a
:3 0 12c 21d 21f
:3 0 15 :2 0 40
:4 0 12f 221 223
:3 0 15 :2 0 41
:3 0 42 :3 0 1c
:2 0 43 :2 0 132
226 22a 136 225
22c :3 0 139 21a
22e :2 0 230 13c
231 20c 230 0
232 13f 0 240
4f :3 0 c :3 0
50 :3 0 7 :3 0
4e :3 0 5 :3 0
51 :4 0 55 1
:a 0 23c :2 0 240
234 23a :2 0 6
:3 0 c :3 0 23e
:2 0 240 141 243
:3 0 243 0 243
242 240 241 :6 0
245 1 :3 0 146
247 148 246 245
:2 0 248 14a :2 0
24a 14d 24a 249
1a9 248 :6 0 24b
:2 0 2 10 24a
24e :3 0 24d 24b
24f :8 0 
150
4
:3 0 1 3 1
7 2 6 a
1 12 1 18
1 25 1 31
2 34 36 2
39 3b 2 3d
3f 2 41 43
2 45 47 2
49 4b 2 4d
4f 2 51 53
2 55 57 4
2d 33 38 59
1 5b 1 5d
2 67 69 3
65 66 6b 2
74 76 2 73
78 1 7a 1
7c 1 7e 1
84 2 94 96
3 92 93 98
2 a1 a3 2
a5 a7 2 a9
ab 1 b3 2
b5 b6 2 ad
b8 2 a0 ba
1 bc 1 be
2 c8 ca 3
c6 c7 cc 2
d5 d7 2 d4
d9 1 db 1
dd 2 e4 e5
3 bf de e7
1 e9 1 f3
2 f2 f3 1
fb 1 101 2
103 104 2 f0
105 1 10c 1
107 2 11f 121
3 11d 11e 123
2 12c 12e 2
130 132 2 134
136 2 138 13a
2 13c 13e 3
143 144 145 2
140 147 2 12b
149 1 14b 1
14d 2 116 14e
1 152 1 111
2 10f 156 2
163 165 3 161
162 167 2 170
172 2 174 176
2 178 17a 1
182 2 184 185
2 17c 187 2
189 18b 2 18d
18f 2 191 193
2 195 197 2
16f 199 1 19b
1 19d 3 1a4
1a5 1a6 6 5e
7d ea 159 19e
1a8 2 1b5 1b7
3 1b3 1b4 1b9
2 1c2 1c4 2
1c1 1c6 2 1cd
1d1 2 1d3 1d5
2 1d7 1db 2
1cc 1dd 2 1c8
1df 1 1e1 3
1e2 1ed 1f1 1
1ac 2 204 206
3 202 203 208
2 211 213 2
210 215 2 21c
21e 2 220 222
3 227 228 229
2 224 22b 2
21b 22d 2 217
22f 1 231 4
1fb 232 23b 23f
1 243 1 1f6
2 1f4 247 2
16 1d 
1
4
0 
24e
0
1
14
4
5
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
7 1 0
12 1 0
3 1 0
18 1 0
0

/
SHOW ERRORS FUNCTION SP_U_TIMECODE2;
ALTER FUNCTION SP_U_TIMECODE2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_S_PROFILE
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
 $$bitflag       Description
   0	-  WBS Project global view: Resources  Profile with Competencies  Skills
   1	-  WBS Project global view: Resources  Profiles
   6	-  CRI Project global view: Resources  Profiles
   2,3	-  WBS  CRI - Assignments View
   4	-  WBS  CRI - All assignments with effort (no participants, no project assignments) in the current project
   5	-  WBS  CRI - All participants (no effort) in the current project
   8	-  WBS  CRI - All assignments (effort, participants, project assignments) in the current project
   9	-  WBS  CRI - All assignments for a Resource / Profile under a element (project, deliverable, task)
   7	-  WBS Project Assignments
   11	-  DOC Assignments View (SC_TABLE_DOC, SC_TABLE_POL_DOC, SC_TABLE_RES_DOC, SC_TABLE_AST_DOC,SC_TABLE_CLN_DOC,SC_TABLE_VDR_DOC)
   12	-  WBS  CRI - display nickname for All assignments (effort, participants, project assignments) in the current project
   13	-  Returns nickname for All assignments (effort, participants, project assignments) in the current pool
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_S_PROFILE ==
CREATE OR REPLACE FUNCTION SP_S_PROFILE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
200
2 :e:
1FUNCTION:
1SP_S_PROFILE:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_RANK:
1200:
1H_ID:
132:
1H_REC_USER:
1H_PROJECT_ID:
1H_IN:
1255:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_PER_DAY:
1H_TYPE_ID:
1H_COUNT:
1H_TEMP_SC_STATE:
1H_LEVEL_STATE:
1C7751A:
1C7751B:
1C7751C:
1C7751T:
1C7751D:
1C7751E:
1C7751F:
1C7751G:
1C7751H:
1C7751J:
1C7751L:
1C7751M:
1C7751N:
1C77513N:
1CLN_AST_RES:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_S_PROFILE(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
175:
1+:
1FPUT:
1               ENTER:: SP_S_PROFILE(76) :: cplan.sql(13379) :: :
1IS NULL:
182:
1        RETURN_ERROR:: SP_S_PROFILE(83) :: cplan.sql(13386) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1 ID:: :
185:
1                EXIT:: SP_S_PROFILE(86) :: cplan.sql(13389) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1=:
12:
13:
1B:
1PROJECT_ID:
1TYPE_ID:
1A:
1MINUTE_PER_DAY:
1LEVEL_STATE:
1TMT_WBS:
1ELEMENT_ID:
1SELECT B.PROJECT_ID, B.TYPE_ID, COALESCE(A.MINUTE_PER_DAY, 480), B.LEVEL_STAT+
1E:n         INTO h_project_id, h_type_id, h_per_day, h_level_state:n         +
1FROM TMT_WBS A, TMT_WBS B WHERE B.ELEMENT_ID = h_id AND A.ELEMENT_ID = B.PROJ+
1ECT_ID:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1110:
1           EXCEPTION:: SP_S_PROFILE(111) :: cplan.sql(13414) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT B.PROJECT_ID, B.TYPE_ID, COALESCE(A.MINUTE_PER_DAY, 480):n            +
1INTO h_project_id, h_type_id, h_per_day:n            FROM TMT_WBS A, TMT_CRI +
1B WHERE B.ELEMENT_ID = h_id AND A.ELEMENT_ID = B.PROJECT_ID:
1129:
1           EXCEPTION:: SP_S_PROFILE(130) :: cplan.sql(13433) :: :
1TMT_POOLS:
1SELECT 480 INTO h_per_day FROM TMT_POOLS WHERE ELEMENT_ID = h_id:
1146:
1           EXCEPTION:: SP_S_PROFILE(147) :: cplan.sql(13450) :: :
1153:
1        RETURN_ERROR:: SP_S_PROFILE(154) :: cplan.sql(13457) :: :
1156:
1                EXIT:: SP_S_PROFILE(157) :: cplan.sql(13460) :: :
1ELSIF:
110:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID INTO h_project_id:n         FROM TASK_ASSIGNMENTS WHERE TSK+
1_ASSIGNMENT_ID = h_id:
1174:
1           EXCEPTION:: SP_S_PROFILE(175) :: cplan.sql(13478) :: :
1181:
1        RETURN_ERROR:: SP_S_PROFILE(182) :: cplan.sql(13485) :: :
1184:
1                EXIT:: SP_S_PROFILE(185) :: cplan.sql(13488) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), LEVEL_STATE INTO h_per_day, h_level_sta+
1te:n         FROM TMT_WBS WHERE ELEMENT_ID = h_id:
1           EXCEPTION:: SP_S_PROFILE(201) :: cplan.sql(13504) :: :
113:
1RANK:
1SELECT RANK INTO h_rank FROM TMT_POOLS WHERE ELEMENT_ID = h_id:
1215:
1           EXCEPTION:: SP_S_PROFILE(216) :: cplan.sql(13519) :: :
1222:
1        RETURN_ERROR:: SP_S_PROFILE(223) :: cplan.sql(13526) :: :
1225:
1                EXIT:: SP_S_PROFILE(226) :: cplan.sql(13529) :: :
1480:
1!=:
1SC_SRCH_PARTICIPANT:
111:
1SC_ASSET_ASSIGNED_RESOURCES:
1SC_CLIENT_ASSIGNED_RESOURCES:
1SELECT COALESCE(MINUTE_PER_DAY, 480), LEVEL_STATE INTO h_per_day, h_level_sta+
1te:n         FROM TMT_WBS WHERE ELEMENT_ID = id:
1245:
1           EXCEPTION:: SP_S_PROFILE(246) :: cplan.sql(13549) :: :
1252:
1        RETURN_ERROR:: SP_S_PROFILE(253) :: cplan.sql(13556) :: :
1                EXIT:: SP_S_PROFILE(256) :: cplan.sql(13559) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_ASGNDRES_INFO:
1PMO_TMP_ASGNDRES_INFO:
1RESOURCE_ID:
1PARENT_ID:
1RATE_ID:
1PROFICIENCY_LEVEL_ID:
1PREFERENCE_LEVEL_ID:
1EXPERIENCE_ID:
1LAST_USED_DATETIME:
1R:
1RESOURCE_ASSIGNMENTS:
1JOIN:
1TMT_COMPETENCIES:
1RESOURCE_TYPE:
1INSERT INTO PMO_TMP_ASGNDRES_INFO:n         (:n         RESOURCE_ID,:n       +
1  PARENT_ID,:n         RATE_ID,:n         PROFICIENCY_LEVEL_ID,:n         PRE+
1FERENCE_LEVEL_ID,:n         EXPERIENCE_ID,:n         LAST_USED_DATETIME:n    +
1     ):n         SELECT DISTINCT:n         a.RESOURCE_ID,:n         r.PARENT_+
1ID,:n         r.RATE_ID,:n         r.PROFICIENCY_LEVEL_ID,:n         r.PREFER+
1ENCE_LEVEL_ID,:n         r.EXPERIENCE_ID,:n         r.LAST_USED_DATETIME:n   +
1      FROM RESOURCE_ASSIGNMENTS a JOIN TMT_COMPETENCIES r ON a.RESOURCE_ID=r.+
1RESOURCE_ID:n         WHERE PROJECT_ID = h_id AND RESOURCE_TYPE = '0':
1FOUND:
1100:
1301:
1           EXCEPTION:: SP_S_PROFILE(302) :: cplan.sql(13605) :: :
1DELETE FROM PMO_TMP_PROF_INFO:
1PMO_TMP_PROF_INFO:
1PROFILE_ID:
1INSERT INTO PMO_TMP_PROF_INFO (PROFILE_ID):n         SELECT DISTINCT RESOURCE+
1_ID:n         FROM RESOURCE_ASSIGNMENTS:n         WHERE PROJECT_ID = h_id AND+
1 RESOURCE_TYPE = '1':
1327:
1           EXCEPTION:: SP_S_PROFILE(328) :: cplan.sql(13631) :: :
1OPEN:
1TA:
1RES:
1RES_TYPE:
1P:
1FULL_NAME:
1ELEMENT_NAME:
1STATUS1_ID:
1E_MAIL_ADDRESS:
1D:
1ROLE_NAME:
1LAST_USED:
1RC:
1REGULAR_COST:
1REGULAR_SALE:
1SPECIAL_COST:
1SPECIAL_SALE:
1OBJECTIVES:
1RESOURCES:
1C:
1LEFT:
1OUTER:
1RATES:
1PRF:
1PROFILE_NAME:
1PROFILES:
1ROLE_ID:
1RESOURCE_ASSIGN_SKILLS:
1S:
1RES_ASSIGNMENT_ID:
1SKILL_ID:
1RESOURCE_ASSIGN_ROLES:
1SELECT CASE WHEN EXISTS(SELECT * FROM TASK_ASSIGNMENTS ta WHERE ta.PROJECT_ID+
1=h_id AND ta.RESOURCE_ID = RES.RESOURCE_ID) THEN 13 ELSE 185 END AS RES_TYPE,+
1:n      RES.RESOURCE_ID, p.FULL_NAME AS ELEMENT_NAME, p.STATUS1_ID, p.E_MAIL_+
1ADDRESS, d.TYPE_ID, d.ELEMENT_NAME AS ROLE_NAME,:n      RES.PROFICIENCY_LEVEL+
1_ID, RES.PREFERENCE_LEVEL_ID, RES.EXPERIENCE_ID, RES.LAST_USED_DATETIME AS LA+
1ST_USED,rc.REGULAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE, '' A+
1S OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_ASGNDRES_INFO RES JOIN RESOURCES +
1p ON RES.RESOURCE_ID=p.RESOURCE_ID:n      JOIN TMT_COMPETENCIES c ON c.ELEMEN+
1T_ID=RES.PARENT_ID:n      JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID+
1:n      LEFT OUTER JOIN RATES rc ON rc.RATE_ID=RES.RATE_ID:n      :n      UNI+
1ON ALL:n      :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID AS RESOURCE_ID, p.+
1PROFILE_NAME AS ELEMENT_NAME, 0 AS STATUS1_ID, '' AS E_MAIL_ADDRESS,:n      c+
1.TYPE_ID, c.ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_LEVEL_ID, r.PREFE+
1RENCE_LEVEL_ID,r.EXPERIENCE_ID,r.LAST_USED_DATETIME AS LAST_USED,:n      rc.R+
1EGULAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE,'' AS OBJECTIVES,+
1'' AS RANK:n      FROM PMO_TMP_PROF_INFO PRF  JOIN PROFILES p ON PRF.PROFILE_+
1ID=p.PROFILE_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES r ON p.ROLE_ID=r.ELEM+
1ENT_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.PARENT_ID+
1:n      LEFT OUTER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID:n      :n      UNION+
1 ALL:n      :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID AS RESOURCE_ID,p.PRO+
1FILE_NAME AS ELEMENT_NAME,0 AS STATUS1_ID,'' AS E_MAIL_ADDRESS,:n      c.TYPE+
1_ID, c.ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_LEVEL_ID, r.PREFERENCE+
1_LEVEL_ID, r.EXPERIENCE_ID, r.LAST_USED_DATETIME AS LAST_USED,:n      rc.REGU+
1LAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE, '' AS OBJECTIVES,''+
1 AS RANK:n      FROM PMO_TMP_PROF_INFO PRF JOIN PROFILES p ON PRF.PROFILE_ID=+
1p.PROFILE_ID:n      JOIN RESOURCE_ASSIGN_SKILLS s ON p.PROFILE_ID=s.RES_ASSIG+
1NMENT_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES r ON s.SKILL_ID=r.ELEMENT_ID+
1:n      LEFT OUTER JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.PARENT_ID:n     +
1 LEFT OUTER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID:n      :n      UNION ALL:n +
1     :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID AS RESOURCE_ID,p.PROFILE_NA+
1ME AS ELEMENT_NAME,0 AS STATUS1_ID,'' AS E_MAIL_ADDRESS,:n      c.TYPE_ID, c.+
1ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_LEVEL_ID, r.PREFERENCE_LEVEL_+
1ID, r.EXPERIENCE_ID, r.LAST_USED_DATETIME AS LAST_USED,:n      rc.REGULAR_COS+
1T,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE, '' AS OBJECTIVES,'' AS RAN+
1K:n      FROM PMO_TMP_PROF_INFO PRF JOIN PROFILES p ON PRF.PROFILE_ID=p.PROFI+
1LE_ID:n      JOIN RESOURCE_ASSIGN_ROLES s ON p.PROFILE_ID=s.RES_ASSIGNMENT_ID+
1:n      LEFT OUTER JOIN TMT_COMPETENCIES r ON s.ROLE_ID=r.ELEMENT_ID:n      L+
1EFT OUTER JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.PARENT_ID:n      LEFT OUT+
1ER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID:n      ORDER BY RES_TYPE, RESOURCE_I+
1D, TYPE_ID:
1376:
1                EXIT:: SP_S_PROFILE(377) :: cplan.sql(13680) :: :
16:
1DELETE FROM PMO_TMP_RES_DATA:
1PMO_TMP_RES_DATA:
1RA:
1PROJECT_ASSIGNMENT_ID:
1T:
1TASK_ID:
1INSERT INTO PMO_TMP_RES_DATA (RESOURCE_ID, TYPE_ID):n         SELECT DISTINCT+
1:n         ra.RESOURCE_ID,:n         CASE WHEN ta.TSK_ASSIGNMENT_ID IS NuLL T+
1HEN 185 ELSE 13 END AS TYPE_ID:n         FROM RESOURCE_ASSIGNMENTS ra LEFT OU+
1TER JOIN TASK_ASSIGNMENTS ta ON ta.PROJECT_ID=h_id AND ra.RESOURCE_ID = ta.RE+
1SOURCE_ID:n         WHERE ra.PROJECT_ID=h_id AND ra.RESOURCE_TYPE='0' AND ta.+
1PROJECT_ASSIGNMENT_ID IS NuLL AND:n         NOT EXISTS(SELECT * FROM TASK_ASS+
1IGNMENTS t WHERE ra.RESOURCE_ID = t.RESOURCE_ID AND t.TASK_ID=h_id):
1404:
1           EXCEPTION:: SP_S_PROFILE(405) :: cplan.sql(13708) :: :
1FC_U_CREATETMPTABLE:
1PMO_TMP_CPLN01_TEMP:
1ELEMENT_TYPE:
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME):n         SELECT DIS+
1TINCT r.PROFILE_ID ,r.PROFILE_NAME:n         FROM RESOURCE_ASSIGNMENTS a JOIN+
1 PROFILES r ON a.RESOURCE_TYPE='1' AND r.PROFILE_ID=a.RESOURCE_ID :n         +
1JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.ROLE_ID:n         JOIN TMT_COMPETEN+
1CIES d ON d.ELEMENT_ID=c.PARENT_ID :n         JOIN TASK_ASSIGNMENTS t ON t.RE+
1S_ASSIGNMENT_ID=a.RES_ASSIGNMENT_ID AND t.PROJECT_ASSIGNMENT_ID IS NuLL:n    +
1     WHERE a.PROJECT_ID=h_id AND a.ELEMENT_TYPE>1:
1431:
1           EXCEPTION:: SP_S_PROFILE(432) :: cplan.sql(13735) :: :
1TO_TIMESTAMP:
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_EFFORT:
1START_DATE:
1FINISH_DATE:
1WORK:
1REMAINING:
1T_UNIT:
1BEST_START:
1BEST_FINISH:
1CALENDAR:
1PLANNED_WORK:
1PERIOD_AVAILABILITY:
1ASSIGN_STRING:
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME,a.TYPE_ID,p.E_MAIL_ADDRESS,:n      TO_TIMESTAMP('1899-12-31 00::00+
1::00') AS PLANNED_START, TO_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_FIN+
1ISH,0 AS PLANNED_EFFORT,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS STAR+
1T_DATE, TO_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DATE, 0 AS WORK, 0 AS+
1 REMAINING,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,'' AS BEST_START,'' AS BES+
1T_FINISH,:n      0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, +
1'' AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_RES_DATA+
1 a JOIN RESOURCES p ON a.RESOURCE_ID=p.RESOURCE_ID:n      :n      UNION ALL:n+
1      :n      SELECT ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, ELEMENT_NAME,41 AS T+
1YPE_ID,'' AS E_MAIL_ADDRESS,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS +
1PLANNED_START, TO_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_FINISH,0 AS P+
1LANNED_EFFORT,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS START_DATE, TO+
1_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DATE, 0 AS WORK, 0 AS REMAINING+
1,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  AS BEST+
1_FINISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASS+
1IGN_STRING, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_CPLN01_TEMP:n    +
1  ORDER BY TYPE_ID:
1451:
1                EXIT:: SP_S_PROFILE(452) :: cplan.sql(13755) :: :
1PARTICIPANT:
1START_DT:
1FINISH_DT:
1WORK_LOCATION:
1SECURITY_ID:
1G:
1SECURITY_NAME:
1CRI_SECURITY_ID:
1G2:
1CRI_SECURITY_NAME:
1REGULAR_RATE:
1SPECIAL_RATE:
1FS_LABOR_CODE:
1REC_STATUS:
1TIMECODE2_ID:
1TC:
1TIMECODE2:
1C_EFFORT:
1C_UNIT:
1C_CONTOUR:
1CONTOUR_TYPE:
1C_OCCURRENCE:
1BILLABLE:
1ASSIGNMENT_DELAY:
1TMT_GLOBAL_SECURITY:
1TMT_TIMECODES:
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID,:n      a.PROFILE_ID, p.PROFILE_NAME +
1AS ELEMENT_NAME,41 AS TYPE_ID,a.RES_ASSIGNMENT_ID, a.PARTICIPANT, t.PLANNED_S+
1TART,t.PLANNED_FINISH,:n      t.PLANNED_WORK,t.START_DT,t.FINISH_DT,h_per_day+
1 AS MINUTE_PER_DAY, a.WORK_LOCATION, a.SECURITY_ID, g.ELEMENT_NAME AS SECURIT+
1Y_NAME,:n      COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, +
1g2.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SPECIAL+
1_COST,t.SPECIAL_RATE,'' AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,:n     +
1 t.PROJECT_ASSIGNMENT_ID,t.TIMECODE2_ID,TC.ELEMENT_NAME AS TIMECODE2, t.T_UNI+
1T, t.C_EFFORT, t.C_UNIT, t.C_CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, BILLABL+
1E,:n      t.ASSIGNMENT_DELAY:n      FROM RESOURCE_ASSIGNMENTS a LEFT OUTER JO+
1IN TASK_ASSIGNMENTS t ON t.TASK_ID = h_id AND a.RES_ASSIGNMENT_ID = t.RES_ASS+
1IGNMENT_ID:n      LEFT OUTER JOIN PROFILES p ON a.RESOURCE_ID = p.PROFILE_ID +
1LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=g.ELEMENT_ID:n      LE+
1FT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY+
1_ID)=g2.ELEMENT_ID:n      LEFT OUTER JOIN TMT_TIMECODES TC ON TC.ELEMENT_ID= +
1t.TIMECODE2_ID:n      WHERE a.ELEMENT_ID = h_id AND a.RESOURCE_TYPE='1' ORDER+
1 BY ELEMENT_NAME:
1467:
1                EXIT:: SP_S_PROFILE(468) :: cplan.sql(13771) :: :
1ISTASK:
1COUNT:
1SELECT COUNT(*) INTO h_count FROM TASK_ASSIGNMENTS WHERE PROJECT_ID = h_proje+
1ct_id AND TASK_ID = h_id:
1483:
1           EXCEPTION:: SP_S_PROFILE(484) :: cplan.sql(13787) :: :
1DUAL:
1BIT_FLAG:
1SELECT COUNT('X') INTO h_count FROM DUAL WHERE EXISTS (:n               SELEC+
1T 'X' FROM TASK_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND TASK_ID = h_i+
1d AND BIT_FLAG = '0'):
1503:
1           EXCEPTION:: SP_S_PROFILE(504) :: cplan.sql(13807) :: :
1TIMESHEET_APPROVAL_STATUS:
1APV:
1TO_DATE:
1ACTUAL_START:
1WEEK_OF:
1SELECT COUNT('X') INTO h_count FROM DUAL WHERE EXISTS (:n                  SE+
1LECT 'X' FROM TASK_ASSIGNMENTS ta JOIN TIMESHEET_APPROVAL_STATUS apv:n       +
1           ON apv.ELEMENT_ID = ta.PROJECT_ID AND apv.RESOURCE_ID = ta.RESOURC+
1E_ID:n                  WHERE ta.PROJECT_ID = h_project_id AND ta.TASK_ID = h+
1_id AND:n                  (TO_DATE(SubStr(ta.ACTUAL_START, 1, 10)) - 7     )+
1 <= apv.WEEK_OF):
1523:
1           EXCEPTION:: SP_S_PROFILE(524) :: cplan.sql(13827) :: :
1SD:
1FD:
1SCHED_EFFORT:
1WORK_TODATE:
1UNITS_PERCENT:
1MILESTONE_PERCENT:
1TRUNC:
1TO_NUMBER:
1WORK_PERCENT:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1FORECAST_START:
1FORECAST_FINISH:
1ETC:
1ACTUAL_FINISH:
1ACTUAL:
1PROPOSED_START:
1PROPOSED_FINISH:
1PROPOSED_EFFORT:
1PROPOSED_WORK:
1CLOB_DATA:
1EMPTYLOB:
1BASELINE1_START:
1BASELINE1_FINISH:
1BASELINE1_EFFORT:
1BASELINE1_WORK:
1TIMECODE2_NAME:
1CAPITAL_EXPENSE:
1RATE_ADJUSTMENT:
1ASSIGN_COUNT:
1DURATION:
1LEVEL_START:
1LEVEL_FINISH:
1LEVEL_DURATION:
1LEVEL_EFFORT:
1PERCENT_DISCRETE:
1TOP_ID:
1LEVEL_AFFECTED_FLAG:
1LABOR_COST_CC_ID:
1LABOR_COST_CC_NAME:
1LABOR_REVENUE_CC_ID:
1LABOR_REVENUE_CC_NAME:
1DEFAULT_LABOR_FLAG:
1CONTRACT_ID:
1CONTRACT_NAME:
1EXTERNAL_ID:
1SCHED_FINISH:
1SC_UFS:
1SC_FS:
1SC_SS:
1SC_FF:
1SC_SF:
1SCHED_START:
1SCHED_WORK:
1ASSIGN_UNITS:
1UNITS_MSP:
1SCHED_DURATION:
1PLANNED_DURATION:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1EC:
1CC:
1CTR:
1TMT_CHARGECODES:
1TMT_CONTRACTS:
1SELECT t.ELEMENT_ID, a.RESOURCE_ID, t.ELEMENT_NAME, t.TYPE_ID, '' AS RES_ASSI+
1GNMENT_ID, a.PARTICIPANT, t.START_DT,t.FINISH_DT,:n         t.SD, t.FD, t.STA+
1RT_DT AS PLANNED_START, t.FINISH_DT AS PLANNED_FINISH,:n         t.SCHED_EFFO+
1RT + t.PLANNED_EFFORT AS PLANNED_WORK, t.SCHED_EFFORT + t.PLANNED_EFFORT - t.+
1WORK_TODATE AS REMAINING,:n         0 UNITS_PERCENT, t.MILESTONE_PERCENT,:n  +
1       CASE WHEN t.WORK_TODATE = 0 THEN 0 ELSE Trunc((TO_NUMBER(t.WORK_TODATE+
1)/TO_NUMBER(t.SCHED_EFFORT + t.PLANNED_EFFORT))*10000) END AS WORK_PERCENT,:n+
1         TO_TIMESTAMP('1899-12-31 00::00::00') AS BAK_START_DT,TO_TIMESTAMP('+
11899-12-31 00::00::00') AS BAK_FINISH_DT,0 AS BAK_WORK,:n         t.FORECAST_+
1START,t.FORECAST_FINISH,t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n         t.WO+
1RK_TODATE AS ACTUAL,t.PROPOSED_START, t.PROPOSED_FINISH, t.PROPOSED_EFFORT AS+
1 PROPOSED_WORK,:n         h_per_day AS MINUTE_PER_DAY, 0 AS WORK_LOCATION, ''+
1 AS SECURITY_ID, '' AS SECURITY_NAME,:n         '' AS CRI_SECURITY_ID, '' AS +
1CRI_SECURITY_NAME, 0.00 AS REGULAR_COST,0.00 AS REGULAR_RATE,0.00 AS SPECIAL_+
1COST,0.00 AS SPECIAL_RATE,:n         '' AS FS_LABOR_CODE,t.REC_STATUS,(SELECT+
1 CLOB_DATA FROM EMPTYLOB) AS ASSIGN_STRING,t.BASELINE1_START,t.BASELINE1_FINI+
1SH,t.BASELINE1_EFFORT AS BASELINE1_WORK,:n         '' AS PROJECT_ASSIGNMENT_I+
1D,'' AS TIMECODE2_ID, '' AS TIMECODE2_NAME, 0 AS T_UNIT, 0 AS C_EFFORT, 0 AS +
1C_UNIT, 0 AS C_CONTOUR, 0 AS CONTOUR_TYPE, 0 AS C_OCCURRENCE, 0 AS BILLABLE, +
10 AS CAPITAL_EXPENSE,:n         0 AS ASSIGNMENT_DELAY, h_bit_flag AS BIT_FLAG+
1, 0 AS RATE_ADJUSTMENT, t.ASSIGN_COUNT, t.DURATION,:n         CASE WHEN h_lev+
1el_state = 1 THEN t.LEVEL_START ELSE TO_TIMESTAMP('1899-12-31 00::00::00') EN+
1D AS LEVEL_START,:n         CASE WHEN h_level_state = 1 THEN t.LEVEL_FINISH E+
1LSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_FINISH,:n         CASE+
1 WHEN h_level_state = 1 THEN t.LEVEL_DURATION ELSE 0 END AS LEVEL_EFFORT, t.W+
1ORK_PERCENT AS PERCENT_DISCRETE, 0 as TOP_ID, '0' AS LEVEL_AFFECTED_FLAG,:n  +
1       '' AS LABOR_COST_CC_ID, '' AS LABOR_COST_CC_NAME, '' AS LABOR_REVENUE_+
1CC_ID, '' AS LABOR_REVENUE_CC_NAME, 'N' AS DEFAULT_LABOR_FLAG,:n         '' A+
1S CONTRACT_ID, '' AS CONTRACT_NAME, '' AS EXTERNAL_ID:n         FROM TMT_WBS +
1t LEFT JOIN RESOURCE_ASSIGNMENTS a ON a.ELEMENT_ID = t.ELEMENT_ID AND a.RESOU+
1RCE_ID = h_rec_user:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECU+
1RITY_ID=g.ELEMENT_ID:n         WHERE t.PROJECT_ID = h_project_id AND t.ELEMEN+
1T_ID = h_id:n         UNION ALL:n         SELECT CASE WHEN t.TSK_ASSIGNMENT_I+
1D IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELSE a.RES_ASSIGNMENT_ID END AS ELEMEN+
1T_ID, a.RESOURCE_ID,:n         CASE WHEN a.RESOURCE_TYPE='1' THEN (SELECT p.P+
1ROFILE_NAME FROM PROFILES p WHERE a.RESOURCE_ID = p.PROFILE_ID):n         ELS+
1E (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID) E+
1ND AS ELEMENT_NAME,:n         CASE WHEN a.RESOURCE_TYPE='1' THEN 41 WHEN t.TS+
1K_ASSIGNMENT_ID IS NuLL THEN 185 ELSE 13 END AS TYPE_ID,:n         a.RES_ASSI+
1GNMENT_ID, a.PARTICIPANT, t.START_DT, COALESCE(PLANNED_FINISH,SCHED_FINISH) A+
1S FINISH_DT,:n         CASE WHEN t.SD = pmo_cnst.SC_UFS OR t.SD = pmo_cnst.SC+
1_FS THEN pmo_cnst.SC_SS ELSE t.SD END AS SD, CASE WHEN t.FD = pmo_cnst.SC_FF +
1THEN pmo_cnst.SC_SF ELSE t.FD END AS FD, :n         COALESCE(PLANNED_START,SC+
1HED_START) AS PLANNED_START, COALESCE(PLANNED_FINISH,SCHED_FINISH) AS PLANNED+
1_FINISH,:n         CASE WHEN t.BIT_FLAG = '2' THEN t.SCHED_WORK ELSE t.PLANNE+
1D_WORK END AS PLANNED_WORK,:n         CASE WHEN t.BIT_FLAG = '2' THEN t.SCHED+
1_WORK - t.WORK_TODATE ELSE t.PLANNED_WORK END AS REMAINING,:n         CASE WH+
1EN t.ASSIGN_UNITS > t.UNITS_MSP THEN t.ASSIGN_UNITS ELSE t.UNITS_MSP END AS U+
1NITS_PERCENT,:n         0 AS MILESTONE_PERCENT,:n         CASE WHEN t.WORK_TO+
1DATE = 0 THEN 0 ELSE Trunc((TO_NUMBER(t.WORK_TODATE)/TO_NUMBER(PLANNED_WORK+S+
1CHED_WORK))*10000) END AS WORK_PERCENT,:n         t.BAK_START_DT,t.BAK_FINISH+
1_DT,t.BAK_WORK,:n         t.FORECAST_START,t.FORECAST_FINISH,t.ETC, t.ACTUAL_+
1START,t.ACTUAL_FINISH,:n         t.WORK_TODATE AS ACTUAL,PROPOSED_START, PROP+
1OSED_FINISH, PROPOSED_WORK,:n         h_per_day AS MINUTE_PER_DAY, a.WORK_LOC+
1ATION, a.SECURITY_ID, g.ELEMENT_NAME AS SECURITY_NAME,:n         COALESCE(a.C+
1RI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, g2.ELEMENT_NAME AS CRI_SECU+
1RITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SPECIAL_COST,t.SPECIAL_RATE,:n    +
1     CASE WHEN a.RESOURCE_TYPE='0' THEN (SELECT r.FS_LABOR_CODE FROM RESOURCE+
1S r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n         ELSE '' END AS FS_LABOR_CO+
1DE,a.REC_STATUS,t.ASSIGN_STRING,t.BASELINE1_START,t.BASELINE1_FINISH,t.BASELI+
1NE1_WORK,:n         t.PROJECT_ASSIGNMENT_ID,t.TIMECODE2_ID, TC.ELEMENT_NAME A+
1S TIMECODE2_NAME, t.T_UNIT, t.C_EFFORT, t.C_UNIT, t.C_CONTOUR, t.CONTOUR_TYPE+
1, t.C_OCCURRENCE, t.BILLABLE, t.CAPITAL_EXPENSE,:n         t.ASSIGNMENT_DELAY+
1, CASE WHEN t.BIT_FLAG IS NuLL THEN '' WHEN t.BIT_FLAG = '0' THEN '1' ELSE '2+
1' END AS BIT_FLAG, t.RATE_ADJUSTMENT, 0 AS ASSIGN_COUNT, :n         CASE WHEN+
1 t.BIT_FLAG = '2' THEN t.SCHED_DURATION ELSE t.PLANNED_DURATION END AS DURATI+
1ON,:n         CASE WHEN h_level_state = 1 THEN COALESCE(t.LEVEL_START,t.UNRES+
1OLVED_START) ELSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_START,:n+
1         CASE WHEN h_level_state = 1 THEN COALESCE(t.LEVEL_FINISH,t.UNRESOLVE+
1D_FINISH) ELSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_FINISH,:n  +
1       CASE WHEN h_level_state = 1 THEN CASE WHEN t.LEVEL_EFFORT = 0 THEN t.E+
1TC ELSE t.LEVEL_EFFORT END ELSE 0 END AS LEVEL_EFFORT, t.MILESTONE_PERCENT AS+
1 PERCENT_DISCRETE, 1 as TOP_ID, '0' AS LEVEL_AFFECTED_FLAG,:n         T.LABOR+
1_COST_CC_ID,:n         EC.ELEMENT_NAME AS LABOR_COST_CC_NAME,:n         T.LAB+
1OR_REVENUE_CC_ID,:n         CC.ELEMENT_NAME AS LABOR_REVENUE_CC_NAME, T.DEFAU+
1LT_LABOR_FLAG,:n         T.CONTRACT_ID, CTR.ELEMENT_NAME AS CONTRACT_NAME,:n +
1        CASE WHEN a.RESOURCE_TYPE= '0' THEN (SELECT r.EXTERNAL_ID FROM RESOUR+
1CES r WHERE a.RESOURCE_ID = r.RESOURCE_ID) ELSE '' END AS EXTERNAL_ID:n      +
1   FROM RESOURCE_ASSIGNMENTS a LEFT OUTER JOIN TASK_ASSIGNMENTS t ON a.RES_AS+
1SIGNMENT_ID = t.RES_ASSIGNMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURI+
1TY g ON a.SECURITY_ID=g.ELEMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECUR+
1ITY g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n         L+
1EFT OUTER JOIN TMT_TIMECODES TC ON TC.ELEMENT_ID= t.TIMECODE2_ID:n         LE+
1FT OUTER JOIN TMT_CHARGECODES EC ON EC.ELEMENT_ID = T.LABOR_COST_CC_ID:n     +
1    LEFT OUTER JOIN TMT_CHARGECODES CC ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_+
1ID:n         LEFT OUTER JOIN TMT_CONTRACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT+
1_ID:n         WHERE a.PROJECT_ID = h_project_id AND a.ELEMENT_ID = h_id AND a+
1.REC_STATUS NOT IN ('L','D'):n         ORDER BY TOP_ID, ELEMENT_NAME:
1605:
1                EXIT:: SP_S_PROFILE(606) :: cplan.sql(13909) :: :
1TMT_ORGANIZATIONS:
1SC_PROFILE:
1SC_POOLS:
1SC_ORGANIZATION:
1SC_RESOURCE:
1BEST:
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID,a.RESOURCE_ID,:n         CASE WHEN a.+
1RESOURCE_TYPE='0' THEN (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.RESOURCE_+
1ID = r.RESOURCE_ID):n         WHEN a.RESOURCE_TYPE='1' THEN (SELECT p.PROFILE+
1_NAME FROM PROFILES p WHERE a.RESOURCE_ID = p.PROFILE_ID):n         WHEN a.RE+
1SOURCE_TYPE='2' THEN (SELECT p.ELEMENT_NAME FROM TMT_POOLS p WHERE a.RESOURCE+
1_ID = p.ELEMENT_ID):n         ELSE (SELECT p.ELEMENT_NAME FROM TMT_ORGANIZATI+
1ONS p WHERE a.RESOURCE_ID = p.ELEMENT_ID) END AS ELEMENT_NAME,:n         CASE+
1 WHEN a.RESOURCE_TYPE='1' THEN pmo_cnst.SC_PROFILE:n         WHEN a.RESOURCE_+
1TYPE='2' THEN pmo_cnst.SC_POOLS :n         WHEN a.RESOURCE_TYPE='3' THEN pmo_+
1cnst.SC_ORGANIZATION :n         WHEN t.TSK_ASSIGNMENT_ID IS NuLL THEN 185 ELS+
1E pmo_cnst.SC_RESOURCE END AS TYPE_ID,:n         a.RES_ASSIGNMENT_ID, a.PARTI+
1CIPANT, t.START_DT,t.FINISH_DT,:n         t.SD, t.FD, COALESCE(PLANNED_START,+
1SCHED_START) AS PLANNED_START, COALESCE(PLANNED_FINISH,SCHED_FINISH) AS PLANN+
1ED_FINISH,:n         t.BEST AS PLANNED_WORK, CASE WHEN t.BIT_FLAG = '2' THEN +
1t.SCHED_WORK ELSE t.PLANNED_WORK END AS REMAINING,:n         t.UNITS_MSP AS U+
1NITS_PERCENT, t.MILESTONE_PERCENT, 0 AS WORK_PERCENT,:n         t.BAK_START_D+
1T,t.BAK_FINISH_DT,t.BAK_WORK,:n         t.FORECAST_START,t.FORECAST_FINISH,t.+
1ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n         t.WORK_TODATE AS ACTUAL,PROPOS+
1ED_START, PROPOSED_FINISH, PROPOSED_WORK,:n         h_per_day AS MINUTE_PER_D+
1AY, a.WORK_LOCATION, a.SECURITY_ID, g.ELEMENT_NAME AS SECURITY_NAME,:n       +
1  COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, g2.ELEMENT_NA+
1ME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SPECIAL_COST,t.SPECI+
1AL_RATE,:n         CASE WHEN a.RESOURCE_TYPE='0' THEN (SELECT r.FS_LABOR_CODE+
1 FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n         ELSE '' END +
1AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,t.BASELINE1_START,t.BASELINE1_F+
1INISH,t.BASELINE1_WORK,:n         t.PROJECT_ASSIGNMENT_ID,t.TIMECODE2_ID, TC.+
1ELEMENT_NAME AS TIMECODE2_NAME, t.T_UNIT, t.C_EFFORT, t.C_UNIT, t.C_CONTOUR, +
1t.CONTOUR_TYPE, t.C_OCCURRENCE, t.BILLABLE, t.CAPITAL_EXPENSE,:n         t.AS+
1SIGNMENT_DELAY, CASE WHEN t.BIT_FLAG IS NuLL THEN '' WHEN t.BIT_FLAG = '0' TH+
1EN '1' ELSE '2' END AS BIT_FLAG, t.RATE_ADJUSTMENT, 0 AS ASSIGN_COUNT, 0 AS D+
1URATION,:n         t.LEVEL_START, t.LEVEL_FINISH, t.LEVEL_EFFORT, t.MILESTONE+
1_PERCENT AS PERCENT_DISCRETE, 0 as TOP_ID,:n         CASE WHEN t.TSK_ASSIGNME+
1NT_ID IS NOT NuLL AND t.PROJECT_ASSIGNMENT_ID = t.TSK_ASSIGNMENT_ID AND (t.LE+
1VEL_START <> t.UNRESOLVED_START OR t.LEVEL_FINISH <> t.UNRESOLVED_FINISH) THE+
1N '1' ELSE '0' END AS LEVEL_AFFECTED_FLAG,:n         T.LABOR_COST_CC_ID,:n   +
1      EC.ELEMENT_NAME AS LABOR_COST_CC_NAME,:n         T.LABOR_REVENUE_CC_ID,+
1:n         CC.ELEMENT_NAME AS LABOR_REVENUE_CC_NAME, T.DEFAULT_LABOR_FLAG,:n +
1        T.CONTRACT_ID, CTR.ELEMENT_NAME AS CONTRACT_NAME,:n         CASE WHEN+
1 a.RESOURCE_TYPE= '0' THEN (SELECT r.EXTERNAL_ID FROM RESOURCES r WHERE a.RES+
1OURCE_ID = r.RESOURCE_ID) ELSE '' END AS EXTERNAL_ID:n         FROM RESOURCE_+
1ASSIGNMENTS a LEFT OUTER JOIN TASK_ASSIGNMENTS t ON a.RES_ASSIGNMENT_ID = t.R+
1ES_ASSIGNMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURIT+
1Y_ID=g.ELEMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESC+
1E(a.CRI_SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n         LEFT OUTER JOIN TM+
1T_TIMECODES TC ON TC.ELEMENT_ID= t.TIMECODE2_ID:n         LEFT OUTER JOIN TMT+
1_CHARGECODES EC ON EC.ELEMENT_ID = T.LABOR_COST_CC_ID:n         LEFT OUTER JO+
1IN TMT_CHARGECODES CC ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_ID:n         LEFT+
1 OUTER JOIN TMT_CONTRACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT_ID:n         WHE+
1RE a.REC_STATUS NOT IN ('L','D') AND a.ELEMENT_ID = h_id:n         ORDER BY T+
1YPE_ID, ELEMENT_NAME:
1651:
1                EXIT:: SP_S_PROFILE(652) :: cplan.sql(13955) :: :
14:
1DELETE FROM PMO_TMP_RES_SET:
1PMO_TMP_RES_SET:
1MIN:
1MAX:
1SUM:
1INSERT INTO PMO_TMP_RES_SET:n         (:n         RESOURCE_ID,:n         RESO+
1URCE_TYPE ,:n         PLANNED_START ,:n         PLANNED_FINISH ,:n         PL+
1ANNED_EFFORT ,:n         START_DATE ,:n         FINISH_DATE ,:n         WORK +
1,:n         REMAINING:n         ):n         SELECT:n         RESOURCE_ID,:n  +
1       RESOURCE_TYPE,:n         MIN(PLANNED_START) AS PLANNED_START,:n       +
1  MAX(PLANNED_FINISH) AS PLANNED_FINISH,:n         SUM(PLANNED_WORK) AS PLANN+
1ED_EFFORT,:n         MIN(SCHED_START) AS START_DATE,:n         MAX(SCHED_FINI+
1SH) AS FINISH_DATE,:n         SUM(SCHED_WORK) AS WORK,:n         SUM(ETC) AS +
1REMAINING:n         FROM TASK_ASSIGNMENTS WHERE PROJECT_ID=h_id AND PROJECT_A+
1SSIGNMENT_ID IS NuLL GROUP BY RESOURCE_ID, RESOURCE_TYPE:
1696:
1           EXCEPTION:: SP_S_PROFILE(697) :: cplan.sql(14000) :: :
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME, PLANNED_START, PLANN+
1ED_FINISH, PLANNED_EFFORT,START_DATE, FINISH_DATE,:n         WORK, REMAINING)+
1:n         SELECT DISTINCT r.PROFILE_ID,r.PROFILE_NAME,:n         a.PLANNED_S+
1TART, a.PLANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK,+
1 a.REMAINING:n         FROM PMO_TMP_RES_SET a JOIN PROFILES r ON a.RESOURCE_T+
1YPE='1' AND r.PROFILE_ID=a.RESOURCE_ID JOIN TMT_COMPETENCIES c ON c.ELEMENT_I+
1D=r.ROLE_ID:n         JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID:
1722:
1           EXCEPTION:: SP_S_PROFILE(723) :: cplan.sql(14026) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME,13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED_+
1FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 A+
1S T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS BEST_FINI+
1SH, 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_+
1STRING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_RES_S+
1ET a JOIN RESOURCES p ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_I+
1D:n      :n      UNION ALL:n      :n      SELECT ELEMENT_ID,'' AS RES_ASSIGNM+
1ENT_ID, ELEMENT_NAME,41 AS TYPE_ID,'' AS E_MAIL_ADDRESS,:n      PLANNED_START+
1, PLANNED_FINISH,PLANNED_EFFORT,   START_DATE, FINISH_DATE, WORK, REMAINING,0+
1 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  AS BEST_F+
1INISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIG+
1N_STRING,'' AS FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP+
1_CPLN01_TEMP ORDER BY TYPE_ID:
1739:
1                EXIT:: SP_S_PROFILE(740) :: cplan.sql(14043) :: :
15:
1783:
1           EXCEPTION:: SP_S_PROFILE(784) :: cplan.sql(14087) :: :
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME, RESOURCE_TYPE, TYPE_+
1ID, E_MAIL_ADDRESS, PLANNED_START, PLANNED_FINISH, PLANNED_EFFORT,START_DATE,+
1 FINISH_DATE,:n         WORK, REMAINING, FS_LABOR_CODE):n         SELECT DIST+
1INCT r.PROFILE_ID ,r.PROFILE_NAME ,'1',41 ,'',:n         a.PLANNED_START, a.P+
1LANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAIN+
1ING,:n         '':n         FROM PMO_TMP_RES_SET a JOIN PROFILES r ON a.RESOU+
1RCE_TYPE='1' AND r.PROFILE_ID=a.RESOURCE_ID JOIN TMT_COMPETENCIES c ON c.ELEM+
1ENT_ID=r.ROLE_ID:n         JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_I+
1D:n         UNION ALL:n         SELECT DISTINCT ra.RESOURCE_ID ,p.FULL_NAME ,+
1'0',185 ,p.E_MAIL_ADDRESS,:n         TO_TIMESTAMP('1899-12-31 00::00::00') , +
1TO_TIMESTAMP('1899-12-31 00::00::00') ,0 ,:n         TO_TIMESTAMP('1899-12-31+
1 00::00::00') , TO_TIMESTAMP('1899-12-31 00::00::00') , 0 , 0 ,p.FS_LABOR_COD+
1E:n         FROM RESOURCE_ASSIGNMENTS ra, RESOURCES p:n         WHERE ra.PROJ+
1ECT_ID=h_id AND ra.RESOURCE_ID = p.RESOURCE_ID:n         AND NOT EXISTS(SELEC+
1T ta.TSK_ASSIGNMENT_ID FROM TASK_ASSIGNMENTS ta:n         WHERE ta.RES_ASSIGN+
1MENT_ID IN (SELECT a.RES_ASSIGNMENT_ID:n         FROM RESOURCE_ASSIGNMENTS a +
1WHERE a.PROJECT_ID = ra.PROJECT_ID AND a.RESOURCE_ID = ra.RESOURCE_ID)):
1819:
1           EXCEPTION:: SP_S_PROFILE(820) :: cplan.sql(14123) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME,13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED_+
1FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 A+
1S T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS BEST_FINI+
1SH, 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_+
1STRING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_RES_S+
1ET a JOIN RESOURCES p ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_I+
1D:n      UNION ALL:n      SELECT ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, ELEMENT_+
1NAME,TYPE_ID,E_MAIL_ADDRESS,:n      PLANNED_START, PLANNED_FINISH,PLANNED_EFF+
1ORT,   START_DATE, FINISH_DATE, WORK, REMAINING,0 AS T_UNIT,h_per_day AS MINU+
1TE_PER_DAY,:n      '' AS BEST_START,''  AS BEST_FINISH,0 AS CALENDAR, 0 AS PL+
1ANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STRING, FS_LABOR_CODE, '' +
1AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_CPLN01_TEMP WHERE RESOURCE_TYPE=+
1'1' AND TYPE_ID = 41:n      UNION ALL:n      SELECT ELEMENT_ID,'' AS RES_ASSI+
1GNMENT_ID, ELEMENT_NAME,TYPE_ID,E_MAIL_ADDRESS,:n      PLANNED_START, PLANNED+
1_FINISH,PLANNED_EFFORT,:n      START_DATE, FINISH_DATE, WORK, REMAINING,0 AS +
1T_UNIT,h_per_day AS MINUTE_PER_DAY,'' AS BEST_START,'' AS BEST_FINISH,:n     +
1 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STR+
1ING,FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_CPLN01_TEM+
1P:n      WHERE RESOURCE_TYPE = '0' AND TYPE_ID = 185:n      ORDER BY TYPE_ID +
1DESC, ELEMENT_NAME:
1842:
1                EXIT:: SP_S_PROFILE(843) :: cplan.sql(14146) :: :
17:
1PLANNED_REMAINING:
1PA:
1DESCRIPTION:
1LEVEL_PLANNED_START:
1LEVEL_PLANNED_FINISH:
1LEVEL_SCHED_START:
1LEVEL_SCHED_FINISH:
1ESTIMATED_BASELINE1_START:
1ESTIMATED_BASELINE1_FINISH:
1ESTIMATED_BASELINE1_EFFORT:
1ESTIMATED_BASELINE3_START:
1ESTIMATED_BASELINE3_FINISH:
1ESTIMATED_BASELINE3_EFFORT:
1PROJECT_ASSIGNMENTS:
1SELECT t.RESOURCE_ID AS ELEMENT_ID, t.RES_ASSIGNMENT_ID, p.FULL_NAME AS ELEME+
1NT_NAME, 13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      b.PLANNED_START, b.PLANNED_FI+
1NISH, b.BEST AS PLANNED_EFFORT, b.PLANNED_WORK AS PLANNED_REMAINING, a.BAK_ST+
1ART_DT AS START_DATE, a.BAK_FINISH_DT AS FINISH_DATE,:n      a.BEST AS WORK, +
1a.SCHED_WORK AS REMAINING, h_per_day AS MINUTE_PER_DAY,'' AS BEST_START, '' A+
1S BEST_FINISH,:n      0 AS CALENDAR,0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILI+
1TY, (SELECT CLOB_DATA FROM EMPTYLOB) AS ASSIGN_STRING,p.FS_LABOR_CODE, '' AS +
1OBJECTIVES,'' AS RANK,:n      pa.REGULAR_COST, pa.REGULAR_RATE, pa.SPECIAL_CO+
1ST, pa.SPECIAL_RATE, pa.DESCRIPTION,:n      pa.LEVEL_PLANNED_START, pa.LEVEL_+
1PLANNED_FINISH, pa.LEVEL_SCHED_START, pa.LEVEL_SCHED_FINISH,:n      pa.ESTIMA+
1TED_BASELINE1_START, pa.ESTIMATED_BASELINE1_FINISH, pa.ESTIMATED_BASELINE1_EF+
1FORT,:n      pa.ESTIMATED_BASELINE3_START, pa.ESTIMATED_BASELINE3_FINISH, pa.+
1ESTIMATED_BASELINE3_EFFORT, P.EXTERNAL_ID:n      FROM RESOURCE_ASSIGNMENTS t +
1JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID = h_id AND pa.RESOURCE_ID = t.RE+
1SOURCE_ID:n      LEFT JOIN TASK_ASSIGNMENTS a ON a.RES_ASSIGNMENT_ID=t.RES_AS+
1SIGNMENT_ID AND a.BIT_FLAG='2':n      LEFT JOIN TASK_ASSIGNMENTS b ON b.RES_A+
1SSIGNMENT_ID=t.RES_ASSIGNMENT_ID AND b.BIT_FLAG='0':n      JOIN RESOURCES p O+
1N t.RESOURCE_ID=p.RESOURCE_ID:n      WHERE t.ELEMENT_ID=h_id AND t.RESOURCE_T+
1YPE='0' AND (a.TSK_ASSIGNMENT_ID IS NOT NuLL OR b.TSK_ASSIGNMENT_ID IS NOT Nu+
1LL):n      UNION ALL:n      SELECT t.RESOURCE_ID AS ELEMENT_ID, a.RES_ASSIGNM+
1ENT_ID, p.PROFILE_NAME AS ELEMENT_NAME, 41 AS TYPE_ID,'' AS E_MAIL_ADDRESS,:n+
1      t.PLANNED_START, t.PLANNED_FINISH,t.BEST AS PLANNED_EFFORT,t.PLANNED_WO+
1RK AS PLANNED_REMAINING,TO_TIMESTAMP('1899-12-31 00::00::00') AS START_DATE, +
1TO_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DATE,:n      0 AS WORK,0 AS R+
1EMAINING,h_per_day AS MINUTE_PER_DAY,'' AS BEST_START, '' AS BEST_FINISH,:n  +
1    0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, t.ASSIGN_STRI+
1NG,'' AS FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      pa.REGULAR_COST, +
1pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE, pa.DESCRIPTION,:n      pa.+
1LEVEL_PLANNED_START, pa.LEVEL_PLANNED_FINISH, pa.LEVEL_SCHED_START, pa.LEVEL_+
1SCHED_FINISH,:n      pa.ESTIMATED_BASELINE1_START, pa.ESTIMATED_BASELINE1_FIN+
1ISH, pa.ESTIMATED_BASELINE1_EFFORT,:n      pa.ESTIMATED_BASELINE3_START, pa.E+
1STIMATED_BASELINE3_FINISH, pa.ESTIMATED_BASELINE3_EFFORT, '' AS EXTERNAL_ID:n+
1      FROM RESOURCE_ASSIGNMENTS a JOIN PROFILES p ON a.RESOURCE_ID=p.PROFILE_+
1ID:n      JOIN TASK_ASSIGNMENTS t ON t.RES_ASSIGNMENT_ID=a.RES_ASSIGNMENT_ID+
1:n      JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID = h_id AND pa.RESOURCE_I+
1D = a.RESOURCE_ID:n      WHERE a.ELEMENT_ID=h_id AND a.RESOURCE_TYPE='1':n   +
1   ORDER BY TYPE_ID DESC, ELEMENT_NAME:
1940:
1                EXIT:: SP_S_PROFILE(941) :: cplan.sql(14244) :: :
18:
1DELETE FROM PMO_TMP_PRJ_INFO:
1PMO_TMP_PRJ_INFO:
1PRJ_PLANNED_START:
1PRJ_PLANNED_FINISH:
1PRJ_SCHED_START:
1PRJ_SCHED_FINISH:
1SCHED_REMAINING:
1INSERT INTO PMO_TMP_PRJ_INFO:n         (RESOURCE_ID,:n         RESOURCE_TYPE,+
1:n         PRJ_PLANNED_START,:n         PRJ_PLANNED_FINISH,:n         PLANNED+
1_REMAINING,:n         PLANNED_EFFORT,:n         PRJ_SCHED_START ,:n         P+
1RJ_SCHED_FINISH,:n         SCHED_REMAINING,:n         WORK,:n         TYPE_ID+
1:n         ):n         SELECT:n         RESOURCE_ID,:n         RESOURCE_TYPE,+
1:n         MIN(PLANNED_START)  AS PRJ_PLANNED_START,:n         MAX(PLANNED_FI+
1NISH) AS PRJ_PLANNED_FINISH,:n         SUM(PLANNED_WORK)   AS PLANNED_REMAINI+
1NG,:n         SUM(CASE WHEN BIT_FLAG='0' THEN BEST ELSE 0 END) AS PLANNED_EFF+
1ORT,:n         MIN(SCHED_START)    AS PRJ_SCHED_START,:n         MAX(SCHED_FI+
1NISH)   AS PRJ_SCHED_FINISH,:n         SUM(SCHED_WORK)     AS SCHED_REMAINING+
1,:n         SUM(CASE WHEN BIT_FLAG='2' THEN BEST ELSE 0 END) AS WORK, 13:n   +
1      FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_ID=h_id AND TASK_ID=h_id+
1:n         GROUP BY RESOURCE_ID, RESOURCE_TYPE:
1988:
1           EXCEPTION:: SP_S_PROFILE(989) :: cplan.sql(14292) :: :
1DELETE FROM PMO_TMP_RES_INFO:
1PMO_TMP_RES_INFO:
1INSERT INTO PMO_TMP_RES_INFO:n         (:n         RESOURCE_ID,:n         RES+
1OURCE_TYPE,:n         PLANNED_START,:n         PLANNED_FINISH,:n         PLAN+
1NED_EFFORT,:n         START_DATE,:n         FINISH_DATE,:n         WORK,:n   +
1      REMAINING,:n         PRJ_PLANNED_START,:n         PRJ_PLANNED_FINISH,:n+
1         PLANNED_REMAINING,:n         PRJ_SCHED_START,:n         PRJ_SCHED_FI+
1NISH,:n         SCHED_REMAINING,:n         LEVEL_PLANNED_START,:n         LEV+
1EL_PLANNED_FINISH,:n         LEVEL_SCHED_START,:n         LEVEL_SCHED_FINISH,+
1:n         ESTIMATED_BASELINE1_START,:n         ESTIMATED_BASELINE1_FINISH,:n+
1         ESTIMATED_BASELINE1_EFFORT,:n         ESTIMATED_BASELINE3_START,:n  +
1       ESTIMATED_BASELINE3_FINISH,:n         ESTIMATED_BASELINE3_EFFORT,:n   +
1      REGULAR_COST,:n         REGULAR_RATE,:n         SPECIAL_COST,:n        +
1 SPECIAL_RATE,:n         TYPE_ID,:n         DESCRIPTION:n         ):n        +
1 SELECT:n         a.RESOURCE_ID,      a.RESOURCE_TYPE,        a.PLANNED_START+
1,        a.PLANNED_FINISH,:n         a.PLANNED_WORK,     a.SCHED_START,      +
1    a.SCHED_FINISH,         a.SCHED_WORK,:n         a.ETC,              b.PRJ+
1_PLANNED_START,    b.PRJ_PLANNED_FINISH,   b.PLANNED_REMAINING,:n         b.P+
1RJ_SCHED_START,  b.PRJ_SCHED_FINISH,     b.SCHED_REMAINING,:n         a.LEVEL+
1_PLANNED_START, a.LEVEL_PLANNED_FINISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FI+
1NISH,:n         a.ESTIMATED_BASELINE1_START, a.ESTIMATED_BASELINE1_FINISH, a.+
1ESTIMATED_BASELINE1_EFFORT,:n         a.ESTIMATED_BASELINE3_START, a.ESTIMATE+
1D_BASELINE3_FINISH, a.ESTIMATED_BASELINE3_EFFORT,:n         a.REGULAR_COST,  +
1   a.REGULAR_RATE,         a.SPECIAL_COST,         a.SPECIAL_RATE,:n         +
1COALESCE(b.TYPE_ID,CASE WHEN (a.PLANNED_WORK+a.SCHED_WORK) = 0 THEN 185 ELSE +
113 END), a.DESCRIPTION:n         FROM PROJECT_ASSIGNMENTS a LEFT OUTER JOIN P+
1MO_TMP_PRJ_INFO b ON a.RESOURCE_ID = b.RESOURCE_ID:n         WHERE a.PROJECT_+
1ID=h_id:
11057:
1           EXCEPTION:: SP_S_PROFILE(1058) :: cplan.sql(14361) :: :
1RI:
1UPDATE PMO_TMP_RES_INFO RI SET TYPE_ID = 13 WHERE TYPE_ID = 185 AND EXISTS(:n+
1         SELECT TASK_ID FROM TASK_ASSIGNMENTS T WHERE T.PROJECT_ID=h_id AND T+
1.RESOURCE_ID = RI.RESOURCE_ID AND T.RESOURCE_TYPE = '0'):
11078:
1           EXCEPTION:: SP_S_PROFILE(1079) :: cplan.sql(14382) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME, a.TYPE_ID,p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED_FIN+
1ISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 AS T+
1_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS BEST_FINISH,+
1 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STR+
1ING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      CASE WHEN a.PRJ_PLAN+
1NED_START IS NOT NuLL OR a.PRJ_SCHED_START IS NOT NuLL THEN a.RESOURCE_ID ELS+
1E '' END AS PROJECT_ASSIGNMENT_ID, a.PRJ_PLANNED_START, a.PRJ_PLANNED_FINISH,+
1 a.PLANNED_REMAINING, a.PRJ_SCHED_START, a.PRJ_SCHED_FINISH, a.SCHED_REMAININ+
1G,:n      h_id AS PROJECT_ID,:n      a.LEVEL_PLANNED_START, a.LEVEL_PLANNED_F+
1INISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FINISH,:n      a.ESTIMATED_BASELINE+
11_START, a.ESTIMATED_BASELINE1_FINISH, a.ESTIMATED_BASELINE1_EFFORT,:n      a+
1.ESTIMATED_BASELINE3_START, a.ESTIMATED_BASELINE3_FINISH, a.ESTIMATED_BASELIN+
1E3_EFFORT,:n      a.REGULAR_COST, a.REGULAR_RATE, a.SPECIAL_COST, a.SPECIAL_R+
1ATE, a.DESCRIPTION, p.EXTERNAL_ID:n      FROM PMO_TMP_RES_INFO a JOIN RESOURC+
1ES p ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_ID:n      UNION AL+
1L:n      SELECT  r.PROFILE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, r.PROFIL+
1E_NAME AS ELEMENT_NAME,41 AS TYPE_ID,'' AS E_MAIL_ADDRESS,:n      a.PLANNED_S+
1TART, a.PLANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK,+
1 a.REMAINING,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START+
1,''  AS BEST_FINISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILIT+
1Y, '' AS ASSIGN_STRING,'' AS FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n   +
1   CASE WHEN a.PRJ_PLANNED_START IS NOT NuLL OR a.PRJ_SCHED_START IS NOT NuLL+
1 THEN a.RESOURCE_ID ELSE '' END AS PROJECT_ASSIGNMENT_ID, a.PRJ_PLANNED_START+
1, a.PRJ_PLANNED_FINISH, a.PLANNED_REMAINING, a.PRJ_SCHED_START, a.PRJ_SCHED_F+
1INISH, a.SCHED_REMAINING,:n      h_id AS PROJECT_ID,:n      a.LEVEL_PLANNED_S+
1TART, a.LEVEL_PLANNED_FINISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FINISH,:n   +
1   a.ESTIMATED_BASELINE1_START, a.ESTIMATED_BASELINE1_FINISH, a.ESTIMATED_BAS+
1ELINE1_EFFORT,:n      a.ESTIMATED_BASELINE3_START, a.ESTIMATED_BASELINE3_FINI+
1SH, a.ESTIMATED_BASELINE3_EFFORT,:n      a.REGULAR_COST, a.REGULAR_RATE, a.SP+
1ECIAL_COST, a.SPECIAL_RATE, a.DESCRIPTION, '' AS EXTERNAL_ID:n      FROM PMO_+
1TMP_RES_INFO a JOIN PROFILES r ON a.RESOURCE_TYPE='1' AND r.PROFILE_ID=a.RESO+
1URCE_ID:n      JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.ROLE_ID:n      JOIN +
1TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID:
11107:
1                EXIT:: SP_S_PROFILE(1108) :: cplan.sql(14411) :: :
1SELECT PROFILE_NAME INTO h_in FROM PROFILES WHERE PROFILE_ID = h_id:
11121:
1           EXCEPTION:: SP_S_PROFILE(1122) :: cplan.sql(14425) :: :
1SC_SQL_SUCCESS:
1ROLE_TYPE:
1ORG_ID:
1ORG:
1ORG_NAME:
1GEO_ID:
1GEO:
1GEO_NAME:
1POOL_ID:
1POOL:
1POOL_NAME:
1TMT_GEOGRAPHIES:
1DS:
1CS:
1PMO_ORASTD:
1STRINGCONCAT:
1RTRIM:
1SELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAME,41 AS TYPE_ID,30 AS ROLE_TYPE+
1, p.ROLE_ID, h_in AS ROLE_NAME,:n         ORG_ID, org.ELEMENT_NAME AS ORG_NAM+
1E, GEO_ID, geo.ELEMENT_NAME AS GEO_NAME, POOL_ID, pool.ELEMENT_NAME AS POOL_N+
1AME:n         FROM PROFILES p:n         LEFT JOIN TMT_ORGANIZATIONS org ON or+
1g.ELEMENT_ID  = ORG_ID:n         LEFT JOIN TMT_GEOGRAPHIES geo   ON geo.ELEME+
1NT_ID  = GEO_ID:n         LEFT JOIN TMT_POOLS pool        ON pool.ELEMENT_ID +
1= POOL_ID:n         WHERE p.PROFILE_ID = h_id:n         UNION ALL:n         S+
1ELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAME,41 AS TYPE_ID,ds.TYPE_ID AS RO+
1LE_TYPE,:n         cs.ELEMENT_ID AS ROLE_ID, PMO_ORASTD.StringConcat(PMO_ORAS+
1TD.StringConcat(RTRIM(ds.ELEMENT_NAME), ', '), RTRIM(cs.ELEMENT_NAME)) AS ROL+
1E_NAME,:n         '' ORG_ID, '' AS ORG_NAME, '' GEO_ID, '' AS GEO_NAME, '' PO+
1OL_ID, '' AS POOL_NAME:n         FROM RESOURCE_ASSIGN_ROLES r LEFT OUTER JOIN+
1 TMT_COMPETENCIES cs ON r.ROLE_ID=cs.ELEMENT_ID:n         LEFT OUTER JOIN TMT+
1_COMPETENCIES ds ON ds.ELEMENT_ID=cs.PARENT_ID WHERE r.RES_ASSIGNMENT_ID=h_id+
1:n         UNION ALL:n         SELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAM+
1E,41 AS TYPE_ID,ds.TYPE_ID AS ROLE_TYPE,:n         cs.ELEMENT_ID AS ROLE_ID, +
1PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(ds.ELEMENT_NAME), ', ')+
1, RTRIM(cs.ELEMENT_NAME)) AS ROLE_NAME,:n         '' ORG_ID, '' AS ORG_NAME, +
1'' GEO_ID, '' AS GEO_NAME, '' POOL_ID, '' AS POOL_NAME:n         FROM RESOURC+
1E_ASSIGN_SKILLS s LEFT OUTER JOIN TMT_COMPETENCIES cs ON s.SKILL_ID=cs.ELEMEN+
1T_ID:n         LEFT OUTER JOIN TMT_COMPETENCIES ds ON ds.ELEMENT_ID=cs.PARENT+
1_ID WHERE s.RES_ASSIGNMENT_ID=h_id:n         ORDER BY ELEMENT_ID,TYPE_ID:
11148:
1                EXIT:: SP_S_PROFILE(1149) :: cplan.sql(14452) :: :
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID, a.RESOURCE_ID,:n      CASE WHEN a.RE+
1SOURCE_TYPE='1' THEN (SELECT p.PROFILE_NAME FROM PROFILES p WHERE a.RESOURCE_+
1ID = p.PROFILE_ID):n      ELSE (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.R+
1ESOURCE_ID = r.RESOURCE_ID) END AS ELEMENT_NAME,:n      CASE WHEN t.TSK_ASSIG+
1NMENT_ID IS NuLL THEN 185 WHEN a.RESOURCE_TYPE='1' THEN 41 ELSE 13 END AS TYP+
1E_ID,:n      a.RES_ASSIGNMENT_ID, a.PARTICIPANT, t.START_DT, COALESCE(PLANNED+
1_FINISH,SCHED_FINISH) AS FINISH_DT,:n      t.SD, t.FD, COALESCE(PLANNED_START+
1,SCHED_START) AS PLANNED_START, COALESCE(PLANNED_FINISH,SCHED_FINISH) AS PLAN+
1NED_FINISH,:n      CASE WHEN BIT_FLAG = '2' THEN SCHED_WORK ELSE PLANNED_WORK+
1 END AS PLANNED_WORK,:n      CASE WHEN BIT_FLAG = '2' THEN SCHED_WORK - WORK_+
1TODATE ELSE PLANNED_WORK END AS REMAINING,:n      CASE WHEN t.ASSIGN_UNITS > +
1t.UNITS_MSP THEN t.ASSIGN_UNITS ELSE t.UNITS_MSP END AS UNITS_PERCENT,:n     +
1 0 AS MILESTONE_PERCENT,:n      CASE WHEN t.WORK_TODATE = 0 THEN 0 ELSE Trunc+
1((TO_NUMBER(t.WORK_TODATE)/TO_NUMBER(PLANNED_WORK+SCHED_WORK))*10000) END AS +
1WORK_PERCENT,:n      t.BAK_START_DT,t.BAK_FINISH_DT,t.BAK_WORK,:n      t.FORE+
1CAST_START,t.FORECAST_FINISH,t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n      t.+
1WORK_TODATE AS ACTUAL,PROPOSED_START, PROPOSED_FINISH, PROPOSED_WORK,:n      +
1h_per_day AS MINUTE_PER_DAY, a.WORK_LOCATION, a.SECURITY_ID, g.ELEMENT_NAME A+
1S SECURITY_NAME,:n      COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECU+
1RITY_ID, g2.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,+
1t.SPECIAL_COST,t.SPECIAL_RATE,:n      CASE WHEN a.RESOURCE_TYPE='0' THEN (SEL+
1ECT r.FS_LABOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n  +
1    ELSE '' END AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,t.BASELINE1_STA+
1RT,t.BASELINE1_FINISH,t.BASELINE1_WORK,:n      t.PROJECT_ASSIGNMENT_ID,t.TIME+
1CODE2_ID, TC.ELEMENT_NAME AS TIMECODE2_NAME, t.T_UNIT, t.C_EFFORT, t.C_UNIT, +
1t.C_CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, t.BILLABLE, t.CAPITAL_EXPENSE,:n+
1      t.ASSIGNMENT_DELAY, CASE WHEN t.BIT_FLAG IS NuLL THEN '' WHEN t.BIT_FLA+
1G = '0' THEN '1' ELSE '2' END AS BIT_FLAG, t.RATE_ADJUSTMENT, 0 AS ASSIGN_COU+
1NT, :n      CASE WHEN BIT_FLAG = '2' THEN SCHED_DURATION ELSE PLANNED_DURATIO+
1N END AS DURATION,:n      CASE WHEN h_level_state = 1 THEN COALESCE(t.LEVEL_S+
1TART,t.UNRESOLVED_START) ELSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LE+
1VEL_START,:n      CASE WHEN h_level_state = 1 THEN COALESCE(t.LEVEL_FINISH,t.+
1UNRESOLVED_FINISH) ELSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_FI+
1NISH,:n      CASE WHEN h_level_state = 1 THEN CASE WHEN t.LEVEL_EFFORT = 0 TH+
1EN t.ETC ELSE t.LEVEL_EFFORT END ELSE 0 END AS LEVEL_EFFORT, t.MILESTONE_PERC+
1ENT AS PERCENT_DISCRETE, 0 as TOP_ID,:n      CASE WHEN t.TSK_ASSIGNMENT_ID IS+
1 NOT NuLL AND t.PROJECT_ASSIGNMENT_ID = t.TSK_ASSIGNMENT_ID AND (t.LEVEL_STAR+
1T <> t.UNRESOLVED_START OR t.LEVEL_FINISH <> t.UNRESOLVED_FINISH) THEN '1' EL+
1SE '0' END AS LEVEL_AFFECTED_FLAG,:n      T.LABOR_COST_CC_ID,:n      EC.ELEME+
1NT_NAME AS LABOR_COST_CC_NAME,:n      T.LABOR_REVENUE_CC_ID,:n      CC.ELEMEN+
1T_NAME AS LABOR_REVENUE_CC_NAME, T.DEFAULT_LABOR_FLAG,:n      T.CONTRACT_ID, +
1CTR.ELEMENT_NAME AS CONTRACT_NAME:n      FROM RESOURCE_ASSIGNMENTS a JOIN TAS+
1K_ASSIGNMENTS t ON t.TSK_ASSIGNMENT_ID = h_id AND a.RES_ASSIGNMENT_ID = t.RES+
1_ASSIGNMENT_ID:n      LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=+
1g.ELEMENT_ID:n      LEFT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESCE(a.CRI_+
1SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n      LEFT OUTER JOIN TMT_TIMECODES+
1 TC ON TC.ELEMENT_ID= t.TIMECODE2_ID:n      LEFT OUTER JOIN TMT_CHARGECODES E+
1C ON EC.ELEMENT_ID = T.LABOR_COST_CC_ID:n      LEFT OUTER JOIN TMT_CHARGECODE+
1S CC ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_ID:n      LEFT OUTER JOIN TMT_CONT+
1RACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT_ID:n      ORDER BY TYPE_ID DESC, ELE+
1MENT_NAME:
11192:
1                EXIT:: SP_S_PROFILE(1193) :: cplan.sql(14496) :: :
1ACCEPTED_DATE:
1DELAY:
1SELECT a.RES_ASSIGNMENT_ID AS ELEMENT_ID, a.RESOURCE_ID,:n      CASE WHEN a.R+
1ESOURCE_TYPE='0' THEN (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.RESOURCE_I+
1D = r.RESOURCE_ID):n      WHEN a.RESOURCE_TYPE='2' THEN (SELECT p.ELEMENT_NAM+
1E FROM TMT_POOLS p WHERE a.RESOURCE_ID = p.ELEMENT_ID):n      ELSE (SELECT p.+
1ELEMENT_NAME FROM TMT_ORGANIZATIONS p WHERE a.RESOURCE_ID = p.ELEMENT_ID) END+
1 AS ELEMENT_NAME,:n      CASE WHEN a.RESOURCE_TYPE='2' THEN pmo_cnst.SC_POOLS+
1:n      WHEN a.RESOURCE_TYPE='3' THEN pmo_cnst.SC_ORGANIZATION :n      ELSE 1+
185 END AS TYPE_ID,  :n      a.RES_ASSIGNMENT_ID, a.PARTICIPANT, TO_TIMESTAMP(+
1'1899-12-31 00::00::00') AS PLANNED_START, TO_TIMESTAMP('1899-12-31 00::00::0+
10') AS PLANNED_FINISH,:n      0 AS PLANNED_WORK,TO_TIMESTAMP('1899-12-31 00::+
100::00') AS START_DT,TO_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DT,:n   +
1   TO_TIMESTAMP('1899-12-31 00::00::00') AS SCHED_START,TO_TIMESTAMP('1899-12+
1-31 00::00::00') AS SCHED_FINISH, 0 AS SCHED_WORK,:n      TO_TIMESTAMP('1899-+
112-31 00::00::00') AS BAK_START_DT,TO_TIMESTAMP('1899-12-31 00::00::00') AS B+
1AK_FINISH_DT, 0 AS BAK_WORK,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS +
1FORECAST_START,TO_TIMESTAMP('1899-12-31 00::00::00') AS FORECAST_FINISH,0 AS +
1ETC,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS ACTUAL_START,TO_TIMESTAM+
1P('1899-12-31 00::00::00') AS ACTUAL_FINISH,:n      0 AS ACTUAL,h_per_day AS +
1MINUTE_PER_DAY, a.WORK_LOCATION, TO_TIMESTAMP('1899-12-31 00::00::00') AS ACC+
1EPTED_DATE,:n      a.SECURITY_ID, g.ELEMENT_NAME AS SECURITY_NAME, COALESCE(a+
1.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, g2.ELEMENT_NAME AS CRI_SE+
1CURITY_NAME,:n      0 AS REGULAR_COST,0 AS REGULAR_RATE,0 AS SPECIAL_COST, 0 +
1AS SPECIAL_RATE,:n      CASE WHEN a.RESOURCE_TYPE='0' THEN (SELECT r.FS_LABOR+
1_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n      ELSE '' EN+
1D AS FS_LABOR_CODE,:n      a.REC_STATUS,'' AS ASSIGN_STRING,:n      TO_TIMEST+
1AMP('1899-12-31 00::00::00') AS BASELINE1_START,TO_TIMESTAMP('1899-12-31 00::+
100::00') AS BASELINE1_FINISH,0 AS BASELINE1_WORK,:n      '' AS PROJECT_ASSIGN+
1MENT_ID, '' AS TIMECODE2_ID, '' AS TIMECODE2_NAME, 0 AS T_UNIT,:n      0 AS C+
1_EFFORT, 0 AS C_UNIT, 0 AS C_CONTOUR, 0 AS CONTOUR_TYPE, 0 AS C_OCCURRENCE, 0+
1 AS BILLABLE,:n      0 AS DELAY:n      FROM RESOURCE_ASSIGNMENTS a:n      LEF+
1T OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=g.ELEMENT_ID:n      LEFT +
1OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID+
1)=g2.ELEMENT_ID:n      WHERE a.REC_STATUS NOT IN ('L','D') AND a.ELEMENT_ID =+
1 h_id:n      ORDER BY TYPE_ID DESC, ELEMENT_NAME:
11225:
1                EXIT:: SP_S_PROFILE(1226) :: cplan.sql(14529) :: :
112:
1DELETE FROM PMO_TMP_RTA:
1PMO_TMP_RTA:
1PA_FLAG:
1TABLE_TYPE:
1SC_TABLE_WBS:
1INSERT INTO PMO_TMP_RTA (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n         SELEC+
1T RESOURCE_ID, RESOURCE_TYPE, 'N' AS PA_FLAG:n         FROM TASK_ASSIGNMENTS+
1:n         WHERE PROJECT_ID = h_id AND:n         PROJECT_ASSIGNMENT_ID IS NuL+
1L AND:n         TABLE_TYPE = pmo_cnst.SC_TABLE_WBS:n         GROUP BY RESOURC+
1E_ID, RESOURCE_TYPE:
11255:
1           EXCEPTION:: SP_S_PROFILE(1256) :: cplan.sql(14559) :: :
1DELETE FROM PMO_TMP_CP_PRJ:
1PMO_TMP_CP_PRJ:
1INSERT INTO PMO_TMP_CP_PRJ (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n         SE+
1LECT  RESOURCE_ID, RESOURCE_TYPE, 'Y' AS PA_FLAG:n         FROM TASK_ASSIGNME+
1NTS:n         WHERE PROJECT_ID = h_id AND:n         TASK_ID = h_id:n         +
1GROUP BY RESOURCE_ID, RESOURCE_TYPE:
11283:
1           EXCEPTION:: SP_S_PROFILE(1284) :: cplan.sql(14587) :: :
1DELETE FROM PMO_TMP_RESOURCE_DATA:
1PMO_TMP_RESOURCE_DATA:
1INSERT INTO PMO_TMP_RESOURCE_DATA (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n    +
1     SELECT a.RESOURCE_ID, a.RESOURCE_TYPE, a.PA_FLAG:n         FROM PMO_TMP_+
1RTA a LEFT OUTER JOIN PMO_TMP_CP_PRJ b ON a.RESOURCE_ID=b.RESOURCE_ID:n      +
1   UNION:n         SELECT b.RESOURCE_ID, b.RESOURCE_TYPE, b.PA_FLAG:n        +
1 FROM PMO_TMP_CP_PRJ b LEFT OUTER JOIN PMO_TMP_RTA a ON a.RESOURCE_ID=b.RESOU+
1RCE_ID:
11311:
1           EXCEPTION:: SP_S_PROFILE(1312) :: cplan.sql(14615) :: :
1NICK_NAME:
1PRJ:
1RD:
1SELECT a.RESOURCE_ID AS ELEMENT_ID, p.FULL_NAME AS ELEMENT_NAME,13 AS TYPE_ID+
1, p.NICK_NAME, a.PA_FLAG:n      FROM PMO_TMP_RESOURCE_DATA a JOIN RESOURCES p+
1 ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_ID:n      LEFT OUTER J+
1OIN PMO_TMP_CP_PRJ PRJ ON a.RESOURCE_ID=PRJ.RESOURCE_ID:n      :n      UNION +
1ALL:n      :n      SELECT DISTINCT r.PROFILE_ID AS ELEMENT_ID, r.PROFILE_NAME+
1 AS ELEMENT_NAME,41 AS TYPE_ID, ' ' AS NICK_NAME, a.PA_FLAG:n      FROM PMO_T+
1MP_RESOURCE_DATA a JOIN PROFILES r ON a.RESOURCE_TYPE = '1' AND r.PROFILE_ID +
1= a.RESOURCE_ID:n      JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.ROLE_ID:n   +
1   JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID:n      LEFT OUTER JOIN+
1 PMO_TMP_CP_PRJ PRJ ON a.RESOURCE_ID=PRJ.RESOURCE_ID:n      :n      UNION ALL+
1:n      :n      SELECT DISTINCT ra.RESOURCE_ID AS ELEMENT_ID, p.FULL_NAME AS +
1ELEMENT_NAME, 185 AS TYPE_ID, p.NICK_NAME, 'N' AS PA_FLAG:n      FROM RESOURC+
1E_ASSIGNMENTS ra, RESOURCES p:n      WHERE ra.PROJECT_ID=h_id AND:n      ra.R+
1ESOURCE_ID = p.RESOURCE_ID AND:n      NOT EXISTS(SELECT rd.RESOURCE_ID FROM P+
1MO_TMP_RESOURCE_DATA rd WHERE ra.RESOURCE_ID = rd.RESOURCE_ID):n      ORDER B+
1Y TYPE_ID DESC, ELEMENT_NAME:
11337:
1                EXIT:: SP_S_PROFILE(1338) :: cplan.sql(14641) :: :
1%%:
1SELECT t.ELEMENT_ID, p.FULL_NAME AS ELEMENT_NAME,13 AS TYPE_ID, p.NICK_NAME, +
1'N' AS PA_FLAG:n      FROM TMT_POOLS t JOIN RESOURCES p:n      ON t.ELEMENT_I+
1D = p.RESOURCE_ID:n      WHERE t.TYPE_ID = 13:n      AND t.RANK LIKE h_rank:n+
1      ORDER BY ELEMENT_NAME:
11352:
1                EXIT:: SP_S_PROFILE(1353) :: cplan.sql(14656) :: :
1SELECT R.RESOURCE_ID AS ELEMENT_ID, R.FULL_NAME AS ELEMENT_NAME,pmo_cnst.SC_R+
1ESOURCE AS TYPE_ID, R.NICK_NAME, 'N' AS PA_FLAG:n      FROM PROJECT_ASSIGNMEN+
1TS RA, RESOURCES R:n      WHERE RA.PROJECT_ID = h_id:n      AND RA.RESOURCE_I+
1D = R.RESOURCE_ID:n      ORDER BY ELEMENT_NAME:
11366:
1                EXIT:: SP_S_PROFILE(1367) :: cplan.sql(14670) :: :
11371:
1       RETURN_STATUS:: SP_S_PROFILE(1372) :: cplan.sql(14675) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
11380:
1           EXCEPTION:: SP_S_PROFILE(1381) :: cplan.sql(14684) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11392:
1           EXCEPTION:: SP_S_PROFILE(1393) :: cplan.sql(14696) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2082
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 d :2 a0
d :2 a0 d :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 :18 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :15 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :4 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c b7 19 3c b7 19 3c
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :8 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 19 :2 a0 51 a5 b
7e 51 b4 2e :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c a0 51 d a0 b7 19 :2 a0
51 a5 b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b a0 7e a0 6b b4 2e 5a
a 10 :2 a0 51 a5 b a0 7e
a0 6b b4 2e 5a a 10 :8 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 :2 19 3c :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6e 11e 11d :2 a0 6b 51 d :22 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6e 11e 11d :2 a0 6b 51 d :7 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :12d a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :2 a0 6e
11e 11d :2 a0 6b 51 d :26 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 b4 2e d :2e a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :49 a0 12a e9 dd
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 65 a0 b7 19
:2 a0 51 a5 b 7e 51 b4 2e
:8d a0 12a e9 dd :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
65 a0 b7 19 :2 a0 51 a5 b
7e 51 b4 2e :3 a0 51 a5 b
a5 b 7e 51 b4 2e a0 51
d :7 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e a0 6e d b7 a0
51 d :9 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :1c a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e a0 6e
d b7 a0 6e d b7 :2 19 3c
b7 a0 6e d b7 :2 19 3c b7
:2 19 3c :212 a0 12a e9 dd :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 65 b7 :14e a0 12a e9 dd
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 65 b7 :2 19 3c
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6e 11e 11d :2 a0
6b 51 d :27 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 b4 2e
d :35 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :4c a0 12a e9 dd :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 65 a0 b7 19 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6e 11e
11d :2 a0 6b 51 d :27 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
b4 2e d :62 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :6a a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e :e7 a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6e 11e 11d :2 a0
6b 51 d :2f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6e 11e 11d :2 a0
6b 51 d :71 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :10 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :d8 a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b a0 7e a0 6b b4
2e :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :9a a0 12a e9 dd
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 65 b7 19 3c
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :143 a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e :a2 a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6e 11e 11d :2 a0
6b 51 d :10 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6e 11e 11d :2 a0
6b 51 d :e a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6e 11e 11d :2 a0
6b 51 d :26 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :6c a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e :3 a0
7e 6e b4 2e :2 51 a5 b d
:1a a0 12a e9 dd :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
65 a0 b7 19 :2 a0 51 a5 b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b a0 7e a0 6b b4
2e 5a 52 10 :1a a0 12a e9 dd
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 65 b7 19 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 19 3c b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
2082
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
133 122 126 101 12e 121 14f 13e
142 11e 14a 13d 16b 15a 15e 13a
166 159 187 176 17a 156 182 175
1a3 192 196 172 19e 191 1bf 1ae
1b2 18e 1ba 1ad 1df 1ca 1ce 1aa
1d2 1da 1c9 1ff 1ea 1ee 1c6 1f2
1fa 1e9 21f 20a 20e 1e6 212 21a
209 23f 22a 22e 206 232 23a 229
25f 24a 24e 226 252 25a 249 27f
26a 26e 246 272 27a 269 29f 28a
28e 266 292 29a 289 2bf 2aa 2ae
286 2b2 2ba 2a9 2df 2ca 2ce 2a6
2d2 2da 2c9 2ff 2ea 2ee 2c6 2f2
2fa 2e9 31f 30a 30e 2e6 312 31a
309 33f 32a 32e 306 332 33a 329
35f 34a 34e 326 352 35a 349 37f
36a 36e 346 372 37a 369 39f 38a
38e 366 392 39a 389 3bf 3aa 3ae
386 3b2 3ba 3a9 3c6 3ca 3a6 3ce
3d2 3d6 3d9 3de 3df 1 3e1 3e6
3ea 3ee 3f1 3f6 3fa 3fe 401 406
407 409 40e 411 415 416 41b 420
423 428 429 42e 431 435 436 43b
43e 443 444 449 44c 451 452 457
45a 45e 462 466 467 469 46e 46f
471 472 477 47a 47f 480 485 488
48d 48e 493 496 49a 49b 4a0 4a3
4a8 4a9 4ae 4b1 4b6 4b7 4bc 4bd
4c2 4c4 4c8 4cb 4cf 4d3 4d6 4da
4de 4e1 4e4 4e9 4ec 4ef 4f2 4f3
4f8 4f9 1 4fb 500 504 508 50b
510 515 518 51c 51d 522 523 528
52a 52e 531 535 538 539 53e 541
545 549 54c 550 554 557 55a 55f
562 565 568 569 56e 56f 1 571
576 57a 57e 581 586 58b 58e 592
593 598 59b 5a0 5a1 5a6 5a9 5ae
5af 5b4 5b7 5bb 5bf 5c3 5c7 5ca
5cb 5cd 5d2 5d3 5d5 5d6 5db 5de
5e3 5e4 5e9 5ec 5f1 5f2 5f7 5fa
5fe 5ff 604 607 60c 60d 612 613
618 61a 61e 621 625 629 62c 630
634 637 63a 63f 642 645 648 649
64e 64f 1 651 656 65a 65e 661
666 66b 66e 672 673 678 679 67e
680 684 687 68b 68f 692 696 69a
69d 6a1 6a5 6a6 6ab 6ad 6b1 6b4
6b8 6bc 6c0 6c4 6c8 6cc 6d0 6d4
6d8 6dc 6e0 6e3 6e4 6e6 6e9 6ec
6ed 6f2 6f5 6f9 6fd 700 701 703
706 709 70a 70f 1 712 717 71b
71f 723 727 72b 72f 733 737 73b
73f 743 747 74b 74f 753 757 75b
75f 763 767 76b 76f 773 777 783
787 78b 78e 792 796 798 79c 7a0
7a4 7a7 7ab 7af 7b1 7b2 7b7 1
7bb 7bf 7c3 7c6 7ca 7ce 7d2 7d6
7d9 7dd 7e1 7e4 7e7 7ec 7ef 7f2
7f5 7f6 7fb 7fc 1 7fe 803 807
80b 80e 813 818 81b 81f 820 825
828 82d 82e 833 836 83b 83c 841
844 848 849 84e 851 856 857 85c
85f 863 867 86a 86d 86e 870 871
876 877 87c 87e 882 885 887 88b
88d 899 89b 89d 89e 8a3 8a7 8a9
8b5 8b7 8bb 8bf 8c2 8c6 8c9 8cd
8d0 8d1 8d6 8d9 8dd 8e1 8e5 8e9
8ed 8f1 8f5 8f9 8fd 901 905 909
90d 911 915 919 91d 921 925 929
92d 939 93d 941 944 948 94c 94e
952 956 95a 95d 961 965 967 968
96d 1 971 975 979 97c 980 984
988 98c 98f 993 997 99a 99d 9a2
9a5 9a8 9ab 9ac 9b1 9b2 1 9b4
9b9 9bd 9c1 9c4 9c9 9ce 9d1 9d5
9d6 9db 9de 9e3 9e4 9e9 9ec 9f1
9f2 9f7 9fa 9fe 9ff a04 a07 a0c
a0d a12 a15 a19 a1d a20 a23 a24
a26 a27 a2c a2d a32 a34 a38 a3b
a3d a41 a43 a4f a51 a53 a54 a59
a5d a5f a6b a6d a71 a75 a78 a7c
a7f a83 a86 a87 a8c a8f a93 a97
a9b a9f aab aaf ab3 ab6 aba abe
ac0 ac4 ac8 acc acf ad3 ad7 ad9
ada adf 1 ae3 ae7 aeb aee af2
af6 afa afe b01 b05 b09 b0c b0f
b14 b17 b1a b1d b1e b23 b24 1
b26 b2b b2f b33 b36 b3b b40 b43
b47 b48 b4d b50 b55 b56 b5b b5e
b63 b64 b69 b6c b70 b71 b76 b79
b7e b7f b84 b87 b8b b8f b92 b95
b96 b98 b99 b9e b9f ba4 ba6 baa
bad baf bb3 bb5 bc1 bc3 bc5 bc6
bcb bcf bd1 bdd bdf be3 be7 bea
bee bf1 bf5 bf8 bf9 bfe c01 c05
c09 c0c c10 c14 c17 c1a c1f c22
c25 c28 c29 c2e c2f 1 c31 c36
c3a c3e c41 c46 c4b c4e c52 c53
c58 c5b c60 c61 c66 c69 c6e c6f
c74 c77 c7b c7f c83 c87 c8a c8b
c8d c92 c93 c95 c96 c9b c9e ca3
ca4 ca9 cac cb1 cb2 cb7 cba cbe
cbf cc4 cc7 ccc ccd cd2 cd3 cd8
cda cde ce1 ce5 ce9 cec cf0 cf4
cf7 cfa cff d02 d05 d08 d09 d0e
d0f 1 d11 d16 d1a d1e d21 d26
d2b d2e d32 d33 d38 d39 d3e d40
d44 d47 d4b d4f d52 d56 d5a d5d
d61 d65 d66 d6b d6d d71 d74 d76
d7a d7d d7f d83 d86 d8a d8c d90
d94 d97 d98 d9a d9d da0 da1 da6
daa dae db2 db6 dba dc6 dca dce
dd1 dd5 dd9 ddb ddf de3 de7 dea
dee df2 df4 df5 dfa 1 dfe e02
e06 e09 e0d e11 e15 e19 e1c e20
e24 e27 e2a e2f e32 e35 e38 e39
e3e e3f 1 e41 e46 e4a e4e e51
e56 e5b e5e e62 e63 e68 e6b e70
e71 e76 e79 e7e e7f e84 e87 e8b
e8c e91 e94 e99 e9a e9f ea2 ea6
eaa ead eb0 eb1 eb3 eb4 eb9 eba
ebf ec1 ec5 ec8 eca ece ed0 edc
ede ee0 ee1 ee6 eea eec ef8 efa
efe f02 f05 f09 f0c f10 f13 f14
f19 f1c f20 f24 f27 f2b f2f f32
f35 f3a f3d f40 f43 f44 f49 f4a
1 f4c f51 f55 f59 f5c f61 f66
f69 f6d f6e f73 f76 f7b f7c f81
f84 f89 f8a f8f f92 f96 f9a f9e
fa2 fa5 fa6 fa8 fad fae fb0 fb1
fb6 fb9 fbe fbf fc4 fc7 fcc fcd
fd2 fd5 fd9 fda fdf fe2 fe7 fe8
fed fee ff3 ff5 ff9 ffc 1000 1004
1007 100b 100f 1012 1015 101a 101d 1020
1023 1024 1029 102a 1 102c 1031 1035
1039 103c 1041 1046 1049 104d 104e 1053
1054 1059 105b 105f 1062 1066 106a 106d
1071 1075 1078 107c 1080 1081 1086 1088
108c 108f 1093 1097 109b 109f 10a3 10a7
10ab 10af 10bb 10bf 10c3 10c6 10ca 10ce
10d0 10d4 10d8 10dc 10df 10e3 10e7 10e9
10ea 10ef 1 10f3 10f7 10fb 10fe 1102
1106 110a 110e 1111 1115 1119 111c 111f
1124 1127 112a 112d 112e 1133 1134 1
1136 113b 113f 1143 1146 114b 1150 1153
1157 1158 115d 1160 1165 1166 116b 116e
1173 1174 1179 117c 1180 1181 1186 1189
118e 118f 1194 1197 119b 119f 11a2 11a5
11a6 11a8 11a9 11ae 11af 11b4 11b6 11ba
11bd 11bf 11c3 11c5 11d1 11d3 11d5 11d6
11db 11df 11e1 11ed 11ef 11f3 11f5 11f9
11fd 1201 1204 1205 1207 120a 120d 120e
1213 1217 121b 121f 1223 1227 1233 1237
123b 123e 1242 1246 1248 124c 1250 1254
1257 125b 125f 1261 1262 1267 1 126b
126f 1273 1276 127a 127e 1282 1286 1289
128d 1291 1294 1297 129c 129f 12a2 12a5
12a6 12ab 12ac 1 12ae 12b3 12b7 12bb
12be 12c3 12c8 12cb 12cf 12d0 12d5 12d8
12dd 12de 12e3 12e6 12eb 12ec 12f1 12f4
12f8 12f9 12fe 1301 1306 1307 130c 130f
1313 1317 131a 131d 131e 1320 1321 1326
1327 132c 132e 1332 1335 1337 133b 133d
1349 134b 134d 134e 1353 1357 1359 1365
1367 136b 136f 1372 1376 1379 137d 1380
1381 1386 1389 138d 1391 1394 1398 139c
139f 13a2 13a7 13aa 13ad 13b0 13b1 13b6
13b7 1 13b9 13be 13c2 13c6 13c9 13ce
13d3 13d6 13da 13db 13e0 13e3 13e8 13e9
13ee 13f1 13f6 13f7 13fc 13ff 1403 1407
140b 140f 1412 1413 1415 141a 141b 141d
141e 1423 1426 142b 142c 1431 1434 1439
143a 143f 1442 1446 1447 144c 144f 1454
1455 145a 145b 1460 1462 1466 1469 146d
1471 1474 1478 147c 147f 1482 1487 148a
148d 1490 1491 1496 1497 1 1499 149e
14a2 14a6 14a9 14ae 14b3 14b6 14ba 14bb
14c0 14c1 14c6 14c8 14cc 14cf 14d3 14d7
14da 14de 14e2 14e5 14e9 14ed 14ee 14f3
14f5 14f9 14fc 1500 1503 1507 150b 150d
1511 1515 1519 151c 151d 151f 1523 1526
152a 152d 152e 1533 1536 153a 153e 1541
1542 1544 1547 154a 154b 1550 1 1553
1558 155c 1560 1563 1564 1566 156a 156d
1571 1574 1575 157a 1 157d 1582 1586
158a 158d 158e 1590 1594 1597 159b 159e
159f 15a4 1 15a7 15ac 15b0 15b4 15b8
15bc 15c0 15c4 15c8 15cc 15d8 15dc 15e0
15e3 15e7 15eb 15ed 15f1 15f5 15f9 15fc
1600 1604 1606 1607 160c 1 1610 1614
1618 161b 161f 1623 1627 162b 162e 1632
1636 1639 163c 1641 1644 1647 164a 164b
1650 1651 1 1653 1658 165c 1660 1663
1668 166d 1670 1674 1675 167a 167d 1682
1683 1688 168b 1690 1691 1696 1699 169d
169e 16a3 16a6 16ab 16ac 16b1 16b4 16b8
16bc 16bf 16c2 16c3 16c5 16c6 16cb 16cc
16d1 16d3 16d7 16da 16dc 16e0 16e2 16ee
16f0 16f2 16f3 16f8 16fc 16fe 170a 170c
1710 1714 1717 171b 171e 1722 1725 1726
172b 172e 1732 1736 1739 173d 1741 1744
1747 174c 174f 1752 1755 1756 175b 175c
1 175e 1763 1767 176b 176e 1773 1778
177b 177f 1780 1785 1788 178d 178e 1793
1796 179b 179c 17a1 17a4 17a8 17ac 17b0
17b4 17b7 17b8 17ba 17bf 17c0 17c2 17c3
17c8 17cb 17d0 17d1 17d6 17d9 17de 17df
17e4 17e7 17eb 17ec 17f1 17f4 17f9 17fa
17ff 1800 1805 1807 180b 180e 1812 1816
1819 181d 1821 1824 1827 182c 182f 1832
1835 1836 183b 183c 1 183e 1843 1847
184b 184e 1853 1858 185b 185f 1860 1865
1866 186b 186d 1871 1874 1878 187c 187f
1883 1887 188a 188e 1892 1893 1898 189a
189e 18a1 18a3 18a7 18ab 18ae 18b2 18b6
18b9 18ba 18bc 18bf 18c2 18c3 18c8 18cc
18d0 18d5 18da 18de 18e2 18e6 18e9 18ec
18f0 18f4 18f8 18fc 1900 1904 1908 190c
1910 1914 1918 191c 1920 1924 1928 192c
1930 1934 1938 193c 1940 1944 1948 194c
1950 1954 1958 195c 1960 1964 1968 196c
1970 1974 1978 1984 1988 198d 1991 1994
1995 199a 199e 19a2 19a5 19a8 19ac 19ae
19b2 19b6 19b9 19bc 19c0 19c2 19c6 19ca
19cd 19cf 19d3 19d7 19db 19de 19e2 19e6
19e8 19e9 19ee 1 19f2 19f6 19fa 19fd
1a01 1a05 1a09 1a0d 1a10 1a14 1a18 1a1b
1a1e 1a23 1a26 1a29 1a2c 1a2d 1a32 1a33
1 1a35 1a3a 1a3e 1a42 1a45 1a4a 1a4f
1a52 1a56 1a57 1a5c 1a5f 1a64 1a65 1a6a
1a6d 1a72 1a73 1a78 1a7b 1a7f 1a80 1a85
1a88 1a8d 1a8e 1a93 1a96 1a9a 1a9e 1aa1
1aa4 1aa5 1aa7 1aa8 1aad 1aae 1ab3 1ab5
1ab9 1abc 1abe 1ac2 1ac4 1ad0 1ad2 1ad4
1ad5 1ada 1ade 1ae0 1aec 1aee 1af2 1af6
1afb 1b00 1b04 1b08 1b0c 1b0f 1b12 1b16
1b1a 1b1e 1b22 1b26 1b2a 1b2e 1b32 1b3e
1b42 1b47 1b4b 1b4e 1b4f 1b54 1b58 1b5c
1b5f 1b62 1b66 1b68 1b6c 1b70 1b73 1b76
1b7a 1b7c 1b80 1b84 1b87 1b89 1b8d 1b91
1b95 1b98 1b9c 1ba0 1ba2 1ba3 1ba8 1
1bac 1bb0 1bb4 1bb7 1bbb 1bbf 1bc3 1bc7
1bca 1bce 1bd2 1bd5 1bd8 1bdd 1be0 1be3
1be6 1be7 1bec 1bed 1 1bef 1bf4 1bf8
1bfc 1bff 1c04 1c09 1c0c 1c10 1c11 1c16
1c19 1c1e 1c1f 1c24 1c27 1c2c 1c2d 1c32
1c35 1c39 1c3a 1c3f 1c42 1c47 1c48 1c4d
1c50 1c54 1c58 1c5b 1c5e 1c5f 1c61 1c62
1c67 1c68 1c6d 1c6f 1c73 1c76 1c78 1c7c
1c7e 1c8a 1c8c 1c8e 1c8f 1c94 1c98 1c9a
1ca6 1ca8 1cac 1cb0 1cb4 1cb8 1cbc 1cc0
1cc4 1cc8 1ccc 1cd0 1cd4 1cd8 1cdc 1ce0
1ce4 1ce8 1cec 1cf0 1cf4 1cf8 1cfc 1d00
1d04 1d08 1d0c 1d10 1d14 1d18 1d1c 1d20
1d24 1d28 1d2c 1d30 1d34 1d38 1d3c 1d40
1d44 1d48 1d4c 1d50 1d54 1d58 1d5c 1d60
1d64 1d68 1d6c 1d70 1d74 1d78 1d7c 1d80
1d84 1d88 1d8c 1d90 1d94 1d98 1d9c 1da0
1da4 1da8 1dac 1db0 1db4 1db8 1dbc 1dc0
1dc4 1dc8 1dcc 1dd0 1dd4 1dd8 1ddc 1de0
1de4 1de8 1dec 1df0 1df4 1df8 1dfc 1e00
1e04 1e08 1e0c 1e10 1e14 1e18 1e1c 1e20
1e24 1e28 1e2c 1e30 1e34 1e38 1e3c 1e40
1e44 1e48 1e4c 1e50 1e54 1e58 1e5c 1e60
1e64 1e68 1e6c 1e70 1e74 1e78 1e7c 1e80
1e84 1e88 1e8c 1e90 1e94 1e98 1e9c 1ea0
1ea4 1ea8 1eac 1eb0 1eb4 1eb8 1ebc 1ec0
1ec4 1ec8 1ecc 1ed0 1ed4 1ed8 1edc 1ee0
1ee4 1ee8 1eec 1ef0 1ef4 1ef8 1efc 1f00
1f04 1f08 1f0c 1f10 1f14 1f18 1f1c 1f20
1f24 1f28 1f2c 1f30 1f34 1f38 1f3c 1f40
1f44 1f48 1f4c 1f50 1f54 1f58 1f5c 1f60
1f64 1f68 1f6c 1f70 1f74 1f78 1f7c 1f80
1f84 1f88 1f8c 1f90 1f94 1f98 1f9c 1fa0
1fa4 1fa8 1fac 1fb0 1fb4 1fb8 1fbc 1fc0
1fc4 1fc8 1fcc 1fd0 1fd4 1fd8 1fdc 1fe0
1fe4 1fe8 1fec 1ff0 1ff4 1ff8 1ffc 2000
2004 2008 200c 2010 2014 2018 201c 2020
2024 2028 202c 2030 2034 2038 203c 2040
2044 2048 204c 2050 2054 2058 205c 2060
2064 2068 206c 2070 2074 2078 207c 2080
2084 2088 208c 2090 2094 2098 209c 20a0
20a4 20a8 20ac 20b0 20b4 20b8 20bc 20c0
20c4 20c8 20cc 20d0 20d4 20d8 20dc 20e0
20e4 20e8 20ec 20f0 20f4 20f8 20fc 2100
2104 2108 210c 2110 2114 2118 211c 2120
2124 2128 212c 2130 2134 2138 213c 2140
2144 2148 214c 2150 2154 2158 215c 2168
216d 2171 2175 2179 217c 2180 2184 2187
218a 218f 2192 2195 2198 2199 219e 219f
1 21a1 21a6 21aa 21ae 21b1 21b6 21bb
21be 21c2 21c3 21c8 21c9 21ce 21d0 21d4
21d7 21db 21df 21e3 21e7 21e9 21ed 21f1
21f4 21f5 21f7 21fa 21fd 21fe 2203 2206
220a 220e 2211 2212 2214 2217 221a 221b
2220 1 2223 2228 222c 2230 2235 223a
223e 2242 2246 2249 224c 2250 2254 2258
225c 2260 2264 2268 226c 2270 2274 2278
227c 2280 2284 2288 228c 2290 2294 2298
229c 22a0 22a4 22a8 22ac 22b0 22b4 22b8
22bc 22c0 22c4 22c8 22cc 22d0 22d4 22d8
22dc 22e0 22e4 22e8 22f4 22f8 22fd 2301
2304 2305 230a 230e 2312 2315 2318 231c
231e 2322 2326 2329 232c 2330 2332 2336
233a 233d 233f 2343 2347 234b 234e 2352
2356 2358 2359 235e 1 2362 2366 236a
236d 2371 2375 2379 237d 2380 2384 2388
238b 238e 2393 2396 2399 239c 239d 23a2
23a3 1 23a5 23aa 23ae 23b2 23b5 23ba
23bf 23c2 23c6 23c7 23cc 23cf 23d4 23d5
23da 23dd 23e2 23e3 23e8 23eb 23ef 23f0
23f5 23f8 23fd 23fe 2403 2406 240a 240e
2411 2414 2415 2417 2418 241d 241e 2423
2425 2429 242c 242e 2432 2434 2440 2442
2444 2445 244a 244e 2450 245c 245e 2462
2466 2469 246d 246e 2473 2477 247b 247f
2483 2487 248b 248f 2493 2497 249b 249f
24a3 24a7 24ab 24af 24b3 24b7 24bb 24bf
24c3 24c7 24cb 24cf 24d3 24d7 24db 24df
24e3 24e7 24eb 24ef 24f3 24f7 24fb 24ff
2503 2507 250b 250f 2513 2517 251b 251f
2523 2527 252b 252f 253b 253f 2544 2548
254b 254c 2551 2555 2559 255c 255f 2563
2565 2569 256d 2570 2573 2577 2579 257d
2581 2584 2586 258a 258e 2592 2595 2599
259d 259f 25a0 25a5 1 25a9 25ad 25b1
25b4 25b8 25bc 25c0 25c4 25c7 25cb 25cf
25d2 25d5 25da 25dd 25e0 25e3 25e4 25e9
25ea 1 25ec 25f1 25f5 25f9 25fc 2601
2606 2609 260d 260e 2613 2616 261b 261c
2621 2624 2629 262a 262f 2632 2636 2637
263c 263f 2644 2645 264a 264d 2651 2655
2658 265b 265c 265e 265f 2664 2665 266a
266c 2670 2673 2675 2679 267b 2687 2689
268b 268c 2691 2695 2697 26a3 26a5 26a9
26ad 26b1 26b5 26b9 26bd 26c1 26c5 26c9
26cd 26d1 26d5 26d9 26dd 26e1 26e5 26e9
26ed 26f1 26f5 26f9 26fd 2701 2705 2709
270d 2711 2715 2719 271d 2721 2725 2729
272d 2731 2735 2739 273d 2741 2745 2749
274d 2751 2755 2759 275d 2761 2765 2769
276d 2771 2775 2779 277d 2781 2785 2789
278d 2791 2795 2799 279d 27a1 27a5 27a9
27ad 27b1 27b5 27b9 27bd 27c1 27c5 27c9
27d5 27da 27de 27e2 27e6 27e9 27ed 27f1
27f4 27f7 27fc 27ff 2802 2805 2806 280b
280c 1 280e 2813 2817 281b 281e 2823
2828 282b 282f 2830 2835 2836 283b 283d
2841 2844 2848 284c 2850 2854 2856 285a
285e 2862 2865 2866 2868 286b 286e 286f
2874 2878 287c 2880 2884 2888 288c 2890
2894 2898 289c 28a0 28a4 28a8 28ac 28b0
28b4 28b8 28bc 28c0 28c4 28c8 28cc 28d0
28d4 28d8 28dc 28e0 28e4 28e8 28ec 28f0
28f4 28f8 28fc 2900 2904 2908 290c 2910
2914 2918 291c 2920 2924 2928 292c 2930
2934 2938 293c 2940 2944 2948 294c 2950
2954 2958 295c 2960 2964 2968 296c 2970
2974 2978 297c 2980 2984 2988 298c 2990
2994 2998 299c 29a0 29a4 29a8 29ac 29b0
29b4 29b8 29bc 29c0 29c4 29c8 29cc 29d0
29d4 29d8 29dc 29e0 29e4 29e8 29ec 29f0
29f4 29f8 29fc 2a00 2a04 2a08 2a0c 2a10
2a14 2a18 2a1c 2a20 2a24 2a28 2a2c 2a30
2a34 2a38 2a3c 2a40 2a44 2a48 2a4c 2a50
2a54 2a58 2a5c 2a60 2a64 2a68 2a6c 2a70
2a74 2a78 2a7c 2a80 2a84 2a88 2a8c 2a90
2a94 2a98 2a9c 2aa0 2aa4 2aa8 2ab4 2ab9
2abd 2ac1 2ac5 2ac8 2acc 2ad0 2ad3 2ad6
2adb 2ade 2ae1 2ae4 2ae5 2aea 2aeb 1
2aed 2af2 2af6 2afa 2afd 2b02 2b07 2b0a
2b0e 2b0f 2b14 2b15 2b1a 2b1c 2b20 2b23
2b27 2b2b 2b2f 2b33 2b35 2b39 2b3d 2b41
2b44 2b45 2b47 2b4a 2b4d 2b4e 2b53 2b57
2b5b 2b5f 2b62 2b63 2b65 2b66 2b68 2b6b
2b6e 2b6f 2b74 2b78 2b7b 2b7f 2b83 2b87
2b8b 2b8f 2b93 2b97 2b9b 2ba7 2bab 2baf
2bb2 2bb6 2bba 2bbc 2bc0 2bc4 2bc8 2bcb
2bcf 2bd3 2bd5 2bd6 2bdb 1 2bdf 2be3
2be7 2bea 2bee 2bf2 2bf6 2bfa 2bfd 2c01
2c05 2c08 2c0b 2c10 2c13 2c16 2c19 2c1a
2c1f 2c20 1 2c22 2c27 2c2b 2c2f 2c32
2c37 2c3c 2c3f 2c43 2c44 2c49 2c4c 2c51
2c52 2c57 2c5a 2c5f 2c60 2c65 2c68 2c6c
2c6d 2c72 2c75 2c7a 2c7b 2c80 2c83 2c87
2c8b 2c8e 2c91 2c92 2c94 2c95 2c9a 2c9b
2ca0 2ca2 2ca6 2ca9 2cab 2caf 2cb1 2cbd
2cbf 2cc1 2cc2 2cc7 2ccb 2ccd 2cd9 2cdb
2cdf 2ce3 2ce6 2ce7 2ce9 2cec 2cef 2cf0
2cf5 2cf9 2cfe 2d02 2d04 2d08 2d0b 2d0f
2d13 2d17 2d1b 2d1f 2d23 2d27 2d2b 2d2f
2d33 2d3f 2d43 2d47 2d4a 2d4e 2d52 2d54
2d58 2d5c 2d60 2d63 2d67 2d6b 2d6d 2d6e
2d73 1 2d77 2d7b 2d7f 2d82 2d86 2d8a
2d8e 2d92 2d95 2d99 2d9d 2da0 2da3 2da8
2dab 2dae 2db1 2db2 2db7 2db8 1 2dba
2dbf 2dc3 2dc7 2dca 2dcf 2dd4 2dd7 2ddb
2ddc 2de1 2de4 2de9 2dea 2def 2df2 2df7
2df8 2dfd 2e00 2e04 2e05 2e0a 2e0d 2e12
2e13 2e18 2e1b 2e1f 2e23 2e26 2e29 2e2a
2e2c 2e2d 2e32 2e33 2e38 2e3a 2e3e 2e41
2e43 2e47 2e49 2e55 2e57 2e59 2e5a 2e5f
2e63 2e65 2e71 2e73 2e77 2e7b 2e7e 2e7f
2e81 2e84 2e87 2e88 2e8d 2e91 2e95 2e99
2e9d 2ea1 2ea5 2ea9 2ead 2eb1 2eb5 2eb9
2ebd 2ec1 2ec5 2ec9 2ecd 2ed1 2ed5 2ed9
2edd 2ee1 2ee5 2ee9 2eed 2ef1 2ef5 2ef9
2efd 2f09 2f0d 2f11 2f14 2f18 2f1c 2f1e
2f22 2f26 2f2a 2f2d 2f31 2f35 2f37 2f38
2f3d 1 2f41 2f45 2f49 2f4c 2f50 2f54
2f58 2f5c 2f5f 2f63 2f67 2f6a 2f6d 2f72
2f75 2f78 2f7b 2f7c 2f81 2f82 1 2f84
2f89 2f8d 2f91 2f94 2f99 2f9e 2fa1 2fa5
2fa6 2fab 2fae 2fb3 2fb4 2fb9 2fbc 2fc1
2fc2 2fc7 2fca 2fce 2fcf 2fd4 2fd7 2fdc
2fdd 2fe2 2fe5 2fe9 2fed 2ff0 2ff3 2ff4
2ff6 2ff7 2ffc 2ffd 3002 3004 3008 300b
300d 3011 3013 301f 3021 3023 3024 3029
302d 302f 303b 303d 3041 3045 3048 3049
304b 304e 3051 3052 3057 305b 3060 3064
3066 306a 306f 3073 3075 3079 307d 3080
3082 3086 308b 308f 3091 3095 3099 309c
309e 30a2 30a6 30a9 30ad 30b1 30b5 30b9
30bd 30c1 30c5 30c9 30cd 30d1 30d5 30d9
30dd 30e1 30e5 30e9 30ed 30f1 30f5 30f9
30fd 3101 3105 3109 310d 3111 3115 3119
311d 3121 3125 3129 312d 3131 3135 3139
313d 3141 3145 3149 314d 3151 3155 3159
315d 3161 3165 3169 316d 3171 3175 3179
317d 3181 3185 3189 318d 3191 3195 3199
319d 31a1 31a5 31a9 31ad 31b1 31b5 31b9
31bd 31c1 31c5 31c9 31cd 31d1 31d5 31d9
31dd 31e1 31e5 31e9 31ed 31f1 31f5 31f9
31fd 3201 3205 3209 320d 3211 3215 3219
321d 3221 3225 3229 322d 3231 3235 3239
323d 3241 3245 3249 324d 3251 3255 3259
325d 3261 3265 3269 326d 3271 3275 3279
327d 3281 3285 3289 328d 3291 3295 3299
329d 32a1 32a5 32a9 32ad 32b1 32b5 32b9
32bd 32c1 32c5 32c9 32cd 32d1 32d5 32d9
32dd 32e1 32e5 32e9 32ed 32f1 32f5 32f9
32fd 3301 3305 3309 330d 3311 3315 3319
331d 3321 3325 3329 332d 3331 3335 3339
333d 3341 3345 3349 334d 3351 3355 3359
335d 3361 3365 3369 336d 3371 3375 3379
337d 3381 3385 3389 338d 3391 3395 3399
339d 33a1 33a5 33a9 33ad 33b1 33b5 33b9
33bd 33c1 33c5 33c9 33cd 33d1 33d5 33d9
33dd 33e1 33e5 33e9 33ed 33f1 33f5 33f9
33fd 3401 3405 3409 340d 3411 3415 3419
341d 3421 3425 3429 342d 3431 3435 3439
343d 3441 3445 3449 344d 3451 3455 3459
345d 3461 3465 3469 346d 3471 3475 3479
347d 3481 3485 3489 348d 3491 3495 3499
349d 34a1 34a5 34a9 34ad 34b1 34b5 34b9
34bd 34c1 34c5 34c9 34cd 34d1 34d5 34d9
34dd 34e1 34e5 34e9 34ed 34f1 34f5 34f9
34fd 3501 3505 3509 350d 3511 3515 3519
351d 3521 3525 3529 352d 3531 3535 3539
353d 3541 3545 3549 354d 3551 3555 3559
355d 3561 3565 3569 356d 3571 3575 3579
357d 3581 3585 3589 358d 3591 3595 3599
359d 35a1 35a5 35a9 35ad 35b1 35b5 35b9
35bd 35c1 35c5 35c9 35cd 35d1 35d5 35d9
35dd 35e1 35e5 35e9 35ed 35f1 35f5 35f9
35fd 3601 3605 3609 360d 3611 3615 3619
361d 3621 3625 3629 362d 3631 3635 3639
363d 3641 3645 3649 364d 3651 3655 3659
365d 3661 3665 3669 366d 3671 3675 3679
367d 3681 3685 3689 368d 3691 3695 3699
369d 36a1 36a5 36a9 36ad 36b1 36b5 36b9
36bd 36c1 36c5 36c9 36cd 36d1 36d5 36d9
36dd 36e1 36e5 36e9 36ed 36f1 36f5 36f9
36fd 3701 3705 3709 370d 3711 3715 3719
371d 3721 3725 3729 372d 3731 3735 3739
373d 3741 3745 3749 374d 3751 3755 3759
375d 3761 3765 3769 376d 3771 3775 3779
377d 3781 3785 3789 378d 3791 3795 3799
379d 37a1 37a5 37a9 37ad 37b1 37b5 37b9
37bd 37c1 37c5 37c9 37cd 37d1 37d5 37d9
37dd 37e1 37e5 37e9 37ed 37f1 37f5 37f9
37fd 3801 3805 3809 380d 3811 3815 3819
381d 3821 3825 3829 382d 3831 3835 3839
383d 3841 3845 3849 384d 3851 3855 3859
385d 3861 3865 3869 386d 3871 3875 3879
387d 3881 3885 3889 388d 3891 3895 3899
389d 38a1 38a5 38a9 38ad 38b1 38b5 38b9
38bd 38c1 38c5 38c9 38cd 38d1 38d5 38d9
38dd 38e1 38e5 38e9 38ed 38f1 38fd 3902
3906 390a 390e 3911 3915 3919 391c 391f
3924 3927 392a 392d 392e 3933 3934 1
3936 393b 393f 3943 3946 394b 3950 3953
3957 3958 395d 395e 3963 3965 3969 396c
3970 3974 3978 397a 397e 3982 3986 398a
398e 3992 3996 399a 399e 39a2 39a6 39aa
39ae 39b2 39b6 39ba 39be 39c2 39c6 39ca
39ce 39d2 39d6 39da 39de 39e2 39e6 39ea
39ee 39f2 39f6 39fa 39fe 3a02 3a06 3a0a
3a0e 3a12 3a16 3a1a 3a1e 3a22 3a26 3a2a
3a2e 3a32 3a36 3a3a 3a3e 3a42 3a46 3a4a
3a4e 3a52 3a56 3a5a 3a5e 3a62 3a66 3a6a
3a6e 3a72 3a76 3a7a 3a7e 3a82 3a86 3a8a
3a8e 3a92 3a96 3a9a 3a9e 3aa2 3aa6 3aaa
3aae 3ab2 3ab6 3aba 3abe 3ac2 3ac6 3aca
3ace 3ad2 3ad6 3ada 3ade 3ae2 3ae6 3aea
3aee 3af2 3af6 3afa 3afe 3b02 3b06 3b0a
3b0e 3b12 3b16 3b1a 3b1e 3b22 3b26 3b2a
3b2e 3b32 3b36 3b3a 3b3e 3b42 3b46 3b4a
3b4e 3b52 3b56 3b5a 3b5e 3b62 3b66 3b6a
3b6e 3b72 3b76 3b7a 3b7e 3b82 3b86 3b8a
3b8e 3b92 3b96 3b9a 3b9e 3ba2 3ba6 3baa
3bae 3bb2 3bb6 3bba 3bbe 3bc2 3bc6 3bca
3bce 3bd2 3bd6 3bda 3bde 3be2 3be6 3bea
3bee 3bf2 3bf6 3bfa 3bfe 3c02 3c06 3c0a
3c0e 3c12 3c16 3c1a 3c1e 3c22 3c26 3c2a
3c2e 3c32 3c36 3c3a 3c3e 3c42 3c46 3c4a
3c4e 3c52 3c56 3c5a 3c5e 3c62 3c66 3c6a
3c6e 3c72 3c76 3c7a 3c7e 3c82 3c86 3c8a
3c8e 3c92 3c96 3c9a 3c9e 3ca2 3ca6 3caa
3cae 3cb2 3cb6 3cba 3cbe 3cc2 3cc6 3cca
3cce 3cd2 3cd6 3cda 3cde 3ce2 3ce6 3cea
3cee 3cf2 3cf6 3cfa 3cfe 3d02 3d06 3d0a
3d0e 3d12 3d16 3d1a 3d1e 3d22 3d26 3d2a
3d2e 3d32 3d36 3d3a 3d3e 3d42 3d46 3d4a
3d4e 3d52 3d56 3d5a 3d5e 3d62 3d66 3d6a
3d6e 3d72 3d76 3d7a 3d7e 3d82 3d86 3d8a
3d8e 3d92 3d96 3d9a 3d9e 3da2 3da6 3daa
3dae 3db2 3db6 3dba 3dbe 3dc2 3dc6 3dca
3dce 3dd2 3dd6 3dda 3dde 3de2 3de6 3dea
3dee 3df2 3df6 3dfa 3dfe 3e02 3e06 3e0a
3e0e 3e12 3e16 3e1a 3e1e 3e22 3e26 3e2a
3e2e 3e32 3e36 3e3a 3e3e 3e42 3e46 3e4a
3e4e 3e52 3e56 3e5a 3e5e 3e62 3e66 3e6a
3e6e 3e72 3e76 3e7a 3e7e 3e82 3e86 3e8a
3e8e 3e92 3e96 3e9a 3e9e 3ea2 3ea6 3eaa
3eae 3eb2 3ebe 3ec3 3ec7 3ecb 3ecf 3ed2
3ed6 3eda 3edd 3ee0 3ee5 3ee8 3eeb 3eee
3eef 3ef4 3ef5 1 3ef7 3efc 3f00 3f04
3f07 3f0c 3f11 3f14 3f18 3f19 3f1e 3f1f
3f24 3f26 3f2a 3f2d 3f31 3f35 3f39 3f3b
3f3f 3f43 3f46 3f4a 3f4c 3f50 3f54 3f58
3f5b 3f5c 3f5e 3f61 3f64 3f65 3f6a 3f6e
3f72 3f77 3f7c 3f80 3f84 3f88 3f8b 3f8e
3f92 3f96 3f9a 3f9e 3fa2 3fa6 3faa 3fae
3fb2 3fb6 3fba 3fbe 3fc2 3fc6 3fca 3fce
3fd2 3fd6 3fda 3fde 3fe2 3fe6 3fea 3fee
3ff2 3ff6 3ffa 3ffe 4002 4006 400a 400e
4012 4016 401a 401e 4022 4026 402a 402e
403a 403e 4043 4047 404a 404b 4050 4054
4058 405b 405e 4062 4064 4068 406c 406f
4072 4076 4078 407c 4080 4083 4085 4089
408d 4091 4094 4098 409c 409e 409f 40a4
1 40a8 40ac 40b0 40b3 40b7 40bb 40bf
40c3 40c6 40ca 40ce 40d1 40d4 40d9 40dc
40df 40e2 40e3 40e8 40e9 1 40eb 40f0
40f4 40f8 40fb 4100 4105 4108 410c 410d
4112 4115 411a 411b 4120 4123 4128 4129
412e 4131 4135 4136 413b 413e 4143 4144
4149 414c 4150 4154 4157 415a 415b 415d
415e 4163 4164 4169 416b 416f 4172 4174
4178 417a 4186 4188 418a 418b 4190 4194
4196 41a2 41a4 41a8 41ac 41af 41b3 41b4
41b9 41bd 41c1 41c5 41c9 41cd 41d1 41d5
41d9 41dd 41e1 41e5 41e9 41ed 41f1 41f5
41f9 41fd 4201 4205 4209 420d 4211 4215
4219 421d 4221 4225 4229 422d 4231 4235
4239 423d 4241 4245 4249 424d 4251 4255
4259 425d 4261 4265 4269 426d 4271 4275
4279 427d 4281 4285 4289 428d 4291 429d
42a1 42a6 42aa 42ad 42ae 42b3 42b7 42bb
42be 42c1 42c5 42c7 42cb 42cf 42d2 42d5
42d9 42db 42df 42e3 42e6 42e8 42ec 42f0
42f4 42f7 42fb 42ff 4301 4302 4307 1
430b 430f 4313 4316 431a 431e 4322 4326
4329 432d 4331 4334 4337 433c 433f 4342
4345 4346 434b 434c 1 434e 4353 4357
435b 435e 4363 4368 436b 436f 4370 4375
4378 437d 437e 4383 4386 438b 438c 4391
4394 4398 4399 439e 43a1 43a6 43a7 43ac
43af 43b3 43b7 43ba 43bd 43be 43c0 43c1
43c6 43c7 43cc 43ce 43d2 43d5 43d7 43db
43dd 43e9 43eb 43ed 43ee 43f3 43f7 43f9
4405 4407 440b 440f 4413 4417 441b 441f
4423 4427 442b 442f 4433 4437 443b 443f
4443 4447 444b 444f 4453 4457 445b 445f
4463 4467 446b 446f 4473 4477 447b 447f
4483 4487 448b 448f 4493 4497 449b 449f
44a3 44a7 44ab 44af 44b3 44b7 44bb 44bf
44c3 44c7 44cb 44cf 44d3 44d7 44db 44df
44e3 44e7 44eb 44ef 44f3 44f7 44fb 44ff
4503 4507 450b 450f 4513 4517 451b 451f
4523 4527 452b 452f 4533 4537 4543 4548
454c 4550 4554 4557 455b 455f 4562 4565
456a 456d 4570 4573 4574 4579 457a 1
457c 4581 4585 4589 458c 4591 4596 4599
459d 459e 45a3 45a4 45a9 45ab 45af 45b2
45b6 45ba 45be 45c2 45c4 45c8 45cc 45d0
45d3 45d4 45d6 45d9 45dc 45dd 45e2 45e6
45ea 45ef 45f4 45f8 45fc 4600 4603 4606
460a 460e 4612 4616 461a 461e 4622 4626
462a 462e 4632 4636 463a 463e 4642 4646
464a 464e 4652 4656 465a 465e 4662 4666
466a 466e 4672 4676 467a 467e 4682 4686
468a 468e 4692 4696 469a 469e 46a2 46a6
46b2 46b6 46bb 46bf 46c2 46c3 46c8 46cc
46d0 46d3 46d6 46da 46dc 46e0 46e4 46e7
46ea 46ee 46f0 46f4 46f8 46fb 46fd 4701
4705 4709 470c 4710 4714 4716 4717 471c
1 4720 4724 4728 472b 472f 4733 4737
473b 473e 4742 4746 4749 474c 4751 4754
4757 475a 475b 4760 4761 1 4763 4768
476c 4770 4773 4778 477d 4780 4784 4785
478a 478d 4792 4793 4798 479b 47a0 47a1
47a6 47a9 47ad 47ae 47b3 47b6 47bb 47bc
47c1 47c4 47c8 47cc 47cf 47d2 47d3 47d5
47d6 47db 47dc 47e1 47e3 47e7 47ea 47ec
47f0 47f2 47fe 4800 4802 4803 4808 480c
480e 481a 481c 4820 4824 4827 482b 482c
4831 4835 4839 483d 4841 4845 4849 484d
4851 4855 4859 485d 4861 4865 4869 486d
4871 4875 4879 487d 4881 4885 4889 488d
4891 4895 4899 489d 48a1 48a5 48a9 48ad
48b1 48b5 48b9 48bd 48c1 48c5 48c9 48cd
48d1 48d5 48d9 48dd 48e1 48e5 48e9 48ed
48f1 48f5 48f9 48fd 4901 4905 4909 490d
4911 4915 4919 491d 4921 4925 4929 492d
4931 4935 4939 493d 4941 4945 4949 494d
4951 4955 4959 495d 4961 4965 4969 496d
4971 4975 4979 497d 4981 4985 4989 498d
4991 4995 4999 499d 49a1 49a5 49a9 49ad
49b1 49b5 49b9 49bd 49c9 49cd 49d2 49d6
49d9 49da 49df 49e3 49e7 49ea 49ed 49f1
49f3 49f7 49fb 49fe 4a01 4a05 4a07 4a0b
4a0f 4a12 4a14 4a18 4a1c 4a20 4a23 4a27
4a2b 4a2d 4a2e 4a33 1 4a37 4a3b 4a3f
4a42 4a46 4a4a 4a4e 4a52 4a55 4a59 4a5d
4a60 4a63 4a68 4a6b 4a6e 4a71 4a72 4a77
4a78 1 4a7a 4a7f 4a83 4a87 4a8a 4a8f
4a94 4a97 4a9b 4a9c 4aa1 4aa4 4aa9 4aaa
4aaf 4ab2 4ab7 4ab8 4abd 4ac0 4ac4 4ac5
4aca 4acd 4ad2 4ad3 4ad8 4adb 4adf 4ae3
4ae6 4ae9 4aea 4aec 4aed 4af2 4af3 4af8
4afa 4afe 4b01 4b03 4b07 4b09 4b15 4b17
4b19 4b1a 4b1f 4b23 4b25 4b31 4b33 4b37
4b3b 4b3f 4b43 4b47 4b4b 4b4f 4b53 4b57
4b5b 4b5f 4b63 4b67 4b6b 4b6f 4b73 4b77
4b7b 4b7f 4b83 4b87 4b8b 4b8f 4b93 4b97
4b9b 4b9f 4ba3 4ba7 4bab 4baf 4bb3 4bb7
4bbb 4bbf 4bc3 4bc7 4bcb 4bcf 4bd3 4bd7
4bdb 4bdf 4be3 4be7 4beb 4bef 4bf3 4bf7
4bfb 4bff 4c03 4c07 4c0b 4c0f 4c13 4c17
4c1b 4c1f 4c23 4c27 4c2b 4c2f 4c33 4c37
4c3b 4c3f 4c43 4c47 4c4b 4c4f 4c53 4c57
4c5b 4c5f 4c63 4c67 4c6b 4c6f 4c73 4c77
4c7b 4c7f 4c83 4c87 4c8b 4c8f 4c93 4c97
4c9b 4c9f 4ca3 4ca7 4cab 4caf 4cb3 4cb7
4cbb 4cbf 4cc3 4cc7 4ccb 4ccf 4cd3 4cd7
4cdb 4ce7 4cec 4cf0 4cf4 4cf8 4cfb 4cff
4d03 4d06 4d09 4d0e 4d11 4d14 4d17 4d18
4d1d 4d1e 1 4d20 4d25 4d29 4d2d 4d30
4d35 4d3a 4d3d 4d41 4d42 4d47 4d48 4d4d
4d4f 4d53 4d56 4d5a 4d5e 4d62 4d66 4d68
4d6c 4d70 4d74 4d77 4d78 4d7a 4d7d 4d80
4d81 4d86 4d8a 4d8e 4d92 4d96 4d9a 4d9e
4da2 4da6 4daa 4dae 4db2 4db6 4dba 4dbe
4dc2 4dc6 4dca 4dce 4dd2 4dd6 4dda 4dde
4de2 4de6 4dea 4dee 4df2 4df6 4dfa 4dfe
4e02 4e06 4e0a 4e0e 4e12 4e16 4e1a 4e1e
4e22 4e26 4e2a 4e2e 4e32 4e36 4e3a 4e3e
4e42 4e46 4e4a 4e4e 4e52 4e56 4e5a 4e5e
4e62 4e66 4e6a 4e6e 4e72 4e76 4e7a 4e7e
4e82 4e86 4e8a 4e8e 4e92 4e96 4e9a 4e9e
4ea2 4ea6 4eaa 4eae 4eb2 4eb6 4eba 4ebe
4ec2 4ec6 4eca 4ece 4ed2 4ed6 4eda 4ede
4ee2 4ee6 4eea 4eee 4ef2 4ef6 4efa 4efe
4f02 4f06 4f0a 4f0e 4f12 4f16 4f1a 4f1e
4f22 4f26 4f2a 4f2e 4f32 4f36 4f3a 4f3e
4f42 4f46 4f4a 4f4e 4f52 4f56 4f5a 4f5e
4f62 4f66 4f6a 4f6e 4f72 4f76 4f7a 4f7e
4f82 4f86 4f8a 4f8e 4f92 4f96 4f9a 4f9e
4fa2 4fa6 4faa 4fae 4fb2 4fb6 4fba 4fbe
4fc2 4fc6 4fca 4fce 4fd2 4fd6 4fda 4fde
4fe2 4fe6 4fea 4fee 4ff2 4ff6 4ffa 4ffe
5002 5006 500a 500e 5012 5016 501a 501e
5022 5026 502a 502e 5032 5036 503a 503e
5042 5046 504a 504e 5052 5056 505a 505e
5062 5066 506a 506e 5072 5076 507a 507e
5082 5086 508a 508e 5092 5096 509a 509e
50a2 50a6 50aa 50ae 50b2 50b6 50ba 50be
50c2 50c6 50ca 50ce 50d2 50d6 50da 50de
50e2 50e6 50ea 50ee 50f2 50f6 50fa 50fe
5102 5106 510a 510e 5112 5116 511a 511e
5122 512e 5133 5137 513b 513f 5142 5146
514a 514d 5150 5155 5158 515b 515e 515f
5164 5165 1 5167 516c 5170 5174 5177
517c 5181 5184 5188 5189 518e 518f 5194
5196 519a 519d 51a1 51a5 51a9 51ad 51af
51b3 51b7 51bb 51be 51bf 51c1 51c4 51c7
51c8 51cd 51d1 51d5 51da 51df 51e3 51e7
51eb 51ee 51f1 51f5 51f9 51fd 5201 5205
5209 520d 5211 5215 5219 521d 5221 5225
5229 522d 5231 5235 5239 523d 5241 5245
5249 524d 5251 5255 5259 525d 5261 5265
5269 526d 5271 5275 5279 527d 5281 5285
5289 528d 5291 5295 5299 529d 52a1 52a5
52a9 52ad 52b1 52bd 52c1 52c6 52ca 52cd
52ce 52d3 52d7 52db 52de 52e1 52e5 52e7
52eb 52ef 52f2 52f5 52f9 52fb 52ff 5303
5306 5308 530c 5310 5314 5317 531b 531f
5321 5322 5327 1 532b 532f 5333 5336
533a 533e 5342 5346 5349 534d 5351 5354
5357 535c 535f 5362 5365 5366 536b 536c
1 536e 5373 5377 537b 537e 5383 5388
538b 538f 5390 5395 5398 539d 539e 53a3
53a6 53ab 53ac 53b1 53b4 53b8 53b9 53be
53c1 53c6 53c7 53cc 53cf 53d3 53d7 53da
53dd 53de 53e0 53e1 53e6 53e7 53ec 53ee
53f2 53f5 53f7 53fb 53fd 5409 540b 540d
540e 5413 5417 5419 5425 5427 542b 542f
5434 5439 543d 5441 5445 5448 544b 544f
5453 5457 545b 545f 5463 5467 546b 546f
5473 5477 547b 547f 5483 5487 548b 548f
5493 5497 549b 549f 54a3 54a7 54ab 54af
54b3 54b7 54bb 54bf 54c3 54c7 54cb 54cf
54d3 54d7 54db 54df 54e3 54e7 54eb 54ef
54f3 54f7 54fb 54ff 5503 5507 550b 550f
5513 5517 551b 551f 5523 5527 552b 552f
5533 5537 553b 553f 5543 5547 554b 554f
5553 5557 555b 555f 5563 5567 556b 556f
5573 5577 557b 557f 5583 5587 558b 558f
5593 5597 559b 559f 55a3 55a7 55ab 55af
55b3 55b7 55bb 55bf 55c3 55c7 55cb 55cf
55d3 55d7 55db 55df 55e3 55e7 55eb 55ef
55f3 55f7 55fb 55ff 5603 5607 560b 560f
5613 561f 5623 5628 562c 562f 5630 5635
5639 563d 5640 5643 5647 5649 564d 5651
5654 5657 565b 565d 5661 5665 5668 566a
566e 5672 5676 5679 567d 5681 5683 5684
5689 1 568d 5691 5695 5698 569c 56a0
56a4 56a8 56ab 56af 56b3 56b6 56b9 56be
56c1 56c4 56c7 56c8 56cd 56ce 1 56d0
56d5 56d9 56dd 56e0 56e5 56ea 56ed 56f1
56f2 56f7 56fa 56ff 5700 5705 5708 570d
570e 5713 5716 571a 571b 5720 5723 5728
5729 572e 5731 5735 5739 573c 573f 5740
5742 5743 5748 5749 574e 5750 5754 5757
5759 575d 575f 576b 576d 576f 5770 5775
5779 577b 5787 5789 578d 5791 5795 5799
579d 57a1 57a5 57a9 57ad 57b1 57b5 57b9
57bd 57c1 57c5 57c9 57d5 57d9 57de 57e2
57e5 57e6 57eb 57ef 57f3 57f6 57f9 57fd
57ff 5803 5807 580a 580d 5811 5813 5817
581b 581e 5820 5824 5828 582c 582f 5833
5837 5839 583a 583f 1 5843 5847 584b
584e 5852 5856 585a 585e 5861 5865 5869
586c 586f 5874 5877 587a 587d 587e 5883
5884 1 5886 588b 588f 5893 5896 589b
58a0 58a3 58a7 58a8 58ad 58b0 58b5 58b6
58bb 58be 58c3 58c4 58c9 58cc 58d0 58d1
58d6 58d9 58de 58df 58e4 58e7 58eb 58ef
58f2 58f5 58f6 58f8 58f9 58fe 58ff 5904
5906 590a 590d 590f 5913 5915 5921 5923
5925 5926 592b 592f 5931 593d 593f 5943
5947 594b 594f 5953 5957 595b 595f 5963
5967 596b 596f 5973 5977 597b 597f 5983
5987 598b 598f 5993 5997 599b 599f 59a3
59a7 59ab 59af 59b3 59b7 59bb 59bf 59c3
59c7 59cb 59cf 59d3 59d7 59db 59df 59e3
59e7 59eb 59ef 59f3 59f7 59fb 59ff 5a03
5a07 5a0b 5a0f 5a13 5a17 5a1b 5a1f 5a23
5a27 5a2b 5a2f 5a33 5a37 5a3b 5a3f 5a43
5a47 5a4b 5a4f 5a53 5a57 5a5b 5a5f 5a63
5a67 5a6b 5a6f 5a73 5a77 5a7b 5a7f 5a83
5a87 5a8b 5a8f 5a93 5a97 5a9b 5a9f 5aa3
5aa7 5aab 5aaf 5ab3 5ab7 5abb 5abf 5ac3
5ac7 5acb 5acf 5ad3 5ad7 5adb 5adf 5ae3
5ae7 5aeb 5aef 5af3 5af7 5afb 5aff 5b03
5b07 5b0b 5b0f 5b13 5b17 5b1b 5b1f 5b23
5b27 5b2b 5b2f 5b33 5b37 5b3b 5b3f 5b43
5b47 5b4b 5b4f 5b53 5b57 5b5b 5b5f 5b63
5b67 5b6b 5b6f 5b73 5b77 5b7b 5b7f 5b83
5b87 5b8b 5b8f 5b93 5b97 5b9b 5b9f 5ba3
5ba7 5bab 5baf 5bb3 5bb7 5bbb 5bbf 5bc3
5bc7 5bcb 5bcf 5bd3 5bd7 5bdb 5bdf 5be3
5be7 5beb 5bef 5bf3 5bf7 5bfb 5bff 5c03
5c07 5c0b 5c0f 5c13 5c17 5c1b 5c1f 5c23
5c27 5c2b 5c2f 5c33 5c37 5c3b 5c3f 5c43
5c47 5c4b 5c4f 5c53 5c57 5c5b 5c5f 5c63
5c67 5c6b 5c6f 5c73 5c77 5c7b 5c7f 5c83
5c87 5c8b 5c8f 5c93 5c97 5c9b 5c9f 5cab
5cb0 5cb4 5cb8 5cbc 5cbf 5cc3 5cc7 5cca
5ccd 5cd2 5cd5 5cd8 5cdb 5cdc 5ce1 5ce2
1 5ce4 5ce9 5ced 5cf1 5cf4 5cf9 5cfe
5d01 5d05 5d06 5d0b 5d0c 5d11 5d13 5d17
5d1a 5d1e 5d22 5d26 5d2a 5d2c 5d30 5d34
5d38 5d3b 5d3c 5d3e 5d42 5d45 5d49 5d4c
5d4d 5d52 5d56 5d5a 5d5e 5d62 5d66 5d72
5d76 5d7a 5d7d 5d81 5d85 5d87 5d8b 5d8f
5d93 5d96 5d9a 5d9e 5da0 5da1 5da6 1
5daa 5dae 5db2 5db5 5db9 5dbd 5dc1 5dc5
5dc8 5dcc 5dd0 5dd3 5dd6 5ddb 5dde 5de1
5de4 5de5 5dea 5deb 1 5ded 5df2 5df6
5dfa 5dfd 5e02 5e07 5e0a 5e0e 5e0f 5e14
5e17 5e1c 5e1d 5e22 5e25 5e2a 5e2b 5e30
5e33 5e37 5e38 5e3d 5e40 5e45 5e46 5e4b
5e4e 5e52 5e56 5e59 5e5c 5e5d 5e5f 5e60
5e65 5e66 5e6b 5e6d 5e71 5e74 5e76 5e7a
5e7c 5e88 5e8a 5e8c 5e8d 5e92 5e96 5e98
5ea4 5ea6 5eaa 5eae 5eb1 5eb5 5eb8 5ebc
5ebf 5ec0 5ec5 5ec8 5ecc 5ed0 5ed4 5ed8
5edc 5ee0 5ee4 5ee8 5eec 5ef0 5ef4 5ef8
5efc 5f00 5f04 5f08 5f0c 5f10 5f14 5f18
5f1c 5f20 5f24 5f28 5f2c 5f30 5f34 5f38
5f3c 5f40 5f44 5f48 5f4c 5f50 5f54 5f58
5f5c 5f60 5f64 5f68 5f6c 5f70 5f74 5f78
5f7c 5f80 5f84 5f88 5f8c 5f90 5f94 5f98
5f9c 5fa0 5fa4 5fa8 5fac 5fb0 5fb4 5fb8
5fbc 5fc0 5fc4 5fc8 5fcc 5fd0 5fd4 5fd8
5fdc 5fe0 5fe4 5fe8 5fec 5ff0 5ff4 5ff8
5ffc 6000 6004 6008 600c 6010 6014 6018
601c 6020 6024 6028 602c 6030 6034 6038
603c 6040 6044 6048 604c 6050 6054 6058
605c 6060 6064 6068 606c 6070 6074 6078
607c 6080 6084 6088 608c 6090 6094 6098
609c 60a0 60a4 60a8 60ac 60b0 60b4 60b8
60bc 60c0 60c4 60c8 60cc 60d0 60d4 60d8
60dc 60e0 60e4 60e8 60ec 60f0 60f4 60f8
60fc 6100 6104 6108 610c 6110 6114 6118
611c 6120 6124 6128 612c 6130 613c 6141
6145 6149 614d 6150 6154 6158 615b 615e
6163 6166 6169 616c 616d 6172 6173 1
6175 617a 617e 6182 6185 618a 618f 6192
6196 6197 619c 619d 61a2 61a4 61a8 61ab
61af 61b3 61b7 61b9 61bd 61c0 61c4 61c6
61ca 61ce 61d2 61d5 61d6 61d8 61db 61de
61df 61e4 61e8 61ec 61f0 61f4 61f8 61fc
6200 6204 6208 620c 6210 6214 6218 621c
6220 6224 6228 622c 6230 6234 6238 623c
6240 6244 6248 624c 6250 6254 6258 625c
6260 6264 6268 626c 6270 6274 6278 627c
6280 6284 6288 628c 6290 6294 6298 629c
62a0 62a4 62a8 62ac 62b0 62b4 62b8 62bc
62c0 62c4 62c8 62cc 62d0 62d4 62d8 62dc
62e0 62e4 62e8 62ec 62f0 62f4 62f8 62fc
6300 6304 6308 630c 6310 6314 6318 631c
6320 6324 6328 632c 6330 6334 6338 633c
6340 6344 6348 634c 6350 6354 6358 635c
6360 6364 6368 636c 6370 6374 6378 637c
6380 6384 6388 638c 6390 6394 6398 639c
63a0 63a4 63a8 63ac 63b0 63b4 63b8 63bc
63c0 63c4 63c8 63cc 63d0 63d4 63d8 63dc
63e0 63e4 63e8 63ec 63f0 63f4 63f8 63fc
6400 6404 6408 640c 6410 6414 6418 641c
6420 6424 6428 642c 6430 6434 6438 643c
6440 6444 6448 644c 6450 6454 6458 645c
6460 6464 6468 646c 6470 6474 6478 647c
6480 6484 6488 648c 6490 6494 6498 649c
64a0 64a4 64a8 64ac 64b0 64b4 64b8 64bc
64c0 64c4 64c8 64cc 64d0 64d4 64d8 64dc
64e0 64e4 64e8 64ec 64f0 64f4 64f8 64fc
6500 6504 6508 650c 6510 6514 6518 651c
6520 6524 6528 652c 6530 6534 6538 653c
6540 6544 6548 654c 6550 6554 6558 655c
6560 6564 6568 656c 6570 6574 6578 657c
6580 6584 6588 658c 6590 6594 6598 659c
65a0 65a4 65a8 65ac 65b0 65b4 65b8 65bc
65c0 65c4 65c8 65cc 65d0 65d4 65d8 65dc
65e0 65e4 65e8 65ec 65f0 65f4 65f8 65fc
6600 6604 6608 660c 6610 6614 6618 661c
6620 6624 6628 662c 6630 6634 6638 663c
6640 6644 6648 664c 6650 6654 6658 665c
6660 6664 6668 666c 6670 6674 6678 667c
6680 6684 6688 668c 6690 6694 6698 669c
66a0 66a4 66a8 66ac 66b0 66b4 66b8 66bc
66c0 66c4 66c8 66cc 66d0 66d4 66d8 66dc
66e0 66e4 66e8 66ec 66f0 66fc 6701 6705
6709 670d 6710 6714 6718 671b 671e 6723
6726 6729 672c 672d 6732 6733 1 6735
673a 673e 6742 6745 674a 674f 6752 6756
6757 675c 675d 6762 6764 6768 676b 676f
6773 6777 677b 677d 6781 6785 6789 678c
678d 678f 6792 6795 6796 679b 679f 67a3
67a7 67ab 67af 67b3 67b7 67bb 67bf 67c3
67c7 67cb 67cf 67d3 67d7 67db 67df 67e3
67e7 67eb 67ef 67f3 67f7 67fb 67ff 6803
6807 680b 680f 6813 6817 681b 681f 6823
6827 682b 682f 6833 6837 683b 683f 6843
6847 684b 684f 6853 6857 685b 685f 6863
6867 686b 686f 6873 6877 687b 687f 6883
6887 688b 688f 6893 6897 689b 689f 68a3
68a7 68ab 68af 68b3 68b7 68bb 68bf 68c3
68c7 68cb 68cf 68d3 68d7 68db 68df 68e3
68e7 68eb 68ef 68f3 68f7 68fb 68ff 6903
6907 690b 690f 6913 6917 691b 691f 6923
6927 692b 692f 6933 6937 693b 693f 6943
6947 694b 694f 6953 6957 695b 695f 6963
6967 696b 696f 6973 6977 697b 697f 6983
6987 698b 698f 6993 6997 699b 699f 69a3
69a7 69ab 69af 69b3 69b7 69bb 69bf 69c3
69c7 69cb 69cf 69d3 69d7 69db 69df 69e3
69e7 69eb 69ef 69f3 69f7 69fb 69ff 6a03
6a07 6a0b 6a0f 6a13 6a17 6a1b 6a1f 6a23
6a2f 6a34 6a38 6a3c 6a40 6a43 6a47 6a4b
6a4e 6a51 6a56 6a59 6a5c 6a5f 6a60 6a65
6a66 1 6a68 6a6d 6a71 6a75 6a78 6a7d
6a82 6a85 6a89 6a8a 6a8f 6a90 6a95 6a97
6a9b 6a9e 6aa2 6aa6 6aaa 6aae 6ab0 6ab4
6ab8 6abc 6abf 6ac0 6ac2 6ac5 6ac8 6ac9
6ace 6ad2 6ad6 6adb 6ae0 6ae4 6ae8 6aec
6aef 6af2 6af6 6afa 6afe 6b02 6b06 6b0a
6b0e 6b12 6b16 6b1a 6b1e 6b22 6b26 6b2a
6b2e 6b32 6b36 6b42 6b46 6b4b 6b4f 6b52
6b53 6b58 6b5c 6b60 6b63 6b66 6b6a 6b6c
6b70 6b74 6b77 6b7a 6b7e 6b80 6b84 6b88
6b8b 6b8d 6b91 6b95 6b99 6b9c 6ba0 6ba4
6ba6 6ba7 6bac 1 6bb0 6bb4 6bb8 6bbb
6bbf 6bc3 6bc7 6bcb 6bce 6bd2 6bd6 6bd9
6bdc 6be1 6be4 6be7 6bea 6beb 6bf0 6bf1
1 6bf3 6bf8 6bfc 6c00 6c03 6c08 6c0d
6c10 6c14 6c15 6c1a 6c1d 6c22 6c23 6c28
6c2b 6c30 6c31 6c36 6c39 6c3d 6c3e 6c43
6c46 6c4b 6c4c 6c51 6c54 6c58 6c5c 6c5f
6c62 6c63 6c65 6c66 6c6b 6c6c 6c71 6c73
6c77 6c7a 6c7c 6c80 6c82 6c8e 6c90 6c92
6c93 6c98 6c9c 6c9e 6caa 6cac 6cb0 6cb4
6cb9 6cbe 6cc2 6cc6 6cca 6ccd 6cd0 6cd4
6cd8 6cdc 6ce0 6ce4 6ce8 6cec 6cf0 6cf4
6cf8 6cfc 6d00 6d04 6d08 6d0c 6d18 6d1c
6d21 6d25 6d28 6d29 6d2e 6d32 6d36 6d39
6d3c 6d40 6d42 6d46 6d4a 6d4d 6d50 6d54
6d56 6d5a 6d5e 6d61 6d63 6d67 6d6b 6d6f
6d72 6d76 6d7a 6d7c 6d7d 6d82 1 6d86
6d8a 6d8e 6d91 6d95 6d99 6d9d 6da1 6da4
6da8 6dac 6daf 6db2 6db7 6dba 6dbd 6dc0
6dc1 6dc6 6dc7 1 6dc9 6dce 6dd2 6dd6
6dd9 6dde 6de3 6de6 6dea 6deb 6df0 6df3
6df8 6df9 6dfe 6e01 6e06 6e07 6e0c 6e0f
6e13 6e14 6e19 6e1c 6e21 6e22 6e27 6e2a
6e2e 6e32 6e35 6e38 6e39 6e3b 6e3c 6e41
6e42 6e47 6e49 6e4d 6e50 6e52 6e56 6e58
6e64 6e66 6e68 6e69 6e6e 6e72 6e74 6e80
6e82 6e86 6e8a 6e8f 6e94 6e98 6e9c 6ea0
6ea3 6ea6 6eaa 6eae 6eb2 6eb6 6eba 6ebe
6ec2 6ec6 6eca 6ece 6ed2 6ed6 6eda 6ede
6ee2 6ee6 6eea 6eee 6ef2 6ef6 6efa 6efe
6f02 6f06 6f0a 6f0e 6f12 6f16 6f1a 6f1e
6f22 6f26 6f2a 6f2e 6f32 6f36 6f3a 6f3e
6f42 6f4e 6f52 6f57 6f5b 6f5e 6f5f 6f64
6f68 6f6c 6f6f 6f72 6f76 6f78 6f7c 6f80
6f83 6f86 6f8a 6f8c 6f90 6f94 6f97 6f99
6f9d 6fa1 6fa5 6fa8 6fac 6fb0 6fb2 6fb3
6fb8 1 6fbc 6fc0 6fc4 6fc7 6fcb 6fcf
6fd3 6fd7 6fda 6fde 6fe2 6fe5 6fe8 6fed
6ff0 6ff3 6ff6 6ff7 6ffc 6ffd 1 6fff
7004 7008 700c 700f 7014 7019 701c 7020
7021 7026 7029 702e 702f 7034 7037 703c
703d 7042 7045 7049 704a 704f 7052 7057
7058 705d 7060 7064 7068 706b 706e 706f
7071 7072 7077 7078 707d 707f 7083 7086
7088 708c 708e 709a 709c 709e 709f 70a4
70a8 70aa 70b6 70b8 70bc 70c0 70c4 70c8
70cc 70d0 70d4 70d8 70dc 70e0 70e4 70e8
70ec 70f0 70f4 70f8 70fc 7100 7104 7108
710c 7110 7114 7118 711c 7120 7124 7128
712c 7130 7134 7138 713c 7140 7144 7148
714c 7150 7154 7158 715c 7160 7164 7168
716c 7170 7174 7178 717c 7180 7184 7188
718c 7190 7194 7198 719c 71a0 71a4 71a8
71ac 71b0 71b4 71b8 71bc 71c0 71c4 71c8
71cc 71d0 71d4 71d8 71dc 71e0 71e4 71e8
71ec 71f0 71f4 71f8 71fc 7200 7204 7208
720c 7210 7214 7218 721c 7220 7224 7228
722c 7230 7234 7238 723c 7240 7244 7248
724c 7250 7254 7258 725c 7260 7264 7268
7274 7279 727d 7281 7285 7288 728c 7290
7293 7296 729b 729e 72a1 72a4 72a5 72aa
72ab 1 72ad 72b2 72b6 72ba 72bd 72c2
72c7 72ca 72ce 72cf 72d4 72d5 72da 72dc
72e0 72e3 72e7 72eb 72ef 72f3 72f5 72f9
72fd 7301 7304 7305 7307 730a 730d 730e
7313 7317 731b 731f 7322 7327 7328 732d
7330 7333 7334 7336 733a 733e 7342 7346
734a 734e 7352 7356 735a 735e 7362 7366
736a 736e 7372 7376 737a 737e 7382 7386
738a 738e 7392 7396 739a 739e 73a2 73ae
73b3 73b7 73bb 73bf 73c2 73c6 73ca 73cd
73d0 73d5 73d8 73db 73de 73df 73e4 73e5
1 73e7 73ec 73f0 73f4 73f7 73fc 7401
7404 7408 7409 740e 740f 7414 7416 741a
741d 7421 7425 7429 742d 742f 7433 7437
743b 743e 743f 7441 7445 7448 744c 744f
7450 7455 7458 745c 7460 7463 7464 7466
746a 746d 7471 7474 7475 747a 1 747d
7482 7486 748a 748e 7492 7496 749a 749e
74a2 74a6 74aa 74ae 74b2 74b6 74ba 74be
74c2 74c6 74ca 74ce 74d2 74d6 74da 74de
74e2 74e6 74ea 74f6 74fb 74ff 7503 7507
750a 750e 7512 7515 7518 751d 7520 7523
7526 7527 752c 752d 1 752f 7534 7538
753c 753f 7544 7549 754c 7550 7551 7556
7557 755c 755e 7562 7565 7569 756d 7571
7573 7577 757b 757f 7582 7586 758a 758d
7590 7595 7598 759b 759e 759f 75a4 75a5
1 75a7 75ac 75b0 75b4 75b7 75bc 75c1
75c4 75c8 75c9 75ce 75d1 75d6 75d7 75dc
75df 75e4 75e5 75ea 75ed 75f1 75f5 75f9
75fd 7600 7601 7603 7608 7609 760b 760c
7611 7614 7619 761a 761f 7622 7627 7628
762d 7630 7634 7635 763a 763d 7642 7643
7648 7649 764e 7650 7654 7657 765b 765f
7662 7666 766a 766d 7671 7675 7676 767b
767d 7681 7685 7688 768a 768e 7692 7695
7699 769d 76a0 76a4 76a8 76ab 76ae 76b3
76b6 76b9 76bc 76bd 76c2 76c3 1 76c5
76ca 76ce 76d2 76d5 76da 76df 76e2 76e6
76e7 76ec 76ed 76f2 76f6 76fa 76fd 7702
7707 770a 770e 7712 7715 7716 771b 771e
7723 7724 7729 772c 7730 7734 7737 7738
773d 773e 7743 7745 7749 774c 7750 7754
7758 775c 7760 7764 7768 776c 7770 777c
7781 7785 7789 778d 7791 7793 7794 7799
1 779d 77a1 77a5 77a8 77ac 77b0 77b4
77b8 77bb 77bf 77c3 77c6 77c9 77ce 77d1
77d4 77d7 77d8 77dd 77de 1 77e0 77e5
77e9 77ed 77f0 77f5 77fa 77fd 7801 7802
7807 7808 780d 7811 7815 7818 781d 7822
7825 7829 782a 782f 7832 7837 7838 783d
7840 7844 7848 784b 784e 784f 7851 7852
7857 7858 785d 785f 7863 7866 786a 786e
7872 7876 787a 787e 7882 788e 7893 7897
789b 789f 78a3 78a5 78a9 78ab 78b7 78b9
78bb 78bc 78c1 78c5 78c7 78d3 78d7 78d9
78da 78e3 
2082
2
0 1 a 6 9 :3 6 11 :3 6
10 :2 6 1 3 a 13 a :2 1
4 b 14 13 :2 b :2 4 9 12
11 :2 9 :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 9 12 11
:2 9 :2 4 f 18 17 :2 f :2 4 :2 e
1d e :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 14
23 14 :2 4 :2 12 21 12 4 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 f 18 :3 f :2 7
13 1c :3 13 7 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 54 5a
5d :2 54 6b 81 8 :2 6b d 10
:2 6b 13 16 :2 6b b e :2 6b 13
16 1f 27 :2 1f 34 :2 16 :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
28 2b :2 6b 30 33 :2 6b :2 7 4a
:2 4 7 :2 11 23 :2 2d 39 3c 4c
4e 4f :2 4c :2 23 :3 7 :2 d 12 1e
5d 60 :2 1e :2 7 52 :2 4 :4 8 7
a :2 14 26 :2 30 3c 40 50 52
53 :2 50 :2 26 :3 a :2 10 15 21 60
63 :2 21 70 73 :2 21 77 7a :2 21
84 87 90 98 :2 a1 :2 90 b2 :2 87
:2 21 ba bd :2 21 c5 c8 :2 21 cd
d0 :2 21 d3 d6 :2 21 :2 a 56 :2 7
a :2 14 26 :2 30 3c 3f 4f 51
52 :2 4f :2 26 :3 a :2 10 15 21 60
63 :2 21 :2 a 55 :3 7 :2 12 26 :2 2f
3f 43 :2 7 14 :3 4 c :2 4 11
:2 4 12 4 8 11 1c :2 8 1f
21 :2 1f 7 28 31 3c :2 28 3f
41 :2 3f 27 :2 7 11 13 1f 21
2a 33 35 4b 4d f 1d 28
33 f 17 1a 22 2a 2c 39
42 44 51 53 :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 67 6a :2 27 77
7a :2 27 7e 81 :2 27 8d 90 :2 27
98 9b :2 27 a7 aa b1 ba bd
:2 aa :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 44 b :2 14 1f 1d :2 28 :2 1d
a 14 16 22 24 2d 36 38
12 20 2b 12 1a 1d 25 2d
2f 3c 45 47 54 56 :2 d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 59 5c 5d
:2 59 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 90
93 :2 2a 9b 9e :2 2a aa ad b4
bd c0 :2 ad :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :3 38 e :2 17 22 20
:2 2b :2 20 d 20 2f 3f 4c :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5c 5f
60 :2 5c :2 32 :3 16 :2 1c 21 2d 6d
70 :2 2d 7d 80 :2 2d 84 87 :2 2d
93 96 :2 2d 9e a1 :2 2d ad b0
b7 c0 c3 :2 b0 :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :3 3b 11 :2 1a 25
23 :2 2e :2 23 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a 7a 7d
:2 2a 81 84 :2 2a 8e 91 9a a2
:2 ab :2 9a bc :2 91 :2 2a c4 c7 :2 2a
cf d2 :2 2a d7 da :2 2a df e2
:2 2a :2 13 60 :2 10 13 :2 1d 2f :2 39
45 48 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a :2 13 5f
:3 10 :2 1b 2f :2 38 48 4e :2 10 3e
:2 d 3b :2 a 38 :2 7 4 44 a
13 1e :2 a 21 23 :2 21 11 21
f 26 3a :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 67 6a :2 27 77 7a
:2 27 7e 81 :2 27 8d 90 :2 27 98
9b :2 27 a7 aa b1 ba bd :2 aa
:2 27 :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 26 b :2 14 1f 1d :2 28 :2 1d a
d :2 17 29 :2 33 3f 43 53 56
57 :2 53 :2 29 :3 d :2 13 18 24 64
67 :2 24 74 77 :2 24 7b 7e :2 24
88 8b 94 9c :2 a5 :2 94 b6 :2 8b
:2 24 be c1 :2 24 c9 cc :2 24 d1
d4 :2 24 d7 da :2 24 :2 d 5a :2 a
d :2 17 29 :2 33 3f 42 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 64
67 :2 24 :2 d 59 :3 a :2 15 29 :2 32
42 46 :2 a 38 :2 7 11 1a 30
41 4c f 1d 2a :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 67 6a :2 27
77 7a :2 27 7e 81 :2 27 8d 90
:2 27 98 9b :2 27 a7 aa b1 ba
bd :2 aa :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 26 4 26 44 a 13
1e :2 a 21 23 :2 21 11 1b 27
37 44 :2 a :2 13 1f a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8d 90 :2 27 98 9b
:2 27 a7 aa b1 ba bd :2 aa :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 26
b :2 14 1f 1d :2 28 :2 1d a d
:2 17 29 :2 33 3f 43 53 56 57
:2 53 :2 29 :3 d :2 13 18 24 64 67
:2 24 74 77 :2 24 7b 7e :2 24 88
8b 94 9c :2 a5 :2 94 b6 :2 8b :2 24
be c1 :2 24 c9 cc :2 24 d1 d4
:2 24 d7 da :2 24 :2 d 5a :2 a d
:2 17 29 :2 33 3f 42 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 64 67
:2 24 :2 d 59 :3 a :2 15 29 :2 32 42
46 :2 a 38 :3 7 14 7 4 26
44 b 14 1f :2 b 25 22 :2 2e
:2 22 a 48 51 5c :2 48 5f 62
:2 5f 47 :2 a 16 1f 2a :2 16 30
2d :2 39 :2 2d 15 :2 a 5b 11 1c
:2 5b 22 1f :2 2b :2 1f 5a :2 a 11
1a 30 41 4c f 1d 2a :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 49 b :2 14 1f
1d :2 28 :2 1d a d :2 17 29 :2 33
3f 43 53 56 57 :2 53 :2 29 :3 d
:2 13 18 24 64 67 :2 24 74 77
:2 24 7b 7e :2 24 88 8b 94 9c
:2 a5 :2 94 b6 :2 8b :2 24 be c1 :2 24
c9 cc :2 24 d1 d4 :2 24 d7 da
:2 24 :2 d 5a :2 a d :2 17 29 :2 33
3f 42 52 55 56 :2 52 :2 29 :3 d
:2 13 18 24 64 67 :2 24 :2 d 59
:3 a :2 15 29 :2 32 42 46 :2 a 38
:2 7 49 44 :2 4 7 10 1b :2 7
1e 20 :2 1e 7 f 19 :3 7 :2 10
1c 7 16 :8 a c a c a
c a c a c a c a
c f 24 26 2b 3c 41 43
4f 51 10 1d 26 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
67 6a :2 27 77 7a :2 27 7e 81
:2 27 8d 90 :2 27 98 9b :2 27 a7
aa b1 ba bd :2 aa :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 22 7 f
19 :3 7 :2 10 1c 7 16 29 1a
f 10 1d 26 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 22 7 c 3d
4e 57 5a 65 6e 71 7f 83
a8 7 b 18 1a 27 35 37
43 45 55 57 60 62 72 7
b 21 25 3a 3e 4d 51 67
71 74 81 84 91 94 a1 a4
b8 c9 c 22 26 2b 35 3a
3e 4a 4c 7 c 1d 22 24
2f 33 7 c 1d 22 24 2f
31 7 c 12 17 1d 23 26
2e 32 14 1d 21 2f 3c 3e
4e 61 73 7 9 12 14 24
7 9 1f 21 35 37 45 47
5d 7 a 17 1a 27 2a 37
3a 4d 5e c 1e 23 28 31
36 3a 45 47 7 c 12 17
28 2d 2f 37 39 7 c 12
17 28 2d 2f 3a 3c 7 c
12 17 1d 23 26 2e 30 14
1d 21 2f 3b 3d 4d 5f 70
7 9 12 14 24 7 9 1f
21 36 38 47 49 5f 7 a
17 1a 27 2a 37 3a 4e 5f
c 1e 22 27 30 35 39 44
46 7 c 23 28 2a 35 37
7 c 12 17 28 2d 2f 38
3a 7 c 12 17 28 2d 2f
3a 3c 7 c 12 17 1d 23
26 2e 30 14 1d 21 2f 3b
3d 4d 5f 70 7 9 12 14
24 7 9 1f 21 36 38 47
49 5f 7 a 17 1a 27 2a
37 3a 4e 5f c 1e 22 27
30 35 39 44 46 7 c 22
27 29 34 36 7 c 12 17
28 2d 2f 37 39 7 c 12
17 28 2d 2f 3a 3c 7 c
12 17 1d 23 26 2e 30 10
1a 27 17 7 17 a :2 14 26
:2 30 3c 3f 4f 52 53 :2 4f :2 26
:3 a :2 10 15 21 61 64 :2 21 :2 a
56 :3 7 e 7 4 22 b 14
1f :2 b 22 24 :2 22 a 2b 34
3f :2 2b 42 44 :2 42 2a :2 a 7
f 19 :3 7 :2 10 1c 7 16 28
35 a d 14 17 49 f 24
27 2c 32 37 48 4e 51 5c
65 68 76 79 10 13 1e 27
2a 40 43 23 34 3c 3f 4d
4f 5f 61 69 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 47 7 :2 10 :3 1c
7 16 2a 35 1a 1c 28 2a
f 24 26 2b 34 39 3b 51
53 5e 60 a f 20 25 27
32 34 a f 20 25 27 32
34 a f 20 25 27 39 3b
51 53 10 12 1d 26 28 a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8d 90 :2 27 98 9b
:2 27 a7 aa b1 ba bd :2 aa :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 47
7 c 1e 20 2f 40 53 55
62 6f 71 79 7b 7 2e 3d
64 78 7 2e 3a 61 73 7e
8d 94 a1 b6 c7 c 1b 2e
49 5e 6f c 1d 1f 24 2e
33 35 41 43 e 1f 32 45
53 7 2e 3d 64 78 7 2e
3a 61 73 7e 8d 94 a1 d
1f 30 3f 52 6d 82 93 c
10 17 7 17 a :2 14 26 :2 30
3c 3f 4f 52 53 :2 4f :2 26 :3 a
:2 10 15 21 61 64 :2 21 :2 a 56
:3 7 e 7 4 47 22 a 13
1e :2 a 21 23 :2 21 7 c 28
2a 4d 4f 66 68 81 7 9
15 17 27 3a 42 44 57 59
66 68 76 78 7 9 16 18
21 23 2d 3a 4a 4c 5b 5d
6a 6c 7c 7 10 12 22 24
34 45 48 58 6b 6d 7a 7c
89 8b 98 9a ad bb bd c8
ca 7 9 1f 21 2e 31 41
4c 4e 56 58 62 64 6c 6e
79 7b 89 8b 99 7 9 c
21 23 28 2e 33 44 49 4b
55 5e 60 74 76 7 c 12
17 20 25 27 35 37 42 47
4d 52 66 6b 6d 79 7b 7
c 12 17 2b 31 3a 3c 4c
4e 5b 5e 7 c 12 17 25
2b 2e 3a 3c d f 1c 25
27 42 17 7 17 a :2 14 26
:2 30 3c 3f 4f 52 53 :2 4f :2 26
:3 a :2 10 15 21 61 64 :2 21 :2 a
56 :3 7 e 7 4 25 22 a
13 1e :2 a 21 23 :2 21 a 11
1a 25 :2 11 :2 a 29 2c :2 29 a
15 a 14 22 2f 46 53 64
6e :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
59 5c 5d :2 59 :2 2f :3 13 :2 19 1e
2a 6a 6d :2 2a 7a 7d :2 2a 81
84 :2 2a 90 93 :2 2a 9b 9e :2 2a
aa ad b4 bd c0 :2 ad :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :3 2e d
16 1f :2 d 22 24 :2 22 d 1b
d 26 d 18 d 17 27 34
20 37 44 55 5f 68 :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5c 5f 60
:2 5c :2 32 :3 16 :2 1c 21 2d 6d 70
:2 2d 7d 80 :2 2d 84 87 :2 2d 93
96 :2 2d 9e a1 :2 2d ad b0 b7
c0 c3 :2 b0 :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :3 a 10 19 22 :2 10
25 27 :2 25 1a 2a 37 23 34
37 3c 56 16 1a 27 2a 39
3d 4b 4e 19 1c 29 3a 3d
47 14 1c 23 26 49 4d :2 13
:2 1c 28 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5f 62
63 :2 5f :2 35 :3 19 :2 1f 24 30 70
73 :2 30 80 83 :2 30 87 8a :2 30
96 99 :2 30 a1 a4 :2 30 b0 b3
ba c3 c6 :2 b3 :2 30 :2 19 66 :2 16
:2 13 :4 1f :2 13 10 :3 29 13 1c 25
:2 13 28 2a :2 28 13 21 13 2c
13 21 13 :4 10 29 10 1e 10
:4 d :5 a f 21 23 2f 31 3e
40 4e 50 5f 72 74 81 83
8c 8e a c 10 12 16 18
24 33 35 42 a c 1b 1d
2f 3d 3f 4e 50 61 63 72
c 1b 1d 14 16 32 39 43
45 52 5c 5e 6d 6f 8e a
31 3e 65 78 a c 1b 1d
2d 2f 34 36 43 45 a c
1b 22 24 34 36 47 49 5c
a 17 2c 41 54 10 27 42
57 6c 81 10 1e 20 33 42
4f 5d 5f 6f 71 82 84 98
10 2c 40 55 62 71 7e 8e
a1 b4 c3 f 21 2f 3e 4f
51 5f 61 14 2b 2d 3e 69
14 2b 2d 3f 6a 14 2b 2d
4a 58 5a 6a 81 90 10 28
42 5d 7b 10 23 38 f 17
19 1e 23 38 3d 3f 4c 4e
5d 5f 6d a f 15 1a 2e
33 35 41 43 10 12 1f 30
32 3f 1b 1d 40 42 59 5b
74 80 82 14 16 35 37 49
52 5a 5c 6a 6c 17 19 28
32 3a 3c 4a 4c 60 14 16
35 37 69 a c 1f 21 2e
30 3a 43 52 63 14 16 1b
24 2e 30 35 3e 49 52 5d
5f 69 77 79 7e 87 92 9b
a6 a8 b2 a 13 21 31 40
49 58 69 14 16 2a 2c 3c
3e 52 14 16 2a 2c 39 3b
4c 4e 62 14 16 25 27 36
38 4a 4c 5d f 14 16 32
39 43 45 52 5c 69 84 a
c 19 1b 29 2b a c 1b
1d 2d 2f 34 36 43 45 a
c 1b 22 32 43 a 17 27
29 38 3a 47 49 59 a 13
15 25 27 37 48 4b 5b 6e
70 7d 7f 8c 8e 9b 9d 14
16 35 37 4a 54 5c 5e 6c
6e 19 27 29 34 36 44 46
56 58 69 6b a c 22 24
32 35 45 55 57 5f 61 6b
6d 75 77 82 84 92 94 a2
a4 ae b0 a c 28 2a 48
4a 72 7c 7e 94 14 16 2a
2c 40 42 5a 14 2b 34 36
42 44 5b 86 14 2b 34 36
43 45 5d 88 14 35 37 4d
4f 58 5a 79 87 89 9e b5
c4 a c a d 1d a c
a d 1d 34 36 a c 19
1d 2d 14 16 36 38 49 53
5b 5d 6b 6d 89 f 24 26
2b 31 36 47 4c 4e 62 64
a f 15 1a 2e 33 35 41
43 a f 15 1a 2e 34 3d
3f 4f 51 5e 61 a f 15
1a 28 2e 31 3d 3f a f
15 1a 2a 30 33 40 42 a
f 15 1a 2a 30 33 40 42
a f 15 1a 28 2f 33 40
42 10 12 1f 30 32 3f 48
4a 13 1b 1a a 1a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 64 67 :2 24
:2 d 59 :3 a 11 a 2e a f
2b 2d 50 52 69 6b 84 8f
91 14 16 35 37 46 50 58
5a 68 6a f 11 30 32 44
4d 55 57 65 67 f 11 30
32 44 4e 56 58 66 68 17
19 2b 3d 45 47 55 57 6a
14 16 2d 36 f 11 28 31
f 11 28 31 f 11 39 42
55 a c 1f 21 2e 30 39
3b a c 10 12 16 1f 2d
3d 4c 55 64 75 a c 14
2c 2e 42 44 54 56 6a a
c 19 28 2a 42 a c 19
1b 29 2b a c 1b 1d 2d
2f 34 36 43 45 a c 1b
22 32 43 a 17 27 29 38
3a 47 49 59 a 13 15 25
27 37 48 4b 5b 6e 70 7d
7f 8c 8e 9b 9d 14 16 35
37 4a 54 5c 5e 6c 6e 19
27 29 34 36 44 46 56 58
69 6b a c 22 24 32 35
45 55 57 5f 61 6b 6d 75
77 82 84 92 94 a2 a4 ae
b0 a c 28 2a 48 4a 72
7c 7e 94 a7 a c 19 1b
29 2b 39 3b 50 67 14 16
38 3a 52 54 6b 6d 7c 7e
92 94 a4 a6 d2 a c a
d 1d a c a d 1d 34
36 a c 19 1d 2d 14 16
36 38 49 53 5b 5d 6b 6d
89 f 24 26 2b 31 36 47
4c 4e 62 64 a f 15 1a
2e 33 35 41 43 a f 15
1a 2e 34 3d 3f 4f 51 5e
61 a f 15 1a 28 2e 31
3d 3f a f 15 1a 2a 30
33 40 42 a f 15 1a 2a
30 33 40 42 a f 15 1a
28 2f 33 40 42 10 12 32
34 41 13 1c 1a a 1a d
:2 17 29 :2 33 3f 42 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 64 67
:2 24 :2 d 59 :3 a 11 a :4 7 4
25 22 a 13 1e :2 a 21 23
:2 21 7 f 19 :3 7 :2 10 1c 7
16 :c a e 20 a e 21 a
e 1f a e 1e a e 1f
a e 1d a e 16 f 26
31 3a 61 6e a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 25 7 :2 10 :3 1c
7 16 2a 35 43 52 62 71
7d a 10 1a 1c 27 29 a
c 1b 1d 2c 2e 3e 40 4c
4e 5b 5d 63 65 f 1f 21
26 2f 34 36 4c 4e 59 5b
67 6c 7d 82 84 8f 91 a
f 20 25 27 32 34 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 77 7a :2 27 7e
81 :2 27 8d 90 :2 27 98 9b :2 27
a7 aa b1 ba bd :2 aa :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 25 7
c 1e 20 2f 40 53 55 62
75 7d 7f 7 9 18 1a 29
2b 3b 3d 49 4b 58 5a 60
62 71 78 85 d 1e 30 3f
52 6d 7b 7d 92 a3 c 1c
1e 23 2d 32 34 4c 4e 5a
5c e 1f 32 45 53 7 16
25 37 43 50 56 65 6c 79
d 1f 30 3f 52 6d 81 96
a7 c 29 17 7 17 a :2 14
26 :2 30 3c 3f 4f 52 53 :2 4f
:2 26 :3 a :2 10 15 21 61 64 :2 21
:2 a 56 :3 7 e 7 4 25 22
a 13 1e :2 a 21 23 :2 21 7
f 19 :3 7 :2 10 1c 7 16 :c a
e 20 a e 21 a e 1f
a e 1e a e 1f a e
1d a e 16 f 26 31 3a
61 6e a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 67 6a :2 27
77 7a :2 27 7e 81 :2 27 8d 90
:2 27 98 9b :2 27 a7 aa b1 ba
bd :2 aa :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 25 7 :2 10 :3 1c 7 16
2a 35 43 52 5b 6b 7a 8a
99 a5 a 10 1b 1a 1c 28
2a a c 1b 1d 2c 2e 3e
40 4c 4e 5b 5d 63 65 f
1f 21 26 2f 34 36 4c 4e
59 5b 67 6c 7d 82 84 8f
91 a f 20 25 27 32 34
1a 1d 2a 2c 40 42 a 30
a 30 5d 5f f 24 28 32
10 13 1e 27 2a 38 3a 20
23 3a 4b 10 13 30 32 f
24 2c 2e 3b 3e 4d 4f 5d
60 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 67 6a :2 27 77
7a :2 27 7e 81 :2 27 8d 90 :2 27
98 9b :2 27 a7 aa b1 ba bd
:2 aa :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 25 7 c 1e 20 2f 40
53 55 62 75 7d 7f 7 9
18 1a 29 2b 3b 3d 49 4b
58 5a 60 62 71 78 85 d
1e 30 3f 52 6d 7b 7d 92
a3 c 1c 1e 23 2d 32 34
4c 4e 5a 5c e 1f 32 3f
47 7 16 25 37 43 50 56
65 6c 79 d 1f 30 3f 52
6d 7c 91 a2 c 26 3c e
1f 32 3f 47 7 16 25 7
13 20 26 35 3c 49 5e 6f
c 1b 2e 49 57 6c 7d c
d 25 10 1e 17 7 17 a
:2 14 26 :2 30 3c 3f 4f 52 53
:2 4f :2 26 :3 a :2 10 15 21 61 64
:2 21 :2 a 56 :3 7 e 7 4 25
22 a 13 1e :2 a 21 23 :2 21
7 c 1e 20 2f 3b 3d 50
52 5f 73 7b 7d 7 9 18
1a 2a 2c 34 44 46 56 69
6b 7b 87 89 9a 7 9 11
17 19 27 32 3f 54 66 c
1a 2d 4a 59 66 74 76 8b
9c 7 a 18 1b 29 2c 3a
3d 4b 4e 7 a 1f 22 38
3b 4e 51 7 a 25 28 44
47 7 a 25 28 44 47 63
65 c 21 23 28 3c 42 45
52 5b 5e 6c 6e 7 c 11
22 27 29 3b 3d 53 55 7
c 11 22 27 29 3b 3d 53
55 7 c 16 1b 1d 29 2b
d f 1a 23 25 3c 3e 5f
61 e 10 1f 2b 2d 40 42
52 66 74 7 9 18 1a 29
2b 33 42 44 54 66 8d 99
c0 c 16 20 2d 42 54 c
1b 2e 43 45 59 6e 7f 7
a 18 1b 29 2c 3a 3d 4b
4e 7 a 1f 22 38 3b 4e
51 7 a 25 28 44 47 7
a 25 28 44 47 69 c 21
23 28 31 36 38 44 46 7
c 1d 22 24 36 38 7 c
20 26 29 36 3f 42 50 52
d f 1a 23 25 10 1e 17
7 17 a :2 14 26 :2 30 3c 3f
4f 52 53 :2 4f :2 26 :3 a :2 10 15
21 61 64 :2 21 :2 a 56 :3 7 e
7 4 25 22 a 13 1e :2 a
21 23 :2 21 7 f 19 :3 7 :2 10
1c 7 16 b :d a e 21 a
e 21 a e 21 a 18 2a
3e a e 21 a e 21 a
e 21 a 18 2a 3e f 10
1b 24 2c 13 20 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
67 6a :2 27 77 7a :2 27 7e 81
:2 27 8d 90 :2 27 98 9b :2 27 a7
aa b1 ba bd :2 aa :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 25 7 f
19 :3 7 :2 10 1c 7 16 :20 a c
1e 20 36 38 4e 50 a c
1e 20 36 38 4e 50 a c
1e 20 36 38 4e 50 a c
1e 20 36 38 a c 21 23
39 3b 4e 50 a c 27 29
45 47 a c 27 29 45 47
a c 1e 20 36 38 4e 50
a 13 15 28 2a 37 39 60
62 f 23 25 2a 30 35 46
4b 4d 5b 5d 10 12 1d a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 5a 5b :2 56 :2 2c :3 10 :2 16
1b 27 68 6b :2 27 78 7b :2 27
7f 82 :2 27 8e 91 :2 27 99 9c
:2 27 a8 ab b2 bb be :2 ab :2 27
:2 10 5e :2 d :2 a :4 16 :2 a 7 :3 25
11 22 29 3c 11 1e 2f 37
39 44 4d 4f 5d 60 70 72
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 56 5a 5b :2 56 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5e :2 d :2 a :4 16 :2 a 7
:3 25 7 c 1e 20 2f 40 53
55 62 70 72 7a 7c 7 9
18 1a 29 2b 3b 3d 49 4b
58 5a 60 62 71 78 85 d
1e 30 3f 52 6d 7b 7d 92
a3 11 13 34 36 57 59 74
8b 8d a0 a2 b6 b8 cb cd
de e0 f2 f4 7 f 7 9
1e 20 36 38 4b 4d 7 9
24 26 42 44 7 9 24 26
42 44 7 9 17 19 27 29
37 39 47 49 56 58 c 1d
1f 24 2e 33 35 4d 4f 5b
5d f 11 1f 30 43 45 55
68 76 7 9 18 1a 29 2b
3b 3d 49 4b 58 5a 60 62
71 78 85 d 1f 30 3f 52
6d 81 96 a7 11 13 34 36
57 59 74 8b 8d a0 a2 b6
b8 cb cd de e0 f2 f4 7
f 7 9 1e 20 36 38 4b
4d 7 9 24 26 42 44 7
9 24 26 42 44 7 9 17
19 27 29 37 39 47 49 5c
c 1d 1f 24 2d 32 34 4a
4c 57 59 7 c 1d 22 24
2f 31 7 c 1d 22 24 2f
31 17 7 17 a :2 14 26 :2 30
3c 3f 4f 53 54 :2 4f :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 e 7 4 25 22 a 13
1e :2 a 23 21 :2 2c :2 21 11 23
2d 3c 49 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 56 5a 5b :2 56 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5e :2 d :2 a :4 16 :2 a 7
:3 40 b :2 14 1f 1d :2 28 :2 1d :2 a
f 21 29 35 3d 50 5e 69
6b 74 7c a 12 16 26 30
38 3c 4c 56 5f 64 74 f
18 a f 14 26 2d 31 3f
a f 14 24 2d 31 3f a
f 14 1e 2d 32 3f 10 12
1f 11 19 25 2d 40 48 4b
56 a d 1b 24 2f 3c 47
54 5a 5d 73 79 7c 8e d
1b 28 36 43 52 f 25 27
2c 32 37 48 4e 50 58 5b
a f 15 1a 2b 31 34 3f
42 52 54 66 11 19 25 2d
40 48 4b 56 a d 1b 24
2f 3c 47 54 5a 5d 73 79
7c 8e d 1b 28 36 43 52
f 26 28 2d 33 38 49 4f
51 5a 5d a f 15 1a 2b
31 34 3f 42 52 54 66 13
1e 1a a 1a d :2 17 29 :2 33
3f 42 52 56 57 :2 52 :2 29 :3 d
:2 13 18 24 65 68 :2 24 :2 d 5a
:3 a 11 a 38 :2 7 4 40 22
a 13 1e :2 a 21 23 :2 21 7
c 28 2a 4d 4f 66 68 81
8d 8f 11 13 32 34 46 4f
57 59 67 69 14 16 25 2f
37 39 47 49 5d 11 13 3b
3d 66 7 9 1c 1e 2b 2d
37 40 4f 60 7 9 d f
13 1c 2a 3a 49 52 61 72
11 25 35 49 11 25 32 43
57 11 13 22 24 33 35 47
49 5a c 11 13 2f 36 40
42 4f 59 66 81 7 9 16
18 26 28 7 9 18 1a 2a
2c 31 33 40 42 7 9 18
1f 2f 40 7 14 24 26 35
37 44 46 56 7 10 12 22
24 34 45 48 58 6b 6d 7a
7c 89 8b 98 9a 11 13 32
34 47 51 59 5b 69 6b 16
24 26 31 33 41 43 53 55
66 68 7 9 1f 21 2f 32
42 52 54 5c 5e 68 6a 72
74 7f 81 8f 91 9f a1 ab
ad 7 9 25 27 45 47 6f
79 7b 91 11 25 39 51 11
28 31 33 3f 41 58 83 11
28 31 33 40 42 5a 85 11
32 34 4a 4c 55 57 76 84
86 9b b2 11 13 35 37 4f
51 68 6a 79 7b 8f 91 a1
a3 cf 7 9 7 a 1a 7
9 7 a 1a 31 33 7 9
16 1a 2a c 21 23 28 39
3e 40 54 5d 5f 73 75 7
c 12 17 2b 30 32 3e 40
7 c 12 17 2b 31 3a 3c
4c 4e 5b 5e 7 c 12 17
25 2b 2e 3a 3c 7 c 12
17 27 2d 30 3d 3f 7 c
12 17 27 2d 30 3d 3f 7
c 12 17 25 2c 30 3d 3f
10 1e 17 7 17 a :2 14 26
:2 30 3c 3f 4f 53 54 :2 4f :2 26
:3 a :2 10 15 21 62 65 :2 21 :2 a
57 :3 7 e 7 4 26 22 a
13 1e :2 a 21 23 :2 21 7 c
1e 20 35 41 43 11 13 32
34 43 4d 55 57 65 67 c
e 2d 2f 41 4b 53 55 63
65 14 16 28 3a 42 44 52
54 67 11 13 2a 33 c e
25 2e 17 7 9 1c 1e 2b
52 61 88 c 19 40 49 70
7 2e 3a 61 74 7 2e 3b
62 76 7 2e 3d 64 79 7
2e 3b 62 c 13 20 30 32
41 68 7 9 16 18 28 37
40 42 52 54 64 75 78 88
c 1e 30 43 11 13 32 34
47 51 59 5b 69 6b 16 7
9 1a 7 2e 3e 65 7b d
2a 3e 53 c 1b 28 38 4b
5e :2 c 21 7 c 12 17 2b
30 32 3e 40 7 c 12 17
2b 31 3a 3c 4c 4e 5b 5e
d f 2f 31 3e 10 1e 17
7 17 a :2 14 26 :2 30 3c 3f
4f 53 54 :2 4f :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 57 :3 7 e
7 4 26 22 a 13 1e :2 a
21 23 :2 21 7 f 19 :3 7 :2 10
1c 7 16 23 30 3f 11 1e
34 f 10 1d :2 a 17 20 13
20 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 5a 5b :2 56 :2 2c
:3 10 :2 16 1b 27 68 6b :2 27 78
7b :2 27 7f 82 :2 27 8e 91 :2 27
99 9c :2 27 a8 ab b2 bb be
:2 ab :2 27 :2 10 5e :2 d :2 a :4 16 :2 a
7 :3 26 7 f 19 :3 7 :2 10 1c
7 16 26 33 42 12 1f 35
f 10 1d a 14 13 20 a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 5a 5b :2 56 :2 2c :3 10 :2 16
1b 27 68 6b :2 27 78 7b :2 27
7f 82 :2 27 8e 91 :2 27 99 9c
:2 27 a8 ab b2 bb be :2 ab :2 27
:2 10 5e :2 d :2 a :4 16 :2 a 7 :3 26
7 f 19 :3 7 :2 10 1c 7 16
2d 3a 49 11 13 20 22 31
33 f 1b 1d 22 28 2d 3c
41 43 4f 51 11 13 20 22
31 33 f 1e 20 25 2b 30
3c 41 43 4f 51 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
5a 5b :2 56 :2 2c :3 10 :2 16 1b 27
68 6b :2 27 78 7b :2 27 7f 82
:2 27 8e 91 :2 27 99 9c :2 27 a8
ab b2 bb be :2 ab :2 27 :2 10 5e
:2 d :2 a :4 16 :2 a 7 :3 26 7 c
1e 20 2f 3b 3d 4a 5d 66
68 73 75 c 22 24 29 33
38 3a 52 54 60 62 7 c
12 17 26 2d 2f 3b 3f 17
19 27 33 35 45 58 68 73
75 c 22 24 29 32 37 39
51 53 60 62 7 c 1d 22
24 2f 31 7 c 1d 22 24
2f 31 7 c 12 17 26 2d
2f 3b 3f 17 1a 29 35 37
44 59 62 64 76 c 21 25
2f d 10 1b 7 a 18 1a
19 1c 2d 43 4c 4f 5d 60
10 1e 17 7 17 a :2 14 26
:2 30 3c 3f 4f 53 54 :2 4f :2 26
:3 a :2 10 15 21 62 65 :2 21 :2 a
57 :3 7 e 7 4 26 22 a
13 1e :2 a 21 23 :2 21 7 11
18 1f 22 :2 18 28 2b :2 11 :2 7
c 1f 21 2d 2f 3c 4f 58
5a 6c c 16 18 1d 27 a
c 19 1b d f b d 17
10 18 7 18 a :2 14 26 :2 30
3c 3f 4f 53 54 :2 4f :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 e 7 4 26 22 b 14
1f :2 b 24 22 :2 2d :2 22 a 4e
11 1c :2 4e 21 1f :2 2a :2 1f 4d
:2 a 7 c 23 25 34 40 42
4f 5c 65 74 7d 7f 91 c
20 24 2e d 10 1d b e
1c 1e 10 1c 7 1c a :2 14
26 :2 30 3c 3f 4f 53 54 :2 4f
:2 26 :3 a :2 10 15 21 62 65 :2 21
:2 a 57 :3 7 e 7 48 22 a
:2 14 26 :2 30 3c 3f 4f 53 54
:2 4f :2 26 :3 a :2 10 15 21 62 65
:2 21 72 75 :2 21 79 7c :2 21 86
89 92 9a :2 a3 :2 92 b4 :2 89 :2 21
bc bf :2 21 c7 ca :2 21 cf d2
:2 21 d5 d8 :2 21 :2 a 57 :3 7 :2 12
24 :2 2d 3d 41 :2 7 :4 4 1 9
12 9 a :2 14 26 :2 30 3c 40
50 54 55 :2 50 :2 26 :3 a :2 10 15
21 62 65 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 58 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4d 51 52 :2 4d :2 23 :3 7 :2 d 12
1e 5f 62 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 55 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
2082
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :6 e :6 f
:6 10 :6 11 :6 12 :6 13
:7 16 :7 19 :7 1c :7 1f
:7 22 :7 25 :7 28 :7 2b
:7 2e :7 31 :7 34 :7 37
:7 3a :7 3d :7 40 :7 42
:b 44 :11 45 46 :2 45
:2 46 :2 45 :2 46 :2 45
:2 47 :2 45 :9 47 :2 45
:2 48 :2 45 :2 48 :2 45
:2 48 :2 45 :2 48 :2 45
:2 48 :4 45 :3 44 :11 4b
:b 4c :3 4b :5 51 :11 52
:30 53 :3 52 :11 55 :b 56
:3 55 :a 58 :3 51 :3 5d
:3 5e :3 5f :16 62 :9 64
:4 65 :b 66 64 :5 67
63 69 :5 6a :3 69
:2 6b :5 6d :11 6e :24 6f
:3 6e :2 6c :6 6b 68
:3 62 :a 75 :7 77 :3 78
:b 79 77 :5 7a 76
7c :5 7d :3 7c :2 7e
:5 80 :11 81 :24 82 :3 81
:2 7f :6 7e 7b :3 75
:a 88 :5 8a :5 8b 89
8d :5 8e :3 8d :2 8f
:5 91 :11 92 :24 93 :3 92
:2 90 :6 8f 8c :3 88
:a 98 :11 99 :30 9a :3 99
:11 9c :b 9d :3 9c :a 9f
:3 98 :3 88 :3 75 a3
62 :9 a3 :2 a5 :3 a6
a5 :5 a7 a4 a9
:5 aa :3 a9 :2 ab :5 ad
:11 ae :24 af :3 ae :2 ac
:6 ab a8 :3 a3 :a b4
:11 b5 :30 b6 :3 b5 :11 b8
:b b9 :3 b8 :a bb :3 b4
:5 bf :3 c0 bf :5 c1
be c3 :5 c4 :3 c3
:2 c5 :5 c7 :11 c8 :24 c9
:3 c8 :2 c6 :6 c5 c2
:3 a3 cd a3 62
:9 cd :6 cf :5 d0 ce
d2 :5 d3 :3 d2 :2 d4
:5 d6 :11 d7 :24 d8 :3 d7
:2 d5 :6 d4 d1 :3 cd
:a dd :11 de :30 df :3 de
:11 e1 :b e2 :3 e1 :a e4
:3 dd :3 e7 e8 cd
62 :18 e8 :c e9 :2 e8
e9 :2 ea :2 e9 :6 ea
e9 :2 e8 :5 ec :3 ed
ec :5 ee eb f0
:5 f1 :3 f0 :2 f2 :5 f4
:11 f5 :24 f6 :3 f5 :2 f3
:6 f2 ef :3 ea :a fb
:11 fc :30 fd :3 fc :11 ff
:b 100 :3 ff :a 102 :3 fb
ea :3 62 :9 108 :5 10a
:5 10b 10e 110 111
112 113 114 115
116 :2 119 :2 11a :2 11b
:2 11c :2 11d :2 11e :2 11f
:9 120 :3 121 10e :6 122
:5 123 122 :5 125 124
:3 122 10d 128 :5 129
:3 128 :2 12a :5 12c :11 12d
:24 12e :3 12d :2 12b :6 12a
127 :3 108 :5 134 :5 135
:2 138 139 13a :3 13b
138 :6 13c :5 13d 13c
:5 13f 13e :3 13c 137
142 :5 143 :3 142 :2 144
:5 146 :11 147 :24 148 :3 147
:2 145 :6 144 141 :3 108
:c 14d :e 14e :13 14f :9 150
:7 151 :7 152 :9 153 :9 157
:5 158 :9 159 :a 15a :9 15b
:9 15c :9 15d :9 15e :9 162
:5 163 :9 164 :a 165 :9 166
:7 167 :9 168 :9 169 :9 16a
:9 16e :5 16f :9 170 :a 171
:9 172 :7 173 :9 174 :9 175
:9 176 :3 177 :3 14d :11 178
:b 179 :3 178 :3 17b 17c
108 :16 17c :5 17e :5 17f
:3 182 :2 184 :3 185 :e 186
:7 187 :9 188 182 :6 189
:5 18a 189 :5 18c 18b
:3 189 181 18f :5 190
:3 18f :2 191 :5 193 :11 194
:24 195 :3 194 :2 192 :6 191
18e :3 17c :7 19a :3 19d
:4 19e :b 19f :7 1a0 :7 1a1
:9 1a2 :5 1a3 19d :6 1a4
:5 1a5 1a4 :5 1a7 1a6
:3 1a4 19c 1aa :5 1ab
:3 1aa :2 1ac :5 1ae :11 1af
:24 1b0 :3 1af :2 1ad :6 1ac
1a9 :3 17c :d 1b5 :5 1b6
:b 1b7 :6 1b8 :9 1b9 :5 1bd
:5 1be :9 1bf :8 1c0 1c1
1c2 :3 1b5 :11 1c3 :b 1c4
:3 1c3 :3 1c6 1c7 17c
108 :9 1c7 :9 1c8 :e 1c9
:f 1ca :16 1cb :14 1cc :2 1cd
:e 1ce :12 1cf :c 1d0 :9 1d1
:6 1d2 :3 1c8 :11 1d3 :b 1d4
:3 1d3 :3 1d6 1d7 1c7
108 :9 1d7 :c 1d8 :3 1d9
:8 1db :5 1dc 1da 1de
:5 1df :3 1de :2 1e0 :5 1e2
:11 1e3 :24 1e4 :3 1e3 :2 1e1
:6 1e0 1dd :3 1d8 :9 1e9
:3 1ea 1e9 :3 1ec :3 1ee
:6 1ef 1ee :5 1f0 1ed
1f2 :5 1f3 :3 1f2 :2 1f4
:5 1f6 :11 1f7 :24 1f8 :3 1f7
:2 1f5 :6 1f4 1f1 :3 1eb
:9 1fd :3 1ff :5 200 :8 201
:6 202 :6 203 1ff :5 204
1fe 206 :5 207 :3 206
:2 208 :5 20a :11 20b :24 20c
:3 20b :2 209 :6 208 205
:3 1fd :9 211 :3 212 211
:3 214 213 :3 211 1fd
:3 217 216 :3 1fd 1eb
:3 1e9 :11 21f :a 220 :c 221
:3 222 :c 223 :5 224 :a 225
:a 226 :5 227 :6 228 :d 229
:b 22a :8 22b :5 22c :5 22d
:9 22e :5 22f :3 230 :d 231
:9 232 :6 233 :9 235 :a 236
:9 237 :5 238 :a 239 :16 23a
:8 23b :7 23c :9 23d :9 23e
23f :a 240 :6 241 :a 242
:6 243 :9 244 :11 245 :a 246
:b 247 :17 248 :a 249 :7 24a
:8 24b :8 24c :d 24d :2 24e
:3 24f :2 250 :5 251 :5 252
:b 253 :b 254 :9 255 :c 256
:9 257 :9 258 :9 259 :9 25a
:8 25b :2 25c :3 21f :11 25d
:b 25e :3 25d :3 260 1d8
:b 264 :a 265 :a 266 :a 267
:9 268 :4 269 :4 26a :4 26b
:5 26c :8 26d :c 26e :a 26f
:6 270 :6 271 :a 272 :6 273
:9 274 :11 275 :a 276 :b 277
:17 278 :b 279 :a 27a :f 27b
:2 27c :3 27d :2 27e :5 27f
:5 280 :b 281 :b 282 :9 283
:c 284 :9 285 :9 286 :9 287
:9 288 :5 289 :2 28a :3 264
:11 28b :b 28c :3 28b :3 28e
261 :3 1d8 290 1d7
108 :9 290 :5 292 :5 293
296 298 299 29a
29b 29c 29d 29e
29f 2a0 2a3 2a4
:3 2a5 :3 2a6 :3 2a7 :3 2a8
:3 2a9 :3 2aa :3 2ab :6 2ac
296 :6 2ad :5 2ae 2ad
:5 2b0 2af :3 2ad 295
2b3 :5 2b4 :3 2b3 :2 2b5
:5 2b7 :11 2b8 :24 2b9 :3 2b8
:2 2b6 :6 2b5 2b2 :3 290
:7 2be :8 2c1 :2 2c2 :4 2c3
:e 2c4 :12 2c5 :7 2c6 2c1
:6 2c7 :5 2c8 2c7 :5 2ca
2c9 :3 2c7 2c0 2cd
:5 2ce :3 2cd :2 2cf :5 2d1
:11 2d2 :24 2d3 :3 2d2 :2 2d0
:6 2cf 2cc :3 290 :c 2d8
:11 2d9 :a 2da :b 2db :5 2df
:a 2e0 :9 2e1 :2 2e2 :3 2d8
:11 2e3 :b 2e4 :3 2e3 :3 2e6
2e7 290 108 :9 2e7
:5 2e9 :5 2ea 2ed 2ef
2f0 2f1 2f2 2f3
2f4 2f5 2f6 2f7
2fa 2fb :3 2fc :3 2fd
:3 2fe :3 2ff :3 300 :3 301
:3 302 :6 303 2ed :6 304
:5 305 304 :5 307 306
:3 304 2ec 30a :5 30b
:3 30a :2 30c :5 30e :11 30f
:24 310 :3 30f :2 30d :6 30c
309 :3 2e7 :7 315 :b 318
:3 319 :4 31a :e 31b :12 31d
:7 31e :6 320 :2 321 :4 322
:4 323 :7 324 :4 325 :4 326
:a 327 318 :6 328 :5 329
328 :5 32b 32a :3 328
317 32e :5 32f :3 32e
:2 330 :5 332 :11 333 :24 334
:3 333 :2 331 :6 330 32d
:3 2e7 :c 339 :11 33a :a 33b
:b 33c :5 33e :a 33f :9 340
:3 341 :5 343 :3 344 :9 345
:7 346 347 :2 348 :2 349
:3 339 :11 34a :b 34b :3 34a
:3 34d 390 2e7 108
:9 390 :d 391 :10 392 :a 393
:a 394 :a 395 :8 396 :6 397
:8 398 :c 399 :a 39a :a 39b
:7 39c :9 39d :a 39f :e 3a0
:6 3a1 :8 3a2 :a 3a3 :8 3a4
:6 3a5 :7 3a6 :9 3a7 :7 3a8
:a 3a9 :5 3aa :2 3ab :3 391
:11 3ac :b 3ad :3 3ac :3 3af
3b0 390 108 :9 3b0
:5 3b2 :5 3b3 3b6 3b7
3b8 3b9 3ba 3bb
3bc 3bd 3be 3bf
3c0 3c1 3c4 3c5
:3 3c6 :3 3c7 :3 3c8 :4 3c9
:3 3ca :3 3cb :3 3cc :4 3cd
3ce :4 3cf :2 3d0 3b6
:6 3d1 :5 3d2 3d1 :5 3d4
3d3 :3 3d1 3b5 3d7
:5 3d8 :3 3d7 :2 3d9 :5 3db
:11 3dc :24 3dd :3 3dc :2 3da
:6 3d9 3d6 :3 3b0 :5 3e4
:5 3e5 3e8 3ea 3eb
3ec 3ed 3ee 3ef
3f0 3f1 3f2 3f3
3f4 3f5 3f6 3f7
3f8 3f9 3fa 3fb
3fc 3fd 3fe 3ff
400 401 402 403
404 405 406 407
408 :8 40b :8 40c :8 40d
:6 40e :8 40f :6 410 :6 411
:8 412 :9 413 :b 414 :3 415
3e8 :6 416 :5 417 416
:5 419 418 :3 416 3e7
41c :5 41d :3 41c :2 41e
:5 420 :11 421 :24 422 :3 421
:2 41f :6 41e 41b :3 3b0
:4 429 :c 42a 429 :6 42b
:5 42c 42b :5 42e 42d
:3 42b 428 431 :5 432
:3 431 :2 433 :5 435 :11 436
:24 437 :3 436 :2 434 :6 433
430 :3 3b0 :d 43c :11 43d
:a 43e :13 43f :2 440 :8 441
:6 442 :6 443 :c 444 :b 445
:9 447 :11 448 :9 449 :13 44a
:2 44b :8 44c :6 44d :6 44e
:b 44f :b 450 :7 451 :7 452
:3 43c :11 453 :b 454 :3 453
:3 456 457 3b0 108
:b 457 :6 459 :5 45a 458
45c :5 45d :3 45c :2 45e
:5 460 :11 461 :24 462 :3 461
:2 45f :6 45e 45b :3 457
:a 467 :c 468 :c 469 :2 46a
:7 46b :7 46c :7 46d :3 46e
:8 470 :e 471 :6 472 :b 473
:c 474 :8 476 :e 477 :6 478
:b 479 :c 47a :2 47b :3 468
:11 47c :b 47d :3 47c :3 47f
:3 467 481 457 108
:9 481 :b 482 :a 483 :9 484
:5 485 :a 486 :c 487 :4 488
:5 489 :9 48a 48b :a 48c
:6 48d :a 48e :6 48f :9 490
:11 491 :a 492 :b 493 :17 494
:a 495 :4 496 :8 497 :8 498
:c 499 :f 49a :2 49b :3 49c
:2 49d :5 49e :5 49f :c 4a0
:9 4a1 :c 4a2 :9 4a3 :9 4a4
:9 4a5 :9 4a6 :2 4a7 :3 482
:11 4a8 :b 4a9 :3 4a8 :3 4ab
4ac 481 108 :9 4ac
:7 4ad :a 4ae :a 4af :9 4b0
:4 4b1 :4 4b2 4b3 :8 4b4
:5 4b5 :5 4b6 :5 4b7 :5 4b8
:4 4b9 :7 4ba :e 4bb :4 4bc
:a 4bd 4be :3 4bf :5 4c0
:4 4c1 :6 4c2 4c3 :2 4c4
:9 4c5 :c 4c6 :5 4c7 :2 4c8
:3 4ad :11 4c9 :b 4ca :3 4c9
:3 4cc 4cd 4ac 108
:9 4cd :5 4d1 :5 4d2 :4 4d5
:3 4d6 4d7 :2 4d8 4d9
:3 4da :2 4db 4d5 :6 4dc
:5 4dd 4dc :5 4df 4de
:3 4dc 4d4 4e2 :5 4e3
:3 4e2 :2 4e4 :5 4e6 :11 4e7
:24 4e8 :3 4e7 :2 4e5 :6 4e4
4e1 :3 4cd :5 4ee :5 4ef
:4 4f2 :3 4f3 4f4 :2 4f5
:2 4f6 :2 4f7 4f2 :6 4f8
:5 4f9 4f8 :5 4fb 4fa
:3 4f8 4f1 4fe :5 4ff
:3 4fe :2 500 :5 502 :11 503
:24 504 :3 503 :2 501 :6 500
4fd :3 4cd :5 50a :5 50b
:4 50e :6 50f :b 510 :6 512
:b 513 50e :6 514 :5 515
514 :5 517 516 :3 514
50d 51a :5 51b :3 51a
:2 51c :5 51e :11 51f :24 520
:3 51f :2 51d :6 51c 519
:3 4cd :d 525 :b 526 :9 527
:a 52b :b 52c :7 52d :7 52e
:9 52f :a 533 :4 534 :3 535
:4 536 :8 537 :2 538 :3 525
:11 539 :b 53a :3 539 :3 53c
53d 4cd 108 :9 53d
:c 540 :b 542 :5 543 :4 544
:2 545 :3 546 547 :3 542
:11 548 :b 549 :3 548 :3 54b
54c 53d 108 :d 54c
:2 54d :2 54c :6 54d :3 54c
:e 551 :4 552 :3 553 :4 554
555 :3 551 :11 556 :b 557
:3 556 :3 559 54d 108
:11 55b :30 55c :3 55b :a 55e
55a :3 108 43 :3 563
:11 564 :b 565 :17 566 :3 564
:2 568 :3 569 :3 56a 56b
569 568 569 :3 56c
:3 563 :2 56d :5 56f :11 570
:b 571 :18 572 :3 570 :2 574
575 :3 576 577 575
574 575 :3 578 :2 56e
:6 56d 562 :7 1 
78e5
4
:3 0 1 :3 0 2
:a 0 207d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 207d 2 14
:2 0 e :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 207b
0 b :6 0 e
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 207b
0 d :6 0 e
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 207b
0 f :6 0 12
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 207b
0 10 :6 0 14
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 207b
0 11 :6 0 16
:2 0 23 4 :3 0
21 3a 3c :6 0
3f 3d 0 207b
0 13 :6 0 16
:2 0 25 6 :3 0
41 :7 0 45 42
43 207b 0 15
:6 0 16 :2 0 27
6 :3 0 47 :7 0
4b 48 49 207b
0 17 :6 0 16
:2 0 29 6 :3 0
4d :7 0 51 4e
4f 207b 0 18
:6 0 16 :2 0 2b
6 :3 0 53 :7 0
57 54 55 207b
0 19 :6 0 16
:2 0 2d 6 :3 0
59 :7 0 5d 5a
5b 207b 0 1a
:6 0 65 66 0
2f 6 :3 0 5f
:7 0 63 60 61
207b 0 1b :6 0
6c 6d 0 31
9 :3 0 a :2 0
4 67 :7 0 6a
68 0 207b 0
1c :6 0 73 74
0 33 9 :3 0
a :2 0 4 6e
:7 0 71 6f 0
207b 0 1d :6 0
7a 7b 0 35
9 :3 0 a :2 0
4 75 :7 0 78
76 0 207b 0
1e :6 0 81 82
0 37 9 :3 0
a :2 0 4 7c
:7 0 7f 7d 0
207b 0 1f :6 0
88 89 0 39
9 :3 0 a :2 0
4 83 :7 0 86
84 0 207b 0
20 :6 0 8f 90
0 3b 9 :3 0
a :2 0 4 8a
:7 0 8d 8b 0
207b 0 21 :6 0
96 97 0 3d
9 :3 0 a :2 0
4 91 :7 0 94
92 0 207b 0
22 :6 0 9d 9e
0 3f 9 :3 0
a :2 0 4 98
:7 0 9b 99 0
207b 0 23 :6 0
a4 a5 0 41
9 :3 0 a :2 0
4 9f :7 0 a2
a0 0 207b 0
24 :6 0 ab ac
0 43 9 :3 0
a :2 0 4 a6
:7 0 a9 a7 0
207b 0 25 :6 0
b2 b3 0 45
9 :3 0 a :2 0
4 ad :7 0 b0
ae 0 207b 0
26 :6 0 b9 ba
0 47 9 :3 0
a :2 0 4 b4
:7 0 b7 b5 0
207b 0 27 :6 0
c0 c1 0 49
9 :3 0 a :2 0
4 bb :7 0 be
bc 0 207b 0
28 :6 0 c7 c8
0 4b 9 :3 0
a :2 0 4 c2
:7 0 c5 c3 0
207b 0 29 :6 0
ce cf 0 4d
9 :3 0 a :2 0
4 c9 :7 0 cc
ca 0 207b 0
2a :6 0 d4 d5
0 4f 9 :3 0
a :2 0 4 d0
:7 0 d3 d1 0
207b 0 2b :6 0
2c :3 0 2d :3 0
2c :3 0 2e :3 0
d7 d8 0 2
:4 0 51 d9 db
d6 dd dc :2 0
2f :3 0 30 :3 0
df e0 0 31
:4 0 2c :3 0 32
:3 0 e3 e4 0
2 :4 0 53 e5
e7 33 :4 0 34
:2 0 35 :3 0 55
ea ec :3 0 36
:4 0 34 :2 0 37
:4 0 58 ef f1
:3 0 34 :2 0 3
:3 0 5b f3 f5
:3 0 34 :2 0 37
:4 0 5e f7 f9
:3 0 34 :2 0 38
:4 0 61 fb fd
:3 0 34 :2 0 39
:3 0 3a :3 0 5
:3 0 64 101 103
3b :4 0 66 100
106 69 ff 108
:3 0 34 :2 0 38
:4 0 6c 10a 10c
:3 0 34 :2 0 37
:4 0 6f 10e 110
:3 0 34 :2 0 7
:3 0 72 112 114
:3 0 34 :2 0 37
:4 0 75 116 118
:3 0 34 :2 0 3c
:4 0 78 11a 11c
:3 0 7b e1 11e
:2 0 120 80 121
de 120 0 122
82 0 1fdb 2c
:3 0 2d :3 0 123
124 0 2c :3 0
3d :3 0 126 127
0 14 :2 0 2
:4 0 3e :2 0 3f
:2 0 14 :2 0 84
12c 12e :3 0 87
128 130 125 132
131 :2 0 2f :3 0
40 :3 0 134 135
0 31 :4 0 41
:4 0 34 :2 0 35
:3 0 8b 139 13b
:3 0 8e 136 13d
:2 0 13f 91 140
133 13f 0 141
93 0 1fdb 3
:3 0 42 :2 0 95
143 144 :3 0 145
:2 0 2c :3 0 2d
:3 0 147 148 0
2c :3 0 3d :3 0
14a 14b 0 e
:2 0 2 :4 0 43
:2 0 3f :2 0 14
:2 0 97 150 152
:3 0 9a 14c 154
149 156 155 :2 0
2f :3 0 40 :3 0
158 159 0 31
:4 0 44 :4 0 34
:2 0 35 :3 0 9e
15d 15f :3 0 34
:2 0 45 :4 0 a1
161 163 :3 0 34
:2 0 46 :4 0 a4
165 167 :3 0 34
:2 0 39 :3 0 3a
:3 0 47 :3 0 48
:3 0 16c 16d 0
a7 16b 16f 3b
:4 0 a9 16a 172
ac 169 174 :3 0
34 :2 0 49 :4 0
af 176 178 :3 0
34 :2 0 37 :4 0
b2 17a 17c :3 0
34 :2 0 3 :3 0
b5 17e 180 :3 0
34 :2 0 37 :4 0
b8 182 184 :3 0
bb 15a 186 :2 0
188 be 189 157
188 0 18a c0
0 1b4 2c :3 0
2d :3 0 18b 18c
0 2c :3 0 3d
:3 0 18e 18f 0
14 :2 0 2 :4 0
4a :2 0 3f :2 0
14 :2 0 c2 194
196 :3 0 c5 190
198 18d 19a 199
:2 0 2f :3 0 40
:3 0 19c 19d 0
31 :4 0 4b :4 0
34 :2 0 35 :3 0
c9 1a1 1a3 :3 0
cc 19e 1a5 :2 0
1a7 cf 1a8 19b
1a7 0 1a9 d1
0 1b4 4c :3 0
4d :3 0 1aa 1ab
0 47 :3 0 48
:3 0 1ad 1ae 0
3 :3 0 4e :3 0
d3 1ac 1b2 :2 0
1b4 d7 1b5 146
1b4 0 1b6 db
0 1fdb d :3 0
3 :3 0 1b7 1b8
0 1fdb 15 :3 0
5 :3 0 1ba 1bb
0 1fdb f :3 0
7 :3 0 1bd 1be
0 1fdb 39 :3 0
15 :3 0 16 :2 0
dd 1c0 1c3 4f
:2 0 50 :2 0 e2
1c5 1c7 :3 0 1c8
:2 0 39 :3 0 15
:3 0 16 :2 0 e5
1ca 1cd 4f :2 0
51 :2 0 ea 1cf
1d1 :3 0 1d2 :2 0
1c9 1d4 1d3 :2 0
52 :3 0 53 :3 0
52 :3 0 54 :3 0
39 :3 0 55 :3 0
56 :3 0 52 :3 0
57 :3 0 10 :3 0
18 :3 0 17 :3 0
1b :3 0 58 :3 0
55 :3 0 58 :3 0
52 :3 0 52 :3 0
59 :3 0 d :3 0
55 :3 0 59 :3 0
52 :3 0 53 :4 0
5a 1 :8 0 1f4
9 :3 0 5b :3 0
1ef 1f0 0 5c
:3 0 1f1 1f2 0
1f4 ed 247 5d
:3 0 9 :3 0 5b
:3 0 1f6 1f7 0
5c :3 0 1f8 1f9
0 1fb f0 1fd
f2 1fc 1fb :2 0
245 5e :3 0 9
:3 0 5b :3 0 200
201 0 5c :3 0
202 203 0 23d
2c :3 0 2d :3 0
205 206 0 2c
:3 0 3d :3 0 208
209 0 5f :2 0
2 :4 0 60 :2 0
3f :2 0 14 :2 0
f4 20e 210 :3 0
f7 20a 212 207
214 213 :2 0 2f
:3 0 40 :3 0 216
217 0 31 :4 0
61 :4 0 34 :2 0
35 :3 0 fb 21b
21d :3 0 34 :2 0
45 :4 0 fe 21f
221 :3 0 34 :2 0
62 :4 0 101 223
225 :3 0 34 :2 0
5c :3 0 104 227
229 :3 0 34 :2 0
63 :4 0 107 22b
22d :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
10a 230 234 10e
22f 236 :3 0 111
218 238 :2 0 23a
114 23b 215 23a
0 23c 116 0
23d 118 240 :3 0
240 0 240 23f
23d 23e :6 0 242
2 :3 0 11b 244
11d 243 242 :2 0
245 11f :2 0 247
0 247 246 1f4
245 :6 0 3ad 1
:3 0 9 :3 0 5b
:3 0 249 24a 0
9 :3 0 4f :2 0
67 :3 0 24c 24e
0 124 24d 250
:3 0 251 :2 0 52
:3 0 53 :3 0 52
:3 0 54 :3 0 39
:3 0 55 :3 0 56
:3 0 10 :3 0 18
:3 0 17 :3 0 58
:3 0 55 :3 0 68
:3 0 52 :3 0 52
:3 0 59 :3 0 d
:3 0 55 :3 0 59
:3 0 52 :3 0 53
:4 0 69 1 :8 0
26e 9 :3 0 5b
:3 0 269 26a 0
5c :3 0 26b 26c
0 26e 127 2c1
5d :3 0 9 :3 0
5b :3 0 270 271
0 5c :3 0 272
273 0 275 12a
277 12c 276 275
:2 0 2bf 5e :3 0
9 :3 0 5b :3 0
27a 27b 0 5c
:3 0 27c 27d 0
2b7 2c :3 0 2d
:3 0 27f 280 0
2c :3 0 3d :3 0
282 283 0 5f
:2 0 2 :4 0 6a
:2 0 3f :2 0 14
:2 0 12e 288 28a
:3 0 131 284 28c
281 28e 28d :2 0
2f :3 0 40 :3 0
290 291 0 31
:4 0 6b :4 0 34
:2 0 35 :3 0 135
295 297 :3 0 34
:2 0 45 :4 0 138
299 29b :3 0 34
:2 0 62 :4 0 13b
29d 29f :3 0 34
:2 0 5c :3 0 13e
2a1 2a3 :3 0 34
:2 0 63 :4 0 141
2a5 2a7 :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 144 2aa 2ae
148 2a9 2b0 :3 0
14b 292 2b2 :2 0
2b4 14e 2b5 28f
2b4 0 2b6 150
0 2b7 152 2ba
:3 0 2ba 0 2ba
2b9 2b7 2b8 :6 0
2bc 4 :3 0 155
2be 157 2bd 2bc
:2 0 2bf 159 :2 0
2c1 0 2c1 2c0
26e 2bf :6 0 3a9
1 :3 0 9 :3 0
5b :3 0 2c3 2c4
0 9 :3 0 4f
:2 0 67 :3 0 2c6
2c8 0 15e 2c7
2ca :3 0 2cb :2 0
17 :3 0 6c :3 0
59 :3 0 d :4 0
6d 1 :8 0 2d7
9 :3 0 5b :3 0
2d2 2d3 0 5c
:3 0 2d4 2d5 0
2d7 161 32a 5d
:3 0 9 :3 0 5b
:3 0 2d9 2da 0
5c :3 0 2db 2dc
0 2de 164 2e0
166 2df 2de :2 0
328 5e :3 0 9
:3 0 5b :3 0 2e3
2e4 0 5c :3 0
2e5 2e6 0 320
2c :3 0 2d :3 0
2e8 2e9 0 2c
:3 0 3d :3 0 2eb
2ec 0 5f :2 0
2 :4 0 6e :2 0
3f :2 0 14 :2 0
168 2f1 2f3 :3 0
16b 2ed 2f5 2ea
2f7 2f6 :2 0 2f
:3 0 40 :3 0 2f9
2fa 0 31 :4 0
6f :4 0 34 :2 0
35 :3 0 16f 2fe
300 :3 0 34 :2 0
45 :4 0 172 302
304 :3 0 34 :2 0
62 :4 0 175 306
308 :3 0 34 :2 0
5c :3 0 178 30a
30c :3 0 34 :2 0
63 :4 0 17b 30e
310 :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
17e 313 317 182
312 319 :3 0 185
2fb 31b :2 0 31d
188 31e 2f8 31d
0 31f 18a 0
320 18c 323 :3 0
323 0 323 322
320 321 :6 0 325
6 :3 0 18f 327
191 326 325 :2 0
328 193 :2 0 32a
0 32a 329 2d7
328 :6 0 3a6 1
:3 0 9 :3 0 5b
:3 0 32c 32d 0
9 :3 0 4f :2 0
67 :3 0 32f 331
0 198 330 333
:3 0 334 :2 0 2c
:3 0 2d :3 0 336
337 0 2c :3 0
3d :3 0 339 33a
0 e :2 0 2
:4 0 70 :2 0 3f
:2 0 14 :2 0 19b
33f 341 :3 0 19e
33b 343 338 345
344 :2 0 2f :3 0
40 :3 0 347 348
0 31 :4 0 71
:4 0 34 :2 0 35
:3 0 1a2 34c 34e
:3 0 34 :2 0 45
:4 0 1a5 350 352
:3 0 34 :2 0 46
:4 0 1a8 354 356
:3 0 34 :2 0 39
:3 0 3a :3 0 47
:3 0 48 :3 0 35b
35c 0 1ab 35a
35e 3b :4 0 1ad
359 361 1b0 358
363 :3 0 34 :2 0
49 :4 0 1b3 365
367 :3 0 34 :2 0
37 :4 0 1b6 369
36b :3 0 34 :2 0
d :3 0 1b9 36d
36f :3 0 34 :2 0
37 :4 0 1bc 371
373 :3 0 1bf 349
375 :2 0 377 1c2
378 346 377 0
379 1c4 0 3a3
2c :3 0 2d :3 0
37a 37b 0 2c
:3 0 3d :3 0 37d
37e 0 14 :2 0
2 :4 0 72 :2 0
3f :2 0 14 :2 0
1c6 383 385 :3 0
1c9 37f 387 37c
389 388 :2 0 2f
:3 0 40 :3 0 38b
38c 0 31 :4 0
73 :4 0 34 :2 0
35 :3 0 1cd 390
392 :3 0 1d0 38d
394 :2 0 396 1d3
397 38a 396 0
398 1d5 0 3a3
4c :3 0 4d :3 0
399 39a 0 47
:3 0 48 :3 0 39c
39d 0 d :3 0
4e :3 0 1d7 39b
3a1 :2 0 3a3 1db
3a4 335 3a3 0
3a5 1df 0 3a6
1e1 3a7 2cc 3a6
0 3a8 1e4 0
3a9 1e6 3aa 252
3a9 0 3ab 1e9
0 3ad 74 :3 0
1eb 6f3 39 :3 0
15 :3 0 16 :2 0
1ee 3ae 3b1 4f
:2 0 75 :2 0 1f3
3b3 3b5 :3 0 53
:3 0 10 :3 0 76
:3 0 77 :3 0 d
:4 0 78 1 :8 0
3c2 9 :3 0 5b
:3 0 3bd 3be 0
5c :3 0 3bf 3c0
0 3c2 1f6 415
5d :3 0 9 :3 0
5b :3 0 3c4 3c5
0 5c :3 0 3c6
3c7 0 3c9 1f9
3cb 1fb 3ca 3c9
:2 0 413 5e :3 0
9 :3 0 5b :3 0
3ce 3cf 0 5c
:3 0 3d0 3d1 0
40b 2c :3 0 2d
:3 0 3d3 3d4 0
2c :3 0 3d :3 0
3d6 3d7 0 5f
:2 0 2 :4 0 79
:2 0 3f :2 0 14
:2 0 1fd 3dc 3de
:3 0 200 3d8 3e0
3d5 3e2 3e1 :2 0
2f :3 0 40 :3 0
3e4 3e5 0 31
:4 0 7a :4 0 34
:2 0 35 :3 0 204
3e9 3eb :3 0 34
:2 0 45 :4 0 207
3ed 3ef :3 0 34
:2 0 62 :4 0 20a
3f1 3f3 :3 0 34
:2 0 5c :3 0 20d
3f5 3f7 :3 0 34
:2 0 63 :4 0 210
3f9 3fb :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 213 3fe 402
217 3fd 404 :3 0
21a 3e6 406 :2 0
408 21d 409 3e3
408 0 40a 21f
0 40b 221 40e
:3 0 40e 0 40e
40d 40b 40c :6 0
410 8 :3 0 224
412 226 411 410
:2 0 413 228 :2 0
415 0 415 414
3c2 413 :6 0 4f5
1 :3 0 9 :3 0
5b :3 0 417 418
0 9 :3 0 4f
:2 0 67 :3 0 41a
41c 0 22d 41b
41e :3 0 41f :2 0
2c :3 0 2d :3 0
421 422 0 2c
:3 0 3d :3 0 424
425 0 e :2 0
2 :4 0 7b :2 0
3f :2 0 14 :2 0
230 42a 42c :3 0
233 426 42e 423
430 42f :2 0 2f
:3 0 40 :3 0 432
433 0 31 :4 0
7c :4 0 34 :2 0
35 :3 0 237 437
439 :3 0 34 :2 0
45 :4 0 23a 43b
43d :3 0 34 :2 0
46 :4 0 23d 43f
441 :3 0 34 :2 0
39 :3 0 3a :3 0
47 :3 0 48 :3 0
446 447 0 240
445 449 3b :4 0
242 444 44c 245
443 44e :3 0 34
:2 0 49 :4 0 248
450 452 :3 0 34
:2 0 37 :4 0 24b
454 456 :3 0 34
:2 0 3 :3 0 24e
458 45a :3 0 34
:2 0 37 :4 0 251
45c 45e :3 0 254
434 460 :2 0 462
257 463 431 462
0 464 259 0
48e 2c :3 0 2d
:3 0 465 466 0
2c :3 0 3d :3 0
468 469 0 14
:2 0 2 :4 0 7d
:2 0 3f :2 0 14
:2 0 25b 46e 470
:3 0 25e 46a 472
467 474 473 :2 0
2f :3 0 40 :3 0
476 477 0 31
:4 0 7e :4 0 34
:2 0 35 :3 0 262
47b 47d :3 0 265
478 47f :2 0 481
268 482 475 481
0 483 26a 0
48e 4c :3 0 4d
:3 0 484 485 0
47 :3 0 48 :3 0
487 488 0 3
:3 0 4e :3 0 26c
486 48c :2 0 48e
270 48f 420 48e
0 490 274 0
4f5 39 :3 0 56
:3 0 57 :3 0 17
:3 0 1b :3 0 58
:3 0 59 :3 0 d
:4 0 7f 1 :8 0
49f 9 :3 0 5b
:3 0 49a 49b 0
5c :3 0 49c 49d
0 49f 276 4f2
5d :3 0 9 :3 0
5b :3 0 4a1 4a2
0 5c :3 0 4a3
4a4 0 4a6 279
4a8 27b 4a7 4a6
:2 0 4f0 5e :3 0
9 :3 0 5b :3 0
4ab 4ac 0 5c
:3 0 4ad 4ae 0
4e8 2c :3 0 2d
:3 0 4b0 4b1 0
2c :3 0 3d :3 0
4b3 4b4 0 5f
:2 0 2 :4 0 c
:2 0 3f :2 0 14
:2 0 27d 4b9 4bb
:3 0 280 4b5 4bd
4b2 4bf 4be :2 0
2f :3 0 40 :3 0
4c1 4c2 0 31
:4 0 80 :4 0 34
:2 0 35 :3 0 284
4c6 4c8 :3 0 34
:2 0 45 :4 0 287
4ca 4cc :3 0 34
:2 0 62 :4 0 28a
4ce 4d0 :3 0 34
:2 0 5c :3 0 28d
4d2 4d4 :3 0 34
:2 0 63 :4 0 290
4d6 4d8 :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 293 4db 4df
297 4da 4e1 :3 0
29a 4c3 4e3 :2 0
4e5 29d 4e6 4c0
4e5 0 4e7 29f
0 4e8 2a1 4eb
:3 0 4eb 0 4eb
4ea 4e8 4e9 :6 0
4ed a :3 0 2a4
4ef 2a6 4ee 4ed
:2 0 4f0 2a8 :2 0
4f2 0 4f2 4f1
49f 4f0 :6 0 4f5
1 :3 0 74 :3 0
2ab 4f6 3b6 4f5
0 6f4 39 :3 0
15 :3 0 16 :2 0
2af 4f7 4fa 4f
:2 0 81 :2 0 2b4
4fc 4fe :3 0 82
:3 0 b :3 0 6c
:3 0 59 :3 0 d
:4 0 83 1 :8 0
50b 9 :3 0 5b
:3 0 506 507 0
5c :3 0 508 509
0 50b 2b7 55e
5d :3 0 9 :3 0
5b :3 0 50d 50e
0 5c :3 0 50f
510 0 512 2ba
514 2bc 513 512
:2 0 55c 5e :3 0
9 :3 0 5b :3 0
517 518 0 5c
:3 0 519 51a 0
554 2c :3 0 2d
:3 0 51c 51d 0
2c :3 0 3d :3 0
51f 520 0 5f
:2 0 2 :4 0 84
:2 0 3f :2 0 14
:2 0 2be 525 527
:3 0 2c1 521 529
51e 52b 52a :2 0
2f :3 0 40 :3 0
52d 52e 0 31
:4 0 85 :4 0 34
:2 0 35 :3 0 2c5
532 534 :3 0 34
:2 0 45 :4 0 2c8
536 538 :3 0 34
:2 0 62 :4 0 2cb
53a 53c :3 0 34
:2 0 5c :3 0 2ce
53e 540 :3 0 34
:2 0 63 :4 0 2d1
542 544 :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 2d4 547 54b
2d8 546 54d :3 0
2db 52f 54f :2 0
551 2de 552 52c
551 0 553 2e0
0 554 2e2 557
:3 0 557 0 557
556 554 555 :6 0
559 c :3 0 2e5
55b 2e7 55a 559
:2 0 55c 2e9 :2 0
55e 0 55e 55d
50b 55c :6 0 5de
1 :3 0 9 :3 0
5b :3 0 560 561
0 9 :3 0 4f
:2 0 67 :3 0 563
565 0 2ee 564
567 :3 0 568 :2 0
2c :3 0 2d :3 0
56a 56b 0 2c
:3 0 3d :3 0 56d
56e 0 e :2 0
2 :4 0 86 :2 0
3f :2 0 14 :2 0
2f1 573 575 :3 0
2f4 56f 577 56c
579 578 :2 0 2f
:3 0 40 :3 0 57b
57c 0 31 :4 0
87 :4 0 34 :2 0
35 :3 0 2f8 580
582 :3 0 34 :2 0
45 :4 0 2fb 584
586 :3 0 34 :2 0
46 :4 0 2fe 588
58a :3 0 34 :2 0
39 :3 0 3a :3 0
47 :3 0 48 :3 0
58f 590 0 301
58e 592 3b :4 0
303 58d 595 306
58c 597 :3 0 34
:2 0 49 :4 0 309
599 59b :3 0 34
:2 0 37 :4 0 30c
59d 59f :3 0 34
:2 0 3 :3 0 30f
5a1 5a3 :3 0 34
:2 0 37 :4 0 312
5a5 5a7 :3 0 315
57d 5a9 :2 0 5ab
318 5ac 57a 5ab
0 5ad 31a 0
5d7 2c :3 0 2d
:3 0 5ae 5af 0
2c :3 0 3d :3 0
5b1 5b2 0 14
:2 0 2 :4 0 88
:2 0 3f :2 0 14
:2 0 31c 5b7 5b9
:3 0 31f 5b3 5bb
5b0 5bd 5bc :2 0
2f :3 0 40 :3 0
5bf 5c0 0 31
:4 0 89 :4 0 34
:2 0 35 :3 0 323
5c4 5c6 :3 0 326
5c1 5c8 :2 0 5ca
329 5cb 5be 5ca
0 5cc 32b 0
5d7 4c :3 0 4d
:3 0 5cd 5ce 0
47 :3 0 48 :3 0
5d0 5d1 0 3
:3 0 4e :3 0 32d
5cf 5d5 :2 0 5d7
331 5d8 569 5d7
0 5d9 335 0
5de 17 :3 0 8a
:2 0 5da 5db 0
5de 74 :3 0 337
5df 4ff 5de 0
6f4 39 :3 0 15
:3 0 16 :2 0 33b
5e0 5e3 47 :3 0
8b :2 0 8c :3 0
5e5 5e7 0 340
5e6 5e9 :3 0 5ea
:2 0 39 :3 0 15
:3 0 16 :2 0 343
5ec 5ef 8b :2 0
8d :2 0 348 5f1
5f3 :3 0 5f4 :2 0
5eb 5f6 5f5 :2 0
39 :3 0 15 :3 0
16 :2 0 34b 5f8
5fb 47 :3 0 8b
:2 0 8e :3 0 5fd
5ff 0 350 5fe
601 :3 0 602 :2 0
5f7 604 603 :2 0
39 :3 0 15 :3 0
16 :2 0 353 606
609 47 :3 0 8b
:2 0 8f :3 0 60b
60d 0 358 60c
60f :3 0 610 :2 0
605 612 611 :2 0
39 :3 0 56 :3 0
57 :3 0 17 :3 0
1b :3 0 58 :3 0
59 :3 0 3 :4 0
90 1 :8 0 622
9 :3 0 5b :3 0
61d 61e 0 5c
:3 0 61f 620 0
622 35b 675 5d
:3 0 9 :3 0 5b
:3 0 624 625 0
5c :3 0 626 627
0 629 35e 62b
360 62a 629 :2 0
673 5e :3 0 9
:3 0 5b :3 0 62e
62f 0 5c :3 0
630 631 0 66b
2c :3 0 2d :3 0
633 634 0 2c
:3 0 3d :3 0 636
637 0 5f :2 0
2 :4 0 91 :2 0
3f :2 0 14 :2 0
362 63c 63e :3 0
365 638 640 635
642 641 :2 0 2f
:3 0 40 :3 0 644
645 0 31 :4 0
92 :4 0 34 :2 0
35 :3 0 369 649
64b :3 0 34 :2 0
45 :4 0 36c 64d
64f :3 0 34 :2 0
62 :4 0 36f 651
653 :3 0 34 :2 0
5c :3 0 372 655
657 :3 0 34 :2 0
63 :4 0 375 659
65b :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
378 65e 662 37c
65d 664 :3 0 37f
646 666 :2 0 668
382 669 643 668
0 66a 384 0
66b 386 66e :3 0
66e 0 66e 66d
66b 66c :6 0 670
e :3 0 389 672
38b 671 670 :2 0
673 38d :2 0 675
0 675 674 622
673 :6 0 6f1 1
:3 0 9 :3 0 5b
:3 0 677 678 0
9 :3 0 4f :2 0
67 :3 0 67a 67c
0 392 67b 67e
:3 0 67f :2 0 2c
:3 0 2d :3 0 681
682 0 2c :3 0
3d :3 0 684 685
0 e :2 0 2
:4 0 93 :2 0 3f
:2 0 14 :2 0 395
68a 68c :3 0 398
686 68e 683 690
68f :2 0 2f :3 0
40 :3 0 692 693
0 31 :4 0 94
:4 0 34 :2 0 35
:3 0 39c 697 699
:3 0 34 :2 0 45
:4 0 39f 69b 69d
:3 0 34 :2 0 46
:4 0 3a2 69f 6a1
:3 0 34 :2 0 39
:3 0 3a :3 0 47
:3 0 48 :3 0 6a6
6a7 0 3a5 6a5
6a9 3b :4 0 3a7
6a4 6ac 3aa 6a3
6ae :3 0 34 :2 0
49 :4 0 3ad 6b0
6b2 :3 0 34 :2 0
37 :4 0 3b0 6b4
6b6 :3 0 34 :2 0
3 :3 0 3b3 6b8
6ba :3 0 34 :2 0
37 :4 0 3b6 6bc
6be :3 0 3b9 694
6c0 :2 0 6c2 3bc
6c3 691 6c2 0
6c4 3be 0 6ee
2c :3 0 2d :3 0
6c5 6c6 0 2c
:3 0 3d :3 0 6c8
6c9 0 14 :2 0
2 :4 0 12 :2 0
3f :2 0 14 :2 0
3c0 6ce 6d0 :3 0
3c3 6ca 6d2 6c7
6d4 6d3 :2 0 2f
:3 0 40 :3 0 6d6
6d7 0 31 :4 0
95 :4 0 34 :2 0
35 :3 0 3c7 6db
6dd :3 0 3ca 6d8
6df :2 0 6e1 3cd
6e2 6d5 6e1 0
6e3 3cf 0 6ee
4c :3 0 4d :3 0
6e4 6e5 0 47
:3 0 48 :3 0 6e7
6e8 0 3 :3 0
4e :3 0 3d1 6e6
6ec :2 0 6ee 3d5
6ef 680 6ee 0
6f0 3d9 0 6f1
3db 6f2 613 6f1
0 6f4 1d5 3ad
0 6f4 3de 0
1fdb 39 :3 0 15
:3 0 16 :2 0 3e3
6f5 6f8 4f :2 0
16 :2 0 3e8 6fa
6fc :3 0 96 :3 0
97 :3 0 98 :4 0
700 :4 0 701 :2 0
964 9 :3 0 5b
:3 0 703 704 0
16 :2 0 705 706
0 964 99 :3 0
9a :3 0 9b :3 0
9c :3 0 9d :3 0
9e :3 0 9f :3 0
a0 :3 0 55 :3 0
9a :3 0 a1 :3 0
9b :3 0 a1 :3 0
9c :3 0 a1 :3 0
9d :3 0 a1 :3 0
9e :3 0 a1 :3 0
9f :3 0 a1 :3 0
a0 :3 0 a2 :3 0
55 :3 0 a3 :3 0
a4 :3 0 a1 :3 0
55 :3 0 9a :3 0
a1 :3 0 9a :3 0
53 :3 0 d :3 0
a5 :4 0 a6 1
:8 0 740 a7 :4 0
72b :3 0 4e :3 0
4f :2 0 3ed 72e
72f :3 0 9 :3 0
5b :3 0 731 732
0 16 :2 0 733
734 0 736 3f0
73d 9 :3 0 5b
:3 0 737 738 0
a8 :2 0 739 73a
0 73c 3f2 73e
730 736 0 73f
0 73c 0 73f
3f4 0 740 3f7
793 5d :3 0 9
:3 0 5b :3 0 742
743 0 5c :3 0
744 745 0 747
3fa 749 3fc 748
747 :2 0 791 5e
:3 0 9 :3 0 5b
:3 0 74c 74d 0
5c :3 0 74e 74f
0 789 2c :3 0
2d :3 0 751 752
0 2c :3 0 3d
:3 0 754 755 0
5f :2 0 2 :4 0
a9 :2 0 3f :2 0
14 :2 0 3fe 75a
75c :3 0 401 756
75e 753 760 75f
:2 0 2f :3 0 40
:3 0 762 763 0
31 :4 0 aa :4 0
34 :2 0 35 :3 0
405 767 769 :3 0
34 :2 0 45 :4 0
408 76b 76d :3 0
34 :2 0 62 :4 0
40b 76f 771 :3 0
34 :2 0 5c :3 0
40e 773 775 :3 0
34 :2 0 63 :4 0
411 777 779 :3 0
34 :2 0 64 :3 0
65 :3 0 14 :2 0
66 :2 0 414 77c
780 418 77b 782
:3 0 41b 764 784
:2 0 786 41e 787
761 786 0 788
420 0 789 422
78c :3 0 78c 0
78c 78b 789 78a
:6 0 78e 10 :3 0
425 790 427 78f
78e :2 0 791 429
:2 0 793 0 793
792 740 791 :6 0
964 1 :3 0 96
:3 0 97 :3 0 ab
:4 0 797 :4 0 798
:2 0 964 9 :3 0
5b :3 0 79a 79b
0 16 :2 0 79c
79d 0 964 ac
:3 0 ad :3 0 9a
:3 0 a2 :3 0 53
:3 0 d :3 0 a5
:4 0 ae 1 :8 0
7bc a7 :4 0 7a7
:3 0 4e :3 0 4f
:2 0 42e 7aa 7ab
:3 0 9 :3 0 5b
:3 0 7ad 7ae 0
16 :2 0 7af 7b0
0 7b2 431 7b9
9 :3 0 5b :3 0
7b3 7b4 0 a8
:2 0 7b5 7b6 0
7b8 433 7ba 7ac
7b2 0 7bb 0
7b8 0 7bb 435
0 7bc 438 80f
5d :3 0 9 :3 0
5b :3 0 7be 7bf
0 5c :3 0 7c0
7c1 0 7c3 43b
7c5 43d 7c4 7c3
:2 0 80d 5e :3 0
9 :3 0 5b :3 0
7c8 7c9 0 5c
:3 0 7ca 7cb 0
805 2c :3 0 2d
:3 0 7cd 7ce 0
2c :3 0 3d :3 0
7d0 7d1 0 5f
:2 0 2 :4 0 af
:2 0 3f :2 0 14
:2 0 43f 7d6 7d8
:3 0 442 7d2 7da
7cf 7dc 7db :2 0
2f :3 0 40 :3 0
7de 7df 0 31
:4 0 b0 :4 0 34
:2 0 35 :3 0 446
7e3 7e5 :3 0 34
:2 0 45 :4 0 449
7e7 7e9 :3 0 34
:2 0 62 :4 0 44c
7eb 7ed :3 0 34
:2 0 5c :3 0 44f
7ef 7f1 :3 0 34
:2 0 63 :4 0 452
7f3 7f5 :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 455 7f8 7fc
459 7f7 7fe :3 0
45c 7e0 800 :2 0
802 45f 803 7dd
802 0 804 461
0 805 463 808
:3 0 808 0 808
807 805 806 :6 0
80a 12 :3 0 466
80c 468 80b 80a
:2 0 80d 46a :2 0
80f 0 80f 80e
7bc 80d :6 0 964
1 :3 0 b1 :3 0
1c :3 0 76 :3 0
b2 :3 0 b2 :3 0
53 :3 0 d :3 0
b2 :3 0 9a :3 0
b3 :3 0 9a :3 0
b4 :3 0 b3 :3 0
9a :3 0 b5 :3 0
b6 :3 0 b7 :3 0
b5 :3 0 b8 :3 0
b5 :3 0 b9 :3 0
ba :3 0 54 :3 0
ba :3 0 b7 :3 0
bb :3 0 b3 :3 0
9d :3 0 b3 :3 0
9e :3 0 b3 :3 0
9f :3 0 b3 :3 0
a0 :3 0 bc :3 0
bd :3 0 be :3 0
bd :3 0 bf :3 0
bd :3 0 c0 :3 0
bd :3 0 c1 :3 0
c2 :3 0 82 :3 0
99 :3 0 b3 :3 0
a3 :3 0 c3 :3 0
b5 :3 0 b3 :3 0
9a :3 0 b5 :3 0
9a :3 0 a3 :3 0
a4 :3 0 c4 :3 0
c4 :3 0 59 :3 0
b3 :3 0 9b :3 0
a3 :3 0 a4 :3 0
ba :3 0 ba :3 0
59 :3 0 c4 :3 0
9b :3 0 c5 :3 0
c6 :3 0 a3 :3 0
c7 :3 0 bd :3 0
bd :3 0 9c :3 0
b3 :3 0 9c :3 0
b4 :3 0 c8 :3 0
ad :3 0 9a :3 0
b5 :3 0 c9 :3 0
b7 :3 0 b8 :3 0
b9 :3 0 c4 :3 0
54 :3 0 c4 :3 0
b7 :3 0 bb :3 0
a1 :3 0 9d :3 0
a1 :3 0 9e :3 0
a1 :3 0 9f :3 0
a1 :3 0 a0 :3 0
bc :3 0 bd :3 0
be :3 0 bd :3 0
bf :3 0 bd :3 0
c0 :3 0 bd :3 0
c1 :3 0 c2 :3 0
82 :3 0 ac :3 0
c8 :3 0 a3 :3 0
ca :3 0 b5 :3 0
c8 :3 0 ad :3 0
b5 :3 0 ad :3 0
c5 :3 0 c6 :3 0
a3 :3 0 a4 :3 0
a1 :3 0 b5 :3 0
cb :3 0 a1 :3 0
59 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
a4 :3 0 c4 :3 0
c4 :3 0 59 :3 0
a1 :3 0 9b :3 0
c5 :3 0 c6 :3 0
a3 :3 0 c7 :3 0
bd :3 0 bd :3 0
9c :3 0 a1 :3 0
9c :3 0 b4 :3 0
c8 :3 0 ad :3 0
9a :3 0 b5 :3 0
c9 :3 0 b7 :3 0
b8 :3 0 b9 :3 0
c4 :3 0 54 :3 0
c4 :3 0 b7 :3 0
bb :3 0 a1 :3 0
9d :3 0 a1 :3 0
9e :3 0 a1 :3 0
9f :3 0 a1 :3 0
a0 :3 0 bc :3 0
bd :3 0 be :3 0
bd :3 0 bf :3 0
bd :3 0 c0 :3 0
bd :3 0 c1 :3 0
c2 :3 0 82 :3 0
ac :3 0 c8 :3 0
a3 :3 0 ca :3 0
b5 :3 0 c8 :3 0
ad :3 0 b5 :3 0
ad :3 0 a3 :3 0
cc :3 0 cd :3 0
b5 :3 0 ad :3 0
cd :3 0 ce :3 0
c5 :3 0 c6 :3 0
a3 :3 0 a4 :3 0
a1 :3 0 cd :3 0
cf :3 0 a1 :3 0
59 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
a4 :3 0 c4 :3 0
c4 :3 0 59 :3 0
a1 :3 0 9b :3 0
c5 :3 0 c6 :3 0
a3 :3 0 c7 :3 0
bd :3 0 bd :3 0
9c :3 0 a1 :3 0
9c :3 0 b4 :3 0
c8 :3 0 ad :3 0
9a :3 0 b5 :3 0
c9 :3 0 b7 :3 0
b8 :3 0 b9 :3 0
c4 :3 0 54 :3 0
c4 :3 0 b7 :3 0
bb :3 0 a1 :3 0
9d :3 0 a1 :3 0
9e :3 0 a1 :3 0
9f :3 0 a1 :3 0
a0 :3 0 bc :3 0
bd :3 0 be :3 0
bd :3 0 bf :3 0
bd :3 0 c0 :3 0
bd :3 0 c1 :3 0
c2 :3 0 82 :3 0
ac :3 0 c8 :3 0
a3 :3 0 ca :3 0
b5 :3 0 c8 :3 0
ad :3 0 b5 :3 0
ad :3 0 a3 :3 0
d0 :3 0 cd :3 0
b5 :3 0 ad :3 0
cd :3 0 ce :3 0
c5 :3 0 c6 :3 0
a3 :3 0 a4 :3 0
a1 :3 0 cd :3 0
cb :3 0 a1 :3 0
59 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
a4 :3 0 c4 :3 0
c4 :3 0 59 :3 0
a1 :3 0 9b :3 0
c5 :3 0 c6 :3 0
a3 :3 0 c7 :3 0
bd :3 0 bd :3 0
9c :3 0 a1 :3 0
9c :3 0 b4 :3 0
9a :3 0 54 :4 0
d1 1 :a 0 940
:2 0 964 812 93e
:2 0 2c :3 0 2d
:3 0 941 942 0
2c :3 0 3d :3 0
944 945 0 14
:2 0 2 :4 0 d2
:2 0 3f :2 0 14
:2 0 46d 94a 94c
:3 0 470 946 94e
943 950 94f :2 0
2f :3 0 40 :3 0
952 953 0 31
:4 0 d3 :4 0 34
:2 0 35 :3 0 474
957 959 :3 0 477
954 95b :2 0 95d
47a 95e 951 95d
0 95f 47c 0
964 8 :3 0 1c
:3 0 961 :2 0 964
74 :3 0 47e 1fd8
39 :3 0 15 :3 0
16 :2 0 488 965
968 4f :2 0 14
:2 0 48d 96a 96c
:3 0 96d :2 0 39
:3 0 15 :3 0 16
:2 0 490 96f 972
4f :2 0 d4 :2 0
495 974 976 :3 0
977 :2 0 96e 979
978 :2 0 96 :3 0
97 :3 0 d5 :4 0
97d :4 0 97e :2 0
b25 9 :3 0 5b
:3 0 980 981 0
16 :2 0 982 983
0 b25 d6 :3 0
9a :3 0 54 :3 0
d7 :3 0 9a :3 0
b2 :3 0 77 :3 0
54 :3 0 a2 :3 0
d7 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
76 :3 0 b2 :3 0
b2 :3 0 53 :3 0
d :3 0 d7 :3 0
9a :3 0 b2 :3 0
9a :3 0 d7 :3 0
53 :3 0 d :3 0
d7 :3 0 a5 :3 0
b2 :3 0 d8 :3 0
76 :3 0 d9 :3 0
d7 :3 0 9a :3 0
d9 :3 0 9a :3 0
d9 :3 0 da :3 0
d :4 0 db 1
:8 0 9c1 a7 :4 0
9ac :3 0 4e :3 0
4f :2 0 49a 9af
9b0 :3 0 9 :3 0
5b :3 0 9b2 9b3
0 16 :2 0 9b4
9b5 0 9b7 49d
9be 9 :3 0 5b
:3 0 9b8 9b9 0
a8 :2 0 9ba 9bb
0 9bd 49f 9bf
9b1 9b7 0 9c0
0 9bd 0 9c0
4a1 0 9c1 4a4
a14 5d :3 0 9
:3 0 5b :3 0 9c3
9c4 0 5c :3 0
9c5 9c6 0 9c8
4a7 9ca 4a9 9c9
9c8 :2 0 a12 5e
:3 0 9 :3 0 5b
:3 0 9cd 9ce 0
5c :3 0 9cf 9d0
0 a0a 2c :3 0
2d :3 0 9d2 9d3
0 2c :3 0 3d
:3 0 9d5 9d6 0
5f :2 0 2 :4 0
dc :2 0 3f :2 0
14 :2 0 4ab 9db
9dd :3 0 4ae 9d7
9df 9d4 9e1 9e0
:2 0 2f :3 0 40
:3 0 9e3 9e4 0
31 :4 0 dd :4 0
34 :2 0 35 :3 0
4b2 9e8 9ea :3 0
34 :2 0 45 :4 0
4b5 9ec 9ee :3 0
34 :2 0 62 :4 0
4b8 9f0 9f2 :3 0
34 :2 0 5c :3 0
4bb 9f4 9f6 :3 0
34 :2 0 63 :4 0
4be 9f8 9fa :3 0
34 :2 0 64 :3 0
65 :3 0 14 :2 0
66 :2 0 4c1 9fd
a01 4c5 9fc a03
:3 0 4c8 9e5 a05
:2 0 a07 4cb a08
9e2 a07 0 a09
4cd 0 a0a 4cf
a0d :3 0 a0d 0
a0d a0c a0a a0b
:6 0 a0f 14 :3 0
4d2 a11 4d4 a10
a0f :2 0 a12 4d6
:2 0 a14 0 a14
a13 9c1 a12 :6 0
b25 1 :3 0 9
:3 0 5b :3 0 a16
a17 0 de :4 0
a19 a1a :3 0 a18
a1b 0 b25 df
:3 0 59 :3 0 b7
:3 0 a1 :3 0 ad
:3 0 a1 :3 0 c9
:3 0 a2 :3 0 55
:3 0 a3 :3 0 ca
:3 0 a1 :3 0 55
:3 0 a5 :3 0 a1
:3 0 ad :3 0 55
:3 0 9a :3 0 a3
:3 0 a4 :3 0 c4
:3 0 c4 :3 0 59
:3 0 a1 :3 0 cb
:3 0 a3 :3 0 a4
:3 0 ba :3 0 ba
:3 0 59 :3 0 c4
:3 0 9b :3 0 a3
:3 0 76 :3 0 d9
:3 0 d9 :3 0 ce
:3 0 55 :3 0 ce
:3 0 d9 :3 0 d8
:3 0 55 :3 0 53
:3 0 d :3 0 55
:3 0 e0 :4 0 e1
1 :8 0 a61 a7
:4 0 a4c :3 0 4e
:3 0 4f :2 0 4db
a4f a50 :3 0 9
:3 0 5b :3 0 a52
a53 0 16 :2 0
a54 a55 0 a57
4de a5e 9 :3 0
5b :3 0 a58 a59
0 a8 :2 0 a5a
a5b 0 a5d 4e0
a5f a51 a57 0
a60 0 a5d 0
a60 4e2 0 a61
4e5 ab4 5d :3 0
9 :3 0 5b :3 0
a63 a64 0 5c
:3 0 a65 a66 0
a68 4e8 a6a 4ea
a69 a68 :2 0 ab2
5e :3 0 9 :3 0
5b :3 0 a6d a6e
0 5c :3 0 a6f
a70 0 aaa 2c
:3 0 2d :3 0 a72
a73 0 2c :3 0
3d :3 0 a75 a76
0 5f :2 0 2
:4 0 e2 :2 0 3f
:2 0 14 :2 0 4ec
a7b a7d :3 0 4ef
a77 a7f a74 a81
a80 :2 0 2f :3 0
40 :3 0 a83 a84
0 31 :4 0 e3
:4 0 34 :2 0 35
:3 0 4f3 a88 a8a
:3 0 34 :2 0 45
:4 0 4f6 a8c a8e
:3 0 34 :2 0 62
:4 0 4f9 a90 a92
:3 0 34 :2 0 5c
:3 0 4fc a94 a96
:3 0 34 :2 0 63
:4 0 4ff a98 a9a
:3 0 34 :2 0 64
:3 0 65 :3 0 14
:2 0 66 :2 0 502
a9d aa1 506 a9c
aa3 :3 0 509 a85
aa5 :2 0 aa7 50c
aa8 a82 aa7 0
aa9 50e 0 aaa
510 aad :3 0 aad
0 aad aac aaa
aab :6 0 aaf 16
:3 0 513 ab1 515
ab0 aaf :2 0 ab2
517 :2 0 ab4 0
ab4 ab3 a61 ab2
:6 0 b25 1 :3 0
b1 :3 0 1d :3 0
55 :3 0 9a :3 0
59 :3 0 ce :3 0
b5 :3 0 b6 :3 0
b7 :3 0 55 :3 0
54 :3 0 b5 :3 0
b9 :3 0 e4 :3 0
e5 :3 0 e4 :3 0
e6 :3 0 e7 :3 0
e4 :3 0 e8 :3 0
e4 :3 0 e9 :3 0
ea :3 0 eb :3 0
ec :3 0 17 :3 0
56 :3 0 ed :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 c2 :3 0
82 :3 0 d6 :3 0
55 :3 0 a3 :3 0
c3 :3 0 b5 :3 0
55 :3 0 9a :3 0
b5 :3 0 9a :3 0
59 :3 0 ce :3 0
b7 :3 0 54 :3 0
b9 :3 0 e4 :3 0
e5 :3 0 e4 :3 0
e6 :3 0 e7 :3 0
e4 :3 0 e8 :3 0
e4 :3 0 e9 :3 0
ea :3 0 eb :3 0
ec :3 0 17 :3 0
56 :3 0 ed :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 c2 :3 0
82 :3 0 df :3 0
54 :4 0 f3 1
:a 0 b01 :2 0 b25
ab7 aff :2 0 2c
:3 0 2d :3 0 b02
b03 0 2c :3 0
3d :3 0 b05 b06
0 14 :2 0 2
:4 0 f4 :2 0 3f
:2 0 14 :2 0 51a
b0b b0d :3 0 51d
b07 b0f b04 b11
b10 :2 0 2f :3 0
40 :3 0 b13 b14
0 31 :4 0 f5
:4 0 34 :2 0 35
:3 0 521 b18 b1a
:3 0 524 b15 b1c
:2 0 b1e 527 b1f
b12 b1e 0 b20
529 0 b25 8
:3 0 1d :3 0 b22
:2 0 b25 74 :3 0
52b b26 97a b25
0 1fda 39 :3 0
15 :3 0 16 :2 0
534 b27 b2a 4f
:2 0 50 :2 0 539
b2c b2e :3 0 b1
:3 0 1e :3 0 d9
:3 0 77 :3 0 d9
:3 0 77 :3 0 55
:3 0 ce :3 0 59
:3 0 55 :3 0 ad
:3 0 b5 :3 0 c9
:3 0 b7 :3 0 54
:3 0 55 :3 0 ce
:3 0 55 :3 0 f6
:3 0 d9 :3 0 e5
:3 0 d9 :3 0 e6
:3 0 d9 :3 0 f0
:3 0 d9 :3 0 f7
:3 0 d9 :3 0 f8
:3 0 17 :3 0 56
:3 0 55 :3 0 f9
:3 0 55 :3 0 fa
:3 0 fb :3 0 b7
:3 0 fc :3 0 39
:3 0 55 :3 0 fd
:3 0 55 :3 0 fa
:3 0 fd :3 0 fe
:3 0 b7 :3 0 ff
:3 0 d9 :3 0 be
:3 0 d9 :3 0 100
:3 0 d9 :3 0 c0
:3 0 d9 :3 0 101
:3 0 102 :3 0 55
:3 0 103 :3 0 d9
:3 0 f2 :3 0 d9
:3 0 d8 :3 0 d9
:3 0 104 :3 0 105
:3 0 b7 :3 0 106
:3 0 d9 :3 0 ec
:3 0 d9 :3 0 107
:3 0 d9 :3 0 108
:3 0 d9 :3 0 109
:3 0 d9 :3 0 10a
:3 0 d9 :3 0 10b
:3 0 10c :3 0 d9
:3 0 10d :3 0 a2
:3 0 55 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 76 :3 0 d9
:3 0 d9 :3 0 da
:3 0 d :3 0 55
:3 0 ce :3 0 d9
:3 0 ce :3 0 c5
:3 0 c6 :3 0 a3
:3 0 ca :3 0 b5
:3 0 55 :3 0 9a
:3 0 b5 :3 0 ad
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 10e
:3 0 fb :3 0 55
:3 0 fa :3 0 fb
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10e :3 0 fe
:3 0 39 :3 0 55
:3 0 fd :3 0 55
:3 0 fa :3 0 fe
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10f :3 0 105
:3 0 105 :3 0 59
:3 0 d9 :3 0 104
:3 0 55 :3 0 59
:3 0 d :3 0 55
:3 0 a5 :3 0 b7
:4 0 110 1 :a 0
bbf :2 0 be3 b31
bbd :2 0 2c :3 0
2d :3 0 bc0 bc1
0 2c :3 0 3d
:3 0 bc3 bc4 0
14 :2 0 2 :4 0
111 :2 0 3f :2 0
14 :2 0 53c bc9
bcb :3 0 53f bc5
bcd bc2 bcf bce
:2 0 2f :3 0 40
:3 0 bd1 bd2 0
31 :4 0 112 :4 0
34 :2 0 35 :3 0
543 bd6 bd8 :3 0
546 bd3 bda :2 0
bdc 549 bdd bd0
bdc 0 bde 54b
0 be3 8 :3 0
1e :3 0 be0 :2 0
be3 74 :3 0 54d
be4 b2f be3 0
1fda 39 :3 0 15
:3 0 16 :2 0 551
be5 be8 4f :2 0
51 :2 0 556 bea
bec :3 0 113 :3 0
39 :3 0 18 :3 0
16 :2 0 559 bef
bf2 55c bee bf4
8b :2 0 16 :2 0
560 bf6 bf8 :3 0
19 :3 0 16 :2 0
bfa bfb 0 faa
114 :3 0 19 :3 0
76 :3 0 53 :3 0
10 :3 0 da :3 0
d :4 0 115 1
:8 0 c0a 9 :3 0
5b :3 0 c05 c06
0 5c :3 0 c07
c08 0 c0a 563
c5d 5d :3 0 9
:3 0 5b :3 0 c0c
c0d 0 5c :3 0
c0e c0f 0 c11
566 c13 568 c12
c11 :2 0 c5b 5e
:3 0 9 :3 0 5b
:3 0 c16 c17 0
5c :3 0 c18 c19
0 c53 2c :3 0
2d :3 0 c1b c1c
0 2c :3 0 3d
:3 0 c1e c1f 0
5f :2 0 2 :4 0
116 :2 0 3f :2 0
14 :2 0 56a c24
c26 :3 0 56d c20
c28 c1d c2a c29
:2 0 2f :3 0 40
:3 0 c2c c2d 0
31 :4 0 117 :4 0
34 :2 0 35 :3 0
571 c31 c33 :3 0
34 :2 0 45 :4 0
574 c35 c37 :3 0
34 :2 0 62 :4 0
577 c39 c3b :3 0
34 :2 0 5c :3 0
57a c3d c3f :3 0
34 :2 0 63 :4 0
57d c41 c43 :3 0
34 :2 0 64 :3 0
65 :3 0 14 :2 0
66 :2 0 580 c46
c4a 584 c45 c4c
:3 0 587 c2e c4e
:2 0 c50 58a c51
c2b c50 0 c52
58c 0 c53 58e
c56 :3 0 c56 0
c56 c55 c53 c54
:6 0 c58 18 :3 0
591 c5a 593 c59
c58 :2 0 c5b 595
:2 0 c5d 0 c5d
c5c c0a c5b :6 0
faa 1 :3 0 39
:3 0 19 :3 0 16
:2 0 598 c5f c62
4f :2 0 16 :2 0
59d c64 c66 :3 0
13 :3 0 14 :4 0
c68 c69 0 c6b
5a0 d70 19 :3 0
16 :2 0 c6c c6d
0 d6f 114 :3 0
19 :3 0 118 :3 0
76 :3 0 53 :3 0
10 :3 0 da :3 0
d :3 0 119 :4 0
11a 1 :8 0 c7e
9 :3 0 5b :3 0
c79 c7a 0 5c
:3 0 c7b c7c 0
c7e 5a2 cd1 5d
:3 0 9 :3 0 5b
:3 0 c80 c81 0
5c :3 0 c82 c83
0 c85 5a5 c87
5a7 c86 c85 :2 0
ccf 5e :3 0 9
:3 0 5b :3 0 c8a
c8b 0 5c :3 0
c8c c8d 0 cc7
2c :3 0 2d :3 0
c8f c90 0 2c
:3 0 3d :3 0 c92
c93 0 5f :2 0
2 :4 0 11b :2 0
3f :2 0 14 :2 0
5a9 c98 c9a :3 0
5ac c94 c9c c91
c9e c9d :2 0 2f
:3 0 40 :3 0 ca0
ca1 0 31 :4 0
11c :4 0 34 :2 0
35 :3 0 5b0 ca5
ca7 :3 0 34 :2 0
45 :4 0 5b3 ca9
cab :3 0 34 :2 0
62 :4 0 5b6 cad
caf :3 0 34 :2 0
5c :3 0 5b9 cb1
cb3 :3 0 34 :2 0
63 :4 0 5bc cb5
cb7 :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
5bf cba cbe 5c3
cb9 cc0 :3 0 5c6
ca2 cc2 :2 0 cc4
5c9 cc5 c9f cc4
0 cc6 5cb 0
cc7 5cd cca :3 0
cca 0 cca cc9
cc7 cc8 :6 0 ccc
1a :3 0 5d0 cce
5d2 ccd ccc :2 0
ccf 5d4 :2 0 cd1
0 cd1 cd0 c7e
ccf :6 0 d6f 1
:3 0 39 :3 0 19
:3 0 16 :2 0 5d7
cd3 cd6 4f :2 0
16 :2 0 5dc cd8
cda :3 0 114 :3 0
19 :3 0 118 :3 0
76 :3 0 b2 :3 0
a3 :3 0 11d :3 0
11e :3 0 11e :3 0
59 :3 0 b2 :3 0
53 :3 0 11e :3 0
9a :3 0 b2 :3 0
9a :3 0 b2 :3 0
53 :3 0 10 :3 0
b2 :3 0 da :3 0
d :3 0 11f :3 0
64 :3 0 b2 :3 0
120 :3 0 11e :3 0
121 :4 0 122 1
:8 0 cfe 9 :3 0
5b :3 0 cf9 cfa
0 5c :3 0 cfb
cfc 0 cfe 5df
d51 5d :3 0 9
:3 0 5b :3 0 d00
d01 0 5c :3 0
d02 d03 0 d05
5e2 d07 5e4 d06
d05 :2 0 d4f 5e
:3 0 9 :3 0 5b
:3 0 d0a d0b 0
5c :3 0 d0c d0d
0 d47 2c :3 0
2d :3 0 d0f d10
0 2c :3 0 3d
:3 0 d12 d13 0
5f :2 0 2 :4 0
123 :2 0 3f :2 0
14 :2 0 5e6 d18
d1a :3 0 5e9 d14
d1c d11 d1e d1d
:2 0 2f :3 0 40
:3 0 d20 d21 0
31 :4 0 124 :4 0
34 :2 0 35 :3 0
5ed d25 d27 :3 0
34 :2 0 45 :4 0
5f0 d29 d2b :3 0
34 :2 0 62 :4 0
5f3 d2d d2f :3 0
34 :2 0 5c :3 0
5f6 d31 d33 :3 0
34 :2 0 63 :4 0
5f9 d35 d37 :3 0
34 :2 0 64 :3 0
65 :3 0 14 :2 0
66 :2 0 5fc d3a
d3e 600 d39 d40
:3 0 603 d22 d42
:2 0 d44 606 d45
d1f d44 0 d46
608 0 d47 60a
d4a :3 0 d4a 0
d4a d49 d47 d48
:6 0 d4c 1c :3 0
60d d4e 60f d4d
d4c :2 0 d4f 611
:2 0 d51 0 d51
d50 cfe d4f :6 0
d67 1 :3 0 39
:3 0 19 :3 0 16
:2 0 614 d53 d56
4f :2 0 16 :2 0
619 d58 d5a :3 0
13 :3 0 50 :4 0
d5c d5d 0 d5f
61c d64 13 :3 0
14 :4 0 d60 d61
0 d63 61e d65
d5b d5f 0 d66
0 d63 0 d66
620 0 d67 623
d6c 13 :3 0 14
:4 0 d68 d69 0
d6b 626 d6d cdb
d67 0 d6e 0
d6b 0 d6e 628
0 d6f 62b d71
c67 c6b 0 d72
0 d6f 0 d72
62f 0 faa b1
:3 0 1f :3 0 d9
:3 0 59 :3 0 55
:3 0 9a :3 0 d9
:3 0 b7 :3 0 d9
:3 0 54 :3 0 ce
:3 0 55 :3 0 f6
:3 0 d9 :3 0 f7
:3 0 d9 :3 0 f8
:3 0 d9 :3 0 125
:3 0 d9 :3 0 126
:3 0 d9 :3 0 f7
:3 0 e5 :3 0 d9
:3 0 f8 :3 0 e6
:3 0 d9 :3 0 127
:3 0 d9 :3 0 e7
:3 0 f0 :3 0 d9
:3 0 127 :3 0 d9
:3 0 e7 :3 0 d9
:3 0 128 :3 0 eb
:3 0 129 :3 0 d9
:3 0 12a :3 0 d9
:3 0 128 :3 0 12b
:3 0 12c :3 0 d9
:3 0 128 :3 0 12c
:3 0 d9 :3 0 127
:3 0 d9 :3 0 e7
:3 0 12d :3 0 e4
:3 0 12e :3 0 e4
:3 0 12f :3 0 130
:3 0 d9 :3 0 131
:3 0 d9 :3 0 132
:3 0 d9 :3 0 133
:3 0 d9 :3 0 120
:3 0 d9 :3 0 134
:3 0 d9 :3 0 128
:3 0 135 :3 0 d9
:3 0 136 :3 0 d9
:3 0 137 :3 0 d9
:3 0 138 :3 0 139
:3 0 17 :3 0 56
:3 0 f9 :3 0 fa
:3 0 fc :3 0 fd
:3 0 ff :3 0 be
:3 0 100 :3 0 c0
:3 0 101 :3 0 102
:3 0 d9 :3 0 103
:3 0 13a :3 0 13b
:3 0 f2 :3 0 d9
:3 0 13c :3 0 d9
:3 0 13d :3 0 d9
:3 0 13e :3 0 13f
:3 0 d8 :3 0 104
:3 0 140 :3 0 ec
:3 0 107 :3 0 108
:3 0 109 :3 0 10a
:3 0 10b :3 0 10c
:3 0 141 :3 0 10d
:3 0 13 :3 0 119
:3 0 142 :3 0 d9
:3 0 143 :3 0 d9
:3 0 144 :3 0 1b
:3 0 d9 :3 0 145
:3 0 e4 :3 0 145
:3 0 1b :3 0 d9
:3 0 146 :3 0 e4
:3 0 146 :3 0 1b
:3 0 d9 :3 0 147
:3 0 148 :3 0 d9
:3 0 12d :3 0 149
:3 0 14a :3 0 14b
:3 0 14c :3 0 14d
:3 0 14e :3 0 14f
:3 0 150 :3 0 151
:3 0 152 :3 0 153
:3 0 58 :3 0 d9
:3 0 c5 :3 0 a3
:3 0 a2 :3 0 55
:3 0 55 :3 0 59
:3 0 d9 :3 0 59
:3 0 55 :3 0 9a
:3 0 f :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10e :3 0 fb
:3 0 55 :3 0 fa
:3 0 fb :3 0 59
:3 0 d9 :3 0 53
:3 0 10 :3 0 d9
:3 0 59 :3 0 d
:3 0 d9 :3 0 77
:3 0 d9 :3 0 77
:3 0 55 :3 0 ce
:3 0 59 :3 0 55
:3 0 9a :3 0 55
:3 0 a5 :3 0 b5
:3 0 c9 :3 0 ca
:3 0 b5 :3 0 55
:3 0 9a :3 0 b5
:3 0 ad :3 0 a1
:3 0 b6 :3 0 c3
:3 0 a1 :3 0 55
:3 0 9a :3 0 a1
:3 0 9a :3 0 b7
:3 0 55 :3 0 a5
:3 0 d9 :3 0 77
:3 0 54 :3 0 55
:3 0 ce :3 0 55
:3 0 f6 :3 0 d9
:3 0 f7 :3 0 39
:3 0 e6 :3 0 154
:3 0 f8 :3 0 d9
:3 0 125 :3 0 47
:3 0 155 :3 0 d9
:3 0 125 :3 0 47
:3 0 156 :3 0 47
:3 0 157 :3 0 d9
:3 0 125 :3 0 125
:3 0 d9 :3 0 126
:3 0 47 :3 0 158
:3 0 47 :3 0 159
:3 0 d9 :3 0 126
:3 0 126 :3 0 39
:3 0 e5 :3 0 15a
:3 0 e5 :3 0 39
:3 0 e6 :3 0 154
:3 0 e6 :3 0 d9
:3 0 119 :3 0 d9
:3 0 15b :3 0 d9
:3 0 f0 :3 0 f0
:3 0 d9 :3 0 119
:3 0 d9 :3 0 15b
:3 0 d9 :3 0 128
:3 0 d9 :3 0 f0
:3 0 eb :3 0 d9
:3 0 15c :3 0 d9
:3 0 15d :3 0 d9
:3 0 15c :3 0 d9
:3 0 15d :3 0 129
:3 0 12a :3 0 d9
:3 0 128 :3 0 12b
:3 0 12c :3 0 d9
:3 0 128 :3 0 12c
:3 0 f0 :3 0 15b
:3 0 12d :3 0 d9
:3 0 12e :3 0 d9
:3 0 12f :3 0 d9
:3 0 130 :3 0 d9
:3 0 131 :3 0 d9
:3 0 132 :3 0 d9
:3 0 133 :3 0 d9
:3 0 120 :3 0 d9
:3 0 134 :3 0 d9
:3 0 128 :3 0 135
:3 0 136 :3 0 137
:3 0 139 :3 0 17
:3 0 56 :3 0 55
:3 0 f9 :3 0 55
:3 0 fa :3 0 fb
:3 0 b7 :3 0 fc
:3 0 39 :3 0 55
:3 0 fd :3 0 55
:3 0 fa :3 0 fd
:3 0 fe :3 0 b7
:3 0 ff :3 0 d9
:3 0 be :3 0 d9
:3 0 100 :3 0 d9
:3 0 c0 :3 0 d9
:3 0 101 :3 0 55
:3 0 a5 :3 0 a1
:3 0 102 :3 0 c3
:3 0 a1 :3 0 55
:3 0 9a :3 0 a1
:3 0 9a :3 0 102
:3 0 55 :3 0 103
:3 0 d9 :3 0 f2
:3 0 d9 :3 0 13c
:3 0 d9 :3 0 13d
:3 0 d9 :3 0 13f
:3 0 d9 :3 0 d8
:3 0 d9 :3 0 104
:3 0 105 :3 0 b7
:3 0 140 :3 0 d9
:3 0 ec :3 0 d9
:3 0 107 :3 0 d9
:3 0 108 :3 0 d9
:3 0 109 :3 0 d9
:3 0 10a :3 0 d9
:3 0 10b :3 0 d9
:3 0 10c :3 0 d9
:3 0 141 :3 0 d9
:3 0 10d :3 0 d9
:3 0 119 :3 0 d9
:3 0 119 :3 0 119
:3 0 d9 :3 0 142
:3 0 143 :3 0 d9
:3 0 119 :3 0 d9
:3 0 15e :3 0 d9
:3 0 15f :3 0 144
:3 0 1b :3 0 39
:3 0 d9 :3 0 145
:3 0 d9 :3 0 160
:3 0 e4 :3 0 145
:3 0 1b :3 0 39
:3 0 d9 :3 0 146
:3 0 d9 :3 0 161
:3 0 e4 :3 0 146
:3 0 1b :3 0 d9
:3 0 148 :3 0 d9
:3 0 133 :3 0 d9
:3 0 148 :3 0 148
:3 0 d9 :3 0 12a
:3 0 149 :3 0 14a
:3 0 14b :3 0 d9
:3 0 14c :3 0 162
:3 0 b7 :3 0 14d
:3 0 d9 :3 0 14e
:3 0 163 :3 0 b7
:3 0 14f :3 0 d9
:3 0 150 :3 0 d9
:3 0 151 :3 0 164
:3 0 b7 :3 0 152
:3 0 55 :3 0 a5
:3 0 a1 :3 0 153
:3 0 c3 :3 0 a1
:3 0 55 :3 0 9a
:3 0 a1 :3 0 9a
:3 0 153 :3 0 a2
:3 0 55 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 76 :3 0 d9
:3 0 55 :3 0 ce
:3 0 d9 :3 0 ce
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 10e
:3 0 fb :3 0 55
:3 0 fa :3 0 fb
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10e :3 0 fe
:3 0 39 :3 0 55
:3 0 fd :3 0 55
:3 0 fa :3 0 fe
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10f :3 0 105
:3 0 105 :3 0 59
:3 0 d9 :3 0 104
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 165
:3 0 162 :3 0 162
:3 0 59 :3 0 d9
:3 0 14c :3 0 c5
:3 0 c6 :3 0 a3
:3 0 165 :3 0 163
:3 0 163 :3 0 59
:3 0 d9 :3 0 14e
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 166
:3 0 164 :3 0 164
:3 0 59 :3 0 d9
:3 0 151 :3 0 55
:3 0 53 :3 0 10
:3 0 55 :3 0 59
:3 0 d :3 0 55
:3 0 103 :3 0 14a
:3 0 b7 :4 0 167
1 :a 0 f87 :2 0
faa d74 f85 :2 0
2c :3 0 2d :3 0
f88 f89 0 2c
:3 0 3d :3 0 f8b
f8c 0 14 :2 0
2 :4 0 168 :2 0
3f :2 0 14 :2 0
632 f91 f93 :3 0
635 f8d f95 f8a
f97 f96 :2 0 2f
:3 0 40 :3 0 f99
f9a 0 31 :4 0
169 :4 0 34 :2 0
35 :3 0 639 f9e
fa0 :3 0 63c f9b
fa2 :2 0 fa4 63f
fa5 f98 fa4 0
fa6 641 0 faa
8 :3 0 1f :3 0
fa8 :2 0 faa 643
111f b1 :3 0 20
:3 0 d9 :3 0 77
:3 0 d9 :3 0 77
:3 0 55 :3 0 ce
:3 0 59 :3 0 55
:3 0 9a :3 0 55
:3 0 a5 :3 0 a1
:3 0 b6 :3 0 c3
:3 0 a1 :3 0 55
:3 0 9a :3 0 a1
:3 0 9a :3 0 55
:3 0 a5 :3 0 b5
:3 0 c9 :3 0 ca
:3 0 b5 :3 0 55
:3 0 9a :3 0 b5
:3 0 ad :3 0 55
:3 0 a5 :3 0 b5
:3 0 b7 :3 0 6c
:3 0 b5 :3 0 55
:3 0 9a :3 0 b5
:3 0 59 :3 0 b5
:3 0 b7 :3 0 16a
:3 0 b5 :3 0 55
:3 0 9a :3 0 b5
:3 0 59 :3 0 b7
:3 0 55 :3 0 a5
:3 0 47 :3 0 16b
:3 0 55 :3 0 a5
:3 0 47 :3 0 16c
:3 0 55 :3 0 a5
:3 0 47 :3 0 16d
:3 0 d9 :3 0 77
:3 0 47 :3 0 16e
:3 0 54 :3 0 55
:3 0 ce :3 0 55
:3 0 f6 :3 0 d9
:3 0 f7 :3 0 d9
:3 0 f8 :3 0 d9
:3 0 125 :3 0 d9
:3 0 126 :3 0 39
:3 0 e5 :3 0 15a
:3 0 e5 :3 0 39
:3 0 e6 :3 0 154
:3 0 e6 :3 0 d9
:3 0 16f :3 0 f0
:3 0 d9 :3 0 119
:3 0 d9 :3 0 15b
:3 0 d9 :3 0 f0
:3 0 eb :3 0 d9
:3 0 15d :3 0 129
:3 0 d9 :3 0 12a
:3 0 12d :3 0 d9
:3 0 12e :3 0 d9
:3 0 12f :3 0 d9
:3 0 130 :3 0 d9
:3 0 131 :3 0 d9
:3 0 132 :3 0 d9
:3 0 133 :3 0 d9
:3 0 120 :3 0 d9
:3 0 134 :3 0 d9
:3 0 128 :3 0 135
:3 0 136 :3 0 137
:3 0 139 :3 0 17
:3 0 56 :3 0 55
:3 0 f9 :3 0 55
:3 0 fa :3 0 fb
:3 0 b7 :3 0 fc
:3 0 39 :3 0 55
:3 0 fd :3 0 55
:3 0 fa :3 0 fd
:3 0 fe :3 0 b7
:3 0 ff :3 0 d9
:3 0 be :3 0 d9
:3 0 100 :3 0 d9
:3 0 c0 :3 0 d9
:3 0 101 :3 0 55
:3 0 a5 :3 0 a1
:3 0 102 :3 0 c3
:3 0 a1 :3 0 55
:3 0 9a :3 0 a1
:3 0 9a :3 0 102
:3 0 55 :3 0 103
:3 0 d9 :3 0 f2
:3 0 d9 :3 0 13c
:3 0 d9 :3 0 13d
:3 0 d9 :3 0 13f
:3 0 d9 :3 0 d8
:3 0 d9 :3 0 104
:3 0 105 :3 0 b7
:3 0 140 :3 0 d9
:3 0 ec :3 0 d9
:3 0 107 :3 0 d9
:3 0 108 :3 0 d9
:3 0 109 :3 0 d9
:3 0 10a :3 0 d9
:3 0 10b :3 0 d9
:3 0 10c :3 0 d9
:3 0 141 :3 0 d9
:3 0 10d :3 0 d9
:3 0 119 :3 0 d9
:3 0 119 :3 0 119
:3 0 d9 :3 0 142
:3 0 143 :3 0 144
:3 0 d9 :3 0 145
:3 0 d9 :3 0 146
:3 0 d9 :3 0 148
:3 0 d9 :3 0 12a
:3 0 149 :3 0 14a
:3 0 d9 :3 0 77
:3 0 d9 :3 0 d8
:3 0 d9 :3 0 77
:3 0 d9 :3 0 145
:3 0 d9 :3 0 160
:3 0 d9 :3 0 146
:3 0 d9 :3 0 161
:3 0 14b :3 0 d9
:3 0 14c :3 0 162
:3 0 b7 :3 0 14d
:3 0 d9 :3 0 14e
:3 0 163 :3 0 b7
:3 0 14f :3 0 d9
:3 0 150 :3 0 d9
:3 0 151 :3 0 164
:3 0 b7 :3 0 152
:3 0 55 :3 0 a5
:3 0 a1 :3 0 153
:3 0 c3 :3 0 a1
:3 0 55 :3 0 9a
:3 0 a1 :3 0 9a
:3 0 153 :3 0 a2
:3 0 55 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 76 :3 0 d9
:3 0 55 :3 0 ce
:3 0 d9 :3 0 ce
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 10e
:3 0 fb :3 0 55
:3 0 fa :3 0 fb
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10e :3 0 fe
:3 0 39 :3 0 55
:3 0 fd :3 0 55
:3 0 fa :3 0 fe
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10f :3 0 105
:3 0 105 :3 0 59
:3 0 d9 :3 0 104
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 165
:3 0 162 :3 0 162
:3 0 59 :3 0 d9
:3 0 14c :3 0 c5
:3 0 c6 :3 0 a3
:3 0 165 :3 0 163
:3 0 163 :3 0 59
:3 0 d9 :3 0 14e
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 166
:3 0 164 :3 0 164
:3 0 59 :3 0 d9
:3 0 151 :3 0 55
:3 0 103 :3 0 55
:3 0 59 :3 0 d
:3 0 54 :3 0 b7
:4 0 170 1 :a 0
10fb :2 0 111e fac
10f9 :2 0 2c :3 0
2d :3 0 10fc 10fd
0 2c :3 0 3d
:3 0 10ff 1100 0
14 :2 0 2 :4 0
171 :2 0 3f :2 0
14 :2 0 64a 1105
1107 :3 0 64d 1101
1109 10fe 110b 110a
:2 0 2f :3 0 40
:3 0 110d 110e 0
31 :4 0 172 :4 0
34 :2 0 35 :3 0
651 1112 1114 :3 0
654 110f 1116 :2 0
1118 657 1119 110c
1118 0 111a 659
0 111e 8 :3 0
20 :3 0 111c :2 0
111e 65b 1120 bf9
faa 0 1121 0
111e 0 1121 65f
0 1123 74 :3 0
662 1124 bed 1123
0 1fda 39 :3 0
15 :3 0 16 :2 0
664 1125 1128 4f
:2 0 173 :2 0 669
112a 112c :3 0 96
:3 0 97 :3 0 174
:4 0 1130 :4 0 1131
:2 0 12e3 9 :3 0
5b :3 0 1133 1134
0 16 :2 0 1135
1136 0 12e3 175
:3 0 9a :3 0 a5
:3 0 e5 :3 0 e6
:3 0 e7 :3 0 e8
:3 0 e9 :3 0 ea
:3 0 eb :3 0 9a
:3 0 a5 :3 0 176
:3 0 e5 :3 0 e5
:3 0 177 :3 0 e6
:3 0 e6 :3 0 178
:3 0 f0 :3 0 e7
:3 0 176 :3 0 15a
:3 0 e8 :3 0 177
:3 0 154 :3 0 e9
:3 0 178 :3 0 15b
:3 0 ea :3 0 178
:3 0 133 :3 0 eb
:3 0 76 :3 0 53
:3 0 d :3 0 d8
:3 0 9a :3 0 a5
:4 0 179 1 :8 0
1175 a7 :4 0 1160
:3 0 4e :3 0 4f
:2 0 66e 1163 1164
:3 0 9 :3 0 5b
:3 0 1166 1167 0
16 :2 0 1168 1169
0 116b 671 1172
9 :3 0 5b :3 0
116c 116d 0 a8
:2 0 116e 116f 0
1171 673 1173 1165
116b 0 1174 0
1171 0 1174 675
0 1175 678 11c8
5d :3 0 9 :3 0
5b :3 0 1177 1178
0 5c :3 0 1179
117a 0 117c 67b
117e 67d 117d 117c
:2 0 11c6 5e :3 0
9 :3 0 5b :3 0
1181 1182 0 5c
:3 0 1183 1184 0
11be 2c :3 0 2d
:3 0 1186 1187 0
2c :3 0 3d :3 0
1189 118a 0 5f
:2 0 2 :4 0 17a
:2 0 3f :2 0 14
:2 0 67f 118f 1191
:3 0 682 118b 1193
1188 1195 1194 :2 0
2f :3 0 40 :3 0
1197 1198 0 31
:4 0 17b :4 0 34
:2 0 35 :3 0 686
119c 119e :3 0 34
:2 0 45 :4 0 689
11a0 11a2 :3 0 34
:2 0 62 :4 0 68c
11a4 11a6 :3 0 34
:2 0 5c :3 0 68f
11a8 11aa :3 0 34
:2 0 63 :4 0 692
11ac 11ae :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 695 11b1 11b5
699 11b0 11b7 :3 0
69c 1199 11b9 :2 0
11bb 69f 11bc 1196
11bb 0 11bd 6a1
0 11be 6a3 11c1
:3 0 11c1 0 11c1
11c0 11be 11bf :6 0
11c3 1e :3 0 6a6
11c5 6a8 11c4 11c3
:2 0 11c6 6aa :2 0
11c8 0 11c8 11c7
1175 11c6 :6 0 12e3
1 :3 0 9 :3 0
5b :3 0 11ca 11cb
0 de :4 0 11cd
11ce :3 0 11cc 11cf
0 12e3 df :3 0
59 :3 0 b7 :3 0
e5 :3 0 e6 :3 0
e7 :3 0 e8 :3 0
e9 :3 0 ea :3 0
eb :3 0 a1 :3 0
ad :3 0 a1 :3 0
c9 :3 0 55 :3 0
e5 :3 0 55 :3 0
e6 :3 0 55 :3 0
e7 :3 0 55 :3 0
e8 :3 0 55 :3 0
e9 :3 0 55 :3 0
ea :3 0 55 :3 0
eb :3 0 175 :3 0
55 :3 0 a3 :3 0
ca :3 0 a1 :3 0
55 :3 0 a5 :3 0
a1 :3 0 ad :3 0
55 :3 0 9a :3 0
a3 :3 0 a4 :3 0
c4 :3 0 c4 :3 0
59 :3 0 a1 :3 0
cb :3 0 a3 :3 0
a4 :3 0 ba :3 0
ba :3 0 59 :3 0
c4 :3 0 9b :4 0
17c 1 :8 0 121c
a7 :4 0 1207 :3 0
4e :3 0 4f :2 0
6af 120a 120b :3 0
9 :3 0 5b :3 0
120d 120e 0 16
:2 0 120f 1210 0
1212 6b2 1219 9
:3 0 5b :3 0 1213
1214 0 a8 :2 0
1215 1216 0 1218
6b4 121a 120c 1212
0 121b 0 1218
0 121b 6b6 0
121c 6b9 126f 5d
:3 0 9 :3 0 5b
:3 0 121e 121f 0
5c :3 0 1220 1221
0 1223 6bc 1225
6be 1224 1223 :2 0
126d 5e :3 0 9
:3 0 5b :3 0 1228
1229 0 5c :3 0
122a 122b 0 1265
2c :3 0 2d :3 0
122d 122e 0 2c
:3 0 3d :3 0 1230
1231 0 5f :2 0
2 :4 0 17d :2 0
3f :2 0 14 :2 0
6c0 1236 1238 :3 0
6c3 1232 123a 122f
123c 123b :2 0 2f
:3 0 40 :3 0 123e
123f 0 31 :4 0
17e :4 0 34 :2 0
35 :3 0 6c7 1243
1245 :3 0 34 :2 0
45 :4 0 6ca 1247
1249 :3 0 34 :2 0
62 :4 0 6cd 124b
124d :3 0 34 :2 0
5c :3 0 6d0 124f
1251 :3 0 34 :2 0
63 :4 0 6d3 1253
1255 :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
6d6 1258 125c 6da
1257 125e :3 0 6dd
1240 1260 :2 0 1262
6e0 1263 123d 1262
0 1264 6e2 0
1265 6e4 1268 :3 0
1268 0 1268 1267
1265 1266 :6 0 126a
20 :3 0 6e7 126c
6e9 126b 126a :2 0
126d 6eb :2 0 126f
0 126f 126e 121c
126d :6 0 12e3 1
:3 0 b1 :3 0 21
:3 0 55 :3 0 9a
:3 0 59 :3 0 ce
:3 0 b5 :3 0 b6
:3 0 b7 :3 0 54
:3 0 b5 :3 0 b9
:3 0 55 :3 0 e5
:3 0 55 :3 0 e6
:3 0 55 :3 0 e7
:3 0 55 :3 0 e8
:3 0 55 :3 0 e9
:3 0 55 :3 0 ea
:3 0 55 :3 0 eb
:3 0 ec :3 0 17
:3 0 56 :3 0 ed
:3 0 ee :3 0 ef
:3 0 f0 :3 0 f1
:3 0 f2 :3 0 b5
:3 0 102 :3 0 c2
:3 0 82 :3 0 175
:3 0 55 :3 0 a3
:3 0 c3 :3 0 b5
:3 0 55 :3 0 a5
:3 0 55 :3 0 9a
:3 0 b5 :3 0 9a
:3 0 59 :3 0 ce
:3 0 b7 :3 0 54
:3 0 b9 :3 0 e5
:3 0 e6 :3 0 e7
:3 0 e8 :3 0 e9
:3 0 ea :3 0 eb
:3 0 ec :3 0 17
:3 0 56 :3 0 ed
:3 0 ee :3 0 ef
:3 0 f0 :3 0 f1
:3 0 f2 :3 0 102
:3 0 c2 :3 0 82
:3 0 df :3 0 54
:4 0 17f 1 :a 0
12bf :2 0 12e3 1272
12bd :2 0 2c :3 0
2d :3 0 12c0 12c1
0 2c :3 0 3d
:3 0 12c3 12c4 0
14 :2 0 2 :4 0
180 :2 0 3f :2 0
14 :2 0 6ee 12c9
12cb :3 0 6f1 12c5
12cd 12c2 12cf 12ce
:2 0 2f :3 0 40
:3 0 12d1 12d2 0
31 :4 0 181 :4 0
34 :2 0 35 :3 0
6f5 12d6 12d8 :3 0
6f8 12d3 12da :2 0
12dc 6fb 12dd 12d0
12dc 0 12de 6fd
0 12e3 8 :3 0
21 :3 0 12e0 :2 0
12e3 74 :3 0 6ff
12e4 112d 12e3 0
1fda 39 :3 0 15
:3 0 16 :2 0 708
12e5 12e8 4f :2 0
182 :2 0 70d 12ea
12ec :3 0 96 :3 0
97 :3 0 174 :4 0
12f0 :4 0 12f1 :2 0
14ee 9 :3 0 5b
:3 0 12f3 12f4 0
16 :2 0 12f5 12f6
0 14ee 175 :3 0
9a :3 0 a5 :3 0
e5 :3 0 e6 :3 0
e7 :3 0 e8 :3 0
e9 :3 0 ea :3 0
eb :3 0 9a :3 0
a5 :3 0 176 :3 0
e5 :3 0 e5 :3 0
177 :3 0 e6 :3 0
e6 :3 0 178 :3 0
f0 :3 0 e7 :3 0
176 :3 0 15a :3 0
e8 :3 0 177 :3 0
154 :3 0 e9 :3 0
178 :3 0 15b :3 0
ea :3 0 178 :3 0
133 :3 0 eb :3 0
76 :3 0 53 :3 0
d :3 0 d8 :3 0
9a :3 0 a5 :4 0
179 1 :8 0 1335
a7 :4 0 1320 :3 0
4e :3 0 4f :2 0
712 1323 1324 :3 0
9 :3 0 5b :3 0
1326 1327 0 16
:2 0 1328 1329 0
132b 715 1332 9
:3 0 5b :3 0 132c
132d 0 a8 :2 0
132e 132f 0 1331
717 1333 1325 132b
0 1334 0 1331
0 1334 719 0
1335 71c 1388 5d
:3 0 9 :3 0 5b
:3 0 1337 1338 0
5c :3 0 1339 133a
0 133c 71f 133e
721 133d 133c :2 0
1386 5e :3 0 9
:3 0 5b :3 0 1341
1342 0 5c :3 0
1343 1344 0 137e
2c :3 0 2d :3 0
1346 1347 0 2c
:3 0 3d :3 0 1349
134a 0 5f :2 0
2 :4 0 183 :2 0
3f :2 0 14 :2 0
723 134f 1351 :3 0
726 134b 1353 1348
1355 1354 :2 0 2f
:3 0 40 :3 0 1357
1358 0 31 :4 0
184 :4 0 34 :2 0
35 :3 0 72a 135c
135e :3 0 34 :2 0
45 :4 0 72d 1360
1362 :3 0 34 :2 0
62 :4 0 730 1364
1366 :3 0 34 :2 0
5c :3 0 733 1368
136a :3 0 34 :2 0
63 :4 0 736 136c
136e :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
739 1371 1375 73d
1370 1377 :3 0 740
1359 1379 :2 0 137b
743 137c 1356 137b
0 137d 745 0
137e 747 1381 :3 0
1381 0 1381 1380
137e 137f :6 0 1383
22 :3 0 74a 1385
74c 1384 1383 :2 0
1386 74e :2 0 1388
0 1388 1387 1335
1386 :6 0 14ee 1
:3 0 9 :3 0 5b
:3 0 138a 138b 0
de :4 0 138d 138e
:3 0 138c 138f 0
14ee df :3 0 59
:3 0 b7 :3 0 a5
:3 0 54 :3 0 b9
:3 0 e5 :3 0 e6
:3 0 e7 :3 0 e8
:3 0 e9 :3 0 ea
:3 0 eb :3 0 102
:3 0 a1 :3 0 ad
:3 0 a1 :3 0 c9
:3 0 55 :3 0 e5
:3 0 55 :3 0 e6
:3 0 55 :3 0 e7
:3 0 55 :3 0 e8
:3 0 55 :3 0 e9
:3 0 55 :3 0 ea
:3 0 55 :3 0 eb
:3 0 175 :3 0 55
:3 0 a3 :3 0 ca
:3 0 a1 :3 0 55
:3 0 a5 :3 0 a1
:3 0 ad :3 0 55
:3 0 9a :3 0 a3
:3 0 a4 :3 0 c4
:3 0 c4 :3 0 59
:3 0 a1 :3 0 cb
:3 0 a3 :3 0 a4
:3 0 ba :3 0 ba
:3 0 59 :3 0 c4
:3 0 9b :3 0 d7
:3 0 9a :3 0 b5
:3 0 b6 :3 0 b5
:3 0 b9 :3 0 e4
:3 0 e4 :3 0 e4
:3 0 e4 :3 0 b5
:3 0 102 :3 0 a2
:3 0 d7 :3 0 c3
:3 0 b5 :3 0 d7
:3 0 53 :3 0 d
:3 0 d7 :3 0 9a
:3 0 b5 :3 0 9a
:3 0 b2 :3 0 77
:3 0 76 :3 0 b2
:3 0 b2 :3 0 ce
:3 0 55 :3 0 ce
:3 0 a2 :3 0 55
:3 0 55 :3 0 53
:3 0 d7 :3 0 53
:3 0 55 :3 0 9a
:3 0 d7 :3 0 9a
:4 0 185 1 :8 0
1409 a7 :4 0 13f4
:3 0 4e :3 0 4f
:2 0 753 13f7 13f8
:3 0 9 :3 0 5b
:3 0 13fa 13fb 0
16 :2 0 13fc 13fd
0 13ff 756 1406
9 :3 0 5b :3 0
1400 1401 0 a8
:2 0 1402 1403 0
1405 758 1407 13f9
13ff 0 1408 0
1405 0 1408 75a
0 1409 75d 145c
5d :3 0 9 :3 0
5b :3 0 140b 140c
0 5c :3 0 140d
140e 0 1410 760
1412 762 1411 1410
:2 0 145a 5e :3 0
9 :3 0 5b :3 0
1415 1416 0 5c
:3 0 1417 1418 0
1452 2c :3 0 2d
:3 0 141a 141b 0
2c :3 0 3d :3 0
141d 141e 0 5f
:2 0 2 :4 0 186
:2 0 3f :2 0 14
:2 0 764 1423 1425
:3 0 767 141f 1427
141c 1429 1428 :2 0
2f :3 0 40 :3 0
142b 142c 0 31
:4 0 187 :4 0 34
:2 0 35 :3 0 76b
1430 1432 :3 0 34
:2 0 45 :4 0 76e
1434 1436 :3 0 34
:2 0 62 :4 0 771
1438 143a :3 0 34
:2 0 5c :3 0 774
143c 143e :3 0 34
:2 0 63 :4 0 777
1440 1442 :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 77a 1445 1449
77e 1444 144b :3 0
781 142d 144d :2 0
144f 784 1450 142a
144f 0 1451 786
0 1452 788 1455
:3 0 1455 0 1455
1454 1452 1453 :6 0
1457 24 :3 0 78b
1459 78d 1458 1457
:2 0 145a 78f :2 0
145c 0 145c 145b
1409 145a :6 0 14ee
1 :3 0 b1 :3 0
22 :3 0 55 :3 0
9a :3 0 59 :3 0
ce :3 0 b5 :3 0
b6 :3 0 b7 :3 0
54 :3 0 b5 :3 0
b9 :3 0 55 :3 0
e5 :3 0 55 :3 0
e6 :3 0 55 :3 0
e7 :3 0 55 :3 0
e8 :3 0 55 :3 0
e9 :3 0 55 :3 0
ea :3 0 55 :3 0
eb :3 0 ec :3 0
17 :3 0 56 :3 0
ed :3 0 ee :3 0
ef :3 0 f0 :3 0
f1 :3 0 f2 :3 0
b5 :3 0 102 :3 0
c2 :3 0 82 :3 0
175 :3 0 55 :3 0
a3 :3 0 c3 :3 0
b5 :3 0 55 :3 0
a5 :3 0 55 :3 0
9a :3 0 b5 :3 0
9a :3 0 59 :3 0
ce :3 0 b7 :3 0
54 :3 0 b9 :3 0
e5 :3 0 e6 :3 0
e7 :3 0 e8 :3 0
e9 :3 0 ea :3 0
eb :3 0 ec :3 0
17 :3 0 56 :3 0
ed :3 0 ee :3 0
ef :3 0 f0 :3 0
f1 :3 0 f2 :3 0
102 :3 0 c2 :3 0
82 :3 0 df :3 0
a5 :3 0 54 :3 0
59 :3 0 ce :3 0
b7 :3 0 54 :3 0
b9 :3 0 e5 :3 0
e6 :3 0 e7 :3 0
e8 :3 0 e9 :3 0
ea :3 0 eb :3 0
ec :3 0 17 :3 0
56 :3 0 ed :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 102 :3 0
c2 :3 0 82 :3 0
df :3 0 a5 :3 0
54 :3 0 54 :3 0
b7 :4 0 188 1
:a 0 14ca :2 0 14ee
145f 14c8 :2 0 2c
:3 0 2d :3 0 14cb
14cc 0 2c :3 0
3d :3 0 14ce 14cf
0 14 :2 0 2
:4 0 189 :2 0 3f
:2 0 14 :2 0 792
14d4 14d6 :3 0 795
14d0 14d8 14cd 14da
14d9 :2 0 2f :3 0
40 :3 0 14dc 14dd
0 31 :4 0 18a
:4 0 34 :2 0 35
:3 0 799 14e1 14e3
:3 0 79c 14de 14e5
:2 0 14e7 79f 14e8
14db 14e7 0 14e9
7a1 0 14ee 8
:3 0 22 :3 0 14eb
:2 0 14ee 74 :3 0
7a3 14ef 12ed 14ee
0 1fda 39 :3 0
15 :3 0 16 :2 0
7ac 14f0 14f3 4f
:2 0 18b :2 0 7b1
14f5 14f7 :3 0 b1
:3 0 23 :3 0 d9
:3 0 9a :3 0 59
:3 0 d9 :3 0 ce
:3 0 b5 :3 0 b6
:3 0 b7 :3 0 54
:3 0 b5 :3 0 b9
:3 0 52 :3 0 e5
:3 0 52 :3 0 e6
:3 0 52 :3 0 16f
:3 0 e7 :3 0 52
:3 0 f0 :3 0 18c
:3 0 55 :3 0 12e
:3 0 e8 :3 0 55
:3 0 12f :3 0 e9
:3 0 55 :3 0 16f
:3 0 ea :3 0 55
:3 0 15b :3 0 eb
:3 0 17 :3 0 56
:3 0 ed :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 13a
:3 0 13b :3 0 f2
:3 0 b5 :3 0 102
:3 0 c2 :3 0 82
:3 0 18d :3 0 be
:3 0 18d :3 0 100
:3 0 18d :3 0 c0
:3 0 18d :3 0 101
:3 0 18d :3 0 18e
:3 0 18d :3 0 18f
:3 0 18d :3 0 190
:3 0 18d :3 0 191
:3 0 18d :3 0 192
:3 0 18d :3 0 193
:3 0 18d :3 0 194
:3 0 18d :3 0 195
:3 0 18d :3 0 196
:3 0 18d :3 0 197
:3 0 18d :3 0 198
:3 0 b5 :3 0 153
:3 0 a2 :3 0 d9
:3 0 a3 :3 0 199
:3 0 18d :3 0 18d
:3 0 53 :3 0 d
:3 0 18d :3 0 9a
:3 0 d9 :3 0 9a
:3 0 c5 :3 0 a3
:3 0 76 :3 0 55
:3 0 55 :3 0 ce
:3 0 d9 :3 0 ce
:3 0 55 :3 0 119
:3 0 c5 :3 0 a3
:3 0 76 :3 0 52
:3 0 52 :3 0 ce
:3 0 d9 :3 0 ce
:3 0 52 :3 0 119
:3 0 a3 :3 0 c3
:3 0 b5 :3 0 d9
:3 0 9a :3 0 b5
:3 0 9a :3 0 d9
:3 0 59 :3 0 d
:3 0 d9 :3 0 a5
:3 0 55 :3 0 77
:3 0 52 :3 0 77
:3 0 d9 :3 0 9a
:3 0 59 :3 0 55
:3 0 ce :3 0 b5
:3 0 c9 :3 0 b7
:3 0 54 :3 0 b9
:3 0 d9 :3 0 e5
:3 0 d9 :3 0 e6
:3 0 d9 :3 0 16f
:3 0 e7 :3 0 d9
:3 0 f0 :3 0 18c
:3 0 e4 :3 0 e8
:3 0 e4 :3 0 e9
:3 0 ea :3 0 eb
:3 0 17 :3 0 56
:3 0 ed :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 d9
:3 0 f2 :3 0 102
:3 0 c2 :3 0 82
:3 0 18d :3 0 be
:3 0 18d :3 0 100
:3 0 18d :3 0 c0
:3 0 18d :3 0 101
:3 0 18d :3 0 18e
:3 0 18d :3 0 18f
:3 0 18d :3 0 190
:3 0 18d :3 0 191
:3 0 18d :3 0 192
:3 0 18d :3 0 193
:3 0 18d :3 0 194
:3 0 18d :3 0 195
:3 0 18d :3 0 196
:3 0 18d :3 0 197
:3 0 18d :3 0 198
:3 0 153 :3 0 a2
:3 0 55 :3 0 a3
:3 0 ca :3 0 b5
:3 0 55 :3 0 9a
:3 0 b5 :3 0 ad
:3 0 a3 :3 0 76
:3 0 d9 :3 0 d9
:3 0 ce :3 0 55
:3 0 ce :3 0 a3
:3 0 199 :3 0 18d
:3 0 18d :3 0 53
:3 0 d :3 0 18d
:3 0 9a :3 0 55
:3 0 9a :3 0 55
:3 0 59 :3 0 d
:3 0 55 :3 0 a5
:3 0 54 :3 0 b7
:4 0 19a 1 :a 0
15e2 :2 0 1606 14fa
15e0 :2 0 2c :3 0
2d :3 0 15e3 15e4
0 2c :3 0 3d
:3 0 15e6 15e7 0
14 :2 0 2 :4 0
19b :2 0 3f :2 0
14 :2 0 7b4 15ec
15ee :3 0 7b7 15e8
15f0 15e5 15f2 15f1
:2 0 2f :3 0 40
:3 0 15f4 15f5 0
31 :4 0 19c :4 0
34 :2 0 35 :3 0
7bb 15f9 15fb :3 0
7be 15f6 15fd :2 0
15ff 7c1 1600 15f3
15ff 0 1601 7c3
0 1606 8 :3 0
23 :3 0 1603 :2 0
1606 74 :3 0 7c5
1607 14f8 1606 0
1fda 39 :3 0 15
:3 0 16 :2 0 7c9
1608 160b 4f :2 0
19d :2 0 7ce 160d
160f :3 0 96 :3 0
97 :3 0 19e :4 0
1613 :4 0 1614 :2 0
1914 9 :3 0 5b
:3 0 1616 1617 0
16 :2 0 1618 1619
0 1914 19f :3 0
9a :3 0 a5 :3 0
1a0 :3 0 1a1 :3 0
18c :3 0 e7 :3 0
1a2 :3 0 1a3 :3 0
1a4 :3 0 ea :3 0
54 :3 0 9a :3 0
a5 :3 0 176 :3 0
e5 :3 0 1a0 :3 0
177 :3 0 e6 :3 0
1a1 :3 0 178 :3 0
f0 :3 0 18c :3 0
178 :3 0 119 :3 0
16f :3 0 e7 :3 0
176 :3 0 15a :3 0
1a2 :3 0 177 :3 0
154 :3 0 1a3 :3 0
178 :3 0 15b :3 0
1a4 :3 0 178 :3 0
119 :3 0 16f :3 0
ea :3 0 76 :3 0
53 :3 0 d :3 0
da :3 0 d :3 0
9a :3 0 a5 :4 0
1a5 1 :8 0 1660
a7 :4 0 164b :3 0
4e :3 0 4f :2 0
7d3 164e 164f :3 0
9 :3 0 5b :3 0
1651 1652 0 16
:2 0 1653 1654 0
1656 7d6 165d 9
:3 0 5b :3 0 1657
1658 0 a8 :2 0
1659 165a 0 165c
7d8 165e 1650 1656
0 165f 0 165c
0 165f 7da 0
1660 7dd 16b3 5d
:3 0 9 :3 0 5b
:3 0 1662 1663 0
5c :3 0 1664 1665
0 1667 7e0 1669
7e2 1668 1667 :2 0
16b1 5e :3 0 9
:3 0 5b :3 0 166c
166d 0 5c :3 0
166e 166f 0 16a9
2c :3 0 2d :3 0
1671 1672 0 2c
:3 0 3d :3 0 1674
1675 0 5f :2 0
2 :4 0 1a6 :2 0
3f :2 0 14 :2 0
7e4 167a 167c :3 0
7e7 1676 167e 1673
1680 167f :2 0 2f
:3 0 40 :3 0 1682
1683 0 31 :4 0
1a7 :4 0 34 :2 0
35 :3 0 7eb 1687
1689 :3 0 34 :2 0
45 :4 0 7ee 168b
168d :3 0 34 :2 0
62 :4 0 7f1 168f
1691 :3 0 34 :2 0
5c :3 0 7f4 1693
1695 :3 0 34 :2 0
63 :4 0 7f7 1697
1699 :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
7fa 169c 16a0 7fe
169b 16a2 :3 0 801
1684 16a4 :2 0 16a6
804 16a7 1681 16a6
0 16a8 806 0
16a9 808 16ac :3 0
16ac 0 16ac 16ab
16a9 16aa :6 0 16ae
26 :3 0 80b 16b0
80d 16af 16ae :2 0
16b1 80f :2 0 16b3
0 16b3 16b2 1660
16b1 :6 0 1914 1
:3 0 96 :3 0 97
:3 0 1a8 :4 0 16b7
:4 0 16b8 :2 0 1914
9 :3 0 5b :3 0
16ba 16bb 0 16
:2 0 16bc 16bd 0
1914 1a9 :3 0 9a
:3 0 a5 :3 0 e5
:3 0 e6 :3 0 e7
:3 0 e8 :3 0 e9
:3 0 ea :3 0 eb
:3 0 1a0 :3 0 1a1
:3 0 18c :3 0 1a2
:3 0 1a3 :3 0 1a4
:3 0 18f :3 0 190
:3 0 191 :3 0 192
:3 0 193 :3 0 194
:3 0 195 :3 0 196
:3 0 197 :3 0 198
:3 0 be :3 0 100
:3 0 c0 :3 0 101
:3 0 54 :3 0 18e
:3 0 55 :3 0 9a
:3 0 55 :3 0 a5
:3 0 55 :3 0 e5
:3 0 55 :3 0 e6
:3 0 55 :3 0 f0
:3 0 55 :3 0 15a
:3 0 55 :3 0 154
:3 0 55 :3 0 15b
:3 0 55 :3 0 133
:3 0 52 :3 0 1a0
:3 0 52 :3 0 1a1
:3 0 52 :3 0 18c
:3 0 52 :3 0 1a2
:3 0 52 :3 0 1a3
:3 0 52 :3 0 1a4
:3 0 55 :3 0 18f
:3 0 55 :3 0 190
:3 0 55 :3 0 191
:3 0 55 :3 0 192
:3 0 55 :3 0 193
:3 0 55 :3 0 194
:3 0 55 :3 0 195
:3 0 55 :3 0 196
:3 0 55 :3 0 197
:3 0 55 :3 0 198
:3 0 55 :3 0 be
:3 0 55 :3 0 100
:3 0 55 :3 0 c0
:3 0 55 :3 0 101
:3 0 39 :3 0 52
:3 0 54 :3 0 55
:3 0 f0 :3 0 55
:3 0 15b :3 0 55
:3 0 18e :3 0 199
:3 0 55 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 19f :3 0 52
:3 0 55 :3 0 9a
:3 0 52 :3 0 9a
:3 0 55 :3 0 53
:3 0 d :4 0 1aa
1 :8 0 1746 a7
:4 0 1731 :3 0 4e
:3 0 4f :2 0 814
1734 1735 :3 0 9
:3 0 5b :3 0 1737
1738 0 16 :2 0
1739 173a 0 173c
817 1743 9 :3 0
5b :3 0 173d 173e
0 a8 :2 0 173f
1740 0 1742 819
1744 1736 173c 0
1745 0 1742 0
1745 81b 0 1746
81e 1799 5d :3 0
9 :3 0 5b :3 0
1748 1749 0 5c
:3 0 174a 174b 0
174d 821 174f 823
174e 174d :2 0 1797
5e :3 0 9 :3 0
5b :3 0 1752 1753
0 5c :3 0 1754
1755 0 178f 2c
:3 0 2d :3 0 1757
1758 0 2c :3 0
3d :3 0 175a 175b
0 5f :2 0 2
:4 0 1ab :2 0 3f
:2 0 14 :2 0 825
1760 1762 :3 0 828
175c 1764 1759 1766
1765 :2 0 2f :3 0
40 :3 0 1768 1769
0 31 :4 0 1ac
:4 0 34 :2 0 35
:3 0 82c 176d 176f
:3 0 34 :2 0 45
:4 0 82f 1771 1773
:3 0 34 :2 0 62
:4 0 832 1775 1777
:3 0 34 :2 0 5c
:3 0 835 1779 177b
:3 0 34 :2 0 63
:4 0 838 177d 177f
:3 0 34 :2 0 64
:3 0 65 :3 0 14
:2 0 66 :2 0 83b
1782 1786 83f 1781
1788 :3 0 842 176a
178a :2 0 178c 845
178d 1767 178c 0
178e 847 0 178f
849 1792 :3 0 1792
0 1792 1791 178f
1790 :6 0 1794 28
:3 0 84c 1796 84e
1795 1794 :2 0 1797
850 :2 0 1799 0
1799 1798 1746 1797
:6 0 1914 1 :3 0
1a9 :3 0 1ad :3 0
54 :3 0 54 :3 0
da :3 0 76 :3 0
d9 :3 0 d9 :3 0
53 :3 0 d :3 0
d9 :3 0 9a :3 0
1ad :3 0 9a :3 0
d9 :3 0 a5 :4 0
1ae 1 :8 0 17c1
a7 :4 0 17ac :3 0
4e :3 0 4f :2 0
855 17af 17b0 :3 0
9 :3 0 5b :3 0
17b2 17b3 0 16
:2 0 17b4 17b5 0
17b7 858 17be 9
:3 0 5b :3 0 17b8
17b9 0 a8 :2 0
17ba 17bb 0 17bd
85a 17bf 17b1 17b7
0 17c0 0 17bd
0 17c0 85c 0
17c1 85f 1814 5d
:3 0 9 :3 0 5b
:3 0 17c3 17c4 0
5c :3 0 17c5 17c6
0 17c8 862 17ca
864 17c9 17c8 :2 0
1812 5e :3 0 9
:3 0 5b :3 0 17cd
17ce 0 5c :3 0
17cf 17d0 0 180a
2c :3 0 2d :3 0
17d2 17d3 0 2c
:3 0 3d :3 0 17d5
17d6 0 5f :2 0
2 :4 0 1af :2 0
3f :2 0 14 :2 0
866 17db 17dd :3 0
869 17d7 17df 17d4
17e1 17e0 :2 0 2f
:3 0 40 :3 0 17e3
17e4 0 31 :4 0
1b0 :4 0 34 :2 0
35 :3 0 86d 17e8
17ea :3 0 34 :2 0
45 :4 0 870 17ec
17ee :3 0 34 :2 0
62 :4 0 873 17f0
17f2 :3 0 34 :2 0
5c :3 0 876 17f4
17f6 :3 0 34 :2 0
63 :4 0 879 17f8
17fa :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
87c 17fd 1801 880
17fc 1803 :3 0 883
17e5 1805 :2 0 1807
886 1808 17e2 1807
0 1809 888 0
180a 88a 180d :3 0
180d 0 180d 180c
180a 180b :6 0 180f
2a :3 0 88d 1811
88f 1810 180f :2 0
1812 891 :2 0 1814
0 1814 1813 17c1
1812 :6 0 1914 1
:3 0 b1 :3 0 24
:3 0 55 :3 0 9a
:3 0 59 :3 0 ce
:3 0 b5 :3 0 b6
:3 0 b7 :3 0 55
:3 0 54 :3 0 b5
:3 0 b9 :3 0 55
:3 0 e5 :3 0 55
:3 0 e6 :3 0 55
:3 0 e7 :3 0 55
:3 0 e8 :3 0 55
:3 0 e9 :3 0 55
:3 0 ea :3 0 55
:3 0 eb :3 0 ec
:3 0 17 :3 0 56
:3 0 ed :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 f2
:3 0 b5 :3 0 102
:3 0 c2 :3 0 82
:3 0 55 :3 0 1a0
:3 0 55 :3 0 1a2
:3 0 55 :3 0 9a
:3 0 d8 :3 0 55
:3 0 1a0 :3 0 55
:3 0 1a1 :3 0 55
:3 0 18c :3 0 55
:3 0 1a2 :3 0 55
:3 0 1a3 :3 0 55
:3 0 1a4 :3 0 d
:3 0 53 :3 0 55
:3 0 18f :3 0 55
:3 0 190 :3 0 55
:3 0 191 :3 0 55
:3 0 192 :3 0 55
:3 0 193 :3 0 55
:3 0 194 :3 0 55
:3 0 195 :3 0 55
:3 0 196 :3 0 55
:3 0 197 :3 0 55
:3 0 198 :3 0 55
:3 0 be :3 0 55
:3 0 100 :3 0 55
:3 0 c0 :3 0 55
:3 0 101 :3 0 55
:3 0 18e :3 0 b5
:3 0 153 :3 0 1a9
:3 0 55 :3 0 a3
:3 0 c3 :3 0 b5
:3 0 55 :3 0 a5
:3 0 55 :3 0 9a
:3 0 b5 :3 0 9a
:3 0 a1 :3 0 ad
:3 0 59 :3 0 ce
:3 0 a1 :3 0 c9
:3 0 b7 :3 0 54
:3 0 b9 :3 0 55
:3 0 e5 :3 0 55
:3 0 e6 :3 0 55
:3 0 e7 :3 0 55
:3 0 e8 :3 0 55
:3 0 e9 :3 0 55
:3 0 ea :3 0 55
:3 0 eb :3 0 ec
:3 0 17 :3 0 56
:3 0 ed :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 f2
:3 0 102 :3 0 c2
:3 0 82 :3 0 55
:3 0 1a0 :3 0 55
:3 0 1a2 :3 0 55
:3 0 9a :3 0 d8
:3 0 55 :3 0 1a0
:3 0 55 :3 0 1a1
:3 0 55 :3 0 18c
:3 0 55 :3 0 1a2
:3 0 55 :3 0 1a3
:3 0 55 :3 0 1a4
:3 0 d :3 0 53
:3 0 55 :3 0 18f
:3 0 55 :3 0 190
:3 0 55 :3 0 191
:3 0 55 :3 0 192
:3 0 55 :3 0 193
:3 0 55 :3 0 194
:3 0 55 :3 0 195
:3 0 55 :3 0 196
:3 0 55 :3 0 197
:3 0 55 :3 0 198
:3 0 55 :3 0 be
:3 0 55 :3 0 100
:3 0 55 :3 0 c0
:3 0 55 :3 0 101
:3 0 55 :3 0 18e
:3 0 153 :3 0 1a9
:3 0 55 :3 0 a3
:3 0 ca :3 0 a1
:3 0 55 :3 0 a5
:3 0 a1 :3 0 ad
:3 0 55 :3 0 9a
:3 0 a3 :3 0 a4
:3 0 c4 :3 0 c4
:3 0 59 :3 0 a1
:3 0 cb :3 0 a3
:3 0 a4 :3 0 ba
:3 0 ba :3 0 59
:3 0 c4 :3 0 9b
:4 0 1b1 1 :a 0
18f0 :2 0 1914 1817
18ee :2 0 2c :3 0
2d :3 0 18f1 18f2
0 2c :3 0 3d
:3 0 18f4 18f5 0
14 :2 0 2 :4 0
1b2 :2 0 3f :2 0
14 :2 0 894 18fa
18fc :3 0 897 18f6
18fe 18f3 1900 18ff
:2 0 2f :3 0 40
:3 0 1902 1903 0
31 :4 0 1b3 :4 0
34 :2 0 35 :3 0
89b 1907 1909 :3 0
89e 1904 190b :2 0
190d 8a1 190e 1901
190d 0 190f 8a3
0 1914 8 :3 0
24 :3 0 1911 :2 0
1914 74 :3 0 8a5
1915 1610 1914 0
1fda 39 :3 0 15
:3 0 16 :2 0 8b0
1916 1919 47 :3 0
4f :2 0 8c :3 0
191b 191d 0 8b5
191c 191f :3 0 c9
:3 0 11 :3 0 ca
:3 0 ad :3 0 d
:4 0 1b4 1 :8 0
192c 9 :3 0 5b
:3 0 1927 1928 0
5c :3 0 1929 192a
0 192c 8b8 197f
5d :3 0 9 :3 0
5b :3 0 192e 192f
0 5c :3 0 1930
1931 0 1933 8bb
1935 8bd 1934 1933
:2 0 197d 5e :3 0
9 :3 0 5b :3 0
1938 1939 0 5c
:3 0 193a 193b 0
1975 2c :3 0 2d
:3 0 193d 193e 0
2c :3 0 3d :3 0
1940 1941 0 5f
:2 0 2 :4 0 1b5
:2 0 3f :2 0 14
:2 0 8bf 1946 1948
:3 0 8c2 1942 194a
193f 194c 194b :2 0
2f :3 0 40 :3 0
194e 194f 0 31
:4 0 1b6 :4 0 34
:2 0 35 :3 0 8c6
1953 1955 :3 0 34
:2 0 45 :4 0 8c9
1957 1959 :3 0 34
:2 0 62 :4 0 8cc
195b 195d :3 0 34
:2 0 5c :3 0 8cf
195f 1961 :3 0 34
:2 0 63 :4 0 8d2
1963 1965 :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 8d5 1968 196c
8d9 1967 196e :3 0
8dc 1950 1970 :2 0
1972 8df 1973 194d
1972 0 1974 8e1
0 1975 8e3 1978
:3 0 1978 0 1978
1977 1975 1976 :6 0
197a 2c :3 0 8e6
197c 8e8 197b 197a
:2 0 197d 8ea :2 0
197f 0 197f 197e
192c 197d :6 0 1a4e
1 :3 0 9 :3 0
5b :3 0 1981 1982
0 9 :3 0 4f
:2 0 1b7 :3 0 1984
1986 0 8ef 1985
1988 :3 0 1989 :2 0
b1 :3 0 25 :3 0
d :3 0 59 :3 0
11 :3 0 b7 :3 0
54 :3 0 1b8 :3 0
b5 :3 0 cb :3 0
11 :3 0 bb :3 0
1b9 :3 0 1ba :3 0
b7 :3 0 1bb :3 0
1bc :3 0 1bd :3 0
b7 :3 0 1be :3 0
1bf :3 0 1c0 :3 0
b7 :3 0 1c1 :3 0
ca :3 0 b5 :3 0
c5 :3 0 a3 :3 0
16a :3 0 1ba :3 0
1ba :3 0 59 :3 0
1b9 :3 0 c5 :3 0
a3 :3 0 1c2 :3 0
1bd :3 0 1bd :3 0
59 :3 0 1bc :3 0
c5 :3 0 a3 :3 0
6c :3 0 1c0 :3 0
1c0 :3 0 59 :3 0
1bf :3 0 b5 :3 0
ad :3 0 d :3 0
d :3 0 59 :3 0
11 :3 0 b7 :3 0
54 :3 0 1c3 :3 0
54 :3 0 1b8 :3 0
1c4 :3 0 59 :3 0
cb :3 0 1c5 :3 0
1c6 :3 0 1c5 :3 0
1c6 :3 0 1c7 :3 0
1c3 :3 0 b7 :3 0
1c7 :3 0 1c4 :3 0
b7 :3 0 bb :3 0
1b9 :3 0 1bb :3 0
1bc :3 0 1be :3 0
1bf :3 0 1c1 :3 0
d0 :3 0 a1 :3 0
c5 :3 0 c6 :3 0
a3 :3 0 a4 :3 0
1c4 :3 0 a1 :3 0
cb :3 0 1c4 :3 0
59 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
a4 :3 0 1c3 :3 0
1c3 :3 0 59 :3 0
1c4 :3 0 9b :3 0
a1 :3 0 ce :3 0
d :3 0 d :3 0
59 :3 0 11 :3 0
b7 :3 0 54 :3 0
1c3 :3 0 54 :3 0
1b8 :3 0 1c4 :3 0
59 :3 0 cb :3 0
1c5 :3 0 1c6 :3 0
1c5 :3 0 1c6 :3 0
1c7 :3 0 1c3 :3 0
b7 :3 0 1c7 :3 0
1c4 :3 0 b7 :3 0
bb :3 0 1b9 :3 0
1bb :3 0 1bc :3 0
1be :3 0 1bf :3 0
1c1 :3 0 cc :3 0
cd :3 0 c5 :3 0
c6 :3 0 a3 :3 0
a4 :3 0 1c4 :3 0
cd :3 0 cf :3 0
1c4 :3 0 59 :3 0
c5 :3 0 c6 :3 0
a3 :3 0 a4 :3 0
1c3 :3 0 1c3 :3 0
59 :3 0 1c4 :3 0
9b :3 0 cd :3 0
ce :3 0 d :3 0
59 :3 0 54 :4 0
1c8 1 :a 0 1a27
:2 0 1a4a 198c 1a25
:2 0 2c :3 0 2d
:3 0 1a28 1a29 0
2c :3 0 3d :3 0
1a2b 1a2c 0 14
:2 0 2 :4 0 1c9
:2 0 3f :2 0 14
:2 0 8f2 1a31 1a33
:3 0 8f5 1a2d 1a35
1a2a 1a37 1a36 :2 0
2f :3 0 40 :3 0
1a39 1a3a 0 31
:4 0 1ca :4 0 34
:2 0 35 :3 0 8f9
1a3e 1a40 :3 0 8fc
1a3b 1a42 :2 0 1a44
8ff 1a45 1a38 1a44
0 1a46 901 0
1a4a 8 :3 0 25
:3 0 1a48 :2 0 1a4a
903 1a4b 198a 1a4a
0 1a4c 907 0
1a4e 74 :3 0 909
1a4f 1920 1a4e 0
1fda 39 :3 0 15
:3 0 16 :2 0 90c
1a50 1a53 4f :2 0
75 :2 0 911 1a55
1a57 :3 0 b1 :3 0
26 :3 0 d9 :3 0
77 :3 0 d9 :3 0
77 :3 0 55 :3 0
ce :3 0 59 :3 0
55 :3 0 9a :3 0
55 :3 0 a5 :3 0
b5 :3 0 c9 :3 0
ca :3 0 b5 :3 0
55 :3 0 9a :3 0
b5 :3 0 ad :3 0
a1 :3 0 b6 :3 0
c3 :3 0 a1 :3 0
55 :3 0 9a :3 0
a1 :3 0 9a :3 0
b7 :3 0 d9 :3 0
77 :3 0 55 :3 0
a5 :3 0 54 :3 0
55 :3 0 ce :3 0
55 :3 0 f6 :3 0
d9 :3 0 f7 :3 0
39 :3 0 e6 :3 0
154 :3 0 f8 :3 0
d9 :3 0 125 :3 0
d9 :3 0 126 :3 0
39 :3 0 e5 :3 0
15a :3 0 e5 :3 0
39 :3 0 e6 :3 0
154 :3 0 e6 :3 0
119 :3 0 15b :3 0
f0 :3 0 f0 :3 0
119 :3 0 15b :3 0
128 :3 0 f0 :3 0
eb :3 0 d9 :3 0
15c :3 0 d9 :3 0
15d :3 0 d9 :3 0
15c :3 0 d9 :3 0
15d :3 0 129 :3 0
12a :3 0 d9 :3 0
128 :3 0 12b :3 0
12c :3 0 d9 :3 0
128 :3 0 12c :3 0
f0 :3 0 15b :3 0
12d :3 0 d9 :3 0
12e :3 0 d9 :3 0
12f :3 0 d9 :3 0
130 :3 0 d9 :3 0
131 :3 0 d9 :3 0
132 :3 0 d9 :3 0
133 :3 0 d9 :3 0
120 :3 0 d9 :3 0
134 :3 0 d9 :3 0
128 :3 0 135 :3 0
136 :3 0 137 :3 0
139 :3 0 17 :3 0
56 :3 0 55 :3 0
f9 :3 0 55 :3 0
fa :3 0 fb :3 0
b7 :3 0 fc :3 0
39 :3 0 55 :3 0
fd :3 0 55 :3 0
fa :3 0 fd :3 0
fe :3 0 b7 :3 0
ff :3 0 d9 :3 0
be :3 0 d9 :3 0
100 :3 0 d9 :3 0
c0 :3 0 d9 :3 0
101 :3 0 55 :3 0
a5 :3 0 a1 :3 0
102 :3 0 c3 :3 0
a1 :3 0 55 :3 0
9a :3 0 a1 :3 0
9a :3 0 102 :3 0
55 :3 0 103 :3 0
d9 :3 0 f2 :3 0
d9 :3 0 13c :3 0
d9 :3 0 13d :3 0
d9 :3 0 13f :3 0
d9 :3 0 d8 :3 0
d9 :3 0 104 :3 0
105 :3 0 b7 :3 0
140 :3 0 d9 :3 0
ec :3 0 d9 :3 0
107 :3 0 d9 :3 0
108 :3 0 d9 :3 0
109 :3 0 d9 :3 0
10a :3 0 d9 :3 0
10b :3 0 d9 :3 0
10c :3 0 d9 :3 0
141 :3 0 d9 :3 0
10d :3 0 d9 :3 0
119 :3 0 d9 :3 0
119 :3 0 119 :3 0
d9 :3 0 142 :3 0
143 :3 0 119 :3 0
15e :3 0 15f :3 0
144 :3 0 1b :3 0
39 :3 0 d9 :3 0
145 :3 0 d9 :3 0
160 :3 0 e4 :3 0
145 :3 0 1b :3 0
39 :3 0 d9 :3 0
146 :3 0 d9 :3 0
161 :3 0 e4 :3 0
146 :3 0 1b :3 0
d9 :3 0 148 :3 0
d9 :3 0 133 :3 0
d9 :3 0 148 :3 0
148 :3 0 d9 :3 0
12a :3 0 149 :3 0
14a :3 0 d9 :3 0
77 :3 0 d9 :3 0
d8 :3 0 d9 :3 0
77 :3 0 d9 :3 0
145 :3 0 d9 :3 0
160 :3 0 d9 :3 0
146 :3 0 d9 :3 0
161 :3 0 14b :3 0
d9 :3 0 14c :3 0
162 :3 0 b7 :3 0
14d :3 0 d9 :3 0
14e :3 0 163 :3 0
b7 :3 0 14f :3 0
d9 :3 0 150 :3 0
d9 :3 0 151 :3 0
164 :3 0 b7 :3 0
152 :3 0 a2 :3 0
55 :3 0 a3 :3 0
76 :3 0 d9 :3 0
d9 :3 0 77 :3 0
d :3 0 55 :3 0
ce :3 0 d9 :3 0
ce :3 0 c5 :3 0
c6 :3 0 a3 :3 0
10e :3 0 fb :3 0
55 :3 0 fa :3 0
fb :3 0 59 :3 0
c5 :3 0 c6 :3 0
a3 :3 0 10e :3 0
fe :3 0 39 :3 0
55 :3 0 fd :3 0
55 :3 0 fa :3 0
fe :3 0 59 :3 0
c5 :3 0 c6 :3 0
a3 :3 0 10f :3 0
105 :3 0 105 :3 0
59 :3 0 d9 :3 0
104 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
165 :3 0 162 :3 0
162 :3 0 59 :3 0
d9 :3 0 14c :3 0
c5 :3 0 c6 :3 0
a3 :3 0 165 :3 0
163 :3 0 163 :3 0
59 :3 0 d9 :3 0
14e :3 0 c5 :3 0
c6 :3 0 a3 :3 0
166 :3 0 164 :3 0
164 :3 0 59 :3 0
d9 :3 0 151 :3 0
54 :3 0 b7 :4 0
1cb 1 :a 0 1b9e
:2 0 1bc2 1a5a 1b9c
:2 0 2c :3 0 2d
:3 0 1b9f 1ba0 0
2c :3 0 3d :3 0
1ba2 1ba3 0 14
:2 0 2 :4 0 1cc
:2 0 3f :2 0 14
:2 0 914 1ba8 1baa
:3 0 917 1ba4 1bac
1ba1 1bae 1bad :2 0
2f :3 0 40 :3 0
1bb0 1bb1 0 31
:4 0 1cd :4 0 34
:2 0 35 :3 0 91b
1bb5 1bb7 :3 0 91e
1bb2 1bb9 :2 0 1bbb
921 1bbc 1baf 1bbb
0 1bbd 923 0
1bc2 8 :3 0 26
:3 0 1bbf :2 0 1bc2
74 :3 0 925 1bc3
1a58 1bc2 0 1fda
39 :3 0 15 :3 0
16 :2 0 929 1bc4
1bc7 4f :2 0 8d
:2 0 92e 1bc9 1bcb
:3 0 b1 :3 0 27
:3 0 55 :3 0 ce
:3 0 59 :3 0 55
:3 0 9a :3 0 55
:3 0 a5 :3 0 a1
:3 0 b6 :3 0 c3
:3 0 a1 :3 0 55
:3 0 9a :3 0 a1
:3 0 9a :3 0 55
:3 0 a5 :3 0 b5
:3 0 b7 :3 0 6c
:3 0 b5 :3 0 55
:3 0 9a :3 0 b5
:3 0 59 :3 0 b5
:3 0 b7 :3 0 16a
:3 0 b5 :3 0 55
:3 0 9a :3 0 b5
:3 0 59 :3 0 b7
:3 0 55 :3 0 a5
:3 0 47 :3 0 16c
:3 0 55 :3 0 a5
:3 0 47 :3 0 16d
:3 0 54 :3 0 55
:3 0 ce :3 0 55
:3 0 f6 :3 0 e4
:3 0 e5 :3 0 e4
:3 0 e6 :3 0 f0
:3 0 e4 :3 0 f7
:3 0 e4 :3 0 f8
:3 0 e4 :3 0 15a
:3 0 e4 :3 0 154
:3 0 15b :3 0 e4
:3 0 12e :3 0 e4
:3 0 12f :3 0 130
:3 0 e4 :3 0 131
:3 0 e4 :3 0 132
:3 0 133 :3 0 e4
:3 0 120 :3 0 e4
:3 0 134 :3 0 135
:3 0 17 :3 0 56
:3 0 55 :3 0 f9
:3 0 e4 :3 0 1ce
:3 0 55 :3 0 fa
:3 0 fb :3 0 b7
:3 0 fc :3 0 39
:3 0 55 :3 0 fd
:3 0 55 :3 0 fa
:3 0 fd :3 0 fe
:3 0 b7 :3 0 ff
:3 0 be :3 0 100
:3 0 c0 :3 0 101
:3 0 55 :3 0 a5
:3 0 a1 :3 0 102
:3 0 c3 :3 0 a1
:3 0 55 :3 0 9a
:3 0 a1 :3 0 9a
:3 0 102 :3 0 55
:3 0 103 :3 0 f2
:3 0 e4 :3 0 13c
:3 0 e4 :3 0 13d
:3 0 13f :3 0 d8
:3 0 104 :3 0 140
:3 0 ec :3 0 107
:3 0 108 :3 0 109
:3 0 10a :3 0 10b
:3 0 10c :3 0 1cf
:3 0 a2 :3 0 55
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 10e
:3 0 fb :3 0 55
:3 0 fa :3 0 fb
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10e :3 0 fe
:3 0 39 :3 0 55
:3 0 fd :3 0 55
:3 0 fa :3 0 fe
:3 0 59 :3 0 55
:3 0 103 :3 0 55
:3 0 59 :3 0 d
:3 0 54 :3 0 b7
:4 0 1d0 1 :a 0
1c71 :2 0 1c95 1bce
1c6f :2 0 2c :3 0
2d :3 0 1c72 1c73
0 2c :3 0 3d
:3 0 1c75 1c76 0
14 :2 0 2 :4 0
1d1 :2 0 3f :2 0
14 :2 0 931 1c7b
1c7d :3 0 934 1c77
1c7f 1c74 1c81 1c80
:2 0 2f :3 0 40
:3 0 1c83 1c84 0
31 :4 0 1d2 :4 0
34 :2 0 35 :3 0
938 1c88 1c8a :3 0
93b 1c85 1c8c :2 0
1c8e 93e 1c8f 1c82
1c8e 0 1c90 940
0 1c95 8 :3 0
27 :3 0 1c92 :2 0
1c95 74 :3 0 942
1c96 1bcc 1c95 0
1fda 39 :3 0 15
:3 0 16 :2 0 946
1c97 1c9a 4f :2 0
1d3 :2 0 94b 1c9c
1c9e :3 0 96 :3 0
97 :3 0 1d4 :4 0
1ca2 :4 0 1ca3 :2 0
1ed5 9 :3 0 5b
:3 0 1ca5 1ca6 0
16 :2 0 1ca7 1ca8
0 1ed5 1d5 :3 0
9a :3 0 a5 :3 0
1d6 :3 0 9a :3 0
a5 :3 0 1d6 :3 0
76 :3 0 53 :3 0
d :3 0 d8 :3 0
1d7 :3 0 47 :3 0
1d8 :3 0 9a :3 0
a5 :4 0 1d9 1
:8 0 1cd0 a7 :4 0
1cbb :3 0 4e :3 0
4f :2 0 950 1cbe
1cbf :3 0 9 :3 0
5b :3 0 1cc1 1cc2
0 16 :2 0 1cc3
1cc4 0 1cc6 953
1ccd 9 :3 0 5b
:3 0 1cc7 1cc8 0
a8 :2 0 1cc9 1cca
0 1ccc 955 1cce
1cc0 1cc6 0 1ccf
0 1ccc 0 1ccf
957 0 1cd0 95a
1d23 5d :3 0 9
:3 0 5b :3 0 1cd2
1cd3 0 5c :3 0
1cd4 1cd5 0 1cd7
95d 1cd9 95f 1cd8
1cd7 :2 0 1d21 5e
:3 0 9 :3 0 5b
:3 0 1cdc 1cdd 0
5c :3 0 1cde 1cdf
0 1d19 2c :3 0
2d :3 0 1ce1 1ce2
0 2c :3 0 3d
:3 0 1ce4 1ce5 0
5f :2 0 2 :4 0
1da :2 0 3f :2 0
14 :2 0 961 1cea
1cec :3 0 964 1ce6
1cee 1ce3 1cf0 1cef
:2 0 2f :3 0 40
:3 0 1cf2 1cf3 0
31 :4 0 1db :4 0
34 :2 0 35 :3 0
968 1cf7 1cf9 :3 0
34 :2 0 45 :4 0
96b 1cfb 1cfd :3 0
34 :2 0 62 :4 0
96e 1cff 1d01 :3 0
34 :2 0 5c :3 0
971 1d03 1d05 :3 0
34 :2 0 63 :4 0
974 1d07 1d09 :3 0
34 :2 0 64 :3 0
65 :3 0 14 :2 0
66 :2 0 977 1d0c
1d10 97b 1d0b 1d12
:3 0 97e 1cf4 1d14
:2 0 1d16 981 1d17
1cf1 1d16 0 1d18
983 0 1d19 985
1d1c :3 0 1d1c 0
1d1c 1d1b 1d19 1d1a
:6 0 1d1e 2e :3 0
988 1d20 98a 1d1f
1d1e :2 0 1d21 98c
:2 0 1d23 0 1d23
1d22 1cd0 1d21 :6 0
1ed5 1 :3 0 96
:3 0 97 :3 0 1dc
:4 0 1d27 :4 0 1d28
:2 0 1ed5 9 :3 0
5b :3 0 1d2a 1d2b
0 16 :2 0 1d2c
1d2d 0 1ed5 1dd
:3 0 9a :3 0 a5
:3 0 1d6 :3 0 9a
:3 0 a5 :3 0 1d6
:3 0 76 :3 0 53
:3 0 d :3 0 da
:3 0 d :3 0 9a
:3 0 a5 :4 0 1de
1 :8 0 1d53 a7
:4 0 1d3e :3 0 4e
:3 0 4f :2 0 991
1d41 1d42 :3 0 9
:3 0 5b :3 0 1d44
1d45 0 16 :2 0
1d46 1d47 0 1d49
994 1d50 9 :3 0
5b :3 0 1d4a 1d4b
0 a8 :2 0 1d4c
1d4d 0 1d4f 996
1d51 1d43 1d49 0
1d52 0 1d4f 0
1d52 998 0 1d53
99b 1da6 5d :3 0
9 :3 0 5b :3 0
1d55 1d56 0 5c
:3 0 1d57 1d58 0
1d5a 99e 1d5c 9a0
1d5b 1d5a :2 0 1da4
5e :3 0 9 :3 0
5b :3 0 1d5f 1d60
0 5c :3 0 1d61
1d62 0 1d9c 2c
:3 0 2d :3 0 1d64
1d65 0 2c :3 0
3d :3 0 1d67 1d68
0 5f :2 0 2
:4 0 1df :2 0 3f
:2 0 14 :2 0 9a2
1d6d 1d6f :3 0 9a5
1d69 1d71 1d66 1d73
1d72 :2 0 2f :3 0
40 :3 0 1d75 1d76
0 31 :4 0 1e0
:4 0 34 :2 0 35
:3 0 9a9 1d7a 1d7c
:3 0 34 :2 0 45
:4 0 9ac 1d7e 1d80
:3 0 34 :2 0 62
:4 0 9af 1d82 1d84
:3 0 34 :2 0 5c
:3 0 9b2 1d86 1d88
:3 0 34 :2 0 63
:4 0 9b5 1d8a 1d8c
:3 0 34 :2 0 64
:3 0 65 :3 0 14
:2 0 66 :2 0 9b8
1d8f 1d93 9bc 1d8e
1d95 :3 0 9bf 1d77
1d97 :2 0 1d99 9c2
1d9a 1d74 1d99 0
1d9b 9c4 0 1d9c
9c6 1d9f :3 0 1d9f
0 1d9f 1d9e 1d9c
1d9d :6 0 1da1 30
:3 0 9c9 1da3 9cb
1da2 1da1 :2 0 1da4
9cd :2 0 1da6 0
1da6 1da5 1d53 1da4
:6 0 1ed5 1 :3 0
96 :3 0 97 :3 0
1e1 :4 0 1daa :4 0
1dab :2 0 1ed5 9
:3 0 5b :3 0 1dad
1dae 0 16 :2 0
1daf 1db0 0 1ed5
1e2 :3 0 9a :3 0
a5 :3 0 1d6 :3 0
55 :3 0 9a :3 0
55 :3 0 a5 :3 0
55 :3 0 1d6 :3 0
1d5 :3 0 55 :3 0
c5 :3 0 c6 :3 0
a3 :3 0 1dd :3 0
52 :3 0 55 :3 0
9a :3 0 52 :3 0
9a :3 0 52 :3 0
9a :3 0 52 :3 0
a5 :3 0 52 :3 0
1d6 :3 0 1dd :3 0
52 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
1d5 :3 0 55 :3 0
55 :3 0 9a :3 0
52 :3 0 9a :4 0
1e3 1 :8 0 1dee
a7 :4 0 1dd9 :3 0
4e :3 0 4f :2 0
9d2 1ddc 1ddd :3 0
9 :3 0 5b :3 0
1ddf 1de0 0 16
:2 0 1de1 1de2 0
1de4 9d5 1deb 9
:3 0 5b :3 0 1de5
1de6 0 a8 :2 0
1de7 1de8 0 1dea
9d7 1dec 1dde 1de4
0 1ded 0 1dea
0 1ded 9d9 0
1dee 9dc 1e41 5d
:3 0 9 :3 0 5b
:3 0 1df0 1df1 0
5c :3 0 1df2 1df3
0 1df5 9df 1df7
9e1 1df6 1df5 :2 0
1e3f 5e :3 0 9
:3 0 5b :3 0 1dfa
1dfb 0 5c :3 0
1dfc 1dfd 0 1e37
2c :3 0 2d :3 0
1dff 1e00 0 2c
:3 0 3d :3 0 1e02
1e03 0 5f :2 0
2 :4 0 1e4 :2 0
3f :2 0 14 :2 0
9e3 1e08 1e0a :3 0
9e6 1e04 1e0c 1e01
1e0e 1e0d :2 0 2f
:3 0 40 :3 0 1e10
1e11 0 31 :4 0
1e5 :4 0 34 :2 0
35 :3 0 9ea 1e15
1e17 :3 0 34 :2 0
45 :4 0 9ed 1e19
1e1b :3 0 34 :2 0
62 :4 0 9f0 1e1d
1e1f :3 0 34 :2 0
5c :3 0 9f3 1e21
1e23 :3 0 34 :2 0
63 :4 0 9f6 1e25
1e27 :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
9f9 1e2a 1e2e 9fd
1e29 1e30 :3 0 a00
1e12 1e32 :2 0 1e34
a03 1e35 1e0f 1e34
0 1e36 a05 0
1e37 a07 1e3a :3 0
1e3a 0 1e3a 1e39
1e37 1e38 :6 0 1e3c
32 :3 0 a0a 1e3e
a0c 1e3d 1e3c :2 0
1e3f a0e :2 0 1e41
0 1e41 1e40 1dee
1e3f :6 0 1ed5 1
:3 0 b1 :3 0 28
:3 0 55 :3 0 9a
:3 0 59 :3 0 b5
:3 0 b6 :3 0 b7
:3 0 54 :3 0 b5
:3 0 1e6 :3 0 55
:3 0 1d6 :3 0 1e2
:3 0 55 :3 0 a3
:3 0 c3 :3 0 b5
:3 0 55 :3 0 a5
:3 0 55 :3 0 9a
:3 0 b5 :3 0 9a
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 1dd
:3 0 1e7 :3 0 55
:3 0 9a :3 0 1e7
:3 0 9a :3 0 a1
:3 0 ad :3 0 59
:3 0 a1 :3 0 c9
:3 0 b7 :3 0 54
:3 0 1e6 :3 0 55
:3 0 1d6 :3 0 1e2
:3 0 55 :3 0 a3
:3 0 ca :3 0 a1
:3 0 55 :3 0 a5
:3 0 a1 :3 0 ad
:3 0 55 :3 0 9a
:3 0 a3 :3 0 a4
:3 0 c4 :3 0 c4
:3 0 59 :3 0 a1
:3 0 cb :3 0 a3
:3 0 a4 :3 0 ba
:3 0 ba :3 0 59
:3 0 c4 :3 0 9b
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 1dd
:3 0 1e7 :3 0 55
:3 0 9a :3 0 1e7
:3 0 9a :3 0 d7
:3 0 9a :3 0 59
:3 0 b5 :3 0 b6
:3 0 b7 :3 0 54
:3 0 b5 :3 0 1e6
:3 0 1d6 :3 0 a2
:3 0 d7 :3 0 c3
:3 0 b5 :3 0 d7
:3 0 53 :3 0 d
:3 0 d7 :3 0 9a
:3 0 b5 :3 0 9a
:3 0 1e8 :3 0 9a
:3 0 1e2 :3 0 1e8
:3 0 d7 :3 0 9a
:3 0 1e8 :3 0 9a
:3 0 54 :3 0 b7
:4 0 1e9 1 :a 0
1eb1 :2 0 1ed5 1e44
1eaf :2 0 2c :3 0
2d :3 0 1eb2 1eb3
0 2c :3 0 3d
:3 0 1eb5 1eb6 0
14 :2 0 2 :4 0
1ea :2 0 3f :2 0
14 :2 0 a11 1ebb
1ebd :3 0 a14 1eb7
1ebf 1eb4 1ec1 1ec0
:2 0 2f :3 0 40
:3 0 1ec3 1ec4 0
31 :4 0 1eb :4 0
34 :2 0 35 :3 0
a18 1ec8 1eca :3 0
a1b 1ec5 1ecc :2 0
1ece a1e 1ecf 1ec2
1ece 0 1ed0 a20
0 1ed5 8 :3 0
28 :3 0 1ed2 :2 0
1ed5 74 :3 0 a22
1ed6 1c9f 1ed5 0
1fda 39 :3 0 15
:3 0 16 :2 0 a2f
1ed7 1eda 4f :2 0
81 :2 0 a34 1edc
1ede :3 0 b :3 0
64 :3 0 b :3 0
34 :2 0 1ec :4 0
a37 1ee3 1ee5 :3 0
14 :2 0 c :2 0
a3a 1ee1 1ee9 1ee0
1eea 0 1f2c b1
:3 0 29 :3 0 d9
:3 0 59 :3 0 b5
:3 0 b6 :3 0 b7
:3 0 54 :3 0 b5
:3 0 1e6 :3 0 1d6
:3 0 6c :3 0 d9
:3 0 a3 :3 0 c3
:3 0 b5 :3 0 d9
:3 0 59 :3 0 b5
:3 0 9a :3 0 d9
:3 0 54 :3 0 d9
:3 0 82 :3 0 b
:3 0 b7 :4 0 1ed
1 :a 0 1f08 :2 0
1f2c 1eed 1f06 :2 0
2c :3 0 2d :3 0
1f09 1f0a 0 2c
:3 0 3d :3 0 1f0c
1f0d 0 14 :2 0
2 :4 0 1ee :2 0
3f :2 0 14 :2 0
a3e 1f12 1f14 :3 0
a41 1f0e 1f16 1f0b
1f18 1f17 :2 0 2f
:3 0 40 :3 0 1f1a
1f1b 0 31 :4 0
1ef :4 0 34 :2 0
35 :3 0 a45 1f1f
1f21 :3 0 a48 1f1c
1f23 :2 0 1f25 a4b
1f26 1f19 1f25 0
1f27 a4d 0 1f2c
8 :3 0 29 :3 0
1f29 :2 0 1f2c 74
:3 0 a4f 1f2d 1edf
1f2c 0 1fda 39
:3 0 15 :3 0 16
:2 0 a54 1f2e 1f31
47 :3 0 4f :2 0
8e :3 0 1f33 1f35
0 a59 1f34 1f37
:3 0 1f38 :2 0 39
:3 0 15 :3 0 16
:2 0 a5c 1f3a 1f3d
47 :3 0 4f :2 0
8f :3 0 1f3f 1f41
0 a61 1f40 1f43
:3 0 1f44 :2 0 1f39
1f46 1f45 :2 0 b1
:3 0 2a :3 0 a1
:3 0 9a :3 0 59
:3 0 a1 :3 0 b6
:3 0 b7 :3 0 47
:3 0 16e :3 0 54
:3 0 a1 :3 0 1e6
:3 0 1d6 :3 0 199
:3 0 d7 :3 0 c3
:3 0 a1 :3 0 d7
:3 0 53 :3 0 d
:3 0 d7 :3 0 9a
:3 0 a1 :3 0 9a
:3 0 b7 :4 0 1f0
1 :a 0 1f64 :2 0
1f87 1f49 1f62 :2 0
2c :3 0 2d :3 0
1f65 1f66 0 2c
:3 0 3d :3 0 1f68
1f69 0 14 :2 0
2 :4 0 1f1 :2 0
3f :2 0 14 :2 0
a64 1f6e 1f70 :3 0
a67 1f6a 1f72 1f67
1f74 1f73 :2 0 2f
:3 0 40 :3 0 1f76
1f77 0 31 :4 0
1f2 :4 0 34 :2 0
35 :3 0 a6b 1f7b
1f7d :3 0 a6e 1f78
1f7f :2 0 1f81 a71
1f82 1f75 1f81 0
1f83 a73 0 1f87
8 :3 0 2a :3 0
1f85 :2 0 1f87 a75
1f88 1f47 1f87 0
1fda 2c :3 0 2d
:3 0 1f89 1f8a 0
2c :3 0 3d :3 0
1f8c 1f8d 0 173
:2 0 2 :4 0 1f3
:2 0 3f :2 0 14
:2 0 a79 1f92 1f94
:3 0 a7c 1f8e 1f96
1f8b 1f98 1f97 :2 0
2f :3 0 40 :3 0
1f9a 1f9b 0 31
:4 0 1f4 :4 0 34
:2 0 35 :3 0 a80
1f9f 1fa1 :3 0 34
:2 0 45 :4 0 a83
1fa3 1fa5 :3 0 34
:2 0 46 :4 0 a86
1fa7 1fa9 :3 0 34
:2 0 39 :3 0 3a
:3 0 47 :3 0 48
:3 0 1fae 1faf 0
a89 1fad 1fb1 3b
:4 0 a8b 1fac 1fb4
a8e 1fab 1fb6 :3 0
34 :2 0 49 :4 0
a91 1fb8 1fba :3 0
34 :2 0 37 :4 0
a94 1fbc 1fbe :3 0
34 :2 0 3 :3 0
a97 1fc0 1fc2 :3 0
34 :2 0 37 :4 0
a9a 1fc4 1fc6 :3 0
a9d 1f9c 1fc8 :2 0
1fca aa0 1fcb 1f99
1fca 0 1fcc aa2
0 1fd7 4c :3 0
1f5 :3 0 1fcd 1fce
0 47 :3 0 48
:3 0 1fd0 1fd1 0
3 :3 0 4e :3 0
aa4 1fcf 1fd5 :2 0
1fd7 aa8 1fd9 6fd
964 0 1fda 0
1fd7 0 1fda aab
0 1fdb abb 207c
9 :3 0 1f6 :2 0
4 1fdc 1fdd 0
2c :3 0 2d :3 0
1fdf 1fe0 0 2c
:3 0 3d :3 0 1fe2
1fe3 0 5f :2 0
2 :4 0 1f7 :2 0
3f :2 0 14 :2 0
ac4 1fe8 1fea :3 0
ac7 1fe4 1fec 1fe1
1fee 1fed :2 0 2f
:3 0 40 :3 0 1ff0
1ff1 0 31 :4 0
1f8 :4 0 34 :2 0
35 :3 0 acb 1ff5
1ff7 :3 0 ace 1ff2
1ff9 :2 0 2012 2f
:3 0 40 :3 0 1ffb
1ffc 0 31 :4 0
1f9 :4 0 34 :2 0
9 :3 0 1fa :3 0
2001 2002 0 ad1
2000 2004 :3 0 34
:2 0 49 :4 0 ad4
2006 2008 :3 0 34
:2 0 9 :3 0 1fb
:3 0 200b 200c 0
ad7 200a 200e :3 0
ada 1ffd 2010 :2 0
2012 add 2013 1fef
2012 0 2014 ae0
0 2024 b1 :3 0
2b :3 0 9 :3 0
1fa :3 0 1fc :3 0
9 :3 0 1fb :3 0
3 :3 0 118 :4 0
1fd 1 :a 0 2020
:2 0 2024 2016 201e
:2 0 8 :3 0 2b
:3 0 2022 :2 0 2024
ae2 2026 ae6 2025
2024 :2 0 207a 5e
:3 0 9 :3 0 5b
:3 0 2029 202a 0
5c :3 0 202b 202c
0 2072 2c :3 0
2d :3 0 202e 202f
0 2c :3 0 3d
:3 0 2031 2032 0
5f :2 0 2 :4 0
1fe :2 0 3f :2 0
14 :2 0 ae8 2037
2039 :3 0 aeb 2033
203b 2030 203d 203c
:2 0 2f :3 0 40
:3 0 203f 2040 0
31 :4 0 1ff :4 0
34 :2 0 35 :3 0
aef 2044 2046 :3 0
af2 2041 2048 :2 0
2062 2f :3 0 40
:3 0 204a 204b 0
31 :4 0 62 :4 0
34 :2 0 5c :3 0
af5 204f 2051 :3 0
34 :2 0 63 :4 0
af8 2053 2055 :3 0
34 :2 0 64 :3 0
65 :3 0 14 :2 0
66 :2 0 afb 2058
205c aff 2057 205e
:3 0 b02 204c 2060
:2 0 2062 b05 2063
203e 2062 0 2064
b08 0 2072 b1
:3 0 2b :3 0 1fc
:3 0 9 :3 0 1fb
:3 0 3 :3 0 118
:4 0 200 1 :a 0
206e :2 0 2072 2066
206c :2 0 8 :3 0
2b :3 0 2070 :2 0
2072 b0a 2075 :3 0
2075 0 2075 2074
2072 2073 :6 0 2077
1 :3 0 b0f 2079
b11 2078 2077 :2 0
207a b13 :2 0 207c
b16 207c 207b 1fdb
207a :6 0 207d :2 0
2 14 207c 2080
:3 0 207f 207d 2081
:8 0 
b33
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
40 1 46 1
4c 1 52 1
58 1 5e 1
64 1 6b 1
72 1 79 1
80 1 87 1
8e 1 95 1
9c 1 a3 1
aa 1 b1 1
b8 1 bf 1
c6 1 cd 1
da 1 e6 2
e9 eb 2 ee
f0 2 f2 f4
2 f6 f8 2
fa fc 1 102
2 104 105 2
fe 107 2 109
10b 2 10d 10f
2 111 113 2
115 117 2 119
11b 4 e2 e8
ed 11d 1 11f
1 121 2 12b
12d 3 129 12a
12f 2 138 13a
2 137 13c 1
13e 1 140 1
142 2 14f 151
3 14d 14e 153
2 15c 15e 2
160 162 2 164
166 1 16e 2
170 171 2 168
173 2 175 177
2 179 17b 2
17d 17f 2 181
183 2 15b 185
1 187 1 189
2 193 195 3
191 192 197 2
1a0 1a2 2 19f
1a4 1 1a6 1
1a8 3 1af 1b0
1b1 3 18a 1a9
1b3 1 1b5 2
1c1 1c2 1 1c6
2 1c4 1c6 2
1cb 1cc 1 1d0
2 1ce 1d0 2
1ee 1f3 1 1fa
1 1f5 2 20d
20f 3 20b 20c
211 2 21a 21c
2 21e 220 2
222 224 2 226
228 2 22a 22c
3 231 232 233
2 22e 235 2
219 237 1 239
1 23b 2 204
23c 1 240 1
1ff 2 1fd 244
1 24f 2 24b
24f 2 268 26d
1 274 1 26f
2 287 289 3
285 286 28b 2
294 296 2 298
29a 2 29c 29e
2 2a0 2a2 2
2a4 2a6 3 2ab
2ac 2ad 2 2a8
2af 2 293 2b1
1 2b3 1 2b5
2 27e 2b6 1
2ba 1 279 2
277 2be 1 2c9
2 2c5 2c9 2
2d1 2d6 1 2dd
1 2d8 2 2f0
2f2 3 2ee 2ef
2f4 2 2fd 2ff
2 301 303 2
305 307 2 309
30b 2 30d 30f
3 314 315 316
2 311 318 2
2fc 31a 1 31c
1 31e 2 2e7
31f 1 323 1
2e2 2 2e0 327
1 332 2 32e
332 2 33e 340
3 33c 33d 342
2 34b 34d 2
34f 351 2 353
355 1 35d 2
35f 360 2 357
362 2 364 366
2 368 36a 2
36c 36e 2 370
372 2 34a 374
1 376 1 378
2 382 384 3
380 381 386 2
38f 391 2 38e
393 1 395 1
397 3 39e 39f
3a0 3 379 398
3a2 1 3a4 2
32a 3a5 1 3a7
2 2c1 3a8 1
3aa 2 247 3ab
2 3af 3b0 1
3b4 2 3b2 3b4
2 3bc 3c1 1
3c8 1 3c3 2
3db 3dd 3 3d9
3da 3df 2 3e8
3ea 2 3ec 3ee
2 3f0 3f2 2
3f4 3f6 2 3f8
3fa 3 3ff 400
401 2 3fc 403
2 3e7 405 1
407 1 409 2
3d2 40a 1 40e
1 3cd 2 3cb
412 1 41d 2
419 41d 2 429
42b 3 427 428
42d 2 436 438
2 43a 43c 2
43e 440 1 448
2 44a 44b 2
442 44d 2 44f
451 2 453 455
2 457 459 2
45b 45d 2 435
45f 1 461 1
463 2 46d 46f
3 46b 46c 471
2 47a 47c 2
479 47e 1 480
1 482 3 489
48a 48b 3 464
483 48d 1 48f
2 499 49e 1
4a5 1 4a0 2
4b8 4ba 3 4b6
4b7 4bc 2 4c5
4c7 2 4c9 4cb
2 4cd 4cf 2
4d1 4d3 2 4d5
4d7 3 4dc 4dd
4de 2 4d9 4e0
2 4c4 4e2 1
4e4 1 4e6 2
4af 4e7 1 4eb
1 4aa 2 4a8
4ef 3 415 490
4f2 2 4f8 4f9
1 4fd 2 4fb
4fd 2 505 50a
1 511 1 50c
2 524 526 3
522 523 528 2
531 533 2 535
537 2 539 53b
2 53d 53f 2
541 543 3 548
549 54a 2 545
54c 2 530 54e
1 550 1 552
2 51b 553 1
557 1 516 2
514 55b 1 566
2 562 566 2
572 574 3 570
571 576 2 57f
581 2 583 585
2 587 589 1
591 2 593 594
2 58b 596 2
598 59a 2 59c
59e 2 5a0 5a2
2 5a4 5a6 2
57e 5a8 1 5aa
1 5ac 2 5b6
5b8 3 5b4 5b5
5ba 2 5c3 5c5
2 5c2 5c7 1
5c9 1 5cb 3
5d2 5d3 5d4 3
5ad 5cc 5d6 1
5d8 3 55e 5d9
5dc 2 5e1 5e2
1 5e8 2 5e4
5e8 2 5ed 5ee
1 5f2 2 5f0
5f2 2 5f9 5fa
1 600 2 5fc
600 2 607 608
1 60e 2 60a
60e 2 61c 621
1 628 1 623
2 63b 63d 3
639 63a 63f 2
648 64a 2 64c
64e 2 650 652
2 654 656 2
658 65a 3 65f
660 661 2 65c
663 2 647 665
1 667 1 669
2 632 66a 1
66e 1 62d 2
62b 672 1 67d
2 679 67d 2
689 68b 3 687
688 68d 2 696
698 2 69a 69c
2 69e 6a0 1
6a8 2 6aa 6ab
2 6a2 6ad 2
6af 6b1 2 6b3
6b5 2 6b7 6b9
2 6bb 6bd 2
695 6bf 1 6c1
1 6c3 2 6cd
6cf 3 6cb 6cc
6d1 2 6da 6dc
2 6d9 6de 1
6e0 1 6e2 3
6e9 6ea 6eb 3
6c4 6e3 6ed 1
6ef 2 675 6f0
4 6f3 4f6 5df
6f2 2 6f6 6f7
1 6fb 2 6f9
6fb 1 72d 2
72c 72d 1 735
1 73b 2 73d
73e 2 72a 73f
1 746 1 741
2 759 75b 3
757 758 75d 2
766 768 2 76a
76c 2 76e 770
2 772 774 2
776 778 3 77d
77e 77f 2 77a
781 2 765 783
1 785 1 787
2 750 788 1
78c 1 74b 2
749 790 1 7a9
2 7a8 7a9 1
7b1 1 7b7 2
7b9 7ba 2 7a6
7bb 1 7c2 1
7bd 2 7d5 7d7
3 7d3 7d4 7d9
2 7e2 7e4 2
7e6 7e8 2 7ea
7ec 2 7ee 7f0
2 7f2 7f4 3
7f9 7fa 7fb 2
7f6 7fd 2 7e1
7ff 1 801 1
803 2 7cc 804
1 808 1 7c7
2 7c5 80c 2
949 94b 3 947
948 94d 2 956
958 2 955 95a
1 95c 1 95e
9 702 707 793
799 79e 80f 93f
95f 962 2 966
967 1 96b 2
969 96b 2 970
971 1 975 2
973 975 1 9ae
2 9ad 9ae 1
9b6 1 9bc 2
9be 9bf 2 9ab
9c0 1 9c7 1
9c2 2 9da 9dc
3 9d8 9d9 9de
2 9e7 9e9 2
9eb 9ed 2 9ef
9f1 2 9f3 9f5
2 9f7 9f9 3
9fe 9ff a00 2
9fb a02 2 9e6
a04 1 a06 1
a08 2 9d1 a09
1 a0d 1 9cc
2 9ca a11 1
a4e 2 a4d a4e
1 a56 1 a5c
2 a5e a5f 2
a4b a60 1 a67
1 a62 2 a7a
a7c 3 a78 a79
a7e 2 a87 a89
2 a8b a8d 2
a8f a91 2 a93
a95 2 a97 a99
3 a9e a9f aa0
2 a9b aa2 2
a86 aa4 1 aa6
1 aa8 2 a71
aa9 1 aad 1
a6c 2 a6a ab1
2 b0a b0c 3
b08 b09 b0e 2
b17 b19 2 b16
b1b 1 b1d 1
b1f 8 97f 984
a14 a1c ab4 b00
b20 b23 2 b28
b29 1 b2d 2
b2b b2d 2 bc8
bca 3 bc6 bc7
bcc 2 bd5 bd7
2 bd4 bd9 1
bdb 1 bdd 3
bbe bde be1 2
be6 be7 1 beb
2 be9 beb 2
bf0 bf1 1 bf3
1 bf7 2 bf5
bf7 2 c04 c09
1 c10 1 c0b
2 c23 c25 3
c21 c22 c27 2
c30 c32 2 c34
c36 2 c38 c3a
2 c3c c3e 2
c40 c42 3 c47
c48 c49 2 c44
c4b 2 c2f c4d
1 c4f 1 c51
2 c1a c52 1
c56 1 c15 2
c13 c5a 2 c60
c61 1 c65 2
c63 c65 1 c6a
2 c78 c7d 1
c84 1 c7f 2
c97 c99 3 c95
c96 c9b 2 ca4
ca6 2 ca8 caa
2 cac cae 2
cb0 cb2 2 cb4
cb6 3 cbb cbc
cbd 2 cb8 cbf
2 ca3 cc1 1
cc3 1 cc5 2
c8e cc6 1 cca
1 c89 2 c87
cce 2 cd4 cd5
1 cd9 2 cd7
cd9 2 cf8 cfd
1 d04 1 cff
2 d17 d19 3
d15 d16 d1b 2
d24 d26 2 d28
d2a 2 d2c d2e
2 d30 d32 2
d34 d36 3 d3b
d3c d3d 2 d38
d3f 2 d23 d41
1 d43 1 d45
2 d0e d46 1
d4a 1 d09 2
d07 d4e 2 d54
d55 1 d59 2
d57 d59 1 d5e
1 d62 2 d64
d65 2 d51 d66
1 d6a 2 d6c
d6d 3 c6e cd1
d6e 2 d70 d71
2 f90 f92 3
f8e f8f f94 2
f9d f9f 2 f9c
fa1 1 fa3 1
fa5 6 bfc c5d
d72 f86 fa6 fa9
2 1104 1106 3
1102 1103 1108 2
1111 1113 2 1110
1115 1 1117 1
1119 3 10fa 111a
111d 2 111f 1120
1 1121 2 1126
1127 1 112b 2
1129 112b 1 1162
2 1161 1162 1
116a 1 1170 2
1172 1173 2 115f
1174 1 117b 1
1176 2 118e 1190
3 118c 118d 1192
2 119b 119d 2
119f 11a1 2 11a3
11a5 2 11a7 11a9
2 11ab 11ad 3
11b2 11b3 11b4 2
11af 11b6 2 119a
11b8 1 11ba 1
11bc 2 1185 11bd
1 11c1 1 1180
2 117e 11c5 1
1209 2 1208 1209
1 1211 1 1217
2 1219 121a 2
1206 121b 1 1222
1 121d 2 1235
1237 3 1233 1234
1239 2 1242 1244
2 1246 1248 2
124a 124c 2 124e
1250 2 1252 1254
3 1259 125a 125b
2 1256 125d 2
1241 125f 1 1261
1 1263 2 122c
1264 1 1268 1
1227 2 1225 126c
2 12c8 12ca 3
12c6 12c7 12cc 2
12d5 12d7 2 12d4
12d9 1 12db 1
12dd 8 1132 1137
11c8 11d0 126f 12be
12de 12e1 2 12e6
12e7 1 12eb 2
12e9 12eb 1 1322
2 1321 1322 1
132a 1 1330 2
1332 1333 2 131f
1334 1 133b 1
1336 2 134e 1350
3 134c 134d 1352
2 135b 135d 2
135f 1361 2 1363
1365 2 1367 1369
2 136b 136d 3
1372 1373 1374 2
136f 1376 2 135a
1378 1 137a 1
137c 2 1345 137d
1 1381 1 1340
2 133e 1385 1
13f6 2 13f5 13f6
1 13fe 1 1404
2 1406 1407 2
13f3 1408 1 140f
1 140a 2 1422
1424 3 1420 1421
1426 2 142f 1431
2 1433 1435 2
1437 1439 2 143b
143d 2 143f 1441
3 1446 1447 1448
2 1443 144a 2
142e 144c 1 144e
1 1450 2 1419
1451 1 1455 1
1414 2 1412 1459
2 14d3 14d5 3
14d1 14d2 14d7 2
14e0 14e2 2 14df
14e4 1 14e6 1
14e8 8 12f2 12f7
1388 1390 145c 14c9
14e9 14ec 2 14f1
14f2 1 14f6 2
14f4 14f6 2 15eb
15ed 3 15e9 15ea
15ef 2 15f8 15fa
2 15f7 15fc 1
15fe 1 1600 3
15e1 1601 1604 2
1609 160a 1 160e
2 160c 160e 1
164d 2 164c 164d
1 1655 1 165b
2 165d 165e 2
164a 165f 1 1666
1 1661 2 1679
167b 3 1677 1678
167d 2 1686 1688
2 168a 168c 2
168e 1690 2 1692
1694 2 1696 1698
3 169d 169e 169f
2 169a 16a1 2
1685 16a3 1 16a5
1 16a7 2 1670
16a8 1 16ac 1
166b 2 1669 16b0
1 1733 2 1732
1733 1 173b 1
1741 2 1743 1744
2 1730 1745 1
174c 1 1747 2
175f 1761 3 175d
175e 1763 2 176c
176e 2 1770 1772
2 1774 1776 2
1778 177a 2 177c
177e 3 1783 1784
1785 2 1780 1787
2 176b 1789 1
178b 1 178d 2
1756 178e 1 1792
1 1751 2 174f
1796 1 17ae 2
17ad 17ae 1 17b6
1 17bc 2 17be
17bf 2 17ab 17c0
1 17c7 1 17c2
2 17da 17dc 3
17d8 17d9 17de 2
17e7 17e9 2 17eb
17ed 2 17ef 17f1
2 17f3 17f5 2
17f7 17f9 3 17fe
17ff 1800 2 17fb
1802 2 17e6 1804
1 1806 1 1808
2 17d1 1809 1
180d 1 17cc 2
17ca 1811 2 18f9
18fb 3 18f7 18f8
18fd 2 1906 1908
2 1905 190a 1
190c 1 190e a
1615 161a 16b3 16b9
16be 1799 1814 18ef
190f 1912 2 1917
1918 1 191e 2
191a 191e 2 1926
192b 1 1932 1
192d 2 1945 1947
3 1943 1944 1949
2 1952 1954 2
1956 1958 2 195a
195c 2 195e 1960
2 1962 1964 3
1969 196a 196b 2
1966 196d 2 1951
196f 1 1971 1
1973 2 193c 1974
1 1978 1 1937
2 1935 197c 1
1987 2 1983 1987
2 1a30 1a32 3
1a2e 1a2f 1a34 2
1a3d 1a3f 2 1a3c
1a41 1 1a43 1
1a45 3 1a26 1a46
1a49 1 1a4b 2
197f 1a4c 2 1a51
1a52 1 1a56 2
1a54 1a56 2 1ba7
1ba9 3 1ba5 1ba6
1bab 2 1bb4 1bb6
2 1bb3 1bb8 1
1bba 1 1bbc 3
1b9d 1bbd 1bc0 2
1bc5 1bc6 1 1bca
2 1bc8 1bca 2
1c7a 1c7c 3 1c78
1c79 1c7e 2 1c87
1c89 2 1c86 1c8b
1 1c8d 1 1c8f
3 1c70 1c90 1c93
2 1c98 1c99 1
1c9d 2 1c9b 1c9d
1 1cbd 2 1cbc
1cbd 1 1cc5 1
1ccb 2 1ccd 1cce
2 1cba 1ccf 1
1cd6 1 1cd1 2
1ce9 1ceb 3 1ce7
1ce8 1ced 2 1cf6
1cf8 2 1cfa 1cfc
2 1cfe 1d00 2
1d02 1d04 2 1d06
1d08 3 1d0d 1d0e
1d0f 2 1d0a 1d11
2 1cf5 1d13 1
1d15 1 1d17 2
1ce0 1d18 1 1d1c
1 1cdb 2 1cd9
1d20 1 1d40 2
1d3f 1d40 1 1d48
1 1d4e 2 1d50
1d51 2 1d3d 1d52
1 1d59 1 1d54
2 1d6c 1d6e 3
1d6a 1d6b 1d70 2
1d79 1d7b 2 1d7d
1d7f 2 1d81 1d83
2 1d85 1d87 2
1d89 1d8b 3 1d90
1d91 1d92 2 1d8d
1d94 2 1d78 1d96
1 1d98 1 1d9a
2 1d63 1d9b 1
1d9f 1 1d5e 2
1d5c 1da3 1 1ddb
2 1dda 1ddb 1
1de3 1 1de9 2
1deb 1dec 2 1dd8
1ded 1 1df4 1
1def 2 1e07 1e09
3 1e05 1e06 1e0b
2 1e14 1e16 2
1e18 1e1a 2 1e1c
1e1e 2 1e20 1e22
2 1e24 1e26 3
1e2b 1e2c 1e2d 2
1e28 1e2f 2 1e13
1e31 1 1e33 1
1e35 2 1dfe 1e36
1 1e3a 1 1df9
2 1df7 1e3e 2
1eba 1ebc 3 1eb8
1eb9 1ebe 2 1ec7
1ec9 2 1ec6 1ecb
1 1ecd 1 1ecf
c 1ca4 1ca9 1d23
1d29 1d2e 1da6 1dac
1db1 1e41 1eb0 1ed0
1ed3 2 1ed8 1ed9
1 1edd 2 1edb
1edd 2 1ee2 1ee4
3 1ee6 1ee7 1ee8
2 1f11 1f13 3
1f0f 1f10 1f15 2
1f1e 1f20 2 1f1d
1f22 1 1f24 1
1f26 4 1eeb 1f07
1f27 1f2a 2 1f2f
1f30 1 1f36 2
1f32 1f36 2 1f3b
1f3c 1 1f42 2
1f3e 1f42 2 1f6d
1f6f 3 1f6b 1f6c
1f71 2 1f7a 1f7c
2 1f79 1f7e 1
1f80 1 1f82 3
1f63 1f83 1f86 2
1f91 1f93 3 1f8f
1f90 1f95 2 1f9e
1fa0 2 1fa2 1fa4
2 1fa6 1fa8 1
1fb0 2 1fb2 1fb3
2 1faa 1fb5 2
1fb7 1fb9 2 1fbb
1fbd 2 1fbf 1fc1
2 1fc3 1fc5 2
1f9d 1fc7 1 1fc9
1 1fcb 3 1fd2
1fd3 1fd4 2 1fcc
1fd6 f 1fd8 b26
be4 1124 12e4 14ef
1607 1915 1a4f 1bc3
1c96 1ed6 1f2d 1f88
1fd9 8 122 141
1b6 1b9 1bc 1bf
6f4 1fda 2 1fe7
1fe9 3 1fe5 1fe6
1feb 2 1ff4 1ff6
2 1ff3 1ff8 2
1fff 2003 2 2005
2007 2 2009 200d
2 1ffe 200f 2
1ffa 2011 1 2013
3 2014 201f 2023
1 1fde 2 2036
2038 3 2034 2035
203a 2 2043 2045
2 2042 2047 2
204e 2050 2 2052
2054 3 2059 205a
205b 2 2056 205d
2 204d 205f 2
2049 2061 1 2063
4 202d 2064 206d
2071 1 2075 1
2028 2 2026 2079
1c 1b 22 29
30 37 3e 44
4a 50 56 5c
62 69 70 77
7e 85 8c 93
9a a1 a8 af
b6 bd c4 cb
d2 
1
4
0 
2080
0
1
50
34
20
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 4552 4f53 5255 4543
495f 2944 5420 4548 204e 3331 4520 534c
2045 3831 2035 4e45 2044 5341 5220 5345
545f 5059 2c45 200a 2020 2020 5220 5345

3 1 0
c6 1 0
b 1 0
bf 1 0
52 1 0
2 0 1
64 1 0
6b 1 0
72 1 0
58 1 0
80 1 0
4c 1 0
87 1 0
8e 1 0
95 1 0
9c 1 0
a3 1 0
aa 1 0
b1 1 0
b8 1 0
79 1 0
40 1 0
1d 1 0
16 1 0
5e 1 0
39 1 0
32 1 0
2b 1 0
46 1 0
7 1 0
24 1 0
cd 1 0
0

/
SHOW ERRORS FUNCTION SP_S_PROFILE;
ALTER FUNCTION SP_S_PROFILE COMPILE DEBUG;
/*********************************************************************************************************************************************/
Prompt == FUNCTION FC_U_NAMES ==
CREATE OR REPLACE FUNCTION FC_U_NAMES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
6f
2 :e:
1FUNCTION:
1FC_U_NAMES:
1A_ELEMENT_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1H_FULL_NAME:
1A_PARTICIPANT_ID:
1SH_H_TABLE_TYPE:
1PLS_INTEGER:
1RETURN:
1H_TABLE_TYPE:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_NAMES(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
119:
1+:
1FPUT:
1               ENTER:: FC_U_NAMES(20) :: cplan.sql(14732) :: :
1PMO_CNST:
1SC_TABLE_SCD:
1TMT_ASSIGNED_SCORECARDS:
1ASSIGN_NAMES:
1INSTR:
1REPLACE:
1LENGTH:
1ELEMENT_ID:
1UPDATE TMT_ASSIGNED_SCORECARDS SET ASSIGN_NAMES =:n            CASE:n        +
1    WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_ful+
1l_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            +
1ELSE:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_+
1NAMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIG+
1N_NAMES:n            END:n            END:n            WHERE ELEMENT_ID = a_e+
1lement_id:
1FOUND:
1TRUE:
1=:
1PMO_DB2M:
1SC_STATE:
10:
1100:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
148:
1           EXCEPTION:: FC_U_NAMES(49) :: cplan.sql(14761) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_TABLE_POL:
1TMT_POOLS:
1MANAGER_ID:
1UPDATE TMT_POOLS SET MANAGER_ID = a_participant_id, ASSIGN_NAMES =:n         +
1   CASE:n            WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n     +
1       THEN h_full_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', +
1''):n            ELSE:n            CASE:n            WHEN LENGTH(h_full_name)+
1 + LENGTH(ASSIGN_NAMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_nam+
1e || ';' || ASSIGN_NAMES:n            END:n            END:n            WHERE+
1 ELEMENT_ID = a_element_id:
180:
1           EXCEPTION:: FC_U_NAMES(81) :: cplan.sql(14793) :: :
1SC_TABLE_CRI:
1TMT_CRI:
1UPDATE TMT_CRI SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || ';' ||+
1 REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n          +
1  CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2040 TH+
1EN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n       +
1     END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1111:
1           EXCEPTION:: FC_U_NAMES(112) :: cplan.sql(14824) :: :
1SC_TABLE_DOC:
1TMT_DOCUMENTS:
1UPDATE TMT_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            WHEN I+
1nStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || +
1';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n    +
1        CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2+
1040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n +
1           END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1143:
1           EXCEPTION:: FC_U_NAMES(144) :: cplan.sql(14856) :: :
1SC_TABLE_POL_DOC:
1TMT_POOL_DOCUMENTS:
1UPDATE TMT_POOL_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            W+
1HEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_nam+
1e || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE+
1:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAME+
1S) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NA+
1MES:n            END:n            END:n            WHERE ELEMENT_ID = a_eleme+
1nt_id:
1175:
1           EXCEPTION:: FC_U_NAMES(176) :: cplan.sql(14888) :: :
1SC_TABLE_RES_DOC:
1TMT_RESOURCE_DOCUMENTS:
1UPDATE TMT_RESOURCE_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n         +
1   WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full+
1_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            E+
1LSE:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_N+
1AMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN+
1_NAMES:n            END:n            END:n            WHERE ELEMENT_ID = a_el+
1ement_id:
1207:
1           EXCEPTION:: FC_U_NAMES(208) :: cplan.sql(14920) :: :
1SC_TABLE_AST_DOC:
1TMT_ASSET_DOCUMENTS:
1UPDATE TMT_ASSET_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            +
1WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_na+
1me || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE+
1:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAME+
1S) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NA+
1MES:n            END:n            END:n            WHERE ELEMENT_ID = a_eleme+
1nt_id:
1239:
1           EXCEPTION:: FC_U_NAMES(240) :: cplan.sql(14952) :: :
1SC_TABLE_CLN_DOC:
1TMT_CLIENT_DOCUMENTS:
1UPDATE TMT_CLIENT_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n           +
1 WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_n+
1ame || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELS+
1E:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAM+
1ES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_N+
1AMES:n            END:n            END:n            WHERE ELEMENT_ID = a_elem+
1ent_id:
1271:
1           EXCEPTION:: FC_U_NAMES(272) :: cplan.sql(14984) :: :
1SC_TABLE_VDR_DOC:
1TMT_VENDOR_DOCUMENTS:
1UPDATE TMT_VENDOR_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n           +
1 WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_n+
1ame || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELS+
1E:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAM+
1ES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_N+
1AMES:n            END:n            END:n            WHERE ELEMENT_ID = a_elem+
1ent_id:
1303:
1           EXCEPTION:: FC_U_NAMES(304) :: cplan.sql(15016) :: :
1TMT_WBS:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || ';' ||+
1 REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n          +
1  CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2040 TH+
1EN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n       +
1     END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1335:
1           EXCEPTION:: FC_U_NAMES(336) :: cplan.sql(15048) :: :
1343:
1                EXIT:: FC_U_NAMES(344) :: cplan.sql(15056) :: :
1STATE:: :
0

0
0
5fc
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 8f
a0 b0 3d b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a6 9 :2 a0 6b
:14 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a6 9 :2 a0 6b :12 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 a6 9
:2 a0 6b :12 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a6 9 :2 a0 6b :12 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
a6 9 :2 a0 6b :12 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a6 9 :2 a0
6b :12 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 a6 9 :2 a0 6b :12 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 a6
9 :2 a0 6b :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a6 9 :12 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 9
a4 14 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
5fc
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 73 6f 37
7b 6e 80 84 88 8c a9 94
98 a0 a4 6b 90 b0 b4 b7
bb bf c2 c7 c8 1 ca cf
d3 d7 da df e3 e7 ea ef
f0 f2 f7 fa fe ff 104 109
10c 111 112 117 11a 11e 11f 124
127 12c 12d 132 135 13a 13b 140
143 148 149 14e 151 155 156 15b
15e 163 164 169 16c 171 172 177
17a 17f 180 185 188 18c 18d 192
195 19a 19b 1a0 1a3 1a8 1a9 1ae
1b1 1b5 1b9 1bd 1be 1c0 1c5 1c6
1c8 1c9 1ce 1d1 1d6 1d7 1dc 1dd
1e2 1e4 1e8 1eb 1ef 1f3 1f6 1fa
1fe 201 204 209 20c 20f 212 213
218 219 1 21b 220 224 228 22b
230 235 238 23c 23d 242 243 248
24a 24e 251 255 259 25d 260 264
268 26c 270 274 278 27c 280 284
288 28c 290 294 298 29c 2a0 2a4
2a8 2b4 2b8 2bd 2c1 2c4 2c5 2ca
2ce 2d2 2d5 2d8 2dc 2de 2e2 2e6
2e9 2ec 2f0 2f2 2f6 2fa 2fd 2ff
303 307 30b 30e 312 316 318 319
31e 1 322 326 32a 32d 331 335
339 33d 340 344 348 34b 34e 353
356 359 35c 35d 362 363 1 365
36a 36e 372 375 37a 37f 382 386
387 38c 38f 394 395 39a 39d 3a2
3a3 3a8 3ab 3af 3b0 3b5 3b8 3bd
3be 3c3 3c6 3ca 3ce 3d1 3d4 3d5
3d7 3d8 3dd 3de 3e3 3e5 3e9 3ec
3ee 3f2 3f4 400 402 404 405 40a
40e 410 41c 41e 420 421 426 42a
42e 431 435 439 43d 441 445 449
44d 451 455 459 45d 461 465 469
46d 471 475 479 47d 481 48d 491
496 49a 49d 49e 4a3 4a7 4ab 4ae
4b1 4b5 4b7 4bb 4bf 4c2 4c5 4c9
4cb 4cf 4d3 4d6 4d8 4dc 4e0 4e4
4e7 4eb 4ef 4f1 4f2 4f7 1 4fb
4ff 503 506 50a 50e 512 516 519
51d 521 524 527 52c 52f 532 535
536 53b 53c 1 53e 543 547 54b
54e 553 558 55b 55f 560 565 568
56d 56e 573 576 57b 57c 581 584
588 589 58e 591 596 597 59c 59f
5a3 5a7 5aa 5ad 5ae 5b0 5b1 5b6
5b7 5bc 5be 5c2 5c5 5c7 5cb 5cd
5d9 5db 5dd 5de 5e3 5e7 5e9 5f5
5f7 5f9 5fa 5ff 603 607 60a 60e
612 616 61a 61e 622 626 62a 62e
632 636 63a 63e 642 646 64a 64e
652 65e 662 667 66b 66e 66f 674
678 67c 67f 682 686 688 68c 690
693 696 69a 69c 6a0 6a4 6a7 6a9
6ad 6b1 6b5 6b8 6bc 6c0 6c2 6c3
6c8 1 6cc 6d0 6d4 6d7 6db 6df
6e3 6e7 6ea 6ee 6f2 6f5 6f8 6fd
700 703 706 707 70c 70d 1 70f
714 718 71c 71f 724 729 72c 730
731 736 739 73e 73f 744 747 74c
74d 752 755 759 75a 75f 762 767
768 76d 770 774 778 77b 77e 77f
781 782 787 788 78d 78f 793 796
798 79c 79e 7aa 7ac 7ae 7af 7b4
7b8 7ba 7c6 7c8 7ca 7cb 7d0 7d4
7d8 7db 7df 7e3 7e7 7eb 7ef 7f3
7f7 7fb 7ff 803 807 80b 80f 813
817 81b 81f 823 82f 833 838 83c
83f 840 845 849 84d 850 853 857
859 85d 861 864 867 86b 86d 871
875 878 87a 87e 882 886 889 88d
891 893 894 899 1 89d 8a1 8a5
8a8 8ac 8b0 8b4 8b8 8bb 8bf 8c3
8c6 8c9 8ce 8d1 8d4 8d7 8d8 8dd
8de 1 8e0 8e5 8e9 8ed 8f0 8f5
8fa 8fd 901 902 907 90a 90f 910
915 918 91d 91e 923 926 92a 92b
930 933 938 939 93e 941 945 949
94c 94f 950 952 953 958 959 95e
960 964 967 969 96d 96f 97b 97d
97f 980 985 989 98b 997 999 99b
99c 9a1 9a5 9a9 9ac 9b0 9b4 9b8
9bc 9c0 9c4 9c8 9cc 9d0 9d4 9d8
9dc 9e0 9e4 9e8 9ec 9f0 9f4 a00
a04 a09 a0d a10 a11 a16 a1a a1e
a21 a24 a28 a2a a2e a32 a35 a38
a3c a3e a42 a46 a49 a4b a4f a53
a57 a5a a5e a62 a64 a65 a6a 1
a6e a72 a76 a79 a7d a81 a85 a89
a8c a90 a94 a97 a9a a9f aa2 aa5
aa8 aa9 aae aaf 1 ab1 ab6 aba
abe ac1 ac6 acb ace ad2 ad3 ad8
adb ae0 ae1 ae6 ae9 aee aef af4
af7 afb afc b01 b04 b09 b0a b0f
b12 b16 b1a b1d b20 b21 b23 b24
b29 b2a b2f b31 b35 b38 b3a b3e
b40 b4c b4e b50 b51 b56 b5a b5c
b68 b6a b6c b6d b72 b76 b7a b7d
b81 b85 b89 b8d b91 b95 b99 b9d
ba1 ba5 ba9 bad bb1 bb5 bb9 bbd
bc1 bc5 bd1 bd5 bda bde be1 be2
be7 beb bef bf2 bf5 bf9 bfb bff
c03 c06 c09 c0d c0f c13 c17 c1a
c1c c20 c24 c28 c2b c2f c33 c35
c36 c3b 1 c3f c43 c47 c4a c4e
c52 c56 c5a c5d c61 c65 c68 c6b
c70 c73 c76 c79 c7a c7f c80 1
c82 c87 c8b c8f c92 c97 c9c c9f
ca3 ca4 ca9 cac cb1 cb2 cb7 cba
cbf cc0 cc5 cc8 ccc ccd cd2 cd5
cda cdb ce0 ce3 ce7 ceb cee cf1
cf2 cf4 cf5 cfa cfb d00 d02 d06
d09 d0b d0f d11 d1d d1f d21 d22
d27 d2b d2d d39 d3b d3d d3e d43
d47 d4b d4e d52 d56 d5a d5e d62
d66 d6a d6e d72 d76 d7a d7e d82
d86 d8a d8e d92 d96 da2 da6 dab
daf db2 db3 db8 dbc dc0 dc3 dc6
dca dcc dd0 dd4 dd7 dda dde de0
de4 de8 deb ded df1 df5 df9 dfc
e00 e04 e06 e07 e0c 1 e10 e14
e18 e1b e1f e23 e27 e2b e2e e32
e36 e39 e3c e41 e44 e47 e4a e4b
e50 e51 1 e53 e58 e5c e60 e63
e68 e6d e70 e74 e75 e7a e7d e82
e83 e88 e8b e90 e91 e96 e99 e9d
e9e ea3 ea6 eab eac eb1 eb4 eb8
ebc ebf ec2 ec3 ec5 ec6 ecb ecc
ed1 ed3 ed7 eda edc ee0 ee2 eee
ef0 ef2 ef3 ef8 efc efe f0a f0c
f0e f0f f14 f18 f1c f1f f23 f27
f2b f2f f33 f37 f3b f3f f43 f47
f4b f4f f53 f57 f5b f5f f63 f67
f73 f77 f7c f80 f83 f84 f89 f8d
f91 f94 f97 f9b f9d fa1 fa5 fa8
fab faf fb1 fb5 fb9 fbc fbe fc2
fc6 fca fcd fd1 fd5 fd7 fd8 fdd
1 fe1 fe5 fe9 fec ff0 ff4 ff8
ffc fff 1003 1007 100a 100d 1012 1015
1018 101b 101c 1021 1022 1 1024 1029
102d 1031 1034 1039 103e 1041 1045 1046
104b 104e 1053 1054 1059 105c 1061 1062
1067 106a 106e 106f 1074 1077 107c 107d
1082 1085 1089 108d 1090 1093 1094 1096
1097 109c 109d 10a2 10a4 10a8 10ab 10ad
10b1 10b3 10bf 10c1 10c3 10c4 10c9 10cd
10cf 10db 10dd 10df 10e0 10e5 10e9 10ed
10f0 10f4 10f8 10fc 1100 1104 1108 110c
1110 1114 1118 111c 1120 1124 1128 112c
1130 1134 1138 1144 1148 114d 1151 1154
1155 115a 115e 1162 1165 1168 116c 116e
1172 1176 1179 117c 1180 1182 1186 118a
118d 118f 1193 1197 119b 119e 11a2 11a6
11a8 11a9 11ae 1 11b2 11b6 11ba 11bd
11c1 11c5 11c9 11cd 11d0 11d4 11d8 11db
11de 11e3 11e6 11e9 11ec 11ed 11f2 11f3
1 11f5 11fa 11fe 1202 1205 120a 120f
1212 1216 1217 121c 121f 1224 1225 122a
122d 1232 1233 1238 123b 123f 1240 1245
1248 124d 124e 1253 1256 125a 125e 1261
1264 1265 1267 1268 126d 126e 1273 1275
1279 127c 127e 1282 1284 1290 1292 1294
1295 129a 129e 12a0 12ac 12ae 12b0 12b1
12b6 12ba 12be 12c2 12c6 12ca 12ce 12d2
12d6 12da 12de 12e2 12e6 12ea 12ee 12f2
12f6 12fa 12fe 130a 130e 1313 1317 131a
131b 1320 1324 1328 132b 132e 1332 1334
1338 133c 133f 1342 1346 1348 134c 1350
1353 1355 1359 135d 1361 1364 1368 136c
136e 136f 1374 1 1378 137c 1380 1383
1387 138b 138f 1393 1396 139a 139e 13a1
13a4 13a9 13ac 13af 13b2 13b3 13b8 13b9
1 13bb 13c0 13c4 13c8 13cb 13d0 13d5
13d8 13dc 13dd 13e2 13e5 13ea 13eb 13f0
13f3 13f8 13f9 13fe 1401 1405 1406 140b
140e 1413 1414 1419 141c 1420 1424 1427
142a 142b 142d 142e 1433 1434 1439 143b
143f 1442 1444 1448 144a 1456 1458 145a
145b 1460 1464 1466 1472 1474 1476 147b
147f 1484 1488 148c 148f 1493 1497 149a
149d 14a2 14a5 14a8 14ab 14ac 14b1 14b2
1 14b4 14b9 14bd 14c1 14c4 14c9 14ce
14d1 14d5 14d6 14db 14de 14e3 14e4 14e9
14ec 14f1 14f2 14f7 14fa 14fe 1502 1505
1506 150b 150c 1511 1513 1517 151a 151e
1522 1526 1529 152d 152f 1533 1535 1541
1545 1547 1548 1551 
5fc
2
0 1 a 6 16 1a 21 :3 6
15 19 20 :3 6 1a 1e 25 :3 6
16 :2 6 1 3 a :2 1 4 :2 11
20 11 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
52 58 5b :2 52 69 7d 8 :2 69
d 10 :2 69 1d 20 :2 69 b e
:2 69 13 16 :2 69 1b 1e :2 69 2a
2d :2 69 b e :2 69 13 16 :2 69
1b 1e :2 69 2f 32 :2 69 b e
:2 69 13 16 1f 27 :2 1f 39 :2 16
:2 69 41 44 :2 69 :2 7 48 :2 4 7
:2 11 23 :2 2d 39 3c 4a 4c 4d
:2 4a :2 23 :3 7 :2 d 12 1e 5b 5e
:2 1e :2 7 50 :2 4 9 c :2 15 14
30 12 19 27 12 28 31 3f
12 19 28 2f 49 12 28 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 57 59 5a :2 57 :2 2f
:3 13 :2 19 1e 2a 67 6a :2 2a 77
7a :2 2a 7e 81 :2 2a 8d 90 :2 2a
98 9b :2 2a a7 aa b1 ba bd
:2 aa :2 2a :2 13 5d :2 10 :2 d :4 19 :2 d
a :4 22 :2 7 c :2 15 14 22 2f
41 12 19 27 12 28 31 3f
12 19 28 2f 49 12 28 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 57 59 5a :2 57 :2 2f
:3 13 :2 19 1e 2a 67 6a :2 2a 77
7a :2 2a 7e 81 :2 2a 8d 90 :2 2a
98 9b :2 2a a7 aa b1 ba bd
:2 aa :2 2a :2 13 5d :2 10 :2 d :4 19 :2 d
a :4 22 :2 7 c :2 15 14 20 12
19 27 12 28 31 3f 12 19
28 2f 49 12 28 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5e :2 10 :2 d :4 19 :2 d a :4 22
:2 7 c :2 15 14 26 12 19 27
12 28 31 3f 12 19 28 2f
49 12 28 13 20 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 57
5a 5b :2 57 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5e
:2 10 :2 d :4 19 :2 d a :4 22 :2 7 c
:2 15 14 2b 12 19 27 12 28
31 3f 12 19 28 2f 49 12
28 13 20 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 57 5a 5b
:2 57 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5e :2 10 :2 d
:4 19 :2 d a :4 26 :2 7 c :2 15 14
2f 12 19 27 12 28 31 3f
12 19 28 2f 49 12 28 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 57 5a 5b :2 57 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5e :2 10 :2 d :4 19 :2 d
a :4 26 :2 7 c :2 15 14 2c 12
19 27 12 28 31 3f 12 19
28 2f 49 12 28 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5e :2 10 :2 d :4 19 :2 d a :4 26
:2 7 c :2 15 14 2d 12 19 27
12 28 31 3f 12 19 28 2f
49 12 28 13 20 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 57
5a 5b :2 57 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5e
:2 10 :2 d :4 19 :2 d a :4 26 :2 7 c
:2 15 14 2d 12 19 27 12 28
31 3f 12 19 28 2f 49 12
28 13 20 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 57 5a 5b
:2 57 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5e :2 10 :2 d
:4 19 :2 d a :4 26 :2 7 14 20 12
19 27 12 28 31 3f 12 19
28 2f 49 12 28 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5e :2 10 :2 d :4 19 :2 d a :4 7
:3 4 7 :2 11 23 :2 2d 39 3c 4a
4d 4e :2 4a :2 23 :3 7 :2 d 12 1e
5c 5f :2 1e 6c 6f :2 1e 73 76
:2 1e 80 83 :2 8c :2 1e :2 7 51 :3 4
b :2 14 4 :9 1 
5fc
4
0 :2 1 :6 3 :6 4
:6 5 :4 6 2 :2 7
:2 1 :6 9 :b b :11 c
d :2 c :2 d :2 c
:2 d :2 c :2 e :2 c
:2 e :2 c :2 e :2 c
:2 e :2 c :2 f :2 c
:2 f :2 c :2 f :2 c
:2 f :2 c :2 10 :2 c
:9 10 :2 c :2 10 :4 c
:3 b :11 13 :b 14 :3 13
17 :3 18 :2 1a :3 1c
:4 1d :5 20 :2 21 :2 24
1a :6 25 :5 26 25
:5 28 27 :3 25 19
2b :5 2c :3 2b :2 2d
:5 2f :11 30 :24 31 :3 30
:2 2e :6 2d 2a :6 18
:3 38 :4 3a :3 3c :4 3d
:5 40 :2 41 :2 44 3a
:6 45 :5 46 45 :5 48
47 :3 45 39 4b
:5 4c :3 4b :2 4d :5 4f
:11 50 :24 51 :3 50 :2 4e
:6 4d 4a :6 38 :3 57
:2 59 :3 5b :4 5c :5 5f
:2 60 :2 63 59 :6 64
:5 65 64 :5 67 66
:3 64 58 6a :5 6b
:3 6a :2 6c :5 6e :11 6f
:24 70 :3 6f :2 6d :6 6c
69 :6 57 :3 77 :2 79
:3 7b :4 7c :5 7f :2 80
:2 83 79 :6 84 :5 85
84 :5 87 86 :3 84
78 8a :5 8b :3 8a
:2 8c :5 8e :11 8f :24 90
:3 8f :2 8d :6 8c 89
:6 77 :3 97 :2 99 :3 9b
:4 9c :5 9f :2 a0 :2 a3
99 :6 a4 :5 a5 a4
:5 a7 a6 :3 a4 98
aa :5 ab :3 aa :2 ac
:5 ae :11 af :24 b0 :3 af
:2 ad :6 ac a9 :6 97
:3 b7 :2 b9 :3 bb :4 bc
:5 bf :2 c0 :2 c3 b9
:6 c4 :5 c5 c4 :5 c7
c6 :3 c4 b8 ca
:5 cb :3 ca :2 cc :5 ce
:11 cf :24 d0 :3 cf :2 cd
:6 cc c9 :6 b7 :3 d7
:2 d9 :3 db :4 dc :5 df
:2 e0 :2 e3 d9 :6 e4
:5 e5 e4 :5 e7 e6
:3 e4 d8 ea :5 eb
:3 ea :2 ec :5 ee :11 ef
:24 f0 :3 ef :2 ed :6 ec
e9 :6 d7 :3 f7 :2 f9
:3 fb :4 fc :5 ff :2 100
:2 103 f9 :6 104 :5 105
104 :5 107 106 :3 104
f8 10a :5 10b :3 10a
:2 10c :5 10e :11 10f :24 110
:3 10f :2 10d :6 10c 109
:6 f7 :3 117 :2 119 :3 11b
:4 11c :5 11f :2 120 :2 123
119 :6 124 :5 125 124
:5 127 126 :3 124 118
12a :5 12b :3 12a :2 12c
:5 12e :11 12f :24 130 :3 12f
:2 12d :6 12c 129 :6 117
:2 139 :3 13b :4 13c :5 13f
:2 140 :2 143 139 :6 144
:5 145 144 :5 147 146
:3 144 138 14a :5 14b
:3 14a :2 14c :5 14e :11 14f
:24 150 :3 14f :2 14d :6 14c
149 :4 137 :3 17 :11 157
:19 158 :3 157 :5 15a :2 a
:7 1 
1553
4
:3 0 1 :3 0 2
:a 0 5f7 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
6 :3 0 8 :5 0
1 13 12 :3 0
10 90 0 b
a :3 0 9 :7 0
17 16 :3 0 b
:3 0 a :3 0 19
1b 0 5f7 2
1c :2 0 d :3 0
a :3 0 1f :7 0
9 :3 0 23 20
21 5f5 0 c
:6 0 e :3 0 24
25 0 d :3 0
f :3 0 27 28
0 2 :4 0 12
29 2b 26 2d
2c :2 0 10 :3 0
11 :3 0 2f 30
0 12 :4 0 d
:3 0 13 :3 0 33
34 0 2 :4 0
14 35 37 14
:4 0 15 :2 0 16
:3 0 16 3a 3c
:3 0 17 :4 0 15
:2 0 18 :4 0 19
3f 41 :3 0 15
:2 0 3 :3 0 1c
43 45 :3 0 15
:2 0 18 :4 0 1f
47 49 :3 0 15
:2 0 19 :4 0 22
4b 4d :3 0 15
:2 0 18 :4 0 25
4f 51 :3 0 15
:2 0 7 :3 0 28
53 55 :3 0 15
:2 0 18 :4 0 2b
57 59 :3 0 15
:2 0 19 :4 0 2e
5b 5d :3 0 15
:2 0 18 :4 0 31
5f 61 :3 0 15
:2 0 8 :3 0 34
63 65 :3 0 15
:2 0 18 :4 0 37
67 69 :3 0 15
:2 0 19 :4 0 3a
6b 6d :3 0 15
:2 0 1a :3 0 1b
:3 0 9 :3 0 3d
71 73 1c :4 0
3f 70 76 42
6f 78 :3 0 15
:2 0 1d :4 0 45
7a 7c :3 0 48
31 7e :2 0 80
4d 81 2e 80
0 82 4f 0
5f3 d :3 0 e
:3 0 83 84 0
d :3 0 1e :3 0
86 87 0 1f
:2 0 2 :4 0 20
:2 0 21 :2 0 1f
:2 0 51 8c 8e
:3 0 54 88 90
85 92 91 :2 0
10 :3 0 22 :3 0
94 95 0 12
:4 0 23 :4 0 15
:2 0 16 :3 0 58
99 9b :3 0 5b
96 9d :2 0 9f
5e a0 93 9f
0 a1 60 0
5f3 c :3 0 24
:3 0 25 :3 0 a3
a4 0 26 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 2c 1
:8 0 ce 2d :4 0
b9 :3 0 2e :3 0
2f :2 0 64 bc
bd :3 0 30 :3 0
31 :3 0 bf c0
0 32 :2 0 c1
c2 0 c4 67
cb 30 :3 0 31
:3 0 c5 c6 0
33 :2 0 c7 c8
0 ca 69 cc
be c4 0 cd
0 ca 0 cd
6b 0 ce 6e
121 34 :3 0 30
:3 0 31 :3 0 d0
d1 0 35 :3 0
d2 d3 0 d5
71 d7 73 d6
d5 :2 0 11f 36
:3 0 30 :3 0 31
:3 0 da db 0
35 :3 0 dc dd
0 117 d :3 0
e :3 0 df e0
0 d :3 0 1e
:3 0 e2 e3 0
37 :2 0 2 :4 0
38 :2 0 21 :2 0
1f :2 0 75 e8
ea :3 0 78 e4
ec e1 ee ed
:2 0 10 :3 0 22
:3 0 f0 f1 0
12 :4 0 39 :4 0
15 :2 0 16 :3 0
7c f5 f7 :3 0
15 :2 0 3a :4 0
7f f9 fb :3 0
15 :2 0 3b :4 0
82 fd ff :3 0
15 :2 0 35 :3 0
85 101 103 :3 0
15 :2 0 3c :4 0
88 105 107 :3 0
15 :2 0 3d :3 0
3e :3 0 1f :2 0
3f :2 0 8b 10a
10e 8f 109 110
:3 0 92 f2 112
:2 0 114 95 115
ef 114 0 116
97 0 117 99
11a :3 0 11a 0
11a 119 117 118
:6 0 11c 2 :3 0
9c 11e 9e 11d
11c :2 0 11f a0
:2 0 121 0 121
120 ce 11f :6 0
123 1 :3 0 a3
125 a5 124 123
:2 0 5bf 24 :3 0
40 :3 0 126 127
0 41 :3 0 42
:3 0 8 :3 0 27
:3 0 28 :3 0 27
:3 0 7 :3 0 7
:3 0 29 :3 0 27
:3 0 7 :3 0 2a
:3 0 7 :3 0 2a
:3 0 27 :3 0 27
:3 0 7 :3 0 27
:3 0 2b :3 0 3
:4 0 43 1 :8 0
153 2d :4 0 13e
:3 0 2e :3 0 2f
:2 0 a9 141 142
:3 0 30 :3 0 31
:3 0 144 145 0
32 :2 0 146 147
0 149 ac 150
30 :3 0 31 :3 0
14a 14b 0 33
:2 0 14c 14d 0
14f ae 151 143
149 0 152 0
14f 0 152 b0
0 153 b3 1a6
34 :3 0 30 :3 0
31 :3 0 155 156
0 35 :3 0 157
158 0 15a b6
15c b8 15b 15a
:2 0 1a4 36 :3 0
30 :3 0 31 :3 0
15f 160 0 35
:3 0 161 162 0
19c d :3 0 e
:3 0 164 165 0
d :3 0 1e :3 0
167 168 0 37
:2 0 2 :4 0 44
:2 0 21 :2 0 1f
:2 0 ba 16d 16f
:3 0 bd 169 171
166 173 172 :2 0
10 :3 0 22 :3 0
175 176 0 12
:4 0 45 :4 0 15
:2 0 16 :3 0 c1
17a 17c :3 0 15
:2 0 3a :4 0 c4
17e 180 :3 0 15
:2 0 3b :4 0 c7
182 184 :3 0 15
:2 0 35 :3 0 ca
186 188 :3 0 15
:2 0 3c :4 0 cd
18a 18c :3 0 15
:2 0 3d :3 0 3e
:3 0 1f :2 0 3f
:2 0 d0 18f 193
d4 18e 195 :3 0
d7 177 197 :2 0
199 da 19a 174
199 0 19b dc
0 19c de 19f
:3 0 19f 0 19f
19e 19c 19d :6 0
1a1 4 :3 0 e1
1a3 e3 1a2 1a1
:2 0 1a4 e5 :2 0
1a6 0 1a6 1a5
153 1a4 :6 0 1a8
1 :3 0 e8 1aa
ea 1a9 1a8 :2 0
5bf 24 :3 0 46
:3 0 1ab 1ac 0
47 :3 0 27 :3 0
28 :3 0 27 :3 0
7 :3 0 7 :3 0
29 :3 0 27 :3 0
7 :3 0 2a :3 0
7 :3 0 2a :3 0
27 :3 0 27 :3 0
7 :3 0 27 :3 0
2b :3 0 3 :4 0
48 1 :8 0 1d6
2d :4 0 1c1 :3 0
2e :3 0 2f :2 0
ee 1c4 1c5 :3 0
30 :3 0 31 :3 0
1c7 1c8 0 32
:2 0 1c9 1ca 0
1cc f1 1d3 30
:3 0 31 :3 0 1cd
1ce 0 33 :2 0
1cf 1d0 0 1d2
f3 1d4 1c6 1cc
0 1d5 0 1d2
0 1d5 f5 0
1d6 f8 229 34
:3 0 30 :3 0 31
:3 0 1d8 1d9 0
35 :3 0 1da 1db
0 1dd fb 1df
fd 1de 1dd :2 0
227 36 :3 0 30
:3 0 31 :3 0 1e2
1e3 0 35 :3 0
1e4 1e5 0 21f
d :3 0 e :3 0
1e7 1e8 0 d
:3 0 1e :3 0 1ea
1eb 0 37 :2 0
2 :4 0 49 :2 0
21 :2 0 1f :2 0
ff 1f0 1f2 :3 0
102 1ec 1f4 1e9
1f6 1f5 :2 0 10
:3 0 22 :3 0 1f8
1f9 0 12 :4 0
4a :4 0 15 :2 0
16 :3 0 106 1fd
1ff :3 0 15 :2 0
3a :4 0 109 201
203 :3 0 15 :2 0
3b :4 0 10c 205
207 :3 0 15 :2 0
35 :3 0 10f 209
20b :3 0 15 :2 0
3c :4 0 112 20d
20f :3 0 15 :2 0
3d :3 0 3e :3 0
1f :2 0 3f :2 0
115 212 216 119
211 218 :3 0 11c
1fa 21a :2 0 21c
11f 21d 1f7 21c
0 21e 121 0
21f 123 222 :3 0
222 0 222 221
21f 220 :6 0 224
6 :3 0 126 226
128 225 224 :2 0
227 12a :2 0 229
0 229 228 1d6
227 :6 0 22b 1
:3 0 12d 22d 12f
22c 22b :2 0 5bf
24 :3 0 4b :3 0
22e 22f 0 4c
:3 0 27 :3 0 28
:3 0 27 :3 0 7
:3 0 7 :3 0 29
:3 0 27 :3 0 7
:3 0 2a :3 0 7
:3 0 2a :3 0 27
:3 0 27 :3 0 7
:3 0 27 :3 0 2b
:3 0 3 :4 0 4d
1 :8 0 259 2d
:4 0 244 :3 0 2e
:3 0 2f :2 0 133
247 248 :3 0 30
:3 0 31 :3 0 24a
24b 0 32 :2 0
24c 24d 0 24f
136 256 30 :3 0
31 :3 0 250 251
0 33 :2 0 252
253 0 255 138
257 249 24f 0
258 0 255 0
258 13a 0 259
13d 2ac 34 :3 0
30 :3 0 31 :3 0
25b 25c 0 35
:3 0 25d 25e 0
260 140 262 142
261 260 :2 0 2aa
36 :3 0 30 :3 0
31 :3 0 265 266
0 35 :3 0 267
268 0 2a2 d
:3 0 e :3 0 26a
26b 0 d :3 0
1e :3 0 26d 26e
0 37 :2 0 2
:4 0 4e :2 0 21
:2 0 1f :2 0 144
273 275 :3 0 147
26f 277 26c 279
278 :2 0 10 :3 0
22 :3 0 27b 27c
0 12 :4 0 4f
:4 0 15 :2 0 16
:3 0 14b 280 282
:3 0 15 :2 0 3a
:4 0 14e 284 286
:3 0 15 :2 0 3b
:4 0 151 288 28a
:3 0 15 :2 0 35
:3 0 154 28c 28e
:3 0 15 :2 0 3c
:4 0 157 290 292
:3 0 15 :2 0 3d
:3 0 3e :3 0 1f
:2 0 3f :2 0 15a
295 299 15e 294
29b :3 0 161 27d
29d :2 0 29f 164
2a0 27a 29f 0
2a1 166 0 2a2
168 2a5 :3 0 2a5
0 2a5 2a4 2a2
2a3 :6 0 2a7 8
:3 0 16b 2a9 16d
2a8 2a7 :2 0 2aa
16f :2 0 2ac 0
2ac 2ab 259 2aa
:6 0 2ae 1 :3 0
172 2b0 174 2af
2ae :2 0 5bf 24
:3 0 50 :3 0 2b1
2b2 0 51 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 52 1
:8 0 2dc 2d :4 0
2c7 :3 0 2e :3 0
2f :2 0 178 2ca
2cb :3 0 30 :3 0
31 :3 0 2cd 2ce
0 32 :2 0 2cf
2d0 0 2d2 17b
2d9 30 :3 0 31
:3 0 2d3 2d4 0
33 :2 0 2d5 2d6
0 2d8 17d 2da
2cc 2d2 0 2db
0 2d8 0 2db
17f 0 2dc 182
32f 34 :3 0 30
:3 0 31 :3 0 2de
2df 0 35 :3 0
2e0 2e1 0 2e3
185 2e5 187 2e4
2e3 :2 0 32d 36
:3 0 30 :3 0 31
:3 0 2e8 2e9 0
35 :3 0 2ea 2eb
0 325 d :3 0
e :3 0 2ed 2ee
0 d :3 0 1e
:3 0 2f0 2f1 0
37 :2 0 2 :4 0
53 :2 0 21 :2 0
1f :2 0 189 2f6
2f8 :3 0 18c 2f2
2fa 2ef 2fc 2fb
:2 0 10 :3 0 22
:3 0 2fe 2ff 0
12 :4 0 54 :4 0
15 :2 0 16 :3 0
190 303 305 :3 0
15 :2 0 3a :4 0
193 307 309 :3 0
15 :2 0 3b :4 0
196 30b 30d :3 0
15 :2 0 35 :3 0
199 30f 311 :3 0
15 :2 0 3c :4 0
19c 313 315 :3 0
15 :2 0 3d :3 0
3e :3 0 1f :2 0
3f :2 0 19f 318
31c 1a3 317 31e
:3 0 1a6 300 320
:2 0 322 1a9 323
2fd 322 0 324
1ab 0 325 1ad
328 :3 0 328 0
328 327 325 326
:6 0 32a a :3 0
1b0 32c 1b2 32b
32a :2 0 32d 1b4
:2 0 32f 0 32f
32e 2dc 32d :6 0
331 1 :3 0 1b7
333 1b9 332 331
:2 0 5bf 24 :3 0
55 :3 0 334 335
0 56 :3 0 27
:3 0 28 :3 0 27
:3 0 7 :3 0 7
:3 0 29 :3 0 27
:3 0 7 :3 0 2a
:3 0 7 :3 0 2a
:3 0 27 :3 0 27
:3 0 7 :3 0 27
:3 0 2b :3 0 3
:4 0 57 1 :8 0
35f 2d :4 0 34a
:3 0 2e :3 0 2f
:2 0 1bd 34d 34e
:3 0 30 :3 0 31
:3 0 350 351 0
32 :2 0 352 353
0 355 1c0 35c
30 :3 0 31 :3 0
356 357 0 33
:2 0 358 359 0
35b 1c2 35d 34f
355 0 35e 0
35b 0 35e 1c4
0 35f 1c7 3b2
34 :3 0 30 :3 0
31 :3 0 361 362
0 35 :3 0 363
364 0 366 1ca
368 1cc 367 366
:2 0 3b0 36 :3 0
30 :3 0 31 :3 0
36b 36c 0 35
:3 0 36d 36e 0
3a8 d :3 0 e
:3 0 370 371 0
d :3 0 1e :3 0
373 374 0 37
:2 0 2 :4 0 58
:2 0 21 :2 0 1f
:2 0 1ce 379 37b
:3 0 1d1 375 37d
372 37f 37e :2 0
10 :3 0 22 :3 0
381 382 0 12
:4 0 59 :4 0 15
:2 0 16 :3 0 1d5
386 388 :3 0 15
:2 0 3a :4 0 1d8
38a 38c :3 0 15
:2 0 3b :4 0 1db
38e 390 :3 0 15
:2 0 35 :3 0 1de
392 394 :3 0 15
:2 0 3c :4 0 1e1
396 398 :3 0 15
:2 0 3d :3 0 3e
:3 0 1f :2 0 3f
:2 0 1e4 39b 39f
1e8 39a 3a1 :3 0
1eb 383 3a3 :2 0
3a5 1ee 3a6 380
3a5 0 3a7 1f0
0 3a8 1f2 3ab
:3 0 3ab 0 3ab
3aa 3a8 3a9 :6 0
3ad c :3 0 1f5
3af 1f7 3ae 3ad
:2 0 3b0 1f9 :2 0
3b2 0 3b2 3b1
35f 3b0 :6 0 3b4
1 :3 0 1fc 3b6
1fe 3b5 3b4 :2 0
5bf 24 :3 0 5a
:3 0 3b7 3b8 0
5b :3 0 27 :3 0
28 :3 0 27 :3 0
7 :3 0 7 :3 0
29 :3 0 27 :3 0
7 :3 0 2a :3 0
7 :3 0 2a :3 0
27 :3 0 27 :3 0
7 :3 0 27 :3 0
2b :3 0 3 :4 0
5c 1 :8 0 3e2
2d :4 0 3cd :3 0
2e :3 0 2f :2 0
202 3d0 3d1 :3 0
30 :3 0 31 :3 0
3d3 3d4 0 32
:2 0 3d5 3d6 0
3d8 205 3df 30
:3 0 31 :3 0 3d9
3da 0 33 :2 0
3db 3dc 0 3de
207 3e0 3d2 3d8
0 3e1 0 3de
0 3e1 209 0
3e2 20c 435 34
:3 0 30 :3 0 31
:3 0 3e4 3e5 0
35 :3 0 3e6 3e7
0 3e9 20f 3eb
211 3ea 3e9 :2 0
433 36 :3 0 30
:3 0 31 :3 0 3ee
3ef 0 35 :3 0
3f0 3f1 0 42b
d :3 0 e :3 0
3f3 3f4 0 d
:3 0 1e :3 0 3f6
3f7 0 37 :2 0
2 :4 0 5d :2 0
21 :2 0 1f :2 0
213 3fc 3fe :3 0
216 3f8 400 3f5
402 401 :2 0 10
:3 0 22 :3 0 404
405 0 12 :4 0
5e :4 0 15 :2 0
16 :3 0 21a 409
40b :3 0 15 :2 0
3a :4 0 21d 40d
40f :3 0 15 :2 0
3b :4 0 220 411
413 :3 0 15 :2 0
35 :3 0 223 415
417 :3 0 15 :2 0
3c :4 0 226 419
41b :3 0 15 :2 0
3d :3 0 3e :3 0
1f :2 0 3f :2 0
229 41e 422 22d
41d 424 :3 0 230
406 426 :2 0 428
233 429 403 428
0 42a 235 0
42b 237 42e :3 0
42e 0 42e 42d
42b 42c :6 0 430
e :3 0 23a 432
23c 431 430 :2 0
433 23e :2 0 435
0 435 434 3e2
433 :6 0 437 1
:3 0 241 439 243
438 437 :2 0 5bf
24 :3 0 5f :3 0
43a 43b 0 60
:3 0 27 :3 0 28
:3 0 27 :3 0 7
:3 0 7 :3 0 29
:3 0 27 :3 0 7
:3 0 2a :3 0 7
:3 0 2a :3 0 27
:3 0 27 :3 0 7
:3 0 27 :3 0 2b
:3 0 3 :4 0 61
1 :8 0 465 2d
:4 0 450 :3 0 2e
:3 0 2f :2 0 247
453 454 :3 0 30
:3 0 31 :3 0 456
457 0 32 :2 0
458 459 0 45b
24a 462 30 :3 0
31 :3 0 45c 45d
0 33 :2 0 45e
45f 0 461 24c
463 455 45b 0
464 0 461 0
464 24e 0 465
251 4b8 34 :3 0
30 :3 0 31 :3 0
467 468 0 35
:3 0 469 46a 0
46c 254 46e 256
46d 46c :2 0 4b6
36 :3 0 30 :3 0
31 :3 0 471 472
0 35 :3 0 473
474 0 4ae d
:3 0 e :3 0 476
477 0 d :3 0
1e :3 0 479 47a
0 37 :2 0 2
:4 0 62 :2 0 21
:2 0 1f :2 0 258
47f 481 :3 0 25b
47b 483 478 485
484 :2 0 10 :3 0
22 :3 0 487 488
0 12 :4 0 63
:4 0 15 :2 0 16
:3 0 25f 48c 48e
:3 0 15 :2 0 3a
:4 0 262 490 492
:3 0 15 :2 0 3b
:4 0 265 494 496
:3 0 15 :2 0 35
:3 0 268 498 49a
:3 0 15 :2 0 3c
:4 0 26b 49c 49e
:3 0 15 :2 0 3d
:3 0 3e :3 0 1f
:2 0 3f :2 0 26e
4a1 4a5 272 4a0
4a7 :3 0 275 489
4a9 :2 0 4ab 278
4ac 486 4ab 0
4ad 27a 0 4ae
27c 4b1 :3 0 4b1
0 4b1 4b0 4ae
4af :6 0 4b3 10
:3 0 27f 4b5 281
4b4 4b3 :2 0 4b6
283 :2 0 4b8 0
4b8 4b7 465 4b6
:6 0 4ba 1 :3 0
286 4bc 288 4bb
4ba :2 0 5bf 24
:3 0 64 :3 0 4bd
4be 0 65 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 66 1
:8 0 4e8 2d :4 0
4d3 :3 0 2e :3 0
2f :2 0 28c 4d6
4d7 :3 0 30 :3 0
31 :3 0 4d9 4da
0 32 :2 0 4db
4dc 0 4de 28f
4e5 30 :3 0 31
:3 0 4df 4e0 0
33 :2 0 4e1 4e2
0 4e4 291 4e6
4d8 4de 0 4e7
0 4e4 0 4e7
293 0 4e8 296
53b 34 :3 0 30
:3 0 31 :3 0 4ea
4eb 0 35 :3 0
4ec 4ed 0 4ef
299 4f1 29b 4f0
4ef :2 0 539 36
:3 0 30 :3 0 31
:3 0 4f4 4f5 0
35 :3 0 4f6 4f7
0 531 d :3 0
e :3 0 4f9 4fa
0 d :3 0 1e
:3 0 4fc 4fd 0
37 :2 0 2 :4 0
67 :2 0 21 :2 0
1f :2 0 29d 502
504 :3 0 2a0 4fe
506 4fb 508 507
:2 0 10 :3 0 22
:3 0 50a 50b 0
12 :4 0 68 :4 0
15 :2 0 16 :3 0
2a4 50f 511 :3 0
15 :2 0 3a :4 0
2a7 513 515 :3 0
15 :2 0 3b :4 0
2aa 517 519 :3 0
15 :2 0 35 :3 0
2ad 51b 51d :3 0
15 :2 0 3c :4 0
2b0 51f 521 :3 0
15 :2 0 3d :3 0
3e :3 0 1f :2 0
3f :2 0 2b3 524
528 2b7 523 52a
:3 0 2ba 50c 52c
:2 0 52e 2bd 52f
509 52e 0 530
2bf 0 531 2c1
534 :3 0 534 0
534 533 531 532
:6 0 536 12 :3 0
2c4 538 2c6 537
536 :2 0 539 2c8
:2 0 53b 0 53b
53a 4e8 539 :6 0
53d 1 :3 0 2cb
53f 2cd 53e 53d
:2 0 5bf 69 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 6a 1
:8 0 568 2d :4 0
553 :3 0 2e :3 0
2f :2 0 2d1 556
557 :3 0 30 :3 0
31 :3 0 559 55a
0 32 :2 0 55b
55c 0 55e 2d4
565 30 :3 0 31
:3 0 55f 560 0
33 :2 0 561 562
0 564 2d6 566
558 55e 0 567
0 564 0 567
2d8 0 568 2db
5bb 34 :3 0 30
:3 0 31 :3 0 56a
56b 0 35 :3 0
56c 56d 0 56f
2de 571 2e0 570
56f :2 0 5b9 36
:3 0 30 :3 0 31
:3 0 574 575 0
35 :3 0 576 577
0 5b1 d :3 0
e :3 0 579 57a
0 d :3 0 1e
:3 0 57c 57d 0
37 :2 0 2 :4 0
6b :2 0 21 :2 0
1f :2 0 2e2 582
584 :3 0 2e5 57e
586 57b 588 587
:2 0 10 :3 0 22
:3 0 58a 58b 0
12 :4 0 6c :4 0
15 :2 0 16 :3 0
2e9 58f 591 :3 0
15 :2 0 3a :4 0
2ec 593 595 :3 0
15 :2 0 3b :4 0
2ef 597 599 :3 0
15 :2 0 35 :3 0
2f2 59b 59d :3 0
15 :2 0 3c :4 0
2f5 59f 5a1 :3 0
15 :2 0 3d :3 0
3e :3 0 1f :2 0
3f :2 0 2f8 5a4
5a8 2fc 5a3 5aa
:3 0 2ff 58c 5ac
:2 0 5ae 302 5af
589 5ae 0 5b0
304 0 5b1 306
5b4 :3 0 5b4 0
5b4 5b3 5b1 5b2
:6 0 5b6 14 :3 0
309 5b8 30b 5b7
5b6 :2 0 5b9 30d
:2 0 5bb 0 5bb
5ba 568 5b9 :6 0
5bd 1 :3 0 310
5be 0 5bd :2 0
5bf 312 :2 0 5c0
a2 5bf 0 5f3
0 d :3 0 e
:3 0 5c1 5c2 0
d :3 0 1e :3 0
5c4 5c5 0 1f
:2 0 2 :4 0 6d
:2 0 21 :2 0 1f
:2 0 31d 5ca 5cc
:3 0 320 5c6 5ce
5c3 5d0 5cf :2 0
10 :3 0 22 :3 0
5d2 5d3 0 12
:4 0 6e :4 0 15
:2 0 16 :3 0 324
5d7 5d9 :3 0 15
:2 0 3a :4 0 327
5db 5dd :3 0 15
:2 0 6f :4 0 32a
5df 5e1 :3 0 15
:2 0 30 :3 0 31
:3 0 5e4 5e5 0
32d 5e3 5e7 :3 0
330 5d4 5e9 :2 0
5eb 333 5ec 5d1
5eb 0 5ed 335
0 5f3 b :3 0
30 :3 0 31 :3 0
5ef 5f0 0 5f1
:2 0 5f3 337 5f6
:3 0 5f6 33d 5f6
5f5 5f3 5f4 :6 0
5f7 :2 0 2 1c
5f6 5fa :3 0 5f9
5f7 5fb :8 0 
33f
4
:3 0 1 3 1
9 1 f 1
15 4 8 e
14 18 1 1e
1 2a 1 36
2 39 3b 2
3e 40 2 42
44 2 46 48
2 4a 4c 2
4e 50 2 52
54 2 56 58
2 5a 5c 2
5e 60 2 62
64 2 66 68
2 6a 6c 1
72 2 74 75
2 6e 77 2
79 7b 4 32
38 3d 7d 1
7f 1 81 2
8b 8d 3 89
8a 8f 2 98
9a 2 97 9c
1 9e 1 a0
1 bb 2 ba
bb 1 c3 1
c9 2 cb cc
2 b8 cd 1
d4 1 cf 2
e7 e9 3 e5
e6 eb 2 f4
f6 2 f8 fa
2 fc fe 2
100 102 2 104
106 3 10b 10c
10d 2 108 10f
2 f3 111 1
113 1 115 2
de 116 1 11a
1 d9 2 d7
11e 1 121 1
a5 1 140 2
13f 140 1 148
1 14e 2 150
151 2 13d 152
1 159 1 154
2 16c 16e 3
16a 16b 170 2
179 17b 2 17d
17f 2 181 183
2 185 187 2
189 18b 3 190
191 192 2 18d
194 2 178 196
1 198 1 19a
2 163 19b 1
19f 1 15e 2
15c 1a3 1 1a6
1 128 1 1c3
2 1c2 1c3 1
1cb 1 1d1 2
1d3 1d4 2 1c0
1d5 1 1dc 1
1d7 2 1ef 1f1
3 1ed 1ee 1f3
2 1fc 1fe 2
200 202 2 204
206 2 208 20a
2 20c 20e 3
213 214 215 2
210 217 2 1fb
219 1 21b 1
21d 2 1e6 21e
1 222 1 1e1
2 1df 226 1
229 1 1ad 1
246 2 245 246
1 24e 1 254
2 256 257 2
243 258 1 25f
1 25a 2 272
274 3 270 271
276 2 27f 281
2 283 285 2
287 289 2 28b
28d 2 28f 291
3 296 297 298
2 293 29a 2
27e 29c 1 29e
1 2a0 2 269
2a1 1 2a5 1
264 2 262 2a9
1 2ac 1 230
1 2c9 2 2c8
2c9 1 2d1 1
2d7 2 2d9 2da
2 2c6 2db 1
2e2 1 2dd 2
2f5 2f7 3 2f3
2f4 2f9 2 302
304 2 306 308
2 30a 30c 2
30e 310 2 312
314 3 319 31a
31b 2 316 31d
2 301 31f 1
321 1 323 2
2ec 324 1 328
1 2e7 2 2e5
32c 1 32f 1
2b3 1 34c 2
34b 34c 1 354
1 35a 2 35c
35d 2 349 35e
1 365 1 360
2 378 37a 3
376 377 37c 2
385 387 2 389
38b 2 38d 38f
2 391 393 2
395 397 3 39c
39d 39e 2 399
3a0 2 384 3a2
1 3a4 1 3a6
2 36f 3a7 1
3ab 1 36a 2
368 3af 1 3b2
1 336 1 3cf
2 3ce 3cf 1
3d7 1 3dd 2
3df 3e0 2 3cc
3e1 1 3e8 1
3e3 2 3fb 3fd
3 3f9 3fa 3ff
2 408 40a 2
40c 40e 2 410
412 2 414 416
2 418 41a 3
41f 420 421 2
41c 423 2 407
425 1 427 1
429 2 3f2 42a
1 42e 1 3ed
2 3eb 432 1
435 1 3b9 1
452 2 451 452
1 45a 1 460
2 462 463 2
44f 464 1 46b
1 466 2 47e
480 3 47c 47d
482 2 48b 48d
2 48f 491 2
493 495 2 497
499 2 49b 49d
3 4a2 4a3 4a4
2 49f 4a6 2
48a 4a8 1 4aa
1 4ac 2 475
4ad 1 4b1 1
470 2 46e 4b5
1 4b8 1 43c
1 4d5 2 4d4
4d5 1 4dd 1
4e3 2 4e5 4e6
2 4d2 4e7 1
4ee 1 4e9 2
501 503 3 4ff
500 505 2 50e
510 2 512 514
2 516 518 2
51a 51c 2 51e
520 3 525 526
527 2 522 529
2 50d 52b 1
52d 1 52f 2
4f8 530 1 534
1 4f3 2 4f1
538 1 53b 1
4bf 1 555 2
554 555 1 55d
1 563 2 565
566 2 552 567
1 56e 1 569
2 581 583 3
57f 580 585 2
58e 590 2 592
594 2 596 598
2 59a 59c 2
59e 5a0 3 5a5
5a6 5a7 2 5a2
5a9 2 58d 5ab
1 5ad 1 5af
2 578 5b0 1
5b4 1 573 2
571 5b8 1 5bb
a 125 1aa 22d
2b0 333 3b6 439
4bc 53f 5be 2
5c9 5cb 3 5c7
5c8 5cd 2 5d6
5d8 2 5da 5dc
2 5de 5e0 2
5e2 5e6 2 5d5
5e8 1 5ea 1
5ec 5 82 a1
5c0 5ed 5f2 1
22 
1
4
0 
5fa
0
1
28
15
6
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

2 0 1
f 1 0
3 1 0
1e 1 0
9 1 0
15 1 0
0

/
SHOW ERRORS FUNCTION FC_U_NAMES;
ALTER FUNCTION FC_U_NAMES COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_WP_DATES ==
CREATE OR REPLACE FUNCTION SP_U_WP_DATES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
f0
2 :e:
1FUNCTION:
1SP_U_WP_DATES:
1ASSIGN_ID:
1VARCHAR2:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_PROJECT_ID:
1H_ACTUAL_START:
1H_START_DATE:
1H_FINISH_DATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_SD:
1DATE:
1H_FD:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_BILLABLE:
1PLS_INTEGER:
10:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DAYOFYEAR:
1H_LAST_SUBMITTED:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_TRANSFED_CRI:
1H_TASK_ID:
1H_RES_ID:
1H_REC_USER:
1H_EFFORT:
1H_CONTOUR:
1H_DELAY:
1H_PERCENT_UNITS:
1H_WORK_PERCENT:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_WORK:
1H_SKIP:
1H_LAST_DAY:
1H_MINUTES:
1H_PER_DAY:
1H_WORK_TYPE:
1H_ASSIGN_COUNT:
1H_DURATION:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_SCHED_EFFORT:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_DATES(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1);:
1CHECK_TRACE:
174:
1+:
1FPUT:
1               ENTER:: SP_U_WP_DATES(75) :: cplan.sql(15146) :: :
1PROJECT_ASSIGNMENT_ID:
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1LAST_SUBMITTED:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1UNITS_MSP:
1ACTUAL_START:
1WORK_TODATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1ASSIGNMENT_DELAY:
1LAST_SCHED_MIN:
1TO_DATE:
1SUBSTR:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ASSIGNMENT_ID, PROJECT_ID, RESOURCE_ID,:n      RESOURCE_TYPE, +
1BIT_FLAG, LAST_SUBMITTED, C_CONTOUR, C_EFFORT, T_UNIT, C_UNIT,:n      UNITS_M+
1SP, ACTUAL_START, WORK_TODATE, UNRESOLVED_START, UNRESOLVED_FINISH,:n      CA+
1SE WHEN BIT_FLAG = '0' THEN PLANNED_WORK ELSE SCHED_WORK END, ASSIGNMENT_DELA+
1Y, LAST_SCHED_MIN,:n      TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n      REGULAR_C+
1OST, SPECIAL_COST, REGULAR_RATE, SPECIAL_RATE,:n      B_REGULAR_COST, B_SPECI+
1AL_COST, B_REGULAR_RATE, B_SPECIAL_RATE,:n      MILESTONE_PERCENT, TASK_ID:n +
1     INTO h_prj_assign_id, h_project_id, h_res_id,:n      h_res_type, h_bit_f+
1lag, h_last_submitted, h_contour, h_work, h_eunit, h_unit,:n      h_percent_u+
1nits, h_actual_start, h_work_todate, h_start_date, h_finish_date,:n      h_ef+
1fort, h_delay, h_last_day,:n      h_SD, h_FD, h_billable, h_capital_expense,+
1:n      h_reg_cost, h_spec_cost, h_reg_sale, h_spec_sale,:n      h_b_reg_cost+
1, h_b_spec_cost, h_b_reg_sale, h_b_spec_sale,:n      h_work_percent, h_task_i+
1d:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID = h_tsk_assignm+
1ent_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1110:
1           EXCEPTION:: SP_U_WP_DATES(111) :: cplan.sql(15182) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1118:
1        RETURN_ERROR:: SP_U_WP_DATES(119) :: cplan.sql(15190) :: :
1STATE:: :
1TO_CHAR:
1PMO_CNST:
1RECORD_NOT_FOUND:
1 ID:: :
1121:
1                EXIT:: SP_U_WP_DATES(122) :: cplan.sql(15193) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1>:
1!=:
1134:
1        RETURN_ERROR:: SP_U_WP_DATES(135) :: cplan.sql(15206) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1137:
1                EXIT:: SP_U_WP_DATES(138) :: cplan.sql(15209) :: :
1MINUTE_PER_DAY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, MINUTE_PER_DAY:n         INTO h_project_id, h_per_day:n   +
1      FROM TMT_WBS WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1155:
1           EXCEPTION:: SP_U_WP_DATES(156) :: cplan.sql(15227) :: :
18:
1167:
1      RETURN_INVALID:: SP_U_WP_DATES(168) :: cplan.sql(15239) :: :
1INVALID_PARAMS:
1170:
1                EXIT:: SP_U_WP_DATES(171) :: cplan.sql(15242) :: :
1PMO_RETURN_INVALID_SP:
1-:
1FC_TPHASE_SCHED_ASSIGN:
1FC_U_TDY_LAST_ACTUAL:
1FC_DEL_NOACTUAL:
12:
1DB2TIMESTAMP:
1TIME:
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n         INTO h_start_date:n         FRO+
1M DUAL:
1211:
1           EXCEPTION:: SP_U_WP_DATES(212) :: cplan.sql(15283) :: :
1FC_RESCHEDULE:
1228:
1        RETURN_ERROR:: SP_U_WP_DATES(229) :: cplan.sql(15300) :: :
1TASK_ASSIGNMENT_ERROR:
1231:
1                EXIT:: SP_U_WP_DATES(232) :: cplan.sql(15303) :: :
1BAK_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n              BAK_ASSIGN_STRING = NULL:n        +
1 WHERE TSK_ASSIGNMENT_ID = H_TSK_ASSIGNMENT_ID:
1CONSIDER:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_SCHED_BIT:
1SC_PLANNED_BIT:
1BAK_START_DT:
1SCHED_START:
1PLANNED_START:
1BAK_FINISH_DT:
1SCHED_FINISH:
1PLANNED_FINISH:
1ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,(pmo_cnst.SC_SCHED_BIT+pmo_cnst.SC_PLANNED_BIT)),:n         BAK_START_+
1DT = COALESCE(SCHED_START,PLANNED_START), BAK_FINISH_DT = COALESCE(SCHED_FINI+
1SH,PLANNED_FINISH),:n         BAK_ASSIGN_STRING = ASSIGN_STRING:n         WHE+
1RE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1FOUND:
1100:
1257:
1           EXCEPTION:: SP_U_WP_DATES(258) :: cplan.sql(15329) :: :
1FC_ROLLUP:
1265:
1        RETURN_ERROR:: SP_U_WP_DATES(266) :: cplan.sql(15337) :: :
1268:
1                EXIT:: SP_U_WP_DATES(269) :: cplan.sql(15340) :: :
14:
1274:
1       RETURN_STATUS:: SP_U_WP_DATES(275) :: cplan.sql(15346) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1281:
1           EXCEPTION:: SP_U_WP_DATES(282) :: cplan.sql(15353) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1293:
1           EXCEPTION:: SP_U_WP_DATES(294) :: cplan.sql(15365) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
7f4
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6e 7e a0 b4 2e 7e
6e b4 2e 6e a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 6e a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:2 a0 d :49 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c a0
7e b4 2e 5a a0 7e b4 2e
5a a 10 :2 a0 d :2 a0 d :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d a0
51 d b7 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 :2 19 3c b7 19 3c
a0 7e 51 b4 2e d :c a0 a5
b d :2 a0 51 a5 b 7e 51
b4 2e 5a a0 7e b4 2e :2 5a
a 10 :9 a0 51 a5 b d b7
19 3c a0 7e b4 2e 5a :4 a0
51 a5 b d b7 :2 a0 :2 51 a5
b 7e 6e b4 2e :4 a0 51 a5
b d b7 :4 a0 51 a5 b d
b7 :2 19 3c b7 :2 19 3c a0 7e
b4 2e 5a :a a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d b7 19 3c a0 51 d :a a0
51 a5 b :2 a0 51 a5 b a5
b d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :4 a0 12a :16 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :3 a0
a5 b d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
:2 a0 a5 57 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
7f4
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ee
dd e1 e9 bc 106 f5 f9 101
dc 122 111 115 11d d9 13a 129
12d 135 110 156 145 149 151 10d
16e 15d 161 169 144 18a 179 17d
185 141 1a6 191 195 198 199 1a1
178 1c3 1b1 175 1b5 1b6 1be 1b0
1df 1ce 1d2 1ad 1da 1cd 1fb 1ea
1ee 1ca 1f6 1e9 217 206 20a 1e6
212 205 233 222 226 22e 202 24b
23a 23e 246 221 267 256 25a 21e
262 255 283 272 276 252 27e 271
29f 28e 292 26e 29a 28d 2bb 2aa
2ae 28a 2b6 2a9 2d8 2c6 2a6 2ca
2cb 2d3 2c5 2f5 2e3 2c2 2e7 2e8
2f0 2e2 312 300 2df 304 305 30d
2ff 32e 31d 321 2fc 329 31c 34a
339 33d 319 345 338 366 355 359
335 361 354 382 371 375 351 37d
370 39e 38d 391 36d 399 38c 3ba
3a9 3ad 389 3b5 3a8 3d6 3c5 3c9
3a5 3d1 3c4 3f2 3e1 3e5 3c1 3ed
3e0 40e 3fd 401 3dd 409 3fc 42a
419 41d 3f9 425 418 446 435 439
415 441 434 462 451 455 431 45d
450 47e 46d 471 44d 479 46c 49a
489 48d 469 495 488 4b6 4a5 4a9
485 4b1 4a4 4d2 4c1 4c5 4a1 4cd
4c0 4ee 4dd 4e1 4bd 4e9 4dc 50a
4f9 4fd 4d9 505 4f8 526 515 519
4f5 521 514 542 531 535 511 53d
530 55e 54d 551 52d 559 54c 57a
569 56d 549 575 568 596 585 589
565 591 584 5b2 5a1 5a5 581 5ad
5a0 5ce 5bd 5c1 59d 5c9 5bc 5ea
5d9 5dd 5b9 5e5 5d8 606 5f5 5f9
5d5 601 5f4 622 611 615 5f1 61d
610 63e 62d 631 60d 639 62c 65a
649 64d 629 655 648 67a 665 669
645 66d 675 664 681 685 661 689
68d 691 694 699 69a 1 69c 6a1
6a5 6a9 6ac 6b1 6b5 6b9 6bc 6c1
6c2 6c4 6c9 6cc 6d0 6d1 6d6 6db
6de 6e3 6e4 6e9 6ec 6f0 6f1 6f6
6f9 6fe 6ff 704 707 70c 70d 712
715 719 71d 722 725 729 72a 72f
732 737 738 73d 742 743 745 74a
74b 74d 74e 753 756 75b 75c 761
764 768 76c 771 774 778 779 77e
781 786 787 78c 791 792 794 799
79a 79c 79d 7a2 7a5 7aa 7ab 7b0
7b3 7b8 7b9 7be 7c1 7c5 7c6 7cb
7ce 7d3 7d4 7d9 7dc 7e1 7e2 7e7
7e8 7ed 7ef 7f3 7f6 7fa 7fe 801
805 809 80c 80f 814 817 81a 81d
81e 823 824 1 826 82b 82f 833
836 83b 840 843 847 848 84d 84e
853 855 859 85c 860 864 868 86c
870 874 878 87c 880 884 888 88c
890 894 898 89c 8a0 8a4 8a8 8ac
8b0 8b4 8b8 8bc 8c0 8c4 8c8 8cc
8d0 8d4 8d8 8dc 8e0 8e4 8e8 8ec
8f0 8f4 8f8 8fc 900 904 908 90c
910 914 918 91c 920 924 928 92c
930 934 938 93c 940 944 948 94c
950 954 958 95c 960 964 968 96c
970 974 978 97c 980 984 988 98c
990 994 998 9a4 9a8 9ac 9af 9b3
9b7 9b9 9bd 9c1 9c5 9c8 9cc 9d0
9d2 9d3 9d8 1 9dc 9e0 9e4 9e7
9eb 9ef 9f3 9f7 9fa 9fe a02 a05
a08 a0d a10 a13 a16 a17 a1c a1d
1 a1f a24 a28 a2c a2f a34 a39
a3c a40 a41 a46 a49 a4e a4f a54
a57 a5c a5d a62 a65 a69 a6a a6f
a72 a77 a78 a7d a80 a84 a88 a8b
a8e a8f a91 a92 a97 a98 a9d a9f
aa3 aa6 aa8 aac aae aba abc abe
abf ac4 ac8 aca ad6 ad8 adc ae0
ae3 ae7 aea aee af1 af2 af7 afa
afe b02 b05 b09 b0d b10 b13 b18
b1b b1e b21 b22 b27 b28 1 b2a
b2f b33 b37 b3a b3f b44 b47 b4b
b4c b51 b54 b59 b5a b5f b62 b67
b68 b6d b70 b74 b78 b7c b80 b83
b84 b86 b8b b8c b8e b8f b94 b97
b9c b9d ba2 ba5 baa bab bb0 bb3
bb7 bb8 bbd bc0 bc5 bc6 bcb bcc
bd1 bd3 bd7 bda bde be2 be5 be9
bed bf0 bf3 bf8 bfb bfe c01 c02
c07 c08 1 c0a c0f c13 c17 c1a
c1f c24 c27 c2b c2c c31 c32 c37
c39 c3d c40 c44 c48 c4b c4f c53
c56 c5a c5e c5f c64 c66 c6a c6d
c71 c74 c75 c7a c7d c81 c84 c85
c8a 1 c8d c92 c96 c9a c9e ca2
ca6 caa cae cb2 cb5 cb9 cbd cc0
cc1 cc3 cc6 cc9 cca ccf cd2 cd6
cda cdd ce1 ce5 ce8 ce9 ceb cee
cf1 cf2 cf7 1 cfa cff d03 d07
d0a d0e d12 d15 d18 d1d d20 d23
d26 d27 d2c d2d 1 d2f d34 d38
d3c d3f d44 d49 d4c d50 d51 d56
d59 d5e d5f d64 d67 d6c d6d d72
d75 d79 d7d d81 d85 d88 d89 d8b
d90 d91 d93 d94 d99 d9c da1 da2
da7 daa daf db0 db5 db8 dbc dbd
dc2 dc5 dca dcb dd0 dd1 dd6 dd8
ddc ddf de3 de7 dea dee df2 df5
df8 dfd e00 e03 e06 e07 e0c e0d
1 e0f e14 e18 e1c e1f e24 e29
e2c e30 e31 e36 e37 e3c e3e e42
e45 e49 e4d e50 e54 e58 e5b e5f
e63 e64 e69 e6b e6f e72 e76 e7a
e7e e82 e86 e8a e8e e92 e96 ea2
ea6 eaa ead eb1 eb5 eb7 ebb ebf
ec3 ec6 eca ece ed0 ed1 ed6 1
eda ede ee2 ee5 ee9 eed ef1 ef5
ef8 efc f00 f03 f06 f0b f0e f11
f14 f15 f1a f1b 1 f1d f22 f26
f2a f2d f32 f37 f3a f3e f3f f44
f47 f4c f4d f52 f55 f5a f5b f60
f63 f67 f68 f6d f70 f75 f76 f7b
f7e f82 f86 f89 f8c f8d f8f f90
f95 f96 f9b f9d fa1 fa4 fa6 faa
fac fb8 fba fbc fbd fc2 fc6 fc8
fd4 fd6 fda fde fe1 fe5 fe9 fec
fed fef ff2 ff5 ff6 ffb fff 1003
1007 100b 100e 1012 1014 1018 101c 101f
1023 1027 102a 102d 1032 1035 1038 103b
103c 1041 1042 1 1044 1049 104d 1051
1054 1059 105e 1061 1065 1066 106b 106e
1073 1074 1079 107c 1081 1082 1087 108a
108e 1092 1096 109a 109d 109e 10a0 10a5
10a6 10a8 10a9 10ae 10af 10b4 10b6 10ba
10bd 10c1 10c5 10c8 10cc 10d0 10d3 10d6
10db 10de 10e1 10e4 10e5 10ea 10eb 1
10ed 10f2 10f6 10fa 10fd 1102 1107 110a
110e 110f 1114 1115 111a 111c 1120 1123
1127 112b 112e 1132 1136 1139 113d 113e
1143 1145 1149 114d 1150 1152 1156 1159
115d 1160 1163 1164 1169 116d 1171 1175
1179 117d 1181 1185 1189 118d 1191 1195
1199 119d 119e 11a0 11a4 11a8 11ac 11af
11b0 11b2 11b5 11b8 11b9 11be 11c1 11c5
11c8 11c9 11ce 11d1 1 11d4 11d9 11dd
11e1 11e5 11e9 11ed 11f1 11f5 11f9 11fd
1200 1201 1203 1207 1209 120d 1210 1214
1217 1218 121d 1220 1224 1228 122c 1230
1233 1234 1236 123a 123c 1240 1244 1247
124a 124b 124d 1250 1255 1256 125b 125f
1263 1267 126b 126e 126f 1271 1275 1277
127b 127f 1283 1287 128a 128b 128d 1291
1293 1297 129b 129e 12a0 12a4 12a8 12ab
12af 12b2 12b3 12b8 12bb 12bf 12c3 12c7
12cb 12cf 12d3 12d7 12db 12df 12e3 12ef
12f3 12f7 12fa 12fe 1302 1304 1308 130c
1310 1313 1317 131b 131d 131e 1323 1
1327 132b 132f 1332 1336 133a 133e 1342
1345 1349 134d 1350 1353 1358 135b 135e
1361 1362 1367 1368 1 136a 136f 1373
1377 137a 137f 1384 1387 138b 138c 1391
1394 1399 139a 139f 13a2 13a7 13a8 13ad
13b0 13b4 13b5 13ba 13bd 13c2 13c3 13c8
13cb 13cf 13d3 13d6 13d9 13da 13dc 13dd
13e2 13e3 13e8 13ea 13ee 13f1 13f3 13f7
13f9 1405 1407 1409 140a 140f 1413 1415
1421 1423 1427 142b 142f 1432 1433 1435
1438 143c 1440 1443 1444 1446 1447 144c
1450 1452 1456 1459 145d 1460 1464 1468
146c 1470 1474 1478 147c 1480 1484 1488
148c 148f 1490 1492 1496 149a 149d 149e
14a0 14a1 14a3 14a7 14ab 14af 14b2 14b3
14b5 14b8 14bb 14bc 14c1 14c5 14c9 14cc
14d0 14d4 14d7 14da 14df 14e2 14e5 14e8
14e9 14ee 14ef 1 14f1 14f6 14fa 14fe
1501 1506 150b 150e 1512 1513 1518 151b
1520 1521 1526 1529 152e 152f 1534 1537
153b 153f 1543 1547 154a 154b 154d 1552
1553 1555 1556 155b 155e 1563 1564 1569
156c 1571 1572 1577 157a 157e 157f 1584
1587 158c 158d 1592 1593 1598 159a 159e
15a1 15a5 15a9 15ac 15b0 15b4 15b7 15ba
15bf 15c2 15c5 15c8 15c9 15ce 15cf 1
15d1 15d6 15da 15de 15e1 15e6 15eb 15ee
15f2 15f3 15f8 15f9 15fe 1600 1604 1607
160b 160f 1612 1616 161a 161d 1621 1625
1626 162b 162d 1631 1635 1639 163d 1649
164d 1651 1655 1659 165d 1661 1665 1669
166d 1671 1675 1679 167d 1681 1685 1689
168d 1691 1695 1699 169d 16a1 16ad 16b1
16b6 16ba 16bd 16be 16c3 16c7 16cb 16ce
16d1 16d5 16d7 16db 16df 16e2 16e5 16e9
16eb 16ef 16f3 16f6 16f8 16fc 1700 1704
1707 170b 170f 1711 1712 1717 1 171b
171f 1723 1726 172a 172e 1732 1736 1739
173d 1741 1744 1747 174c 174f 1752 1755
1756 175b 175c 1 175e 1763 1767 176b
176e 1773 1778 177b 177f 1780 1785 1788
178d 178e 1793 1796 179b 179c 17a1 17a4
17a8 17a9 17ae 17b1 17b6 17b7 17bc 17bf
17c3 17c7 17ca 17cd 17ce 17d0 17d1 17d6
17d7 17dc 17de 17e2 17e5 17e7 17eb 17ed
17f9 17fb 17fd 17fe 1803 1807 1809 1815
1817 1819 181d 1821 1824 1828 182c 1830
1831 1833 1837 183b 183f 1842 1846 184a
184d 1850 1855 1858 185b 185e 185f 1864
1865 1 1867 186c 1870 1874 1877 187c
1881 1884 1888 1889 188e 1891 1896 1897
189c 189f 18a4 18a5 18aa 18ad 18b1 18b5
18b9 18ba 18bc 18c1 18c2 18c4 18c5 18ca
18cd 18d2 18d3 18d8 18db 18e0 18e1 18e6
18e9 18ed 18ee 18f3 18f6 18fb 18fc 1901
1902 1907 1909 190d 1910 1914 1918 191b
191f 1923 1926 1929 192e 1931 1934 1937
1938 193d 193e 1 1940 1945 1949 194d
1950 1955 195a 195d 1961 1962 1967 1968
196d 196f 1973 1976 197a 197e 1981 1985
1989 198c 198d 198f 1993 1997 1998 199d
19a1 19a5 19a8 19ac 19b0 19b3 19b6 19bb
19be 19c1 19c4 19c5 19ca 19cb 1 19cd
19d2 19d6 19da 19dd 19e2 19e7 19ea 19ee
19ef 19f4 19f7 19fc 19fd 1a02 1a05 1a0a
1a0b 1a10 1a13 1a17 1a1b 1a1f 1a23 1a26
1a27 1a29 1a2e 1a2f 1a31 1a32 1a37 1a3a
1a3f 1a40 1a45 1a48 1a4d 1a4e 1a53 1a56
1a5a 1a5b 1a60 1a63 1a68 1a69 1a6e 1a6f
1a74 1a76 1a7a 1a7d 1a81 1a85 1a88 1a8c
1a90 1a93 1a97 1a9b 1a9c 1aa1 1aa3 1aa7
1aab 1aae 1ab2 1ab6 1ab9 1abd 1ac1 1ac4
1ac7 1acc 1acf 1ad2 1ad5 1ad6 1adb 1adc
1 1ade 1ae3 1ae7 1aeb 1aee 1af3 1af8
1afb 1aff 1b00 1b05 1b06 1b0b 1b0f 1b13
1b16 1b1b 1b20 1b23 1b27 1b2b 1b2e 1b2f
1b34 1b37 1b3c 1b3d 1b42 1b45 1b49 1b4d
1b50 1b51 1b56 1b57 1b5c 1b5e 1b62 1b65
1b69 1b6d 1b71 1b75 1b79 1b7d 1b81 1b85
1b89 1b95 1b9a 1b9e 1ba2 1ba6 1baa 1bac
1bad 1bb2 1 1bb6 1bba 1bbe 1bc1 1bc5
1bc9 1bcd 1bd1 1bd4 1bd8 1bdc 1bdf 1be2
1be7 1bea 1bed 1bf0 1bf1 1bf6 1bf7 1
1bf9 1bfe 1c02 1c06 1c09 1c0e 1c13 1c16
1c1a 1c1b 1c20 1c21 1c26 1c2a 1c2e 1c31
1c36 1c3b 1c3e 1c42 1c43 1c48 1c4b 1c50
1c51 1c56 1c59 1c5d 1c61 1c64 1c67 1c68
1c6a 1c6b 1c70 1c71 1c76 1c78 1c7c 1c7f
1c83 1c87 1c8b 1c8f 1c93 1c97 1c9b 1ca7
1cac 1cb0 1cb4 1cb8 1cbc 1cbe 1cc2 1cc4
1cd0 1cd2 1cd4 1cd5 1cda 1cde 1ce0 1cec
1cf0 1cf2 1cf3 1cfc 
7f4
2
0 1 a 6 10 :3 6 16 :3 6
17 :3 6 10 :2 6 1 3 a 13
a :2 1 4 18 21 20 :2 18 :2 4
14 1d 1c :2 14 :2 4 11 1a 19
:2 11 :2 4 :3 13 :2 4 :3 11 :2 4 :3 12 :2 4
:3 12 :2 4 :3 13 :2 4 :3 9 :2 4 :3 9 :2 4
f 18 17 :2 f :2 4 f 18 17
:2 f :2 4 :2 f 1e f :2 4 :2 16 25
16 :2 4 :2 11 20 11 :2 4 :3 10 :2 4
:3 15 :2 4 :2 12 21 12 :2 4 :2 d 1c
d :2 4 :2 11 20 11 :2 4 :2 13 22
13 :2 4 e 17 16 :2 e :2 4 d
16 15 :2 d :2 4 f 18 17 :2 f
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :2 c 1b c :2 4 :2 14 23 14
:2 4 :2 13 22 13 :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 b 1a b
:2 4 :2 b 1a b :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 e 1d e
:2 4 :2 10 1f 10 :2 4 :2 13 22 13
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 13 22 13
:2 4 :2 14 23 14 :2 4 :2 f 1e f
:2 4 :2 f 19 f :2 4 :2 f 19 f
:2 4 :2 10 1a 10 :2 4 :2 10 1a 10
:2 4 :2 11 1b 11 :2 4 :2 11 1b 11
:2 4 :2 12 1c 12 :2 4 :2 12 1c 12
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 55 5b 5e :2 55 6c 83
8 :2 6c d 10 :2 6c 1a 1d :2 6c
b e :2 6c 13 16 1f 26 2b
2e :2 26 3e 41 :2 26 46 :2 1f 4f
:2 16 :2 6c b e :2 6c 13 16 1f
26 2b 2e :2 26 3f 42 :2 26 47
:2 1f 50 :2 16 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 28 2b :2 6c
30 33 :2 6c :2 7 4b :2 4 7 :2 11
23 :2 2d 39 3c 4d 4f 50 :2 4d
:2 23 :3 7 :2 d 12 1e 5e 61 :2 1e
:2 7 53 :3 4 1b :2 4 12 4 e
25 31 7 16 20 30 3b 45
4d 7 12 20 2d 3f 11 25
37 47 59 7 f 16 31 39
40 5c 66 7 15 23 31 7
17 27 37 7 1a c 1d 2b
7 13 1f 31 3c 44 4d 7
18 28 37 45 7 11 1a 7
d 13 1f 7 13 20 2c 7
15 24 32 7 17 c d 21
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 54
57 58 :2 54 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 8b 8e :2 24 96 99 :2 24 a5
a8 af b8 bb :2 a8 :2 24 :2 d 5b
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1c 1a :2 25 :2 1a 7 a :2 14 26
:2 30 3c 40 51 54 55 :2 51 :2 26
:3 a :2 10 15 21 62 65 :2 21 72
75 :2 21 79 7c :2 21 86 89 92
9a :2 a3 :2 92 b6 :2 89 :2 21 be c1
:2 21 c9 cc :2 21 d1 d4 :2 21 e8
eb :2 21 :2 a 58 :2 7 a :2 14 26
:2 30 3c 3f 50 53 54 :2 50 :2 26
:3 a :2 10 15 21 62 65 :2 21 :2 a
57 :3 7 :2 12 26 :2 2f 41 f :2 7
35 :2 4 :4 8 7 :4 2a 29 :3 7 18
:2 7 19 7 b :2 16 1e 2d 3d
:2 b 41 43 :2 41 a 4b :2 56 d
1d 2c :2 4b 30 33 :2 30 4a :2 a
d :2 17 29 :2 33 3f 43 54 57
58 :2 54 :2 29 :3 d :2 13 18 24 65
68 :2 24 75 78 :2 24 7c 7f :2 24
89 8c 95 9d :2 a6 :2 95 c3 :2 8c
:2 24 cb ce :2 24 d6 d9 :2 24 de
e1 :2 24 f5 f8 :2 24 :2 d 5b :2 a
d :2 17 29 :2 33 3f 42 53 56
57 :2 53 :2 29 :3 d :2 13 18 24 65
68 :2 24 :2 d 5a :3 a :2 15 29 :2 32
4e 12 :2 a 36 :2 7 11 1d f
1d f 1d 2a 3b 48 :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 57 5a 5b
:2 57 :2 2c :3 10 :2 16 1b 27 68 6b
:2 27 78 7b :2 27 7f 82 :2 27 8e
91 :2 27 99 9c :2 27 a8 ab b2
bb be :2 ab :2 27 :2 10 5e :2 d :2 a
:4 16 :2 a 7 :3 48 a :2 15 1d 2c
3a :2 a 3e 41 :2 3e a 1a :2 a
15 a 43 d :2 17 29 :2 33 3f
42 53 56 57 :2 53 :2 29 :3 d :2 13
18 24 65 68 :2 24 75 78 :2 24
7c 7f :2 24 89 8c 95 9d :2 a6
:2 95 b7 :2 8c :2 24 :2 d 5a :2 a d
:2 17 29 :2 33 3f 42 53 56 57
:2 53 :2 29 :3 d :2 13 18 24 65 68
:2 24 :2 d 5a :3 a :2 15 2b :2 34 44
:2 a :4 7 48 :3 4 14 15 :2 14 :2 4
17 2e 3c 47 5c 62 2d 39
45 53 2d :2 17 4 8 11 1d
:2 8 20 22 :2 20 7 :4 2b 2a 29
:3 7 15 2a 38 43 4d 26 3b
4d 59 :2 15 7 4a :2 4 :4 8 :2 7
1a 2a 38 4d :2 1a 7 25 a
11 1d 20 :2 a 23 25 :2 23 a
1d 2d 3b 50 :2 1d a 29 a
1d 2d 3b 50 :2 1d a :4 7 :4 4
:4 8 7 11 1c 29 31 38 53
5e 63 :2 f :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 57 5a 5b :2 57 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5e :2 d :2 a :4 16 :2 a 7
:3 26 7 13 1c 26 :2 13 29 2b
34 43 :2 2b :2 13 7 26 :3 4 12
:2 4 17 25 3a 48 52 5e 24
30 39 42 :2 30 46 4f 60 :2 46
:2 17 4 7 10 21 :2 7 24 27
:2 24 a :2 14 26 :2 30 3c 40 51
54 55 :2 51 :2 26 :3 a :2 10 15 21
62 65 :2 21 72 75 :2 21 79 7c
:2 21 86 89 92 9a :2 a3 :2 92 bb
:2 89 :2 21 c3 c6 :2 21 ce d1 :2 21
d6 d9 :2 21 ed f0 :2 21 :2 a 58
:2 7 a :2 14 26 :2 30 3c 3f 50
53 54 :2 50 :2 26 :3 a :2 10 15 21
62 65 :2 21 :2 a 57 :3 7 :2 12 26
:2 2f 46 f :2 7 29 e f 10
24 7 11 26 34 42 4b 52
5f 68 75 7e a 19 22 2e
3e 4e 57 64 a 1e 10 24
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 57 5a 5b :2 57 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5e :2 d :2 a :4 16 :2 a 7
:8 4 12 1c :2 12 4 7 :2 11 23
:2 2d 39 3d 4e 51 52 :2 4e :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e 6f
72 :2 1e 76 79 :2 1e 83 86 8f
97 :2 8f a4 :2 86 :2 1e ac af :2 1e
b7 ba :2 1e bf c2 :2 1e d6 d9
:2 1e :2 7 55 :2 4 7 :2 11 23 :2 2d
39 3c 4d 50 51 :2 4d :2 23 :3 7
:2 d 12 1e 5f 62 :2 1e :2 7 54
:3 4 :2 f 23 2c 38 :2 23 3c c
:2 4 7 :2 11 23 :2 2d 39 3c 4d
50 51 :2 4d :2 23 :3 7 :2 d 12 1e
5f 62 :2 1e 6f 72 :2 1e 76 79
:2 1e 83 86 8f 97 :2 a0 :2 8f ab
:2 86 :2 1e b3 b6 :2 1e be c1 :2 1e
c6 c9 :2 1e dd e0 :2 1e :2 7 54
:3 4 :2 f 21 :2 2a 34 49 :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 51 54 55 :2 51 :2 26 :3 a :2 10
15 21 62 65 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 58 :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 4e 51 52 :2 4e :2 23 :3 7 :2 d
12 1e 5f 62 :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 55
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
7f4
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:5 c :5 d :5 e :5 f
:5 10 :5 11 :5 12 :7 13
:7 14 :6 15 :6 16 :6 17
:5 18 :5 19 :6 1a :6 1b
:6 1c :6 1d :7 1e :7 1f
:7 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :7 40
:b 42 :11 43 44 :2 43
:2 44 :2 43 :2 44 :2 43
:2 45 :2 43 :12 45 :2 43
:2 46 :2 43 :12 46 :2 43
:2 47 :2 43 :2 47 :2 43
:2 47 :2 43 :2 47 :2 43
:2 47 :4 43 :3 42 :11 4a
:b 4b :3 4a :3 51 :3 52
:3 55 :7 56 :5 57 :5 58
:8 59 :4 5a :4 5b :2 5c
:3 5d :7 5e :5 5f :3 60
:4 61 :4 62 :4 63 :2 64
65 :2 66 55 :5 67
54 69 :5 6a :3 69
:2 6b :5 6d :11 6e :24 6f
:3 6e :2 6c :6 6b 68
:3 41 :a 75 :11 76 :30 77
:3 76 :11 79 :b 7a :3 79
:7 7c 7d :2 7c :3 75
:c 80 :3 81 :3 82 :10 84
:3 85 :2 84 :4 85 :3 84
:11 86 :30 87 :3 86 :11 89
:b 8a :3 89 :7 8c 8d
:2 8c 85 :2 84 :2 91
:2 92 :5 93 91 :5 94
90 96 :5 97 :3 96
:2 98 :5 9a :11 9b :24 9c
:3 9b :2 99 :6 98 95
:3 80 :c a3 :3 a4 :3 a5
a3 :11 a7 :20 a8 :3 a7
:11 aa :b ab :3 aa :9 ad
a6 :3 a3 :3 80 :6 b2
:7 b3 :4 b4 b5 :3 b3
:12 b7 :6 b8 :4 b9 :3 b8
:3 b7 :5 bd :8 be bd
:a c0 :8 c1 c0 :8 c3
c2 :3 c0 bf :3 bd
:5 c7 :8 c9 ca cb
c9 :5 cc c8 ce
:5 cf :3 ce :2 d0 :5 d2
:11 d3 :24 d4 :3 d3 :2 d1
:6 d0 cd :3 c7 :f d9
:3 c7 :3 de :7 df :b e0
:3 df :9 e3 :11 e4 :30 e5
:3 e4 :11 e7 :b e8 :3 e7
:7 ea eb :2 ea e3
ed ee :2 ef ed
:a f2 :8 f3 :2 f4 :2 f5
f2 :6 f6 :5 f7 f6
:5 f9 f8 :3 f6 f1
fc :5 fd :3 fc :2 fe
:5 100 :11 101 :24 102 :3 101
:2 ff :6 fe fb :4 ec
:3 e3 :6 108 :11 109 :2e 10a
:3 109 :11 10c :b 10d :3 10c
:9 10f 110 :2 10f :11 112
:30 113 :3 112 :a 115 41
:3 118 :11 119 :b 11a :17 11b
:3 119 :2 11d :3 11e :3 11f
120 11e 11d 11e
:3 121 :3 118 :2 122 :5 124
:11 125 :b 126 :18 127 :3 125
:2 129 12a :3 12b 12c
12a 129 12a :3 12d
:2 123 :6 122 117 :7 1

1cfe
4
:3 0 1 :3 0 2
:a 0 7ef 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 15 16 0
b 4 :3 0 8
:7 0 11 10 :3 0
9 :3 0 a :3 0
b :2 0 4 13
17 0 7ef 2
18 :2 0 d :2 0
12 4 :3 0 d
:2 0 10 1b 1d
:6 0 20 1e 0
7ed 0 c :6 0
d :2 0 16 4
:3 0 14 22 24
:6 0 27 25 0
7ed 0 e :6 0
1c d9 0 1a
4 :3 0 18 29
2b :6 0 2e 2c
0 7ed 0 f
:6 0 20 10d 0
1e 6 :3 0 30
:7 0 33 31 0
7ed 0 10 :6 0
6 :3 0 35 :7 0
38 36 0 7ed
0 11 :6 0 24
141 0 22 6
:3 0 3a :7 0 3d
3b 0 7ed 0
12 :6 0 6 :3 0
3f :7 0 42 40
0 7ed 0 13
:6 0 28 175 0
26 6 :3 0 44
:7 0 47 45 0
7ed 0 14 :6 0
16 :3 0 49 :7 0
4c 4a 0 7ed
0 15 :6 0 19
:2 0 2c 16 :3 0
4e :7 0 51 4f
0 7ed 0 17
:6 0 4 :3 0 19
:2 0 2a 53 55
:6 0 58 56 0
7ed 0 18 :6 0
1d :2 0 30 4
:3 0 2e 5a 5c
:6 0 5f 5d 0
7ed 0 1a :6 0
1d :2 0 32 1c
:3 0 61 :7 0 65
62 63 7ed 0
1b :6 0 1d :2 0
34 1c :3 0 67
:7 0 6b 68 69
7ed 0 1e :6 0
38 21e 0 36
1c :3 0 6d :7 0
71 6e 6f 7ed
0 1f :6 0 1d
:2 0 3a 16 :3 0
73 :7 0 76 74
0 7ed 0 20
:6 0 16 :3 0 78
:7 0 7b 79 0
7ed 0 21 :6 0
1d :2 0 3c 1c
:3 0 7d :7 0 81
7e 7f 7ed 0
22 :6 0 1d :2 0
3e 1c :3 0 83
:7 0 87 84 85
7ed 0 23 :6 0
1d :2 0 40 1c
:3 0 89 :7 0 8d
8a 8b 7ed 0
24 :6 0 d :2 0
42 1c :3 0 8f
:7 0 93 90 91
7ed 0 25 :6 0
d :2 0 46 4
:3 0 44 95 97
:6 0 9a 98 0
7ed 0 26 :6 0
d :2 0 4a 4
:3 0 48 9c 9e
:6 0 a1 9f 0
7ed 0 27 :6 0
1d :2 0 4e 4
:3 0 4c a3 a5
:6 0 a8 a6 0
7ed 0 28 :6 0
1d :2 0 50 1c
:3 0 aa :7 0 ae
ab ac 7ed 0
29 :6 0 1d :2 0
52 1c :3 0 b0
:7 0 b4 b1 b2
7ed 0 2a :6 0
1d :2 0 54 1c
:3 0 b6 :7 0 ba
b7 b8 7ed 0
2b :6 0 1d :2 0
56 1c :3 0 bc
:7 0 c0 bd be
7ed 0 2c :6 0
1d :2 0 58 1c
:3 0 c2 :7 0 c6
c3 c4 7ed 0
2d :6 0 1d :2 0
5a 1c :3 0 c8
:7 0 cc c9 ca
7ed 0 2e :6 0
1d :2 0 5c 1c
:3 0 ce :7 0 d2
cf d0 7ed 0
2f :6 0 1d :2 0
5e 1c :3 0 d4
:7 0 d8 d5 d6
7ed 0 30 :6 0
1d :2 0 60 1c
:3 0 da :7 0 de
db dc 7ed 0
31 :6 0 1d :2 0
62 1c :3 0 e0
:7 0 e4 e1 e2
7ed 0 32 :6 0
1d :2 0 64 1c
:3 0 e6 :7 0 ea
e7 e8 7ed 0
33 :6 0 1d :2 0
66 1c :3 0 ec
:7 0 f0 ed ee
7ed 0 34 :6 0
1d :2 0 68 1c
:3 0 f2 :7 0 f6
f3 f4 7ed 0
35 :6 0 1d :2 0
6a 1c :3 0 f8
:7 0 fc f9 fa
7ed 0 36 :6 0
1d :2 0 6c 1c
:3 0 fe :7 0 102
ff 100 7ed 0
37 :6 0 1d :2 0
6e 1c :3 0 104
:7 0 108 105 106
7ed 0 38 :6 0
1d :2 0 70 1c
:3 0 10a :7 0 10e
10b 10c 7ed 0
39 :6 0 1d :2 0
72 1c :3 0 110
:7 0 114 111 112
7ed 0 3a :6 0
1d :2 0 74 1c
:3 0 116 :7 0 11a
117 118 7ed 0
3b :6 0 1d :2 0
76 1c :3 0 11c
:7 0 120 11d 11e
7ed 0 3c :6 0
1d :2 0 78 1c
:3 0 122 :7 0 126
123 124 7ed 0
3d :6 0 1d :2 0
7a 1c :3 0 128
:7 0 12c 129 12a
7ed 0 3e :6 0
1d :2 0 7c 40
:3 0 12e :7 0 132
12f 130 7ed 0
3f :6 0 1d :2 0
7e 40 :3 0 134
:7 0 138 135 136
7ed 0 41 :6 0
1d :2 0 80 40
:3 0 13a :7 0 13e
13b 13c 7ed 0
42 :6 0 1d :2 0
82 40 :3 0 140
:7 0 144 141 142
7ed 0 43 :6 0
1d :2 0 84 40
:3 0 146 :7 0 14a
147 148 7ed 0
44 :6 0 1d :2 0
86 40 :3 0 14c
:7 0 150 14d 14e
7ed 0 45 :6 0
1d :2 0 88 40
:3 0 152 :7 0 156
153 154 7ed 0
46 :6 0 15e 15f
0 8a 40 :3 0
158 :7 0 15c 159
15a 7ed 0 47
:6 0 164 165 0
8c a :3 0 b
:2 0 4 160 :7 0
163 161 0 7ed
0 48 :6 0 49
:3 0 4a :3 0 49
:3 0 4b :3 0 167
168 0 2 :4 0
8e 169 16b 166
16d 16c :2 0 4c
:3 0 4d :3 0 16f
170 0 4e :4 0
49 :3 0 4f :3 0
173 174 0 2
:4 0 90 175 177
50 :4 0 51 :2 0
52 :3 0 92 17a
17c :3 0 53 :4 0
51 :2 0 54 :4 0
95 17f 181 :3 0
51 :2 0 3 :3 0
98 183 185 :3 0
51 :2 0 54 :4 0
9b 187 189 :3 0
51 :2 0 55 :4 0
9e 18b 18d :3 0
51 :2 0 56 :3 0
57 :3 0 54 :4 0
51 :2 0 5 :3 0
a1 193 195 :3 0
51 :2 0 54 :4 0
a4 197 199 :3 0
58 :4 0 a7 191
19c 59 :4 0 aa
190 19f ad 18f
1a1 :3 0 51 :2 0
55 :4 0 b0 1a3
1a5 :3 0 51 :2 0
56 :3 0 57 :3 0
54 :4 0 51 :2 0
7 :3 0 b3 1ab
1ad :3 0 51 :2 0
54 :4 0 b6 1af
1b1 :3 0 58 :4 0
b9 1a9 1b4 59
:4 0 bc 1a8 1b7
bf 1a7 1b9 :3 0
51 :2 0 55 :4 0
c2 1bb 1bd :3 0
51 :2 0 54 :4 0
c5 1bf 1c1 :3 0
51 :2 0 8 :3 0
c8 1c3 1c5 :3 0
51 :2 0 54 :4 0
cb 1c7 1c9 :3 0
51 :2 0 5a :4 0
ce 1cb 1cd :3 0
d1 171 1cf :2 0
1d1 d6 1d2 16e
1d1 0 1d3 d8
0 74d 49 :3 0
4a :3 0 1d4 1d5
0 49 :3 0 5b
:3 0 1d7 1d8 0
19 :2 0 2 :4 0
5c :2 0 5d :2 0
19 :2 0 da 1dd
1df :3 0 dd 1d9
1e1 1d6 1e3 1e2
:2 0 4c :3 0 5e
:3 0 1e5 1e6 0
4e :4 0 5f :4 0
51 :2 0 52 :3 0
e1 1ea 1ec :3 0
e4 1e7 1ee :2 0
1f0 e7 1f1 1e4
1f0 0 1f2 e9
0 74d c :3 0
3 :3 0 1f3 1f4
0 74d 28 :3 0
8 :3 0 1f6 1f7
0 74d 60 :3 0
61 :3 0 62 :3 0
63 :3 0 64 :3 0
65 :3 0 66 :3 0
67 :3 0 68 :3 0
69 :3 0 6a :3 0
6b :3 0 6c :3 0
6d :3 0 6e :3 0
64 :3 0 6f :3 0
70 :3 0 71 :3 0
72 :3 0 73 :3 0
74 :3 0 6d :3 0
73 :3 0 74 :3 0
6e :3 0 75 :3 0
76 :3 0 77 :3 0
78 :3 0 79 :3 0
7a :3 0 7b :3 0
7c :3 0 7d :3 0
7e :3 0 7f :3 0
80 :3 0 e :3 0
f :3 0 27 :3 0
1a :3 0 18 :3 0
21 :3 0 2a :3 0
30 :3 0 3a :3 0
3b :3 0 2c :3 0
10 :3 0 2e :3 0
11 :3 0 12 :3 0
29 :3 0 2b :3 0
32 :3 0 15 :3 0
17 :3 0 1b :3 0
1e :3 0 3f :3 0
42 :3 0 41 :3 0
43 :3 0 44 :3 0
46 :3 0 45 :3 0
47 :3 0 2d :3 0
26 :3 0 81 :3 0
82 :3 0 c :4 0
83 1 :8 0 248
a :3 0 84 :3 0
243 244 0 85
:3 0 245 246 0
248 eb 29b 86
:3 0 a :3 0 84
:3 0 24a 24b 0
85 :3 0 24c 24d
0 24f ee 251
f0 250 24f :2 0
299 87 :3 0 a
:3 0 84 :3 0 254
255 0 85 :3 0
256 257 0 291
49 :3 0 4a :3 0
259 25a 0 49
:3 0 5b :3 0 25c
25d 0 88 :2 0
2 :4 0 89 :2 0
5d :2 0 19 :2 0
f2 262 264 :3 0
f5 25e 266 25b
268 267 :2 0 4c
:3 0 5e :3 0 26a
26b 0 4e :4 0
8a :4 0 51 :2 0
52 :3 0 f9 26f
271 :3 0 51 :2 0
8b :4 0 fc 273
275 :3 0 51 :2 0
8c :4 0 ff 277
279 :3 0 51 :2 0
85 :3 0 102 27b
27d :3 0 51 :2 0
8d :4 0 105 27f
281 :3 0 51 :2 0
74 :3 0 8e :3 0
19 :2 0 8f :2 0
108 284 288 10c
283 28a :3 0 10f
26c 28c :2 0 28e
112 28f 269 28e
0 290 114 0
291 116 294 :3 0
294 0 294 293
291 292 :6 0 296
2 :3 0 119 298
11b 297 296 :2 0
299 11d :2 0 29b
0 29b 29a 248
299 :6 0 74d 1
:3 0 a :3 0 84
:3 0 29d 29e 0
a :3 0 90 :2 0
91 :3 0 2a0 2a2
0 122 2a1 2a4
:3 0 2a5 :2 0 49
:3 0 4a :3 0 2a7
2a8 0 49 :3 0
5b :3 0 2aa 2ab
0 d :2 0 2
:4 0 92 :2 0 5d
:2 0 19 :2 0 125
2b0 2b2 :3 0 128
2ac 2b4 2a9 2b6
2b5 :2 0 4c :3 0
5e :3 0 2b8 2b9
0 4e :4 0 93
:4 0 51 :2 0 52
:3 0 12c 2bd 2bf
:3 0 51 :2 0 8b
:4 0 12f 2c1 2c3
:3 0 51 :2 0 94
:4 0 132 2c5 2c7
:3 0 51 :2 0 56
:3 0 95 :3 0 96
:3 0 97 :3 0 2cc
2cd 0 135 2cb
2cf 59 :4 0 137
2ca 2d2 13a 2c9
2d4 :3 0 51 :2 0
98 :4 0 13d 2d6
2d8 :3 0 51 :2 0
54 :4 0 140 2da
2dc :3 0 51 :2 0
c :3 0 143 2de
2e0 :3 0 51 :2 0
54 :4 0 146 2e2
2e4 :3 0 149 2ba
2e6 :2 0 2e8 14c
2e9 2b7 2e8 0
2ea 14e 0 314
49 :3 0 4a :3 0
2eb 2ec 0 49
:3 0 5b :3 0 2ee
2ef 0 19 :2 0
2 :4 0 99 :2 0
5d :2 0 19 :2 0
150 2f4 2f6 :3 0
153 2f0 2f8 2ed
2fa 2f9 :2 0 4c
:3 0 5e :3 0 2fc
2fd 0 4e :4 0
9a :4 0 51 :2 0
52 :3 0 157 301
303 :3 0 15a 2fe
305 :2 0 307 15d
308 2fb 307 0
309 15f 0 314
9b :3 0 9c :3 0
30a 30b 0 96
:3 0 97 :3 0 30d
30e 0 c :3 0
9d :3 0 161 30c
312 :2 0 314 165
315 2a6 314 0
316 169 0 74d
5 :3 0 9e :2 0
16b 318 319 :3 0
31a :2 0 7 :3 0
9e :2 0 16d 31d
31e :3 0 31f :2 0
31b 321 320 :2 0
13 :3 0 5 :3 0
323 324 0 48c
14 :3 0 7 :3 0
326 327 0 48c
9f :3 0 a0 :3 0
329 32a 0 13
:3 0 14 :3 0 a1
:2 0 16f 32b 32f
a2 :2 0 1d :2 0
175 331 333 :3 0
334 :2 0 9f :3 0
a0 :3 0 336 337
0 14 :3 0 12
:3 0 a1 :2 0 178
338 33c a3 :2 0
1d :2 0 17e 33e
340 :3 0 341 :2 0
335 343 342 :2 0
49 :3 0 4a :3 0
345 346 0 49
:3 0 5b :3 0 348
349 0 d :2 0
2 :4 0 a4 :2 0
5d :2 0 19 :2 0
181 34e 350 :3 0
184 34a 352 347
354 353 :2 0 4c
:3 0 5e :3 0 356
357 0 4e :4 0
a5 :4 0 51 :2 0
52 :3 0 188 35b
35d :3 0 51 :2 0
8b :4 0 18b 35f
361 :3 0 51 :2 0
94 :4 0 18e 363
365 :3 0 51 :2 0
56 :3 0 95 :3 0
96 :3 0 a6 :3 0
36a 36b 0 191
369 36d 59 :4 0
193 368 370 196
367 372 :3 0 51
:2 0 98 :4 0 199
374 376 :3 0 51
:2 0 54 :4 0 19c
378 37a :3 0 51
:2 0 c :3 0 19f
37c 37e :3 0 51
:2 0 54 :4 0 1a2
380 382 :3 0 1a5
358 384 :2 0 386
1a8 387 355 386
0 388 1aa 0
3b2 49 :3 0 4a
:3 0 389 38a 0
49 :3 0 5b :3 0
38c 38d 0 19
:2 0 2 :4 0 a7
:2 0 5d :2 0 19
:2 0 1ac 392 394
:3 0 1af 38e 396
38b 398 397 :2 0
4c :3 0 5e :3 0
39a 39b 0 4e
:4 0 a8 :4 0 51
:2 0 52 :3 0 1b3
39f 3a1 :3 0 1b6
39c 3a3 :2 0 3a5
1b9 3a6 399 3a5
0 3a7 1bb 0
3b2 9b :3 0 9c
:3 0 3a8 3a9 0
96 :3 0 a6 :3 0
3ab 3ac 0 c
:3 0 9d :3 0 1bd
3aa 3b0 :2 0 3b2
1c1 3b3 344 3b2
0 3b4 1c5 0
48c 61 :3 0 a9
:3 0 f :3 0 34
:3 0 aa :3 0 61
:3 0 f :3 0 ab
:3 0 26 :4 0 ac
1 :8 0 3c4 a
:3 0 84 :3 0 3bf
3c0 0 85 :3 0
3c1 3c2 0 3c4
1c7 417 86 :3 0
a :3 0 84 :3 0
3c6 3c7 0 85
:3 0 3c8 3c9 0
3cb 1ca 3cd 1cc
3cc 3cb :2 0 415
87 :3 0 a :3 0
84 :3 0 3d0 3d1
0 85 :3 0 3d2
3d3 0 40d 49
:3 0 4a :3 0 3d5
3d6 0 49 :3 0
5b :3 0 3d8 3d9
0 88 :2 0 2
:4 0 ad :2 0 5d
:2 0 19 :2 0 1ce
3de 3e0 :3 0 1d1
3da 3e2 3d7 3e4
3e3 :2 0 4c :3 0
5e :3 0 3e6 3e7
0 4e :4 0 ae
:4 0 51 :2 0 52
:3 0 1d5 3eb 3ed
:3 0 51 :2 0 8b
:4 0 1d8 3ef 3f1
:3 0 51 :2 0 8c
:4 0 1db 3f3 3f5
:3 0 51 :2 0 85
:3 0 1de 3f7 3f9
:3 0 51 :2 0 8d
:4 0 1e1 3fb 3fd
:3 0 51 :2 0 74
:3 0 8e :3 0 19
:2 0 8f :2 0 1e4
400 404 1e8 3ff
406 :3 0 1eb 3e8
408 :2 0 40a 1ee
40b 3e5 40a 0
40c 1f0 0 40d
1f2 410 :3 0 410
0 410 40f 40d
40e :6 0 412 4
:3 0 1f5 414 1f7
413 412 :2 0 415
1f9 :2 0 417 0
417 416 3c4 415
:6 0 48c 1 :3 0
9f :3 0 a0 :3 0
419 41a 0 13
:3 0 11 :3 0 a1
:2 0 1fc 41b 41f
a3 :2 0 1d :2 0
202 421 423 :3 0
11 :3 0 13 :3 0
425 426 0 42b
2b :3 0 1d :2 0
428 429 0 42b
205 489 49 :3 0
4a :3 0 42c 42d
0 49 :3 0 5b
:3 0 42f 430 0
af :2 0 2 :4 0
b0 :2 0 5d :2 0
19 :2 0 208 435
437 :3 0 20b 431
439 42e 43b 43a
:2 0 4c :3 0 5e
:3 0 43d 43e 0
4e :4 0 b1 :4 0
51 :2 0 52 :3 0
20f 442 444 :3 0
51 :2 0 8b :4 0
212 446 448 :3 0
51 :2 0 94 :4 0
215 44a 44c :3 0
51 :2 0 56 :3 0
95 :3 0 96 :3 0
b2 :3 0 451 452
0 218 450 454
59 :4 0 21a 44f
457 21d 44e 459
:3 0 220 43f 45b
:2 0 45d 223 45e
43c 45d 0 45f
225 0 488 49
:3 0 4a :3 0 460
461 0 49 :3 0
5b :3 0 463 464
0 19 :2 0 2
:4 0 b3 :2 0 5d
:2 0 19 :2 0 227
469 46b :3 0 22a
465 46d 462 46f
46e :2 0 4c :3 0
5e :3 0 471 472
0 4e :4 0 b4
:4 0 51 :2 0 52
:3 0 22e 476 478
:3 0 231 473 47a
:2 0 47c 234 47d
470 47c 0 47e
236 0 488 9b
:3 0 b5 :3 0 47f
480 0 96 :3 0
b2 :3 0 482 483
0 9d :3 0 238
481 486 :2 0 488
23b 48a 424 42b
0 48b 0 488
0 48b 23f 0
48c 242 48d 322
48c 0 48e 248
0 74d 1f :3 0
b6 :2 0 19 :2 0
24a 490 492 :3 0
48f 493 0 74d
3d :3 0 b7 :3 0
f :3 0 26 :3 0
c :3 0 15 :3 0
17 :3 0 3f :3 0
41 :3 0 1f :3 0
1e :3 0 1b :3 0
24c 496 4a1 495
4a2 0 74d 56
:3 0 32 :3 0 1d
:2 0 257 4a4 4a7
a2 :2 0 1d :2 0
25c 4a9 4ab :3 0
4ac :2 0 21 :3 0
9e :2 0 25f 4af
4b0 :3 0 4b1 :2 0
4b2 :2 0 4ad 4b4
4b3 :2 0 3e :3 0
b8 :3 0 f :3 0
26 :3 0 27 :3 0
e :3 0 c :3 0
21 :3 0 32 :3 0
1d :2 0 261 4b7
4c0 4b6 4c1 0
4c3 26a 4c4 4b5
4c3 0 4c5 26c
0 74d e :3 0
9e :2 0 26e 4c7
4c8 :3 0 4c9 :2 0
3d :3 0 b9 :3 0
f :3 0 c :3 0
ba :2 0 270 4cc
4d0 4cb 4d1 0
4d3 274 4f4 74
:3 0 18 :3 0 19
:2 0 19 :2 0 276
4d4 4d8 90 :2 0
ba :4 0 27c 4da
4dc :3 0 3d :3 0
b9 :3 0 f :3 0
c :3 0 1d :2 0
27f 4df 4e3 4de
4e4 0 4e6 283
4f0 3d :3 0 b9
:3 0 f :3 0 c
:3 0 19 :2 0 285
4e8 4ec 4e7 4ed
0 4ef 289 4f1
4dd 4e6 0 4f2
0 4ef 0 4f2
28b 0 4f3 28e
4f5 4ca 4d3 0
4f6 0 4f3 0
4f6 290 0 74d
21 :3 0 9e :2 0
293 4f8 4f9 :3 0
4fa :2 0 9f :3 0
bb :3 0 73 :3 0
74 :3 0 21 :3 0
9f :3 0 bc :3 0
11 :3 0 11 :3 0
bd :4 0 be 1
:8 0 50c a :3 0
84 :3 0 507 508
0 85 :3 0 509
50a 0 50c 295
55f 86 :3 0 a
:3 0 84 :3 0 50e
50f 0 85 :3 0
510 511 0 513
298 515 29a 514
513 :2 0 55d 87
:3 0 a :3 0 84
:3 0 518 519 0
85 :3 0 51a 51b
0 555 49 :3 0
4a :3 0 51d 51e
0 49 :3 0 5b
:3 0 520 521 0
88 :2 0 2 :4 0
bf :2 0 5d :2 0
19 :2 0 29c 526
528 :3 0 29f 522
52a 51f 52c 52b
:2 0 4c :3 0 5e
:3 0 52e 52f 0
4e :4 0 c0 :4 0
51 :2 0 52 :3 0
2a3 533 535 :3 0
51 :2 0 8b :4 0
2a6 537 539 :3 0
51 :2 0 8c :4 0
2a9 53b 53d :3 0
51 :2 0 85 :3 0
2ac 53f 541 :3 0
51 :2 0 8d :4 0
2af 543 545 :3 0
51 :2 0 74 :3 0
8e :3 0 19 :2 0
8f :2 0 2b2 548
54c 2b6 547 54e
:3 0 2b9 530 550
:2 0 552 2bc 553
52d 552 0 554
2be 0 555 2c0
558 :3 0 558 0
558 557 555 556
:6 0 55a 6 :3 0
2c3 55c 2c5 55b
55a :2 0 55d 2c7
:2 0 55f 0 55f
55e 50c 55d :6 0
570 1 :3 0 29
:3 0 56 :3 0 29
:3 0 1d :2 0 2ca
562 565 b6 :2 0
56 :3 0 2e :3 0
1d :2 0 2cd 568
56b 2d0 567 56d
:3 0 561 56e 0
570 2d3 571 4fb
570 0 572 2d6
0 74d 3e :3 0
ba :2 0 573 574
0 74d 3d :3 0
c1 :3 0 c :3 0
11 :3 0 29 :3 0
3e :3 0 2a :3 0
28 :3 0 56 :3 0
2b :3 0 1d :2 0
2d8 57e 581 56
:3 0 2c :3 0 1d
:2 0 2db 583 586
2de 577 588 576
589 0 74d 56
:3 0 3d :3 0 1d
:2 0 2e7 58b 58e
a3 :2 0 1d :2 0
2ec 590 592 :3 0
49 :3 0 4a :3 0
594 595 0 49
:3 0 5b :3 0 597
598 0 d :2 0
2 :4 0 c2 :2 0
5d :2 0 19 :2 0
2ef 59d 59f :3 0
2f2 599 5a1 596
5a3 5a2 :2 0 4c
:3 0 5e :3 0 5a5
5a6 0 4e :4 0
c3 :4 0 51 :2 0
52 :3 0 2f6 5aa
5ac :3 0 51 :2 0
8b :4 0 2f9 5ae
5b0 :3 0 51 :2 0
94 :4 0 2fc 5b2
5b4 :3 0 51 :2 0
56 :3 0 95 :3 0
96 :3 0 c4 :3 0
5b9 5ba 0 2ff
5b8 5bc 59 :4 0
301 5b7 5bf 304
5b6 5c1 :3 0 51
:2 0 98 :4 0 307
5c3 5c5 :3 0 51
:2 0 54 :4 0 30a
5c7 5c9 :3 0 51
:2 0 c :3 0 30d
5cb 5cd :3 0 51
:2 0 54 :4 0 310
5cf 5d1 :3 0 313
5a7 5d3 :2 0 5d5
316 5d6 5a4 5d5
0 5d7 318 0
601 49 :3 0 4a
:3 0 5d8 5d9 0
49 :3 0 5b :3 0
5db 5dc 0 19
:2 0 2 :4 0 c5
:2 0 5d :2 0 19
:2 0 31a 5e1 5e3
:3 0 31d 5dd 5e5
5da 5e7 5e6 :2 0
4c :3 0 5e :3 0
5e9 5ea 0 4e
:4 0 c6 :4 0 51
:2 0 52 :3 0 321
5ee 5f0 :3 0 324
5eb 5f2 :2 0 5f4
327 5f5 5e8 5f4
0 5f6 329 0
601 9b :3 0 9c
:3 0 5f7 5f8 0
96 :3 0 c4 :3 0
5fa 5fb 0 c
:3 0 9d :3 0 32b
5f9 5ff :2 0 601
32f 689 81 :3 0
c7 :3 0 82 :3 0
c :4 0 c8 1
:8 0 688 81 :3 0
c9 :3 0 ca :3 0
cb :3 0 cc :3 0
ca :3 0 96 :3 0
cd :3 0 96 :3 0
ce :3 0 cf :3 0
56 :3 0 d0 :3 0
d1 :3 0 d2 :3 0
56 :3 0 d3 :3 0
d4 :3 0 c7 :3 0
d5 :3 0 82 :3 0
c :4 0 d6 1
:8 0 633 d7 :4 0
61e :3 0 9d :3 0
90 :2 0 335 621
622 :3 0 a :3 0
84 :3 0 624 625
0 1d :2 0 626
627 0 629 338
630 a :3 0 84
:3 0 62a 62b 0
d8 :2 0 62c 62d
0 62f 33a 631
623 629 0 632
0 62f 0 632
33c 0 633 33f
686 86 :3 0 a
:3 0 84 :3 0 635
636 0 85 :3 0
637 638 0 63a
342 63c 344 63b
63a :2 0 684 87
:3 0 a :3 0 84
:3 0 63f 640 0
85 :3 0 641 642
0 67c 49 :3 0
4a :3 0 644 645
0 49 :3 0 5b
:3 0 647 648 0
88 :2 0 2 :4 0
d9 :2 0 5d :2 0
19 :2 0 346 64d
64f :3 0 349 649
651 646 653 652
:2 0 4c :3 0 5e
:3 0 655 656 0
4e :4 0 da :4 0
51 :2 0 52 :3 0
34d 65a 65c :3 0
51 :2 0 8b :4 0
350 65e 660 :3 0
51 :2 0 8c :4 0
353 662 664 :3 0
51 :2 0 85 :3 0
356 666 668 :3 0
51 :2 0 8d :4 0
359 66a 66c :3 0
51 :2 0 74 :3 0
8e :3 0 19 :2 0
8f :2 0 35c 66f
673 360 66e 675
:3 0 363 657 677
:2 0 679 366 67a
654 679 0 67b
368 0 67c 36a
67f :3 0 67f 0
67f 67e 67c 67d
:6 0 681 8 :3 0
36d 683 36f 682
681 :2 0 684 371
:2 0 686 0 686
685 633 684 :6 0
688 1 :3 0 374
68a 593 601 0
68b 0 688 0
68b 377 0 74d
3e :3 0 db :3 0
f :3 0 37a 68d
68f 68c 690 0
74d 49 :3 0 4a
:3 0 692 693 0
49 :3 0 5b :3 0
695 696 0 d
:2 0 2 :4 0 dc
:2 0 5d :2 0 19
:2 0 37c 69b 69d
:3 0 37f 697 69f
694 6a1 6a0 :2 0
4c :3 0 5e :3 0
6a3 6a4 0 4e
:4 0 dd :4 0 51
:2 0 52 :3 0 383
6a8 6aa :3 0 51
:2 0 8b :4 0 386
6ac 6ae :3 0 51
:2 0 94 :4 0 389
6b0 6b2 :3 0 51
:2 0 56 :3 0 95
:3 0 3e :3 0 38c
6b6 6b8 59 :4 0
38e 6b5 6bb 391
6b4 6bd :3 0 51
:2 0 98 :4 0 394
6bf 6c1 :3 0 51
:2 0 54 :4 0 397
6c3 6c5 :3 0 51
:2 0 c :3 0 39a
6c7 6c9 :3 0 51
:2 0 54 :4 0 39d
6cb 6cd :3 0 3a0
6a5 6cf :2 0 6d1
3a3 6d2 6a2 6d1
0 6d3 3a5 0
74d 49 :3 0 4a
:3 0 6d4 6d5 0
49 :3 0 5b :3 0
6d7 6d8 0 19
:2 0 2 :4 0 de
:2 0 5d :2 0 19
:2 0 3a7 6dd 6df
:3 0 3aa 6d9 6e1
6d6 6e3 6e2 :2 0
4c :3 0 5e :3 0
6e5 6e6 0 4e
:4 0 df :4 0 51
:2 0 52 :3 0 3ae
6ea 6ec :3 0 3b1
6e7 6ee :2 0 6f0
3b4 6f1 6e4 6f0
0 6f2 3b6 0
74d 9b :3 0 9c
:3 0 6f3 6f4 0
56 :3 0 3e :3 0
1d :2 0 3b8 6f6
6f9 c :3 0 9d
:3 0 3bb 6f5 6fd
:2 0 74d 49 :3 0
4a :3 0 6ff 700
0 49 :3 0 5b
:3 0 702 703 0
e0 :2 0 2 :4 0
e1 :2 0 5d :2 0
19 :2 0 3bf 708
70a :3 0 3c2 704
70c 701 70e 70d
:2 0 4c :3 0 5e
:3 0 710 711 0
4e :4 0 e2 :4 0
51 :2 0 52 :3 0
3c6 715 717 :3 0
51 :2 0 8b :4 0
3c9 719 71b :3 0
51 :2 0 94 :4 0
3cc 71d 71f :3 0
51 :2 0 56 :3 0
95 :3 0 a :3 0
84 :3 0 724 725
0 3cf 723 727
59 :4 0 3d1 722
72a 3d4 721 72c
:3 0 51 :2 0 98
:4 0 3d7 72e 730
:3 0 51 :2 0 54
:4 0 3da 732 734
:3 0 51 :2 0 c
:3 0 3dd 736 738
:3 0 51 :2 0 54
:4 0 3e0 73a 73c
:3 0 3e3 712 73e
:2 0 740 3e6 741
70f 740 0 742
3e8 0 74d 9b
:3 0 e3 :3 0 743
744 0 a :3 0
84 :3 0 746 747
0 c :3 0 9d
:3 0 3ea 745 74b
:2 0 74d 3ee 7ee
a :3 0 e4 :2 0
4 74e 74f 0
49 :3 0 4a :3 0
751 752 0 49
:3 0 5b :3 0 754
755 0 88 :2 0
2 :4 0 e5 :2 0
5d :2 0 19 :2 0
404 75a 75c :3 0
407 756 75e 753
760 75f :2 0 4c
:3 0 5e :3 0 762
763 0 4e :4 0
e6 :4 0 51 :2 0
52 :3 0 40b 767
769 :3 0 40e 764
76b :2 0 784 4c
:3 0 5e :3 0 76d
76e 0 4e :4 0
e7 :4 0 51 :2 0
a :3 0 e8 :3 0
773 774 0 411
772 776 :3 0 51
:2 0 98 :4 0 414
778 77a :3 0 51
:2 0 a :3 0 e9
:3 0 77d 77e 0
417 77c 780 :3 0
41a 76f 782 :2 0
784 41d 785 761
784 0 786 420
0 796 ea :3 0
48 :3 0 a :3 0
e8 :3 0 eb :3 0
a :3 0 e9 :3 0
ec :3 0 bd :4 0
ed 1 :a 0 792
:2 0 796 788 790
:2 0 9 :3 0 48
:3 0 794 :2 0 796
422 798 426 797
796 :2 0 7ec 87
:3 0 a :3 0 84
:3 0 79b 79c 0
85 :3 0 79d 79e
0 7e4 49 :3 0
4a :3 0 7a0 7a1
0 49 :3 0 5b
:3 0 7a3 7a4 0
88 :2 0 2 :4 0
ee :2 0 5d :2 0
19 :2 0 428 7a9
7ab :3 0 42b 7a5
7ad 7a2 7af 7ae
:2 0 4c :3 0 5e
:3 0 7b1 7b2 0
4e :4 0 ef :4 0
51 :2 0 52 :3 0
42f 7b6 7b8 :3 0
432 7b3 7ba :2 0
7d4 4c :3 0 5e
:3 0 7bc 7bd 0
4e :4 0 8c :4 0
51 :2 0 85 :3 0
435 7c1 7c3 :3 0
51 :2 0 8d :4 0
438 7c5 7c7 :3 0
51 :2 0 74 :3 0
8e :3 0 19 :2 0
8f :2 0 43b 7ca
7ce 43f 7c9 7d0
:3 0 442 7be 7d2
:2 0 7d4 445 7d5
7b0 7d4 0 7d6
448 0 7e4 ea
:3 0 48 :3 0 eb
:3 0 a :3 0 e9
:3 0 ec :3 0 bd
:4 0 f0 1 :a 0
7e0 :2 0 7e4 7d8
7de :2 0 9 :3 0
48 :3 0 7e2 :2 0
7e4 44a 7e7 :3 0
7e7 0 7e7 7e6
7e4 7e5 :6 0 7e9
1 :3 0 44f 7eb
451 7ea 7e9 :2 0
7ec 453 :2 0 7ee
456 7ee 7ed 74d
7ec :6 0 7ef :2 0
2 18 7ee 7f2
:3 0 7f1 7ef 7f3
:8 0 
48e
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 2f
1 34 1 39
1 3e 1 43
1 48 1 4d
1 54 1 52
1 5b 1 59
1 60 1 66
1 6c 1 72
1 77 1 7c
1 82 1 88
1 8e 1 96
1 94 1 9d
1 9b 1 a4
1 a2 1 a9
1 af 1 b5
1 bb 1 c1
1 c7 1 cd
1 d3 1 d9
1 df 1 e5
1 eb 1 f1
1 f7 1 fd
1 103 1 109
1 10f 1 115
1 11b 1 121
1 127 1 12d
1 133 1 139
1 13f 1 145
1 14b 1 151
1 157 1 15d
1 16a 1 176
2 179 17b 2
17e 180 2 182
184 2 186 188
2 18a 18c 2
192 194 2 196
198 2 19a 19b
2 19d 19e 2
18e 1a0 2 1a2
1a4 2 1aa 1ac
2 1ae 1b0 2
1b2 1b3 2 1b5
1b6 2 1a6 1b8
2 1ba 1bc 2
1be 1c0 2 1c2
1c4 2 1c6 1c8
2 1ca 1cc 4
172 178 17d 1ce
1 1d0 1 1d2
2 1dc 1de 3
1da 1db 1e0 2
1e9 1eb 2 1e8
1ed 1 1ef 1
1f1 2 242 247
1 24e 1 249
2 261 263 3
25f 260 265 2
26e 270 2 272
274 2 276 278
2 27a 27c 2
27e 280 3 285
286 287 2 282
289 2 26d 28b
1 28d 1 28f
2 258 290 1
294 1 253 2
251 298 1 2a3
2 29f 2a3 2
2af 2b1 3 2ad
2ae 2b3 2 2bc
2be 2 2c0 2c2
2 2c4 2c6 1
2ce 2 2d0 2d1
2 2c8 2d3 2
2d5 2d7 2 2d9
2db 2 2dd 2df
2 2e1 2e3 2
2bb 2e5 1 2e7
1 2e9 2 2f3
2f5 3 2f1 2f2
2f7 2 300 302
2 2ff 304 1
306 1 308 3
30f 310 311 3
2ea 309 313 1
315 1 317 1
31c 3 32c 32d
32e 1 332 2
330 332 3 339
33a 33b 1 33f
2 33d 33f 2
34d 34f 3 34b
34c 351 2 35a
35c 2 35e 360
2 362 364 1
36c 2 36e 36f
2 366 371 2
373 375 2 377
379 2 37b 37d
2 37f 381 2
359 383 1 385
1 387 2 391
393 3 38f 390
395 2 39e 3a0
2 39d 3a2 1
3a4 1 3a6 3
3ad 3ae 3af 3
388 3a7 3b1 1
3b3 2 3be 3c3
1 3ca 1 3c5
2 3dd 3df 3
3db 3dc 3e1 2
3ea 3ec 2 3ee
3f0 2 3f2 3f4
2 3f6 3f8 2
3fa 3fc 3 401
402 403 2 3fe
405 2 3e9 407
1 409 1 40b
2 3d4 40c 1
410 1 3cf 2
3cd 414 3 41c
41d 41e 1 422
2 420 422 2
427 42a 2 434
436 3 432 433
438 2 441 443
2 445 447 2
449 44b 1 453
2 455 456 2
44d 458 2 440
45a 1 45c 1
45e 2 468 46a
3 466 467 46c
2 475 477 2
474 479 1 47b
1 47d 2 484
485 3 45f 47e
487 2 489 48a
5 325 328 3b4
417 48b 1 48d
1 491 a 497
498 499 49a 49b
49c 49d 49e 49f
4a0 2 4a5 4a6
1 4aa 2 4a8
4aa 1 4ae 8
4b8 4b9 4ba 4bb
4bc 4bd 4be 4bf
1 4c2 1 4c4
1 4c6 3 4cd
4ce 4cf 1 4d2
3 4d5 4d6 4d7
1 4db 2 4d9
4db 3 4e0 4e1
4e2 1 4e5 3
4e9 4ea 4eb 1
4ee 2 4f0 4f1
1 4f2 2 4f4
4f5 1 4f7 2
506 50b 1 512
1 50d 2 525
527 3 523 524
529 2 532 534
2 536 538 2
53a 53c 2 53e
540 2 542 544
3 549 54a 54b
2 546 54d 2
531 54f 1 551
1 553 2 51c
554 1 558 1
517 2 515 55c
2 563 564 2
569 56a 2 566
56c 2 55f 56f
1 571 2 57f
580 2 584 585
8 578 579 57a
57b 57c 57d 582
587 2 58c 58d
1 591 2 58f
591 2 59c 59e
3 59a 59b 5a0
2 5a9 5ab 2
5ad 5af 2 5b1
5b3 1 5bb 2
5bd 5be 2 5b5
5c0 2 5c2 5c4
2 5c6 5c8 2
5ca 5cc 2 5ce
5d0 2 5a8 5d2
1 5d4 1 5d6
2 5e0 5e2 3
5de 5df 5e4 2
5ed 5ef 2 5ec
5f1 1 5f3 1
5f5 3 5fc 5fd
5fe 3 5d7 5f6
600 1 620 2
61f 620 1 628
1 62e 2 630
631 2 61d 632
1 639 1 634
2 64c 64e 3
64a 64b 650 2
659 65b 2 65d
65f 2 661 663
2 665 667 2
669 66b 3 670
671 672 2 66d
674 2 658 676
1 678 1 67a
2 643 67b 1
67f 1 63e 2
63c 683 2 606
686 2 689 68a
1 68e 2 69a
69c 3 698 699
69e 2 6a7 6a9
2 6ab 6ad 2
6af 6b1 1 6b7
2 6b9 6ba 2
6b3 6bc 2 6be
6c0 2 6c2 6c4
2 6c6 6c8 2
6ca 6cc 2 6a6
6ce 1 6d0 1
6d2 2 6dc 6de
3 6da 6db 6e0
2 6e9 6eb 2
6e8 6ed 1 6ef
1 6f1 2 6f7
6f8 3 6fa 6fb
6fc 2 707 709
3 705 706 70b
2 714 716 2
718 71a 2 71c
71e 1 726 2
728 729 2 720
72b 2 72d 72f
2 731 733 2
735 737 2 739
73b 2 713 73d
1 73f 1 741
3 748 749 74a
15 1d3 1f2 1f5
1f8 29b 316 48e
494 4a3 4c5 4f6
572 575 58a 68b
691 6d3 6f2 6fe
742 74c 2 759
75b 3 757 758
75d 2 766 768
2 765 76a 2
771 775 2 777
779 2 77b 77f
2 770 781 2
76c 783 1 785
3 786 791 795
1 750 2 7a8
7aa 3 7a6 7a7
7ac 2 7b5 7b7
2 7b4 7b9 2
7c0 7c2 2 7c4
7c6 3 7cb 7cc
7cd 2 7c8 7cf
2 7bf 7d1 2
7bb 7d3 1 7d5
4 79f 7d6 7df
7e3 1 7e7 1
79a 2 798 7eb
37 1f 26 2d
32 37 3c 41
46 4b 50 57
5e 64 6a 70
75 7a 80 86
8c 92 99 a0
a7 ad b3 b9
bf c5 cb d1
d7 dd e3 e9
ef f5 fb 101
107 10d 113 119
11f 125 12b 131
137 13d 143 149
14f 155 15b 162

1
4
0 
7f2
0
1
14
a
3c
0 1 2 1 4 1 6 1
8 1 0 0 0 0 0 0
0 0 0 0 
11b 1 0
157 1 0
43 1 0
b5 1 0
127 1 0
d9 1 0
b 1 0
109 1 0
39 1 0
1a 1 0
6c 1 0
cd 1 0
df 1 0
f 1 0
59 1 0
3e 1 0
133 1 0
82 1 0
139 1 0
7c 1 0
72 1 0
121 1 0
e5 1 0
bb 1 0
f7 1 0
115 1 0
77 1 0
a9 1 0
c1 1 0
34 1 0
145 1 0
8e 1 0
60 1 0
103 1 0
4d 1 0
151 1 0
3 1 0
66 1 0
94 1 0
2f 1 0
c7 1 0
10f 1 0
d3 1 0
f1 1 0
52 1 0
13f 1 0
88 1 0
9b 1 0
28 1 0
eb 1 0
7 1 0
21 1 0
2 0 1
12d 1 0
48 1 0
fd 1 0
a2 1 0
af 1 0
14b 1 0
15d 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_DATES;
ALTER FUNCTION SP_U_WP_DATES COMPILE DEBUG;
/**************************************************************************/
Prompt == FUNCTION FC_U_WP_ACTUAL ==
CREATE OR REPLACE FUNCTION FC_U_WP_ACTUAL wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
16b
2 :e:
1FUNCTION:
1FC_U_WP_ACTUAL:
1H_ASSIGN_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1SH_H_NEW_WORK_PERCENT:
1PLS_INTEGER:
1SH_H_ACTUAL:
1SH_H_UNITS:
1H_REC_USER:
1H_ERROR_ID:
1RETURN:
1H_NEW_WORK_PERCENT:
1H_ACTUAL:
1H_UNITS:
1H_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RES_ID:
1H_SD:
1DATE:
1H_FD:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_LAST_SUBMITTED:
1H_WEEK_OF:
1H_DAYOFYEAR:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_REC_STATUS:
1H_LAST_MINUTES:
10:
1H_COUNT:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_EFFORT:
1H_WORK_PERCENT:
1H_PERCENT_UNITS:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_LAST_DAY:
1H_PER_DAY:
1H_TASK_TYPE:
1H_TPH_DELETE:
1H_TEMP_VAR:
1H_MINUTES:
1H_DURATION:
1H_CONTOUR:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_WORK:
1H_SCHED_EFFORT:
1H_WORK_TYPE:
1H_ETC:
1H_CLOSE_TASK:
1H_REMAINING:
1H_ROLLUP_BITS:
1H_BITID:
1RAW:
136:
1PMO_CNST:
1SC_ZERO_BIT:
1H_BITID1:
1H_ASSIGN_STRING:
18192:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1DEBUG_PERFTIMING:
1T_TOTAL:
1S_TIME_1:
1S_TIME_2:
1S_TIME_3:
1S_TIME_4:
1H_CONF_FLAG:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_WP_ACTUAL(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
186:
1+:
1FPUT:
1               ENTER:: FC_U_WP_ACTUAL(87) :: cplan.sql(15468) :: :
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1LAST_SUBMITTED:
1WORK_TODATE:
1SCHED_WORK:
1ETC:
1LAST_SCHED_MIN:
1PROJECT_ASSIGNMENT_ID:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1ASSIGN_UNITS:
1UNITS_MSP:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1TO_DATE:
1SUBSTR:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1ROLLUP_BITS:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, RESOURCE_ID, RESOURCE_TYPE, BIT_FLAG, LAST_SUBMITTED, WORK+
1_TODATE, SCHED_WORK-WORK_TODATE, ETC,:n      SCHED_WORK, LAST_SCHED_MIN, PROJ+
1ECT_ASSIGNMENT_ID, C_CONTOUR, C_EFFORT, T_UNIT, C_UNIT, CASE WHEN ASSIGN_UNIT+
1S > UNITS_MSP THEN ASSIGN_UNITS ELSE UNITS_MSP END,:n      UNRESOLVED_START, +
1UNRESOLVED_FINISH, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(SubStr(U+
1NRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n      REGULAR_COST, SP+
1ECIAL_COST, REGULAR_RATE, SPECIAL_RATE,:n      B_REGULAR_COST, B_SPECIAL_COST+
1, B_REGULAR_RATE, B_SPECIAL_RATE,:n      MILESTONE_PERCENT, TASK_ID, ROLLUP_B+
1ITS:n      INTO h_project_id, h_res_id, h_res_type, h_bit_flag, h_last_submit+
1ted, h_work_todate, h_remaining, h_etc,:n      h_effort, h_last_day, h_prj_as+
1sign_id, h_contour, h_work, h_eunit, h_unit, h_percent_units,:n      h_start_+
1date, h_finish_date, h_SD, h_FD, h_billable, h_capital_expense,:n      h_reg_+
1cost, h_spec_cost, h_reg_sale, h_spec_sale,:n      h_b_reg_cost, h_b_spec_cos+
1t, h_b_reg_sale, h_b_spec_sale,:n      h_work_percent, h_task_id, h_rollup_bi+
1ts:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID = h_id:
1PMO_DB2M:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1114:
1           EXCEPTION:: FC_U_WP_ACTUAL(115) :: cplan.sql(15496) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TASK_TYPE:
1SCHED_EFFORT:
1SCHED_DURATION:
1MINUTE_PER_DAY:
1REC_STATUS:
1CONFIG_FLAG:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, TASK_TYPE, SCHED_EFFORT, WORK_TODATE, MILESTONE_PERCENT, S+
1CHED_DURATION, MINUTE_PER_DAY, REC_STATUS, CONFIG_FLAG:n         INTO h_proje+
1ct_id, h_task_type, h_effort, h_work_todate, h_work_percent, h_duration, h_pe+
1r_day, h_rec_status, h_conf_flag:n         FROM TMT_WBS:n         WHERE ELEME+
1NT_ID = h_id:
1133:
1           EXCEPTION:: FC_U_WP_ACTUAL(134) :: cplan.sql(15515) :: :
1141:
1                EXIT:: FC_U_WP_ACTUAL(142) :: cplan.sql(15523) :: :
1RECORD_NOT_FOUND:
1T:
1148:
1                EXIT:: FC_U_WP_ACTUAL(149) :: cplan.sql(15530) :: :
1CANNOT_UPDATE_LOCKED_RECORD:
1BITAND:
1SC_WBS_ENFORCE_TC_TS:
1156:
1                EXIT:: FC_U_WP_ACTUAL(157) :: cplan.sql(15538) :: :
1SC_TIMESHEET_STEP_EXISTS:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK:n         INTO h_temp_var:n         FROM PROJECT_DETAILS:n +
1        WHERE PROJECT_ID = h_project_id:
1175:
1           EXCEPTION:: FC_U_WP_ACTUAL(176) :: cplan.sql(15557) :: :
1>:
1SELECT REC_STATUS:n            INTO h_rec_status:n            FROM TMT_WBS:n +
1           WHERE ELEMENT_ID = h_project_id:
1194:
1           EXCEPTION:: FC_U_WP_ACTUAL(195) :: cplan.sql(15576) :: :
1PMO_ORASTD:
1STRCMP:
1L:
1202:
1                EXIT:: FC_U_WP_ACTUAL(203) :: cplan.sql(15584) :: :
1LEV_LOCKED_BY_COPY:
1COUNT:
1DUAL:
1A:
1TA:
1ACTIVITIES:
1TYPE_ID:
1SC_TIMESHEET_ACTIVITY:
1SELECT COUNT('X'):n         INTO h_temp_var:n         FROM DUAL:n         WHE+
1RE EXISTS(:n         SELECT A.ELEMENT_ID:n         FROM TASK_ASSIGNMENTS TA, +
1ACTIVITIES A:n         WHERE TA.PROJECT_ID = h_project_id:n         AND TA.TA+
1SK_ID = h_id:n         AND TA.TSK_ASSIGNMENT_ID = A.TSK_ASSIGNMENT_ID:n      +
1   AND A.TSK_ASSIGNMENT_ID <> A.ELEMENT_ID:n         AND A.TYPE_ID = pmo_cnst+
1.SC_TIMESHEET_ACTIVITY):
1230:
1           EXCEPTION:: FC_U_WP_ACTUAL(231) :: cplan.sql(15612) :: :
1238:
1                EXIT:: FC_U_WP_ACTUAL(239) :: cplan.sql(15620) :: :
18:
1245:
1      RETURN_INVALID:: FC_U_WP_ACTUAL(246) :: cplan.sql(15627) :: :
1STATE:: :
1INVALID_PARAMS:
1248:
1                EXIT:: FC_U_WP_ACTUAL(249) :: cplan.sql(15630) :: :
1PMODEFINES:
1PMO_RETURN_INVALID:
1FALSE:
1ELSIF:
1!=:
1256:
1                EXIT:: FC_U_WP_ACTUAL(257) :: cplan.sql(15638) :: :
1SC_TASK_ACTUAL_GRATER_THAN_SCH:
1FC_U_TASK_PERCENT:
1268:
1      RETURN_INVALID:: FC_U_WP_ACTUAL(269) :: cplan.sql(15650) :: :
1271:
1                EXIT:: FC_U_WP_ACTUAL(272) :: cplan.sql(15653) :: :
1279:
1                EXIT:: FC_U_WP_ACTUAL(280) :: cplan.sql(15661) :: :
1298:
1           EXCEPTION:: FC_U_WP_ACTUAL(299) :: cplan.sql(15680) :: :
1317:
1           EXCEPTION:: FC_U_WP_ACTUAL(318) :: cplan.sql(15699) :: :
1325:
1                EXIT:: FC_U_WP_ACTUAL(326) :: cplan.sql(15707) :: :
1SELECT MINUTE_PER_DAY, TASK_TYPE, REC_STATUS, CONFIG_FLAG:n         INTO h_pe+
1r_day, h_task_type, h_rec_status, h_conf_flag:n         FROM TMT_WBS:n       +
1  WHERE PROJECT_ID = h_project_id :n         AND ELEMENT_ID = h_task_id:
1345:
1           EXCEPTION:: FC_U_WP_ACTUAL(346) :: cplan.sql(15727) :: :
1353:
1                EXIT:: FC_U_WP_ACTUAL(354) :: cplan.sql(15735) :: :
1361:
1                EXIT:: FC_U_WP_ACTUAL(362) :: cplan.sql(15743) :: :
1SELECT COUNT('X'):n         INTO h_temp_var:n         FROM DUAL:n         WHE+
1RE EXISTS(:n         SELECT ELEMENT_ID:n         FROM ACTIVITIES:n         WH+
1ERE TSK_ASSIGNMENT_ID = h_id:n         AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n +
1        AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY):
1386:
1           EXCEPTION:: FC_U_WP_ACTUAL(387) :: cplan.sql(15768) :: :
1394:
1                EXIT:: FC_U_WP_ACTUAL(395) :: cplan.sql(15776) :: :
1SC_FD_EFFORT_DRIVEN:
1SC_FIXED_DURATION:
1DAY_YEAR:
1MIN:
1TASK_DAY_OF_YEAR:
1ACTUAL_FLAG:
1SELECT COUNT(DAY_YEAR), MIN(DAY_YEAR) :n                  INTO h_count, h_day+
1ofyear :n                  FROM TASK_DAY_OF_YEAR:n                  WHERE PRO+
1JECT_ID = h_project_id:n                  AND TSK_ASSIGNMENT_ID = h_id:n     +
1             AND ACTUAL_FLAG = 0:
1422:
1           EXCEPTION:: FC_U_WP_ACTUAL(423) :: cplan.sql(15804) :: :
1IS NOT NULL:
1-:
1FC_TPHASE_SCHED_ASSIGN:
1SCHED_MIN:
1ACTUAL_MIN:
1SELECT SCHED_MIN - ACTUAL_MIN INTO h_minutes:n                        FROM TA+
1SK_DAY_OF_YEAR :n                        WHERE PROJECT_ID = h_project_id AND +
1TSK_ASSIGNMENT_ID = h_id AND DAY_YEAR = TO_DATE(SubStr(h_last_submitted, 1, 1+
10)):
1449:
1           EXCEPTION:: FC_U_WP_ACTUAL(450) :: cplan.sql(15831) :: :
110000:
1TRUNC:
1TO_NUMBER:
1/:
10.49:
1*:
1FC_FD_U_TDY:
110000.00:
1PMO_FUNC:
1BIT_OR:
1SC_BIT_30:
1U_ASSIGN_STRING:
1<:
1CONSIDER:
1PMO_STPU:
1SC_SCHED_BIT:
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_new_actual,:n           +
1                WORK_TODATE = h_new_actual,:n                           ETC =+
1 h_etc,:n                           MILESTONE_PERCENT = 10000:n              +
1             WHERE TSK_ASSIGNMENT_ID = h_id:
1FOUND:
1TRUE:
1100:
1513:
1           EXCEPTION:: FC_U_WP_ACTUAL(514) :: cplan.sql(15895) :: :
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_new_actual,:n           +
1                WORK_TODATE = h_new_actual,:n                           ETC =+
1 0,:n                           MILESTONE_PERCENT = 10000:n                  +
1         WHERE TSK_ASSIGNMENT_ID = h_id:
1541:
1           EXCEPTION:: FC_U_WP_ACTUAL(542) :: cplan.sql(15923) :: :
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_etc,:n                  +
1         WORK_TODATE = h_new_actual:n                           WHERE TSK_ASS+
1IGNMENT_ID = h_id:
1571:
1           EXCEPTION:: FC_U_WP_ACTUAL(572) :: cplan.sql(15953) :: :
1600:
1           EXCEPTION:: FC_U_WP_ACTUAL(601) :: cplan.sql(15982) :: :
1UPDATE TASK_ASSIGNMENTS:n                     SET CONSIDER = 7,:n            +
1         ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_SCHED_BIT),:n +
1                    SCHED_WORK = h_new_actual,:n                     WORK_TOD+
1ATE = h_new_actual,:n                     ETC = 0,:n                     MILE+
1STONE_PERCENT = 10000:n                     WHERE TSK_ASSIGNMENT_ID = h_id:
1631:
1           EXCEPTION:: FC_U_WP_ACTUAL(632) :: cplan.sql(16013) :: :
1MAX:
1WEEK_OF:
1TIMESHEET_APPROVAL_STATUS:
1SELECT MAX(WEEK_OF):n                     INTO h_week_of:n                   +
1  FROM TIMESHEET_APPROVAL_STATUS:n                     WHERE ELEMENT_ID = h_p+
1roject_id:n                     AND RESOURCE_ID = h_res_id:
1653:
1           EXCEPTION:: FC_U_WP_ACTUAL(654) :: cplan.sql(16035) :: :
1SELECT TO_DATE(SubStr(h_week_of, 1, 10)) + 7      INTO h_week_of FROM DUAL:
1669:
1           EXCEPTION:: FC_U_WP_ACTUAL(670) :: cplan.sql(16051) :: :
1STRNCMP:
110:
1DB2TIMESTAMP:
1TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)):n                        INTO h_start_date:n      +
1                  FROM DUAL:
1692:
1           EXCEPTION:: FC_U_WP_ACTUAL(693) :: cplan.sql(16074) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                        INTO h_start_dat+
1e:n                        FROM DUAL:
1709:
1           EXCEPTION:: FC_U_WP_ACTUAL(710) :: cplan.sql(16091) :: :
1FC_DEL_NOACTUAL:
12:
1FC_RESCHEDULE:
1733:
1                EXIT:: FC_U_WP_ACTUAL(734) :: cplan.sql(16115) :: :
1FC_U_ASSIGN_PERCENT:
1755:
1                EXIT:: FC_U_WP_ACTUAL(756) :: cplan.sql(16137) :: :
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS:n            SET MILESTONE_PERCENT = h_new_work_perce+
1nt,:n            ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PERCEN+
1T_COMPLETE_BIT):n            WHERE TSK_ASSIGNMENT_ID = h_id:
1809:
1           EXCEPTION:: FC_U_WP_ACTUAL(810) :: cplan.sql(16191) :: :
1UPDATE TMT_WBS:n            SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo+
1_cnst.SC_PERCENT_COMPLETE_BIT):n            WHERE PROJECT_ID = h_project_id:n+
1            AND ELEMENT_ID = h_task_id:
1836:
1           EXCEPTION:: FC_U_WP_ACTUAL(837) :: cplan.sql(16218) :: :
1103079040:
1849:
1                EXIT:: FC_U_WP_ACTUAL(850) :: cplan.sql(16231) :: :
1SELECT UNITS_MSP:n               INTO h_temp_var:n               FROM TASK_AS+
1SIGNMENTS:n               WHERE TSK_ASSIGNMENT_ID = h_prj_assign_id:
1871:
1           EXCEPTION:: FC_U_WP_ACTUAL(872) :: cplan.sql(16253) :: :
1SC_SQL_SUCCESS:
1881:
1                EXIT:: FC_U_WP_ACTUAL(882) :: cplan.sql(16263) :: :
1TASK_ASSIGNMENT_ERROR:
1FC_U_TDY_LAST_ACTUAL:
1SC_BIT_29:
1SELECT TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(SubStr(UNRESOLVED_FI+
1NISH, 1, 10)) INTO h_SD, h_FD:n               FROM TASK_ASSIGNMENTS WHERE TSK+
1_ASSIGNMENT_ID = h_id:
1917:
1           EXCEPTION:: FC_U_WP_ACTUAL(918) :: cplan.sql(16299) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                  INTO h_start_date:n   +
1               FROM DUAL:
1959:
1           EXCEPTION:: FC_U_WP_ACTUAL(960) :: cplan.sql(16341) :: :
1978:
1                EXIT:: FC_U_WP_ACTUAL(979) :: cplan.sql(16360) :: :
1CONTOUR_TYPE:
1SC_PLANNED_BIT:
1UPDATE TASK_ASSIGNMENTS:n                  SET CONSIDER = 7,:n               +
1   UNITS_MSP = h_percent_units,:n                  C_EFFORT = 0,:n           +
1       C_UNIT = 0,:n                  C_CONTOUR = 0,:n                  CONTO+
1UR_TYPE = 0,:n                  ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,(pm+
1o_cnst.SC_SCHED_BIT+pmo_cnst.SC_PLANNED_BIT)):n                  WHERE TSK_AS+
1SIGNMENT_ID = h_id:
11004:
1           EXCEPTION:: FC_U_WP_ACTUAL(1005) :: cplan.sql(16386) :: :
1FC_ROLLUP:
11022:
1                EXIT:: FC_U_WP_ACTUAL(1023) :: cplan.sql(16404) :: :
0

0
0
1713
2
0 a0 8d 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 90 :3 a0 b0 3f 90
:3 a0 b0 3f b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c :2 a0 6b 81 b0 a3 a0 51
a5 1c :2 a0 6b 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 :2 a0
6b :2 a0 6b 6e a5 b a 10
:2 a0 6b 6e :2 a0 6b 6e a5 b
6e 7e a0 b4 2e 6e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 d :4d a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :15 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 19 3c
:2 a0 :2 51 a5 b 7e 6e b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c :3 a0 51 a5 b :2 a0
6b a5 b 5a a0 7e a0 6b
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c a0 51 d
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 6e
a5 b 7e 51 b4 2e :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c b7 19 3c a0 51 d :1b a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b :2 a0 6b
a0 a5 b 65 a0 b7 :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e a0 51 d :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 a0 b7 :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e a0
51 d b7 :2 19 3c :2 a0 d :8 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b a5 b d b7 19
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b :2 a0 6b a0 a5 b 65
b7 :2 19 3c b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c a0
51 d :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 6e a5 b 7e 51 b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c b7 19 3c :d a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 :2 51 a5 b 7e 6e b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c :3 a0 51 a5 b :2 a0
6b a5 b 5a a0 7e a0 6b
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c a0 51 d
:c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :3 a0 51 a5
b d :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 d
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e :2 a0 51 a5 b
a0 7e a0 6b b4 2e :2 a0 51
a5 b a0 7e a0 6b b4 2e
52 10 a0 4d d :c a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
7e b4 2e 5a :2 a0 d b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e a0 7e 51 b4 2e d :c a0
a5 b d :2 a0 51 a5 b 7e
51 b4 2e 5a a0 7e b4 2e
:2 5a a 10 :c a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
7e :2 a0 51 a5 b b4 2e d
a0 51 d b7 19 3c :5 a0 a5
b 51 a5 b 7e :3 a0 a5 b
51 a5 b b4 2e 5a 7e 51
b4 2e a5 b d :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
7e :2 a0 51 a5 b b4 2e d
b7 :3 a0 51 a5 b d b7 :2 19
3c :9 a0 51 a5 b d :5 a0 a5
b 51 a5 b 7e :3 a0 a5 b
51 a5 b b4 2e 5a 7e 51
b4 2e a5 b d :3 a0 6b :2 a0
51 a5 b :2 a0 6b a5 b d
:7 a0 51 a5 b :2 a0 51 a5 b
a5 b d a0 51 d :c a0 a5
b d b7 19 3c b7 a0 7e
51 b4 2e d :c a0 a5 b d
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e :2 a0 6b :2 a0 a5
b 7e 51 b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d a0 51 d :2 a0 51 a5 b
7e :2 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e 5a b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e 5a 7e :2 a0 51 a5 b
b4 2e d :11 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 6b :2 a0 51 a5
b :2 a0 6b a5 b d b7 :10 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :2 a0 51 a5 b 7e
:2 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e 5a b4 2e :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d :5 a0 a5 b 51 a5 b
7e :3 a0 a5 b 51 a5 b b4
2e 5a 7e 51 b4 2e 5a 7e
51 b4 2e a5 b d :e a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d a0 51 d :10 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :2 19 3c b7 :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d a0 51 d :10 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c a0
7e b4 2e 5a a0 4d d :8 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 7e b4 2e 5a :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d b7 19 3c a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :3 a0 6b :2 a0 51 a5 b :2 a0
6b a5 b 5a d :a a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 :a a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 19
3c a0 7e b4 2e 5a :4 a0 51
a5 b d b7 :2 a0 :2 51 a5 b
7e 6e b4 2e :4 a0 51 a5 b
d b7 :4 a0 51 a5 b d b7
:2 19 3c b7 :2 19 3c a0 51 d
:8 a0 51 :2 a0 51 a5 b a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 51
a5 b 65 b7 19 3c b7 :2 19
3c :2 a0 d b7 :5 a0 a5 b 51
a5 b 7e :3 a0 a5 b 51 a5
b b4 2e 5a 7e 51 b4 2e
5a 7e 51 b4 2e a5 b d
b7 :2 19 3c :1b a0 51 a5 b :2 a0
51 a5 b a5 b d :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 51 a5 b 65
a0 b7 :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :b a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :b a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 b7
19 :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
b7 :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 19 3c
:3 a0 51 a5 b d b7 :2 19 3c
a0 7e b4 2e 5a :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 5a a 10 :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
19 3c b7 19 3c :2 a0 51 a5
b a0 7e a0 6b b4 2e :2 a0
51 a5 b a0 7e a0 6b b4
2e 52 10 a0 7e 51 b4 2e
d :c a0 a5 b d :2 a0 51 a5
b 7e 51 b4 2e 5a a0 7e
b4 2e :2 5a a 10 :9 a0 51 a5
b d b7 19 3c :4 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
5a 7e 51 b4 2e 5a 7e 51
b4 2e a5 b d :9 a0 51 a5
b d :3 a0 6b :2 a0 51 a5 b
:2 a0 6b a5 b d :5 a0 :2 51 a5
b d :b a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 51 d :c a0
a5 b d b7 a0 7e 51 b4
2e d :c a0 a5 b d :2 a0 51
a5 b 7e 51 b4 2e 5a a0
7e b4 2e :2 5a a 10 :9 a0 51
a5 b d b7 19 3c a0 7e
b4 2e 5a :4 a0 51 a5 b d
b7 :2 a0 :2 51 a5 b 7e 6e b4
2e :4 a0 51 a5 b d b7 :4 a0
51 a5 b d b7 :2 19 3c b7
:2 19 3c a0 7e b4 2e 5a :a a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d b7 19 3c
a0 51 d a0 51 d :8 a0 51
:2 a0 51 a5 b a5 b d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
:12 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c b7 :2 19
3c b7 :2 19 3c :2 a0 6b :2 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
1713
2
0 3 7 2b 1f 23 27 1e
32 3f 3b 1b 47 50 4c 3a
58 65 61 37 6d 7e 72 76
7a 60 85 9a 8e 92 96 5d
a1 8d a6 aa ae b2 cf ba
be c6 ca 8a eb d6 da e2
e6 b9 10b f6 fa 102 106 b6
127 112 116 119 11a 122 f5 144
132 f2 136 137 13f 131 161 14f
12e 153 154 15c 14e 17e 16c 14b
170 171 179 16b 19b 189 168 18d
18e 196 188 1b7 1a6 1aa 1b2 185
1cf 1be 1c2 1ca 1a5 1eb 1da 1de
1e6 1a2 203 1f2 1f6 1fe 1d9 21f
20e 212 21a 1d6 237 226 22a 232
20d 253 242 246 24e 20a 26f 25a
25e 261 262 26a 241 28c 27a 23e
27e 27f 287 279 2a9 297 276 29b
29c 2a4 296 2c5 2b4 2b8 293 2c0
2b3 2e1 2d0 2d4 2b0 2dc 2cf 2fd
2ec 2f0 2cc 2f8 2eb 319 308 30c
2e8 314 307 335 324 328 304 330
323 351 340 344 320 34c 33f 36d
35c 360 33c 368 35b 389 378 37c
358 384 377 3a5 394 398 374 3a0
393 3c1 3b0 3b4 390 3bc 3af 3dd
3cc 3d0 3ac 3d8 3cb 3f9 3e8 3ec
3c8 3f4 3e7 415 404 408 3e4 410
403 431 420 424 400 42c 41f 44d
43c 440 41c 448 43b 469 458 45c
438 464 457 485 474 478 454 480
473 4a1 490 494 470 49c 48f 4bd
4ac 4b0 48c 4b8 4ab 4d9 4c8 4cc
4a8 4d4 4c7 4f5 4e4 4e8 4c4 4f0
4e3 511 500 504 4e0 50c 4ff 52d
51c 520 4fc 528 51b 549 538 53c
518 544 537 565 554 558 534 560
553 581 570 574 550 57c 56f 59d
58c 590 56c 598 58b 5b9 5a8 5ac
588 5b4 5a7 5e1 5c4 5a4 5c8 5c9
5d1 5d5 5d9 5dc 5c3 609 5ec 5c0
5f0 5f1 5f9 5fd 601 604 5eb 626
614 5e8 618 619 621 613 642 631
635 610 63d 630 65e 64d 651 62d
659 64c 67a 669 66d 649 675 668
696 685 689 665 691 684 6b2 6a1
6a5 681 6ad 6a0 6ce 6bd 6c1 69d
6c9 6bc 6ea 6d9 6dd 6b9 6e5 6d8
706 6f5 6f9 6d5 701 6f4 722 711
715 6f1 71d 710 73e 72d 731 70d
739 72c 75a 749 74d 729 755 748
776 765 769 745 771 764 792 781
785 761 78d 780 7ae 79d 7a1 77d
7a9 79c 7ca 7b9 7bd 799 7c5 7b8
7d1 7d5 7b5 7d9 7dd 7e1 7e4 7e9
7ea 1 7ec 7f1 7f5 7f9 7fc 801
805 809 80c 811 812 814 819 81c
820 821 826 82b 82e 833 834 839
83c 840 841 846 849 84e 84f 854
857 85c 85d 862 865 869 86d 871
872 874 879 87a 87c 87d 882 885
88a 88b 890 893 897 89b 89f 8a0
8a2 8a7 8a8 8aa 8ab 8b0 8b3 8b8
8b9 8be 8c1 8c5 8c9 8cd 8ce 8d0
8d5 8d6 8d8 8d9 8de 8e1 8e6 8e7
8ec 8ef 8f4 8f5 8fa 8fd 901 902
907 90a 90f 910 915 918 91d 91e
923 926 92b 92c 931 934 938 939
93e 941 946 947 94c 94f 954 955
95a 95b 960 962 966 969 96d 971
974 978 97c 97f 982 987 98a 98d
990 991 996 997 1 999 99e 9a2
9a6 9a9 9ae 9b3 9b6 9ba 9bb 9c0
9c1 9c6 9c8 9cc 9cf 9d3 9d7 9db
9df 9e3 9e7 9eb 9ef 9f3 9f7 9fb
9ff a03 a07 a0b a0f a13 a17 a1b
a1f a23 a27 a2b a2f a33 a37 a3b
a3f a43 a47 a4b a4f a53 a57 a5b
a5f a63 a67 a6b a6f a73 a77 a7b
a7f a83 a87 a8b a8f a93 a97 a9b
a9f aa3 aa7 aab aaf ab3 ab7 abb
abf ac3 ac7 acb acf ad3 ad7 adb
adf ae3 ae7 aeb aef af3 af7 afb
aff b03 b07 b0b b0f b1b b1f b23
b26 b2a b2e b30 b34 b38 b3c b3f
b43 b47 b49 b4a b4f 1 b53 b57
b5b b5e b62 b66 b6a b6e b71 b75
b79 b7c b7f b84 b87 b8a b8d b8e
b93 b94 1 b96 b9b b9f ba3 ba6
bab bb0 bb3 bb7 bb8 bbd bc0 bc5
bc6 bcb bce bd3 bd4 bd9 bdc be0
be1 be6 be9 bee bef bf4 bf7 bfb
bff c02 c05 c06 c08 c09 c0e c0f
c14 c16 c1a c1d c1f c23 c25 c31
c33 c35 c36 c3b c3f c41 c4d c4f
c53 c57 c5a c5e c61 c65 c68 c69
c6e c71 c75 c79 c7d c81 c85 c89
c8d c91 c95 c99 c9d ca1 ca5 ca9
cad cb1 cb5 cb9 cbd cc1 cc5 cd1
cd5 cd9 cdc ce0 ce4 ce6 cea cee
cf2 cf5 cf9 cfd cff d00 d05 1
d09 d0d d11 d14 d18 d1c d20 d24
d27 d2b d2f d32 d35 d3a d3d d40
d43 d44 d49 d4a 1 d4c d51 d55
d59 d5c d61 d66 d69 d6d d6e d73
d76 d7b d7c d81 d84 d89 d8a d8f
d92 d96 d97 d9c d9f da4 da5 daa
dad db1 db5 db8 dbb dbc dbe dbf
dc4 dc5 dca dcc dd0 dd3 dd5 dd9
ddb de7 de9 deb dec df1 df5 df7
e03 e05 e09 e0d e10 e14 e17 e1b
e1e e1f e24 e27 e2b e2f e33 e37
e3b e3e e42 e46 e49 e4c e51 e54
e57 e5a e5b e60 e61 1 e63 e68
e6c e70 e73 e78 e7d e80 e84 e85
e8a e8b e90 e92 e96 e99 e9d ea1
ea5 ea8 eac eae eb2 eb5 eb9 ebd
ec0 ec3 ec4 ec6 ec9 ece ecf ed4
ed8 edc ee0 ee4 ee8 eeb eef ef3
ef6 ef9 efe f01 f04 f07 f08 f0d
f0e 1 f10 f15 f19 f1d f20 f25
f2a f2d f31 f32 f37 f38 f3d f3f
f43 f46 f4a f4e f52 f55 f59 f5b
f5f f62 f66 f6a f6e f71 f72 f74
f78 f7c f7f f80 f82 f85 f89 f8c
f90 f93 f94 f99 f9d fa1 fa5 fa9
fad fb0 fb4 fb8 fbb fbe fc3 fc6
fc9 fcc fcd fd2 fd3 1 fd5 fda
fde fe2 fe5 fea fef ff2 ff6 ff7
ffc ffd 1002 1004 1008 100b 100f 1013
1017 101a 101e 1020 1024 1027 102b 102e
1032 1036 103a 103e 1042 1046 1052 1056
105a 105d 1061 1065 1067 106b 106f 1073
1076 107a 107e 1080 1081 1086 1 108a
108e 1092 1095 1099 109d 10a1 10a5 10a8
10ac 10b0 10b3 10b6 10bb 10be 10c1 10c4
10c5 10ca 10cb 1 10cd 10d2 10d6 10da
10dd 10e2 10e7 10ea 10ee 10ef 10f4 10f7
10fc 10fd 1102 1105 110a 110b 1110 1113
1117 1118 111d 1120 1125 1126 112b 112e
1132 1136 1139 113c 113d 113f 1140 1145
1146 114b 114d 1151 1154 1156 115a 115c
1168 116a 116c 116d 1172 1176 1178 1184
1186 118a 118e 1191 1192 1194 1197 119a
119b 11a0 11a4 11a8 11ac 11b0 11b4 11c0
11c4 11c8 11cb 11cf 11d3 11d5 11d9 11dd
11e1 11e4 11e8 11ec 11ee 11ef 11f4 1
11f8 11fc 1200 1203 1207 120b 120f 1213
1216 121a 121e 1221 1224 1229 122c 122f
1232 1233 1238 1239 1 123b 1240 1244
1248 124b 1250 1255 1258 125c 125d 1262
1265 126a 126b 1270 1273 1278 1279 127e
1281 1285 1286 128b 128e 1293 1294 1299
129c 12a0 12a4 12a7 12aa 12ab 12ad 12ae
12b3 12b4 12b9 12bb 12bf 12c2 12c4 12c8
12ca 12d6 12d8 12da 12db 12e0 12e4 12e6
12f2 12f4 12f8 12fc 12ff 1303 1308 1309
130b 130e 1311 1312 1317 131b 131f 1323
1327 132b 132e 1332 1336 1339 133c 1341
1344 1347 134a 134b 1350 1351 1 1353
1358 135c 1360 1363 1368 136d 1370 1374
1375 137a 137b 1380 1382 1386 1389 138d
1391 1395 1398 139c 139e 13a2 13a5 13a7
13ab 13ae 13b2 13b5 13b9 13bd 13c1 13c5
13c9 13cd 13d1 13d5 13d9 13dd 13e1 13e5
13e9 13ed 13f1 13f5 13f9 13fd 1401 1405
1409 140d 1411 1415 1419 141d 1421 1425
1431 1435 1439 143c 1440 1444 1446 144a
144e 1452 1455 1459 145d 145f 1460 1465
1 1469 146d 1471 1474 1478 147c 1480
1484 1487 148b 148f 1492 1495 149a 149d
14a0 14a3 14a4 14a9 14aa 1 14ac 14b1
14b5 14b9 14bc 14c1 14c6 14c9 14cd 14ce
14d3 14d6 14db 14dc 14e1 14e4 14e9 14ea
14ef 14f2 14f6 14f7 14fc 14ff 1504 1505
150a 150d 1511 1515 1518 151b 151c 151e
151f 1524 1525 152a 152c 1530 1533 1535
1539 153b 1547 1549 154b 154c 1551 1555
1557 1563 1565 1569 156d 1570 1571 1573
1576 1579 157a 157f 1583 1587 158b 158f
1593 1596 159a 159e 15a1 15a4 15a9 15ac
15af 15b2 15b3 15b8 15b9 1 15bb 15c0
15c4 15c8 15cb 15d0 15d5 15d8 15dc 15dd
15e2 15e3 15e8 15ea 15ee 15f1 15f5 15f9
15fd 1600 1604 1606 160a 160d 1611 1615
1618 1619 161b 161e 1621 1622 1627 162b
162f 1632 1636 163a 163d 1640 1645 1648
164b 164e 164f 1654 1655 1 1657 165c
1660 1664 1667 166c 1671 1674 1678 1679
167e 1681 1686 1687 168c 168f 1694 1695
169a 169d 16a1 16a5 16a9 16ad 16b0 16b1
16b3 16b8 16b9 16bb 16bc 16c1 16c2 16c7
16c9 16cd 16d0 16d4 16d8 16db 16df 16e3
16e6 16e9 16ee 16f1 16f4 16f7 16f8 16fd
16fe 1 1700 1705 1709 170d 1710 1715
171a 171d 1721 1722 1727 1728 172d 172f
1733 1736 173a 173e 1742 1745 1749 174d
1750 1754 1755 1757 175b 175f 1761 1765
1769 176c 176d 176f 1773 1776 177a 177d
177e 1780 1781 1786 178a 178d 1791 1795
1799 179c 179d 179f 17a3 17a6 17aa 17ad
17ae 17b0 17b1 17b6 17ba 17be 17c2 17c6
17ca 17cd 17d1 17d5 17d8 17db 17e0 17e3
17e6 17e9 17ea 17ef 17f0 1 17f2 17f7
17fb 17ff 1802 1807 180c 180f 1813 1814
1819 181a 181f 1821 1825 1828 182c 1830
1834 1837 183b 183f 1841 1845 1849 184c
184d 184f 1853 1856 185a 185d 185e 1860
1861 1866 186a 186d 1871 1873 1877 187b
187e 1882 1886 188a 188e 1892 1896 189a
189e 18a2 18a6 18aa 18ad 18ae 18b0 18b4
18b8 18bb 18bc 18be 18c2 18c6 18c9 18ca
18cc 18cd 18cf 18d3 18d5 18d9 18dd 18e1
18e4 18e8 18ec 18ef 18f2 18f7 18fa 18fd
1900 1901 1906 1907 1 1909 190e 1912
1916 1919 191e 1923 1926 192a 192b 1930
1933 1938 1939 193e 1941 1946 1947 194c
194f 1953 1957 195b 195f 1962 1963 1965
196a 196b 196d 196e 1973 1974 1979 197b
197f 1982 1986 198a 198d 1991 1995 1998
199b 19a0 19a3 19a6 19a9 19aa 19af 19b0
1 19b2 19b7 19bb 19bf 19c2 19c7 19cc
19cf 19d3 19d4 19d9 19da 19df 19e1 19e5
19e8 19ec 19f0 19f4 19f7 19fb 19ff 1a02
1a06 1a07 1a09 1a0d 1a0f 1a13 1a17 1a1a
1a1c 1a20 1a24 1a27 1a28 1a2a 1a2d 1a30
1a31 1a36 1a3a 1a3e 1a42 1a46 1a4a 1a4d
1a51 1a55 1a58 1a5b 1a60 1a63 1a66 1a69
1a6a 1a6f 1a70 1 1a72 1a77 1a7b 1a7f
1a82 1a87 1a8c 1a8f 1a93 1a94 1a99 1a9a
1a9f 1aa1 1aa5 1aa8 1aac 1ab0 1ab4 1ab7
1abb 1abd 1ac1 1ac4 1ac8 1acb 1acf 1ad3
1ad7 1adb 1adf 1ae3 1aef 1af3 1af7 1afa
1afe 1b02 1b04 1b08 1b0c 1b10 1b13 1b17
1b1b 1b1d 1b1e 1b23 1 1b27 1b2b 1b2f
1b32 1b36 1b3a 1b3e 1b42 1b45 1b49 1b4d
1b50 1b53 1b58 1b5b 1b5e 1b61 1b62 1b67
1b68 1 1b6a 1b6f 1b73 1b77 1b7a 1b7f
1b84 1b87 1b8b 1b8c 1b91 1b94 1b99 1b9a
1b9f 1ba2 1ba7 1ba8 1bad 1bb0 1bb4 1bb5
1bba 1bbd 1bc2 1bc3 1bc8 1bcb 1bcf 1bd3
1bd6 1bd9 1bda 1bdc 1bdd 1be2 1be3 1be8
1bea 1bee 1bf1 1bf3 1bf7 1bf9 1c05 1c07
1c09 1c0a 1c0f 1c13 1c15 1c21 1c23 1c27
1c2b 1c2e 1c2f 1c31 1c34 1c37 1c38 1c3d
1c41 1c45 1c49 1c4d 1c51 1c5d 1c61 1c65
1c68 1c6c 1c70 1c72 1c76 1c7a 1c7e 1c81
1c85 1c89 1c8b 1c8c 1c91 1 1c95 1c99
1c9d 1ca0 1ca4 1ca8 1cac 1cb0 1cb3 1cb7
1cbb 1cbe 1cc1 1cc6 1cc9 1ccc 1ccf 1cd0
1cd5 1cd6 1 1cd8 1cdd 1ce1 1ce5 1ce8
1ced 1cf2 1cf5 1cf9 1cfa 1cff 1d02 1d07
1d08 1d0d 1d10 1d15 1d16 1d1b 1d1e 1d22
1d23 1d28 1d2b 1d30 1d31 1d36 1d39 1d3d
1d41 1d44 1d47 1d48 1d4a 1d4b 1d50 1d51
1d56 1d58 1d5c 1d5f 1d61 1d65 1d67 1d73
1d75 1d77 1d78 1d7d 1d81 1d83 1d8f 1d91
1d95 1d99 1d9c 1da0 1da5 1da6 1da8 1dab
1dae 1daf 1db4 1db8 1dbc 1dc0 1dc4 1dc8
1dcb 1dcf 1dd3 1dd6 1dd9 1dde 1de1 1de4
1de7 1de8 1ded 1dee 1 1df0 1df5 1df9
1dfd 1e00 1e05 1e0a 1e0d 1e11 1e12 1e17
1e18 1e1d 1e1f 1e23 1e26 1e2a 1e2e 1e32
1e35 1e39 1e3b 1e3f 1e42 1e44 1e48 1e4b
1e4f 1e53 1e57 1e5b 1e5f 1e63 1e67 1e6b
1e6f 1e73 1e77 1e7b 1e7f 1e8b 1e8f 1e93
1e96 1e9a 1e9e 1ea0 1ea4 1ea8 1eac 1eaf
1eb3 1eb7 1eb9 1eba 1ebf 1 1ec3 1ec7
1ecb 1ece 1ed2 1ed6 1eda 1ede 1ee1 1ee5
1ee9 1eec 1eef 1ef4 1ef7 1efa 1efd 1efe
1f03 1f04 1 1f06 1f0b 1f0f 1f13 1f16
1f1b 1f20 1f23 1f27 1f28 1f2d 1f30 1f35
1f36 1f3b 1f3e 1f43 1f44 1f49 1f4c 1f50
1f51 1f56 1f59 1f5e 1f5f 1f64 1f67 1f6b
1f6f 1f72 1f75 1f76 1f78 1f79 1f7e 1f7f
1f84 1f86 1f8a 1f8d 1f8f 1f93 1f95 1fa1
1fa3 1fa5 1fa6 1fab 1faf 1fb1 1fbd 1fbf
1fc3 1fc7 1fca 1fcd 1fce 1fd0 1fd3 1fd8
1fd9 1fde 1fe2 1fe6 1fea 1fee 1ff2 1ff5
1ff9 1ffd 2000 2003 2008 200b 200e 2011
2012 2017 2018 1 201a 201f 2023 2027
202a 202f 2034 2037 203b 203c 2041 2042
2047 2049 204d 2050 2054 2058 205c 205f
2063 2065 2069 206c 2070 2074 2078 207b
207c 207e 2082 2086 2089 208a 208c 208f
2093 2096 209a 209d 209e 20a3 20a7 20ab
20af 20b3 20b7 20ba 20be 20c2 20c5 20c8
20cd 20d0 20d3 20d6 20d7 20dc 20dd 1
20df 20e4 20e8 20ec 20ef 20f4 20f9 20fc
2100 2101 2106 2107 210c 210e 2112 2115
2119 211d 2121 2124 2128 212a 212e 2131
2135 2138 213c 2140 2144 2148 214c 2150
2154 2158 215c 2160 2164 2168 216c 2178
217c 2180 2183 2187 218b 218d 2191 2195
2199 219c 21a0 21a4 21a6 21a7 21ac 1
21b0 21b4 21b8 21bb 21bf 21c3 21c7 21cb
21ce 21d2 21d6 21d9 21dc 21e1 21e4 21e7
21ea 21eb 21f0 21f1 1 21f3 21f8 21fc
2200 2203 2208 220d 2210 2214 2215 221a
221d 2222 2223 2228 222b 2230 2231 2236
2239 223d 223e 2243 2246 224b 224c 2251
2254 2258 225c 225f 2262 2263 2265 2266
226b 226c 2271 2273 2277 227a 227c 2280
2282 228e 2290 2292 2293 2298 229c 229e
22aa 22ac 22b0 22b4 22b7 22b8 22ba 22bd
22c0 22c1 22c6 22ca 22ce 22d2 22d6 22da
22dd 22e1 22e5 22e8 22eb 22f0 22f3 22f6
22f9 22fa 22ff 2300 1 2302 2307 230b
230f 2312 2317 231c 231f 2323 2324 2329
232a 232f 2331 2335 2338 233c 2340 2344
2347 234b 234d 2351 2354 2358 235c 2360
2363 2364 2366 236a 236e 2372 2375 2376
2378 237c 237f 2383 2386 2387 2389 238a
238f 2393 2397 239b 239f 23a3 23a6 23a7
23a9 23ad 23b0 23b4 23b7 23b8 23ba 23bb
23c0 23c4 23c8 23cb 23cc 23ce 23d2 23d5
23d9 23dc 23dd 23e2 23e6 23ea 23ed 23ee
23f0 23f4 23f7 23fb 23fe 23ff 1 2404
2409 240d 240e 2412 2416 241a 241e 2422
2426 242a 242e 2432 2436 243a 243e 2442
244e 2452 2456 2459 245d 2461 2463 2467
246b 246f 2472 2476 247a 247c 247d 2482
1 2486 248a 248e 2491 2495 2499 249d
24a1 24a4 24a8 24ac 24af 24b2 24b7 24ba
24bd 24c0 24c1 24c6 24c7 1 24c9 24ce
24d2 24d6 24d9 24de 24e3 24e6 24ea 24eb
24f0 24f3 24f8 24f9 24fe 2501 2506 2507
250c 250f 2513 2514 2519 251c 2521 2522
2527 252a 252e 2532 2535 2538 2539 253b
253c 2541 2542 2547 2549 254d 2550 2552
2556 2558 2564 2566 2568 2569 256e 2572
2574 2580 2582 2586 2589 258a 258f 2592
2596 259a 259e 25a0 25a4 25a7 25ab 25af
25b2 25b3 25b5 25b8 25bb 25bc 25c1 25c5
25c8 25cb 25cc 25d1 25d5 25d9 25dd 25e1
25e5 25e9 25ed 25f1 25f5 25f9 25fd 2601
2605 2606 2608 260c 2610 2614 2617 2618
261a 261d 2620 2621 2626 2629 262d 2630
2631 2636 2639 1 263c 2641 2645 2649
264d 2651 2655 2659 265d 2661 2665 2669
266d 2671 267d 2681 2685 2688 268c 2690
2692 2696 269a 269e 26a1 26a5 26a9 26ab
26ac 26b1 1 26b5 26b9 26bd 26c0 26c4
26c8 26cc 26d0 26d3 26d7 26db 26de 26e1
26e6 26e9 26ec 26ef 26f0 26f5 26f6 1
26f8 26fd 2701 2705 2708 270d 2712 2715
2719 271a 271f 2722 2727 2728 272d 2730
2735 2736 273b 273e 2742 2743 2748 274b
2750 2751 2756 2759 275d 2761 2764 2767
2768 276a 276b 2770 2771 2776 2778 277c
277f 2781 2785 2787 2793 2795 2797 2798
279d 27a1 27a3 27af 27b1 27b5 27b9 27bd
27c0 27c1 27c3 27c6 27ca 27ce 27d1 27d2
27d4 27d5 27da 27dd 27e1 27e5 27e8 27e9
27eb 27ec 27f1 27f5 27f9 27fc 2800 2802
2806 2809 280d 2811 2815 2819 281d 281e
2820 2823 2824 2826 2829 282d 2831 2835
2836 2838 283b 283c 283e 283f 2844 2847
284a 284d 284e 2853 2854 2856 285a 285e
2862 2866 2869 286a 286c 286f 2873 2877
287a 287b 287d 287e 2883 2887 288b 288f
2892 2893 2895 2899 289c 28a0 28a3 28a4
28a6 28a7 28ac 28b0 28b4 28b8 28bb 28bc
28be 28c1 28c5 28c9 28cc 28cd 28cf 28d0
28d5 28d8 28dc 28e0 28e3 28e4 28e6 28e7
28ec 28f0 28f2 28f6 28fa 28fe 2901 2902
2904 2908 290a 290e 2912 2915 2919 291d
2921 2925 2929 292d 2931 2935 2939 293c
293d 293f 2943 2947 294b 294f 2953 2957
2958 295a 295d 295e 2960 2963 2967 296b
296f 2970 2972 2975 2976 2978 2979 297e
2981 2984 2987 2988 298d 298e 2990 2994
2998 299c 29a0 29a3 29a7 29ab 29ae 29af
29b1 29b5 29b9 29bc 29bd 29bf 29c3 29c7
29cb 29cf 29d3 29d7 29db 29df 29e2 29e3
29e5 29e9 29ed 29f0 29f1 29f3 29f4 29f6
29fa 29fe 2a01 2a05 2a09 2a0d 2a11 2a15
2a19 2a1d 2a21 2a25 2a29 2a2d 2a31 2a35
2a36 2a38 2a3c 2a3e 2a42 2a45 2a47 2a4b
2a4e 2a51 2a52 2a57 2a5b 2a5f 2a63 2a67
2a6b 2a6f 2a73 2a77 2a7b 2a7f 2a83 2a87
2a8b 2a8c 2a8e 2a92 2a96 2a9a 2a9d 2a9e
2aa0 2aa4 2aa7 2aab 2aae 2aaf 2ab1 2ab2
2ab7 2abb 2abf 2ac2 2ac6 2aca 2acb 2acd
2ad0 2ad3 2ad4 2ad9 2add 2ae1 2ae5 2ae8
2ae9 2aeb 2aee 2af2 2af6 2af9 2afa 2afc
2afd 2b02 2b06 2b0a 2b0d 2b11 2b15 2b19
2b1c 2b1d 2b1f 2b22 2b26 2b2a 2b2d 2b2e
2b30 2b33 2b37 2b3b 2b3e 2b3f 2b41 2b42
2b47 2b4a 2b4b 2b50 2b54 2b58 2b5c 2b5f
2b60 2b62 2b65 2b69 2b6d 2b70 2b71 2b73
2b74 2b79 2b7c 2b7f 2b83 2b87 2b8a 2b8b
2b8d 2b8e 2b93 2b97 2b9b 2b9f 2ba3 2ba7
2bab 2baf 2bb3 2bb7 2bbb 2bbf 2bc3 2bc7
2bcb 2bcf 2bd3 2bd7 2bdb 2be7 2beb 2bf0
2bf4 2bf7 2bf8 2bfd 2c01 2c05 2c08 2c0b
2c0f 2c11 2c15 2c19 2c1c 2c1f 2c23 2c25
2c29 2c2d 2c30 2c32 2c36 2c3a 2c3e 2c41
2c45 2c49 2c4b 2c4c 2c51 1 2c55 2c59
2c5d 2c60 2c64 2c68 2c6c 2c70 2c73 2c77
2c7b 2c7e 2c81 2c86 2c89 2c8c 2c8f 2c90
2c95 2c96 1 2c98 2c9d 2ca1 2ca5 2ca8
2cad 2cb2 2cb5 2cb9 2cba 2cbf 2cc2 2cc7
2cc8 2ccd 2cd0 2cd5 2cd6 2cdb 2cde 2ce2
2ce3 2ce8 2ceb 2cf0 2cf1 2cf6 2cf9 2cfd
2d01 2d04 2d07 2d08 2d0a 2d0b 2d10 2d11
2d16 2d18 2d1c 2d1f 2d21 2d25 2d27 2d33
2d35 2d37 2d38 2d3d 2d41 2d43 2d4f 2d51
2d55 2d59 2d5d 2d60 2d64 2d68 2d6b 2d6c
2d6e 2d72 2d76 2d79 2d7a 2d7c 2d80 2d82
2d86 2d8a 2d8e 2d92 2d96 2d9a 2d9e 2da2
2da6 2daa 2dae 2db2 2db6 2dba 2dbe 2dc2
2dce 2dd2 2dd7 2ddb 2dde 2ddf 2de4 2de8
2dec 2def 2df2 2df6 2df8 2dfc 2e00 2e03
2e06 2e0a 2e0c 2e10 2e14 2e17 2e19 2e1d
2e21 2e25 2e28 2e2c 2e30 2e32 2e33 2e38
1 2e3c 2e40 2e44 2e47 2e4b 2e4f 2e53
2e57 2e5a 2e5e 2e62 2e65 2e68 2e6d 2e70
2e73 2e76 2e77 2e7c 2e7d 1 2e7f 2e84
2e88 2e8c 2e8f 2e94 2e99 2e9c 2ea0 2ea1
2ea6 2ea9 2eae 2eaf 2eb4 2eb7 2ebc 2ebd
2ec2 2ec5 2ec9 2eca 2ecf 2ed2 2ed7 2ed8
2edd 2ee0 2ee4 2ee8 2eeb 2eee 2eef 2ef1
2ef2 2ef7 2ef8 2efd 2eff 2f03 2f06 2f08
2f0c 2f0e 2f1a 2f1c 2f1e 2f1f 2f24 2f28
2f2a 2f36 2f38 2f3a 2f3e 2f42 2f45 2f47
2f4b 2f4f 2f52 2f53 2f55 2f58 2f5c 2f60
2f63 2f64 2f66 2f69 2f6d 2f71 2f74 2f75
2f77 2f78 2f7d 2f80 2f81 2f86 2f8a 2f8e
2f92 2f95 2f96 2f98 2f9b 2f9f 2fa3 2fa6
2fa7 2fa9 2faa 2faf 2fb3 2fb7 2fbb 2fbf
2fc3 2fc7 2fc8 2fca 2fcd 2fce 2fd0 2fd3
2fd7 2fdb 2fdf 2fe0 2fe2 2fe5 2fe6 2fe8
2fe9 2fee 2ff1 2ff4 2ff7 2ff8 2ffd 3000
3003 3006 3007 300c 300d 300f 3013 3017
301b 301f 3023 3027 302b 302f 3033 3037
303b 303f 3043 3047 304b 3057 305b 3060
3064 3067 3068 306d 3071 3075 3078 307b
307f 3081 3085 3089 308c 308f 3093 3095
3099 309d 30a0 30a2 30a6 30aa 30ae 30b1
30b5 30b9 30bb 30bc 30c1 1 30c5 30c9
30cd 30d0 30d4 30d8 30dc 30e0 30e3 30e7
30eb 30ee 30f1 30f6 30f9 30fc 30ff 3100
3105 3106 1 3108 310d 3111 3115 3118
311d 3122 3125 3129 312a 312f 3132 3137
3138 313d 3140 3145 3146 314b 314e 3152
3153 3158 315b 3160 3161 3166 3169 316d
3171 3174 3177 3178 317a 317b 3180 3181
3186 3188 318c 318f 3191 3195 3197 31a3
31a5 31a7 31a8 31ad 31b1 31b3 31bf 31c1
31c3 31c7 31cb 31cf 31d2 31d3 31d5 31d8
31dc 31e0 31e3 31e4 31e6 31e7 31ec 31f0
31f4 31f7 31fb 31ff 3203 3207 320b 320f
3213 3217 321b 321f 3223 3227 322b 322f
3233 3237 323b 3247 324b 3250 3254 3257
3258 325d 3261 3265 3268 326b 326f 3271
3275 3279 327c 327f 3283 3285 3289 328d
3290 3292 3296 329a 329e 32a1 32a5 32a9
32ab 32ac 32b1 1 32b5 32b9 32bd 32c0
32c4 32c8 32cc 32d0 32d3 32d7 32db 32de
32e1 32e6 32e9 32ec 32ef 32f0 32f5 32f6
1 32f8 32fd 3301 3305 3308 330d 3312
3315 3319 331a 331f 3322 3327 3328 332d
3330 3335 3336 333b 333e 3342 3343 3348
334b 3350 3351 3356 3359 335d 3361 3364
3367 3368 336a 336b 3370 3371 3376 3378
337c 337f 3381 3385 3387 3393 3395 3397
3398 339d 33a1 33a3 33af 33b1 33b3 33b7
33bb 33be 33c0 33c4 33c8 33cb 33cd 33d1
33d5 33d9 33dc 33dd 33df 33e2 33e6 33ea
33ed 33ee 33f0 33f1 33f6 33fa 33fe 3401
3405 3409 340d 3411 3415 3419 341d 3421
3425 3429 342d 3431 3435 3439 343d 3441
3445 3451 3455 345a 345e 3461 3462 3467
346b 346f 3472 3475 3479 347b 347f 3483
3486 3489 348d 348f 3493 3497 349a 349c
34a0 34a4 34a8 34ab 34af 34b3 34b5 34b6
34bb 1 34bf 34c3 34c7 34ca 34ce 34d2
34d6 34da 34dd 34e1 34e5 34e8 34eb 34f0
34f3 34f6 34f9 34fa 34ff 3500 1 3502
3507 350b 350f 3512 3517 351c 351f 3523
3524 3529 352c 3531 3532 3537 353a 353f
3540 3545 3548 354c 354d 3552 3555 355a
355b 3560 3563 3567 356b 356e 3571 3572
3574 3575 357a 357b 3580 3582 3586 3589
358b 358f 3591 359d 359f 35a1 35a2 35a7
35ab 35ad 35b9 35bb 35bd 35c1 35c5 35c8
35cc 35cf 35d0 35d5 35d8 35dc 35dd 35e1
35e5 35e9 35ed 35f1 35f5 35f9 35fd 3601
360d 3611 3615 3618 361c 3620 3622 3626
362a 362e 3631 3635 3639 363b 363c 3641
1 3645 3649 364d 3650 3654 3658 365c
3660 3663 3667 366b 366e 3671 3676 3679
367c 367f 3680 3685 3686 1 3688 368d
3691 3695 3698 369d 36a2 36a5 36a9 36aa
36af 36b2 36b7 36b8 36bd 36c0 36c5 36c6
36cb 36ce 36d2 36d3 36d8 36db 36e0 36e1
36e6 36e9 36ed 36f1 36f4 36f7 36f8 36fa
36fb 3700 3701 3706 3708 370c 370f 3711
3715 3717 3723 3725 3727 3728 372d 3731
3733 373f 3741 3745 3748 3749 374e 3751
3755 3759 375d 3761 3765 3771 3775 3779
377c 3780 3784 3786 378a 378e 3792 3795
3799 379d 379f 37a0 37a5 1 37a9 37ad
37b1 37b4 37b8 37bc 37c0 37c4 37c7 37cb
37cf 37d2 37d5 37da 37dd 37e0 37e3 37e4
37e9 37ea 1 37ec 37f1 37f5 37f9 37fc
3801 3806 3809 380d 380e 3813 3816 381b
381c 3821 3824 3829 382a 382f 3832 3836
3837 383c 383f 3844 3845 384a 384d 3851
3855 3858 385b 385c 385e 385f 3864 3865
386a 386c 3870 3873 3875 3879 387b 3887
3889 388b 388c 3891 3895 3897 38a3 38a5
38a9 38ad 38b0 38b4 38b8 38bb 38bc 38be
38c1 38c4 38c5 38ca 38ce 38d2 38d6 38d8
38dc 38df 38e3 38e5 38e9 38ed 38f0 38f1
38f3 38f6 38f9 38fa 38ff 3903 3907 390b
390e 3912 3916 3919 391a 391c 3920 3924
3927 3928 392a 392d 3931 3935 3939 393d
3941 3945 3949 394d 3951 3955 3959 3965
3969 396d 3970 3974 3978 397a 397e 3982
3986 3989 398d 3991 3993 3994 3999 1
399d 39a1 39a5 39a8 39ac 39b0 39b4 39b8
39bb 39bf 39c3 39c6 39c9 39ce 39d1 39d4
39d7 39d8 39dd 39de 1 39e0 39e5 39e9
39ed 39f0 39f5 39fa 39fd 3a01 3a02 3a07
3a0a 3a0f 3a10 3a15 3a18 3a1d 3a1e 3a23
3a26 3a2a 3a2b 3a30 3a33 3a38 3a39 3a3e
3a41 3a45 3a49 3a4c 3a4f 3a50 3a52 3a53
3a58 3a59 3a5e 3a60 3a64 3a67 3a69 3a6d
3a6f 3a7b 3a7d 3a7f 3a80 3a85 3a89 3a8b
3a97 3a99 3a9b 3a9f 3aa3 3aa7 3aab 3aaf
3ab3 3ab7 3abb 3abf 3ac3 3ac7 3ad3 3ad7
3adb 3ade 3ae2 3ae6 3ae8 3aec 3af0 3af4
3af7 3afb 3aff 3b01 3b02 3b07 1 3b0b
3b0f 3b13 3b16 3b1a 3b1e 3b22 3b26 3b29
3b2d 3b31 3b34 3b37 3b3c 3b3f 3b42 3b45
3b46 3b4b 3b4c 1 3b4e 3b53 3b57 3b5b
3b5e 3b63 3b68 3b6b 3b6f 3b70 3b75 3b78
3b7d 3b7e 3b83 3b86 3b8b 3b8c 3b91 3b94
3b98 3b99 3b9e 3ba1 3ba6 3ba7 3bac 3baf
3bb3 3bb7 3bba 3bbd 3bbe 3bc0 3bc1 3bc6
3bc7 3bcc 3bce 3bd2 3bd5 3bd7 3bdb 3bdd
3be9 3beb 3bed 3bee 3bf3 3bf7 3bf9 3c05
3c07 3c09 3c0d 3c11 3c14 3c16 3c1a 3c1d
3c21 3c24 3c25 3c2a 3c2d 3c31 3c35 3c39
3c3d 3c40 3c41 3c43 3c47 3c49 3c4d 3c51
3c54 3c57 3c58 3c5a 3c5d 3c62 3c63 3c68
3c6c 3c70 3c74 3c78 3c7b 3c7c 3c7e 3c82
3c84 3c88 3c8c 3c90 3c94 3c97 3c98 3c9a
3c9e 3ca0 3ca4 3ca8 3cab 3cad 3cb1 3cb5
3cb8 3cbc 3cbf 3cc3 3cc7 3ccb 3ccf 3cd3
3cd7 3cdb 3cdf 3ce3 3ce6 3cea 3cee 3cf1
3cf2 3cf4 3cf5 3cf7 3cfb 3cff 3d03 3d06
3d07 3d09 3d0c 3d0f 3d10 3d15 3d19 3d1d
3d21 3d25 3d29 3d2c 3d30 3d34 3d37 3d3a
3d3f 3d42 3d45 3d48 3d49 3d4e 3d4f 1
3d51 3d56 3d5a 3d5e 3d61 3d66 3d6b 3d6e
3d72 3d73 3d78 3d79 3d7e 3d80 3d84 3d87
3d8b 3d8f 3d93 3d96 3d97 3d99 3d9d 3d9f
3da3 3da6 3da8 3dac 3db0 3db3 3db7 3dbb
3dbf 3dc1 3dc5 3dc9 3dcd 3dd1 3dd5 3dd6
3dd8 3ddb 3ddc 3dde 3de1 3de5 3de9 3ded
3dee 3df0 3df3 3df4 3df6 3df7 3dfc 3dff
3e02 3e05 3e06 3e0b 3e0e 3e11 3e14 3e15
3e1a 3e1b 3e1d 3e21 3e23 3e27 3e2b 3e2e
3e32 3e36 3e3a 3e3e 3e42 3e46 3e4a 3e4e
3e52 3e56 3e5a 3e5e 3e62 3e66 3e6a 3e6e
3e72 3e76 3e7a 3e7e 3e82 3e86 3e8a 3e8e
3e92 3e96 3e9a 3e9d 3e9e 3ea0 3ea4 3ea8
3eab 3eac 3eae 3eaf 3eb1 3eb5 3eb9 3ebd
3ec1 3ec5 3ec9 3ecc 3ed0 3ed4 3ed7 3eda
3edf 3ee2 3ee5 3ee8 3ee9 3eee 3eef 1
3ef1 3ef6 3efa 3efe 3f01 3f06 3f0b 3f0e
3f12 3f13 3f18 3f19 3f1e 3f20 3f24 3f27
3f2b 3f2f 3f33 3f36 3f37 3f39 3f3d 3f41
3f43 3f47 3f4b 3f4e 3f4f 3f51 3f55 3f58
3f5c 3f5f 3f60 3f62 3f63 3f68 3f6c 3f70
3f74 3f78 3f7c 3f80 3f84 3f88 3f8c 3f90
3f94 3fa0 3fa4 3fa9 3fad 3fb0 3fb1 3fb6
3fba 3fbe 3fc1 3fc4 3fc8 3fca 3fce 3fd2
3fd5 3fd8 3fdc 3fde 3fe2 3fe6 3fe9 3feb
3fef 3ff3 3ff7 3ffa 3ffe 4002 4004 4005
400a 1 400e 4012 4016 4019 401d 4021
4025 4029 402c 4030 4034 4037 403a 403f
4042 4045 4048 4049 404e 404f 1 4051
4056 405a 405e 4061 4066 406b 406e 4072
4073 4078 407b 4080 4081 4086 4089 408e
408f 4094 4097 409b 409c 40a1 40a4 40a9
40aa 40af 40b2 40b6 40ba 40bd 40c0 40c1
40c3 40c4 40c9 40ca 40cf 40d1 40d5 40d8
40da 40de 40e0 40ec 40ee 40f0 40f1 40f6
40fa 40fc 4108 410a 410e 4112 4116 411a
411e 4122 4126 412a 412e 4132 4136 4142
4146 414b 414f 4152 4153 4158 415c 4160
4163 4166 416a 416c 4170 4174 4177 417a
417e 4180 4184 4188 418b 418d 4191 4195
4199 419c 41a0 41a4 41a6 41a7 41ac 1
41b0 41b4 41b8 41bb 41bf 41c3 41c7 41cb
41ce 41d2 41d6 41d9 41dc 41e1 41e4 41e7
41ea 41eb 41f0 41f1 1 41f3 41f8 41fc
4200 4203 4208 420d 4210 4214 4215 421a
421d 4222 4223 4228 422b 4230 4231 4236
4239 423d 423e 4243 4246 424b 424c 4251
4254 4258 425c 425f 4262 4263 4265 4266
426b 426c 4271 4273 4277 427a 427c 4280
4282 428e 4290 4292 4293 4298 429c 429e
42aa 42ac 42b0 42b2 42b6 42ba 42be 42c1
42c2 42c4 42c8 42cb 42cf 42d2 42d3 42d5
42d6 42db 42df 42e3 42e6 42e7 42e9 42ec
42ef 42f0 42f5 42f9 42fc 4300 4302 4306
430a 430d 430e 4310 4313 4316 4317 431c
431f 4323 4327 432a 432b 432d 4330 4333
4334 4339 1 433c 4341 4345 4349 434d
4351 4355 4358 435c 4360 4363 4366 436b
436e 4371 4374 4375 437a 437b 1 437d
4382 4386 438a 438d 4392 4397 439a 439e
439f 43a4 43a5 43aa 43ac 43b0 43b3 43b7
43bb 43bf 43c2 43c6 43c8 43cc 43cf 43d3
43d7 43db 43de 43df 43e1 43e5 43e7 43eb
43ef 43f2 43f6 43f9 43fa 43ff 4402 4406
440a 440e 4412 4416 4422 4426 442a 442d
4431 4435 4437 443b 443f 4443 4446 444a
444e 4450 4451 4456 1 445a 445e 4462
4465 4469 446d 4471 4475 4478 447c 4480
4483 4486 448b 448e 4491 4494 4495 449a
449b 1 449d 44a2 44a6 44aa 44ad 44b2
44b7 44ba 44be 44bf 44c4 44c7 44cc 44cd
44d2 44d5 44da 44db 44e0 44e3 44e7 44e8
44ed 44f0 44f5 44f6 44fb 44fe 4502 4506
4509 450c 450d 450f 4510 4515 4516 451b
451d 4521 4524 4526 452a 452c 4538 453a
453c 453d 4542 4546 4548 4554 4556 455a
455e 4561 4565 4568 456c 456f 4570 4575
4578 457c 4580 4583 4584 4586 458a 458d
4591 4594 4595 4597 4598 459d 1 45a0
45a5 45a9 45ad 45b1 45b5 45b9 45bc 45c0
45c4 45c7 45ca 45cf 45d2 45d5 45d8 45d9
45de 45df 1 45e1 45e6 45ea 45ee 45f1
45f6 45fb 45fe 4602 4603 4608 4609 460e
4610 4614 4617 461b 461f 4623 4626 462a
462c 4630 4633 4635 4639 463c 4640 4644
4647 4648 464a 464e 4651 4655 4658 4659
465e 4662 4666 4669 466a 466c 4670 4673
4677 467a 467b 1 4680 4685 4689 468c
468f 4690 4695 4699 469d 46a1 46a5 46a9
46ad 46b1 46b5 46b9 46bd 46c1 46c5 46c9
46ca 46cc 46d0 46d4 46d8 46db 46dc 46de
46e1 46e4 46e5 46ea 46ed 46f1 46f4 46f5
46fa 46fd 1 4700 4705 4709 470d 4711
4715 4719 471d 4721 4725 4729 472c 472d
472f 4733 4735 4739 473c 4740 4744 4748
474c 474f 4750 4752 4755 4759 475d 4760
4761 4763 4764 4769 476c 476f 4772 4773
4778 477b 477e 4781 4782 4787 4788 478a
478e 4792 4796 479a 479e 47a2 47a6 47aa
47ae 47b2 47b5 47b6 47b8 47bc 47c0 47c4
47c8 47cb 47cf 47d3 47d6 47d7 47d9 47dd
47e1 47e4 47e5 47e7 47eb 47ef 47f3 47f7
47fb 47ff 4802 4805 4806 4808 480c 4810
4814 4818 481c 4820 4824 4828 482c 4830
4834 4838 4844 4848 484c 484f 4853 4857
4859 485d 4861 4865 4868 486c 4870 4872
4873 4878 1 487c 4880 4884 4887 488b
488f 4893 4897 489a 489e 48a2 48a5 48a8
48ad 48b0 48b3 48b6 48b7 48bc 48bd 1
48bf 48c4 48c8 48cc 48cf 48d4 48d9 48dc
48e0 48e1 48e6 48e9 48ee 48ef 48f4 48f7
48fc 48fd 4902 4905 4909 490a 490f 4912
4917 4918 491d 4920 4924 4928 492b 492e
492f 4931 4932 4937 4938 493d 493f 4943
4946 4948 494c 494e 495a 495c 495e 495f
4964 4968 496a 4976 4978 497c 497f 4983
4987 498b 498f 4993 4997 499b 499f 49a3
49a7 49ab 49af 49b3 49b4 49b6 49ba 49bc
49c0 49c3 49c6 49c7 49cc 49d0 49d4 49d8
49dc 49e0 49e4 49e8 49ec 49f0 49f4 49f8
49fc 4a00 4a01 4a03 4a07 4a0b 4a0f 4a12
4a13 4a15 4a18 4a1b 4a1c 4a21 4a24 4a28
4a2b 4a2c 4a31 4a34 1 4a37 4a3c 4a40
4a44 4a48 4a4c 4a50 4a54 4a58 4a5c 4a60
4a63 4a64 4a66 4a6a 4a6c 4a70 4a73 4a77
4a7a 4a7b 4a80 4a83 4a87 4a8b 4a8f 4a93
4a96 4a97 4a99 4a9d 4a9f 4aa3 4aa7 4aaa
4aad 4aae 4ab0 4ab3 4ab8 4ab9 4abe 4ac2
4ac6 4aca 4ace 4ad1 4ad2 4ad4 4ad8 4ada
4ade 4ae2 4ae6 4aea 4aed 4aee 4af0 4af4
4af6 4afa 4afe 4b01 4b03 4b07 4b0b 4b0e
4b12 4b15 4b16 4b1b 4b1e 4b22 4b26 4b2a
4b2e 4b32 4b36 4b3a 4b3e 4b42 4b46 4b52
4b56 4b5a 4b5d 4b61 4b65 4b67 4b6b 4b6f
4b73 4b76 4b7a 4b7e 4b80 4b81 4b86 1
4b8a 4b8e 4b92 4b95 4b99 4b9d 4ba1 4ba5
4ba8 4bac 4bb0 4bb3 4bb6 4bbb 4bbe 4bc1
4bc4 4bc5 4bca 4bcb 1 4bcd 4bd2 4bd6
4bda 4bdd 4be2 4be7 4bea 4bee 4bef 4bf4
4bf7 4bfc 4bfd 4c02 4c05 4c0a 4c0b 4c10
4c13 4c17 4c18 4c1d 4c20 4c25 4c26 4c2b
4c2e 4c32 4c36 4c39 4c3c 4c3d 4c3f 4c40
4c45 4c46 4c4b 4c4d 4c51 4c54 4c56 4c5a
4c5c 4c68 4c6a 4c6c 4c6d 4c72 4c76 4c78
4c84 4c86 4c8a 4c8e 4c92 4c95 4c96 4c98
4c9b 4c9f 4ca3 4ca6 4ca7 4ca9 4caa 4caf
4cb3 4cb5 4cb9 4cbc 4cc0 4cc3 4cc7 4ccb
4cce 4cd2 4cd6 4cda 4cde 4ce2 4ce6 4cea
4cee 4cf2 4cf5 4cf9 4cfd 4d00 4d01 4d03
4d04 4d06 4d0a 4d0e 4d12 4d15 4d16 4d18
4d1b 4d1e 4d1f 4d24 4d28 4d2c 4d30 4d34
4d38 4d3b 4d3f 4d43 4d46 4d49 4d4e 4d51
4d54 4d57 4d58 4d5d 4d5e 1 4d60 4d65
4d69 4d6d 4d70 4d75 4d7a 4d7d 4d81 4d82
4d87 4d88 4d8d 4d8f 4d93 4d96 4d9a 4d9e
4da2 4da5 4da9 4dab 4daf 4db3 4db7 4dbb
4dbf 4dc3 4dc7 4dcb 4dcf 4dd3 4dd7 4ddb
4ddf 4de3 4de7 4deb 4def 4df3 4dff 4e03
4e08 4e0c 4e0f 4e10 4e15 4e19 4e1d 4e20
4e23 4e27 4e29 4e2d 4e31 4e34 4e37 4e3b
4e3d 4e41 4e45 4e48 4e4a 4e4e 4e52 4e56
4e59 4e5d 4e61 4e63 4e64 4e69 1 4e6d
4e71 4e75 4e78 4e7c 4e80 4e84 4e88 4e8b
4e8f 4e93 4e96 4e99 4e9e 4ea1 4ea4 4ea7
4ea8 4ead 4eae 1 4eb0 4eb5 4eb9 4ebd
4ec0 4ec5 4eca 4ecd 4ed1 4ed2 4ed7 4eda
4edf 4ee0 4ee5 4ee8 4eed 4eee 4ef3 4ef6
4efa 4efb 4f00 4f03 4f08 4f09 4f0e 4f11
4f15 4f19 4f1c 4f1f 4f20 4f22 4f23 4f28
4f29 4f2e 4f30 4f34 4f37 4f39 4f3d 4f3f
4f4b 4f4d 4f4f 4f50 4f55 4f59 4f5b 4f67
4f69 4f6b 4f6f 4f73 4f76 4f78 4f7c 4f80
4f83 4f85 4f89 4f8d 4f90 4f92 4f96 4f9a
4f9d 4fa1 4fa5 4fa8 4fac 4fb0 4fb1 4fb3
4fb7 4fbb 4fbf 4fc2 4fc6 4fca 4fcd 4fd0
4fd5 4fd8 4fdb 4fde 4fdf 4fe4 4fe5 1
4fe7 4fec 4ff0 4ff4 4ff7 4ffc 5001 5004
5008 5009 500e 5011 5016 5017 501c 501f
5024 5025 502a 502d 5031 5035 5038 5039
503e 503f 5044 5046 504a 504d 5051 5055
5059 505c 5060 5062 5066 5068 5074 5078
507a 507b 5084 
1713
2
0 1 a 6 15 19 20 :3 6
1c :3 6 12 :3 6 11 :3 6 14 18
1f :3 6 14 18 1f :2 6 1 3
a :2 1 4 :2 17 26 17 :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 9
12 11 :2 9 :2 4 14 1d 1c :2 14
:2 4 11 1a 19 :2 11 :2 4 e 17
16 :2 e :2 4 d 16 15 :2 d :2 4
:3 9 :2 4 :3 9 :2 4 :3 11 :2 4 :3 12 :2 4
:3 15 :2 4 :3 e :2 4 :3 10 :2 4 f 18
17 :2 f :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 :2 13 22 13
:2 4 :2 c 1b c :2 4 :2 f 1e f
:2 4 :2 16 25 16 :2 4 :2 d 1c d
:2 4 :2 13 22 13 :2 4 :2 14 23 14
:2 4 :2 12 21 12 :2 4 :2 11 20 11
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 10 1f 10 :2 4 :2 11 20 11
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 c 1b c :2 4 :2 b 1a b
:2 4 :2 b 1a b :2 4 :2 13 22 13
:2 4 :2 10 1f 10 :2 4 :2 a 19 a
:2 4 :2 11 20 11 :2 4 :2 10 1f 10
:2 4 :2 12 21 12 :2 4 c 10 f
c 20 :2 29 c :2 4 d 11 10
d 21 :2 2a d :2 4 14 1d 1c
:2 14 :2 4 :2 f 19 f :2 4 :2 f 19
f :2 4 :2 10 1a 10 :2 4 :2 10 1a
10 :2 4 :2 11 1b 11 :2 4 :2 11 1b
11 :2 4 :2 12 1c 12 :2 4 :2 12 1c
12 :2 4 :2 15 24 15 :2 4 :2 c 16
c :2 4 :2 d 1c d :2 4 :2 d 1c
d :2 4 :2 d 1c d :2 4 :2 d 1c
d :2 4 :2 10 1f 10 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 56 5c 5f :2 56 6d
85 8 :2 6d d 10 :2 6d 1c 1f
:2 6d b e :2 6d 13 16 1f 27
:2 1f 3f :2 16 :2 6d b e :2 6d 13
16 1f 27 :2 1f 35 :2 16 :2 6d b
e :2 6d 13 16 1f 27 :2 1f 34
:2 16 :2 6d b e :2 6d 13 16 :2 6d
1b 1e :2 6d 29 2c :2 6d b e
:2 6d 13 16 :2 6d 1b 1e :2 6d 29
2c :2 6d 31 34 :2 6d :2 7 4c :2 4
7 :2 11 23 :2 2d 39 3c 4e 50
51 :2 4e :2 23 :3 7 :2 d 12 1e 5f
62 :2 1e :2 7 54 :3 4 c 4 e
1a 27 36 40 50 5d 68 75
7 13 23 3a 45 4f 57 69
78 87 99 7 19 2c 34 3b
56 5e 65 81 8b 7 15 23
31 7 17 27 37 7 1a 23
c 1a 24 30 3c 4e 5d 6a
7 11 1d 2e 39 41 4a 52
7 15 24 2a 30 3c 7 13
20 2c 7 15 24 32 7 17
22 c d 21 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 55 58 59 :2 55 :2 29
:3 d :2 13 18 24 66 69 :2 24 76
79 :2 24 7d 80 :2 24 8c 8f :2 24
97 9a :2 24 a6 a9 b0 b9 bc
:2 a9 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 11 1d 28 36 43 56 66
76 82 f 1d 2a 34 43 53
5f 6a 78 f 10 1d :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5b 5c
:2 58 :2 2c :3 10 :2 16 1b 27 69 6c
:2 27 79 7c :2 27 80 83 :2 27 8f
92 :2 27 9a 9d :2 27 a9 ac b3
bc bf :2 ac :2 27 :2 10 5f :2 d :2 a
:4 16 :2 a 7 :3 35 b :2 14 1f 1d
:2 28 :2 1d :2 a 18 a d :2 17 29
:2 33 3f 42 54 57 58 :2 54 :2 29
:3 d :2 13 18 24 66 69 :2 24 :2 d
5b :3 a 11 :2 1a a 38 :2 7 a
11 1f 22 :2 a 25 27 :2 25 a
18 a d :2 17 29 :2 33 3f 42
54 57 58 :2 54 :2 29 :3 d :2 13 18
24 66 69 :2 24 :2 d 5b :3 a 11
:2 1a a 2b :2 7 b 12 d 1a
:2 12 1e :2 27 :2 b a 40 3e :2 49
:2 3e a 18 a d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 :2 d 5b
:3 a 11 :2 1a a 5e :3 7 15 7
11 :2 f 10 1d :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5b 5c :2 58 :2 2c
:3 10 :2 16 1b 27 69 6c :2 27 79
7c :2 27 80 83 :2 27 8f 92 :2 27
9a 9d :2 27 a9 ac b3 bc bf
:2 ac :2 27 :2 10 5f :2 d :2 a :4 16 :2 a
7 :3 35 a 13 1f :2 a 22 24
:2 22 14 :2 12 13 20 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5e 5f :2 5b
:2 2f :3 13 :2 19 1e 2a 6c 6f :2 2a
7c 7f :2 2a 83 86 :2 2a 92 95
:2 2a 9d a0 :2 2a ac af b6 bf
c2 :2 af :2 2a :2 13 62 :2 10 :2 d :4 19
:2 d a :3 26 d :2 18 1f 2d :2 d
32 34 :2 32 d 1b d 10 :2 1a
2c :2 36 42 45 57 5a 5b :2 57
:2 2c :3 10 :2 16 1b 27 69 6c :2 27
:2 10 5e :3 d 14 :2 1d d 36 :2 a
26 :3 7 15 7 11 :2 f 11 13
f 20 24 2f 10 13 20 e
11 1b e 11 25 27 e 10
25 27 e 10 1a 23 :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5b 5c
:2 58 :2 2c :3 10 :2 16 1b 27 69 6c
:2 27 79 7c :2 27 80 83 :2 27 8f
92 :2 27 9a 9d :2 27 a9 ac b3
bc bf :2 ac :2 27 :2 10 5f :2 d :2 a
:4 16 :2 a 7 :3 35 a 13 1f :2 a
22 24 :2 22 a 18 a d :2 17
29 :2 33 3f 42 54 57 58 :2 54
:2 29 :3 d :2 13 18 24 66 69 :2 24
:2 d 5b :3 a 11 :2 1a a 26 :2 7
a 13 1d :2 a 20 22 :2 20 d
:2 17 29 :2 33 3f 42 54 57 58
:2 54 :2 29 :3 d :2 13 18 24 66 69
:2 24 76 79 :2 24 7d 80 :2 24 8a
8d 96 9e :2 a7 :2 96 b8 :2 8d :2 24
:2 d 5b :2 a d :2 17 29 :2 33 3f
42 54 57 58 :2 54 :2 29 :3 d :2 13
18 24 66 69 :2 24 :2 d 5b :3 a
11 :2 1c 2f :2 38 48 :2 11 a 7
24 d 16 20 :2 d 26 23 2f
3e :2 26 :2 23 a 1a a d 16
20 :2 d 25 23 2e 38 :2 25 :2 23
d 1b d 10 :2 1a 2c :2 36 42
45 57 5a 5b :2 57 :2 2c :3 10 :2 16
1b 27 69 6c :2 27 :2 10 5e :3 d
14 :2 1d d a 3b 10 19 23
:2 10 28 26 31 3b :2 28 :2 26 d
1d d 3e 3b :3 a 1a :2 a 18
2a 38 3e 4c 58 21 2f :2 58
33 3c 47 :2 33 4b 54 61 :2 4b
:2 18 a 41 24 d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 76 79
:2 24 7d 80 :2 24 8a 8d 96 9e
:2 a7 :2 96 b8 :2 8d :2 24 :2 d 5b :2 a
d :2 17 29 :2 33 3f 42 54 57
58 :2 54 :2 29 :3 d :2 13 18 24 66
69 :2 24 :2 d 5b :3 a 11 :2 1c 2f
:2 38 48 :2 11 a :4 7 35 a 13
1d :2 a 20 22 :2 20 a 18 a
d :2 17 29 :2 33 3f 42 54 57
58 :2 54 :2 29 :3 d :2 13 18 24 66
69 :2 24 :2 d 5b :3 a 11 :2 1a a
24 :3 7 15 7 11 :2 f 10 1d
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 58
5b 5c :2 58 :2 2c :3 10 :2 16 1b 27
69 6c :2 27 79 7c :2 27 80 83
:2 27 8f 92 :2 27 9a 9d :2 27 a9
ac b3 bc bf :2 ac :2 27 :2 10 5f
:2 d :2 a :4 16 :2 a 7 :3 4 a 13
1f :2 a 22 24 :2 22 14 :2 12 13
20 :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5e 5f :2 5b :2 2f :3 13 :2 19 1e
2a 6c 6f :2 2a 7c 7f :2 2a 83
86 :2 2a 92 95 :2 2a 9d a0 :2 2a
ac af b6 bf c2 :2 af :2 2a :2 13
62 :2 10 :2 d :4 19 :2 d a :3 26 d
:2 18 1f 2d :2 d 32 34 :2 32 d
1b d 10 :2 1a 2c :2 36 42 45
57 5a 5b :2 57 :2 2c :3 10 :2 16 1b
27 69 6c :2 27 :2 10 5e :3 d 14
:2 1d d 36 :2 a 26 :2 7 11 21
2c 38 f 1a 27 35 f 10
1d e 1b :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 58 5b 5c :2 58 :2 2c :3 10
:2 16 1b 27 69 6c :2 27 79 7c
:2 27 80 83 :2 27 8f 92 :2 27 9a
9d :2 27 a9 ac b3 bc bf :2 ac
:2 27 :2 10 5f :2 d :2 a :4 16 :2 a 7
:3 4 a 11 1f 22 :2 a 25 27
:2 25 a 18 a d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 :2 d 5b
:3 a 11 :2 1a a 2b :2 7 b 12
d 1a :2 12 1e :2 27 :2 b a 40
3e :2 49 :2 3e a 18 a d :2 17
29 :2 33 3f 42 54 57 58 :2 54
:2 29 :3 d :2 13 18 24 66 69 :2 24
:2 d 5b :3 a 11 :2 1a a 5e :3 7
15 7 11 :2 f 11 f 10 24
e 23 e 18 21 :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 58 5b 5c :2 58
:2 2c :3 10 :2 16 1b 27 69 6c :2 27
79 7c :2 27 80 83 :2 27 8f 92
:2 27 9a 9d :2 27 a9 ac b3 bc
bf :2 ac :2 27 :2 10 5f :2 d :2 a :4 16
:2 a 7 :3 4 a 13 1f :2 a 22
24 :2 22 a 18 a d :2 17 29
:2 33 3f 42 54 57 58 :2 54 :2 29
:3 d :2 13 18 24 66 69 :2 24 :2 d
5b :3 a 11 :2 1a a 26 :3 7 19
22 2c :2 19 7 a 13 1d :2 a
23 20 2c 3b :2 23 :2 20 a 1a
a d 16 24 :2 d 29 27 32
3c :2 29 :2 27 10 19 26 :2 10 2b
29 :2 34 :2 29 4b 13 20 :2 4b 25
23 :2 2e :2 23 :3 10 1f 10 1a 20
2b 2f 18 21 18 19 26 17
2b 17 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 61 64 65 :2 61 :2 35 :3 19 :2 1f
24 30 72 75 :2 30 82 85 :2 30
89 8c :2 30 98 9b :2 30 a3 a6
:2 30 b2 b5 bc c5 c8 :2 b5 :2 30
:2 19 68 :2 16 :2 13 :4 1f :2 13 10 :3 40
:4 14 :2 13 23 13 2d :2 10 13 1c
25 :2 13 28 2a :2 28 13 23 24
:2 23 :2 13 21 38 46 51 57 5d
63 28 34 42 55 :2 21 13 17
20 2c :2 17 2f 31 :2 2f 16 :4 3a
39 38 :2 16 20 2c 3c 1e 1f
2c 3d 51 5a 65 6d 74 :2 19
:2 22 2e 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 67 6a
6b :2 67 :2 3b :3 1f :2 25 2a 36 78
7b :2 36 88 8b :2 36 8f 92 :2 36
9e a1 :2 36 a9 ac :2 36 b8 bb
c2 cb ce :2 bb :2 36 :2 1f 6e :2 1c
:2 19 :4 25 :2 19 16 :3 59 16 22 2b
39 :2 22 3c 3e 47 56 :2 3e :2 22
59 5b 64 6f :2 5b :2 22 :2 16 28
16 59 :3 13 20 27 30 3a :2 30
45 :2 27 48 4a 53 5d :2 53 67
:2 4a :2 27 26 6b 6d :2 26 :2 20 :2 13
21 2a 35 :2 21 38 3a 43 4c
:2 3a :2 21 13 16 1f 2b :2 16 31
2e 3a 44 :2 31 :2 2e 16 28 31
3c :2 28 3f 41 4a 56 :2 41 :2 28
59 5b 64 6e :2 5b :2 28 16 47
16 28 31 3c :2 28 16 :5 13 21
2d 3b 4c 52 60 1d 2d 38
:2 21 :2 13 26 2d 36 40 :2 36 4c
:2 2d 4f 51 5a 64 :2 5a 70 :2 51
:2 2d 2c 24 26 :2 2c :2 26 :2 13 21
:2 2a 31 3a 4b :2 31 4f :2 58 :2 21
:2 13 21 31 3f 45 51 5a 65
:2 51 69 1f 30 :2 69 :2 21 :2 13 23
:2 13 21 38 46 51 57 5d 63
28 34 42 55 :2 21 13 2c :2 10
40 10 20 21 :2 20 :2 10 1e 35
43 4e 54 5a 60 28 34 42
55 :2 1e 10 13 1c 29 :2 13 2f
2c 38 3f :2 2f :2 2c 16 :2 21 28
32 :2 16 3e 40 :2 3e 16 22 2b
39 :2 22 3c 3e 47 51 :2 3e :2 22
:2 16 28 16 19 22 30 :2 19 33
36 3f 4e :2 36 51 53 5c 63
:2 53 :2 36 35 :2 33 19 23 2c 3b
:2 23 3e 40 49 50 :2 40 :2 23 22
54 56 5f 6d :2 56 :2 22 19 23
20 1c 2a 33 3a 46 4f 1c
29 1c 2a 1c 22 1c 22 36
1c 23 1f 2b :3 29 1f :2 28 34
1f 30 1f :2 28 34 1f :4 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6a 6d 6e :2 6a :2 3e :3 22
:2 28 2d 39 7b 7e :2 39 8b 8e
:2 39 92 95 :2 39 a1 a4 :2 39 ac
af :2 39 bb be c5 ce d1 :2 be
:2 39 :2 22 71 :2 1f :2 1c :4 28 :2 1c 19
:3 67 19 2b :2 34 3b 44 54 :2 3b
58 :2 61 :2 2b 19 67 23 20 1c
2a 33 3a 46 4f 1c 29 1c
2a :2 1c 22 36 1c 23 1f 2b
:3 29 1f :2 28 34 1f 30 1f :2 28
34 1f :4 1c 19 21 1f :2 28 34
1f 2f :2 1c :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 6a 6d
6e :2 6a :2 3e :3 22 :2 28 2d 39 7b
7e :2 39 8b 8e :2 39 92 95 :2 39
a1 a4 :2 39 ac af :2 39 bb be
c5 ce d1 :2 be :2 39 :2 22 71 :2 1f
:2 1c :4 28 :2 1c 19 :7 16 42 19 22
30 :2 19 33 36 3f 4e :2 36 51
53 5c 63 :2 53 :2 36 35 :2 33 19
25 2e 35 :2 25 38 3a 43 4d
:2 3a :2 25 :2 19 2b 33 3c 46 :2 3c
55 :2 33 58 5a 63 6d :2 63 78
:2 5a :2 33 32 24 26 :2 32 31 30
32 :2 31 :2 2b 19 23 20 1c 2a
33 3a 46 4f 1c 29 1c 2a
22 36 1c 23 1f 2b :3 29 1f
:2 28 34 1f 30 1f :2 28 34 1f
:4 1c 19 21 1f :2 28 34 1f 2f
:2 1c :2 21 1f :2 28 34 1f 22 :2 2c
3e :2 48 54 58 6a 6d 6e :2 6a
:2 3e :3 22 :2 28 2d 39 7b 7e :2 39
8b 8e :2 39 92 95 :2 39 a1 a4
:2 39 ac af :2 39 bb be c5 ce
d1 :2 be :2 39 :2 22 71 :2 1f :2 1c :4 28
:2 1c 19 :4 67 19 25 2e 3c :2 25
3f 41 4a 54 :2 41 :2 25 :2 19 2b
19 23 20 1c 2a 33 3a 46
4f 1c 29 1c 2a :2 1c 22 36
1c 23 1f 2b :3 29 1f :2 28 34
1f 30 1f :2 28 34 1f :4 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6a 6d 6e :2 6a :2 3e :3 22
:2 28 2d 39 7b 7e :2 39 8b 8e
:2 39 92 95 :2 39 a1 a4 :2 39 ac
af :2 39 bb be c5 ce d1 :2 be
:2 39 :2 22 71 :2 1f :2 1c :4 28 :2 1c 19
:7 16 :4 13 42 13 1f 28 36 :2 1f
39 3b 44 53 :2 3b :2 1f :2 13 25
13 1d 1a 16 24 2d 34 40
49 16 23 16 24 :2 16 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 67 68 :2 64 :2 38 :3 1c
:2 22 27 33 75 78 :2 33 85 88
:2 33 8c 8f :2 33 9b 9e :2 33 a6
a9 :2 33 b5 b8 bf c8 cb :2 b8
:2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16 13
:7 10 :4 14 :2 13 20 13 1d 21 :2 1b
1c 29 1a 28 :2 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 67 68 :2 64 :2 38
:3 1c :2 22 27 33 75 78 :2 33 85
88 :2 33 8c 8f :2 33 9b 9e :2 33
a6 a9 :2 33 b5 b8 bf c8 cb
:2 b8 :2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16
13 :3 32 :4 17 16 20 28 2f 50
5f :2 19 :2 22 2e 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
67 6a 6b :2 67 :2 3b :3 1f :2 25 2a
36 78 7b :2 36 88 8b :2 36 8f
92 :2 36 9e a1 :2 36 a9 ac :2 36
b8 bb c2 cb ce :2 bb :2 36 :2 1f
6e :2 1c :2 19 :4 25 :2 19 16 :3 2e 19
:2 24 2c 3e 49 :2 19 4d 4f :2 4d
19 29 19 51 :2 16 13 2e 19
22 2d :2 19 30 32 :2 30 16 24
:2 2d 34 3d 48 :2 34 4c :2 55 :2 24
23 16 20 2b 38 40 47 62
6d 72 :2 1e :2 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 67 6a 6b :2 67 :2 3b :3 1f
:2 25 2a 36 78 7b :2 36 88 8b
:2 36 8f 92 :2 36 9e a1 :2 36 a9
ac :2 36 b8 bb c2 cb ce :2 bb
:2 36 :2 1f 6e :2 1c :2 19 :4 25 :2 19 16
:4 34 2e 20 2b 38 40 47 62
6d 72 :2 1e :2 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 67 6a 6b :2 67 :2 3b :3 1f
:2 25 2a 36 78 7b :2 36 88 8b
:2 36 8f 92 :2 36 9e a1 :2 36 a9
ac :2 36 b8 bb c2 cb ce :2 bb
:2 36 :2 1f 6e :2 1c :2 19 :4 25 :2 19 16
:7 13 32 :2 10 :4 14 :2 13 21 31 3f
45 :2 21 13 31 16 1d 29 2c
:2 16 2f 31 :2 2f 16 24 34 42
48 :2 24 16 35 16 24 34 42
48 :2 24 16 :4 13 :5 10 1e :2 10 1e
2c 32 40 4a 56 61 6d 1f
28 39 :2 1f :2 1e 10 13 1c 28
:2 13 2b 2e :2 2b 13 21 13 16
:2 20 32 :2 3c 48 4b 5d 60 61
:2 5d :2 32 :3 16 :2 1c 21 2d 6f 72
:2 2d :2 16 64 :3 13 1a 23 2f :2 1a
13 30 :2 10 :5 d 19 d 3f d
1f 27 30 3a :2 30 49 :2 27 4c
4e 57 61 :2 57 6c :2 4e :2 27 26
24 :3 26 25 30 32 :2 25 :2 1f d
:5 a 18 2c 3a 45 4f 55 25
31 3b 49 25 34 44 50 25
31 3e 4c 25 33 42 55 25
31 3d 46 51 :2 3d 55 23 30
:2 55 :2 18 :2 a 18 a d :2 17 29
:2 33 3f 42 54 57 58 :2 54 :2 29
:3 d :2 13 18 24 66 69 :2 24 :2 d
5b :3 a 11 1a 26 :2 11 a 7
3e d 16 2a :2 d 30 2d 39
49 :2 30 :2 2d 14 11 25 d 1b
24 2b 37 40 13 27 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5e 5f :2 5b :2 2f :3 13 :2 19 1e
2a 6c 6f :2 2a 7c 7f :2 2a 83
86 :2 2a 92 95 :2 2a 9d a0 :2 2a
ac af b6 bf c2 :2 af :2 2a :2 13
62 :2 10 :2 d :4 19 :2 d a :3 4c 14
11 1f 28 2f 3b 44 13 20
11 1e d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5e 5f :2 5b
:2 2f :3 13 :2 19 1e 2a 6c 6f :2 2a
7c 7f :2 2a 83 86 :2 2a 92 95
:2 2a 9d a0 :2 2a ac af b6 bf
c2 :2 af :2 2a :2 13 62 :2 10 :2 d :4 19
:2 d a :3 4c 7 4c 3e d 16
1f :2 d 25 22 2e 3f :2 25 :2 22
d 16 1f :2 d 22 24 :2 22 d
20 d 26 11 1a 23 :2 11 26
28 :2 26 10 2f 38 41 :2 2f 44
46 :2 44 2e :3 10 1e 10 13 :2 1d
2f :2 39 45 48 5a 5d 5e :2 5a
:2 2f :3 13 :2 19 1e 2a 6c 6f :2 2a
:2 13 61 :3 10 17 :2 20 10 51 :3 d
20 29 32 :2 20 d :4 a :4 e d
17 :2 15 16 2a :2 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 61 62 :2 5e :2 32
:3 16 :2 1c 21 2d 6f 72 :2 2d 7f
82 :2 2d 86 89 :2 2d 95 98 :2 2d
a0 a3 :2 2d af b2 b9 c2 c5
:2 b2 :2 2d :2 16 65 :2 13 :2 10 :4 1c :2 10
d :3 2b 11 :2 1a 25 23 :2 2e :2 23
10 43 4c 5d :2 43 62 60 13
1f :2 62 :2 60 42 :3 10 1e 10 13
:2 1d 2f :2 39 45 48 5a 5d 5e
:2 5a :2 2f :3 13 :2 19 1e 2a 6c 6f
:2 2a :2 13 61 :3 10 17 :2 20 10 23
:2 d 2b :2 a d 16 23 :2 d 28
26 :2 31 :2 26 46 10 1d :2 46 22
20 :2 2b :2 20 :3 d 1d 1e :2 1d :2 d
1b 32 40 4b 51 57 5d 28
34 42 55 :2 1b d 11 1a 26
:2 11 29 2b :2 29 10 :4 34 33 32
:3 10 1e 33 41 4c 56 67 26
38 44 :2 1e 10 53 :3 d 1a 22
2b 3c :2 22 3f 41 4a 55 :2 41
:2 22 21 59 5b :2 21 20 65 67
:2 20 :2 1a :2 d 1b 27 35 46 4c
5a 1d 28 33 :2 1b :2 d 1b :2 24
2b 34 45 :2 2b 49 :2 52 :2 1b :2 d
1b 2b 39 3f 4b 4e :2 1b d
17 1f 26 41 49 50 70 76
15 2c 40 :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 61 62 :2 5e :2 32 :3 16
:2 1c 21 2d 6f 72 :2 2d 7f 82
:2 2d 86 89 :2 2d 95 98 :2 2d a0
a3 :2 2d af b2 b9 c2 c5 :2 b2
:2 2d :2 16 65 :2 13 :2 10 :4 1c :2 10 d
:3 3f d 1d :2 d 1b 32 40 4b
51 57 5d 28 34 42 55 :2 1b
d 3f d 1d 1e :2 1d :2 d 1b
32 40 4b 51 57 5d 28 34
42 55 :2 1b d 11 1a 26 :2 11
29 2b :2 29 10 :4 34 33 32 :3 10
1e 33 41 4c 56 67 26 38
44 :2 1e 10 53 :2 d :4 11 :2 10 1e
2e 3c 42 :2 1e 10 2e 13 1a
26 29 :2 13 2c 2e :2 2c 13 21
31 3f 45 :2 21 13 32 13 21
31 3f 45 :2 21 13 :4 10 :4 d :4 11
10 1a 25 32 3a 41 5c 67
6c :2 18 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 61 64 65 :2 61 :2 35 :3 19 :2 1f
24 30 72 75 :2 30 82 85 :2 30
89 8c :2 30 98 9b :2 30 a3 a6
:2 30 b2 b5 bc c5 c8 :2 b5 :2 30
:2 19 68 :2 16 :2 13 :4 1f :2 13 10 :3 2f
10 1c 25 2f :2 1c 32 34 3d
4c :2 34 :2 1c 10 2f :3 d 1a :2 d
1b :2 d 1b 29 2f 3d 47 53
5e 6a 1f 28 39 :2 1f :2 1b d
10 19 25 :2 10 28 2b :2 28 10
1e 10 13 :2 1d 2f :2 39 45 48
5a 5d 5e :2 5a :2 2f :3 13 :2 19 1e
2a 6c 6f :2 2a :2 13 61 :3 10 17
:2 20 10 2d 1a 17 13 1f :5 13
21 2a 31 3e 47 54 5d 19
2d 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 99 9c :2 30
a4 a7 :2 30 b3 b6 bd c6 c9
:2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13
10 :7 d :4 a 42 3e :2 7 :5 4 :2 d
19 23 :2 19 4 7 :2 11 23 :2 2d
39 3c 4e 52 53 :2 4e :2 23 :3 7
:2 d 12 1e 61 64 :2 1e 71 74
:2 1e 78 7b :2 1e 85 88 :2 91 :2 1e
:2 7 56 :3 4 b :2 14 4 :9 1 
1713
4
0 :2 1 :6 3 :4 4
:4 5 :4 6 :6 7 :6 8
2 :2 9 :2 1 :6 b
:6 c :6 d :7 e :7 f
:7 10 :7 11 :7 12 :5 13
:5 14 :5 15 :5 16 :5 17
:5 18 :5 19 :7 1a :7 1b
:7 1c :6 1d :6 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :a 39 :a 3a :7 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :b 4c
:11 4d 4e :2 4d :2 4e
:2 4d :2 4e :2 4d :2 4f
:2 4d :9 4f :2 4d :2 50
:2 4d :9 50 :2 4d :2 51
:2 4d :9 51 :2 4d :2 52
:2 4d :2 52 :2 4d :2 52
:2 4d :2 52 :2 4d :2 53
:2 4d :2 53 :2 4d :2 53
:2 4d :2 53 :2 4d :2 53
:4 4d :3 4c :11 56 :b 57
:3 56 :3 5a :9 5d :b 5e
:a 5f :4 60 :4 61 :3 62
:8 63 :8 64 :6 65 :4 66
:4 67 :3 68 69 :2 6a
5d :5 6b 5c 6d
:5 6e :3 6d :2 6f :5 71
:11 72 :24 73 :3 72 :2 70
:6 6f 6c :3 4b :a 78
:9 7a :9 7b 7c :2 7d
7a :5 7e 79 80
:5 81 :3 80 :2 82 :5 84
:11 85 :24 86 :3 85 :2 83
:6 82 7f :3 78 :a 8b
:3 8c :11 8d :b 8e :3 8d
:5 90 :3 8b :a 92 :3 93
:11 94 :b 95 :3 94 :5 97
:3 92 :2 99 :2 9a :2 99
:3 9a :3 99 :6 9a :3 9b
:11 9c :b 9d :3 9c :5 9f
9a :2 99 :3 a2 a4
a5 a6 :2 a7 a4
:5 a8 a3 aa :5 ab
:3 aa :2 ac :5 ae :11 af
:24 b0 :3 af :2 ad :6 ac
a9 :3 78 :9 b5 b7
b8 b9 :2 ba b7
:5 bb b6 bd :5 be
:3 bd :2 bf :5 c1 :11 c2
:24 c3 :3 c2 :2 c0 :6 bf
bc :3 b5 :b c8 :3 c9
:11 ca :b cb :3 ca :5 cd
:3 c8 :3 b5 :3 d2 d4
d5 d6 :2 d8 :4 d9
:3 da :3 db :4 dc :4 dd
:4 de d4 :5 df d3
e1 :5 e2 :3 e1 :2 e3
:5 e5 :11 e6 :24 e7 :3 e6
:2 e4 :6 e3 e0 :3 78
:9 ec :3 ed :11 ee :b ef
:3 ee :5 f1 :3 ec :9 f4
:11 f5 :20 f6 :3 f5 :11 f8
:b f9 :3 f8 :b fb fc
f4 :d fc :3 fd :d fe
:3 ff :11 100 :b 101 :3 100
:5 103 104 fe :d 104
:3 105 104 :3 fe :3 108
:7 109 :2 10a :2 109 :a 10a
:3 109 fc f4 :11 10c
:20 10d :3 10c :11 10f :b 110
:3 10f :b 112 10b :3 f4
78 :9 115 :3 116 :11 117
:b 118 :3 117 :5 11a :3 115
:3 11d 11f 120 121
:2 122 11f :5 123 11e
125 :5 126 :3 125 :2 127
:5 129 :11 12a :24 12b :3 12a
:2 128 :6 127 124 :3 114
:9 130 132 133 134
:2 135 132 :5 136 131
138 :5 139 :3 138 :2 13a
:5 13c :11 13d :24 13e :3 13d
:2 13b :6 13a 137 :3 130
:b 143 :3 144 :11 145 :b 146
:3 145 :5 148 :3 143 :3 130
:4 14d :4 14e 14f :2 150
:2 151 14d :5 152 14c
154 :5 155 :3 154 :2 156
:5 158 :11 159 :24 15a :3 159
:2 157 :6 156 153 :3 114
:a 15f :3 160 :11 161 :b 162
:3 161 :5 164 :3 15f :2 166
:2 167 :2 166 :3 167 :3 166
:6 167 :3 168 :11 169 :b 16a
:3 169 :5 16c 167 :2 166
:3 170 172 173 174
176 177 :2 178 :2 179
:3 17a 172 :5 17b 171
17d :5 17e :3 17d :2 17f
:5 181 :11 182 :24 183 :3 182
:2 180 :6 17f 17c :3 114
:9 188 :3 189 :11 18a :b 18b
:3 18a :5 18d :3 188 :7 190
:d 191 :3 192 :d 194 :c 195
:2 196 :2 195 :6 196 :2 195
:3 197 :4 199 :2 19a 19b
:2 19c :2 19d 19e 199
:5 19f 198 1a1 :5 1a2
:3 1a1 :2 1a3 :5 1a5 :11 1a6
:24 1a7 :3 1a6 :2 1a4 :6 1a3
1a0 :3 196 :5 1ac :3 1ad
:3 1ac :9 1b0 :6 1b1 :8 1b2
:4 1b3 :3 1b2 :12 1b5 :3 1b7
1b8 :8 1b9 1b7 :5 1ba
1b6 1bc :5 1bd :3 1bc
:2 1be :5 1c0 :11 1c1 :24 1c2
:3 1c1 :2 1bf :6 1be 1bb
:3 1b5 :17 1c7 :3 1c8 :3 1b5
:1d 1cb :f 1cc :d 1cd :17 1ce
1cd :7 1d0 1cf :3 1cd
:7 1d3 :3 1d4 :3 1d3 :16 1d7
:2 1d8 :5 1d7 :f 1d9 :b 1da
:2 1db :5 1da :3 1dd :8 1de
:4 1df :3 1de :3 1b0 196
:6 1e2 :8 1e3 :4 1e4 :3 1e3
:d 1e6 :b 1e7 :f 1e8 :3 1e9
:16 1eb :18 1ec 1ee 1ef
:6 1f0 :2 1f1 :2 1f2 :2 1f3
1f4 :2 1f5 1ee :6 1f6
:5 1f7 1f6 :5 1f9 1f8
:3 1f6 1ed 1fc :5 1fd
:3 1fc :2 1fe :5 200 :11 201
:24 202 :3 201 :2 1ff :6 1fe
1fb :3 1eb :f 207 1eb
20a 20b :6 20c :2 20d
:2 20e 20f 210 :2 211
20a :6 212 :5 213 212
:5 215 214 :3 212 209
218 :5 219 :3 218 :2 21a
:5 21c :11 21d :24 21e :3 21d
:2 21b :6 21a 217 :4 208
:3 1eb 1e7 :16 224 :f 225
:16 226 :2 227 :3 226 :2 227
:5 226 22a 22b :6 22c
:2 22d :2 22e :2 22f 22a
:6 230 :5 231 230 :5 233
232 :3 230 229 236
:5 237 :3 236 :2 238 :5 23a
:11 23b :24 23c :3 23b :2 239
:6 238 235 :4 224 :f 241
:3 242 245 246 :6 247
:2 248 :2 249 24a 24b
:2 24c 245 :6 24d :5 24e
24d :5 250 24f :3 24d
244 253 :5 254 :3 253
:2 255 :5 257 :11 258 :24 259
:3 258 :2 256 :6 255 252
:4 240 :3 224 223 :3 1e7
1e6 :f 260 :3 261 264
265 :6 266 :2 267 :2 268
269 26a :2 26b 264
:6 26c :5 26d 26c :5 26f
26e :3 26c 263 272
:5 273 :3 272 :2 274 :5 276
:11 277 :24 278 :3 277 :2 275
:6 274 271 :4 25f :3 1e6
:5 27e :3 27f :2 281 282
283 :2 284 :2 285 281
:5 286 280 288 :5 289
:3 288 :2 28a :5 28c :11 28d
:24 28e :3 28d :2 28b :6 28a
287 :3 27e :5 293 :6 295
:5 296 294 298 :5 299
:3 298 :2 29a :5 29c :11 29d
:24 29e :3 29d :2 29b :6 29a
297 :3 293 :c 2a3 :3 2a4
:3 2a3 2a6 293 :9 2a6
:10 2a7 :8 2aa 2ab 2ac
2aa :5 2ad 2a9 2af
:5 2b0 :3 2af :2 2b1 :5 2b3
:11 2b4 :24 2b5 :3 2b4 :2 2b2
:6 2b1 2ae :4 2a6 293
:8 2bb 2bc 2bd 2bb
:5 2be 2ba 2c0 :5 2c1
:3 2c0 :2 2c2 :5 2c4 :11 2c5
:24 2c6 :3 2c5 :2 2c3 :6 2c2
2bf :4 2b9 :3 293 :3 27e
:5 2cd :8 2ce 2cd :a 2d0
:8 2d1 2d0 :8 2d3 2d2
:3 2d0 2cf :3 2cd :3 2d7
:9 2d8 :5 2d9 :3 2d8 :9 2db
:3 2dc :11 2dd :b 2de :3 2dd
:7 2e0 :3 2db 1e1 :3 195
:3 2e4 194 :16 2e6 :2 2e7
:3 2e6 :2 2e7 :5 2e6 2e5
:3 194 :7 2ea :4 2eb :4 2ec
:4 2ed :4 2ee :8 2ef :2 2f0
:2 2ef :3 2ea :3 2f2 :11 2f3
:b 2f4 :3 2f3 :7 2f6 2f7
191 :d 2f7 31a :2 31b
:6 31c :2 31d 31a :6 31e
:5 31f 31e :5 321 320
:3 31e 319 324 :5 325
:3 324 :2 326 :5 328 :11 329
:24 32a :3 329 :2 327 :6 326
323 :3 2f7 335 :6 336
:2 337 :2 338 335 :6 339
:5 33a 339 :5 33c 33b
:3 339 334 33f :5 340
:3 33f :2 341 :5 343 :11 344
:24 345 :3 344 :2 342 :6 341
33e :3 2f7 34b 2f7
191 :d 34b :9 34c :3 34d
34c :16 34f :3 350 :11 351
:b 352 :3 351 :5 354 :3 34f
:7 357 34e :3 34c :5 35a
35c 35d 35e :2 35f
35c :5 360 35b 362
:5 363 :3 362 :2 364 :5 366
:11 367 :24 368 :3 367 :2 365
:6 364 361 :3 35a :11 36e
:2 36f :7 36e :3 370 :11 371
:b 372 :3 371 :5 374 36f
:2 36e :3 35a :c 378 :2 379
:2 378 :6 379 :2 378 :6 37a
:8 37b :4 37c :3 37b :12 37e
:7 37f :3 380 :3 37f :3 37e
:1c 384 :7 385 :3 386 :3 385
:f 388 :a 389 :8 38c :3 38d
38c :5 38e 38b 390
:5 391 :3 390 :2 392 :5 394
:11 395 :24 396 :3 395 :2 393
:6 392 38f :3 379 :3 39b
:8 39c :4 39d :3 39c 379
:6 39f :8 3a0 :4 3a1 :3 3a0
:12 3a3 :7 3a4 :3 3a5 :3 3a4
:3 3a3 :5 3a9 :8 3aa 3a9
:a 3ac :8 3ad 3ac :8 3af
3ae :3 3ac 3ab :3 3a9
:5 3b3 :8 3b5 3b6 3b7
3b5 :5 3b8 3b4 3ba
:5 3bb :3 3ba :2 3bc :5 3be
:11 3bf :24 3c0 :3 3bf :2 3bd
:6 3bc 3b9 :3 3b3 :f 3c5
:3 3b3 :3 3ca :3 3cb :9 3cc
:5 3cd :3 3cc :9 3d0 :3 3d1
:11 3d2 :b 3d3 :3 3d2 :5 3d5
3d0 3d8 3d9 :2 3da
3db 3dc 3dd 3de
:8 3df :2 3e0 3d8 :6 3e1
:5 3e2 3e1 :5 3e4 3e3
:3 3e1 3d7 3e7 :5 3e8
:3 3e7 :2 3e9 :5 3eb :11 3ec
:24 3ed :3 3ec :2 3ea :6 3e9
3e6 :4 3d6 :3 3d0 39e
:3 378 34b :3 191 114
:3 78 :8 3f7 :11 3fe :19 3ff
:3 3fe :5 401 :2 4b :7 1

5086
4
:3 0 1 :3 0 2
:a 0 170e 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 5d 0 7
8 :3 0 7 :7 0
b a :3 0 8
:3 0 9 :7 0 f
e :3 0 d 8a
0 b 8 :3 0
a :7 0 13 12
:3 0 4 :3 0 5
:3 0 6 :3 0 b
:5 0 1 19 18
:3 0 16 b6 0
f 4 :3 0 5
:3 0 6 :3 0 c
:5 0 1 1f 1e
:3 0 d :3 0 8
:3 0 21 23 0
170e 2 24 :2 0
1a f2 0 18
8 :3 0 27 :7 0
7 :3 0 2b 28
29 170c 0 e
:6 0 8 :3 0 2d
:7 0 9 :3 0 31
2e 2f 170c 0
f :6 0 12 :2 0
1e 8 :3 0 33
:7 0 a :3 0 37
34 35 170c 0
10 :6 0 6 :3 0
12 :2 0 1c 39
3b :6 0 3e 3c
0 170c 0 11
:6 0 12 :2 0 22
6 :3 0 20 40
42 :6 0 45 43
0 170c 0 13
:6 0 12 :2 0 26
6 :3 0 24 47
49 :6 0 4c 4a
0 170c 0 14
:6 0 12 :2 0 2a
6 :3 0 28 4e
50 :6 0 53 51
0 170c 0 15
:6 0 30 1a2 0
2e 6 :3 0 2c
55 57 :6 0 5a
58 0 170c 0
16 :6 0 34 1d6
0 32 18 :3 0
5c :7 0 5f 5d
0 170c 0 17
:6 0 18 :3 0 61
:7 0 64 62 0
170c 0 19 :6 0
38 20a 0 36
1b :3 0 66 :7 0
69 67 0 170c
0 1a :6 0 1b
:3 0 6b :7 0 6e
6c 0 170c 0
1c :6 0 3c 23e
0 3a 18 :3 0
70 :7 0 73 71
0 170c 0 1d
:6 0 18 :3 0 75
:7 0 78 76 0
170c 0 1e :6 0
21 :2 0 40 18
:3 0 7a :7 0 7d
7b 0 170c 0
1f :6 0 6 :3 0
21 :2 0 3e 7f
81 :6 0 84 82
0 170c 0 20
:6 0 21 :2 0 44
6 :3 0 42 86
88 :6 0 8b 89
0 170c 0 22
:6 0 25 :2 0 48
6 :3 0 46 8d
8f :6 0 92 90
0 170c 0 23
:6 0 25 :2 0 4a
8 :3 0 94 :7 0
98 95 96 170c
0 24 :6 0 25
:2 0 4c 8 :3 0
9a :7 0 9e 9b
9c 170c 0 26
:6 0 25 :2 0 4e
8 :3 0 a0 :7 0
a4 a1 a2 170c
0 27 :6 0 25
:2 0 50 8 :3 0
a6 :7 0 aa a7
a8 170c 0 28
:6 0 25 :2 0 52
8 :3 0 ac :7 0
b0 ad ae 170c
0 29 :6 0 25
:2 0 54 8 :3 0
b2 :7 0 b6 b3
b4 170c 0 2a
:6 0 25 :2 0 56
8 :3 0 b8 :7 0
bc b9 ba 170c
0 2b :6 0 25
:2 0 58 8 :3 0
be :7 0 c2 bf
c0 170c 0 2c
:6 0 25 :2 0 5a
8 :3 0 c4 :7 0
c8 c5 c6 170c
0 2d :6 0 25
:2 0 5c 8 :3 0
ca :7 0 ce cb
cc 170c 0 2e
:6 0 25 :2 0 5e
8 :3 0 d0 :7 0
d4 d1 d2 170c
0 2f :6 0 25
:2 0 60 8 :3 0
d6 :7 0 da d7
d8 170c 0 30
:6 0 25 :2 0 62
8 :3 0 dc :7 0
e0 dd de 170c
0 31 :6 0 25
:2 0 64 8 :3 0
e2 :7 0 e6 e3
e4 170c 0 32
:6 0 25 :2 0 66
8 :3 0 e8 :7 0
ec e9 ea 170c
0 33 :6 0 25
:2 0 68 8 :3 0
ee :7 0 f2 ef
f0 170c 0 34
:6 0 25 :2 0 6a
8 :3 0 f4 :7 0
f8 f5 f6 170c
0 35 :6 0 25
:2 0 6c 8 :3 0
fa :7 0 fe fb
fc 170c 0 36
:6 0 25 :2 0 6e
8 :3 0 100 :7 0
104 101 102 170c
0 37 :6 0 25
:2 0 70 8 :3 0
106 :7 0 10a 107
108 170c 0 38
:6 0 25 :2 0 72
8 :3 0 10c :7 0
110 10d 10e 170c
0 39 :6 0 25
:2 0 74 8 :3 0
112 :7 0 116 113
114 170c 0 3a
:6 0 25 :2 0 76
8 :3 0 118 :7 0
11c 119 11a 170c
0 3b :6 0 25
:2 0 78 8 :3 0
11e :7 0 122 11f
120 170c 0 3c
:6 0 25 :2 0 7a
8 :3 0 124 :7 0
128 125 126 170c
0 3d :6 0 25
:2 0 7c 8 :3 0
12a :7 0 12e 12b
12c 170c 0 3e
:6 0 25 :2 0 7e
8 :3 0 130 :7 0
134 131 132 170c
0 3f :6 0 43
:2 0 80 8 :3 0
136 :7 0 13a 137
138 170c 0 40
:6 0 43 :2 0 84
42 :3 0 82 13c
13e 2 :5 0 44
:3 0 45 :3 0 140
141 0 144 13f
142 170c 0 41
:6 0 48 :2 0 88
42 :3 0 86 146
148 2 :5 0 44
:3 0 45 :3 0 14a
14b 0 14e 149
14c 170c 0 46
:6 0 25 :2 0 8c
6 :3 0 8a 150
152 :6 0 155 153
0 170c 0 47
:6 0 25 :2 0 8e
4a :3 0 157 :7 0
15b 158 159 170c
0 49 :6 0 25
:2 0 90 4a :3 0
15d :7 0 161 15e
15f 170c 0 4b
:6 0 25 :2 0 92
4a :3 0 163 :7 0
167 164 165 170c
0 4c :6 0 25
:2 0 94 4a :3 0
169 :7 0 16d 16a
16b 170c 0 4d
:6 0 25 :2 0 96
4a :3 0 16f :7 0
173 170 171 170c
0 4e :6 0 25
:2 0 98 4a :3 0
175 :7 0 179 176
177 170c 0 4f
:6 0 25 :2 0 9a
4a :3 0 17b :7 0
17f 17c 17d 170c
0 50 :6 0 25
:2 0 9c 4a :3 0
181 :7 0 185 182
183 170c 0 51
:6 0 25 :2 0 9e
8 :3 0 187 :7 0
18b 188 189 170c
0 52 :6 0 25
:2 0 a0 4a :3 0
18d :7 0 191 18e
18f 170c 0 53
:6 0 25 :2 0 a2
8 :3 0 193 :7 0
197 194 195 170c
0 54 :6 0 25
:2 0 a4 8 :3 0
199 :7 0 19d 19a
19b 170c 0 55
:6 0 25 :2 0 a6
8 :3 0 19f :7 0
1a3 1a0 1a1 170c
0 56 :6 0 25
:2 0 a8 8 :3 0
1a5 :7 0 1a9 1a6
1a7 170c 0 57
:6 0 1b0 1b1 0
aa 8 :3 0 1ab
:7 0 1af 1ac 1ad
170c 0 58 :6 0
59 :3 0 5a :3 0
59 :3 0 5b :3 0
1b3 1b4 0 2
:4 0 ac 1b5 1b7
1b2 1b9 1b8 :2 0
5c :3 0 5d :3 0
1bb 1bc 0 5e
:4 0 59 :3 0 5f
:3 0 1bf 1c0 0
2 :4 0 ae 1c1
1c3 60 :4 0 61
:2 0 62 :3 0 b0
1c6 1c8 :3 0 63
:4 0 61 :2 0 64
:4 0 b3 1cb 1cd
:3 0 61 :2 0 3
:3 0 b6 1cf 1d1
:3 0 61 :2 0 64
:4 0 b9 1d3 1d5
:3 0 61 :2 0 65
:4 0 bc 1d7 1d9
:3 0 61 :2 0 66
:3 0 67 :3 0 7
:3 0 bf 1dd 1df
68 :4 0 c1 1dc
1e2 c4 1db 1e4
:3 0 61 :2 0 65
:4 0 c7 1e6 1e8
:3 0 61 :2 0 66
:3 0 67 :3 0 9
:3 0 ca 1ec 1ee
68 :4 0 cc 1eb
1f1 cf 1ea 1f3
:3 0 61 :2 0 65
:4 0 d2 1f5 1f7
:3 0 61 :2 0 66
:3 0 67 :3 0 a
:3 0 d5 1fb 1fd
68 :4 0 d7 1fa
200 da 1f9 202
:3 0 61 :2 0 65
:4 0 dd 204 206
:3 0 61 :2 0 64
:4 0 e0 208 20a
:3 0 61 :2 0 b
:3 0 e3 20c 20e
:3 0 61 :2 0 64
:4 0 e6 210 212
:3 0 61 :2 0 65
:4 0 e9 214 216
:3 0 61 :2 0 64
:4 0 ec 218 21a
:3 0 61 :2 0 c
:3 0 ef 21c 21e
:3 0 61 :2 0 64
:4 0 f2 220 222
:3 0 61 :2 0 69
:4 0 f5 224 226
:3 0 f8 1bd 228
:2 0 22a fd 22b
1ba 22a 0 22c
ff 0 170a 59
:3 0 5a :3 0 22d
22e 0 59 :3 0
6a :3 0 230 231
0 21 :2 0 2
:4 0 6b :2 0 6c
:2 0 21 :2 0 101
236 238 :3 0 104
232 23a 22f 23c
23b :2 0 5c :3 0
6d :3 0 23e 23f
0 5e :4 0 6e
:4 0 61 :2 0 62
:3 0 108 243 245
:3 0 10b 240 247
:2 0 249 10e 24a
23d 249 0 24b
110 0 170a 11
:3 0 3 :3 0 24c
24d 0 170a 6f
:3 0 70 :3 0 71
:3 0 72 :3 0 73
:3 0 74 :3 0 75
:3 0 74 :3 0 76
:3 0 75 :3 0 77
:3 0 78 :3 0 79
:3 0 7a :3 0 7b
:3 0 7c :3 0 7d
:3 0 7e :3 0 7d
:3 0 7e :3 0 7f
:3 0 80 :3 0 81
:3 0 82 :3 0 7f
:3 0 81 :3 0 82
:3 0 80 :3 0 83
:3 0 84 :3 0 85
:3 0 86 :3 0 87
:3 0 88 :3 0 89
:3 0 8a :3 0 8b
:3 0 8c :3 0 8d
:3 0 8e :3 0 8f
:3 0 14 :3 0 16
:3 0 22 :3 0 20
:3 0 1d :3 0 2c
:3 0 3f :3 0 3d
:3 0 29 :3 0 2e
:3 0 13 :3 0 35
:3 0 3a :3 0 38
:3 0 39 :3 0 2b
:3 0 1a :3 0 1c
:3 0 17 :3 0 19
:3 0 27 :3 0 28
:3 0 49 :3 0 4c
:3 0 4b :3 0 4d
:3 0 4e :3 0 50
:3 0 4f :3 0 51
:3 0 2a :3 0 15
:3 0 40 :3 0 90
:3 0 91 :3 0 11
:4 0 92 1 :8 0
2a2 93 :3 0 94
:3 0 29d 29e 0
95 :3 0 29f 2a0
0 2a2 112 2f5
96 :3 0 93 :3 0
94 :3 0 2a4 2a5
0 95 :3 0 2a6
2a7 0 2a9 115
2ab 117 2aa 2a9
:2 0 2f3 97 :3 0
93 :3 0 94 :3 0
2ae 2af 0 95
:3 0 2b0 2b1 0
2eb 59 :3 0 5a
:3 0 2b3 2b4 0
59 :3 0 6a :3 0
2b6 2b7 0 98
:2 0 2 :4 0 99
:2 0 6c :2 0 21
:2 0 119 2bc 2be
:3 0 11c 2b8 2c0
2b5 2c2 2c1 :2 0
5c :3 0 6d :3 0
2c4 2c5 0 5e
:4 0 9a :4 0 61
:2 0 62 :3 0 120
2c9 2cb :3 0 61
:2 0 9b :4 0 123
2cd 2cf :3 0 61
:2 0 9c :4 0 126
2d1 2d3 :3 0 61
:2 0 95 :3 0 129
2d5 2d7 :3 0 61
:2 0 9d :4 0 12c
2d9 2db :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 12f 2de 2e2
133 2dd 2e4 :3 0
136 2c6 2e6 :2 0
2e8 139 2e9 2c3
2e8 0 2ea 13b
0 2eb 13d 2ee
:3 0 2ee 0 2ee
2ed 2eb 2ec :6 0
2f0 2 :3 0 140
2f2 142 2f1 2f0
:2 0 2f3 144 :2 0
2f5 0 2f5 2f4
2a2 2f3 :6 0 170a
1 :3 0 93 :3 0
94 :3 0 2f7 2f8
0 93 :3 0 a0
:2 0 a1 :3 0 2fa
2fc 0 149 2fb
2fe :3 0 2ff :2 0
6f :3 0 a2 :3 0
a3 :3 0 74 :3 0
8d :3 0 a4 :3 0
a5 :3 0 a6 :3 0
a7 :3 0 14 :3 0
30 :3 0 29 :3 0
2c :3 0 2a :3 0
34 :3 0 2f :3 0
23 :3 0 58 :3 0
a8 :3 0 a9 :3 0
11 :4 0 aa 1
:8 0 31c 93 :3 0
94 :3 0 317 318
0 95 :3 0 319
31a 0 31c 14c
36f 96 :3 0 93
:3 0 94 :3 0 31e
31f 0 95 :3 0
320 321 0 323
14f 325 151 324
323 :2 0 36d 97
:3 0 93 :3 0 94
:3 0 328 329 0
95 :3 0 32a 32b
0 365 59 :3 0
5a :3 0 32d 32e
0 59 :3 0 6a
:3 0 330 331 0
98 :2 0 2 :4 0
ab :2 0 6c :2 0
21 :2 0 153 336
338 :3 0 156 332
33a 32f 33c 33b
:2 0 5c :3 0 6d
:3 0 33e 33f 0
5e :4 0 ac :4 0
61 :2 0 62 :3 0
15a 343 345 :3 0
61 :2 0 9b :4 0
15d 347 349 :3 0
61 :2 0 9c :4 0
160 34b 34d :3 0
61 :2 0 95 :3 0
163 34f 351 :3 0
61 :2 0 9d :4 0
166 353 355 :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 169 358
35c 16d 357 35e
:3 0 170 340 360
:2 0 362 173 363
33d 362 0 364
175 0 365 177
368 :3 0 368 0
368 367 365 366
:6 0 36a 4 :3 0
17a 36c 17c 36b
36a :2 0 36d 17e
:2 0 36f 0 36f
36e 31c 36d :6 0
707 1 :3 0 93
:3 0 94 :3 0 371
372 0 93 :3 0
a0 :2 0 a1 :3 0
374 376 0 183
375 378 :3 0 379
:2 0 c :3 0 11
:3 0 37b 37c 0
3a2 59 :3 0 5a
:3 0 37e 37f 0
59 :3 0 6a :3 0
381 382 0 21
:2 0 2 :4 0 ad
:2 0 6c :2 0 21
:2 0 186 387 389
:3 0 189 383 38b
380 38d 38c :2 0
5c :3 0 6d :3 0
38f 390 0 5e
:4 0 ae :4 0 61
:2 0 62 :3 0 18d
394 396 :3 0 190
391 398 :2 0 39a
193 39b 38e 39a
0 39c 195 0
3a2 d :3 0 44
:3 0 af :3 0 39e
39f 0 3a0 :2 0
3a2 197 3a3 37a
3a2 0 3a4 19b
0 707 82 :3 0
23 :3 0 21 :2 0
21 :2 0 19d 3a5
3a9 a0 :2 0 b0
:4 0 1a3 3ab 3ad
:3 0 c :3 0 11
:3 0 3af 3b0 0
3d6 59 :3 0 5a
:3 0 3b2 3b3 0
59 :3 0 6a :3 0
3b5 3b6 0 21
:2 0 2 :4 0 b1
:2 0 6c :2 0 21
:2 0 1a6 3bb 3bd
:3 0 1a9 3b7 3bf
3b4 3c1 3c0 :2 0
5c :3 0 6d :3 0
3c3 3c4 0 5e
:4 0 b2 :4 0 61
:2 0 62 :3 0 1ad
3c8 3ca :3 0 1b0
3c5 3cc :2 0 3ce
1b3 3cf 3c2 3ce
0 3d0 1b5 0
3d6 d :3 0 44
:3 0 b3 :3 0 3d2
3d3 0 3d4 :2 0
3d6 1b7 3d7 3ae
3d6 0 3d8 1bb
0 707 b4 :3 0
66 :3 0 58 :3 0
25 :2 0 1bd 3da
3dd 44 :3 0 b5
:3 0 3df 3e0 0
1c0 3d9 3e2 3e3
:2 0 44 :3 0 a0
:2 0 b5 :3 0 3e5
3e7 0 1c5 3e6
3e9 :3 0 c :3 0
15 :3 0 3eb 3ec
0 412 59 :3 0
5a :3 0 3ee 3ef
0 59 :3 0 6a
:3 0 3f1 3f2 0
21 :2 0 2 :4 0
b6 :2 0 6c :2 0
21 :2 0 1c8 3f7
3f9 :3 0 1cb 3f3
3fb 3f0 3fd 3fc
:2 0 5c :3 0 6d
:3 0 3ff 400 0
5e :4 0 b7 :4 0
61 :2 0 62 :3 0
1cf 404 406 :3 0
1d2 401 408 :2 0
40a 1d5 40b 3fe
40a 0 40c 1d7
0 412 d :3 0
44 :3 0 b8 :3 0
40e 40f 0 410
:2 0 412 1d9 413
3ea 412 0 414
1dd 0 707 32
:3 0 25 :2 0 415
416 0 707 b9
:3 0 32 :3 0 ba
:3 0 6f :3 0 14
:4 0 bb 1 :8 0
423 93 :3 0 94
:3 0 41e 41f 0
95 :3 0 420 421
0 423 1df 476
96 :3 0 93 :3 0
94 :3 0 425 426
0 95 :3 0 427
428 0 42a 1e2
42c 1e4 42b 42a
:2 0 474 97 :3 0
93 :3 0 94 :3 0
42f 430 0 95
:3 0 431 432 0
46c 59 :3 0 5a
:3 0 434 435 0
59 :3 0 6a :3 0
437 438 0 98
:2 0 2 :4 0 bc
:2 0 6c :2 0 21
:2 0 1e6 43d 43f
:3 0 1e9 439 441
436 443 442 :2 0
5c :3 0 6d :3 0
445 446 0 5e
:4 0 bd :4 0 61
:2 0 62 :3 0 1ed
44a 44c :3 0 61
:2 0 9b :4 0 1f0
44e 450 :3 0 61
:2 0 9c :4 0 1f3
452 454 :3 0 61
:2 0 95 :3 0 1f6
456 458 :3 0 61
:2 0 9d :4 0 1f9
45a 45c :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 1fc 45f 463
200 45e 465 :3 0
203 447 467 :2 0
469 206 46a 444
469 0 46b 208
0 46c 20a 46f
:3 0 46f 0 46f
46e 46c 46d :6 0
471 6 :3 0 20d
473 20f 472 471
:2 0 474 211 :2 0
476 0 476 475
423 474 :6 0 707
1 :3 0 66 :3 0
32 :3 0 25 :2 0
214 478 47b be
:2 0 25 :2 0 219
47d 47f :3 0 a6
:3 0 23 :3 0 a8
:3 0 a9 :3 0 14
:4 0 bf 1 :8 0
48c 93 :3 0 94
:3 0 487 488 0
95 :3 0 489 48a
0 48c 21c 4df
96 :3 0 93 :3 0
94 :3 0 48e 48f
0 95 :3 0 490
491 0 493 21f
495 221 494 493
:2 0 4dd 97 :3 0
93 :3 0 94 :3 0
498 499 0 95
:3 0 49a 49b 0
4d5 59 :3 0 5a
:3 0 49d 49e 0
59 :3 0 6a :3 0
4a0 4a1 0 98
:2 0 2 :4 0 c0
:2 0 6c :2 0 21
:2 0 223 4a6 4a8
:3 0 226 4a2 4aa
49f 4ac 4ab :2 0
5c :3 0 6d :3 0
4ae 4af 0 5e
:4 0 c1 :4 0 61
:2 0 62 :3 0 22a
4b3 4b5 :3 0 61
:2 0 9b :4 0 22d
4b7 4b9 :3 0 61
:2 0 9c :4 0 230
4bb 4bd :3 0 61
:2 0 95 :3 0 233
4bf 4c1 :3 0 61
:2 0 9d :4 0 236
4c3 4c5 :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 239 4c8 4cc
23d 4c7 4ce :3 0
240 4b0 4d0 :2 0
4d2 243 4d3 4ad
4d2 0 4d4 245
0 4d5 247 4d8
:3 0 4d8 0 4d8
4d7 4d5 4d6 :6 0
4da 8 :3 0 24a
4dc 24c 4db 4da
:2 0 4dd 24e :2 0
4df 0 4df 4de
48c 4dd :6 0 516
1 :3 0 c2 :3 0
c3 :3 0 4e1 4e2
0 23 :3 0 c4
:4 0 251 4e3 4e6
a0 :2 0 25 :2 0
256 4e8 4ea :3 0
c :3 0 14 :3 0
4ec 4ed 0 513
59 :3 0 5a :3 0
4ef 4f0 0 59
:3 0 6a :3 0 4f2
4f3 0 21 :2 0
2 :4 0 c5 :2 0
6c :2 0 21 :2 0
259 4f8 4fa :3 0
25c 4f4 4fc 4f1
4fe 4fd :2 0 5c
:3 0 6d :3 0 500
501 0 5e :4 0
c6 :4 0 61 :2 0
62 :3 0 260 505
507 :3 0 263 502
509 :2 0 50b 266
50c 4ff 50b 0
50d 268 0 513
d :3 0 44 :3 0
c7 :3 0 50f 510
0 511 :2 0 513
26a 514 4eb 513
0 515 26e 0
516 270 517 480
516 0 518 273
0 707 32 :3 0
25 :2 0 519 51a
0 707 c8 :3 0
32 :3 0 c9 :3 0
ca :3 0 a9 :3 0
90 :3 0 cb :3 0
cc :3 0 ca :3 0
cb :3 0 6f :3 0
14 :3 0 cb :3 0
8e :3 0 11 :3 0
cb :3 0 91 :3 0
ca :3 0 91 :3 0
ca :3 0 91 :3 0
ca :3 0 a9 :3 0
ca :3 0 cd :3 0
44 :3 0 ce :4 0
cf 1 :8 0 53d
93 :3 0 94 :3 0
538 539 0 95
:3 0 53a 53b 0
53d 275 590 96
:3 0 93 :3 0 94
:3 0 53f 540 0
95 :3 0 541 542
0 544 278 546
27a 545 544 :2 0
58e 97 :3 0 93
:3 0 94 :3 0 549
54a 0 95 :3 0
54b 54c 0 586
59 :3 0 5a :3 0
54e 54f 0 59
:3 0 6a :3 0 551
552 0 98 :2 0
2 :4 0 d0 :2 0
6c :2 0 21 :2 0
27c 557 559 :3 0
27f 553 55b 550
55d 55c :2 0 5c
:3 0 6d :3 0 55f
560 0 5e :4 0
d1 :4 0 61 :2 0
62 :3 0 283 564
566 :3 0 61 :2 0
9b :4 0 286 568
56a :3 0 61 :2 0
9c :4 0 289 56c
56e :3 0 61 :2 0
95 :3 0 28c 570
572 :3 0 61 :2 0
9d :4 0 28f 574
576 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
292 579 57d 296
578 57f :3 0 299
561 581 :2 0 583
29c 584 55e 583
0 585 29e 0
586 2a0 589 :3 0
589 0 589 588
586 587 :6 0 58b
a :3 0 2a3 58d
2a5 58c 58b :2 0
58e 2a7 :2 0 590
0 590 58f 53d
58e :6 0 707 1
:3 0 66 :3 0 32
:3 0 25 :2 0 2aa
592 595 be :2 0
25 :2 0 2af 597
599 :3 0 c :3 0
11 :3 0 59b 59c
0 5c2 59 :3 0
5a :3 0 59e 59f
0 59 :3 0 6a
:3 0 5a1 5a2 0
21 :2 0 2 :4 0
d2 :2 0 6c :2 0
21 :2 0 2b2 5a7
5a9 :3 0 2b5 5a3
5ab 5a0 5ad 5ac
:2 0 5c :3 0 6d
:3 0 5af 5b0 0
5e :4 0 d3 :4 0
61 :2 0 62 :3 0
2b9 5b4 5b6 :3 0
2bc 5b1 5b8 :2 0
5ba 2bf 5bb 5ae
5ba 0 5bc 2c1
0 5c2 d :3 0
44 :3 0 b8 :3 0
5be 5bf 0 5c0
:2 0 5c2 2c3 5c3
59a 5c2 0 5c4
2c7 0 707 66
:3 0 29 :3 0 25
:2 0 2c9 5c5 5c8
a0 :2 0 25 :2 0
2ce 5ca 5cc :3 0
59 :3 0 5a :3 0
5ce 5cf 0 59
:3 0 6a :3 0 5d1
5d2 0 d4 :2 0
2 :4 0 d5 :2 0
6c :2 0 21 :2 0
2d1 5d7 5d9 :3 0
2d4 5d3 5db 5d0
5dd 5dc :2 0 5c
:3 0 6d :3 0 5df
5e0 0 5e :4 0
d6 :4 0 61 :2 0
62 :3 0 2d8 5e4
5e6 :3 0 61 :2 0
9b :4 0 2db 5e8
5ea :3 0 61 :2 0
d7 :4 0 2de 5ec
5ee :3 0 61 :2 0
66 :3 0 67 :3 0
44 :3 0 d8 :3 0
5f3 5f4 0 2e1
5f2 5f6 68 :4 0
2e3 5f1 5f9 2e6
5f0 5fb :3 0 2e9
5e1 5fd :2 0 5ff
2ec 600 5de 5ff
0 601 2ee 0
62d 59 :3 0 5a
:3 0 602 603 0
59 :3 0 6a :3 0
605 606 0 21
:2 0 2 :4 0 d9
:2 0 6c :2 0 21
:2 0 2f0 60b 60d
:3 0 2f3 607 60f
604 611 610 :2 0
5c :3 0 6d :3 0
613 614 0 5e
:4 0 da :4 0 61
:2 0 62 :3 0 2f7
618 61a :3 0 2fa
615 61c :2 0 61e
2fd 61f 612 61e
0 620 2ff 0
62d d :3 0 db
:3 0 dc :3 0 622
623 0 44 :3 0
d8 :3 0 625 626
0 dd :3 0 301
624 629 62a :2 0
62d de :3 0 304
704 66 :3 0 f
:3 0 25 :2 0 308
62e 631 66 :3 0
df :2 0 2c :3 0
25 :2 0 30b 633
637 310 634 639
:3 0 3e :3 0 25
:2 0 63b 63c 0
6a3 66 :3 0 f
:3 0 25 :2 0 313
63e 641 66 :3 0
be :2 0 29 :3 0
25 :2 0 316 643
647 31b 644 649
:3 0 c :3 0 11
:3 0 64b 64c 0
673 59 :3 0 5a
:3 0 64e 64f 0
59 :3 0 6a :3 0
651 652 0 21
:2 0 2 :4 0 e0
:2 0 6c :2 0 21
:2 0 31e 657 659
:3 0 321 653 65b
650 65d 65c :2 0
5c :3 0 6d :3 0
65f 660 0 5e
:4 0 e1 :4 0 61
:2 0 62 :3 0 325
664 666 :3 0 328
661 668 :2 0 66a
32b 66b 65e 66a
0 66c 32d 0
673 d :3 0 44
:3 0 e2 :3 0 66e
66f 0 670 :2 0
673 de :3 0 32f
686 66 :3 0 f
:3 0 25 :2 0 333
674 677 66 :3 0
a0 :2 0 29 :3 0
25 :2 0 336 679
67d 33b 67a 67f
:3 0 3e :3 0 21
:2 0 681 682 0
684 33e 685 680
684 0 687 64a
673 0 687 340
0 6a3 2d :3 0
f :3 0 688 689
0 6a3 32 :3 0
e3 :3 0 14 :3 0
11 :3 0 2d :3 0
b :3 0 66 :3 0
3e :3 0 25 :2 0
343 691 694 66
:3 0 2f :3 0 25
:2 0 346 696 699
66 :3 0 30 :3 0
25 :2 0 349 69b
69e 34c 68c 6a0
68b 6a1 0 6a3
354 6a4 63a 6a3
0 706 59 :3 0
5a :3 0 6a5 6a6
0 59 :3 0 6a
:3 0 6a8 6a9 0
d4 :2 0 2 :4 0
e4 :2 0 6c :2 0
21 :2 0 359 6ae
6b0 :3 0 35c 6aa
6b2 6a7 6b4 6b3
:2 0 5c :3 0 6d
:3 0 6b6 6b7 0
5e :4 0 e5 :4 0
61 :2 0 62 :3 0
360 6bb 6bd :3 0
61 :2 0 9b :4 0
363 6bf 6c1 :3 0
61 :2 0 d7 :4 0
366 6c3 6c5 :3 0
61 :2 0 66 :3 0
67 :3 0 44 :3 0
d8 :3 0 6ca 6cb
0 369 6c9 6cd
68 :4 0 36b 6c8
6d0 36e 6c7 6d2
:3 0 371 6b8 6d4
:2 0 6d6 374 6d7
6b5 6d6 0 6d8
376 0 703 59
:3 0 5a :3 0 6d9
6da 0 59 :3 0
6a :3 0 6dc 6dd
0 21 :2 0 2
:4 0 e6 :2 0 6c
:2 0 21 :2 0 378
6e2 6e4 :3 0 37b
6de 6e6 6db 6e8
6e7 :2 0 5c :3 0
6d :3 0 6ea 6eb
0 5e :4 0 e7
:4 0 61 :2 0 62
:3 0 37f 6ef 6f1
:3 0 382 6ec 6f3
:2 0 6f5 385 6f6
6e9 6f5 0 6f7
387 0 703 d
:3 0 db :3 0 dc
:3 0 6f9 6fa 0
44 :3 0 d8 :3 0
6fc 6fd 0 dd
:3 0 389 6fb 700
701 :2 0 703 38c
705 5cd 62d 0
706 0 703 0
706 390 0 707
394 16cd 66 :3 0
29 :3 0 25 :2 0
3a0 708 70b a0
:2 0 25 :2 0 3a5
70d 70f :3 0 c
:3 0 11 :3 0 711
712 0 738 59
:3 0 5a :3 0 714
715 0 59 :3 0
6a :3 0 717 718
0 21 :2 0 2
:4 0 e8 :2 0 6c
:2 0 21 :2 0 3a8
71d 71f :3 0 3ab
719 721 716 723
722 :2 0 5c :3 0
6d :3 0 725 726
0 5e :4 0 e9
:4 0 61 :2 0 62
:3 0 3af 72a 72c
:3 0 3b2 727 72e
:2 0 730 3b5 731
724 730 0 732
3b7 0 738 d
:3 0 44 :3 0 d8
:3 0 734 735 0
736 :2 0 738 3b9
739 710 738 0
73a 3bd 0 16cc
32 :3 0 25 :2 0
73b 73c 0 16cc
b9 :3 0 32 :3 0
ba :3 0 6f :3 0
14 :4 0 bb 1
:8 0 749 93 :3 0
94 :3 0 744 745
0 95 :3 0 746
747 0 749 3bf
79c 96 :3 0 93
:3 0 94 :3 0 74b
74c 0 95 :3 0
74d 74e 0 750
3c2 752 3c4 751
750 :2 0 79a 97
:3 0 93 :3 0 94
:3 0 755 756 0
95 :3 0 757 758
0 792 59 :3 0
5a :3 0 75a 75b
0 59 :3 0 6a
:3 0 75d 75e 0
98 :2 0 2 :4 0
ea :2 0 6c :2 0
21 :2 0 3c6 763
765 :3 0 3c9 75f
767 75c 769 768
:2 0 5c :3 0 6d
:3 0 76b 76c 0
5e :4 0 eb :4 0
61 :2 0 62 :3 0
3cd 770 772 :3 0
61 :2 0 9b :4 0
3d0 774 776 :3 0
61 :2 0 9c :4 0
3d3 778 77a :3 0
61 :2 0 95 :3 0
3d6 77c 77e :3 0
61 :2 0 9d :4 0
3d9 780 782 :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 3dc 785
789 3e0 784 78b
:3 0 3e3 76d 78d
:2 0 78f 3e6 790
76a 78f 0 791
3e8 0 792 3ea
795 :3 0 795 0
795 794 792 793
:6 0 797 c :3 0
3ed 799 3ef 798
797 :2 0 79a 3f1
:2 0 79c 0 79c
79b 749 79a :6 0
16cc 1 :3 0 66
:3 0 32 :3 0 25
:2 0 3f4 79e 7a1
be :2 0 25 :2 0
3f9 7a3 7a5 :3 0
a6 :3 0 23 :3 0
a8 :3 0 a9 :3 0
14 :4 0 bf 1
:8 0 7b2 93 :3 0
94 :3 0 7ad 7ae
0 95 :3 0 7af
7b0 0 7b2 3fc
805 96 :3 0 93
:3 0 94 :3 0 7b4
7b5 0 95 :3 0
7b6 7b7 0 7b9
3ff 7bb 401 7ba
7b9 :2 0 803 97
:3 0 93 :3 0 94
:3 0 7be 7bf 0
95 :3 0 7c0 7c1
0 7fb 59 :3 0
5a :3 0 7c3 7c4
0 59 :3 0 6a
:3 0 7c6 7c7 0
98 :2 0 2 :4 0
ec :2 0 6c :2 0
21 :2 0 403 7cc
7ce :3 0 406 7c8
7d0 7c5 7d2 7d1
:2 0 5c :3 0 6d
:3 0 7d4 7d5 0
5e :4 0 ed :4 0
61 :2 0 62 :3 0
40a 7d9 7db :3 0
61 :2 0 9b :4 0
40d 7dd 7df :3 0
61 :2 0 9c :4 0
410 7e1 7e3 :3 0
61 :2 0 95 :3 0
413 7e5 7e7 :3 0
61 :2 0 9d :4 0
416 7e9 7eb :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 419 7ee
7f2 41d 7ed 7f4
:3 0 420 7d6 7f6
:2 0 7f8 423 7f9
7d3 7f8 0 7fa
425 0 7fb 427
7fe :3 0 7fe 0
7fe 7fd 7fb 7fc
:6 0 800 e :3 0
42a 802 42c 801
800 :2 0 803 42e
:2 0 805 0 805
804 7b2 803 :6 0
83c 1 :3 0 c2
:3 0 c3 :3 0 807
808 0 23 :3 0
c4 :4 0 431 809
80c a0 :2 0 25
:2 0 436 80e 810
:3 0 c :3 0 14
:3 0 812 813 0
839 59 :3 0 5a
:3 0 815 816 0
59 :3 0 6a :3 0
818 819 0 21
:2 0 2 :4 0 ee
:2 0 6c :2 0 21
:2 0 439 81e 820
:3 0 43c 81a 822
817 824 823 :2 0
5c :3 0 6d :3 0
826 827 0 5e
:4 0 ef :4 0 61
:2 0 62 :3 0 440
82b 82d :3 0 443
828 82f :2 0 831
446 832 825 831
0 833 448 0
839 d :3 0 44
:3 0 c7 :3 0 835
836 0 837 :2 0
839 44a 83a 811
839 0 83b 44e
0 83c 450 83d
7a6 83c 0 83e
453 0 16cc a5
:3 0 a2 :3 0 a6
:3 0 a7 :3 0 2f
:3 0 30 :3 0 23
:3 0 58 :3 0 a8
:3 0 6f :3 0 14
:3 0 a9 :3 0 15
:4 0 f0 1 :8 0
852 93 :3 0 94
:3 0 84d 84e 0
95 :3 0 84f 850
0 852 455 8a5
96 :3 0 93 :3 0
94 :3 0 854 855
0 95 :3 0 856
857 0 859 458
85b 45a 85a 859
:2 0 8a3 97 :3 0
93 :3 0 94 :3 0
85e 85f 0 95
:3 0 860 861 0
89b 59 :3 0 5a
:3 0 863 864 0
59 :3 0 6a :3 0
866 867 0 98
:2 0 2 :4 0 f1
:2 0 6c :2 0 21
:2 0 45c 86c 86e
:3 0 45f 868 870
865 872 871 :2 0
5c :3 0 6d :3 0
874 875 0 5e
:4 0 f2 :4 0 61
:2 0 62 :3 0 463
879 87b :3 0 61
:2 0 9b :4 0 466
87d 87f :3 0 61
:2 0 9c :4 0 469
881 883 :3 0 61
:2 0 95 :3 0 46c
885 887 :3 0 61
:2 0 9d :4 0 46f
889 88b :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 472 88e 892
476 88d 894 :3 0
479 876 896 :2 0
898 47c 899 873
898 0 89a 47e
0 89b 480 89e
:3 0 89e 0 89e
89d 89b 89c :6 0
8a0 10 :3 0 483
8a2 485 8a1 8a0
:2 0 8a3 487 :2 0
8a5 0 8a5 8a4
852 8a3 :6 0 16cc
1 :3 0 82 :3 0
23 :3 0 21 :2 0
21 :2 0 48a 8a7
8ab a0 :2 0 b0
:4 0 490 8ad 8af
:3 0 c :3 0 11
:3 0 8b1 8b2 0
8d8 59 :3 0 5a
:3 0 8b4 8b5 0
59 :3 0 6a :3 0
8b7 8b8 0 21
:2 0 2 :4 0 f3
:2 0 6c :2 0 21
:2 0 493 8bd 8bf
:3 0 496 8b9 8c1
8b6 8c3 8c2 :2 0
5c :3 0 6d :3 0
8c5 8c6 0 5e
:4 0 f4 :4 0 61
:2 0 62 :3 0 49a
8ca 8cc :3 0 49d
8c7 8ce :2 0 8d0
4a0 8d1 8c4 8d0
0 8d2 4a2 0
8d8 d :3 0 44
:3 0 b3 :3 0 8d4
8d5 0 8d6 :2 0
8d8 4a4 8d9 8b0
8d8 0 8da 4a8
0 16cc b4 :3 0
66 :3 0 58 :3 0
25 :2 0 4aa 8dc
8df 44 :3 0 b5
:3 0 8e1 8e2 0
4ad 8db 8e4 8e5
:2 0 44 :3 0 a0
:2 0 b5 :3 0 8e7
8e9 0 4b2 8e8
8eb :3 0 c :3 0
15 :3 0 8ed 8ee
0 914 59 :3 0
5a :3 0 8f0 8f1
0 59 :3 0 6a
:3 0 8f3 8f4 0
21 :2 0 2 :4 0
f5 :2 0 6c :2 0
21 :2 0 4b5 8f9
8fb :3 0 4b8 8f5
8fd 8f2 8ff 8fe
:2 0 5c :3 0 6d
:3 0 901 902 0
5e :4 0 f6 :4 0
61 :2 0 62 :3 0
4bc 906 908 :3 0
4bf 903 90a :2 0
90c 4c2 90d 900
90c 0 90e 4c4
0 914 d :3 0
44 :3 0 b8 :3 0
910 911 0 912
:2 0 914 4c6 915
8ec 914 0 916
4ca 0 16cc 32
:3 0 25 :2 0 917
918 0 16cc c8
:3 0 32 :3 0 c9
:3 0 a9 :3 0 cc
:3 0 91 :3 0 11
:3 0 91 :3 0 a9
:3 0 cd :3 0 44
:3 0 ce :4 0 f7
1 :8 0 92c 93
:3 0 94 :3 0 927
928 0 95 :3 0
929 92a 0 92c
4cc 97f 96 :3 0
93 :3 0 94 :3 0
92e 92f 0 95
:3 0 930 931 0
933 4cf 935 4d1
934 933 :2 0 97d
97 :3 0 93 :3 0
94 :3 0 938 939
0 95 :3 0 93a
93b 0 975 59
:3 0 5a :3 0 93d
93e 0 59 :3 0
6a :3 0 940 941
0 98 :2 0 2
:4 0 f8 :2 0 6c
:2 0 21 :2 0 4d3
946 948 :3 0 4d6
942 94a 93f 94c
94b :2 0 5c :3 0
6d :3 0 94e 94f
0 5e :4 0 f9
:4 0 61 :2 0 62
:3 0 4da 953 955
:3 0 61 :2 0 9b
:4 0 4dd 957 959
:3 0 61 :2 0 9c
:4 0 4e0 95b 95d
:3 0 61 :2 0 95
:3 0 4e3 95f 961
:3 0 61 :2 0 9d
:4 0 4e6 963 965
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 4e9
968 96c 4ed 967
96e :3 0 4f0 950
970 :2 0 972 4f3
973 94d 972 0
974 4f5 0 975
4f7 978 :3 0 978
0 978 977 975
976 :6 0 97a 12
:3 0 4fa 97c 4fc
97b 97a :2 0 97d
4fe :2 0 97f 0
97f 97e 92c 97d
:6 0 16cc 1 :3 0
66 :3 0 32 :3 0
25 :2 0 501 981
984 be :2 0 25
:2 0 506 986 988
:3 0 c :3 0 11
:3 0 98a 98b 0
9b1 59 :3 0 5a
:3 0 98d 98e 0
59 :3 0 6a :3 0
990 991 0 21
:2 0 2 :4 0 fa
:2 0 6c :2 0 21
:2 0 509 996 998
:3 0 50c 992 99a
98f 99c 99b :2 0
5c :3 0 6d :3 0
99e 99f 0 5e
:4 0 fb :4 0 61
:2 0 62 :3 0 510
9a3 9a5 :3 0 513
9a0 9a7 :2 0 9a9
516 9aa 99d 9a9
0 9ab 518 0
9b1 d :3 0 44
:3 0 b8 :3 0 9ad
9ae 0 9af :2 0
9b1 51a 9b2 989
9b1 0 9b3 51e
0 16cc 3b :3 0
66 :3 0 29 :3 0
25 :2 0 520 9b5
9b8 9b4 9b9 0
16cc 66 :3 0 f
:3 0 25 :2 0 523
9bb 9be 66 :3 0
df :2 0 2c :3 0
25 :2 0 526 9c0
9c4 52b 9c1 9c6
:3 0 2d :3 0 f
:3 0 9c8 9c9 0
11ff 66 :3 0 2d
:3 0 25 :2 0 52e
9cb 9ce 66 :3 0
be :2 0 29 :3 0
25 :2 0 531 9d0
9d4 536 9d1 9d6
:3 0 66 :3 0 30
:3 0 25 :2 0 539
9d8 9db 44 :3 0
a0 :2 0 fc :3 0
9dd 9df 0 53e
9de 9e1 :3 0 66
:3 0 30 :3 0 25
:2 0 541 9e3 9e6
44 :3 0 a0 :2 0
fd :3 0 9e8 9ea
0 546 9e9 9ec
:3 0 9e2 9ee 9ed
:2 0 1f :4 0 9f0
9f1 0 bd5 c8
:3 0 fe :3 0 ff
:3 0 fe :3 0 26
:3 0 1f :3 0 100
:3 0 6f :3 0 14
:3 0 91 :3 0 11
:3 0 101 :4 0 102
1 :8 0 a05 93
:3 0 94 :3 0 a00
a01 0 95 :3 0
a02 a03 0 a05
549 a58 96 :3 0
93 :3 0 94 :3 0
a07 a08 0 95
:3 0 a09 a0a 0
a0c 54c a0e 54e
a0d a0c :2 0 a56
97 :3 0 93 :3 0
94 :3 0 a11 a12
0 95 :3 0 a13
a14 0 a4e 59
:3 0 5a :3 0 a16
a17 0 59 :3 0
6a :3 0 a19 a1a
0 98 :2 0 2
:4 0 103 :2 0 6c
:2 0 21 :2 0 550
a1f a21 :3 0 553
a1b a23 a18 a25
a24 :2 0 5c :3 0
6d :3 0 a27 a28
0 5e :4 0 104
:4 0 61 :2 0 62
:3 0 557 a2c a2e
:3 0 61 :2 0 9b
:4 0 55a a30 a32
:3 0 61 :2 0 9c
:4 0 55d a34 a36
:3 0 61 :2 0 95
:3 0 560 a38 a3a
:3 0 61 :2 0 9d
:4 0 563 a3c a3e
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 566
a41 a45 56a a40
a47 :3 0 56d a29
a49 :2 0 a4b 570
a4c a26 a4b 0
a4d 572 0 a4e
574 a51 :3 0 a51
0 a51 a50 a4e
a4f :6 0 a53 14
:3 0 577 a55 579
a54 a53 :2 0 a56
57b :2 0 a58 0
a58 a57 a05 a56
:6 0 bd5 1 :3 0
1f :3 0 105 :2 0
57e a5b a5c :3 0
a5d :2 0 1a :3 0
1f :3 0 a5f a60
0 a62 580 a63
a5e a62 0 a64
582 0 bd5 66
:3 0 26 :3 0 25
:2 0 584 a65 a68
be :2 0 25 :2 0
589 a6a a6c :3 0
31 :3 0 106 :2 0
21 :2 0 58c a6f
a71 :3 0 a6e a72
0 bd2 32 :3 0
107 :3 0 14 :3 0
15 :3 0 11 :3 0
17 :3 0 19 :3 0
49 :3 0 4b :3 0
31 :3 0 28 :3 0
27 :3 0 58e a75
a80 a74 a81 0
bd2 66 :3 0 2e
:3 0 25 :2 0 599
a83 a86 be :2 0
25 :2 0 59e a88
a8a :3 0 a8b :2 0
1d :3 0 105 :2 0
5a1 a8e a8f :3 0
a90 :2 0 a91 :2 0
a8c a93 a92 :2 0
108 :3 0 109 :3 0
33 :3 0 100 :3 0
6f :3 0 14 :3 0
91 :3 0 11 :3 0
fe :3 0 81 :3 0
82 :3 0 1d :4 0
10a 1 :8 0 aa7
93 :3 0 94 :3 0
aa2 aa3 0 95
:3 0 aa4 aa5 0
aa7 5a3 afa 96
:3 0 93 :3 0 94
:3 0 aa9 aaa 0
95 :3 0 aab aac
0 aae 5a6 ab0
5a8 aaf aae :2 0
af8 97 :3 0 93
:3 0 94 :3 0 ab3
ab4 0 95 :3 0
ab5 ab6 0 af0
59 :3 0 5a :3 0
ab8 ab9 0 59
:3 0 6a :3 0 abb
abc 0 98 :2 0
2 :4 0 10b :2 0
6c :2 0 21 :2 0
5aa ac1 ac3 :3 0
5ad abd ac5 aba
ac7 ac6 :2 0 5c
:3 0 6d :3 0 ac9
aca 0 5e :4 0
10c :4 0 61 :2 0
62 :3 0 5b1 ace
ad0 :3 0 61 :2 0
9b :4 0 5b4 ad2
ad4 :3 0 61 :2 0
9c :4 0 5b7 ad6
ad8 :3 0 61 :2 0
95 :3 0 5ba ada
adc :3 0 61 :2 0
9d :4 0 5bd ade
ae0 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
5c0 ae3 ae7 5c4
ae2 ae9 :3 0 5c7
acb aeb :2 0 aed
5ca aee ac8 aed
0 aef 5cc 0
af0 5ce af3 :3 0
af3 0 af3 af2
af0 af1 :6 0 af5
16 :3 0 5d1 af7
5d3 af6 af5 :2 0
af8 5d5 :2 0 afa
0 afa af9 aa7
af8 :6 0 b16 1
:3 0 29 :3 0 66
:3 0 2d :3 0 25
:2 0 5d8 afd b00
106 :2 0 66 :3 0
2c :3 0 25 :2 0
5db b03 b06 5de
b02 b08 :3 0 106
:2 0 66 :3 0 33
:3 0 25 :2 0 5e1
b0b b0e 5e4 b0a
b10 :3 0 afc b11
0 b16 2a :3 0
10d :2 0 b13 b14
0 b16 5e7 b17
a94 b16 0 b18
5eb 0 bd2 33
:3 0 10e :3 0 66
:3 0 10f :3 0 29
:3 0 5ed b1c b1e
25 :2 0 5ef b1b
b21 110 :2 0 66
:3 0 10f :3 0 26
:3 0 5f2 b25 b27
25 :2 0 5f4 b24
b2a 5f7 b23 b2c
:3 0 b2d :2 0 6c
:2 0 111 :2 0 5fa
b2f b31 :3 0 5fd
b1a b33 b19 b34
0 bd2 32 :3 0
66 :3 0 33 :3 0
25 :2 0 5ff b37
b3a 112 :2 0 66
:3 0 26 :3 0 25
:2 0 602 b3d b40
605 b3c b42 :3 0
b36 b43 0 bd2
66 :3 0 32 :3 0
25 :2 0 608 b45
b48 66 :3 0 df
:2 0 29 :3 0 25
:2 0 60b b4a b4e
610 b4b b50 :3 0
24 :3 0 66 :3 0
33 :3 0 25 :2 0
613 b53 b56 6c
:2 0 66 :3 0 32
:3 0 25 :2 0 616
b59 b5c 619 b58
b5e :3 0 106 :2 0
66 :3 0 29 :3 0
25 :2 0 61c b61
b64 61f b60 b66
:3 0 b52 b67 0
b69 622 b72 24
:3 0 66 :3 0 33
:3 0 25 :2 0 624
b6b b6e b6a b6f
0 b71 627 b73
b51 b69 0 b74
0 b71 0 b74
629 0 bd2 32
:3 0 113 :3 0 14
:3 0 13 :3 0 11
:3 0 1a :3 0 1c
:3 0 24 :3 0 33
:3 0 25 :2 0 62c
b76 b7f b75 b80
0 bd2 2b :3 0
10e :3 0 66 :3 0
10f :3 0 33 :3 0
635 b85 b87 25
:2 0 637 b84 b8a
110 :2 0 66 :3 0
10f :3 0 2f :3 0
63a b8e b90 25
:2 0 63c b8d b93
63f b8c b95 :3 0
b96 :2 0 112 :2 0
114 :2 0 642 b98
b9a :3 0 645 b83
b9c b82 b9d 0
bd2 32 :3 0 115
:3 0 116 :3 0 ba0
ba1 0 66 :3 0
2b :3 0 25 :2 0
647 ba3 ba6 44
:3 0 117 :3 0 ba8
ba9 0 64a ba2
bab b9f bac 0
bd2 32 :3 0 118
:3 0 14 :3 0 11
:3 0 32 :3 0 66
:3 0 2f :3 0 25
:2 0 64d bb3 bb6
66 :3 0 2b :3 0
25 :2 0 650 bb8
bbb 653 baf bbd
bae bbe 0 bd2
31 :3 0 25 :2 0
bc0 bc1 0 bd2
32 :3 0 107 :3 0
14 :3 0 15 :3 0
11 :3 0 17 :3 0
19 :3 0 49 :3 0
4b :3 0 31 :3 0
28 :3 0 27 :3 0
659 bc4 bcf bc3
bd0 0 bd2 664
bd3 a6d bd2 0
bd4 671 0 bd5
673 1182 31 :3 0
106 :2 0 21 :2 0
678 bd7 bd9 :3 0
bd6 bda 0 1181
32 :3 0 107 :3 0
14 :3 0 15 :3 0
11 :3 0 17 :3 0
19 :3 0 49 :3 0
4b :3 0 31 :3 0
28 :3 0 27 :3 0
67a bdd be8 bdc
be9 0 1181 66
:3 0 3f :3 0 25
:2 0 685 beb bee
66 :3 0 df :2 0
3d :3 0 25 :2 0
688 bf0 bf4 68d
bf1 bf6 :3 0 c2
:3 0 c3 :3 0 bf8
bf9 0 16 :3 0
b :3 0 690 bfa
bfd a0 :2 0 25
:2 0 695 bff c01
:3 0 29 :3 0 66
:3 0 2d :3 0 25
:2 0 698 c04 c07
106 :2 0 66 :3 0
29 :3 0 25 :2 0
69b c0a c0d 69e
c09 c0f :3 0 c03
c10 0 d4e 2a
:3 0 10d :2 0 c12
c13 0 d4e 66
:3 0 2d :3 0 25
:2 0 6a1 c15 c18
119 :2 0 66 :3 0
2c :3 0 25 :2 0
6a4 c1b c1e 6c
:2 0 66 :3 0 3d
:3 0 25 :2 0 6a7
c21 c24 6aa c20
c26 :3 0 c27 :2 0
6af c1a c29 :3 0
3d :3 0 66 :3 0
2c :3 0 25 :2 0
6b2 c2c c2f 6c
:2 0 66 :3 0 3d
:3 0 25 :2 0 6b5
c32 c35 6b8 c31
c37 :3 0 c38 :2 0
106 :2 0 66 :3 0
2d :3 0 25 :2 0
6bb c3b c3e 6be
c3a c40 :3 0 c2b
c41 0 cce 90
:3 0 11a :3 0 8f
:3 0 11b :3 0 116
:3 0 8f :3 0 44
:3 0 11c :3 0 75
:3 0 2d :3 0 74
:3 0 2d :3 0 76
:3 0 3d :3 0 8d
:3 0 91 :3 0 11
:4 0 11d 1 :8 0
c6a 11e :4 0 c55
:3 0 11f :3 0 a0
:2 0 6c3 c58 c59
:3 0 93 :3 0 94
:3 0 c5b c5c 0
25 :2 0 c5d c5e
0 c60 6c6 c67
93 :3 0 94 :3 0
c61 c62 0 120
:2 0 c63 c64 0
c66 6c8 c68 c5a
c60 0 c69 0
c66 0 c69 6ca
0 c6a 6cd cbd
96 :3 0 93 :3 0
94 :3 0 c6c c6d
0 95 :3 0 c6e
c6f 0 c71 6d0
c73 6d2 c72 c71
:2 0 cbb 97 :3 0
93 :3 0 94 :3 0
c76 c77 0 95
:3 0 c78 c79 0
cb3 59 :3 0 5a
:3 0 c7b c7c 0
59 :3 0 6a :3 0
c7e c7f 0 98
:2 0 2 :4 0 121
:2 0 6c :2 0 21
:2 0 6d4 c84 c86
:3 0 6d7 c80 c88
c7d c8a c89 :2 0
5c :3 0 6d :3 0
c8c c8d 0 5e
:4 0 122 :4 0 61
:2 0 62 :3 0 6db
c91 c93 :3 0 61
:2 0 9b :4 0 6de
c95 c97 :3 0 61
:2 0 9c :4 0 6e1
c99 c9b :3 0 61
:2 0 95 :3 0 6e4
c9d c9f :3 0 61
:2 0 9d :4 0 6e7
ca1 ca3 :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 6ea ca6 caa
6ee ca5 cac :3 0
6f1 c8e cae :2 0
cb0 6f4 cb1 c8b
cb0 0 cb2 6f6
0 cb3 6f8 cb6
:3 0 cb6 0 cb6
cb5 cb3 cb4 :6 0
cb8 18 :3 0 6fb
cba 6fd cb9 cb8
:2 0 cbb 6ff :2 0
cbd 0 cbd cbc
c6a cbb :6 0 cce
1 :3 0 2a :3 0
115 :3 0 116 :3 0
cc0 cc1 0 66
:3 0 2a :3 0 25
:2 0 702 cc3 cc6
44 :3 0 117 :3 0
cc8 cc9 0 705
cc2 ccb cbf ccc
0 cce 708 d4b
90 :3 0 11a :3 0
8f :3 0 11b :3 0
116 :3 0 8f :3 0
44 :3 0 11c :3 0
75 :3 0 2d :3 0
74 :3 0 2d :3 0
76 :3 0 8d :3 0
91 :3 0 11 :4 0
123 1 :8 0 cf5
11e :4 0 ce0 :3 0
11f :3 0 a0 :2 0
70e ce3 ce4 :3 0
93 :3 0 94 :3 0
ce6 ce7 0 25
:2 0 ce8 ce9 0
ceb 711 cf2 93
:3 0 94 :3 0 cec
ced 0 120 :2 0
cee cef 0 cf1
713 cf3 ce5 ceb
0 cf4 0 cf1
0 cf4 715 0
cf5 718 d48 96
:3 0 93 :3 0 94
:3 0 cf7 cf8 0
95 :3 0 cf9 cfa
0 cfc 71b cfe
71d cfd cfc :2 0
d46 97 :3 0 93
:3 0 94 :3 0 d01
d02 0 95 :3 0
d03 d04 0 d3e
59 :3 0 5a :3 0
d06 d07 0 59
:3 0 6a :3 0 d09
d0a 0 98 :2 0
2 :4 0 124 :2 0
6c :2 0 21 :2 0
71f d0f d11 :3 0
722 d0b d13 d08
d15 d14 :2 0 5c
:3 0 6d :3 0 d17
d18 0 5e :4 0
125 :4 0 61 :2 0
62 :3 0 726 d1c
d1e :3 0 61 :2 0
9b :4 0 729 d20
d22 :3 0 61 :2 0
9c :4 0 72c d24
d26 :3 0 61 :2 0
95 :3 0 72f d28
d2a :3 0 61 :2 0
9d :4 0 732 d2c
d2e :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
735 d31 d35 739
d30 d37 :3 0 73c
d19 d39 :2 0 d3b
73f d3c d16 d3b
0 d3d 741 0
d3e 743 d41 :3 0
d41 0 d41 d40
d3e d3f :6 0 d43
1a :3 0 746 d45
748 d44 d43 :2 0
d46 74a :2 0 d48
0 d48 d47 cf5
d46 :6 0 d4a 1
:3 0 74d d4c c2a
cce 0 d4d 0
d4a 0 d4d 74f
0 d4e 752 ea2
66 :3 0 2d :3 0
25 :2 0 756 d4f
d52 119 :2 0 66
:3 0 2c :3 0 25
:2 0 759 d55 d58
6c :2 0 66 :3 0
3d :3 0 25 :2 0
75c d5b d5e 75f
d5a d60 :3 0 d61
:2 0 764 d54 d63
:3 0 29 :3 0 66
:3 0 3d :3 0 25
:2 0 767 d66 d69
106 :2 0 66 :3 0
29 :3 0 25 :2 0
76a d6c d6f 76d
d6b d71 :3 0 d65
d72 0 e0f 2a
:3 0 10e :3 0 66
:3 0 10f :3 0 2d
:3 0 770 d77 d79
25 :2 0 772 d76
d7c 110 :2 0 66
:3 0 10f :3 0 29
:3 0 775 d80 d82
25 :2 0 777 d7f
d85 77a d7e d87
:3 0 d88 :2 0 112
:2 0 114 :2 0 77d
d8a d8c :3 0 d8d
:2 0 6c :2 0 111
:2 0 780 d8f d91
:3 0 783 d75 d93
d74 d94 0 e0f
90 :3 0 11a :3 0
8f :3 0 11b :3 0
116 :3 0 8f :3 0
44 :3 0 11c :3 0
75 :3 0 3d :3 0
74 :3 0 2d :3 0
91 :3 0 11 :4 0
126 1 :8 0 dba
11e :4 0 da5 :3 0
11f :3 0 a0 :2 0
787 da8 da9 :3 0
93 :3 0 94 :3 0
dab dac 0 25
:2 0 dad dae 0
db0 78a db7 93
:3 0 94 :3 0 db1
db2 0 120 :2 0
db3 db4 0 db6
78c db8 daa db0
0 db9 0 db6
0 db9 78e 0
dba 791 e0d 96
:3 0 93 :3 0 94
:3 0 dbc dbd 0
95 :3 0 dbe dbf
0 dc1 794 dc3
796 dc2 dc1 :2 0
e0b 97 :3 0 93
:3 0 94 :3 0 dc6
dc7 0 95 :3 0
dc8 dc9 0 e03
59 :3 0 5a :3 0
dcb dcc 0 59
:3 0 6a :3 0 dce
dcf 0 98 :2 0
2 :4 0 127 :2 0
6c :2 0 21 :2 0
798 dd4 dd6 :3 0
79b dd0 dd8 dcd
dda dd9 :2 0 5c
:3 0 6d :3 0 ddc
ddd 0 5e :4 0
128 :4 0 61 :2 0
62 :3 0 79f de1
de3 :3 0 61 :2 0
9b :4 0 7a2 de5
de7 :3 0 61 :2 0
9c :4 0 7a5 de9
deb :3 0 61 :2 0
95 :3 0 7a8 ded
def :3 0 61 :2 0
9d :4 0 7ab df1
df3 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
7ae df6 dfa 7b2
df5 dfc :3 0 7b5
dde dfe :2 0 e00
7b8 e01 ddb e00
0 e02 7ba 0
e03 7bc e06 :3 0
e06 0 e06 e05
e03 e04 :6 0 e08
1c :3 0 7bf e0a
7c1 e09 e08 :2 0
e0b 7c3 :2 0 e0d
0 e0d e0c dba
e0b :6 0 e0f 1
:3 0 7c6 e9e 29
:3 0 66 :3 0 2d
:3 0 25 :2 0 7ca
e11 e14 106 :2 0
66 :3 0 29 :3 0
25 :2 0 7cd e17
e1a 7d0 e16 e1c
:3 0 e10 e1d 0
e9d 2a :3 0 10d
:2 0 e1f e20 0
e9d 90 :3 0 11a
:3 0 8f :3 0 11b
:3 0 116 :3 0 8f
:3 0 44 :3 0 11c
:3 0 75 :3 0 2d
:3 0 74 :3 0 2d
:3 0 76 :3 0 8d
:3 0 91 :3 0 11
:4 0 123 1 :8 0
e48 11e :4 0 e33
:3 0 11f :3 0 a0
:2 0 7d5 e36 e37
:3 0 93 :3 0 94
:3 0 e39 e3a 0
25 :2 0 e3b e3c
0 e3e 7d8 e45
93 :3 0 94 :3 0
e3f e40 0 120
:2 0 e41 e42 0
e44 7da e46 e38
e3e 0 e47 0
e44 0 e47 7dc
0 e48 7df e9b
96 :3 0 93 :3 0
94 :3 0 e4a e4b
0 95 :3 0 e4c
e4d 0 e4f 7e2
e51 7e4 e50 e4f
:2 0 e99 97 :3 0
93 :3 0 94 :3 0
e54 e55 0 95
:3 0 e56 e57 0
e91 59 :3 0 5a
:3 0 e59 e5a 0
59 :3 0 6a :3 0
e5c e5d 0 98
:2 0 2 :4 0 129
:2 0 6c :2 0 21
:2 0 7e6 e62 e64
:3 0 7e9 e5e e66
e5b e68 e67 :2 0
5c :3 0 6d :3 0
e6a e6b 0 5e
:4 0 12a :4 0 61
:2 0 62 :3 0 7ed
e6f e71 :3 0 61
:2 0 9b :4 0 7f0
e73 e75 :3 0 61
:2 0 9c :4 0 7f3
e77 e79 :3 0 61
:2 0 95 :3 0 7f6
e7b e7d :3 0 61
:2 0 9d :4 0 7f9
e7f e81 :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 7fc e84 e88
800 e83 e8a :3 0
803 e6c e8c :2 0
e8e 806 e8f e69
e8e 0 e90 808
0 e91 80a e94
:3 0 e94 0 e94
e93 e91 e92 :6 0
e96 1e :3 0 80d
e98 80f e97 e96
:2 0 e99 811 :2 0
e9b 0 e9b e9a
e48 e99 :6 0 e9d
1 :3 0 814 e9f
d64 e0f 0 ea0
0 e9d 0 ea0
818 0 ea1 81b
ea3 c02 d4e 0
ea4 0 ea1 0
ea4 81d 0 ea5
820 f34 29 :3 0
66 :3 0 2d :3 0
25 :2 0 822 ea7
eaa 106 :2 0 66
:3 0 2c :3 0 25
:2 0 825 ead eb0
828 eac eb2 :3 0
ea6 eb3 0 f33
2a :3 0 10d :2 0
eb5 eb6 0 f33
90 :3 0 11a :3 0
8f :3 0 11b :3 0
116 :3 0 8f :3 0
44 :3 0 11c :3 0
75 :3 0 2d :3 0
74 :3 0 2d :3 0
76 :3 0 8d :3 0
91 :3 0 11 :4 0
12b 1 :8 0 ede
11e :4 0 ec9 :3 0
11f :3 0 a0 :2 0
82d ecc ecd :3 0
93 :3 0 94 :3 0
ecf ed0 0 25
:2 0 ed1 ed2 0
ed4 830 edb 93
:3 0 94 :3 0 ed5
ed6 0 120 :2 0
ed7 ed8 0 eda
832 edc ece ed4
0 edd 0 eda
0 edd 834 0
ede 837 f31 96
:3 0 93 :3 0 94
:3 0 ee0 ee1 0
95 :3 0 ee2 ee3
0 ee5 83a ee7
83c ee6 ee5 :2 0
f2f 97 :3 0 93
:3 0 94 :3 0 eea
eeb 0 95 :3 0
eec eed 0 f27
59 :3 0 5a :3 0
eef ef0 0 59
:3 0 6a :3 0 ef2
ef3 0 98 :2 0
2 :4 0 12c :2 0
6c :2 0 21 :2 0
83e ef8 efa :3 0
841 ef4 efc ef1
efe efd :2 0 5c
:3 0 6d :3 0 f00
f01 0 5e :4 0
12d :4 0 61 :2 0
62 :3 0 845 f05
f07 :3 0 61 :2 0
9b :4 0 848 f09
f0b :3 0 61 :2 0
9c :4 0 84b f0d
f0f :3 0 61 :2 0
95 :3 0 84e f11
f13 :3 0 61 :2 0
9d :4 0 851 f15
f17 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
854 f1a f1e 858
f19 f20 :3 0 85b
f02 f22 :2 0 f24
85e f25 eff f24
0 f26 860 0
f27 862 f2a :3 0
f2a 0 f2a f29
f27 f28 :6 0 f2c
20 :3 0 865 f2e
867 f2d f2c :2 0
f2f 869 :2 0 f31
0 f31 f30 ede
f2f :6 0 f33 1
:3 0 86c f35 bf7
ea5 0 f36 0
f33 0 f36 870
0 1181 1d :3 0
105 :2 0 873 f38
f39 :3 0 f3a :2 0
1e :4 0 f3c f3d
0 1104 12e :3 0
12f :3 0 1e :3 0
130 :3 0 a9 :3 0
14 :3 0 70 :3 0
16 :4 0 131 1
:8 0 f4d 93 :3 0
94 :3 0 f48 f49
0 95 :3 0 f4a
f4b 0 f4d 875
fa0 96 :3 0 93
:3 0 94 :3 0 f4f
f50 0 95 :3 0
f51 f52 0 f54
878 f56 87a f55
f54 :2 0 f9e 97
:3 0 93 :3 0 94
:3 0 f59 f5a 0
95 :3 0 f5b f5c
0 f96 59 :3 0
5a :3 0 f5e f5f
0 59 :3 0 6a
:3 0 f61 f62 0
98 :2 0 2 :4 0
132 :2 0 6c :2 0
21 :2 0 87c f67
f69 :3 0 87f f63
f6b f60 f6d f6c
:2 0 5c :3 0 6d
:3 0 f6f f70 0
5e :4 0 133 :4 0
61 :2 0 62 :3 0
883 f74 f76 :3 0
61 :2 0 9b :4 0
886 f78 f7a :3 0
61 :2 0 9c :4 0
889 f7c f7e :3 0
61 :2 0 95 :3 0
88c f80 f82 :3 0
61 :2 0 9d :4 0
88f f84 f86 :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 892 f89
f8d 896 f88 f8f
:3 0 899 f71 f91
:2 0 f93 89c f94
f6e f93 0 f95
89e 0 f96 8a0
f99 :3 0 f99 0
f99 f98 f96 f97
:6 0 f9b 22 :3 0
8a3 f9d 8a5 f9c
f9b :2 0 f9e 8a7
:2 0 fa0 0 fa0
f9f f4d f9e :6 0
1104 1 :3 0 1e
:3 0 105 :2 0 8aa
fa3 fa4 :3 0 fa5
:2 0 81 :3 0 82
:3 0 1e :3 0 1e
:3 0 c9 :4 0 134
1 :8 0 fb2 93
:3 0 94 :3 0 fad
fae 0 95 :3 0
faf fb0 0 fb2
8ac 1005 96 :3 0
93 :3 0 94 :3 0
fb4 fb5 0 95
:3 0 fb6 fb7 0
fb9 8af fbb 8b1
fba fb9 :2 0 1003
97 :3 0 93 :3 0
94 :3 0 fbe fbf
0 95 :3 0 fc0
fc1 0 ffb 59
:3 0 5a :3 0 fc3
fc4 0 59 :3 0
6a :3 0 fc6 fc7
0 98 :2 0 2
:4 0 135 :2 0 6c
:2 0 21 :2 0 8b3
fcc fce :3 0 8b6
fc8 fd0 fc5 fd2
fd1 :2 0 5c :3 0
6d :3 0 fd4 fd5
0 5e :4 0 136
:4 0 61 :2 0 62
:3 0 8ba fd9 fdb
:3 0 61 :2 0 9b
:4 0 8bd fdd fdf
:3 0 61 :2 0 9c
:4 0 8c0 fe1 fe3
:3 0 61 :2 0 95
:3 0 8c3 fe5 fe7
:3 0 61 :2 0 9d
:4 0 8c6 fe9 feb
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 8c9
fee ff2 8cd fed
ff4 :3 0 8d0 fd6
ff6 :2 0 ff8 8d3
ff9 fd3 ff8 0
ffa 8d5 0 ffb
8d7 ffe :3 0 ffe
0 ffe ffd ffb
ffc :6 0 1000 24
:3 0 8da 1002 8dc
1001 1000 :2 0 1003
8de :2 0 1005 0
1005 1004 fb2 1003
:6 0 101a 1 :3 0
c2 :3 0 137 :3 0
1007 1008 0 1d
:3 0 1e :3 0 138
:2 0 8e1 1009 100d
119 :2 0 25 :2 0
8e7 100f 1011 :3 0
1a :3 0 1e :3 0
1013 1014 0 1016
8ea 1017 1012 1016
0 1018 8ec 0
101a de :3 0 8ee
1101 66 :3 0 35
:3 0 25 :2 0 8f1
101b 101e be :2 0
25 :2 0 8f6 1020
1022 :3 0 35 :3 0
115 :3 0 116 :3 0
1025 1026 0 66
:3 0 35 :3 0 25
:2 0 8f9 1028 102b
44 :3 0 117 :3 0
102d 102e 0 8fc
1027 1030 1031 :2 0
1024 1032 0 1099
c2 :3 0 139 :3 0
81 :3 0 82 :3 0
1d :3 0 c2 :3 0
13a :3 0 1a :3 0
1a :3 0 c9 :4 0
13b 1 :8 0 1044
93 :3 0 94 :3 0
103f 1040 0 95
:3 0 1041 1042 0
1044 8ff 1097 96
:3 0 93 :3 0 94
:3 0 1046 1047 0
95 :3 0 1048 1049
0 104b 902 104d
904 104c 104b :2 0
1095 97 :3 0 93
:3 0 94 :3 0 1050
1051 0 95 :3 0
1052 1053 0 108d
59 :3 0 5a :3 0
1055 1056 0 59
:3 0 6a :3 0 1058
1059 0 98 :2 0
2 :4 0 13c :2 0
6c :2 0 21 :2 0
906 105e 1060 :3 0
909 105a 1062 1057
1064 1063 :2 0 5c
:3 0 6d :3 0 1066
1067 0 5e :4 0
13d :4 0 61 :2 0
62 :3 0 90d 106b
106d :3 0 61 :2 0
9b :4 0 910 106f
1071 :3 0 61 :2 0
9c :4 0 913 1073
1075 :3 0 61 :2 0
95 :3 0 916 1077
1079 :3 0 61 :2 0
9d :4 0 919 107b
107d :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
91c 1080 1084 920
107f 1086 :3 0 923
1068 1088 :2 0 108a
926 108b 1065 108a
0 108c 928 0
108d 92a 1090 :3 0
1090 0 1090 108f
108d 108e :6 0 1092
26 :3 0 92d 1094
92f 1093 1092 :2 0
1095 931 :2 0 1097
0 1097 1096 1044
1095 :6 0 1099 1
:3 0 934 109a 1023
1099 0 1103 c2
:3 0 139 :3 0 81
:3 0 82 :3 0 1d
:3 0 c2 :3 0 13a
:3 0 1a :3 0 1a
:3 0 c9 :4 0 13e
1 :8 0 10ab 93
:3 0 94 :3 0 10a6
10a7 0 95 :3 0
10a8 10a9 0 10ab
937 10fe 96 :3 0
93 :3 0 94 :3 0
10ad 10ae 0 95
:3 0 10af 10b0 0
10b2 93a 10b4 93c
10b3 10b2 :2 0 10fc
97 :3 0 93 :3 0
94 :3 0 10b7 10b8
0 95 :3 0 10b9
10ba 0 10f4 59
:3 0 5a :3 0 10bc
10bd 0 59 :3 0
6a :3 0 10bf 10c0
0 98 :2 0 2
:4 0 13f :2 0 6c
:2 0 21 :2 0 93e
10c5 10c7 :3 0 941
10c1 10c9 10be 10cb
10ca :2 0 5c :3 0
6d :3 0 10cd 10ce
0 5e :4 0 140
:4 0 61 :2 0 62
:3 0 945 10d2 10d4
:3 0 61 :2 0 9b
:4 0 948 10d6 10d8
:3 0 61 :2 0 9c
:4 0 94b 10da 10dc
:3 0 61 :2 0 95
:3 0 94e 10de 10e0
:3 0 61 :2 0 9d
:4 0 951 10e2 10e4
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 954
10e7 10eb 958 10e6
10ed :3 0 95b 10cf
10ef :2 0 10f1 95e
10f2 10cc 10f1 0
10f3 960 0 10f4
962 10f7 :3 0 10f7
0 10f7 10f6 10f4
10f5 :6 0 10f9 28
:3 0 965 10fb 967
10fa 10f9 :2 0 10fc
969 :2 0 10fe 0
10fe 10fd 10ab 10fc
:6 0 1100 1 :3 0
96c 1102 fa6 101a
0 1103 0 1100
0 1103 96e 0
1104 972 1105 f3b
1104 0 1106 976
0 1181 13 :3 0
105 :2 0 978 1108
1109 :3 0 110a :2 0
32 :3 0 141 :3 0
14 :3 0 11 :3 0
142 :2 0 97a 110d
1111 110c 1112 0
1114 97e 1135 82
:3 0 20 :3 0 21
:2 0 21 :2 0 980
1115 1119 a0 :2 0
142 :4 0 986 111b
111d :3 0 32 :3 0
141 :3 0 14 :3 0
11 :3 0 25 :2 0
989 1120 1124 111f
1125 0 1127 98d
1131 32 :3 0 141
:3 0 14 :3 0 11
:3 0 21 :2 0 98f
1129 112d 1128 112e
0 1130 993 1132
111e 1127 0 1133
0 1130 0 1133
995 0 1134 998
1136 110b 1114 0
1137 0 1134 0
1137 99a 0 1181
32 :3 0 142 :2 0
1138 1139 0 1181
32 :3 0 143 :3 0
11 :3 0 1a :3 0
29 :3 0 32 :3 0
35 :3 0 b :3 0
25 :2 0 66 :3 0
2b :3 0 25 :2 0
99d 1144 1147 9a0
113c 1149 113b 114a
0 1181 66 :3 0
32 :3 0 25 :2 0
9a9 114c 114f df
:2 0 25 :2 0 9ae
1151 1153 :3 0 c
:3 0 11 :3 0 1155
1156 0 117e 59
:3 0 5a :3 0 1158
1159 0 59 :3 0
6a :3 0 115b 115c
0 21 :2 0 2
:4 0 144 :2 0 6c
:2 0 21 :2 0 9b1
1161 1163 :3 0 9b4
115d 1165 115a 1167
1166 :2 0 5c :3 0
6d :3 0 1169 116a
0 5e :4 0 145
:4 0 61 :2 0 62
:3 0 9b8 116e 1170
:3 0 9bb 116b 1172
:2 0 1174 9be 1175
1168 1174 0 1176
9c0 0 117e d
:3 0 66 :3 0 32
:3 0 25 :2 0 9c2
1178 117b 117c :2 0
117e 9c5 117f 1154
117e 0 1180 9c9
0 1181 9cb 1183
9ef bd5 0 1184
0 1181 0 1184
9d4 0 1188 29
:3 0 2d :3 0 1185
1186 0 1188 9d7
11ac 2a :3 0 10e
:3 0 66 :3 0 10f
:3 0 2d :3 0 9da
118c 118e 25 :2 0
9dc 118b 1191 110
:2 0 66 :3 0 10f
:3 0 29 :3 0 9df
1195 1197 25 :2 0
9e1 1194 119a 9e4
1193 119c :3 0 119d
:2 0 112 :2 0 114
:2 0 9e7 119f 11a1
:3 0 11a2 :2 0 6c
:2 0 111 :2 0 9ea
11a4 11a6 :3 0 9ed
118a 11a8 1189 11a9
0 11ab 9ef 11ad
9d7 1188 0 11ae
0 11ab 0 11ae
9f1 0 11ff 32
:3 0 146 :3 0 14
:3 0 15 :3 0 16
:3 0 11 :3 0 1d
:3 0 20 :3 0 29
:3 0 2d :3 0 3b
:3 0 2c :3 0 2a
:3 0 49 :3 0 4c
:3 0 4b :3 0 4d
:3 0 4e :3 0 50
:3 0 4f :3 0 51
:3 0 28 :3 0 27
:3 0 2e :3 0 b
:3 0 66 :3 0 2f
:3 0 25 :2 0 9f4
11c8 11cb 66 :3 0
30 :3 0 25 :2 0
9f7 11cd 11d0 9fa
11b0 11d2 11af 11d3
0 11ff c :3 0
11 :3 0 11d5 11d6
0 11ff 59 :3 0
5a :3 0 11d8 11d9
0 59 :3 0 6a
:3 0 11db 11dc 0
21 :2 0 2 :4 0
147 :2 0 6c :2 0
21 :2 0 a14 11e1
11e3 :3 0 a17 11dd
11e5 11da 11e7 11e6
:2 0 5c :3 0 6d
:3 0 11e9 11ea 0
5e :4 0 148 :4 0
61 :2 0 62 :3 0
a1b 11ee 11f0 :3 0
a1e 11eb 11f2 :2 0
11f4 a21 11f5 11e8
11f4 0 11f6 a23
0 11ff d :3 0
66 :3 0 32 :3 0
25 :2 0 a25 11f8
11fb 11fc :2 0 11ff
de :3 0 a28 16ca
66 :3 0 e :3 0
25 :2 0 a2f 1200
1203 66 :3 0 df
:2 0 2a :3 0 25
:2 0 a32 1205 1209
a37 1206 120b :3 0
90 :3 0 8d :3 0
e :3 0 8f :3 0
11b :3 0 116 :3 0
8f :3 0 44 :3 0
149 :3 0 91 :3 0
11 :4 0 14a 1
:8 0 122e 11e :4 0
1219 :3 0 11f :3 0
a0 :2 0 a3c 121c
121d :3 0 93 :3 0
94 :3 0 121f 1220
0 25 :2 0 1221
1222 0 1224 a3f
122b 93 :3 0 94
:3 0 1225 1226 0
120 :2 0 1227 1228
0 122a a41 122c
121e 1224 0 122d
0 122a 0 122d
a43 0 122e a46
1281 96 :3 0 93
:3 0 94 :3 0 1230
1231 0 95 :3 0
1232 1233 0 1235
a49 1237 a4b 1236
1235 :2 0 127f 97
:3 0 93 :3 0 94
:3 0 123a 123b 0
95 :3 0 123c 123d
0 1277 59 :3 0
5a :3 0 123f 1240
0 59 :3 0 6a
:3 0 1242 1243 0
98 :2 0 2 :4 0
14b :2 0 6c :2 0
21 :2 0 a4d 1248
124a :3 0 a50 1244
124c 1241 124e 124d
:2 0 5c :3 0 6d
:3 0 1250 1251 0
5e :4 0 14c :4 0
61 :2 0 62 :3 0
a54 1255 1257 :3 0
61 :2 0 9b :4 0
a57 1259 125b :3 0
61 :2 0 9c :4 0
a5a 125d 125f :3 0
61 :2 0 95 :3 0
a5d 1261 1263 :3 0
61 :2 0 9d :4 0
a60 1265 1267 :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 a63 126a
126e a67 1269 1270
:3 0 a6a 1252 1272
:2 0 1274 a6d 1275
124f 1274 0 1276
a6f 0 1277 a71
127a :3 0 127a 0
127a 1279 1277 1278
:6 0 127c 2a :3 0
a74 127e a76 127d
127c :2 0 127f a78
:2 0 1281 0 1281
1280 122e 127f :6 0
12fa 1 :3 0 a8
:3 0 8f :3 0 11b
:3 0 116 :3 0 8f
:3 0 44 :3 0 149
:3 0 6f :3 0 14
:3 0 a9 :3 0 15
:4 0 14d 1 :8 0
12a4 11e :4 0 128f
:3 0 11f :3 0 a0
:2 0 a7d 1292 1293
:3 0 93 :3 0 94
:3 0 1295 1296 0
25 :2 0 1297 1298
0 129a a80 12a1
93 :3 0 94 :3 0
129b 129c 0 120
:2 0 129d 129e 0
12a0 a82 12a2 1294
129a 0 12a3 0
12a0 0 12a3 a84
0 12a4 a87 12f7
96 :3 0 93 :3 0
94 :3 0 12a6 12a7
0 95 :3 0 12a8
12a9 0 12ab a8a
12ad a8c 12ac 12ab
:2 0 12f5 97 :3 0
93 :3 0 94 :3 0
12b0 12b1 0 95
:3 0 12b2 12b3 0
12ed 59 :3 0 5a
:3 0 12b5 12b6 0
59 :3 0 6a :3 0
12b8 12b9 0 98
:2 0 2 :4 0 14e
:2 0 6c :2 0 21
:2 0 a8e 12be 12c0
:3 0 a91 12ba 12c2
12b7 12c4 12c3 :2 0
5c :3 0 6d :3 0
12c6 12c7 0 5e
:4 0 14f :4 0 61
:2 0 62 :3 0 a95
12cb 12cd :3 0 61
:2 0 9b :4 0 a98
12cf 12d1 :3 0 61
:2 0 9c :4 0 a9b
12d3 12d5 :3 0 61
:2 0 95 :3 0 a9e
12d7 12d9 :3 0 61
:2 0 9d :4 0 aa1
12db 12dd :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 aa4 12e0 12e4
aa8 12df 12e6 :3 0
aab 12c8 12e8 :2 0
12ea aae 12eb 12c5
12ea 0 12ec ab0
0 12ed ab2 12f0
:3 0 12f0 0 12f0
12ef 12ed 12ee :6 0
12f2 2c :3 0 ab5
12f4 ab7 12f3 12f2
:2 0 12f5 ab9 :2 0
12f7 0 12f7 12f6
12a4 12f5 :6 0 12fa
1 :3 0 de :3 0
abc 12fb 120c 12fa
0 16cb 66 :3 0
10 :3 0 25 :2 0
abf 12fc 12ff 66
:3 0 df :2 0 2b
:3 0 25 :2 0 ac2
1301 1305 ac7 1302
1307 :3 0 66 :3 0
10 :3 0 25 :2 0
aca 1309 130c a0
:2 0 25 :2 0 acf
130e 1310 :3 0 2b
:3 0 120 :2 0 1312
1313 0 1315 ad2
135e 66 :3 0 10
:3 0 25 :2 0 ad4
1316 1319 119 :2 0
21 :2 0 ad9 131b
131d :3 0 131e :2 0
66 :3 0 10 :3 0
25 :2 0 adc 1320
1323 be :2 0 150
:2 0 ae1 1325 1327
:3 0 1328 :2 0 131f
132a 1329 :2 0 c
:3 0 11 :3 0 132c
132d 0 1353 59
:3 0 5a :3 0 132f
1330 0 59 :3 0
6a :3 0 1332 1333
0 21 :2 0 2
:4 0 151 :2 0 6c
:2 0 21 :2 0 ae4
1338 133a :3 0 ae7
1334 133c 1331 133e
133d :2 0 5c :3 0
6d :3 0 1340 1341
0 5e :4 0 152
:4 0 61 :2 0 62
:3 0 aeb 1345 1347
:3 0 aee 1342 1349
:2 0 134b af1 134c
133f 134b 0 134d
af3 0 1353 d
:3 0 44 :3 0 d8
:3 0 134f 1350 0
1351 :2 0 1353 af5
1354 132b 1353 0
1355 af9 0 135d
2b :3 0 66 :3 0
10 :3 0 25 :2 0
afb 1357 135a 1356
135b 0 135d afe
135f 1311 1315 0
1360 0 135d 0
1360 b01 0 16c8
13 :3 0 105 :2 0
b04 1362 1363 :3 0
1364 :2 0 7e :3 0
32 :3 0 90 :3 0
91 :3 0 13 :4 0
153 1 :8 0 1371
93 :3 0 94 :3 0
136c 136d 0 95
:3 0 136e 136f 0
1371 b06 13c4 96
:3 0 93 :3 0 94
:3 0 1373 1374 0
95 :3 0 1375 1376
0 1378 b09 137a
b0b 1379 1378 :2 0
13c2 97 :3 0 93
:3 0 94 :3 0 137d
137e 0 95 :3 0
137f 1380 0 13ba
59 :3 0 5a :3 0
1382 1383 0 59
:3 0 6a :3 0 1385
1386 0 98 :2 0
2 :4 0 154 :2 0
6c :2 0 21 :2 0
b0d 138b 138d :3 0
b10 1387 138f 1384
1391 1390 :2 0 5c
:3 0 6d :3 0 1393
1394 0 5e :4 0
155 :4 0 61 :2 0
62 :3 0 b14 1398
139a :3 0 61 :2 0
9b :4 0 b17 139c
139e :3 0 61 :2 0
9c :4 0 b1a 13a0
13a2 :3 0 61 :2 0
95 :3 0 b1d 13a4
13a6 :3 0 61 :2 0
9d :4 0 b20 13a8
13aa :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
b23 13ad 13b1 b27
13ac 13b3 :3 0 b2a
1395 13b5 :2 0 13b7
b2d 13b8 1392 13b7
0 13b9 b2f 0
13ba b31 13bd :3 0
13bd 0 13bd 13bc
13ba 13bb :6 0 13bf
2e :3 0 b34 13c1
b36 13c0 13bf :2 0
13c2 b38 :2 0 13c4
0 13c4 13c3 1371
13c2 :6 0 140a 1
:3 0 93 :3 0 94
:3 0 13c6 13c7 0
93 :3 0 a0 :2 0
156 :3 0 13c9 13cb
0 b3d 13ca 13cd
:3 0 13ce :2 0 66
:3 0 2b :3 0 25
:2 0 b40 13d0 13d3
66 :3 0 be :2 0
32 :3 0 25 :2 0
b43 13d5 13d9 b48
13d6 13db :3 0 13dc
:2 0 13cf 13de 13dd
:2 0 c :3 0 13
:3 0 13e0 13e1 0
1407 59 :3 0 5a
:3 0 13e3 13e4 0
59 :3 0 6a :3 0
13e6 13e7 0 21
:2 0 2 :4 0 157
:2 0 6c :2 0 21
:2 0 b4b 13ec 13ee
:3 0 b4e 13e8 13f0
13e5 13f2 13f1 :2 0
5c :3 0 6d :3 0
13f4 13f5 0 5e
:4 0 158 :4 0 61
:2 0 62 :3 0 b52
13f9 13fb :3 0 b55
13f6 13fd :2 0 13ff
b58 1400 13f3 13ff
0 1401 b5a 0
1407 d :3 0 44
:3 0 159 :3 0 1403
1404 0 1405 :2 0
1407 b5c 1408 13df
1407 0 1409 b60
0 140a b62 140b
1365 140a 0 140c
b65 0 16c8 66
:3 0 30 :3 0 25
:2 0 b67 140d 1410
44 :3 0 a0 :2 0
fd :3 0 1412 1414
0 b6c 1413 1416
:3 0 66 :3 0 30
:3 0 25 :2 0 b6f
1418 141b 44 :3 0
a0 :2 0 fc :3 0
141d 141f 0 b74
141e 1421 :3 0 1417
1423 1422 :2 0 31
:3 0 106 :2 0 21
:2 0 b77 1426 1428
:3 0 1425 1429 0
1516 32 :3 0 107
:3 0 14 :3 0 15
:3 0 11 :3 0 17
:3 0 19 :3 0 49
:3 0 4b :3 0 31
:3 0 28 :3 0 27
:3 0 b79 142c 1437
142b 1438 0 1516
66 :3 0 2e :3 0
25 :2 0 b84 143a
143d be :2 0 25
:2 0 b89 143f 1441
:3 0 1442 :2 0 1d
:3 0 105 :2 0 b8c
1445 1446 :3 0 1447
:2 0 1448 :2 0 1443
144a 1449 :2 0 32
:3 0 15a :3 0 14
:3 0 15 :3 0 16
:3 0 13 :3 0 11
:3 0 1d :3 0 2e
:3 0 25 :2 0 b8e
144d 1456 144c 1457
0 1459 b97 145a
144b 1459 0 145b
b99 0 1516 33
:3 0 10e :3 0 66
:3 0 2b :3 0 25
:2 0 b9b 145e 1461
112 :2 0 66 :3 0
2f :3 0 25 :2 0
b9e 1464 1467 ba1
1463 1469 :3 0 146a
:2 0 110 :2 0 114
:2 0 ba4 146c 146e
:3 0 146f :2 0 6c
:2 0 111 :2 0 ba7
1471 1473 :3 0 baa
145d 1475 145c 1476
0 1516 32 :3 0
113 :3 0 14 :3 0
13 :3 0 11 :3 0
1a :3 0 1c :3 0
33 :3 0 33 :3 0
25 :2 0 bac 1479
1482 1478 1483 0
1516 32 :3 0 115
:3 0 116 :3 0 1486
1487 0 66 :3 0
2b :3 0 25 :2 0
bb5 1489 148c 44
:3 0 15b :3 0 148e
148f 0 bb8 1488
1491 1485 1492 0
1516 32 :3 0 118
:3 0 14 :3 0 11
:3 0 32 :3 0 25
:2 0 25 :2 0 bbb
1495 149b 1494 149c
0 1516 81 :3 0
82 :3 0 7f :3 0
81 :3 0 82 :3 0
80 :3 0 17 :3 0
19 :3 0 90 :3 0
91 :3 0 11 :4 0
15c 1 :8 0 14af
93 :3 0 94 :3 0
14aa 14ab 0 95
:3 0 14ac 14ad 0
14af bc1 1502 96
:3 0 93 :3 0 94
:3 0 14b1 14b2 0
95 :3 0 14b3 14b4
0 14b6 bc4 14b8
bc6 14b7 14b6 :2 0
1500 97 :3 0 93
:3 0 94 :3 0 14bb
14bc 0 95 :3 0
14bd 14be 0 14f8
59 :3 0 5a :3 0
14c0 14c1 0 59
:3 0 6a :3 0 14c3
14c4 0 98 :2 0
2 :4 0 15d :2 0
6c :2 0 21 :2 0
bc8 14c9 14cb :3 0
bcb 14c5 14cd 14c2
14cf 14ce :2 0 5c
:3 0 6d :3 0 14d1
14d2 0 5e :4 0
15e :4 0 61 :2 0
62 :3 0 bcf 14d6
14d8 :3 0 61 :2 0
9b :4 0 bd2 14da
14dc :3 0 61 :2 0
9c :4 0 bd5 14de
14e0 :3 0 61 :2 0
95 :3 0 bd8 14e2
14e4 :3 0 61 :2 0
9d :4 0 bdb 14e6
14e8 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
bde 14eb 14ef be2
14ea 14f1 :3 0 be5
14d3 14f3 :2 0 14f5
be8 14f6 14d0 14f5
0 14f7 bea 0
14f8 bec 14fb :3 0
14fb 0 14fb 14fa
14f8 14f9 :6 0 14fd
30 :3 0 bef 14ff
bf1 14fe 14fd :2 0
1500 bf3 :2 0 1502
0 1502 1501 14af
1500 :6 0 1516 1
:3 0 31 :3 0 25
:2 0 1504 1505 0
1516 32 :3 0 107
:3 0 14 :3 0 15
:3 0 11 :3 0 17
:3 0 19 :3 0 49
:3 0 4b :3 0 31
:3 0 28 :3 0 27
:3 0 bf6 1508 1513
1507 1514 0 1516
c01 16c5 31 :3 0
106 :2 0 21 :2 0
c0c 1518 151a :3 0
1517 151b 0 16c4
32 :3 0 107 :3 0
14 :3 0 15 :3 0
11 :3 0 17 :3 0
19 :3 0 49 :3 0
4b :3 0 31 :3 0
28 :3 0 27 :3 0
c0e 151e 1529 151d
152a 0 16c4 66
:3 0 2e :3 0 25
:2 0 c19 152c 152f
be :2 0 25 :2 0
c1e 1531 1533 :3 0
1534 :2 0 1d :3 0
105 :2 0 c21 1537
1538 :3 0 1539 :2 0
153a :2 0 1535 153c
153b :2 0 32 :3 0
15a :3 0 14 :3 0
15 :3 0 16 :3 0
13 :3 0 11 :3 0
1d :3 0 2e :3 0
25 :2 0 c23 153f
1548 153e 1549 0
154b c2c 154c 153d
154b 0 154d c2e
0 16c4 13 :3 0
105 :2 0 c30 154f
1550 :3 0 1551 :2 0
32 :3 0 141 :3 0
14 :3 0 11 :3 0
142 :2 0 c32 1554
1558 1553 1559 0
155b c36 157c 82
:3 0 20 :3 0 21
:2 0 21 :2 0 c38
155c 1560 a0 :2 0
142 :4 0 c3e 1562
1564 :3 0 32 :3 0
141 :3 0 14 :3 0
11 :3 0 25 :2 0
c41 1567 156b 1566
156c 0 156e c45
1578 32 :3 0 141
:3 0 14 :3 0 11
:3 0 21 :2 0 c47
1570 1574 156f 1575
0 1577 c4b 1579
1565 156e 0 157a
0 1577 0 157a
c4d 0 157b c50
157d 1552 155b 0
157e 0 157b 0
157e c52 0 16c4
1d :3 0 105 :2 0
c55 1580 1581 :3 0
1582 :2 0 c2 :3 0
139 :3 0 81 :3 0
82 :3 0 1d :3 0
c2 :3 0 13a :3 0
1a :3 0 1a :3 0
c9 :4 0 15f 1
:8 0 1594 93 :3 0
94 :3 0 158f 1590
0 95 :3 0 1591
1592 0 1594 c57
15e7 96 :3 0 93
:3 0 94 :3 0 1596
1597 0 95 :3 0
1598 1599 0 159b
c5a 159d c5c 159c
159b :2 0 15e5 97
:3 0 93 :3 0 94
:3 0 15a0 15a1 0
95 :3 0 15a2 15a3
0 15dd 59 :3 0
5a :3 0 15a5 15a6
0 59 :3 0 6a
:3 0 15a8 15a9 0
98 :2 0 2 :4 0
160 :2 0 6c :2 0
21 :2 0 c5e 15ae
15b0 :3 0 c61 15aa
15b2 15a7 15b4 15b3
:2 0 5c :3 0 6d
:3 0 15b6 15b7 0
5e :4 0 161 :4 0
61 :2 0 62 :3 0
c65 15bb 15bd :3 0
61 :2 0 9b :4 0
c68 15bf 15c1 :3 0
61 :2 0 9c :4 0
c6b 15c3 15c5 :3 0
61 :2 0 95 :3 0
c6e 15c7 15c9 :3 0
61 :2 0 9d :4 0
c71 15cb 15cd :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 c74 15d0
15d4 c78 15cf 15d6
:3 0 c7b 15b8 15d8
:2 0 15da c7e 15db
15b5 15da 0 15dc
c80 0 15dd c82
15e0 :3 0 15e0 0
15e0 15df 15dd 15de
:6 0 15e2 32 :3 0
c85 15e4 c87 15e3
15e2 :2 0 15e5 c89
:2 0 15e7 0 15e7
15e6 1594 15e5 :6 0
15f8 1 :3 0 29
:3 0 66 :3 0 29
:3 0 25 :2 0 c8c
15ea 15ed 106 :2 0
66 :3 0 2c :3 0
25 :2 0 c8f 15f0
15f3 c92 15ef 15f5
:3 0 15e9 15f6 0
15f8 c95 15f9 1583
15f8 0 15fa c98
0 16c4 35 :3 0
25 :2 0 15fb 15fc
0 16c4 32 :3 0
142 :2 0 15fe 15ff
0 16c4 32 :3 0
143 :3 0 11 :3 0
1a :3 0 29 :3 0
32 :3 0 35 :3 0
b :3 0 25 :2 0
66 :3 0 2b :3 0
25 :2 0 c9a 160a
160d c9d 1602 160f
1601 1610 0 16c4
66 :3 0 32 :3 0
25 :2 0 ca6 1612
1615 df :2 0 25
:2 0 cab 1617 1619
:3 0 c :3 0 11
:3 0 161b 161c 0
1642 59 :3 0 5a
:3 0 161e 161f 0
59 :3 0 6a :3 0
1621 1622 0 21
:2 0 2 :4 0 162
:2 0 6c :2 0 21
:2 0 cae 1627 1629
:3 0 cb1 1623 162b
1620 162d 162c :2 0
5c :3 0 6d :3 0
162f 1630 0 5e
:4 0 163 :4 0 61
:2 0 62 :3 0 cb5
1634 1636 :3 0 cb8
1631 1638 :2 0 163a
cbb 163b 162e 163a
0 163c cbd 0
1642 d :3 0 44
:3 0 159 :3 0 163e
163f 0 1640 :2 0
1642 cbf 16c1 90
:3 0 11a :3 0 7e
:3 0 2b :3 0 7a
:3 0 7c :3 0 79
:3 0 164 :3 0 8f
:3 0 11b :3 0 116
:3 0 8f :3 0 44
:3 0 11c :3 0 44
:3 0 165 :3 0 91
:3 0 11 :4 0 166
1 :8 0 166b 11e
:4 0 1656 :3 0 11f
:3 0 a0 :2 0 cc5
1659 165a :3 0 93
:3 0 94 :3 0 165c
165d 0 25 :2 0
165e 165f 0 1661
cc8 1668 93 :3 0
94 :3 0 1662 1663
0 120 :2 0 1664
1665 0 1667 cca
1669 165b 1661 0
166a 0 1667 0
166a ccc 0 166b
ccf 16be 96 :3 0
93 :3 0 94 :3 0
166d 166e 0 95
:3 0 166f 1670 0
1672 cd2 1674 cd4
1673 1672 :2 0 16bc
97 :3 0 93 :3 0
94 :3 0 1677 1678
0 95 :3 0 1679
167a 0 16b4 59
:3 0 5a :3 0 167c
167d 0 59 :3 0
6a :3 0 167f 1680
0 98 :2 0 2
:4 0 167 :2 0 6c
:2 0 21 :2 0 cd6
1685 1687 :3 0 cd9
1681 1689 167e 168b
168a :2 0 5c :3 0
6d :3 0 168d 168e
0 5e :4 0 168
:4 0 61 :2 0 62
:3 0 cdd 1692 1694
:3 0 61 :2 0 9b
:4 0 ce0 1696 1698
:3 0 61 :2 0 9c
:4 0 ce3 169a 169c
:3 0 61 :2 0 95
:3 0 ce6 169e 16a0
:3 0 61 :2 0 9d
:4 0 ce9 16a2 16a4
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 cec
16a7 16ab cf0 16a6
16ad :3 0 cf3 168f
16af :2 0 16b1 cf6
16b2 168c 16b1 0
16b3 cf8 0 16b4
cfa 16b7 :3 0 16b7
0 16b7 16b6 16b4
16b5 :6 0 16b9 34
:3 0 cfd 16bb cff
16ba 16b9 :2 0 16bc
d01 :2 0 16be 0
16be 16bd 166b 16bc
:6 0 16c0 1 :3 0
d04 16c2 161a 1642
0 16c3 0 16c0
0 16c3 d06 0
16c4 d09 16c6 1424
1516 0 16c7 0
16c4 0 16c7 d13
0 16c8 d16 16c9
1308 16c8 0 16cb
9c7 11ff 0 16cb
d1a 0 16cc d1e
16ce 300 707 0
16cf 0 16cc 0
16cf d2b 0 170a
93 :3 0 94 :3 0
16d0 16d1 0 169
:3 0 14 :3 0 d2e
16d3 16d5 16d2 16d6
0 170a 59 :3 0
5a :3 0 16d8 16d9
0 59 :3 0 6a
:3 0 16db 16dc 0
21 :2 0 2 :4 0
16a :2 0 6c :2 0
21 :2 0 d30 16e1
16e3 :3 0 d33 16dd
16e5 16da 16e7 16e6
:2 0 5c :3 0 6d
:3 0 16e9 16ea 0
5e :4 0 16b :4 0
61 :2 0 62 :3 0
d37 16ee 16f0 :3 0
61 :2 0 9b :4 0
d3a 16f2 16f4 :3 0
61 :2 0 d7 :4 0
d3d 16f6 16f8 :3 0
61 :2 0 93 :3 0
94 :3 0 16fb 16fc
0 d40 16fa 16fe
:3 0 d43 16eb 1700
:2 0 1702 d46 1703
16e8 1702 0 1704
d48 0 170a d
:3 0 93 :3 0 94
:3 0 1706 1707 0
1708 :2 0 170a d4a
170d :3 0 170d d53
170d 170c 170a 170b
:6 0 170e :2 0 2
24 170d 1711 :3 0
1710 170e 1712 :8 0

d94
4
:3 0 1 3 1
9 1 d 1
11 1 15 1
1b 6 8 c
10 14 1a 20
1 26 1 2c
1 32 1 3a
1 38 1 41
1 3f 1 48
1 46 1 4f
1 4d 1 56
1 54 1 5b
1 60 1 65
1 6a 1 6f
1 74 1 79
1 80 1 7e
1 87 1 85
1 8e 1 8c
1 93 1 99
1 9f 1 a5
1 ab 1 b1
1 b7 1 bd
1 c3 1 c9
1 cf 1 d5
1 db 1 e1
1 e7 1 ed
1 f3 1 f9
1 ff 1 105
1 10b 1 111
1 117 1 11d
1 123 1 129
1 12f 1 135
1 13d 1 13b
1 147 1 145
1 151 1 14f
1 156 1 15c
1 162 1 168
1 16e 1 174
1 17a 1 180
1 186 1 18c
1 192 1 198
1 19e 1 1a4
1 1aa 1 1b6
1 1c2 2 1c5
1c7 2 1ca 1cc
2 1ce 1d0 2
1d2 1d4 2 1d6
1d8 1 1de 2
1e0 1e1 2 1da
1e3 2 1e5 1e7
1 1ed 2 1ef
1f0 2 1e9 1f2
2 1f4 1f6 1
1fc 2 1fe 1ff
2 1f8 201 2
203 205 2 207
209 2 20b 20d
2 20f 211 2
213 215 2 217
219 2 21b 21d
2 21f 221 2
223 225 4 1be
1c4 1c9 227 1
229 1 22b 2
235 237 3 233
234 239 2 242
244 2 241 246
1 248 1 24a
2 29c 2a1 1
2a8 1 2a3 2
2bb 2bd 3 2b9
2ba 2bf 2 2c8
2ca 2 2cc 2ce
2 2d0 2d2 2
2d4 2d6 2 2d8
2da 3 2df 2e0
2e1 2 2dc 2e3
2 2c7 2e5 1
2e7 1 2e9 2
2b2 2ea 1 2ee
1 2ad 2 2ab
2f2 1 2fd 2
2f9 2fd 2 316
31b 1 322 1
31d 2 335 337
3 333 334 339
2 342 344 2
346 348 2 34a
34c 2 34e 350
2 352 354 3
359 35a 35b 2
356 35d 2 341
35f 1 361 1
363 2 32c 364
1 368 1 327
2 325 36c 1
377 2 373 377
2 386 388 3
384 385 38a 2
393 395 2 392
397 1 399 1
39b 3 37d 39c
3a1 1 3a3 3
3a6 3a7 3a8 1
3ac 2 3aa 3ac
2 3ba 3bc 3
3b8 3b9 3be 2
3c7 3c9 2 3c6
3cb 1 3cd 1
3cf 3 3b1 3d0
3d5 1 3d7 2
3db 3dc 2 3de
3e1 1 3e8 2
3e4 3e8 2 3f6
3f8 3 3f4 3f5
3fa 2 403 405
2 402 407 1
409 1 40b 3
3ed 40c 411 1
413 2 41d 422
1 429 1 424
2 43c 43e 3
43a 43b 440 2
449 44b 2 44d
44f 2 451 453
2 455 457 2
459 45b 3 460
461 462 2 45d
464 2 448 466
1 468 1 46a
2 433 46b 1
46f 1 42e 2
42c 473 2 479
47a 1 47e 2
47c 47e 2 486
48b 1 492 1
48d 2 4a5 4a7
3 4a3 4a4 4a9
2 4b2 4b4 2
4b6 4b8 2 4ba
4bc 2 4be 4c0
2 4c2 4c4 3
4c9 4ca 4cb 2
4c6 4cd 2 4b1
4cf 1 4d1 1
4d3 2 49c 4d4
1 4d8 1 497
2 495 4dc 2
4e4 4e5 1 4e9
2 4e7 4e9 2
4f7 4f9 3 4f5
4f6 4fb 2 504
506 2 503 508
1 50a 1 50c
3 4ee 50d 512
1 514 2 4df
515 1 517 2
537 53c 1 543
1 53e 2 556
558 3 554 555
55a 2 563 565
2 567 569 2
56b 56d 2 56f
571 2 573 575
3 57a 57b 57c
2 577 57e 2
562 580 1 582
1 584 2 54d
585 1 589 1
548 2 546 58d
2 593 594 1
598 2 596 598
2 5a6 5a8 3
5a4 5a5 5aa 2
5b3 5b5 2 5b2
5b7 1 5b9 1
5bb 3 59d 5bc
5c1 1 5c3 2
5c6 5c7 1 5cb
2 5c9 5cb 2
5d6 5d8 3 5d4
5d5 5da 2 5e3
5e5 2 5e7 5e9
2 5eb 5ed 1
5f5 2 5f7 5f8
2 5ef 5fa 2
5e2 5fc 1 5fe
1 600 2 60a
60c 3 608 609
60e 2 617 619
2 616 61b 1
61d 1 61f 2
627 628 3 601
620 62b 2 62f
630 2 635 636
1 638 2 632
638 2 63f 640
2 645 646 1
648 2 642 648
2 656 658 3
654 655 65a 2
663 665 2 662
667 1 669 1
66b 3 64d 66c
671 2 675 676
2 67b 67c 1
67e 2 678 67e
1 683 2 686
685 2 692 693
2 697 698 2
69c 69d 7 68d
68e 68f 690 695
69a 69f 4 63d
687 68a 6a2 2
6ad 6af 3 6ab
6ac 6b1 2 6ba
6bc 2 6be 6c0
2 6c2 6c4 1
6cc 2 6ce 6cf
2 6c6 6d1 2
6b9 6d3 1 6d5
1 6d7 2 6e1
6e3 3 6df 6e0
6e5 2 6ee 6f0
2 6ed 6f2 1
6f4 1 6f6 2
6fe 6ff 3 6d8
6f7 702 3 704
6a4 705 b 36f
3a4 3d8 414 417
476 518 51b 590
5c4 706 2 709
70a 1 70e 2
70c 70e 2 71c
71e 3 71a 71b
720 2 729 72b
2 728 72d 1
72f 1 731 3
713 732 737 1
739 2 743 748
1 74f 1 74a
2 762 764 3
760 761 766 2
76f 771 2 773
775 2 777 779
2 77b 77d 2
77f 781 3 786
787 788 2 783
78a 2 76e 78c
1 78e 1 790
2 759 791 1
795 1 754 2
752 799 2 79f
7a0 1 7a4 2
7a2 7a4 2 7ac
7b1 1 7b8 1
7b3 2 7cb 7cd
3 7c9 7ca 7cf
2 7d8 7da 2
7dc 7de 2 7e0
7e2 2 7e4 7e6
2 7e8 7ea 3
7ef 7f0 7f1 2
7ec 7f3 2 7d7
7f5 1 7f7 1
7f9 2 7c2 7fa
1 7fe 1 7bd
2 7bb 802 2
80a 80b 1 80f
2 80d 80f 2
81d 81f 3 81b
81c 821 2 82a
82c 2 829 82e
1 830 1 832
3 814 833 838
1 83a 2 805
83b 1 83d 2
84c 851 1 858
1 853 2 86b
86d 3 869 86a
86f 2 878 87a
2 87c 87e 2
880 882 2 884
886 2 888 88a
3 88f 890 891
2 88c 893 2
877 895 1 897
1 899 2 862
89a 1 89e 1
85d 2 85b 8a2
3 8a8 8a9 8aa
1 8ae 2 8ac
8ae 2 8bc 8be
3 8ba 8bb 8c0
2 8c9 8cb 2
8c8 8cd 1 8cf
1 8d1 3 8b3
8d2 8d7 1 8d9
2 8dd 8de 2
8e0 8e3 1 8ea
2 8e6 8ea 2
8f8 8fa 3 8f6
8f7 8fc 2 905
907 2 904 909
1 90b 1 90d
3 8ef 90e 913
1 915 2 926
92b 1 932 1
92d 2 945 947
3 943 944 949
2 952 954 2
956 958 2 95a
95c 2 95e 960
2 962 964 3
969 96a 96b 2
966 96d 2 951
96f 1 971 1
973 2 93c 974
1 978 1 937
2 935 97c 2
982 983 1 987
2 985 987 2
995 997 3 993
994 999 2 9a2
9a4 2 9a1 9a6
1 9a8 1 9aa
3 98c 9ab 9b0
1 9b2 2 9b6
9b7 2 9bc 9bd
2 9c2 9c3 1
9c5 2 9bf 9c5
2 9cc 9cd 2
9d2 9d3 1 9d5
2 9cf 9d5 2
9d9 9da 1 9e0
2 9dc 9e0 2
9e4 9e5 1 9eb
2 9e7 9eb 2
9ff a04 1 a0b
1 a06 2 a1e
a20 3 a1c a1d
a22 2 a2b a2d
2 a2f a31 2
a33 a35 2 a37
a39 2 a3b a3d
3 a42 a43 a44
2 a3f a46 2
a2a a48 1 a4a
1 a4c 2 a15
a4d 1 a51 1
a10 2 a0e a55
1 a5a 1 a61
1 a63 2 a66
a67 1 a6b 2
a69 a6b 1 a70
a a76 a77 a78
a79 a7a a7b a7c
a7d a7e a7f 2
a84 a85 1 a89
2 a87 a89 1
a8d 2 aa1 aa6
1 aad 1 aa8
2 ac0 ac2 3
abe abf ac4 2
acd acf 2 ad1
ad3 2 ad5 ad7
2 ad9 adb 2
add adf 3 ae4
ae5 ae6 2 ae1
ae8 2 acc aea
1 aec 1 aee
2 ab7 aef 1
af3 1 ab2 2
ab0 af7 2 afe
aff 2 b04 b05
2 b01 b07 2
b0c b0d 2 b09
b0f 3 afa b12
b15 1 b17 1
b1d 2 b1f b20
1 b26 2 b28
b29 2 b22 b2b
2 b2e b30 1
b32 2 b38 b39
2 b3e b3f 2
b3b b41 2 b46
b47 2 b4c b4d
1 b4f 2 b49
b4f 2 b54 b55
2 b5a b5b 2
b57 b5d 2 b62
b63 2 b5f b65
1 b68 2 b6c
b6d 1 b70 2
b72 b73 8 b77
b78 b79 b7a b7b
b7c b7d b7e 1
b86 2 b88 b89
1 b8f 2 b91
b92 2 b8b b94
2 b97 b99 1
b9b 2 ba4 ba5
2 ba7 baa 2
bb4 bb5 2 bb9
bba 5 bb0 bb1
bb2 bb7 bbc a
bc5 bc6 bc7 bc8
bc9 bca bcb bcc
bcd bce c a73
a82 b18 b35 b44
b74 b81 b9e bad
bbf bc2 bd1 1
bd3 4 9f2 a58
a64 bd4 1 bd8
a bde bdf be0
be1 be2 be3 be4
be5 be6 be7 2
bec bed 2 bf2
bf3 1 bf5 2
bef bf5 2 bfb
bfc 1 c00 2
bfe c00 2 c05
c06 2 c0b c0c
2 c08 c0e 2
c16 c17 2 c1c
c1d 2 c22 c23
2 c1f c25 1
c28 2 c19 c28
2 c2d c2e 2
c33 c34 2 c30
c36 2 c3c c3d
2 c39 c3f 1
c57 2 c56 c57
1 c5f 1 c65
2 c67 c68 2
c54 c69 1 c70
1 c6b 2 c83
c85 3 c81 c82
c87 2 c90 c92
2 c94 c96 2
c98 c9a 2 c9c
c9e 2 ca0 ca2
3 ca7 ca8 ca9
2 ca4 cab 2
c8f cad 1 caf
1 cb1 2 c7a
cb2 1 cb6 1
c75 2 c73 cba
2 cc4 cc5 2
cc7 cca 3 c42
cbd ccd 1 ce2
2 ce1 ce2 1
cea 1 cf0 2
cf2 cf3 2 cdf
cf4 1 cfb 1
cf6 2 d0e d10
3 d0c d0d d12
2 d1b d1d 2
d1f d21 2 d23
d25 2 d27 d29
2 d2b d2d 3
d32 d33 d34 2
d2f d36 2 d1a
d38 1 d3a 1
d3c 2 d05 d3d
1 d41 1 d00
2 cfe d45 1
d48 2 d4b d4c
3 c11 c14 d4d
2 d50 d51 2
d56 d57 2 d5c
d5d 2 d59 d5f
1 d62 2 d53
d62 2 d67 d68
2 d6d d6e 2
d6a d70 1 d78
2 d7a d7b 1
d81 2 d83 d84
2 d7d d86 2
d89 d8b 2 d8e
d90 1 d92 1
da7 2 da6 da7
1 daf 1 db5
2 db7 db8 2
da4 db9 1 dc0
1 dbb 2 dd3
dd5 3 dd1 dd2
dd7 2 de0 de2
2 de4 de6 2
de8 dea 2 dec
dee 2 df0 df2
3 df7 df8 df9
2 df4 dfb 2
ddf dfd 1 dff
1 e01 2 dca
e02 1 e06 1
dc5 2 dc3 e0a
3 d73 d95 e0d
2 e12 e13 2
e18 e19 2 e15
e1b 1 e35 2
e34 e35 1 e3d
1 e43 2 e45
e46 2 e32 e47
1 e4e 1 e49
2 e61 e63 3
e5f e60 e65 2
e6e e70 2 e72
e74 2 e76 e78
2 e7a e7c 2
e7e e80 3 e85
e86 e87 2 e82
e89 2 e6d e8b
1 e8d 1 e8f
2 e58 e90 1
e94 1 e53 2
e51 e98 3 e1e
e21 e9b 2 e9e
e9f 1 ea0 2
ea2 ea3 1 ea4
2 ea8 ea9 2
eae eaf 2 eab
eb1 1 ecb 2
eca ecb 1 ed3
1 ed9 2 edb
edc 2 ec8 edd
1 ee4 1 edf
2 ef7 ef9 3
ef5 ef6 efb 2
f04 f06 2 f08
f0a 2 f0c f0e
2 f10 f12 2
f14 f16 3 f1b
f1c f1d 2 f18
f1f 2 f03 f21
1 f23 1 f25
2 eee f26 1
f2a 1 ee9 2
ee7 f2e 3 eb4
eb7 f31 2 f34
f35 1 f37 2
f47 f4c 1 f53
1 f4e 2 f66
f68 3 f64 f65
f6a 2 f73 f75
2 f77 f79 2
f7b f7d 2 f7f
f81 2 f83 f85
3 f8a f8b f8c
2 f87 f8e 2
f72 f90 1 f92
1 f94 2 f5d
f95 1 f99 1
f58 2 f56 f9d
1 fa2 2 fac
fb1 1 fb8 1
fb3 2 fcb fcd
3 fc9 fca fcf
2 fd8 fda 2
fdc fde 2 fe0
fe2 2 fe4 fe6
2 fe8 fea 3
fef ff0 ff1 2
fec ff3 2 fd7
ff5 1 ff7 1
ff9 2 fc2 ffa
1 ffe 1 fbd
2 fbb 1002 3
100a 100b 100c 1
1010 2 100e 1010
1 1015 1 1017
2 1005 1018 2
101c 101d 1 1021
2 101f 1021 2
1029 102a 2 102c
102f 2 103e 1043
1 104a 1 1045
2 105d 105f 3
105b 105c 1061 2
106a 106c 2 106e
1070 2 1072 1074
2 1076 1078 2
107a 107c 3 1081
1082 1083 2 107e
1085 2 1069 1087
1 1089 1 108b
2 1054 108c 1
1090 1 104f 2
104d 1094 2 1033
1097 2 10a5 10aa
1 10b1 1 10ac
2 10c4 10c6 3
10c2 10c3 10c8 2
10d1 10d3 2 10d5
10d7 2 10d9 10db
2 10dd 10df 2
10e1 10e3 3 10e8
10e9 10ea 2 10e5
10ec 2 10d0 10ee
1 10f0 1 10f2
2 10bb 10f3 1
10f7 1 10b6 2
10b4 10fb 1 10fe
3 1101 109a 1102
3 f3e fa0 1103
1 1105 1 1107
3 110e 110f 1110
1 1113 3 1116
1117 1118 1 111c
2 111a 111c 3
1121 1122 1123 1
1126 3 112a 112b
112c 1 112f 2
1131 1132 1 1133
2 1135 1136 2
1145 1146 8 113d
113e 113f 1140 1141
1142 1143 1148 2
114d 114e 1 1152
2 1150 1152 2
1160 1162 3 115e
115f 1164 2 116d
116f 2 116c 1171
1 1173 1 1175
2 1179 117a 3
1157 1176 117d 1
117f 8 bdb bea
f36 1106 1137 113a
114b 1180 2 1182
1183 2 1184 1187
1 118d 2 118f
1190 1 1196 2
1198 1199 2 1192
119b 2 119e 11a0
2 11a3 11a5 1
11a7 1 11aa 2
11ac 11ad 2 11c9
11ca 2 11ce 11cf
19 11b1 11b2 11b3
11b4 11b5 11b6 11b7
11b8 11b9 11ba 11bb
11bc 11bd 11be 11bf
11c0 11c1 11c2 11c3
11c4 11c5 11c6 11c7
11cc 11d1 2 11e0
11e2 3 11de 11df
11e4 2 11ed 11ef
2 11ec 11f1 1
11f3 1 11f5 2
11f9 11fa 6 9ca
11ae 11d4 11d7 11f6
11fd 2 1201 1202
2 1207 1208 1
120a 2 1204 120a
1 121b 2 121a
121b 1 1223 1
1229 2 122b 122c
2 1218 122d 1
1234 1 122f 2
1247 1249 3 1245
1246 124b 2 1254
1256 2 1258 125a
2 125c 125e 2
1260 1262 2 1264
1266 3 126b 126c
126d 2 1268 126f
2 1253 1271 1
1273 1 1275 2
123e 1276 1 127a
1 1239 2 1237
127e 1 1291 2
1290 1291 1 1299
1 129f 2 12a1
12a2 2 128e 12a3
1 12aa 1 12a5
2 12bd 12bf 3
12bb 12bc 12c1 2
12ca 12cc 2 12ce
12d0 2 12d2 12d4
2 12d6 12d8 2
12da 12dc 3 12e1
12e2 12e3 2 12de
12e5 2 12c9 12e7
1 12e9 1 12eb
2 12b4 12ec 1
12f0 1 12af 2
12ad 12f4 2 1281
12f7 2 12fd 12fe
2 1303 1304 1
1306 2 1300 1306
2 130a 130b 1
130f 2 130d 130f
1 1314 2 1317
1318 1 131c 2
131a 131c 2 1321
1322 1 1326 2
1324 1326 2 1337
1339 3 1335 1336
133b 2 1344 1346
2 1343 1348 1
134a 1 134c 3
132e 134d 1352 1
1354 2 1358 1359
2 1355 135c 2
135e 135f 1 1361
2 136b 1370 1
1377 1 1372 2
138a 138c 3 1388
1389 138e 2 1397
1399 2 139b 139d
2 139f 13a1 2
13a3 13a5 2 13a7
13a9 3 13ae 13af
13b0 2 13ab 13b2
2 1396 13b4 1
13b6 1 13b8 2
1381 13b9 1 13bd
1 137c 2 137a
13c1 1 13cc 2
13c8 13cc 2 13d1
13d2 2 13d7 13d8
1 13da 2 13d4
13da 2 13eb 13ed
3 13e9 13ea 13ef
2 13f8 13fa 2
13f7 13fc 1 13fe
1 1400 3 13e2
1401 1406 1 1408
2 13c4 1409 1
140b 2 140e 140f
1 1415 2 1411
1415 2 1419 141a
1 1420 2 141c
1420 1 1427 a
142d 142e 142f 1430
1431 1432 1433 1434
1435 1436 2 143b
143c 1 1440 2
143e 1440 1 1444
8 144e 144f 1450
1451 1452 1453 1454
1455 1 1458 1
145a 2 145f 1460
2 1465 1466 2
1462 1468 2 146b
146d 2 1470 1472
1 1474 8 147a
147b 147c 147d 147e
147f 1480 1481 2
148a 148b 2 148d
1490 5 1496 1497
1498 1499 149a 2
14a9 14ae 1 14b5
1 14b0 2 14c8
14ca 3 14c6 14c7
14cc 2 14d5 14d7
2 14d9 14db 2
14dd 14df 2 14e1
14e3 2 14e5 14e7
3 14ec 14ed 14ee
2 14e9 14f0 2
14d4 14f2 1 14f4
1 14f6 2 14bf
14f7 1 14fb 1
14ba 2 14b8 14ff
a 1509 150a 150b
150c 150d 150e 150f
1510 1511 1512 a
142a 1439 145b 1477
1484 1493 149d 1502
1506 1515 1 1519
a 151f 1520 1521
1522 1523 1524 1525
1526 1527 1528 2
152d 152e 1 1532
2 1530 1532 1
1536 8 1540 1541
1542 1543 1544 1545
1546 1547 1 154a
1 154c 1 154e
3 1555 1556 1557
1 155a 3 155d
155e 155f 1 1563
2 1561 1563 3
1568 1569 156a 1
156d 3 1571 1572
1573 1 1576 2
1578 1579 1 157a
2 157c 157d 1
157f 2 158e 1593
1 159a 1 1595
2 15ad 15af 3
15ab 15ac 15b1 2
15ba 15bc 2 15be
15c0 2 15c2 15c4
2 15c6 15c8 2
15ca 15cc 3 15d1
15d2 15d3 2 15ce
15d5 2 15b9 15d7
1 15d9 1 15db
2 15a4 15dc 1
15e0 1 159f 2
159d 15e4 2 15eb
15ec 2 15f1 15f2
2 15ee 15f4 2
15e7 15f7 1 15f9
2 160b 160c 8
1603 1604 1605 1606
1607 1608 1609 160e
2 1613 1614 1
1618 2 1616 1618
2 1626 1628 3
1624 1625 162a 2
1633 1635 2 1632
1637 1 1639 1
163b 3 161d 163c
1641 1 1658 2
1657 1658 1 1660
1 1666 2 1668
1669 2 1655 166a
1 1671 1 166c
2 1684 1686 3
1682 1683 1688 2
1691 1693 2 1695
1697 2 1699 169b
2 169d 169f 2
16a1 16a3 3 16a8
16a9 16aa 2 16a5
16ac 2 1690 16ae
1 16b0 1 16b2
2 167b 16b3 1
16b7 1 1676 2
1674 16bb 1 16be
2 16c1 16c2 9
151c 152b 154d 157e
15fa 15fd 1600 1611
16c3 2 16c5 16c6
3 1360 140c 16c7
3 16ca 12fb 16c9
c 73a 73d 79c
83e 8a5 8da 916
919 97f 9b3 9ba
16cb 2 16cd 16ce
1 16d4 2 16e0
16e2 3 16de 16df
16e4 2 16ed 16ef
2 16f1 16f3 2
16f5 16f7 2 16f9
16fd 2 16ec 16ff
1 1701 1 1703
8 22c 24b 24e
2f5 16cf 16d7 1704
1709 40 2a 30
36 3d 44 4b
52 59 5e 63
68 6d 72 77
7c 83 8a 91
97 9d a3 a9
af b5 bb c1
c7 cd d3 d9
df e5 eb f1
f7 fd 103 109
10f 115 11b 121
127 12d 133 139
143 14d 154 15a
160 166 16c 172
178 17e 184 18a
190 196 19c 1a2
1a8 1ae 
1
4
0 
1711
0
1
50
35
47
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

117 1 0
1b 1 0
180 1 0
12f 1 0
e1 1 0
ff 1 0
6a 1 0
129 1 0
db 1 0
c3 1 0
123 1 0
c9 1 0
145 1 0
85 1 0
186 1 0
99 1 0
15c 1 0
18c 1 0
3 1 0
26 1 0
162 1 0
13b 1 0
79 1 0
e7 1 0
d 1 0
b7 1 0
10b 1 0
6f 1 0
ab 1 0
1aa 1 0
8c 1 0
b1 1 0
65 1 0
16e 1 0
9f 1 0
9 1 0
f9 1 0
93 1 0
135 1 0
11 1 0
60 1 0
17a 1 0
2c 1 0
a5 1 0
4d 1 0
38 1 0
bd 1 0
105 1 0
2 0 1
111 1 0
32 1 0
11d 1 0
7e 1 0
74 1 0
168 1 0
d5 1 0
54 1 0
46 1 0
cf 1 0
3f 1 0
156 1 0
5b 1 0
192 1 0
198 1 0
ed 1 0
15 1 0
19e 1 0
1a4 1 0
14f 1 0
f3 1 0
174 1 0
0

/
SHOW ERRORS FUNCTION FC_U_WP_ACTUAL;
ALTER FUNCTION FC_U_WP_ACTUAL COMPILE DEBUG;
/******************************************************************************************************************
update Actual Work, %W, %C in Work Packages
assign_id:      TSK_ASSIGNMENT_ID or TASK_ID
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_WP_ACTUAL ==
CREATE OR REPLACE FUNCTION SP_U_WP_ACTUAL wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
4d
2 :e:
1FUNCTION:
1SP_U_WP_ACTUAL:
1ASSIGN_ID:
1VARCHAR2:
1P_WORK_PERCENT:
1PLS_INTEGER:
1P_ACTUAL:
1P_UNITS:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ASSIGN_ID:
132:
1H_NEW_WORK_PERCENT:
10:
1H_ACTUAL:
1H_UNITS:
1H_REC_USER:
1H_ERROR_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_ACTUAL(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
128:
1+:
1FPUT:
1               ENTER:: SP_U_WP_ACTUAL(29) :: cplan.sql(16446) :: :
1SC_STATE:
1FC_U_WP_ACTUAL:
14:
143:
1       RETURN_STATUS:: SP_U_WP_ACTUAL(44) :: cplan.sql(16461) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
150:
1           EXCEPTION:: SP_U_WP_ACTUAL(51) :: cplan.sql(16468) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
162:
1           EXCEPTION:: SP_U_WP_ACTUAL(63) :: cplan.sql(16480) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1ec
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c a0
4d d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :7 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
1ec
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 56
7c 80 84 88 8b 8f ac 97
9b 9e 9f a7 96 c8 b7 bb
93 c3 b6 e4 d3 d7 b3 df
d2 100 ef f3 cf fb ee 11d
10b eb 10f 110 118 10a 13a 128
107 12c 12d 135 127 15a 145 149
124 14d 155 144 161 165 141 169
16d 171 174 179 17a 1 17c 181
185 189 18c 191 195 199 19c 1a1
1a2 1a4 1a9 1ac 1b0 1b1 1b6 1bb
1be 1c3 1c4 1c9 1cc 1d0 1d1 1d6
1d9 1de 1df 1e4 1e7 1ec 1ed 1f2
1f5 1f9 1fd 201 202 204 209 20a
20c 20d 212 215 21a 21b 220 223
227 22b 22f 230 232 237 238 23a
23b 240 243 248 249 24e 251 255
259 25d 25e 260 265 266 268 269
26e 271 276 277 27c 27f 284 285
28a 28d 291 292 297 29a 29f 2a0
2a5 2a8 2ad 2ae 2b3 2b4 2b9 2bb
2bf 2c2 2c6 2ca 2cd 2d1 2d5 2d8
2db 2e0 2e3 2e6 2e9 2ea 2ef 2f0
1 2f2 2f7 2fb 2ff 302 307 30c
30f 313 314 319 31a 31f 321 325
328 32c 32d 331 335 339 33d 341
345 349 34d 351 355 359 35d 361
365 369 36d 371 375 378 37c 380
384 388 38c 390 394 395 397 39b
39f 3a3 3a6 3aa 3ae 3b1 3b4 3b9
3bc 3bf 3c2 3c3 3c8 3c9 1 3cb
3d0 3d4 3d8 3db 3e0 3e5 3e8 3ec
3ed 3f2 3f5 3fa 3fb 400 403 408
409 40e 411 415 419 41d 421 424
425 427 42c 42d 42f 430 435 438
43d 43e 443 446 44b 44c 451 454
458 459 45e 461 466 467 46c 46d
472 474 478 47b 47f 483 486 48a
48e 491 495 499 49a 49f 4a1 4a5
4a9 4ac 4b0 4b4 4b7 4bb 4bf 4c2
4c5 4ca 4cd 4d0 4d3 4d4 4d9 4da
1 4dc 4e1 4e5 4e9 4ec 4f1 4f6
4f9 4fd 4fe 503 504 509 50d 511
514 519 51e 521 525 529 52c 52d
532 535 53a 53b 540 543 547 54b
54e 54f 554 555 55a 55c 560 563
567 56b 56f 573 577 57b 57f 583
587 593 598 59c 5a0 5a4 5a8 5aa
5ab 5b0 1 5b4 5b8 5bc 5bf 5c3
5c7 5cb 5cf 5d2 5d6 5da 5dd 5e0
5e5 5e8 5eb 5ee 5ef 5f4 5f5 1
5f7 5fc 600 604 607 60c 611 614
618 619 61e 61f 624 628 62c 62f
634 639 63c 640 641 646 649 64e
64f 654 657 65b 65f 662 665 666
668 669 66e 66f 674 676 67a 67d
681 685 689 68d 691 695 699 6a5
6aa 6ae 6b2 6b6 6ba 6bc 6c0 6c2
6ce 6d0 6d2 6d3 6d8 6dc 6de 6ea
6ee 6f0 6f1 6fa 
1ec
2
0 1 a 6 10 :3 6 15 :3 6
f :3 6 e :3 6 10 :2 6 1 3
a 13 a :2 1 4 10 19 18
:2 10 :2 4 :2 17 26 17 :2 4 :2 d 1c
d :2 4 :2 c 1b c :2 4 f 18
17 :2 f :2 4 f 18 17 :2 f :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 56 5c 5f :2 56 6d 85 8
:2 6d d 10 :2 6d 1a 1d :2 6d b
e :2 6d 13 16 1f 27 :2 1f 38
:2 16 :2 6d b e :2 6d 13 16 1f
27 :2 1f 32 :2 16 :2 6d b e :2 6d
13 16 1f 27 :2 1f 31 :2 16 :2 6d
b e :2 6d 13 16 :2 6d 1b 1e
:2 6d 28 2b :2 6d 30 33 :2 6d :2 7
4c :2 4 7 :2 11 23 :2 2d 39 3c
4e 50 51 :2 4e :2 23 :3 7 :2 d 12
1e 5f 62 :2 1e :2 7 54 :3 4 12
:2 4 13 :2 4 1a :2 4 10 :2 4 f
:2 4 12 :2 4 :2 d 19 28 35 49
53 5c 27 :2 19 4 7 :2 11 23
:2 2d 39 3c 4e 50 51 :2 4e :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e 6f
72 :2 1e 76 79 :2 1e 83 86 8f
97 :2 a0 :2 8f ab :2 86 :2 1e b3 b6
:2 1e be c1 :2 1e c6 c9 :2 1e d4
d7 :2 1e :2 7 54 :3 4 :2 f 21 :2 2a
34 40 :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 52 54 55
:2 52 :2 26 :3 a :2 10 15 21 62 65
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 58 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4f 51 52
:2 4f :2 23 :3 7 :2 d 12 1e 5f 62
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 55 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
1ec
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 2
:4 8 :2 1 :7 a :6 b
:6 c :6 d :7 e :7 f
:7 11 :b 13 :11 14 15
:2 14 :2 15 :2 14 :2 15
:2 14 :2 16 :2 14 :9 16
:2 14 :2 17 :2 14 :9 17
:2 14 :2 18 :2 14 :9 18
:2 14 :2 19 :2 14 :2 19
:2 14 :2 19 :2 14 :2 19
:2 14 :2 19 :4 14 :3 13
:11 1c :b 1d :3 1c :3 20
:3 22 :3 23 :3 24 :3 25
:3 26 :9 28 29 :3 28
:11 2b :30 2c :3 2b :a 2e
12 :3 31 :11 32 :b 33
:17 34 :3 32 :2 36 :3 37
:3 38 39 37 36
37 :3 3a :3 31 :2 3b
:5 3d :11 3e :b 3f :18 40
:3 3e :2 42 43 :3 44
45 43 42 43
:3 46 :2 3c :6 3b 30
:7 1 
6fc
4
:3 0 1 :3 0 2
:a 0 1e7 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d :2 0 b
6 :3 0 8 :7 0
11 10 :3 0 4
:3 0 9 :7 0 15
14 :3 0 a :3 0
b :3 0 c :2 0
4 19 1a 0
17 1b 0 1e7
2 1c :2 0 10
:2 0 15 4 :3 0
e :2 0 13 1f
21 :6 0 24 22
0 1e5 0 d
:6 0 10 :2 0 17
6 :3 0 26 :7 0
2a 27 28 1e5
0 f :6 0 10
:2 0 19 6 :3 0
2c :7 0 30 2d
2e 1e5 0 11
:6 0 e :2 0 1b
6 :3 0 32 :7 0
36 33 34 1e5
0 12 :6 0 e
:2 0 1f 4 :3 0
1d 38 3a :6 0
3d 3b 0 1e5
0 13 :6 0 46
47 0 23 4
:3 0 21 3f 41
:6 0 44 42 0
1e5 0 14 :6 0
4c 4d 0 25
b :3 0 c :2 0
4 48 :7 0 4b
49 0 1e5 0
15 :6 0 16 :3 0
17 :3 0 16 :3 0
18 :3 0 4f 50
0 2 :4 0 27
51 53 4e 55
54 :2 0 19 :3 0
1a :3 0 57 58
0 1b :4 0 16
:3 0 1c :3 0 5b
5c 0 2 :4 0
29 5d 5f 1d
:4 0 1e :2 0 1f
:3 0 2b 62 64
:3 0 20 :4 0 1e
:2 0 21 :4 0 2e
67 69 :3 0 1e
:2 0 3 :3 0 31
6b 6d :3 0 1e
:2 0 21 :4 0 34
6f 71 :3 0 1e
:2 0 22 :4 0 37
73 75 :3 0 1e
:2 0 23 :3 0 24
:3 0 5 :3 0 3a
79 7b 25 :4 0
3c 78 7e 3f
77 80 :3 0 1e
:2 0 22 :4 0 42
82 84 :3 0 1e
:2 0 23 :3 0 24
:3 0 7 :3 0 45
88 8a 25 :4 0
47 87 8d 4a
86 8f :3 0 1e
:2 0 22 :4 0 4d
91 93 :3 0 1e
:2 0 23 :3 0 24
:3 0 8 :3 0 50
97 99 25 :4 0
52 96 9c 55
95 9e :3 0 1e
:2 0 22 :4 0 58
a0 a2 :3 0 1e
:2 0 21 :4 0 5b
a4 a6 :3 0 1e
:2 0 9 :3 0 5e
a8 aa :3 0 1e
:2 0 21 :4 0 61
ac ae :3 0 1e
:2 0 26 :4 0 64
b0 b2 :3 0 67
59 b4 :2 0 b6
6c b7 56 b6
0 b8 6e 0
145 16 :3 0 17
:3 0 b9 ba 0
16 :3 0 27 :3 0
bc bd 0 28
:2 0 2 :4 0 29
:2 0 2a :2 0 28
:2 0 70 c2 c4
:3 0 73 be c6
bb c8 c7 :2 0
19 :3 0 2b :3 0
ca cb 0 1b
:4 0 2c :4 0 1e
:2 0 1f :3 0 77
cf d1 :3 0 7a
cc d3 :2 0 d5
7d d6 c9 d5
0 d7 7f 0
145 14 :4 0 d8
d9 0 145 d
:3 0 3 :3 0 db
dc 0 145 f
:3 0 5 :3 0 de
df 0 145 11
:3 0 7 :3 0 e1
e2 0 145 12
:3 0 8 :3 0 e4
e5 0 145 13
:3 0 9 :3 0 e7
e8 0 145 b
:3 0 2d :3 0 ea
eb 0 2e :3 0
d :3 0 f :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
81 ed f4 ec
f5 0 145 16
:3 0 17 :3 0 f7
f8 0 16 :3 0
27 :3 0 fa fb
0 2f :2 0 2
:4 0 30 :2 0 2a
:2 0 28 :2 0 88
100 102 :3 0 8b
fc 104 f9 106
105 :2 0 19 :3 0
2b :3 0 108 109
0 1b :4 0 31
:4 0 1e :2 0 1f
:3 0 8f 10d 10f
:3 0 1e :2 0 32
:4 0 92 111 113
:3 0 1e :2 0 33
:4 0 95 115 117
:3 0 1e :2 0 23
:3 0 24 :3 0 b
:3 0 2d :3 0 11c
11d 0 98 11b
11f 25 :4 0 9a
11a 122 9d 119
124 :3 0 1e :2 0
34 :4 0 a0 126
128 :3 0 1e :2 0
21 :4 0 a3 12a
12c :3 0 1e :2 0
14 :3 0 a6 12e
130 :3 0 1e :2 0
21 :4 0 a9 132
134 :3 0 ac 10a
136 :2 0 138 af
139 107 138 0
13a b1 0 145
35 :3 0 36 :3 0
13b 13c 0 b
:3 0 2d :3 0 13e
13f 0 14 :3 0
37 :3 0 b3 13d
143 :2 0 145 b7
1e6 b :3 0 38
:2 0 4 146 147
0 16 :3 0 17
:3 0 149 14a 0
16 :3 0 27 :3 0
14c 14d 0 39
:2 0 2 :4 0 3a
:2 0 2a :2 0 28
:2 0 c3 152 154
:3 0 c6 14e 156
14b 158 157 :2 0
19 :3 0 2b :3 0
15a 15b 0 1b
:4 0 3b :4 0 1e
:2 0 1f :3 0 ca
15f 161 :3 0 cd
15c 163 :2 0 17c
19 :3 0 2b :3 0
165 166 0 1b
:4 0 3c :4 0 1e
:2 0 b :3 0 3d
:3 0 16b 16c 0
d0 16a 16e :3 0
1e :2 0 34 :4 0
d3 170 172 :3 0
1e :2 0 b :3 0
3e :3 0 175 176
0 d6 174 178
:3 0 d9 167 17a
:2 0 17c dc 17d
159 17c 0 17e
df 0 18e 3f
:3 0 15 :3 0 b
:3 0 3d :3 0 40
:3 0 b :3 0 3e
:3 0 41 :3 0 42
:4 0 43 1 :a 0
18a :2 0 18e 180
188 :2 0 a :3 0
15 :3 0 18c :2 0
18e e1 190 e5
18f 18e :2 0 1e4
44 :3 0 b :3 0
2d :3 0 193 194
0 45 :3 0 195
196 0 1dc 16
:3 0 17 :3 0 198
199 0 16 :3 0
27 :3 0 19b 19c
0 39 :2 0 2
:4 0 46 :2 0 2a
:2 0 28 :2 0 e7
1a1 1a3 :3 0 ea
19d 1a5 19a 1a7
1a6 :2 0 19 :3 0
2b :3 0 1a9 1aa
0 1b :4 0 47
:4 0 1e :2 0 1f
:3 0 ee 1ae 1b0
:3 0 f1 1ab 1b2
:2 0 1cc 19 :3 0
2b :3 0 1b4 1b5
0 1b :4 0 48
:4 0 1e :2 0 45
:3 0 f4 1b9 1bb
:3 0 1e :2 0 49
:4 0 f7 1bd 1bf
:3 0 1e :2 0 4a
:3 0 4b :3 0 28
:2 0 4c :2 0 fa
1c2 1c6 fe 1c1
1c8 :3 0 101 1b6
1ca :2 0 1cc 104
1cd 1a8 1cc 0
1ce 107 0 1dc
3f :3 0 15 :3 0
40 :3 0 b :3 0
3e :3 0 41 :3 0
42 :4 0 4d 1
:a 0 1d8 :2 0 1dc
1d0 1d6 :2 0 a
:3 0 15 :3 0 1da
:2 0 1dc 109 1df
:3 0 1df 0 1df
1de 1dc 1dd :6 0
1e1 1 :3 0 10e
1e3 110 1e2 1e1
:2 0 1e4 112 :2 0
1e6 115 1e6 1e5
145 1e4 :6 0 1e7
:2 0 2 1c 1e6
1ea :3 0 1e9 1e7
1eb :8 0 
11d
4
:3 0 1 3 1
7 1 b 1
f 1 13 5
6 a e 12
16 1 20 1
1e 1 25 1
2b 1 31 1
39 1 37 1
40 1 3e 1
45 1 52 1
5e 2 61 63
2 66 68 2
6a 6c 2 6e
70 2 72 74
1 7a 2 7c
7d 2 76 7f
2 81 83 1
89 2 8b 8c
2 85 8e 2
90 92 1 98
2 9a 9b 2
94 9d 2 9f
a1 2 a3 a5
2 a7 a9 2
ab ad 2 af
b1 4 5a 60
65 b3 1 b5
1 b7 2 c1
c3 3 bf c0
c5 2 ce d0
2 cd d2 1
d4 1 d6 6
ee ef f0 f1
f2 f3 2 ff
101 3 fd fe
103 2 10c 10e
2 110 112 2
114 116 1 11e
2 120 121 2
118 123 2 125
127 2 129 12b
2 12d 12f 2
131 133 2 10b
135 1 137 1
139 3 140 141
142 b b8 d7
da dd e0 e3
e6 e9 f6 13a
144 2 151 153
3 14f 150 155
2 15e 160 2
15d 162 2 169
16d 2 16f 171
2 173 177 2
168 179 2 164
17b 1 17d 3
17e 189 18d 1
148 2 1a0 1a2
3 19e 19f 1a4
2 1ad 1af 2
1ac 1b1 2 1b8
1ba 2 1bc 1be
3 1c3 1c4 1c5
2 1c0 1c7 2
1b7 1c9 2 1b3
1cb 1 1cd 4
197 1ce 1d7 1db
1 1df 1 192
2 190 1e3 7
23 29 2f 35
3c 43 4a 
1
4
0 
1ea
0
1
14
2
d
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
3e 1 0
2 0 1
13 1 0
1e 1 0
25 1 0
2b 1 0
3 1 0
31 1 0
f 1 0
7 1 0
b 1 0
37 1 0
45 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_ACTUAL;
ALTER FUNCTION SP_U_WP_ACTUAL COMPILE DEBUG;
Prompt == FUNCTION FC_U_FD_SD ==
CREATE OR REPLACE FUNCTION FC_U_FD_SD wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
81
2 :e:
1FUNCTION:
1FC_U_FD_SD:
1H_SCHED_START:
1OUT:
1NOCOPY:
1TIMESTAMP:
1H_START_DATE:
1H_FINISH_DATE:
1H_PRJ_ASSIGN_ID:
1VARCHAR2:
1H_PROJECT_ID:
1H_TASK_ID:
1A_TEMP_ID:
1H_SD:
1DATE:
1H_FD:
1H_BIT_FLAG:
1H_RES_ID:
1H_RES_TYPE:
1SH_H_PER_DAY:
1PLS_INTEGER:
1SH_H_PERCENT_UNITS:
1SH_H_REG_COST:
1NUMBER:
1SH_H_REG_SALE:
1SH_H_CAPITAL_EXPENSE:
1SH_H_BILLABLE:
1H_REC_USER:
1SH_H_EFFORT:
1SH_H_WORK_TODATE:
1RETURN:
1H_PER_DAY:
1H_PERCENT_UNITS:
1H_REG_COST:
1H_REG_SALE:
1H_CAPITAL_EXPENSE:
1H_BILLABLE:
1H_EFFORT:
1COALESCE:
10:
1H_WORK_TODATE:
1H_ID:
132:
1H_TPH_DELETE:
1H_COUNT:
1H_WORK_TYPE:
1H_REMAINING:
1H_TEMP_VAR:
1I_BITFLAG:
1PMO_ORASTD:
1STRCMP:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_FD_SD(:
1NULLIF:
1':
1'':
1NULL:
1, :
1TO_CHAR:
1);:
1CHECK_TRACE:
11:
167:
1+:
1FPUT:
1               ENTER:: FC_U_FD_SD(68) :: cplan.sql(16564) :: :
1STRNCMP:
110:
1>:
1IS NOT NULL:
1COUNT:
1DAY_YEAR:
1TASK_DAY_OF_YEAR:
1TSK_ASSIGNMENT_ID:
1ACTUAL_FLAG:
1TO_DATE:
1SUBSTR:
1SELECT COUNT(DAY_YEAR) INTO h_count :n         FROM TASK_DAY_OF_YEAR:n       +
1  WHERE TSK_ASSIGNMENT_ID = a_temp_id AND ACTUAL_FLAG = 0 :n         AND DAY_+
1YEAR >= TO_DATE(SubStr(h_start_date, 1, 10)) AND DAY_YEAR < TO_DATE(SubStr(h_+
1sched_start, 1, 10)):
1PMO_DB2M:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
188:
1           EXCEPTION:: FC_U_FD_SD(89) :: cplan.sql(16585) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1SELECT COUNT(DAY_YEAR) INTO h_temp_var FROM TASK_DAY_OF_YEAR:n         WHERE +
1TSK_ASSIGNMENT_ID = h_prj_assign_id AND ACTUAL_FLAG = 0 :n         AND DAY_YE+
1AR > TO_DATE(SubStr(h_finish_date, 1, 10)):
1104:
1           EXCEPTION:: FC_U_FD_SD(105) :: cplan.sql(16601) :: :
1<:
1112:
1                EXIT:: FC_U_FD_SD(113) :: cplan.sql(16609) :: :
1PMO_CNST:
1TASK_ASSIGNMENT_ERROR:
1DB2TIMESTAMP:
1TIME:
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_start, 1, 10)), PMO_ORA+
1STD.TIME(h_start_date)):n      INTO h_sched_start:n      FROM DUAL:
1129:
1           EXCEPTION:: FC_U_FD_SD(130) :: cplan.sql(16626) :: :
1=:
12:
1-:
1FC_TPHASE_SCHED_ASSIGN:
1SC_BIT_30:
1FC_FD_TA_TDY:
1TASK_ASSIGNMENTS:
1SELECT TO_DATE(SubStr(h_sched_start, 1, 10)), TO_DATE(SubStr(h_finish_date, 1+
1, 10)) :n      INTO h_SD, h_FD :n      FROM TASK_ASSIGNMENTS:n      WHERE TSK+
1_ASSIGNMENT_ID = a_temp_id:
1171:
1           EXCEPTION:: FC_U_FD_SD(172) :: cplan.sql(16668) :: :
1181:
1                EXIT:: FC_U_FD_SD(182) :: cplan.sql(16678) :: :
1186:
1                EXIT:: FC_U_FD_SD(187) :: cplan.sql(16683) :: :
1STATE:: :
0

0
0
56e
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 b0 3d b4
:2 a0 2c 6a a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c :2 a0 51 a5 b 81 b0
a3 a0 1c :2 a0 51 a5 b 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c :2 a0 6b :2 a0 a5 b 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 6e a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :2 a0
6e 7e a0 b4 2e 7e 6e b4
2e 6e a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :2 a0 6e
7e a0 b4 2e 7e 6e b4 2e
6e a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :2 a0 6e 7e
a0 b4 2e 7e 6e b4 2e 6e
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :2 a0 6e 7e a0
b4 2e 7e 6e b4 2e 6e a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a a0 7e b4
2e 5a a 10 a0 51 d a0
51 d :f a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :b a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c b7 19 3c
:a a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 :2 51 a5 b 7e 6e
b4 2e a0 51 d b7 a0 51
d b7 :2 19 3c a0 7e 51 b4
2e d :c a0 a5 b d :2 a0 7e
a0 b4 2e d a0 7e b4 2e
5a :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 5a a 10 :3 a0 6b d b7
a0 51 d b7 :2 19 3c :11 a0 51
a5 b 51 :3 a0 51 a5 b a5
b d :b a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 51 d :c a0
a5 b d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 a4 b1 11
68 4f 1d 17 b5 
56e
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 7b 6f 73
77 37 82 93 87 8b 8f 6e
9a af a3 a7 ab 6b b6 c7
bb bf c3 a2 ce e3 d7 db
df 9f ea fb ef f3 f7 d6
102 117 10b 10f 113 d3 11e 12f
123 127 12b 10a 136 14b 13f 143
147 107 152 15b 157 13e 163 170
16c 13b 178 181 17d 16b 189 196
192 168 19e 1a7 1a3 191 1af 1bc
1b8 18e 1c4 1d5 1c9 1cd 1d1 1b7
1dc 1e9 1e5 1b4 1f1 1fa 1f6 1e4
202 1e1 207 20b 20f 213 230 21b
21f 227 22b 21a 250 23b 23f 247
24b 217 26c 257 25b 263 267 23a
28c 277 27b 283 287 237 2a8 293
297 29f 2a3 276 2c8 2b3 2b7 2bf
2c3 273 2ee 2cf 2d3 2db 2df 2e3
2e6 2e7 2e9 2b2 315 2f9 2fd 305
309 2af 30d 30e 310 2f8 332 320
2f5 324 325 32d 31f 34e 33d 341
31c 349 33c 36a 359 35d 339 365
358 386 375 379 355 381 374 3a2
391 395 371 39d 390 3be 3ad 3b1
38d 3b9 3ac 3ed 3c9 3cd 3d5 3d9
3a9 3dd 3e1 3e5 3e6 3e8 3c8 3f4
3f8 3c5 3fc 400 404 407 40c 40d
1 40f 414 418 41c 41f 424 428
42c 42f 434 435 437 43c 43f 443
444 449 44e 451 455 459 45e 461
465 466 46b 46e 473 474 479 47e
47f 481 486 487 489 48a 48f 492
497 498 49d 4a0 4a4 4a8 4ad 4b0
4b4 4b5 4ba 4bd 4c2 4c3 4c8 4cd
4ce 4d0 4d5 4d6 4d8 4d9 4de 4e1
4e6 4e7 4ec 4ef 4f3 4f7 4fc 4ff
503 504 509 50c 511 512 517 51c
51d 51f 524 525 527 528 52d 530
535 536 53b 53e 543 544 549 54c
550 551 556 559 55e 55f 564 567
56c 56d 572 575 57a 57b 580 583
587 588 58d 590 595 596 59b 59e
5a3 5a4 5a9 5ac 5b1 5b2 5b7 5ba
5be 5bf 5c4 5c7 5cc 5cd 5d2 5d5
5da 5db 5e0 5e3 5e8 5e9 5ee 5f1
5f5 5f6 5fb 5fe 603 604 609 60c
611 612 617 61a 61e 622 627 62a
62e 62f 634 637 63c 63d 642 647
648 64a 64f 650 652 653 658 65b
660 661 666 669 66d 671 676 679
67d 67e 683 686 68b 68c 691 696
697 699 69e 69f 6a1 6a2 6a7 6aa
6af 6b0 6b5 6b8 6bd 6be 6c3 6c6
6ca 6cb 6d0 6d3 6d8 6d9 6de 6e1
6e6 6e7 6ec 6ef 6f4 6f5 6fa 6fd
701 702 707 70a 70f 710 715 718
71d 71e 723 726 72b 72c 731 734
738 739 73e 741 746 747 74c 74f
754 755 75a 75d 761 765 769 76a
76c 771 772 774 775 77a 77d 782
783 788 78b 78f 793 797 798 79a
79f 7a0 7a2 7a3 7a8 7ab 7b0 7b1
7b6 7b9 7bd 7c1 7c5 7c6 7c8 7cd
7ce 7d0 7d1 7d6 7d9 7de 7df 7e4
7e7 7eb 7ef 7f3 7f4 7f6 7fb 7fc
7fe 7ff 804 807 80c 80d 812 815
819 81d 821 822 824 829 82a 82c
82d 832 835 83a 83b 840 843 847
84b 84f 850 852 857 858 85a 85b
860 863 868 869 86e 871 876 877
87c 87f 883 884 889 88c 891 892
897 89a 89f 8a0 8a5 8a8 8ac 8b0
8b4 8b5 8b7 8bc 8bd 8bf 8c0 8c5
8c8 8cd 8ce 8d3 8d6 8da 8de 8e2
8e3 8e5 8ea 8eb 8ed 8ee 8f3 8f6
8fb 8fc 901 902 907 909 90d 910
914 918 91b 91f 923 926 929 92e
931 934 937 938 93d 93e 1 940
945 949 94d 950 955 95a 95d 961
962 967 968 96d 96f 973 976 97a
97e 981 985 989 98c 98d 98f 992
995 996 99b 99e 9a2 9a5 9a6 9ab
1 9ae 9b3 9b7 9ba 9be 9c2 9c5
9c9 9cd 9d1 9d5 9d9 9dd 9e1 9e5
9e9 9ed 9f1 9f5 9f9 9fd a01 a05
a11 a15 a19 a1c a20 a24 a26 a2a
a2e a32 a35 a39 a3d a3f a40 a45
1 a49 a4d a51 a54 a58 a5c a60
a64 a67 a6b a6f a72 a75 a7a a7d
a80 a83 a84 a89 a8a 1 a8c a91
a95 a99 a9c aa1 aa6 aa9 aad aae
ab3 ab6 abb abc ac1 ac4 ac9 aca
acf ad2 ad6 ad7 adc adf ae4 ae5
aea aed af1 af5 af8 afb afc afe
aff b04 b05 b0a b0c b10 b13 b15
b19 b1b b27 b29 b2b b2c b31 b35
b37 b43 b45 b49 b4d b51 b55 b59
b5d b61 b65 b69 b6d b71 b7d b81
b85 b88 b8c b90 b92 b96 b9a b9e
ba1 ba5 ba9 bab bac bb1 1 bb5
bb9 bbd bc0 bc4 bc8 bcc bd0 bd3
bd7 bdb bde be1 be6 be9 bec bef
bf0 bf5 bf6 1 bf8 bfd c01 c05
c08 c0d c12 c15 c19 c1a c1f c22
c27 c28 c2d c30 c35 c36 c3b c3e
c42 c43 c48 c4b c50 c51 c56 c59
c5d c61 c64 c67 c68 c6a c6b c70
c71 c76 c78 c7c c7f c81 c85 c87
c93 c95 c97 c98 c9d ca1 ca3 caf
cb1 cb5 cb9 cbc cbd cbf cc3 cc6
cca ccd cce cd0 cd1 cd6 cda cde
ce2 ce6 cea ced cf1 cf5 cf8 cfb
d00 d03 d06 d09 d0a d0f d10 1
d12 d17 d1b d1f d22 d27 d2c d2f
d33 d34 d39 d3a d3f d41 d45 d48
d4c d50 d54 d57 d5b d5d d61 d64
d66 d6a d6d d71 d75 d79 d7d d81
d85 d89 d8d d91 d95 da1 da5 da9
dac db0 db4 db6 dba dbe dc2 dc5
dc9 dcd dcf dd0 dd5 1 dd9 ddd
de1 de4 de8 dec df0 df4 df7 dfb
dff e02 e05 e0a e0d e10 e13 e14
e19 e1a 1 e1c e21 e25 e29 e2c
e31 e36 e39 e3d e3e e43 e46 e4b
e4c e51 e54 e59 e5a e5f e62 e66
e67 e6c e6f e74 e75 e7a e7d e81
e85 e88 e8b e8c e8e e8f e94 e95
e9a e9c ea0 ea3 ea5 ea9 eab eb7
eb9 ebb ebc ec1 ec5 ec7 ed3 ed5
ed9 edd ee0 ee3 ee4 ee6 ee9 eee
eef ef4 ef8 efb eff f01 f05 f08
f0c f0e f12 f16 f19 f1d f20 f23
f24 f29 f2d f31 f35 f39 f3d f41
f45 f49 f4d f51 f55 f59 f5d f5e
f60 f64 f68 f6c f6f f73 f74 f79
f7d f81 f84 f85 f8a f8d f91 f95
f98 f9c fa0 fa3 fa4 fa6 fa9 fac
fad fb2 fb5 fb9 fbd fc0 fc4 fc8
fcb fcc fce fd1 fd4 fd5 fda 1
fdd fe2 1 fe5 fea fee ff2 ff6
ff9 ffd fff 1003 1006 100a 100c 1010
1014 1017 101b 101f 1023 1027 102b 102f
1033 1037 103b 103f 1043 1047 104b 104f
1053 1057 105b 105e 105f 1061 1064 1068
106c 1070 1073 1074 1076 1077 1079 107d
1081 1085 1089 108d 1091 1095 1099 109d
10a1 10a5 10a9 10b5 10b9 10bd 10c0 10c4
10c8 10ca 10ce 10d2 10d6 10d9 10dd 10e1
10e3 10e4 10e9 1 10ed 10f1 10f5 10f8
10fc 1100 1104 1108 110b 110f 1113 1116
1119 111e 1121 1124 1127 1128 112d 112e
1 1130 1135 1139 113d 1140 1145 114a
114d 1151 1152 1157 115a 115f 1160 1165
1168 116d 116e 1173 1176 117a 117b 1180
1183 1188 1189 118e 1191 1195 1199 119c
119f 11a0 11a2 11a3 11a8 11a9 11ae 11b0
11b4 11b7 11b9 11bd 11bf 11cb 11cd 11cf
11d0 11d5 11d9 11db 11e7 11e9 11ed 11f0
11f4 11f8 11fc 1200 1204 1208 120c 1210
1214 1218 121c 1220 1224 1225 1227 122b
122f 1233 1236 123a 123e 1241 1244 1249
124c 124f 1252 1253 1258 1259 1 125b
1260 1264 1268 126b 1270 1275 1278 127c
127d 1282 1283 1288 128a 128e 1291 1295
1299 129d 12a0 12a4 12a8 12ac 12af 12b3
12b7 12ba 12bd 12c2 12c5 12c8 12cb 12cc
12d1 12d2 1 12d4 12d9 12dd 12e1 12e4
12e9 12ee 12f1 12f5 12f6 12fb 12fe 1303
1304 1309 130c 1311 1312 1317 131a 131e
1322 1325 1326 132b 132c 1331 1333 1337
133a 133e 1342 1346 1349 134d 134f 1353
1355 1361 1365 1367 1368 1371 
56e
2
0 1 a 6 17 1b 22 :3 6
16 1a 21 :3 6 17 1b 22 :3 6
19 1d 24 :3 6 16 1a 21 :3 6
13 17 1e :3 6 13 17 1e :3 6
e 12 19 :3 6 e 12 19 :3 6
14 18 1f :3 6 12 16 1d :3 6
14 18 1f :3 6 13 :3 6 19 :3 6
14 :3 6 14 :3 6 1b :3 6 14 :3 6
14 18 1f :3 6 12 :3 6 17 :2 6
1 3 a :2 1 4 :2 e 1d e
:2 4 :2 14 23 14 :2 4 :2 f 19 f
:2 4 :2 f 19 f :2 4 :2 16 25 16
:2 4 :2 f 1e f :2 4 :2 d 1c 25
32 :2 1c d :2 4 :2 12 21 2a 3c
:2 21 12 :2 4 9 12 11 :2 9 :2 4
:2 11 20 11 :2 4 :2 c 1b c :2 4
:2 10 1f 10 :2 4 :2 10 1f 10 :2 4
:2 f 1e f :2 4 :2 e 26 :2 31 38
47 :2 26 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 52 58 5b :2 52 69 7d 8
11 18 1d 20 :2 18 2e 31 :2 18
36 :2 11 3f :2 8 :2 69 b e :2 69
13 16 1f 26 2b 2e :2 26 3b
3e :2 26 43 :2 1f 4c :2 16 :2 69 b
e :2 69 13 16 1f 26 2b 2e
:2 26 3c 3f :2 26 44 :2 1f 4d :2 16
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 2e 31 :2 69 b e :2 69
13 16 :2 69 1b 1e :2 69 2b 2e
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 28 2b :2 69 b e :2 69
13 16 :2 69 1b 1e :2 69 28 2b
:2 69 b e :2 69 13 16 1f 26
2b 2e :2 26 33 36 :2 26 3b :2 1f
44 :2 16 :2 69 b e :2 69 13 16
1f 26 2b 2e :2 26 33 36 :2 26
3b :2 1f 44 :2 16 :2 69 b e :2 69
13 16 :2 69 1b 1e :2 69 29 2c
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 27 2a :2 69 b e :2 69
13 16 :2 69 1b 1e :2 69 29 2c
:2 69 b e :2 69 13 16 1f 27
:2 1f 36 :2 16 :2 69 b e :2 69 13
16 1f 27 :2 1f 3c :2 16 :2 69 b
e :2 69 13 16 1f 27 :2 1f 37
:2 16 :2 69 b e :2 69 13 16 1f
27 :2 1f 37 :2 16 :2 69 b e :2 69
13 16 1f 27 :2 1f 3e :2 16 :2 69
b e :2 69 13 16 1f 27 :2 1f
37 :2 16 :2 69 b e :2 69 13 16
:2 69 1b 1e :2 69 29 2c :2 69 b
e :2 69 13 16 1f 27 :2 1f 35
:2 16 :2 69 b e :2 69 13 16 1f
27 :2 1f 3a :2 16 :2 69 42 45 :2 69
:2 7 48 :2 4 7 :2 11 23 :2 2d 39
3c 4a 4c 4d :2 4a :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 50 :2 4
8 :2 13 1b 2a 38 :2 8 3c 3e
:2 3c 7 :4 46 45 :3 7 15 :2 7 12
7 11 17 26 f 10 24 32
e 1a 22 29 43 4e 56 5d
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 54
56 57 :2 54 :2 2c :3 10 :2 16 1b 27
64 67 :2 27 74 77 :2 27 7b 7e
:2 27 8a 8d :2 27 95 98 :2 27 a4
a7 ae b7 ba :2 a7 :2 27 :2 10 5a
:2 d :2 a :4 16 :2 a 7 :3 63 11 17
26 36 10 24 38 e 19 21
28 :2 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
54 57 58 :2 54 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 8b 8e :2 27 96 99 :2 27
a5 a8 af b8 bb :2 a8 :2 27 :2 10
5b :2 d :2 a :4 16 :2 a 7 :3 63 a
13 1f :2 a 24 22 2d 36 :2 24
:2 22 a 12 a d :2 17 29 :2 33
3f 42 50 53 54 :2 50 :2 29 :3 d
:2 13 18 24 62 65 :2 24 :2 d 57
:3 a 11 :2 1a a 39 :2 7 63 :2 4
e 19 26 2e 35 4d 58 5d
:2 c :2 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 62 65 :2 24 72 75 :2 24 79
7c :2 24 88 8b :2 24 93 96 :2 24
a2 a5 ac b5 b8 :2 a5 :2 24 :2 d
58 :2 a :2 7 :4 13 :2 7 4 :3 1 7
e 1a 1d :2 7 20 22 :2 20 7
16 7 26 7 16 7 :5 4 14
15 :2 14 :2 4 12 29 37 42 4d
53 59 28 34 42 55 :2 12 :2 4
13 1c 1e :2 13 4 :4 8 7 29
:2 34 3c 4b 51 :2 29 55 57 :2 55
28 e :2 19 21 30 36 :2 e 3a
3c :2 3a d :2 28 27 :3 7 15 :2 1e
7 40 7 15 7 :5 4 12 1f
2d 38 43 4d 59 5f 1e 2d
3c 49 54 1e 2a 33 40 :2 2a
44 47 52 1c 28 :2 52 :2 12 4
e 16 1d 35 3d 44 c 12
c d 21 :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 62 65 :2 24 72 75
:2 24 79 7c :2 24 88 8b :2 24 93
96 :2 24 a2 a5 ac b5 b8 :2 a5
:2 24 :2 d 58 :2 a :2 7 :4 13 :2 7 4
:3 1 4 14 :2 4 12 29 37 42
4d 53 59 28 34 42 55 :2 12
4 7 :2 11 23 :2 2d 39 3c 4a
4d 4e :2 4a :2 23 :3 7 :2 d 12 1e
5c 5f :2 1e :2 7 51 :3 4 b :2 14
4 7 :2 11 23 :2 2d 39 3c 4a
4d 4e :2 4a :2 23 :3 7 :2 d 12 1e
5c 5f :2 1e 6c 6f :2 1e 73 76
:2 1e 80 83 :2 8c :2 1e :2 7 51 :3 4
b :2 14 4 :9 1 
56e
4
0 :2 1 :6 3 :6 4
:6 5 :6 6 :6 7 :6 8
:6 9 :6 a :6 b :6 c
:6 d :6 e :4 f :4 10
:4 11 :4 12 :4 13 :4 14
:6 15 :4 16 :4 17 2
:2 18 :2 1 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:a 20 :a 21 :7 22 :6 23
:6 24 :6 25 :6 26 :6 27
:c 28 :b 2a :11 2b :11 2c
:2 2b :2 2d :2 2b :12 2d
:2 2b :2 2e :2 2b :12 2e
:2 2b :2 2f :2 2b :2 2f
:2 2b :2 2f :2 2b :2 2f
:2 2b :2 30 :2 2b :2 30
:2 2b :2 30 :2 2b :2 30
:2 2b :2 31 :2 2b :2 31
:2 2b :2 31 :2 2b :2 31
:2 2b :2 32 :2 2b :2 32
:2 2b :2 32 :2 2b :2 32
:2 2b :2 33 :2 2b :12 33
:2 2b :2 34 :2 2b :12 34
:2 2b :2 35 :2 2b :2 35
:2 2b :2 35 :2 2b :2 35
:2 2b :2 36 :2 2b :2 36
:2 2b :2 36 :2 2b :2 36
:2 2b :2 37 :2 2b :2 37
:2 2b :2 37 :2 2b :2 37
:2 2b :2 38 :2 2b :9 38
:2 2b :2 39 :2 2b :9 39
:2 2b :2 3a :2 2b :9 3a
:2 2b :2 3b :2 2b :9 3b
:2 2b :2 3c :2 2b :9 3c
:2 2b :2 3d :2 2b :9 3d
:2 2b :2 3e :2 2b :2 3e
:2 2b :2 3e :2 2b :2 3e
:2 2b :2 3f :2 2b :9 3f
:2 2b :2 40 :2 2b :9 40
:2 2b :2 40 :4 2b :3 2a
:11 43 :b 44 :3 43 :14 49
:3 4a :3 4b :3 4d 4e
:3 4f :8 50 4d :5 51
4c 53 :5 54 :3 53
:2 55 :5 57 :11 58 :24 59
:3 58 :2 56 :6 55 52
:3 49 :4 5e :3 5f :4 60
5e :5 61 5d 63
:5 64 :3 63 :2 65 :5 67
:11 68 :24 69 :3 68 :2 66
:6 65 62 :3 49 :d 6e
:3 6f :11 70 :b 71 :3 70
:5 73 :3 6e :3 49 :8 77
78 79 77 :5 7a
76 7c :5 7d :3 7c
:2 7e :5 80 :11 81 :24 82
:3 81 :2 7f :6 7e 7b
:3 29 :a 87 :3 88 87
:3 8a 89 :3 87 :6 8e
:8 8f :4 90 :3 8f :7 92
:12 93 :d 94 :5 93 :5 95
94 :3 97 96 :3 93
:9 9a :5 9b :9 9c :2 9d
:2 9c :3 9a :6 a0 :2 a1
a2 :2 a3 a0 :5 a4
9f a6 :5 a7 :3 a6
:2 a8 :5 aa :11 ab :24 ac
:3 ab :2 a9 :6 a8 a5
:3 29 :3 b1 :8 b2 :4 b3
:3 b2 :11 b5 :b b6 :3 b5
:5 b8 :11 ba :19 bb :3 ba
:5 bd :2 29 :7 1 
1373
4
:3 0 1 :3 0 2
:a 0 569 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
6 :3 0 8 :5 0
1 13 12 :3 0
d 9f 0 b
4 :3 0 5 :3 0
a :3 0 9 :5 0
1 19 18 :3 0
4 :3 0 5 :3 0
a :3 0 b :5 0
1 1f 1e :3 0
11 d3 0 f
4 :3 0 5 :3 0
a :3 0 c :5 0
1 25 24 :3 0
4 :3 0 5 :3 0
a :3 0 d :5 0
1 2b 2a :3 0
15 107 0 13
4 :3 0 5 :3 0
f :3 0 e :5 0
1 31 30 :3 0
4 :3 0 5 :3 0
f :3 0 10 :5 0
1 37 36 :3 0
19 13b 0 17
4 :3 0 5 :3 0
a :3 0 11 :5 0
1 3d 3c :3 0
4 :3 0 5 :3 0
a :3 0 12 :5 0
1 43 42 :3 0
1d 168 0 1b
4 :3 0 5 :3 0
a :3 0 13 :5 0
1 49 48 :3 0
15 :3 0 14 :7 0
4d 4c :3 0 21
18e 0 1f 15
:3 0 16 :7 0 51
50 :3 0 18 :3 0
17 :7 0 55 54
:3 0 25 1b4 0
23 18 :3 0 19
:7 0 59 58 :3 0
15 :3 0 1a :7 0
5d 5c :3 0 29
1e1 0 27 15
:3 0 1b :7 0 61
60 :3 0 4 :3 0
5 :3 0 a :3 0
1c :5 0 1 67
66 :3 0 2d :2 0
2b 15 :3 0 1d
:7 0 6b 6a :3 0
15 :3 0 1e :7 0
6f 6e :3 0 1f
:3 0 15 :3 0 71
73 0 569 2
74 :2 0 45 237
0 43 15 :3 0
77 :7 0 14 :3 0
7b 78 79 567
0 20 :6 0 49
273 0 47 15
:3 0 7d :7 0 16
:3 0 81 7e 7f
567 0 21 :6 0
18 :3 0 83 :7 0
17 :3 0 87 84
85 567 0 22
:6 0 4d 2af 0
4b 18 :3 0 89
:7 0 19 :3 0 8d
8a 8b 567 0
23 :6 0 15 :3 0
8f :7 0 1a :3 0
93 90 91 567
0 24 :6 0 28
:2 0 52 15 :3 0
95 :7 0 1b :3 0
99 96 97 567
0 25 :6 0 15
:3 0 9b :7 0 27
:3 0 1d :3 0 28
:2 0 4f 9d a0
a3 9c a1 567
0 26 :6 0 2b
:2 0 57 15 :3 0
a5 :7 0 27 :3 0
1e :3 0 54 a7
aa ad a6 ab
567 0 29 :6 0
28 :2 0 5b a
:3 0 59 af b1
:6 0 b4 b2 0
567 0 2a :6 0
28 :2 0 5d 15
:3 0 b6 :7 0 ba
b7 b8 567 0
2c :6 0 28 :2 0
5f 15 :3 0 bc
:7 0 c0 bd be
567 0 2d :6 0
28 :2 0 61 15
:3 0 c2 :7 0 c6
c3 c4 567 0
2e :6 0 28 :2 0
63 15 :3 0 c8
:7 0 cc c9 ca
567 0 2f :6 0
d6 d7 0 65
15 :3 0 ce :7 0
d2 cf d0 567
0 30 :6 0 df
e0 0 6a 15
:3 0 d4 0 2
:5 0 32 :3 0 33
:3 0 3 :3 0 7
:3 0 67 d8 db
de d5 dc 567
0 31 :6 0 34
:3 0 35 :3 0 34
:3 0 36 :3 0 e2
e3 0 2 :4 0
6c e4 e6 e1
e8 e7 :2 0 37
:3 0 38 :3 0 ea
eb 0 39 :4 0
34 :3 0 3a :3 0
ee ef 0 2
:4 0 6e f0 f2
3b :4 0 3c :2 0
3d :3 0 70 f5
f7 :3 0 3e :4 0
3c :2 0 27 :3 0
3f :3 0 40 :4 0
3c :2 0 3 :3 0
73 fe 100 :3 0
3c :2 0 40 :4 0
76 102 104 :3 0
41 :4 0 79 fc
107 42 :4 0 7c
fb 10a 7f fa
10c :3 0 3c :2 0
43 :4 0 82 10e
110 :3 0 3c :2 0
27 :3 0 3f :3 0
40 :4 0 3c :2 0
7 :3 0 85 116
118 :3 0 3c :2 0
40 :4 0 88 11a
11c :3 0 41 :4 0
8b 114 11f 42
:4 0 8e 113 122
91 112 124 :3 0
3c :2 0 43 :4 0
94 126 128 :3 0
3c :2 0 27 :3 0
3f :3 0 40 :4 0
3c :2 0 8 :3 0
97 12e 130 :3 0
3c :2 0 40 :4 0
9a 132 134 :3 0
41 :4 0 9d 12c
137 42 :4 0 a0
12b 13a a3 12a
13c :3 0 3c :2 0
43 :4 0 a6 13e
140 :3 0 3c :2 0
40 :4 0 a9 142
144 :3 0 3c :2 0
9 :3 0 ac 146
148 :3 0 3c :2 0
40 :4 0 af 14a
14c :3 0 3c :2 0
43 :4 0 b2 14e
150 :3 0 3c :2 0
40 :4 0 b5 152
154 :3 0 3c :2 0
b :3 0 b8 156
158 :3 0 3c :2 0
40 :4 0 bb 15a
15c :3 0 3c :2 0
43 :4 0 be 15e
160 :3 0 3c :2 0
40 :4 0 c1 162
164 :3 0 3c :2 0
c :3 0 c4 166
168 :3 0 3c :2 0
40 :4 0 c7 16a
16c :3 0 3c :2 0
43 :4 0 ca 16e
170 :3 0 3c :2 0
40 :4 0 cd 172
174 :3 0 3c :2 0
d :3 0 d0 176
178 :3 0 3c :2 0
40 :4 0 d3 17a
17c :3 0 3c :2 0
43 :4 0 d6 17e
180 :3 0 3c :2 0
27 :3 0 3f :3 0
40 :4 0 3c :2 0
e :3 0 d9 186
188 :3 0 3c :2 0
40 :4 0 dc 18a
18c :3 0 41 :4 0
df 184 18f 42
:4 0 e2 183 192
e5 182 194 :3 0
3c :2 0 43 :4 0
e8 196 198 :3 0
3c :2 0 27 :3 0
3f :3 0 40 :4 0
3c :2 0 10 :3 0
eb 19e 1a0 :3 0
3c :2 0 40 :4 0
ee 1a2 1a4 :3 0
41 :4 0 f1 19c
1a7 42 :4 0 f4
19b 1aa f7 19a
1ac :3 0 3c :2 0
43 :4 0 fa 1ae
1b0 :3 0 3c :2 0
40 :4 0 fd 1b2
1b4 :3 0 3c :2 0
11 :3 0 100 1b6
1b8 :3 0 3c :2 0
40 :4 0 103 1ba
1bc :3 0 3c :2 0
43 :4 0 106 1be
1c0 :3 0 3c :2 0
40 :4 0 109 1c2
1c4 :3 0 3c :2 0
12 :3 0 10c 1c6
1c8 :3 0 3c :2 0
40 :4 0 10f 1ca
1cc :3 0 3c :2 0
43 :4 0 112 1ce
1d0 :3 0 3c :2 0
40 :4 0 115 1d2
1d4 :3 0 3c :2 0
13 :3 0 118 1d6
1d8 :3 0 3c :2 0
40 :4 0 11b 1da
1dc :3 0 3c :2 0
43 :4 0 11e 1de
1e0 :3 0 3c :2 0
27 :3 0 44 :3 0
14 :3 0 121 1e4
1e6 42 :4 0 123
1e3 1e9 126 1e2
1eb :3 0 3c :2 0
43 :4 0 129 1ed
1ef :3 0 3c :2 0
27 :3 0 44 :3 0
16 :3 0 12c 1f3
1f5 42 :4 0 12e
1f2 1f8 131 1f1
1fa :3 0 3c :2 0
43 :4 0 134 1fc
1fe :3 0 3c :2 0
27 :3 0 44 :3 0
17 :3 0 137 202
204 42 :4 0 139
201 207 13c 200
209 :3 0 3c :2 0
43 :4 0 13f 20b
20d :3 0 3c :2 0
27 :3 0 44 :3 0
19 :3 0 142 211
213 42 :4 0 144
210 216 147 20f
218 :3 0 3c :2 0
43 :4 0 14a 21a
21c :3 0 3c :2 0
27 :3 0 44 :3 0
1a :3 0 14d 220
222 42 :4 0 14f
21f 225 152 21e
227 :3 0 3c :2 0
43 :4 0 155 229
22b :3 0 3c :2 0
27 :3 0 44 :3 0
1b :3 0 158 22f
231 42 :4 0 15a
22e 234 15d 22d
236 :3 0 3c :2 0
43 :4 0 160 238
23a :3 0 3c :2 0
40 :4 0 163 23c
23e :3 0 3c :2 0
1c :3 0 166 240
242 :3 0 3c :2 0
40 :4 0 169 244
246 :3 0 3c :2 0
43 :4 0 16c 248
24a :3 0 3c :2 0
27 :3 0 44 :3 0
1d :3 0 16f 24e
250 42 :4 0 171
24d 253 174 24c
255 :3 0 3c :2 0
43 :4 0 177 257
259 :3 0 3c :2 0
27 :3 0 44 :3 0
1e :3 0 17a 25d
25f 42 :4 0 17c
25c 262 17f 25b
264 :3 0 3c :2 0
45 :4 0 182 266
268 :3 0 185 ec
26a :2 0 26c 18a
26d e9 26c 0
26e 18c 0 565
34 :3 0 35 :3 0
26f 270 0 34
:3 0 46 :3 0 272
273 0 47 :2 0
2 :4 0 48 :2 0
49 :2 0 47 :2 0
18e 278 27a :3 0
191 274 27c 271
27e 27d :2 0 37
:3 0 4a :3 0 280
281 0 39 :4 0
4b :4 0 3c :2 0
3d :3 0 195 285
287 :3 0 198 282
289 :2 0 28b 19b
28c 27f 28b 0
28d 19d 0 565
32 :3 0 4c :3 0
28e 28f 0 3
:3 0 7 :3 0 4d
:2 0 19f 290 294
4e :2 0 28 :2 0
1a5 296 298 :3 0
299 :2 0 9 :3 0
4f :2 0 1a8 29c
29d :3 0 29e :2 0
29a 2a0 29f :2 0
30 :3 0 28 :2 0
2a2 2a3 0 3af
2d :3 0 28 :2 0
2a5 2a6 0 3af
50 :3 0 51 :3 0
2d :3 0 52 :3 0
53 :3 0 d :3 0
54 :3 0 51 :3 0
55 :3 0 56 :3 0
7 :3 0 51 :3 0
55 :3 0 56 :3 0
3 :4 0 57 1
:8 0 2bd 58 :3 0
59 :3 0 2b8 2b9
0 5a :3 0 2ba
2bb 0 2bd 1aa
310 5b :3 0 58
:3 0 59 :3 0 2bf
2c0 0 5a :3 0
2c1 2c2 0 2c4
1ad 2c6 1af 2c5
2c4 :2 0 30e 5c
:3 0 58 :3 0 59
:3 0 2c9 2ca 0
5a :3 0 2cb 2cc
0 306 34 :3 0
35 :3 0 2ce 2cf
0 34 :3 0 46
:3 0 2d1 2d2 0
5d :2 0 2 :4 0
5e :2 0 49 :2 0
47 :2 0 1b1 2d7
2d9 :3 0 1b4 2d3
2db 2d0 2dd 2dc
:2 0 37 :3 0 4a
:3 0 2df 2e0 0
39 :4 0 5f :4 0
3c :2 0 3d :3 0
1b8 2e4 2e6 :3 0
3c :2 0 60 :4 0
1bb 2e8 2ea :3 0
3c :2 0 61 :4 0
1be 2ec 2ee :3 0
3c :2 0 5a :3 0
1c1 2f0 2f2 :3 0
3c :2 0 62 :4 0
1c4 2f4 2f6 :3 0
3c :2 0 56 :3 0
63 :3 0 47 :2 0
64 :2 0 1c7 2f9
2fd 1cb 2f8 2ff
:3 0 1ce 2e1 301
:2 0 303 1d1 304
2de 303 0 305
1d3 0 306 1d5
309 :3 0 309 0
309 308 306 307
:6 0 30b 2 :3 0
1d8 30d 1da 30c
30b :2 0 30e 1dc
:2 0 310 0 310
30f 2bd 30e :6 0
3af 1 :3 0 50
:3 0 51 :3 0 30
:3 0 52 :3 0 53
:3 0 9 :3 0 54
:3 0 51 :3 0 55
:3 0 56 :3 0 8
:4 0 65 1 :8 0
323 58 :3 0 59
:3 0 31e 31f 0
5a :3 0 320 321
0 323 1df 376
5b :3 0 58 :3 0
59 :3 0 325 326
0 5a :3 0 327
328 0 32a 1e2
32c 1e4 32b 32a
:2 0 374 5c :3 0
58 :3 0 59 :3 0
32f 330 0 5a
:3 0 331 332 0
36c 34 :3 0 35
:3 0 334 335 0
34 :3 0 46 :3 0
337 338 0 5d
:2 0 2 :4 0 66
:2 0 49 :2 0 47
:2 0 1e6 33d 33f
:3 0 1e9 339 341
336 343 342 :2 0
37 :3 0 4a :3 0
345 346 0 39
:4 0 67 :4 0 3c
:2 0 3d :3 0 1ed
34a 34c :3 0 3c
:2 0 60 :4 0 1f0
34e 350 :3 0 3c
:2 0 61 :4 0 1f3
352 354 :3 0 3c
:2 0 5a :3 0 1f6
356 358 :3 0 3c
:2 0 62 :4 0 1f9
35a 35c :3 0 3c
:2 0 56 :3 0 63
:3 0 47 :2 0 64
:2 0 1fc 35f 363
200 35e 365 :3 0
203 347 367 :2 0
369 206 36a 344
369 0 36b 208
0 36c 20a 36f
:3 0 36f 0 36f
36e 36c 36d :6 0
371 4 :3 0 20d
373 20f 372 371
:2 0 374 211 :2 0
376 0 376 375
323 374 :6 0 3af
1 :3 0 27 :3 0
30 :3 0 28 :2 0
214 378 37b 27
:3 0 68 :2 0 2d
:3 0 28 :2 0 217
37d 381 21c 37e
383 :3 0 2a :3 0
9 :3 0 385 386
0 3ac 34 :3 0
35 :3 0 388 389
0 34 :3 0 46
:3 0 38b 38c 0
47 :2 0 2 :4 0
69 :2 0 49 :2 0
47 :2 0 21f 391
393 :3 0 222 38d
395 38a 397 396
:2 0 37 :3 0 4a
:3 0 399 39a 0
39 :4 0 6a :4 0
3c :2 0 3d :3 0
226 39e 3a0 :3 0
229 39b 3a2 :2 0
3a4 22c 3a5 398
3a4 0 3a6 22e
0 3ac 1f :3 0
6b :3 0 6c :3 0
3a8 3a9 0 3aa
:2 0 3ac 230 3ad
384 3ac 0 3ae
234 0 3af 236
3b0 2a1 3af 0
3b1 23c 0 565
32 :3 0 6d :3 0
55 :3 0 56 :3 0
3 :3 0 32 :3 0
6e :3 0 7 :3 0
3 :3 0 6f :4 0
70 1 :8 0 3c2
58 :3 0 59 :3 0
3bd 3be 0 5a
:3 0 3bf 3c0 0
3c2 23e 415 5b
:3 0 58 :3 0 59
:3 0 3c4 3c5 0
5a :3 0 3c6 3c7
0 3c9 241 3cb
243 3ca 3c9 :2 0
413 5c :3 0 58
:3 0 59 :3 0 3ce
3cf 0 5a :3 0
3d0 3d1 0 40b
34 :3 0 35 :3 0
3d3 3d4 0 34
:3 0 46 :3 0 3d6
3d7 0 5d :2 0
2 :4 0 71 :2 0
49 :2 0 47 :2 0
245 3dc 3de :3 0
248 3d8 3e0 3d5
3e2 3e1 :2 0 37
:3 0 4a :3 0 3e4
3e5 0 39 :4 0
72 :4 0 3c :2 0
3d :3 0 24c 3e9
3eb :3 0 3c :2 0
60 :4 0 24f 3ed
3ef :3 0 3c :2 0
61 :4 0 252 3f1
3f3 :3 0 3c :2 0
5a :3 0 255 3f5
3f7 :3 0 3c :2 0
62 :4 0 258 3f9
3fb :3 0 3c :2 0
56 :3 0 63 :3 0
47 :2 0 64 :2 0
25b 3fe 402 25f
3fd 404 :3 0 262
3e6 406 :2 0 408
265 409 3e3 408
0 40a 267 0
40b 269 40e :3 0
40e 0 40e 40d
40b 40c :6 0 410
6 :3 0 26c 412
26e 411 410 :2 0
413 270 :2 0 415
0 415 414 3c2
413 :6 0 565 1
:3 0 56 :3 0 11
:3 0 47 :2 0 47
:2 0 273 417 41b
73 :2 0 74 :4 0
279 41d 41f :3 0
2e :3 0 74 :2 0
421 422 0 424
27c 429 2e :3 0
28 :2 0 425 426
0 428 27e 42a
420 424 0 42b
0 428 0 42b
280 0 565 2c
:3 0 75 :2 0 47
:2 0 283 42d 42f
:3 0 42c 430 0
565 30 :3 0 76
:3 0 b :3 0 c
:3 0 d :3 0 e
:3 0 10 :3 0 22
:3 0 23 :3 0 2c
:3 0 24 :3 0 25
:3 0 285 433 43e
432 43f 0 565
2f :3 0 26 :3 0
75 :2 0 29 :3 0
290 443 445 :3 0
441 446 0 565
8 :3 0 4f :2 0
293 449 44a :3 0
44b :2 0 32 :3 0
4c :3 0 44d 44e
0 3 :3 0 10
:3 0 4d :2 0 295
44f 453 4e :2 0
28 :2 0 29b 455
457 :3 0 458 :2 0
32 :3 0 4c :3 0
45a 45b 0 8
:3 0 e :3 0 4d
:2 0 29e 45c 460
68 :2 0 28 :2 0
2a4 462 464 :3 0
465 :2 0 459 467
466 :2 0 468 :2 0
44c 46a 469 :2 0
30 :3 0 6b :3 0
77 :3 0 46d 46e
0 46c 46f 0
471 2a7 476 30
:3 0 28 :2 0 472
473 0 475 2a9
477 46b 471 0
478 0 475 0
478 2ab 0 565
30 :3 0 78 :3 0
b :3 0 c :3 0
d :3 0 12 :3 0
13 :3 0 e :3 0
10 :3 0 3 :3 0
8 :3 0 2e :3 0
20 :3 0 21 :3 0
1c :3 0 27 :3 0
2f :3 0 28 :2 0
2ae 488 48b 47
:2 0 31 :3 0 27
:3 0 30 :3 0 28
:2 0 2b1 48f 492
2b4 47a 494 479
495 0 565 55
:3 0 56 :3 0 3
:3 0 55 :3 0 56
:3 0 8 :3 0 e
:3 0 10 :3 0 79
:3 0 53 :3 0 d
:4 0 7a 1 :8 0
4a8 58 :3 0 59
:3 0 4a3 4a4 0
5a :3 0 4a5 4a6
0 4a8 2c6 4fb
5b :3 0 58 :3 0
59 :3 0 4aa 4ab
0 5a :3 0 4ac
4ad 0 4af 2c9
4b1 2cb 4b0 4af
:2 0 4f9 5c :3 0
58 :3 0 59 :3 0
4b4 4b5 0 5a
:3 0 4b6 4b7 0
4f1 34 :3 0 35
:3 0 4b9 4ba 0
34 :3 0 46 :3 0
4bc 4bd 0 5d
:2 0 2 :4 0 7b
:2 0 49 :2 0 47
:2 0 2cd 4c2 4c4
:3 0 2d0 4be 4c6
4bb 4c8 4c7 :2 0
37 :3 0 4a :3 0
4ca 4cb 0 39
:4 0 7c :4 0 3c
:2 0 3d :3 0 2d4
4cf 4d1 :3 0 3c
:2 0 60 :4 0 2d7
4d3 4d5 :3 0 3c
:2 0 61 :4 0 2da
4d7 4d9 :3 0 3c
:2 0 5a :3 0 2dd
4db 4dd :3 0 3c
:2 0 62 :4 0 2e0
4df 4e1 :3 0 3c
:2 0 56 :3 0 63
:3 0 47 :2 0 64
:2 0 2e3 4e4 4e8
2e7 4e3 4ea :3 0
2ea 4cc 4ec :2 0
4ee 2ed 4ef 4c9
4ee 0 4f0 2ef
0 4f1 2f1 4f4
:3 0 4f4 0 4f4
4f3 4f1 4f2 :6 0
4f6 8 :3 0 2f4
4f8 2f6 4f7 4f6
:2 0 4f9 2f8 :2 0
4fb 0 4fb 4fa
4a8 4f9 :6 0 565
1 :3 0 2c :3 0
28 :2 0 4fd 4fe
0 565 30 :3 0
76 :3 0 b :3 0
c :3 0 d :3 0
e :3 0 10 :3 0
22 :3 0 23 :3 0
2c :3 0 24 :3 0
25 :3 0 2fb 501
50c 500 50d 0
565 34 :3 0 35
:3 0 50f 510 0
34 :3 0 46 :3 0
512 513 0 47
:2 0 2 :4 0 7d
:2 0 49 :2 0 47
:2 0 306 518 51a
:3 0 309 514 51c
511 51e 51d :2 0
37 :3 0 4a :3 0
520 521 0 39
:4 0 7e :4 0 3c
:2 0 3d :3 0 30d
525 527 :3 0 310
522 529 :2 0 52b
313 52c 51f 52b
0 52d 315 0
565 1f :3 0 58
:3 0 59 :3 0 52f
530 0 531 :2 0
565 34 :3 0 35
:3 0 533 534 0
34 :3 0 46 :3 0
536 537 0 47
:2 0 2 :4 0 7f
:2 0 49 :2 0 47
:2 0 317 53c 53e
:3 0 31a 538 540
535 542 541 :2 0
37 :3 0 4a :3 0
544 545 0 39
:4 0 80 :4 0 3c
:2 0 3d :3 0 31e
549 54b :3 0 3c
:2 0 60 :4 0 321
54d 54f :3 0 3c
:2 0 81 :4 0 324
551 553 :3 0 3c
:2 0 58 :3 0 59
:3 0 556 557 0
327 555 559 :3 0
32a 546 55b :2 0
55d 32d 55e 543
55d 0 55f 32f
0 565 1f :3 0
58 :3 0 59 :3 0
561 562 0 563
:2 0 565 331 568
:3 0 568 343 568
567 565 566 :6 0
569 :2 0 2 74
568 56c :3 0 56b
569 56d :8 0 
353
4
:3 0 1 3 1
9 1 f 1
15 1 1b 1
21 1 27 1
2d 1 33 1
39 1 3f 1
45 1 4b 1
4f 1 53 1
57 1 5b 1
5f 1 63 1
69 1 6d 15
8 e 14 1a
20 26 2c 32
38 3e 44 4a
4e 52 56 5a
5e 62 68 6c
70 1 76 1
7c 1 82 1
88 1 8e 1
94 2 9e 9f
1 9a 2 a8
a9 1 a4 1
b0 1 ae 1
b5 1 bb 1
c1 1 c7 1
cd 2 d9 da
1 d3 1 e5
1 f1 2 f4
f6 2 fd ff
2 101 103 2
105 106 2 108
109 2 f9 10b
2 10d 10f 2
115 117 2 119
11b 2 11d 11e
2 120 121 2
111 123 2 125
127 2 12d 12f
2 131 133 2
135 136 2 138
139 2 129 13b
2 13d 13f 2
141 143 2 145
147 2 149 14b
2 14d 14f 2
151 153 2 155
157 2 159 15b
2 15d 15f 2
161 163 2 165
167 2 169 16b
2 16d 16f 2
171 173 2 175
177 2 179 17b
2 17d 17f 2
185 187 2 189
18b 2 18d 18e
2 190 191 2
181 193 2 195
197 2 19d 19f
2 1a1 1a3 2
1a5 1a6 2 1a8
1a9 2 199 1ab
2 1ad 1af 2
1b1 1b3 2 1b5
1b7 2 1b9 1bb
2 1bd 1bf 2
1c1 1c3 2 1c5
1c7 2 1c9 1cb
2 1cd 1cf 2
1d1 1d3 2 1d5
1d7 2 1d9 1db
2 1dd 1df 1
1e5 2 1e7 1e8
2 1e1 1ea 2
1ec 1ee 1 1f4
2 1f6 1f7 2
1f0 1f9 2 1fb
1fd 1 203 2
205 206 2 1ff
208 2 20a 20c
1 212 2 214
215 2 20e 217
2 219 21b 1
221 2 223 224
2 21d 226 2
228 22a 1 230
2 232 233 2
22c 235 2 237
239 2 23b 23d
2 23f 241 2
243 245 2 247
249 1 24f 2
251 252 2 24b
254 2 256 258
1 25e 2 260
261 2 25a 263
2 265 267 4
ed f3 f8 269
1 26b 1 26d
2 277 279 3
275 276 27b 2
284 286 2 283
288 1 28a 1
28c 3 291 292
293 1 297 2
295 297 1 29b
2 2b7 2bc 1
2c3 1 2be 2
2d6 2d8 3 2d4
2d5 2da 2 2e3
2e5 2 2e7 2e9
2 2eb 2ed 2
2ef 2f1 2 2f3
2f5 3 2fa 2fb
2fc 2 2f7 2fe
2 2e2 300 1
302 1 304 2
2cd 305 1 309
1 2c8 2 2c6
30d 2 31d 322
1 329 1 324
2 33c 33e 3
33a 33b 340 2
349 34b 2 34d
34f 2 351 353
2 355 357 2
359 35b 3 360
361 362 2 35d
364 2 348 366
1 368 1 36a
2 333 36b 1
36f 1 32e 2
32c 373 2 379
37a 2 37f 380
1 382 2 37c
382 2 390 392
3 38e 38f 394
2 39d 39f 2
39c 3a1 1 3a3
1 3a5 3 387
3a6 3ab 1 3ad
5 2a4 2a7 310
376 3ae 1 3b0
2 3bc 3c1 1
3c8 1 3c3 2
3db 3dd 3 3d9
3da 3df 2 3e8
3ea 2 3ec 3ee
2 3f0 3f2 2
3f4 3f6 2 3f8
3fa 3 3ff 400
401 2 3fc 403
2 3e7 405 1
407 1 409 2
3d2 40a 1 40e
1 3cd 2 3cb
412 3 418 419
41a 1 41e 2
41c 41e 1 423
1 427 2 429
42a 1 42e a
434 435 436 437
438 439 43a 43b
43c 43d 2 442
444 1 448 3
450 451 452 1
456 2 454 456
3 45d 45e 45f
1 463 2 461
463 1 470 1
474 2 476 477
2 489 48a 2
490 491 11 47b
47c 47d 47e 47f
480 481 482 483
484 485 486 487
48c 48d 48e 493
2 4a2 4a7 1
4ae 1 4a9 2
4c1 4c3 3 4bf
4c0 4c5 2 4ce
4d0 2 4d2 4d4
2 4d6 4d8 2
4da 4dc 2 4de
4e0 3 4e5 4e6
4e7 2 4e2 4e9
2 4cd 4eb 1
4ed 1 4ef 2
4b8 4f0 1 4f4
1 4b3 2 4b1
4f8 a 502 503
504 505 506 507
508 509 50a 50b
2 517 519 3
515 516 51b 2
524 526 2 523
528 1 52a 1
52c 2 53b 53d
3 539 53a 53f
2 548 54a 2
54c 54e 2 550
552 2 554 558
2 547 55a 1
55c 1 55e 11
26e 28d 3b1 415
42b 431 440 447
478 496 4fb 4ff
50e 52d 532 55f
564 f 7a 80
86 8c 92 98
a2 ac b3 b9
bf c5 cb d1
dd 
1
4
0 
56c
0
1
14
9
25
0 1 2 1 4 1 6 1
8 0 0 0 0 0 0 0
0 0 0 0 
6d 1 0
2 0 1
c7 1 0
cd 1 0
d3 1 0
f 1 0
b5 1 0
69 1 0
45 1 0
bb 1 0
3 1 0
88 1 0
4b 1 0
57 1 0
7c 1 0
9a 1 0
27 1 0
9 1 0
94 1 0
5f 1 0
33 1 0
8e 1 0
ae 1 0
21 1 0
4f 1 0
a4 1 0
c1 1 0
39 1 0
5b 1 0
3f 1 0
1b 1 0
76 1 0
15 1 0
82 1 0
2d 1 0
63 1 0
53 1 0
0

/
SHOW ERRORS FUNCTION FC_U_FD_SD;
ALTER FUNCTION FC_U_FD_SD COMPILE DEBUG;
Prompt == FUNCTION FC_U_PARTICIPANT ==
CREATE OR REPLACE FUNCTION FC_U_PARTICIPANT wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
237
2 :e:
1FUNCTION:
1FC_U_PARTICIPANT:
1H_P_ASSIGN_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1H_P_SECURITY_ID:
1H_P_PLANNED_START:
1TIMESTAMP:
1H_P_PLANNED_FINISH:
1SH_H_P_DELAY:
1PLS_INTEGER:
1SH_H_P_UNITS:
1SH_H_P_WORK_PERCENT:
1SH_H_P_ACTUAL:
1H_P_RES_ID:
1H_ID:
1RETURN:
1H_P_DELAY:
1H_P_UNITS:
1H_P_WORK_PERCENT:
1H_P_ACTUAL:
1H_SECURITY_ID:
132:
1A_ELEMENT_ID:
1A_PARTICIPANT_ID:
1255:
1A_PARTICIPANT_NAME:
1A_SECURITY_NAME:
1H_FULL_NAME:
1A_RES_ASSIGNMENT_ID:
1A_SECURITY_ID:
1A_TEMP_ID:
1H_PRJ_ASSIGN_ID:
1H_CREATED_BY:
1H_PROJECT_ID:
1H_CRI_SECURITY_ID:
1H_ACTUAL_START:
1H_START_DATE:
1H_FINISH_DATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_START_DT:
1H_TA_START_DT:
1H_TA_FINISH_DT:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_SD:
1DATE:
1H_FD:
1H_WEEK_OF:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_TASK_ACTUAL:
10:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DAYOFYEAR:
1H_LAST_SUBMITTED:
1A_ASSIGNMENT_COUNT:
1A_ELEMENT_TYPE:
1H_RESPONSIBLE:
1A_PARTICIPANT:
1A_RESOURCE_TYPE:
1A_SECURITY_VALUE:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_TRANSFED_CRI:
1H_TASK_ID:
1H_RES_ID:
1H_REC_USER:
1H_EFFORT:
1H_CONTOUR:
1H_DELAY:
1H_PERCENT_UNITS:
1H_WORK_PERCENT:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_WORK:
1H_LAST_DAY:
1H_MINUTES:
1H_LAST_MINUTES:
1H_TASK_TYPE:
1H_PER_DAY:
1H_WORK_TYPE:
1H_ASSIGN_COUNT:
1H_DURATION:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_SCHED_EFFORT:
1H_ETC:
1H_ROLLUP_BITS:
1H_CLOSE_TASK:
1H_DAY_MIN:
1H_COUNT:
1H_REMAINING:
1H_PRIORITY:
1H_PA_UNITS:
1H_CONF_FLAG:
1H_ASSIGN_STRING:
18192:
1H_TEMP_RES_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1STMT:
17999:
1I_GET_DATE:
1I_RESCHED:
1I_BITFLAG:
1CURSOR:
1C_FD1:
1DAY_YEAR:
1ROW_NUMBER:
1OVER:
1CNT:
1CALENDAR_DAY_OF_YEAR:
1ELEMENT_ID:
1MOD:
1ROWNUM:
1SELECT * FROM (SELECT DAY_YEAR FROM (SELECT DAY_YEAR,ROW_NUMBER() OVER (ORDER+
1 BY DAY_YEAR) AS CNT   :n         FROM CALENDAR_DAY_OF_YEAR:n         WHERE E+
1LEMENT_ID = h_id AND DAY_YEAR >= h_SD ORDER BY DAY_YEAR ) :n         WHERE  M+
1OD(CNT,h_delay) = 0:n          ) WHERE ROWNUM<=1:
1C_P_DELAY:
1PMO_DB2M:
1REF_CURSOR:
1C_R_DELAY:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_PARTICIPANT(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
1144:
1+:
1FPUT:
1               ENTER:: FC_U_PARTICIPANT(145) :: cplan.sql(16838) :: :
1:
1RA:
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1ELEMENT_TYPE:
1RESOURCE_TYPE:
1CRI_SECURITY_ID:
1RESOURCE_ID:
1PROJECT_ID:
1TABLE_TYPE:
1RESOURCE_ASSIGNMENTS:
1SELECT ra.RES_ASSIGNMENT_ID, ra.PARTICIPANT, ra.ELEMENT_ID, ra.ELEMENT_TYPE,+
1:n      CASE WHEN ra.RESOURCE_TYPE = '0' THEN 0 ELSE 1 END,:n      CASE WHEN +
1ra.CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END,:n      ra.RESOURCE_ID,:n      r+
1a.PROJECT_ID, ra.TABLE_TYPE:n      INTO a_res_assignment_id, a_participant, a+
1_element_id, a_element_type,:n      a_resource_type,:n      h_transfed_cri,:n+
1      a_participant_id,:n      h_project_id, h_table_type:n      FROM RESOURC+
1E_ASSIGNMENTS ra:n      WHERE ra.RES_ASSIGNMENT_ID = a_temp_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1178:
1           EXCEPTION:: FC_U_PARTICIPANT(179) :: cplan.sql(16872) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1PROJECT_ASSIGNMENT_ID:
1BIT_FLAG:
1LAST_SUBMITTED:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1CONTOUR_TYPE:
1ASSIGN_UNITS:
1UNITS_MSP:
1ACTUAL_START:
1WORK_TODATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1ASSIGNMENT_DELAY:
1LAST_SCHED_MIN:
1TO_DATE:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1ROLLUP_BITS:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT RES_ASSIGNMENT_ID, PROJECT_ASSIGNMENT_ID, PROJECT_ID, RESOURCE_ID, RES+
1OURCE_TYPE, BIT_FLAG, :n         LAST_SUBMITTED, C_CONTOUR, C_EFFORT, T_UNIT,+
1 C_UNIT, CONTOUR_TYPE, :n         CASE WHEN ASSIGN_UNITS > UNITS_MSP THEN ASS+
1IGN_UNITS ELSE UNITS_MSP END, ACTUAL_START, WORK_TODATE, UNRESOLVED_START, UN+
1RESOLVED_FINISH,:n         CASE WHEN BIT_FLAG = '0' THEN PLANNED_WORK ELSE SC+
1HED_WORK END, ASSIGNMENT_DELAY,LAST_SCHED_MIN,:n         TO_DATE(SubStr(UNRES+
1OLVED_START, 1, 10)), TO_DATE(SubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CA+
1PITAL_EXPENSE,:n         REGULAR_COST, SPECIAL_COST, REGULAR_RATE, SPECIAL_RA+
1TE,:n         B_REGULAR_COST, B_SPECIAL_COST, B_REGULAR_RATE, B_SPECIAL_RATE,+
1:n         MILESTONE_PERCENT, TASK_ID, ROLLUP_BITS:n         INTO a_res_assig+
1nment_id, h_prj_assign_id, h_project_id, h_res_id,h_res_type, h_bit_flag, :n +
1        h_last_submitted, h_contour, h_work, h_eunit, h_unit, h_bitflag,:n   +
1      h_percent_units, h_actual_start, h_work_todate, h_start_date, h_finish_+
1date,:n         h_effort, h_delay, h_last_day,:n         h_SD, h_FD, h_billab+
1le, h_capital_expense,:n         h_reg_cost, h_spec_cost, h_reg_sale, h_spec_+
1sale,:n         h_b_reg_cost, h_b_spec_cost, h_b_reg_sale, h_b_spec_sale,:n  +
1       h_work_percent, h_task_id, h_rollup_bits:n         FROM TASK_ASSIGNMEN+
1TS:n         WHERE TSK_ASSIGNMENT_ID = a_temp_id:
1211:
1           EXCEPTION:: FC_U_PARTICIPANT(212) :: cplan.sql(16905) :: :
1TASK_TYPE:
1MINUTE_PER_DAY:
1START_DT:
1FINISH_DT:
1UNRESOLVED_DURATION:
1PRIORITY:
1CONFIG_FLAG:
1ASSIGN_COUNT:
1SD:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1WORK_PERCENT:
1ETC:
1FORECAST_START:
1FORECAST_FINISH:
1TMT_WBS:
1SELECT PROJECT_ID, TASK_TYPE, MINUTE_PER_DAY, START_DT, FINISH_DT, UNRESOLVED+
1_DURATION, PRIORITY, CONFIG_FLAG, :n            ASSIGN_COUNT, SD, WORK_TODATE+
1, PLANNED_EFFORT + SCHED_EFFORT, WORK_PERCENT, ETC, COALESCE(FORECAST_START,F+
1ORECAST_FINISH):n            INTO h_project_id, h_task_type, h_per_day, h_sta+
1rt_date, h_finish_date, h_duration, h_priority, h_conf_flag,:n            h_a+
1ssign_count, h_work_type, h_work_todate, h_effort, h_work_percent, h_etc, h_s+
1tart_DT:n            FROM TMT_WBS WHERE ELEMENT_ID = a_temp_id:
1231:
1           EXCEPTION:: FC_U_PARTICIPANT(232) :: cplan.sql(16925) :: :
1239:
1                EXIT:: FC_U_PARTICIPANT(240) :: cplan.sql(16933) :: :
1PMO_CNST:
1RECORD_NOT_FOUND:
1BITAND:
1SC_WBS_ENFORCE_TC_TS:
1247:
1                EXIT:: FC_U_PARTICIPANT(248) :: cplan.sql(16941) :: :
1SC_TIMESHEET_STEP_EXISTS:
1PMO_ORASTD:
1STRNCMP:
110:
1>:
1!=:
1258:
1                EXIT:: FC_U_PARTICIPANT(259) :: cplan.sql(16952) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1IS NOT NULL:
1-:
1267:
1                EXIT:: FC_U_PARTICIPANT(268) :: cplan.sql(16961) :: :
1CANNOT_UPDATE_ASSIGN_ACCEPT_RE:
1DB2TIMESTAMP:
1TIME:
1PMO_STPU:
1FIRST_AVAIL_TIME:
1BIT_SCHED:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.FIRST_AVAIL+
1_TIME(BIT_SCHED))) INTO h_sched_start:n                     FROM CALENDAR_DAY+
1_OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n             +
1        AND DAY_YEAR = TO_DATE(SubStr(h_sched_start, 1, 10)):
1289:
1           EXCEPTION:: FC_U_PARTICIPANT(290) :: cplan.sql(16983) :: :
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_start, 1, 10)), PMO_ORA+
1STD.TIME('08::00')) INTO h_sched_start:n                        FROM DUAL:
1306:
1           EXCEPTION:: FC_U_PARTICIPANT(307) :: cplan.sql(17000) :: :
1LAST_AVAIL_TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.LAST_AVAIL_+
1TIME(BIT_SCHED))) INTO h_sched_finish:n                     FROM CALENDAR_DAY+
1_OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n             +
1        AND DAY_YEAR = TO_DATE(SubStr(h_sched_finish, 1, 10)):
1329:
1           EXCEPTION:: FC_U_PARTICIPANT(330) :: cplan.sql(17023) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_finish, 1, 10)), PMO_OR+
1ASTD.TIME('17::00')) INTO h_sched_finish:n                        FROM DUAL:
1346:
1           EXCEPTION:: FC_U_PARTICIPANT(347) :: cplan.sql(17040) :: :
1SC_SS:
1SCHED_START:
1SCHED_FINISH:
1SCHED_DURATION:
1UPDATE TMT_WBS SET SCHED_START = h_sched_start, SCHED_FINISH = h_sched_finish+
1, SCHED_DURATION = h_duration:n                     WHERE ELEMENT_ID = a_temp+
1_id:
1FOUND:
1TRUE:
1100:
1371:
1           EXCEPTION:: FC_U_PARTICIPANT(372) :: cplan.sql(17065) :: :
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_DURATION:
1UPDATE TMT_WBS SET PLANNED_START = h_sched_start, PLANNED_FINISH = h_sched_fi+
1nish, PLANNED_DURATION = h_duration:n                     WHERE ELEMENT_ID = +
1a_temp_id:
1391:
1           EXCEPTION:: FC_U_PARTICIPANT(392) :: cplan.sql(17085) :: :
1SC_SQL_SUCCESS:
1FC_ROLLUP:
1SC_FIXED_DURATION:
1SC_FD_EFFORT_DRIVEN:
1COUNT:
1SELECT COUNT(DAY_YEAR) INTO h_count :n                     FROM CALENDAR_DAY_+
1OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n              +
1       AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_start_date, 1, 10)) AND TO_DATE(+
1SubStr(h_finish_date, 1, 10)):
1418:
1           EXCEPTION:: FC_U_PARTICIPANT(419) :: cplan.sql(17112) :: :
1438:
1           EXCEPTION:: FC_U_PARTICIPANT(439) :: cplan.sql(17132) :: :
1455:
1           EXCEPTION:: FC_U_PARTICIPANT(456) :: cplan.sql(17149) :: :
1TASK_DAY_OF_YEAR:
1ACTUAL_FLAG:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n                 +
1       SELECT 'X' FROM TASK_DAY_OF_YEAR:n                        WHERE PROJEC+
1T_ID = h_project_id AND TASK_ID = a_temp_id :n                        AND ACT+
1UAL_FLAG = 1 AND DAY_YEAR > TO_DATE(SubStr(h_sched_finish, 1, 10))):
1483:
1           EXCEPTION:: FC_U_PARTICIPANT(484) :: cplan.sql(17177) :: :
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n                 +
1          SELECT 'X' FROM TASK_ASSIGNMENTS:n                           WHERE +
1PROJECT_ID = h_project_id AND TASK_ID = a_temp_id :n                         +
1  AND TO_DATE(SubStr(START_DT, 1, 10)) > TO_DATE(SubStr(h_sched_finish, 1, 10+
1))):
1502:
1           EXCEPTION:: FC_U_PARTICIPANT(503) :: cplan.sql(17196) :: :
1511:
1                EXIT:: FC_U_PARTICIPANT(512) :: cplan.sql(17205) :: :
1CANNOT_UPDATE_HAS_ACTUAL:
1530:
1           EXCEPTION:: FC_U_PARTICIPANT(531) :: cplan.sql(17224) :: :
1547:
1           EXCEPTION:: FC_U_PARTICIPANT(548) :: cplan.sql(17241) :: :
1FC_START_FINISH_DT:
1TA:
1PA:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n                 +
1 SELECT 'X' FROM TASK_ASSIGNMENTS ta:n                  WHERE ta.PROJECT_ID =+
1 h_project_id AND ta.TASK_ID = a_temp_id:n                  AND ta.PROJECT_AS+
1SIGNMENT_ID IS NOT NuLL AND EXISTS (:n                  SELECT 'X' FROM TASK_+
1ASSIGNMENTS pa:n                  WHERE pa.PROJECT_ID = h_project_id AND pa.T+
1SK_ASSIGNMENT_ID = ta.PROJECT_ASSIGNMENT_ID :n                  AND (TO_DATE(+
1SubStr(h_sched_start, 1, 10)) < TO_DATE(SubStr(pa.START_DT, 1, 10)) OR TO_DAT+
1E(SubStr(h_sched_finish, 1, 10)) > TO_DATE(SubStr(pa.FINISH_DT, 1, 10))))):
1584:
1           EXCEPTION:: FC_U_PARTICIPANT(585) :: cplan.sql(17278) :: :
1592:
1                EXIT:: FC_U_PARTICIPANT(593) :: cplan.sql(17286) :: :
1TASK_ASSIGNMENT_ERROR:
1FC_CHANGE_TA_DATES:
1605:
1                EXIT:: FC_U_PARTICIPANT(606) :: cplan.sql(17299) :: :
1ELSIF:
1615:
1                EXIT:: FC_U_PARTICIPANT(616) :: cplan.sql(17309) :: :
1SC_TASK_ACTUAL_GRATER_THAN_SCH:
1A:
1ACTIVITIES:
1TYPE_ID:
1SC_TIMESHEET_ACTIVITY:
1SELECT COUNT('X') INTO h_temp_var:n               FROM DUAL:n               W+
1HERE EXISTS(SELECT A.ELEMENT_ID FROM TASK_ASSIGNMENTS TA, ACTIVITIES A:n     +
1          WHERE TA.TASK_ID = a_temp_id:n               AND TA.TSK_ASSIGNMENT_+
1ID = A.TSK_ASSIGNMENT_ID:n               AND A.TSK_ASSIGNMENT_ID <> A.ELEMENT+
1_ID:n               AND A.TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY):
1641:
1           EXCEPTION:: FC_U_PARTICIPANT(642) :: cplan.sql(17335) :: :
1649:
1                EXIT:: FC_U_PARTICIPANT(650) :: cplan.sql(17343) :: :
1JOIN:
1TIMESHEET_APPROVAL_STATUS:
1APV:
1WEEK_OF:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n               SE+
1LECT 'X' FROM TASK_ASSIGNMENTS ta JOIN TIMESHEET_APPROVAL_STATUS apv:n       +
1        ON apv.ELEMENT_ID = ta.PROJECT_ID AND apv.RESOURCE_ID = ta.RESOURCE_I+
1D:n               WHERE ta.PROJECT_ID = h_project_id AND ta.TASK_ID = a_temp_+
1id AND:n               (TO_DATE(SubStr(ta.ACTUAL_START, 1, 10)) - 7     ) <= +
1apv.WEEK_OF):
1670:
1           EXCEPTION:: FC_U_PARTICIPANT(671) :: cplan.sql(17364) :: :
1678:
1                EXIT:: FC_U_PARTICIPANT(679) :: cplan.sql(17372) :: :
1TS_APPROVAL_ERROR:
1FC_U_TASK_PERCENT:
1695:
1                EXIT:: FC_U_PARTICIPANT(696) :: cplan.sql(17389) :: :
1706:
1                EXIT:: FC_U_PARTICIPANT(707) :: cplan.sql(17400) :: :
1SELECT UNRESOLVED_START, UNRESOLVED_FINISH, UNITS_MSP INTO h_ta_start_DT, h_t+
1a_finish_DT, h_pa_units:n               FROM TASK_ASSIGNMENTS:n              +
1 WHERE TSK_ASSIGNMENT_ID = h_prj_assign_id:
1723:
1           EXCEPTION:: FC_U_PARTICIPANT(724) :: cplan.sql(17417) :: :
1731:
1                EXIT:: FC_U_PARTICIPANT(732) :: cplan.sql(17425) :: :
1<:
1740:
1                EXIT:: FC_U_PARTICIPANT(741) :: cplan.sql(17434) :: :
1747:
1                EXIT:: FC_U_PARTICIPANT(748) :: cplan.sql(17441) :: :
1SELECT MINUTE_PER_DAY, TASK_TYPE, WORK_TODATE, START_DT, FINISH_DT, CONFIG_FL+
1AG :n            INTO h_per_day, h_task_type, h_task_actual, h_task_start_DT,+
1 h_task_finish_DT, h_conf_flag:n            FROM TMT_WBS:n            WHERE P+
1ROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1766:
1           EXCEPTION:: FC_U_PARTICIPANT(767) :: cplan.sql(17460) :: :
1775:
1                EXIT:: FC_U_PARTICIPANT(776) :: cplan.sql(17469) :: :
1796:
1                EXIT:: FC_U_PARTICIPANT(797) :: cplan.sql(17490) :: :
1SELECT COUNT(DAY_YEAR) INTO h_count :n                     FROM CALENDAR_DAY_+
1OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n              +
1       AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_task_start_DT, 1, 10)) AND TO_DA+
1TE(SubStr(h_task_finish_DT, 1, 10)):
1817:
1           EXCEPTION:: FC_U_PARTICIPANT(818) :: cplan.sql(17511) :: :
1FC_U_FD_SD:
1838:
1                EXIT:: FC_U_PARTICIPANT(839) :: cplan.sql(17532) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_finish, 1, 10)), PMO_OR+
1ASTD.TIME(h_finish_date)):n                  INTO h_sched_finish:n           +
1       FROM DUAL:
1859:
1           EXCEPTION:: FC_U_PARTICIPANT(860) :: cplan.sql(17553) :: :
1STRCMP:
1FC_TPHASE_SCHED_ASSIGN:
1FC_U_TDY_LAST_ACTUAL:
12:
1FC_FD_TA_TDY:
1FD:
1SC_UHF:
1ACTUAL_FINISH:
1UPDATE TASK_ASSIGNMENTS SET FD = pmo_cnst.SC_UHF, ACTUAL_FINISH = h_sched_fin+
1ish, ETC = 0, :n                        MILESTONE_PERCENT = 10000, SCHED_WORK+
1 = WORK_TODATE, SCHED_FINISH = h_sched_finish :n                        WHERE+
1 TSK_ASSIGNMENT_ID = a_temp_id:
1905:
1           EXCEPTION:: FC_U_PARTICIPANT(906) :: cplan.sql(17599) :: :
1SC_SF:
1UPDATE TASK_ASSIGNMENTS SET FD = pmo_cnst.SC_SF, ACTUAL_FINISH = NULL, MILEST+
1ONE_PERCENT = (WORK_TODATE * 10000)/SCHED_WORK :n                        WHER+
1E TSK_ASSIGNMENT_ID = a_temp_id:
1926:
1           EXCEPTION:: FC_U_PARTICIPANT(927) :: cplan.sql(17620) :: :
1SELECT TO_DATE(SubStr(h_start_date, 1, 10)), TO_DATE(SubStr(h_sched_finish, 1+
1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RATE:n              +
1    INTO h_SD, h_FD, h_billable, h_capital_expense, h_reg_cost, h_reg_sale:n +
1                 FROM TASK_ASSIGNMENTS:n                  WHERE TSK_ASSIGNMEN+
1T_ID = a_temp_id:
1946:
1           EXCEPTION:: FC_U_PARTICIPANT(947) :: cplan.sql(17640) :: :
1960:
1                EXIT:: FC_U_PARTICIPANT(961) :: cplan.sql(17654) :: :
1FC_DELAY:
1OPEN:
1CLOSE:
1997:
1           EXCEPTION:: FC_U_PARTICIPANT(998) :: cplan.sql(17691) :: :
1IS NULL:
11004:
1                EXIT:: FC_U_PARTICIPANT(1005) :: cplan.sql(17698) :: :
1CANNOT_ASSIGN_RESOURCE_CALENDA:
11018:
1                EXIT:: FC_U_PARTICIPANT(1019) :: cplan.sql(17712) :: :
1SELECT START_DT INTO h_start_date:n                  FROM TMT_WBS:n          +
1        WHERE ELEMENT_ID = h_task_id:
11040:
1           EXCEPTION:: FC_U_PARTICIPANT(1041) :: cplan.sql(17734) :: :
1SELECT * FROM (SELECT DAY_YEAR FROM CALENDAR_DAY_OF_YEAR :
1WHERE ELEMENT_ID = ':
1' AND DAY_YEAR < TO_DATE(SubStr(':
1', 1, 10)) :
1ORDER BY DAY_YEAR DESC) WHERE ROWNUM<=:
1LOOP:
1EXIT:
11098:
1           EXCEPTION:: FC_U_PARTICIPANT(1099) :: cplan.sql(17792) :: :
11113:
1           EXCEPTION:: FC_U_PARTICIPANT(1114) :: cplan.sql(17807) :: :
11123:
1                EXIT:: FC_U_PARTICIPANT(1124) :: cplan.sql(17817) :: :
11129:
1                EXIT:: FC_U_PARTICIPANT(1130) :: cplan.sql(17823) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_dayofyear, 1, 10)), PMO_ORAST+
1D.TIME(h_start_date)):n                  INTO h_start_date:n                 +
1 FROM DUAL:
11147:
1           EXCEPTION:: FC_U_PARTICIPANT(1148) :: cplan.sql(17841) :: :
11158:
1                EXIT:: FC_U_PARTICIPANT(1159) :: cplan.sql(17852) :: :
11166:
1                EXIT:: FC_U_PARTICIPANT(1167) :: cplan.sql(17860) :: :
1103079040:
11177:
1                EXIT:: FC_U_PARTICIPANT(1178) :: cplan.sql(17871) :: :
1INVALID_PARAMS:
1TRUNC:
1*:
1/:
110000.00:
10.5:
1SELECT COUNT(*) INTO h_temp_var:n                  FROM TASK_DAY_OF_YEAR:n   +
1               WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = a_temp+
1_id:
11201:
1           EXCEPTION:: FC_U_PARTICIPANT(1202) :: cplan.sql(17895) :: :
11216:
1                EXIT:: FC_U_PARTICIPANT(1217) :: cplan.sql(17910) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)):n                     INTO h_start_date:n         +
1            FROM DUAL:
11249:
1           EXCEPTION:: FC_U_PARTICIPANT(1250) :: cplan.sql(17943) :: :
10.49:
1FC_FD_U_TDY:
1PMO_FUNC:
1BIT_OR:
1SC_BIT_29:
1U_ASSIGN_STRING:
11275:
1           EXCEPTION:: FC_U_PARTICIPANT(1276) :: cplan.sql(17969) :: :
11287:
1                EXIT:: FC_U_PARTICIPANT(1288) :: cplan.sql(17981) :: :
190:
1SC_SCHED_BIT:
1SC_PLANNED_BIT:
1SC_PERCENT_UNITS_BIT:
1CONSIDER:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, UNITS_MSP = h_percent_units,:n     +
1             C_EFFORT = 0, C_UNIT = 0, C_CONTOUR = 0, CONTOUR_TYPE = 1,:n    +
1              ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,h_rollup_bits):n     +
1             WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11317:
1           EXCEPTION:: FC_U_PARTICIPANT(1318) :: cplan.sql(18011) :: :
1FC_DEL_NOACTUAL:
1SC_BIT_30:
11364:
1           EXCEPTION:: FC_U_PARTICIPANT(1365) :: cplan.sql(18058) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                     INTO h_start_date:n+
1                     FROM DUAL:
11381:
1           EXCEPTION:: FC_U_PARTICIPANT(1382) :: cplan.sql(18075) :: :
1FC_RESCHEDULE:
11397:
1                EXIT:: FC_U_PARTICIPANT(1398) :: cplan.sql(18091) :: :
1BAK_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n                       BAK_ASSIGN_STRING = NULL+
1:n                  WHERE TSK_ASSIGNMENT_ID = A_TEMP_ID:
1BAK_START_DT:
1BAK_FINISH_DT:
1ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,(pmo_cnst.SC_SCHED_BIT+pmo_cnst.SC_PLANNED_BIT)),:n                  B+
1AK_START_DT = COALESCE(SCHED_START,PLANNED_START), BAK_FINISH_DT = COALESCE(S+
1CHED_FINISH,PLANNED_FINISH),:n                  BAK_ASSIGN_STRING = ASSIGN_ST+
1RING:n                  WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11422:
1           EXCEPTION:: FC_U_PARTICIPANT(1423) :: cplan.sql(18116) :: :
11431:
1                EXIT:: FC_U_PARTICIPANT(1432) :: cplan.sql(18125) :: :
1SELECT COUNT('X') INTO h_temp_var:n               FROM DUAL:n               W+
1HERE EXISTS(SELECT ELEMENT_ID FROM ACTIVITIES:n               WHERE TSK_ASSIG+
1NMENT_ID = a_temp_id:n               AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n   +
1            AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY):
11454:
1           EXCEPTION:: FC_U_PARTICIPANT(1455) :: cplan.sql(18148) :: :
11462:
1                EXIT:: FC_U_PARTICIPANT(1463) :: cplan.sql(18156) :: :
1MIN:
1SELECT COUNT(DAY_YEAR), MIN(DAY_YEAR) :n                     INTO h_count, h_+
1dayofyear :n                     FROM TASK_DAY_OF_YEAR:n                     +
1WHERE PROJECT_ID = h_project_id:n                     AND TSK_ASSIGNMENT_ID =+
1 a_temp_id:n                     AND ACTUAL_FLAG = 0:
11489:
1           EXCEPTION:: FC_U_PARTICIPANT(1490) :: cplan.sql(18183) :: :
1SCHED_MIN:
1ACTUAL_MIN:
1SELECT SCHED_MIN - ACTUAL_MIN INTO h_minutes:n                           FROM+
1 TASK_DAY_OF_YEAR :n                           WHERE PROJECT_ID = h_project_i+
1d AND TSK_ASSIGNMENT_ID = a_temp_id AND DAY_YEAR = TO_DATE(SubStr(h_last_subm+
1itted, 1, 10)):
11516:
1           EXCEPTION:: FC_U_PARTICIPANT(1517) :: cplan.sql(18210) :: :
110000:
1TO_NUMBER:
1FC_U_ASSIGN_PERCENT:
1SELECT  ( TO_DATE(SubStr(h_finish_date, 1, 10)) )  INTO  h_last_submitted FRO+
1M DUAL:
11634:
1           EXCEPTION:: FC_U_PARTICIPANT(1635) :: cplan.sql(18328) :: :
1SELECT  ( PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_finish_date, 1, 10)), PMO_+
1ORASTD.TIME('00::00')) + 1      )  INTO  h_start_date FROM DUAL:
11648:
1           EXCEPTION:: FC_U_PARTICIPANT(1649) :: cplan.sql(18342) :: :
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,pmo_cnst.SC_SCHED_BIT),:n                     SCHED_WORK = h_new_actua+
1l, WORK_TODATE = h_new_actual, ETC = 0, MILESTONE_PERCENT = 10000,:n         +
1            FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION +
1= 0:n                     WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11670:
1           EXCEPTION:: FC_U_PARTICIPANT(1671) :: cplan.sql(18364) :: :
11683:
1                EXIT:: FC_U_PARTICIPANT(1684) :: cplan.sql(18377) :: :
11707:
1                EXIT:: FC_U_PARTICIPANT(1708) :: cplan.sql(18401) :: :
11714:
1                EXIT:: FC_U_PARTICIPANT(1715) :: cplan.sql(18408) :: :
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = h_p_work_percent,:n          +
1     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PERCENT_COMPLETE_B+
1IT):n               WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11768:
1           EXCEPTION:: FC_U_PARTICIPANT(1769) :: cplan.sql(18462) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PERC+
1ENT_COMPLETE_BIT):n               WHERE PROJECT_ID = h_project_id AND ELEMENT+
1_ID = h_task_id:
11792:
1           EXCEPTION:: FC_U_PARTICIPANT(1793) :: cplan.sql(18486) :: :
11803:
1                EXIT:: FC_U_PARTICIPANT(1804) :: cplan.sql(18497) :: :
1SECURITY_ID:
1SELECT ra.SECURITY_ID, ra.PARTICIPANT, ra.ELEMENT_ID, ra.ELEMENT_TYPE,:n     +
1       CASE WHEN ra.RESOURCE_TYPE = '0' THEN 0 ELSE 1 END,:n            CASE +
1WHEN ra.CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END,:n            ra.RESOURCE_I+
1D,:n            ra.PROJECT_ID, ra.TABLE_TYPE:n            INTO h_security_id,+
1 a_participant, a_element_id, a_element_type,:n            a_resource_type,:n+
1            h_transfed_cri,:n            a_participant_id,:n            h_pro+
1ject_id, h_table_type:n            FROM RESOURCE_ASSIGNMENTS ra WHERE ra.RES_+
1ASSIGNMENT_ID = a_res_assignment_id:
11827:
1           EXCEPTION:: FC_U_PARTICIPANT(1828) :: cplan.sql(18521) :: :
1NOT:
11836:
1                EXIT:: FC_U_PARTICIPANT(1837) :: cplan.sql(18530) :: :
11845:
1                EXIT:: FC_U_PARTICIPANT(1846) :: cplan.sql(18539) :: :
1SC_TABLE_WBS:
1FC_U_ASSIGNED_SECURITY:
11861:
1                EXIT:: FC_U_PARTICIPANT(1862) :: cplan.sql(18555) :: :
11866:
1                EXIT:: FC_U_PARTICIPANT(1867) :: cplan.sql(18560) :: :
1STATE:: :
0

0
0
2a06
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 90 :3 a0 b0 3f 90
:3 a0 b0 3f b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a0 f4 b4 bf c8
:10 a0 12a bd b7 11 a4 b1 a3
:2 a0 6b 1c 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :2 a0 6e 7e a0 b4
2e 7e 6e b4 2e 6e a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :2 a0 6e 7e a0 b4 2e
7e 6e b4 2e 6e a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 51 d a0
6e d :2 a0 d :2 a0 d :2 a0 d
:20 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :52 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :24 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c :3 a0 51 a5 b
:2 a0 6b a5 b 5a a0 7e a0
6b b4 2e :2 a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b 65 b7 19 3c :2 a0 d
:2 a0 d :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c a0 7e b4
2e :2 5a :2 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e 5a a0 7e
a0 51 a5 b b4 2e 5a 52
10 :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e :10 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
a0 4d d b7 19 3c b7 :10 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :9 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c a0
51 d b7 :2 19 3c :2 a0 51 a5
b a0 7e a0 6b b4 2e :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :3 a0 a5 b d
b7 19 3c b7 a0 51 d a0
51 d :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 51 a5 b
a0 7e a0 6b b4 2e 52 10
:d a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e :10 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :9 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 51 a5 b
7e 51 b4 2e d b7 19 3c
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 51 a5 b a0 7e
a0 6b b4 2e 52 10 a0 6e
d a0 51 d b7 19 3c b7
:2 a0 51 a5 b 7e 51 b4 2e
a0 51 d :d a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :e a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c b7 19 3c
:10 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :9 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 51 a5 b a0 7e
a0 6b b4 2e 52 10 5a a
10 a0 6e d a0 51 d b7
19 3c b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e a0 7e 51
b4 2e a 10 5a :2 a0 51 a5
b a0 7e a0 6b b4 2e :2 a0
51 a5 b a0 7e a0 6b b4
2e 52 10 5a a 10 :6 a0 a5
b d b7 19 3c a0 51 d
:24 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :e a0 51 a5
b 51 a5 b d :2 a0 51 a5
b 7e 51 b4 2e :3 a0 a5 b
d b7 :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
51 a5 b 65 b7 :2 19 3c b7
:2 19 3c a0 b7 :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 a0 51 d :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :2 a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b 65 a0 b7 :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e a0 51 d b7 :2 19 3c a0
51 d :18 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c a0
51 d :1c a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c :3 a0
51 a5 b d :8 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
a5 b d b7 :2 19 3c :2 a0 51
a5 b 7e 51 b4 2e :3 a0 a5
b d b7 19 3c :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 51 a5 b 65 a0
b7 a0 7e b4 2e 5a a0 7e
b4 2e 5a a 10 :2 a0 d :2 a0
d :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c a0 7e b4 2e
5a :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 a0
b7 :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 :2 19 3c b7 19 3c :11 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b :2 a0 6b a5
b 5a a0 7e a0 6b b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c :2 a0 :2 51 a5 b 7e
6e b4 2e a0 51 d b7 a0
51 d b7 :2 19 3c a0 51 d
a0 51 d :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a 52 10 :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e 5a
52 10 :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e a 10
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e :2 a0 51 a5
b a0 7e a0 6b b4 2e 52
10 a0 51 d :d a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 a0 6e
d :6 a0 a5 b d b7 19 3c
:17 a0 51 a5 b :2 a0 51 a5 b
a5 b d :3 a0 a5 b d :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 51 a5 b
65 b7 :2 a0 d a0 51 d a0
51 d b7 :2 19 3c a0 b7 :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e :a a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 6b :2 a0 a5 b
d a0 7e 51 b4 2e d :c a0
a5 b d :2 a0 51 a5 b 7e
51 b4 2e 5a a0 7e b4 2e
:2 5a a 10 :9 a0 51 a5 b d
b7 19 3c :2 a0 :2 51 a5 b 7e
6e b4 2e a0 51 d b7 a0
51 d b7 :2 19 3c :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :11 a0 51 a5 b 51 a0 51
a5 b d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e :e a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 b7 :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e a 10 :a a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 19
3c :13 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 51 d :c a0 a5
b d :3 a0 a5 b d :2 a0 6b
51 d :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 a0 b7 19 :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d :2 a0 51 a5
b a0 7e a0 6b b4 2e :2 a0
51 a5 b a0 7e a0 6b b4
2e 52 10 :2 a0 :2 51 a5 b 7e
6e b4 2e 5a :2 a0 d b7 :2 a0
d b7 :2 19 3c :6 a0 a5 b d
a0 4d d :2 a0 e9 dd b3 :2 a0
e9 d3 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c :17 a0 51 a5 b :2 a0 51 a5
b a5 b d :3 a0 a5 b d
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 51 a5
b 65 b7 a0 51 d b7 :2 19
3c a0 b7 19 :2 a0 51 a5 b
7e 51 b4 2e a0 51 d a0
51 d :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 b7 19 :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e d a0
4d d a0 6e d :2 a0 51 a5
b 7e 51 b4 2e a0 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
d :3 a0 11c 11d b7 a0 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
d :3 a0 11c 11d b7 :2 19 3c :3 a0
51 a5 b 7e 51 b4 2e :2 a0
e9 d3 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :2 a0 e9 d3 :2 a0 f :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a a0 2b
b7 19 3c b7 a0 47 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 a0 e9 c1 :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
a0 7e b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 :2 19
3c b7 19 3c :a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 51
d a0 51 d b7 :2 19 3c a0
b7 :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e a 10 :2 a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b 65 b7 19 3c :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
b7 :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 19 3c
:3 a0 51 a5 b d b7 :2 19 3c
:4 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e 5a 7e 51 b4 2e
5a 7e 51 b4 2e a5 b d
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e a0 51 d :7 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 51
65 b7 19 3c b7 19 3c :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 51 a5 b a0 7e a0
6b b4 2e 52 10 a0 7e 51
b4 2e d :c a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e 5a
a0 7e b4 2e :2 5a a 10 :a a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c :4 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e 5a
7e 51 b4 2e 5a 7e 51 b4
2e a5 b d :9 a0 51 a5 b
d :3 a0 6b :2 a0 51 a5 b :2 a0
6b a5 b d :5 a0 :2 51 a5 b
d :13 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 51 d :c a0 a5
b d :3 a0 a5 b d :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 51 a5 b 65
b7 a0 51 d a0 51 d :2 a0
51 a5 b 7e 51 b4 2e a0
51 d b7 19 3c :3 a0 6b :2 a0
6b :2 a0 6b :2 a0 6b a5 b :2 a0
6b a5 b d :f a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 3c b7 :2 19 3c b7 :2 19 3c
a0 7e 51 b4 2e a0 7e 51
b4 2e d :c a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e 5a
a0 7e b4 2e :2 5a a 10 :9 a0
51 a5 b d b7 19 3c a0
7e b4 2e 5a :4 a0 51 a5 b
d b7 :2 a0 :2 51 a5 b 7e 6e
b4 2e :4 a0 51 a5 b d b7
:4 a0 51 a5 b d b7 :2 19 3c
b7 :2 19 3c a0 7e b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 6b
a5 b 5a d :a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :a a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
b7 19 3c a0 51 d :a a0 51
a5 b :2 a0 51 a5 b a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 a0 b7 a0 7e 51 b4 2e
:4 a0 12a :16 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :3 a0 a5 b
d :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 51
a5 b 65 b7 19 3c :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e a0 51 d :c a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
19 3c :3 a0 51 a5 b d :3 a0
51 a5 b d :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 51 a5 b a0 7e
a0 6b b4 2e 52 10 a0 4d
d :c a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e b4 2e 5a
:2 a0 d b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e a0 7e 51
b4 2e d :c a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e 5a
a0 7e b4 2e :2 5a a 10 :c a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e 7e :2 a0 51 a5
b b4 2e d b7 :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d b7 :2 19 3c a0 51 d :5 a0
a5 b 51 a5 b 7e :3 a0 a5
b 51 a5 b b4 2e 5a 7e
51 b4 2e a5 b d :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e 7e :2 a0 51 a5 b b4 2e
d b7 :3 a0 51 a5 b d b7
:2 19 3c :9 a0 51 a5 b d :5 a0
a5 b 51 a5 b 7e :3 a0 a5
b 51 a5 b b4 2e 5a 7e
51 b4 2e a5 b d :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
d :7 a0 51 a5 b :2 a0 51 a5
b a5 b d a0 51 d :c a0
a5 b d b7 19 3c b7 a0
51 d :3 a0 51 a5 b d :1b a0
51 a5 b :2 a0 51 a5 b a5
b d :3 a0 51 a5 b d :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :9 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :13 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 51 d :8 a0 51 :2 a0 51 a5
b a5 b d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 51 a5 b 65 b7 19
3c b7 19 3c b7 :2 19 3c :3 a0
51 a5 b d a0 51 d b7
:5 a0 a5 b 51 a5 b 7e :3 a0
a5 b 51 a5 b b4 2e 5a
7e 51 b4 2e 5a 7e 51 b4
2e a5 b d b7 :2 19 3c :1b a0
51 a5 b :2 a0 51 a5 b a5
b d :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
51 a5 b 65 a0 b7 :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :3 a0 a5 b d
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 51 a5
b 65 b7 19 :20 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a 7e
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :2 a0 6b :2 a0
a5 b 7e 51 b4 2e :2 a0 6b
51 d :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c b7 :2 19 3c
b7 19 3c :2 a0 d :2 a0 d :2 a0
d :3 a0 6b d :2 a0 6b :5 a0 a5
b d :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
2a06
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 7b 6f 73
77 37 82 8b 87 6e 93 a0
9c 6b a8 b1 ad 9b b9 c6
c2 98 ce df d3 d7 db c1
e6 fb ef f3 f7 be 102 ee
107 10b 10f 113 130 11b 11f 127
12b eb 14c 137 13b 143 147 11a
16c 157 15b 163 167 117 188 173
177 17f 183 156 1a5 193 153 197
198 1a0 192 1c2 1b0 18f 1b4 1b5
1bd 1af 1df 1cd 1ac 1d1 1d2 1da
1cc 1fc 1ea 1c9 1ee 1ef 1f7 1e9
219 207 1e6 20b 20c 214 206 236
224 203 228 229 231 223 253 241
220 245 246 24e 240 270 25e 23d
262 263 26b 25d 28d 27b 25a 27f
280 288 27a 2aa 298 277 29c 29d
2a5 297 2c7 2b5 294 2b9 2ba 2c2
2b4 2e4 2d2 2b1 2d6 2d7 2df 2d1
301 2ef 2ce 2f3 2f4 2fc 2ee 31d
30c 310 318 2eb 335 324 328 330
30b 351 340 344 34c 308 369 358
35c 364 33f 385 374 378 380 33c
39d 38c 390 398 373 3b9 3a8 3ac
3b4 370 3d1 3c0 3c4 3cc 3a7 3ed
3dc 3e0 3e8 3a4 405 3f4 3f8 400
3db 421 410 414 41c 3d8 439 428
42c 434 40f 455 444 448 450 40c
471 45c 460 463 464 46c 443 48e
47c 440 480 481 489 47b 4aa 499
49d 478 4a5 498 4c6 4b5 4b9 495
4c1 4b4 4e2 4d1 4d5 4b1 4dd 4d0
4fe 4ed 4f1 4cd 4f9 4ec 51a 509
50d 515 4e9 532 521 525 52d 508
54e 53d 541 505 549 53c 56a 559
55d 539 565 558 586 575 579 555
581 574 5a2 591 595 571 59d 590
5be 5ad 5b1 58d 5b9 5ac 5da 5c9
5cd 5a9 5d5 5c8 5f6 5e5 5e9 5c5
5f1 5e4 612 601 605 5e1 60d 600
62e 61d 621 5fd 629 61c 64a 639
63d 619 645 638 667 655 635 659
65a 662 654 684 672 651 676 677
67f 671 6a1 68f 66e 693 694 69c
68e 6bd 6ac 6b0 68b 6b8 6ab 6d9
6c8 6cc 6a8 6d4 6c7 6f5 6e4 6e8
6c4 6f0 6e3 711 700 704 6e0 70c
6ff 72d 71c 720 6fc 728 71b 749
738 73c 718 744 737 765 754 758
734 760 753 781 770 774 750 77c
76f 79d 78c 790 76c 798 78b 7b9
7a8 7ac 788 7b4 7a7 7d5 7c4 7c8
7a4 7d0 7c3 7f1 7e0 7e4 7c0 7ec
7df 80d 7fc 800 7dc 808 7fb 829
818 81c 7f8 824 817 845 834 838
814 840 833 861 850 854 830 85c
84f 87d 86c 870 84c 878 86b 899
888 88c 868 894 887 8b5 8a4 8a8
884 8b0 8a3 8d1 8c0 8c4 8a0 8cc
8bf 8ed 8dc 8e0 8bc 8e8 8db 909
8f8 8fc 8d8 904 8f7 925 914 918
8f4 920 913 941 930 934 910 93c
92f 95d 94c 950 92c 958 94b 979
968 96c 948 974 967 995 984 988
964 990 983 9b1 9a0 9a4 980 9ac
99f 9cd 9bc 9c0 99c 9c8 9bb 9e9
9d8 9dc 9b8 9e4 9d7 a06 9f4 9d4
9f8 9f9 a01 9f3 a23 a11 9f0 a15
a16 a1e a10 a3f a2e a32 a0d a3a
a2d a5c a4a a2a a4e a4f a57 a49
a78 a67 a6b a46 a73 a66 a94 a83
a87 a63 a8f a82 ab0 a9f aa3 a7f
aab a9e acc abb abf a9b ac7 aba
ae8 ad7 adb ab7 ae3 ad6 b04 af3
af7 ad3 aff af2 b20 b0f b13 aef
b1b b0e b3c b2b b2f b0b b37 b2a
b58 b47 b4b b27 b53 b46 b74 b63
b67 b43 b6f b62 b90 b7f b83 b5f
b8b b7e bad b9b b7b b9f ba0 ba8
b9a bc9 bb8 bbc bc4 b97 be1 bd0
bd4 bdc bb7 bfd bec bf0 bf8 bb4
be8 c04 c15 c16 c19 c1d c21 c25
c29 c2d c31 c35 c39 c3d c41 c45
c49 c4d c51 c55 c59 c5d c69 c6e
c70 c7c c80 c9e c86 c8a c8e c91
c99 c85 cbe ca9 cad c82 cb1 cb9
ca8 cc5 cc9 ca5 ccd cd1 cd5 cd8
cdd cde 1 ce0 ce5 ce9 ced cf0
cf5 cf9 cfd d00 d05 d06 d08 d0d
d10 d14 d15 d1a d1f d22 d27 d28
d2d d30 d34 d35 d3a d3d d42 d43
d48 d4b d50 d51 d56 d59 d5e d5f
d64 d67 d6b d6c d71 d74 d79 d7a
d7f d82 d87 d88 d8d d90 d94 d98
d9d da0 da4 da5 daa dad db2 db3
db8 dbd dbe dc0 dc5 dc6 dc8 dc9
dce dd1 dd6 dd7 ddc ddf de3 de7
dec def df3 df4 df9 dfc e01 e02
e07 e0c e0d e0f e14 e15 e17 e18
e1d e20 e25 e26 e2b e2e e32 e36
e3a e3b e3d e42 e43 e45 e46 e4b
e4e e53 e54 e59 e5c e60 e64 e68
e69 e6b e70 e71 e73 e74 e79 e7c
e81 e82 e87 e8a e8e e92 e96 e97
e99 e9e e9f ea1 ea2 ea7 eaa eaf
eb0 eb5 eb8 ebc ec0 ec4 ec5 ec7
ecc ecd ecf ed0 ed5 ed8 edd ede
ee3 ee6 eeb eec ef1 ef4 ef8 ef9
efe f01 f06 f07 f0c f0f f14 f15
f1a f1d f22 f23 f28 f2b f2f f30
f35 f38 f3d f3e f43 f46 f4b f4c
f51 f52 f57 f59 f5d f60 f64 f68
f6b f6f f73 f76 f79 f7e f81 f84
f87 f88 f8d f8e 1 f90 f95 f99
f9d fa0 fa5 faa fad fb1 fb2 fb7
fb8 fbd fbf fc3 fc6 fca fcd fd1
fd5 fda fde fe2 fe6 fea fee ff2
ff6 ffa ffe 1002 1006 100a 100e 1012
1016 101a 101e 1022 1026 102a 102e 1032
1036 103a 103e 1042 1046 104a 104e 1052
1056 105a 105e 1062 1066 106a 106e 1072
1076 107a 107e 1082 108e 1092 1096 1099
109d 10a1 10a3 10a7 10ab 10af 10b2 10b6
10ba 10bc 10bd 10c2 1 10c6 10ca 10ce
10d1 10d5 10d9 10dd 10e1 10e4 10e8 10ec
10ef 10f2 10f7 10fa 10fd 1100 1101 1106
1107 1 1109 110e 1112 1116 1119 111e
1123 1126 112a 112b 1130 1133 1138 1139
113e 1141 1146 1147 114c 114f 1153 1154
1159 115c 1161 1162 1167 116a 116e 1172
1175 1178 1179 117b 117c 1181 1182 1187
1189 118d 1190 1192 1196 1198 11a4 11a6
11a8 11a9 11ae 11b2 11b4 11c0 11c2 11c6
11ca 11cd 11d1 11d4 11d8 11db 11dc 11e1
11e4 11e8 11ec 11f0 11f4 11f8 11fc 1200
1204 1208 120c 1210 1214 1218 121c 1220
1224 1228 122c 1230 1234 1238 123c 1240
1244 1248 124c 1250 1254 1258 125c 1260
1264 1268 126c 1270 1274 1278 127c 1280
1284 1288 128c 1290 1294 1298 129c 12a0
12a4 12a8 12ac 12b0 12b4 12b8 12bc 12c0
12c4 12c8 12cc 12d0 12d4 12d8 12dc 12e0
12e4 12e8 12ec 12f0 12f4 12f8 12fc 1300
1304 1308 130c 1310 1314 1318 131c 1320
1324 1328 132c 1338 133c 1340 1343 1347
134b 134d 1351 1355 1359 135c 1360 1364
1366 1367 136c 1 1370 1374 1378 137b
137f 1383 1387 138b 138e 1392 1396 1399
139c 13a1 13a4 13a7 13aa 13ab 13b0 13b1
1 13b3 13b8 13bc 13c0 13c3 13c8 13cd
13d0 13d4 13d5 13da 13dd 13e2 13e3 13e8
13eb 13f0 13f1 13f6 13f9 13fd 13fe 1403
1406 140b 140c 1411 1414 1418 141c 141f
1422 1423 1425 1426 142b 142c 1431 1433
1437 143a 143c 1440 1442 144e 1450 1452
1453 1458 145c 145e 146a 146c 1470 1474
1477 147b 147e 1482 1485 1486 148b 148e
1492 1496 149a 149e 14a2 14a6 14aa 14ae
14b2 14b6 14ba 14be 14c2 14c6 14ca 14ce
14d2 14d6 14da 14de 14e2 14e6 14ea 14ee
14f2 14f6 14fa 14fe 1502 1506 150a 150e
1512 1516 151a 151e 152a 152e 1532 1535
1539 153d 153f 1543 1547 154b 154e 1552
1556 1558 1559 155e 1 1562 1566 156a
156d 1571 1575 1579 157d 1580 1584 1588
158b 158e 1593 1596 1599 159c 159d 15a2
15a3 1 15a5 15aa 15ae 15b2 15b5 15ba
15bf 15c2 15c6 15c7 15cc 15cf 15d4 15d5
15da 15dd 15e2 15e3 15e8 15eb 15ef 15f0
15f5 15f8 15fd 15fe 1603 1606 160a 160e
1611 1614 1615 1617 1618 161d 161e 1623
1625 1629 162c 162e 1632 1634 1640 1642
1644 1645 164a 164e 1650 165c 165e 1662
1666 1669 166d 1670 1674 1677 1678 167d
1680 1684 1688 168c 1690 1694 1697 169b
169f 16a2 16a5 16aa 16ad 16b0 16b3 16b4
16b9 16ba 1 16bc 16c1 16c5 16c9 16cc
16d1 16d6 16d9 16dd 16de 16e3 16e4 16e9
16eb 16ef 16f2 16f6 16fa 16fe 1701 1705
1707 170b 170e 1712 1716 171a 171d 171e
1720 1724 1728 172b 172c 172e 1731 1735
1738 173c 173f 1740 1745 1749 174d 1751
1755 1759 175c 1760 1764 1767 176a 176f
1772 1775 1778 1779 177e 177f 1 1781
1786 178a 178e 1791 1796 179b 179e 17a2
17a3 17a8 17a9 17ae 17b0 17b4 17b7 17bb
17bf 17c3 17c6 17ca 17cc 17d0 17d3 17d7
17db 17df 17e3 17e7 17eb 17ef 17f3 17f6
17fa 17fe 1801 1802 1804 1807 180a 180b
1810 1813 1817 181b 181e 1822 1826 1829
182a 182c 182f 1832 1833 1838 1 183b
1840 1844 1848 184c 1850 1854 1857 185b
185f 1862 1865 186a 186d 1870 1873 1874
1879 187a 1 187c 1881 1885 1889 188c
1891 1896 1899 189d 189e 18a3 18a4 18a9
18ab 18af 18b2 18b6 18ba 18be 18c1 18c5
18c7 18cb 18ce 18d2 18d5 18d6 18db 18de
18e1 18e5 18e9 18ec 18ed 18ef 18f2 18f6
18fa 18fd 18fe 1900 1901 1906 1909 190d
1910 1914 1917 1918 191a 191b 1920 1
1923 1928 192c 1930 1934 1938 193c 193f
1943 1947 194a 194d 1952 1955 1958 195b
195c 1961 1962 1 1964 1969 196d 1971
1974 1979 197e 1981 1985 1986 198b 198c
1991 1993 1997 199a 199e 19a2 19a6 19a9
19ad 19af 19b3 19b6 19ba 19be 19c1 19c5
19c9 19cc 19cd 19cf 19d2 19d5 19d6 19db
19de 19e2 19e6 19e9 19ed 19f1 19f4 19f5
19f7 19fa 19fd 19fe 1a03 1 1a06 1a0b
1a0f 1a13 1a16 1a17 1a19 1a1c 1a1f 1a20
1a25 1a29 1a2d 1a30 1a34 1a38 1a3b 1a3c
1a3e 1a41 1a44 1a45 1a4a 1a4e 1a52 1a56
1a5a 1a5e 1a62 1a66 1a6a 1a6e 1a72 1a76
1a7a 1a7e 1a82 1a86 1a8a 1a96 1a9a 1a9e
1aa1 1aa5 1aa9 1aab 1aaf 1ab3 1ab7 1aba
1abe 1ac2 1ac4 1ac5 1aca 1 1ace 1ad2
1ad6 1ad9 1add 1ae1 1ae5 1ae9 1aec 1af0
1af4 1af7 1afa 1aff 1b02 1b05 1b08 1b09
1b0e 1b0f 1 1b11 1b16 1b1a 1b1e 1b21
1b26 1b2b 1b2e 1b32 1b33 1b38 1b3b 1b40
1b41 1b46 1b49 1b4e 1b4f 1b54 1b57 1b5b
1b5c 1b61 1b64 1b69 1b6a 1b6f 1b72 1b76
1b7a 1b7d 1b80 1b81 1b83 1b84 1b89 1b8a
1b8f 1b91 1b95 1b98 1b9a 1b9e 1ba0 1bac
1bae 1bb0 1bb1 1bb6 1bba 1bbc 1bc8 1bca
1bce 1bd2 1bd5 1bd9 1bdc 1be0 1be3 1be4
1be9 1bec 1bf0 1bf4 1bf8 1bfc 1c00 1c04
1c08 1c0c 1c10 1c1c 1c20 1c24 1c27 1c2b
1c2f 1c31 1c35 1c39 1c3d 1c40 1c44 1c48
1c4a 1c4b 1c50 1 1c54 1c58 1c5c 1c5f
1c63 1c67 1c6b 1c6f 1c72 1c76 1c7a 1c7d
1c80 1c85 1c88 1c8b 1c8e 1c8f 1c94 1c95
1 1c97 1c9c 1ca0 1ca4 1ca7 1cac 1cb1
1cb4 1cb8 1cb9 1cbe 1cc1 1cc6 1cc7 1ccc
1ccf 1cd4 1cd5 1cda 1cdd 1ce1 1ce2 1ce7
1cea 1cef 1cf0 1cf5 1cf8 1cfc 1d00 1d03
1d06 1d07 1d09 1d0a 1d0f 1d10 1d15 1d17
1d1b 1d1e 1d20 1d24 1d26 1d32 1d34 1d36
1d37 1d3c 1d40 1d42 1d4e 1d50 1d52 1d56
1d59 1d5d 1d61 1d64 1d68 1d6c 1d6f 1d70
1d72 1d75 1d78 1d79 1d7e 1d82 1d83 1d87
1d89 1d8d 1d90 1d92 1d96 1d9a 1d9e 1da2
1da6 1daa 1dae 1db2 1db6 1dba 1dbe 1dc2
1dc6 1dca 1dce 1dd2 1dde 1de2 1de6 1de9
1ded 1df1 1df3 1df7 1dfb 1dff 1e02 1e06
1e0a 1e0c 1e0d 1e12 1 1e16 1e1a 1e1e
1e21 1e25 1e29 1e2d 1e31 1e34 1e38 1e3c
1e3f 1e42 1e47 1e4a 1e4d 1e50 1e51 1e56
1e57 1 1e59 1e5e 1e62 1e66 1e69 1e6e
1e73 1e76 1e7a 1e7b 1e80 1e83 1e88 1e89
1e8e 1e91 1e96 1e97 1e9c 1e9f 1ea3 1ea4
1ea9 1eac 1eb1 1eb2 1eb7 1eba 1ebe 1ec2
1ec5 1ec8 1ec9 1ecb 1ecc 1ed1 1ed2 1ed7
1ed9 1edd 1ee0 1ee2 1ee6 1ee8 1ef4 1ef6
1ef8 1ef9 1efe 1f02 1f04 1f10 1f12 1f16
1f1a 1f1d 1f21 1f24 1f28 1f2b 1f2c 1f31
1f34 1f38 1f3c 1f40 1f44 1f48 1f4c 1f50
1f54 1f58 1f64 1f68 1f6c 1f6f 1f73 1f77
1f79 1f7d 1f81 1f85 1f88 1f8c 1f90 1f92
1f93 1f98 1 1f9c 1fa0 1fa4 1fa7 1fab
1faf 1fb3 1fb7 1fba 1fbe 1fc2 1fc5 1fc8
1fcd 1fd0 1fd3 1fd6 1fd7 1fdc 1fdd 1
1fdf 1fe4 1fe8 1fec 1fef 1ff4 1ff9 1ffc
2000 2001 2006 2009 200e 200f 2014 2017
201c 201d 2022 2025 2029 202a 202f 2032
2037 2038 203d 2040 2044 2048 204b 204e
204f 2051 2052 2057 2058 205d 205f 2063
2066 2068 206c 206e 207a 207c 207e 207f
2084 2088 208a 2096 2098 209a 209e 20a1
20a5 20a8 20ac 20ae 20b2 20b6 20b9 20bd
20c1 20c4 20c5 20c7 20cb 20ce 20d2 20d5
20d6 20db 20df 20e3 20e7 20eb 20ef 20f3
20f7 20fb 20ff 210b 210f 2114 2118 211b
211c 2121 2125 2129 212c 212f 2133 2135
2139 213d 2140 2143 2147 2149 214d 2151
2154 2156 215a 215e 2162 2165 2169 216d
216f 2170 2175 1 2179 217d 2181 2184
2188 218c 2190 2194 2197 219b 219f 21a2
21a5 21aa 21ad 21b0 21b3 21b4 21b9 21ba
1 21bc 21c1 21c5 21c9 21cc 21d1 21d6
21d9 21dd 21de 21e3 21e6 21eb 21ec 21f1
21f4 21f9 21fa 21ff 2202 2206 2207 220c
220f 2214 2215 221a 221d 2221 2225 2228
222b 222c 222e 222f 2234 2235 223a 223c
2240 2243 2245 2249 224b 2257 2259 225b
225c 2261 2265 2267 2273 2275 2277 227b
227f 2283 2287 228b 228f 2293 2297 229b
22a7 22ab 22b0 22b4 22b7 22b8 22bd 22c1
22c5 22c8 22cb 22cf 22d1 22d5 22d9 22dc
22df 22e3 22e5 22e9 22ed 22f0 22f2 22f6
22fa 22fe 2301 2305 2309 230b 230c 2311
1 2315 2319 231d 2320 2324 2328 232c
2330 2333 2337 233b 233e 2341 2346 2349
234c 234f 2350 2355 2356 1 2358 235d
2361 2365 2368 236d 2372 2375 2379 237a
237f 2382 2387 2388 238d 2390 2395 2396
239b 239e 23a2 23a3 23a8 23ab 23b0 23b1
23b6 23b9 23bd 23c1 23c4 23c7 23c8 23ca
23cb 23d0 23d1 23d6 23d8 23dc 23df 23e1
23e5 23e7 23f3 23f5 23f7 23f8 23fd 2401
2403 240f 2411 2413 2417 241b 241e 2422
2426 2429 242d 2430 2434 2437 2438 243d
2440 2444 2448 244c 244d 244f 2453 2455
2459 245c 245e 2462 2465 2469 246d 2470
2474 2478 247c 247f 2480 2482 2486 2489
248d 2490 2491 2496 249a 249e 24a1 24a2
24a4 24a8 24ab 24af 24b2 24b3 1 24b8
24bd 24c1 24c5 24c9 24cd 24d1 24d5 24d9
24dd 24e1 24e5 24e9 24ed 24f1 24fd 2501
2505 2508 250c 2510 2512 2516 251a 251e
2521 2525 2529 252b 252c 2531 1 2535
2539 253d 2540 2544 2548 254c 2550 2553
2557 255b 255e 2561 2566 2569 256c 256f
2570 2575 2576 1 2578 257d 2581 2585
2588 258d 2592 2595 2599 259a 259f 25a2
25a7 25a8 25ad 25b0 25b5 25b6 25bb 25be
25c2 25c3 25c8 25cb 25d0 25d1 25d6 25d9
25dd 25e1 25e4 25e7 25e8 25ea 25eb 25f0
25f1 25f6 25f8 25fc 25ff 2601 2605 2607
2613 2615 2617 2618 261d 2621 2623 262f
2631 2633 2637 263a 263e 2642 2645 2649
264d 2650 2651 2653 2656 2659 265a 265f
2663 2667 266b 266f 2673 2677 267b 267f
2683 2687 268b 268f 2693 2697 269b 269f
26ab 26af 26b3 26b6 26ba 26be 26c0 26c4
26c8 26cc 26cf 26d3 26d7 26d9 26da 26df
1 26e3 26e7 26eb 26ee 26f2 26f6 26fa
26fe 2701 2705 2709 270c 270f 2714 2717
271a 271d 271e 2723 2724 1 2726 272b
272f 2733 2736 273b 2740 2743 2747 2748
274d 2750 2755 2756 275b 275e 2763 2764
2769 276c 2770 2771 2776 2779 277e 277f
2784 2787 278b 278f 2792 2795 2796 2798
2799 279e 279f 27a4 27a6 27aa 27ad 27af
27b3 27b5 27c1 27c3 27c5 27c6 27cb 27cf
27d1 27dd 27df 27e3 27e7 27ea 27ee 27f1
27f5 27f8 27f9 27fe 2801 2805 2809 280d
2811 2815 2819 281d 2821 2825 2831 2835
2839 283c 2840 2844 2846 284a 284e 2852
2855 2859 285d 285f 2860 2865 1 2869
286d 2871 2874 2878 287c 2880 2884 2887
288b 288f 2892 2895 289a 289d 28a0 28a3
28a4 28a9 28aa 1 28ac 28b1 28b5 28b9
28bc 28c1 28c6 28c9 28cd 28ce 28d3 28d6
28db 28dc 28e1 28e4 28e9 28ea 28ef 28f2
28f6 28f7 28fc 28ff 2904 2905 290a 290d
2911 2915 2918 291b 291c 291e 291f 2924
2925 292a 292c 2930 2933 2935 2939 293b
2947 2949 294b 294c 2951 2955 2957 2963
2965 2969 296d 2971 2974 2975 2977 297a
297d 297e 2983 2987 2989 298d 2990 2994
2998 299b 299c 299e 29a2 29a5 29a9 29ac
29ad 29b2 29b6 29ba 29bd 29be 29c0 29c4
29c7 29cb 29ce 29cf 1 29d4 29d9 29dd
29e2 29e6 29ea 29ed 29f1 29f3 29f7 29fa
29fc 2a00 2a04 2a07 2a08 2a0a 2a0d 2a10
2a11 2a16 2a1a 2a1d 2a21 2a25 2a29 2a2d
2a31 2a35 2a39 2a3d 2a41 2a45 2a49 2a4d
2a51 2a55 2a61 2a65 2a69 2a6c 2a70 2a74
2a76 2a7a 2a7e 2a82 2a85 2a89 2a8d 2a8f
2a90 2a95 1 2a99 2a9d 2aa1 2aa4 2aa8
2aac 2ab0 2ab4 2ab7 2abb 2abf 2ac2 2ac5
2aca 2acd 2ad0 2ad3 2ad4 2ad9 2ada 1
2adc 2ae1 2ae5 2ae9 2aec 2af1 2af6 2af9
2afd 2afe 2b03 2b06 2b0b 2b0c 2b11 2b14
2b19 2b1a 2b1f 2b22 2b26 2b27 2b2c 2b2f
2b34 2b35 2b3a 2b3d 2b41 2b45 2b48 2b4b
2b4c 2b4e 2b4f 2b54 2b55 2b5a 2b5c 2b60
2b63 2b65 2b69 2b6b 2b77 2b79 2b7b 2b7c
2b81 2b85 2b87 2b93 2b95 2b99 2b9d 2ba0
2ba1 2ba3 2ba6 2ba9 2baa 2baf 2bb3 2bb7
2bbb 2bbf 2bc3 2bc7 2bcb 2bcf 2bd3 2bd7
2bdb 2bdf 2be3 2be7 2bf3 2bf7 2bfb 2bfe
2c02 2c06 2c08 2c0c 2c10 2c14 2c17 2c1b
2c1f 2c21 2c22 2c27 1 2c2b 2c2f 2c33
2c36 2c3a 2c3e 2c42 2c46 2c49 2c4d 2c51
2c54 2c57 2c5c 2c5f 2c62 2c65 2c66 2c6b
2c6c 1 2c6e 2c73 2c77 2c7b 2c7e 2c83
2c88 2c8b 2c8f 2c90 2c95 2c98 2c9d 2c9e
2ca3 2ca6 2cab 2cac 2cb1 2cb4 2cb8 2cb9
2cbe 2cc1 2cc6 2cc7 2ccc 2ccf 2cd3 2cd7
2cda 2cdd 2cde 2ce0 2ce1 2ce6 2ce7 2cec
2cee 2cf2 2cf5 2cf7 2cfb 2cfd 2d09 2d0b
2d0d 2d0e 2d13 2d17 2d19 2d25 2d27 2d29
2d2d 2d30 2d34 2d38 2d3b 2d3c 2d3e 2d41
2d44 2d45 2d4a 2d4e 2d52 2d56 2d5a 2d5e
2d61 2d65 2d69 2d6c 2d6f 2d74 2d77 2d7a
2d7d 2d7e 2d83 2d84 1 2d86 2d8b 2d8f
2d93 2d96 2d9b 2da0 2da3 2da7 2da8 2dad
2dae 2db3 2db5 2db9 2dbc 2dc0 2dc4 2dc8
2dcb 2dcf 2dd1 2dd5 2dd8 2dda 2dde 2de1
2de5 2de9 2ded 2df1 2df5 2df9 2dfd 2e01
2e05 2e09 2e0d 2e11 2e15 2e19 2e1d 2e21
2e2d 2e31 2e35 2e38 2e3c 2e40 2e42 2e46
2e4a 2e4e 2e51 2e55 2e59 2e5b 2e5c 2e61
1 2e65 2e69 2e6d 2e70 2e74 2e78 2e7c
2e80 2e83 2e87 2e8b 2e8e 2e91 2e96 2e99
2e9c 2e9f 2ea0 2ea5 2ea6 1 2ea8 2ead
2eb1 2eb5 2eb8 2ebd 2ec2 2ec5 2ec9 2eca
2ecf 2ed2 2ed7 2ed8 2edd 2ee0 2ee5 2ee6
2eeb 2eee 2ef2 2ef3 2ef8 2efb 2f00 2f01
2f06 2f09 2f0d 2f11 2f14 2f17 2f18 2f1a
2f1b 2f20 2f21 2f26 2f28 2f2c 2f2f 2f31
2f35 2f37 2f43 2f45 2f47 2f48 2f4d 2f51
2f53 2f5f 2f61 2f65 2f69 2f6c 2f70 2f73
2f77 2f7a 2f7b 2f80 2f83 2f87 2f8b 2f8f
2f93 2f97 2f9b 2f9f 2fa3 2fa7 2fb3 2fb7
2fbb 2fbe 2fc2 2fc6 2fc8 2fcc 2fd0 2fd4
2fd7 2fdb 2fdf 2fe1 2fe2 2fe7 1 2feb
2fef 2ff3 2ff6 2ffa 2ffe 3002 3006 3009
300d 3011 3014 3017 301c 301f 3022 3025
3026 302b 302c 1 302e 3033 3037 303b
303e 3043 3048 304b 304f 3050 3055 3058
305d 305e 3063 3066 306b 306c 3071 3074
3078 3079 307e 3081 3086 3087 308c 308f
3093 3097 309a 309d 309e 30a0 30a1 30a6
30a7 30ac 30ae 30b2 30b5 30b7 30bb 30bd
30c9 30cb 30cd 30ce 30d3 30d7 30d9 30e5
30e7 30e9 30ed 30f0 30f4 30f8 30fb 30fc
30fe 3101 3104 3105 310a 310e 3112 3115
3116 3118 311c 311f 3123 3126 3127 312c
3130 3134 3137 3138 313a 313e 3141 3145
3148 3149 1 314e 3153 1 3156 315b
315f 3164 3168 316c 316f 3173 3175 3179
317c 317e 3182 3186 3189 318d 3191 3194
3195 3197 319a 319d 319e 31a3 31a7 31aa
31ad 31ae 1 31b3 31b8 31bb 31bf 31c3
31c6 31c7 31c9 31cd 31d0 31d4 31d7 31d8
31dd 31e1 31e5 31e8 31e9 31eb 31ef 31f2
31f6 31f9 31fa 1 31ff 3204 1 3207
320c 3210 3214 3218 321c 3220 3224 3225
3227 322b 322d 3231 3234 3238 323b 323f
3243 3247 324b 324f 3253 3257 325b 325f
3263 3267 326b 326f 3273 3277 327b 327f
3283 3287 328b 328f 3293 3297 329b 329f
32a3 32a7 32ab 32af 32b3 32b7 32bb 32bf
32c3 32c7 32cb 32cf 32db 32df 32e3 32e6
32ea 32ee 32f0 32f4 32f8 32fc 32ff 3303
3307 3309 330a 330f 1 3313 3317 331b
331e 3322 3326 332a 332e 3331 3335 3339
333c 333f 3344 3347 334a 334d 334e 3353
3354 1 3356 335b 335f 3363 3366 336b
3370 3373 3377 3378 337d 3380 3385 3386
338b 338e 3393 3394 3399 339c 33a0 33a1
33a6 33a9 33ae 33af 33b4 33b7 33bb 33bf
33c2 33c5 33c6 33c8 33c9 33ce 33cf 33d4
33d6 33da 33dd 33df 33e3 33e5 33f1 33f3
33f5 33f6 33fb 33ff 3401 340d 340f 3413
3417 341a 341b 341d 3420 3423 3424 3429
342d 3431 3435 3439 343d 3440 3444 3448
344b 344e 3453 3456 3459 345c 345d 3462
3463 1 3465 346a 346e 3472 3475 347a
347f 3482 3486 3487 348c 348d 3492 3494
3498 349b 349f 34a3 34a7 34aa 34ae 34b0
34b4 34b7 34bb 34bf 34c3 34c7 34cb 34cf
34d3 34d7 34db 34df 34e3 34e7 34eb 34ef
34f2 34f3 34f5 34f8 34f9 34fb 34ff 3503
3507 350a 350b 350d 3510 3513 3514 3519
351d 3521 3525 3526 3528 352c 352e 3532
3536 353a 353e 3542 3545 3549 354d 3550
3553 3558 355b 355e 3561 3562 3567 3568
1 356a 356f 3573 3577 357a 357f 3584
3587 358b 358c 3591 3592 3597 3599 359d
35a0 35a4 35a8 35ac 35af 35b0 35b2 35b6
35b8 35bc 35c0 35c3 35c5 35c9 35cd 35d0
35d4 35d6 35da 35de 35e1 35e2 35e4 35e8
35eb 35ef 35f2 35f3 35f5 35f6 35fb 35fe
3602 3606 3609 360a 360c 360f 3612 3613
3618 1 361b 3620 3624 3627 362b 362f
3633 3636 3637 3639 363d 3640 3644 3647
3648 364a 364b 3650 3654 3658 365c 3660
3664 3667 366b 366f 3672 3675 367a 367d
3680 3683 3684 3689 368a 1 368c 3691
3695 3699 369c 36a1 36a6 36a9 36ad 36ae
36b3 36b4 36b9 36bb 36bf 36c2 36c6 36ca
36ce 36d1 36d5 36d9 36db 36df 36e3 36e6
36e7 36e9 36ed 36f0 36f4 36f7 36f8 36fa
36fb 3700 3704 3707 370b 370d 3711 3715
3718 371c 371f 3723 3727 372b 372f 3733
3737 373b 373f 3743 3747 374b 374f 3753
3757 375b 375f 3763 3767 376b 376f 3773
3777 377b 377f 3783 378f 3793 3797 379a
379e 37a2 37a4 37a8 37ac 37b0 37b3 37b7
37bb 37bd 37be 37c3 1 37c7 37cb 37cf
37d2 37d6 37da 37de 37e2 37e5 37e9 37ed
37f0 37f3 37f8 37fb 37fe 3801 3802 3807
3808 1 380a 380f 3813 3817 381a 381f
3824 3827 382b 382c 3831 3834 3839 383a
383f 3842 3847 3848 384d 3850 3854 3855
385a 385d 3862 3863 3868 386b 386f 3873
3876 3879 387a 387c 387d 3882 3883 3888
388a 388e 3891 3893 3897 3899 38a5 38a7
38a9 38aa 38af 38b3 38b5 38c1 38c3 38c7
38cb 38ce 38cf 38d1 38d4 38d7 38d8 38dd
38e1 38e5 38e9 38ed 38f1 38f4 38f8 38fc
38ff 3902 3907 390a 390d 3910 3911 3916
3917 1 3919 391e 3922 3926 3929 392e
3933 3936 393a 393b 3940 3941 3946 3948
394c 394f 3953 3957 395b 395e 3962 3964
3968 396b 396f 3972 3976 397a 397e 3982
3986 398a 398e 3992 3996 399a 399e 39a2
39a6 39aa 39ae 39b2 39b6 39ba 39be 39c2
39c6 39ca 39ce 39d2 39d6 39da 39de 39e2
39e6 39f2 39f6 39fa 39fd 3a01 3a05 3a07
3a0b 3a0f 3a13 3a16 3a1a 3a1e 3a20 3a21
3a26 1 3a2a 3a2e 3a32 3a35 3a39 3a3d
3a41 3a45 3a48 3a4c 3a50 3a53 3a56 3a5b
3a5e 3a61 3a64 3a65 3a6a 3a6b 1 3a6d
3a72 3a76 3a7a 3a7d 3a82 3a87 3a8a 3a8e
3a8f 3a94 3a97 3a9c 3a9d 3aa2 3aa5 3aaa
3aab 3ab0 3ab3 3ab7 3ab8 3abd 3ac0 3ac5
3ac6 3acb 3ace 3ad2 3ad6 3ad9 3adc 3add
3adf 3ae0 3ae5 3ae6 3aeb 3aed 3af1 3af4
3af6 3afa 3afc 3b08 3b0a 3b0c 3b0d 3b12
3b16 3b18 3b24 3b26 3b2a 3b2e 3b31 3b32
3b34 3b37 3b3a 3b3b 3b40 3b44 3b48 3b4c
3b50 3b54 3b57 3b5b 3b5f 3b62 3b65 3b6a
3b6d 3b70 3b73 3b74 3b79 3b7a 1 3b7c
3b81 3b85 3b89 3b8c 3b91 3b96 3b99 3b9d
3b9e 3ba3 3ba4 3ba9 3bab 3baf 3bb2 3bb6
3bba 3bbe 3bc1 3bc5 3bc7 3bcb 3bce 3bd2
3bd6 3bda 3bdd 3bde 3be0 3be4 3be8 3bec
3bf0 3bf4 3bf8 3bfc 3c00 3c04 3c07 3c08
3c0a 3c0e 3c12 3c15 3c16 3c18 3c1c 3c20
3c23 3c24 3c26 3c27 3c29 3c2d 3c2f 3c33
3c37 3c3a 3c3e 3c42 3c45 3c46 3c48 3c4b
3c4e 3c4f 3c54 3c58 3c5c 3c60 3c61 3c63
3c67 3c69 3c6d 3c70 3c74 3c78 3c7c 3c80
3c84 3c87 3c8b 3c8f 3c92 3c95 3c9a 3c9d
3ca0 3ca3 3ca4 3ca9 3caa 1 3cac 3cb1
3cb5 3cb9 3cbc 3cc1 3cc6 3cc9 3ccd 3cce
3cd3 3cd4 3cd9 3cdb 3cdf 3ce2 3ce6 3cea
3cee 3cf1 3cf2 3cf4 3cf8 3cfc 3cfe 3d02
3d05 3d06 3d0b 3d0e 3d12 3d15 3d16 3d1b
1 3d1e 3d23 3d27 3d2b 3d2f 3d33 3d37
3d3b 3d3f 3d43 3d46 3d4a 3d4e 3d51 3d52
3d54 3d57 3d5a 3d5b 3d60 3d63 3d67 3d6b
3d6e 3d72 3d76 3d79 3d7a 3d7c 3d7f 3d82
3d83 3d88 1 3d8b 3d90 3d94 3d98 3d9c
3da0 3da4 3da7 3dab 3daf 3db2 3db5 3dba
3dbd 3dc0 3dc3 3dc4 3dc9 3dca 1 3dcc
3dd1 3dd5 3dd9 3ddc 3de1 3de6 3de9 3ded
3dee 3df3 3df4 3df9 3dfb 3dff 3e02 3e06
3e0a 3e0e 3e11 3e15 3e17 3e1b 3e1e 3e22
3e25 3e26 3e2b 3e2e 3e32 3e36 3e3a 3e3e
3e42 3e46 3e4a 3e4e 3e52 3e5e 3e62 3e66
3e69 3e6d 3e71 3e73 3e77 3e7b 3e7f 3e82
3e86 3e8a 3e8c 3e8d 3e92 1 3e96 3e9a
3e9e 3ea1 3ea5 3ea9 3ead 3eb1 3eb4 3eb8
3ebc 3ebf 3ec2 3ec7 3eca 3ecd 3ed0 3ed1
3ed6 3ed7 1 3ed9 3ede 3ee2 3ee6 3ee9
3eee 3ef3 3ef6 3efa 3efb 3f00 3f03 3f08
3f09 3f0e 3f11 3f16 3f17 3f1c 3f1f 3f23
3f24 3f29 3f2c 3f31 3f32 3f37 3f3a 3f3e
3f42 3f45 3f48 3f49 3f4b 3f4c 3f51 3f52
3f57 3f59 3f5d 3f60 3f62 3f66 3f68 3f74
3f76 3f78 3f79 3f7e 3f82 3f84 3f90 3f92
3f96 3f9a 3f9d 3fa1 3fa4 3fa8 3fab 3fac
3fb1 3fb4 3fb8 3fbc 3fc0 3fc4 3fc8 3fcb
3fcf 3fd3 3fd6 3fd9 3fde 3fe1 3fe4 3fe7
3fe8 3fed 3fee 1 3ff0 3ff5 3ff9 3ffd
4000 4005 400a 400d 4011 4012 4017 4018
401d 401f 4023 4026 402a 402e 4032 4035
4039 403b 403f 4042 4046 404a 404d 4051
4055 4058 4059 405b 405e 4061 4062 4067
406a 406e 4072 4075 4079 407d 4080 4081
4083 4086 4089 408a 408f 1 4092 4097
409b 409f 40a3 40a7 40ab 40ae 40b2 40b6
40b9 40bc 40c1 40c4 40c7 40ca 40cb 40d0
40d1 1 40d3 40d8 40dc 40e0 40e3 40e8
40ed 40f0 40f4 40f5 40fa 40fb 4100 4102
4106 4109 410d 4111 4115 4118 411c 4120
4122 4126 412a 412d 4131 4135 4138 4139
413b 413e 4141 4142 4147 414a 414e 4152
4155 4159 415d 4160 4161 4163 4166 4169
416a 416f 1 4172 4177 417b 417f 4183
4187 418b 418e 4192 4196 4199 419c 41a1
41a4 41a7 41aa 41ab 41b0 41b1 1 41b3
41b8 41bc 41c0 41c3 41c8 41cd 41d0 41d4
41d5 41da 41db 41e0 41e2 41e6 41e9 41ed
41f1 41f5 41f8 41fc 41fe 4202 4206 4209
420b 420f 4212 4216 421a 421e 4222 4226
422a 422e 4232 4236 423a 423e 4242 4246
424a 424e 4252 4256 4262 4266 426a 426d
4271 4275 4277 427b 427f 4283 4286 428a
428e 4290 4291 4296 1 429a 429e 42a2
42a5 42a9 42ad 42b1 42b5 42b8 42bc 42c0
42c3 42c6 42cb 42ce 42d1 42d4 42d5 42da
42db 1 42dd 42e2 42e6 42ea 42ed 42f2
42f7 42fa 42fe 42ff 4304 4307 430c 430d
4312 4315 431a 431b 4320 4323 4327 4328
432d 4330 4335 4336 433b 433e 4342 4346
4349 434c 434d 434f 4350 4355 4356 435b
435d 4361 4364 4366 436a 436c 4378 437a
437c 437d 4382 4386 4388 4394 4396 439a
439e 43a2 43a5 43a6 43a8 43ac 43b0 43b3
43b4 43b6 43b9 43bd 43c0 43c4 43c7 43c8
43cd 43d1 43d5 43d9 43dd 43e1 43e4 43e8
43ec 43ef 43f2 43f7 43fa 43fd 4400 4401
4406 4407 1 4409 440e 4412 4416 4419
441e 4423 4426 442a 442b 4430 4431 4436
4438 443c 443f 4443 4447 444b 444e 4452
4454 4458 445b 445f 4463 4466 4469 446a
446c 446f 4474 4475 447a 447e 4481 4485
4487 448b 448e 4492 4494 4498 449c 449f
44a3 44a6 44aa 44ae 44b1 44b5 44b9 44bd
44c0 44c4 44c8 44cb 44cc 44ce 44d1 44d4
44d5 44da 44dd 44e1 44e5 44e8 44ec 44f0
44f3 44f4 44f6 44f9 44fc 44fd 4502 1
4505 450a 450e 4512 4515 4516 4518 451c
451f 4523 4526 4527 4529 452a 452f 1
4532 4537 453b 453f 4542 4546 454a 454d
454e 4550 4553 4556 4557 455c 4560 4564
4567 4568 456a 456d 4570 4571 4576 457a
457e 4581 4585 4589 458c 458d 458f 4592
4595 4596 1 459b 45a0 45a4 45a8 45ac
45b0 45b4 45b7 45bb 45bf 45c2 45c5 45ca
45cd 45d0 45d3 45d4 45d9 45da 1 45dc
45e1 45e5 45e9 45ec 45f1 45f6 45f9 45fd
45fe 4603 4604 4609 460b 460f 4612 4616
461a 461e 4621 4625 4627 462b 462e 4632
4636 4639 463a 463c 4640 4643 4647 464a
464b 4650 4654 4658 465b 465c 465e 4662
4665 4669 466c 466d 1 4672 4677 467b
467e 4682 4686 468a 468e 4692 4696 469a
469e 46a2 46a6 46aa 46ae 46b2 46b6 46c2
46c6 46ca 46cd 46d1 46d5 46d7 46db 46df
46e3 46e6 46ea 46ee 46f0 46f1 46f6 1
46fa 46fe 4702 4705 4709 470d 4711 4715
4718 471c 4720 4723 4726 472b 472e 4731
4734 4735 473a 473b 1 473d 4742 4746
474a 474d 4752 4757 475a 475e 475f 4764
4767 476c 476d 4772 4775 477a 477b 4780
4783 4787 4788 478d 4790 4795 4796 479b
479e 47a2 47a6 47a9 47ac 47ad 47af 47b0
47b5 47b6 47bb 47bd 47c1 47c4 47c6 47ca
47cc 47d8 47da 47dc 47dd 47e2 47e6 47e8
47f4 47f6 47fa 47fe 4801 4805 4809 480c
480d 480f 4812 4815 4816 481b 481e 4822
4826 4829 482d 4831 4834 4835 4837 483a
483d 483e 4843 1 4846 484b 484f 4854
4858 485c 4860 4864 4868 486c 4870 4871
4873 4877 4879 487d 4880 4884 4888 488c
4890 4894 4898 489c 48a0 48a4 48a8 48ac
48b0 48b4 48b8 48bc 48c0 48c4 48c8 48cc
48d0 48d4 48d8 48dc 48df 48e0 48e2 48e6
48ea 48ed 48ee 48f0 48f1 48f3 48f7 48fb
48ff 4903 4904 4906 490a 490e 4912 4916
491a 491e 4921 4925 4929 492c 492f 4934
4937 493a 493d 493e 4943 4944 1 4946
494b 494f 4953 4956 495b 4960 4963 4967
4968 496d 496e 4973 4975 4979 497c 4980
4984 4988 498b 498c 498e 4992 4994 4998
499c 49a0 49a4 49a7 49ab 49af 49b2 49b6
49b8 49bc 49c0 49c3 49c7 49c9 49cd 49d1
49d4 49d8 49dc 49df 49e0 49e2 49e5 49e8
49e9 49ee 49f2 49f6 49fa 49fe 4a02 4a06
4a0a 4a0e 4a12 4a16 4a22 4a26 4a2a 4a2d
4a31 4a35 4a37 4a3b 4a3f 4a43 4a46 4a4a
4a4e 4a50 4a51 4a56 1 4a5a 4a5e 4a62
4a65 4a69 4a6d 4a71 4a75 4a78 4a7c 4a80
4a83 4a86 4a8b 4a8e 4a91 4a94 4a95 4a9a
4a9b 1 4a9d 4aa2 4aa6 4aaa 4aad 4ab2
4ab7 4aba 4abe 4abf 4ac4 4ac7 4acc 4acd
4ad2 4ad5 4ada 4adb 4ae0 4ae3 4ae7 4ae8
4aed 4af0 4af5 4af6 4afb 4afe 4b02 4b06
4b09 4b0c 4b0d 4b0f 4b10 4b15 4b16 4b1b
4b1d 4b21 4b24 4b26 4b2a 4b2c 4b38 4b3a
4b3c 4b3d 4b42 4b46 4b48 4b54 4b56 4b5a
4b5e 4b62 4b65 4b69 4b6d 4b6e 4b70 4b74
4b78 4b7b 4b7e 4b7f 4b84 4b88 4b8c 4b90
4b94 4b98 4b9c 4ba0 4ba4 4ba8 4bac 4bb0
4bb4 4bb8 4bb9 4bbb 4bbf 4bc3 4bc7 4bca
4bcb 4bcd 4bd0 4bd3 4bd4 4bd9 4bdc 4be0
4be3 4be4 4be9 4bec 1 4bef 4bf4 4bf8
4bfc 4c00 4c04 4c08 4c0c 4c10 4c14 4c18
4c1b 4c1c 4c1e 4c22 4c24 4c28 4c2b 4c2f
4c33 4c36 4c39 4c3a 4c3c 4c3f 4c44 4c45
4c4a 4c4e 4c51 4c55 4c57 4c5b 4c5e 4c62
4c64 4c68 4c6c 4c6f 4c73 4c77 4c7b 4c7e
4c7f 4c81 4c84 4c88 4c8c 4c8f 4c90 4c92
4c93 4c98 4c9c 4ca0 4ca4 4ca8 4cac 4cb0
4cb4 4cb8 4cbc 4cc0 4cc4 4cc8 4ccc 4cd0
4cd4 4cd8 4cdc 4ce0 4ce3 4ce4 4ce6 4ce9
4ced 4cf0 4cf1 4cf3 4cf7 4cfb 4cff 4d02
4d03 4d05 4d08 4d0b 4d0c 4d11 4d15 4d19
4d1c 4d20 4d24 4d27 4d28 4d2a 4d2d 4d30
4d31 4d36 4d3a 4d3e 4d42 4d46 4d4a 4d4e
4d52 4d56 4d5a 4d5e 4d62 4d66 4d6a 4d6e
4d7a 4d7e 4d83 4d87 4d8a 4d8b 4d90 4d94
4d98 4d9b 4d9e 4da2 4da4 4da8 4dac 4daf
4db2 4db6 4db8 4dbc 4dc0 4dc3 4dc5 4dc9
4dcd 4dd1 4dd4 4dd8 4ddc 4dde 4ddf 4de4
1 4de8 4dec 4df0 4df3 4df7 4dfb 4dff
4e03 4e06 4e0a 4e0e 4e11 4e14 4e19 4e1c
4e1f 4e22 4e23 4e28 4e29 1 4e2b 4e30
4e34 4e38 4e3b 4e40 4e45 4e48 4e4c 4e4d
4e52 4e55 4e5a 4e5b 4e60 4e63 4e68 4e69
4e6e 4e71 4e75 4e76 4e7b 4e7e 4e83 4e84
4e89 4e8c 4e90 4e94 4e97 4e9a 4e9b 4e9d
4e9e 4ea3 4ea4 4ea9 4eab 4eaf 4eb2 4eb4
4eb8 4eba 4ec6 4ec8 4eca 4ecb 4ed0 4ed4
4ed6 4ee2 4ee4 4ee8 4eea 4eee 4ef2 4ef5
4ef6 4ef8 4efb 4efe 4eff 4f04 4f08 4f0c
4f0f 4f13 4f17 4f1a 4f1b 4f1d 4f20 4f23
4f24 1 4f29 4f2e 4f32 4f36 4f3a 4f3e
4f42 4f46 4f4a 4f4e 4f52 4f56 4f62 4f66
4f6b 4f6f 4f72 4f73 4f78 4f7c 4f80 4f83
4f86 4f8a 4f8c 4f90 4f94 4f97 4f9a 4f9e
4fa0 4fa4 4fa8 4fab 4fad 4fb1 4fb5 4fb9
4fbc 4fc0 4fc4 4fc6 4fc7 4fcc 1 4fd0
4fd4 4fd8 4fdb 4fdf 4fe3 4fe7 4feb 4fee
4ff2 4ff6 4ff9 4ffc 5001 5004 5007 500a
500b 5010 5011 1 5013 5018 501c 5020
5023 5028 502d 5030 5034 5035 503a 503d
5042 5043 5048 504b 5050 5051 5056 5059
505d 505e 5063 5066 506b 506c 5071 5074
5078 507c 507f 5082 5083 5085 5086 508b
508c 5091 5093 5097 509a 509c 50a0 50a2
50ae 50b0 50b2 50b3 50b8 50bc 50be 50ca
50cc 50ce 50d2 50d6 50d9 50db 50df 50e2
50e6 50ea 50ee 50f2 50f6 50fa 50fe 5102
5106 510a 510e 5112 5116 511a 511e 5122
5126 512a 512e 513a 513e 5142 5145 5149
514d 514f 5153 5157 515b 515e 5162 5166
5168 5169 516e 1 5172 5176 517a 517d
5181 5185 5189 518d 5190 5194 5198 519b
519e 51a3 51a6 51a9 51ac 51ad 51b2 51b3
1 51b5 51ba 51be 51c2 51c5 51ca 51cf
51d2 51d6 51d7 51dc 51df 51e4 51e5 51ea
51ed 51f2 51f3 51f8 51fb 51ff 5200 5205
5208 520d 520e 5213 5216 521a 521e 5221
5224 5225 5227 5228 522d 522e 5233 5235
5239 523c 523e 5242 5244 5250 5252 5254
5255 525a 525e 5260 526c 526e 5272 5275
5279 527d 5281 5285 5289 528d 5291 5295
5299 529d 52a1 52a5 52a9 52aa 52ac 52b0
52b4 52b8 52bc 52bd 52bf 52c3 52c7 52cb
52ce 52d1 52d5 52d9 52dd 52e1 52e5 52e9
52ec 52f0 52f4 52f7 52fa 52ff 5302 5305
5308 5309 530e 530f 1 5311 5316 531a
531e 5321 5326 532b 532e 5332 5333 5338
5339 533e 5340 5344 5347 534b 534f 5353
5356 535a 535e 5360 5364 5368 536c 536f
5370 5372 5376 5379 537d 5380 5381 5383
5384 5389 538d 5391 5395 5398 5399 539b
539e 53a2 53a6 53a9 53aa 53ac 53ad 53b2
53b6 53ba 53be 53c1 53c2 53c4 53c8 53cb
53cf 53d2 53d3 53d8 53dc 53e0 53e3 53e4
53e6 53ea 53ed 53f1 53f4 53f5 1 53fa
53ff 5403 5407 540a 540d 540e 5410 5413
5418 5419 541e 5421 5425 5429 542d 542f
5433 5437 543b 543d 5441 5445 5448 544c
5450 5454 5458 545c 5460 5461 5463 5467
546b 546c 5470 5474 5478 547d 5481 5482
5486 548a 548f 5494 5498 549c 54a1 54a5
54a9 54ac 54af 54b3 54b5 54b9 54bd 54c0
54c3 54c7 54c9 54cd 54d1 54d4 54d8 54dc
54e1 54e3 54e7 54eb 54ee 54f2 54f6 54f8
54fc 5500 5504 5507 550b 550f 5511 5512
5517 1 551b 551f 5523 5526 552a 552e
5532 5536 5539 553d 5541 5544 5547 554c
554f 5552 5555 5556 555b 555c 1 555e
5563 5567 556b 556e 5573 5578 557b 557f
5580 5585 5588 558d 558e 5593 5596 559b
559c 55a1 55a4 55a8 55a9 55ae 55b1 55b6
55b7 55bc 55bf 55c3 55c7 55ca 55cd 55ce
55d0 55d1 55d6 55d7 55dc 55de 55e2 55e5
55e7 55eb 55ed 55f9 55fb 55fd 55fe 5603
5607 5609 5615 5617 561b 561e 561f 5624
5627 562b 562f 5632 5636 563a 563d 5640
5645 5648 564b 564e 564f 5654 5655 1
5657 565c 5660 5664 5667 566c 5671 5674
5678 5679 567e 567f 5684 5686 568a 568d
5691 5695 5699 569c 56a0 56a2 56a6 56a9
56ad 56b1 56b5 56b9 56bd 56c1 56c5 56c9
56cd 56d1 56d5 56d9 56dd 56e1 56e5 56e9
56ed 56f1 56f5 56f9 56fd 5701 5705 5708
5709 570b 570f 5713 5716 5717 5719 571a
571c 5720 5724 5728 572c 572d 572f 5733
5737 573b 573f 5743 5747 574a 574e 5752
5755 5758 575d 5760 5763 5766 5767 576c
576d 1 576f 5774 5778 577c 577f 5784
5789 578c 5790 5791 5796 5797 579c 579e
57a2 57a5 57a9 57ad 57b1 57b4 57b5 57b7
57bb 57bd 57c1 57c4 57c8 57ca 57ce 57d2
57d5 57d9 57db 57df 57e3 57e7 57ea 57eb
57ed 57f0 57f3 57f4 57f9 57fd 5800 5804
5808 580b 580f 5813 5817 581b 581f 5823
582f 5833 5837 583a 583e 5842 5844 5848
584c 5850 5853 5857 585b 585d 585e 5863
1 5867 586b 586f 5872 5876 587a 587e
5882 5885 5889 588d 5890 5893 5898 589b
589e 58a1 58a2 58a7 58a8 1 58aa 58af
58b3 58b7 58ba 58bf 58c4 58c7 58cb 58cc
58d1 58d4 58d9 58da 58df 58e2 58e7 58e8
58ed 58f0 58f4 58f5 58fa 58fd 5902 5903
5908 590b 590f 5913 5916 5919 591a 591c
591d 5922 5923 5928 592a 592e 5931 5933
5937 5939 5945 5947 5949 594a 594f 5953
5955 5961 5963 5967 5969 596d 5971 5975
5978 5979 597b 597f 5982 5986 5989 598a
598c 598d 5992 5996 599a 599e 59a1 59a2
59a4 59a7 59ab 59af 59b2 59b3 59b5 59b6
59bb 59bf 59c3 59c4 59c8 59cc 59d1 59d5
59d9 59dd 59e0 59e1 59e3 59e6 59e9 59ea
59ef 59f3 59f8 59fb 5a00 5a01 5a06 5a09
5a0d 5a0e 5a13 5a16 5a1b 5a1c 5a21 5a24
5a28 5a29 5a2e 5a31 5a36 5a37 5a3c 5a3f
5a44 5a45 5a4a 5a4d 5a51 5a55 5a59 5a5c
5a5d 5a5f 5a60 5a62 5a63 5a68 5a6c 5a70
5a74 5a78 5a7b 5a7f 5a81 5a85 5a8a 5a8d
5a92 5a93 5a98 5a9b 5a9f 5aa0 5aa5 5aa8
5aad 5aae 5ab3 5ab6 5aba 5abb 5ac0 5ac3
5ac8 5ac9 5ace 5ad1 5ad6 5ad7 5adc 5adf
5ae3 5ae7 5aeb 5aee 5aef 5af1 5af2 5af4
5af5 5afa 5afe 5b02 5b06 5b0a 5b0d 5b11
5b13 5b17 5b1b 5b1e 5b22 5b26 5b2a 5b2d
5b2e 5b30 5b33 5b36 5b37 5b3c 5b40 5b44
5b49 5b4e 5b52 5b56 5b5b 5b5f 5b63 5b66
5b69 5b6d 5b6f 5b73 5b77 5b7a 5b7d 5b81
5b83 5b87 5b8b 5b8e 5b90 5b94 5b98 5b9d
5ba2 5ba6 5baa 5baf 5bb3 5bb7 5bba 5bbd
5bc1 5bc3 5bc7 5bcb 5bce 5bd1 5bd5 5bd7
5bdb 5bdf 5be2 5be4 5be8 5bec 5bef 5bf3
5bf7 5bfa 5bfe 5c01 5c05 5c08 5c09 5c0e
5c11 5c15 5c1b 5c1d 5c21 5c24 5c26 5c2a
5c31 5c35 5c39 5c3c 5c3d 5c3f 5c42 5c45
5c46 5c4b 5c4f 5c53 5c58 5c5a 5c5e 5c62
5c65 5c69 5c6d 5c6f 5c73 5c77 5c7b 5c7e
5c82 5c86 5c88 5c89 5c8e 1 5c92 5c96
5c9a 5c9d 5ca1 5ca5 5ca9 5cad 5cb0 5cb4
5cb8 5cbb 5cbe 5cc3 5cc6 5cc9 5ccc 5ccd
5cd2 5cd3 1 5cd5 5cda 5cde 5ce2 5ce5
5cea 5cef 5cf2 5cf6 5cf7 5cfc 5cff 5d04
5d05 5d0a 5d0d 5d12 5d13 5d18 5d1b 5d1f
5d20 5d25 5d28 5d2d 5d2e 5d33 5d36 5d3a
5d3e 5d41 5d44 5d45 5d47 5d48 5d4d 5d4e
5d53 5d55 5d59 5d5c 5d5e 5d62 5d64 5d70
5d72 5d74 5d75 5d7a 5d7e 5d80 5d8c 5d8e
5d90 5d94 5d98 5d9d 5d9f 5da3 5da7 5daa
5dae 5db2 5db4 5db8 5dbc 5dc0 5dc3 5dc7
5dcb 5dcd 5dce 5dd3 1 5dd7 5ddb 5ddf
5de2 5de6 5dea 5dee 5df2 5df5 5df9 5dfd
5e00 5e03 5e08 5e0b 5e0e 5e11 5e12 5e17
5e18 1 5e1a 5e1f 5e23 5e27 5e2a 5e2f
5e34 5e37 5e3b 5e3c 5e41 5e44 5e49 5e4a
5e4f 5e52 5e57 5e58 5e5d 5e60 5e64 5e65
5e6a 5e6d 5e72 5e73 5e78 5e7b 5e7f 5e83
5e86 5e89 5e8a 5e8c 5e8d 5e92 5e93 5e98
5e9a 5e9e 5ea1 5ea3 5ea7 5ea9 5eb5 5eb7
5eb9 5eba 5ebf 5ec3 5ec5 5ed1 5ed3 5ed5
5ed9 5edd 5ee0 5ee4 5ee7 5ee8 5eed 5ef0
5ef4 5ef8 5efb 5efc 5efe 5f01 5f04 5f05
5f0a 5f0e 5f12 5f16 5f1a 5f1e 5f21 5f25
5f29 5f2c 5f2f 5f34 5f37 5f3a 5f3d 5f3e
5f43 5f44 1 5f46 5f4b 5f4f 5f53 5f56
5f5b 5f60 5f63 5f67 5f68 5f6d 5f6e 5f73
5f75 5f79 5f7c 5f80 5f84 5f88 5f8b 5f8f
5f91 5f95 5f99 5f9d 5fa1 5fa5 5fa8 5fac
5fb0 5fb3 5fb6 5fbb 5fbe 5fc1 5fc4 5fc5
5fca 5fcb 1 5fcd 5fd2 5fd6 5fda 5fdd
5fe2 5fe7 5fea 5fee 5fef 5ff4 5ff5 5ffa
5ffc 6000 6003 6007 600b 600f 6012 6016
6018 601c 6020 6023 6025 6029 602c 6030
6034 6038 603c 6040 6044 6048 604c 6050
6054 6060 6064 6068 606b 606f 6073 6075
6079 607d 6081 6084 6088 608c 608e 608f
6094 1 6098 609c 60a0 60a3 60a7 60ab
60af 60b3 60b6 60ba 60be 60c1 60c4 60c9
60cc 60cf 60d2 60d3 60d8 60d9 1 60db
60e0 60e4 60e8 60eb 60f0 60f5 60f8 60fc
60fd 6102 6105 610a 610b 6110 6113 6118
6119 611e 6121 6125 6126 612b 612e 6133
6134 6139 613c 6140 6144 6147 614a 614b
614d 614e 6153 6154 6159 615b 615f 6162
6164 6168 616a 6176 6178 617a 617b 6180
6184 6186 6192 6194 6198 619b 619f 61a3
61a6 61aa 61ac 61b0 61b4 61b7 61bb 61bd
61c1 61c5 61c8 61c9 61cb 61cf 61d2 61d6
61d9 61da 61dc 61dd 61e2 61e6 61ea 61ed
61ee 61f0 61f3 61f6 61f7 61fc 6200 6204
6207 6208 620a 620e 6211 6215 6218 6219
621b 621c 1 6221 6226 622a 622e 6232
6236 623a 623d 6241 6245 6248 624b 6250
6253 6256 6259 625a 625f 6260 1 6262
6267 626b 626f 6272 6277 627c 627f 6283
6284 6289 628a 628f 6291 6295 6298 629c
62a0 62a4 62a7 62ab 62ad 62b1 62b4 62b8
62bc 62bf 62c0 62c2 62c6 62c9 62cd 62d0
62d1 62d3 62d4 62d9 62dd 62e1 62e5 62e9
62ed 62f0 62f4 62f8 62fb 62fe 6303 6306
6309 630c 630d 6312 6313 1 6315 631a
631e 6322 6325 632a 632f 6332 6336 6337
633c 633d 6342 6344 6348 634b 634f 6353
6357 635a 635e 6360 6364 6367 636b 636f
6372 6373 6375 6378 637b 637c 6381 6385
6388 638c 638e 6392 6396 6399 639a 639c
639f 63a2 63a3 63a8 63ab 63af 63b3 63b6
63b7 63b9 63bc 63bf 63c0 63c5 1 63c8
63cd 63d1 63d5 63d9 63dd 63e1 63e4 63e8
63ec 63ef 63f2 63f7 63fa 63fd 6400 6401
6406 6407 1 6409 640e 6412 6416 6419
641e 6423 6426 642a 642b 6430 6431 6436
6438 643c 643f 6443 6447 644b 644e 6452
6454 6458 645b 645f 6463 6467 646a 646b
646d 6471 6473 6477 647b 647e 6482 6486
648a 648e 6491 6492 6494 6497 649b 649f
64a2 64a3 64a5 64a6 64ab 64ae 64b1 64b4
64b5 64ba 64bd 64c0 64c3 64c4 64c9 64ca
64cc 64d0 64d4 64d8 64db 64dc 64de 64e2
64e5 64e9 64ec 64ed 64ef 64f0 64f5 64f9
64fc 6500 6504 6508 650c 6510 6514 6518
651c 6528 652c 6530 6533 6537 653b 653d
6541 6545 6549 654c 6550 6554 6556 6557
655c 1 6560 6564 6568 656b 656f 6573
6577 657b 657e 6582 6586 6589 658c 6591
6594 6597 659a 659b 65a0 65a1 1 65a3
65a8 65ac 65b0 65b3 65b8 65bd 65c0 65c4
65c5 65ca 65cd 65d2 65d3 65d8 65db 65e0
65e1 65e6 65e9 65ed 65ee 65f3 65f6 65fb
65fc 6601 6604 6608 660c 660f 6612 6613
6615 6616 661b 661c 6621 6623 6627 662a
662c 6630 6632 663e 6640 6642 6643 6648
664c 664e 665a 665c 6660 6664 6667 6668
666a 666d 6670 6671 6676 667a 667e 6682
6686 668a 668d 6691 6695 6698 669b 66a0
66a3 66a6 66a9 66aa 66af 66b0 1 66b2
66b7 66bb 66bf 66c2 66c7 66cc 66cf 66d3
66d4 66d9 66da 66df 66e1 66e5 66e8 66ec
66ef 66f3 66f5 66f9 66fc 66fe 6702 6705
6709 670d 6710 6711 6713 6717 671a 671e
6721 6722 6727 672b 672f 6732 6733 6735
6739 673c 6740 6743 6744 1 6749 674e
6752 6755 6758 6759 675e 6762 6766 676a
676e 6772 6776 677a 677e 6782 6786 678a
678e 6792 6793 6795 6799 679d 67a1 67a4
67a5 67a7 67aa 67ad 67ae 67b3 67b6 67ba
67bd 67be 67c3 67c6 1 67c9 67ce 67d2
67d6 67da 67de 67e2 67e6 67ea 67ee 67f2
67f6 6802 6806 680a 680d 6811 6815 6817
681b 681f 6823 6826 682a 682e 6830 6831
6836 1 683a 683e 6842 6845 6849 684d
6851 6855 6858 685c 6860 6863 6866 686b
686e 6871 6874 6875 687a 687b 1 687d
6882 6886 688a 688d 6892 6897 689a 689e
689f 68a4 68a7 68ac 68ad 68b2 68b5 68ba
68bb 68c0 68c3 68c7 68c8 68cd 68d0 68d5
68d6 68db 68de 68e2 68e6 68e9 68ec 68ed
68ef 68f0 68f5 68f6 68fb 68fd 6901 6904
6906 690a 690c 6918 691a 691c 691d 6922
6926 6928 6934 6936 6938 693c 693f 6943
6947 694b 694f 6952 6953 6955 6958 695c
6960 6963 6964 6966 6967 696c 696f 6972
6975 6976 697b 697e 6981 6984 6985 698a
698b 698d 6991 6995 6999 699d 69a1 69a5
69a9 69ad 69b1 69b5 69b8 69b9 69bb 69bf
69c3 69c7 69cb 69ce 69d2 69d6 69d9 69da
69dc 69e0 69e4 69e7 69e8 69ea 69ee 69f2
69f6 69fa 69fe 6a02 6a05 6a08 6a09 6a0b
6a0f 6a13 6a17 6a1b 6a1f 6a23 6a27 6a2b
6a2f 6a33 6a37 6a3b 6a3f 6a43 6a47 6a4b
6a4f 6a53 6a57 6a5b 6a67 6a6b 6a6f 6a72
6a76 6a7a 6a7c 6a80 6a84 6a88 6a8b 6a8f
6a93 6a95 6a96 6a9b 1 6a9f 6aa3 6aa7
6aaa 6aae 6ab2 6ab6 6aba 6abd 6ac1 6ac5
6ac8 6acb 6ad0 6ad3 6ad6 6ad9 6ada 6adf
6ae0 1 6ae2 6ae7 6aeb 6aef 6af2 6af7
6afc 6aff 6b03 6b04 6b09 6b0c 6b11 6b12
6b17 6b1a 6b1f 6b20 6b25 6b28 6b2c 6b2d
6b32 6b35 6b3a 6b3b 6b40 6b43 6b47 6b4b
6b4e 6b51 6b52 6b54 6b55 6b5a 6b5b 6b60
6b62 6b66 6b69 6b6b 6b6f 6b71 6b7d 6b7f
6b81 6b82 6b87 6b8b 6b8d 6b99 6b9b 6b9f
6ba2 6ba6 6baa 6bae 6bb2 6bb6 6bba 6bbe
6bc2 6bc6 6bca 6bce 6bd2 6bd6 6bd7 6bd9
6bdd 6be1 6be5 6be9 6bea 6bec 6bf0 6bf4
6bf8 6bfc 6c00 6c04 6c07 6c0b 6c0f 6c12
6c15 6c1a 6c1d 6c20 6c23 6c24 6c29 6c2a
1 6c2c 6c31 6c35 6c39 6c3c 6c41 6c46
6c49 6c4d 6c4e 6c53 6c54 6c59 6c5b 6c5f
6c62 6c66 6c6a 6c6e 6c71 6c72 6c74 6c78
6c7a 6c7e 6c81 6c85 6c89 6c8c 6c90 6c94
6c98 6c9b 6c9c 6c9e 6ca1 6ca4 6ca5 6caa
6cae 6cb1 6cb5 6cb7 6cbb 6cbe 6cc2 6cc6
6cca 6ccd 6cd1 6cd5 6cd8 6cdc 6ce0 6ce3
6ce7 6ceb 6cee 6cef 6cf1 6cf5 6cf9 6cfc
6cfd 6cff 6d03 6d07 6d0b 6d0f 6d13 6d17
6d1b 6d1f 6d23 6d27 6d2b 6d2f 6d33 6d37
6d3b 6d3f 6d4b 6d4f 6d54 6d58 6d5b 6d5c
6d61 6d65 6d69 6d6c 6d6f 6d73 6d75 6d79
6d7d 6d80 6d83 6d87 6d89 6d8d 6d91 6d94
6d96 6d9a 6d9e 6da2 6da5 6da9 6dad 6daf
6db0 6db5 1 6db9 6dbd 6dc1 6dc4 6dc8
6dcc 6dd0 6dd4 6dd7 6ddb 6ddf 6de2 6de5
6dea 6ded 6df0 6df3 6df4 6df9 6dfa 1
6dfc 6e01 6e05 6e09 6e0c 6e11 6e16 6e19
6e1d 6e1e 6e23 6e26 6e2b 6e2c 6e31 6e34
6e39 6e3a 6e3f 6e42 6e46 6e47 6e4c 6e4f
6e54 6e55 6e5a 6e5d 6e61 6e65 6e68 6e6b
6e6c 6e6e 6e6f 6e74 6e75 6e7a 6e7c 6e80
6e83 6e85 6e89 6e8b 6e97 6e99 6e9b 6e9c
6ea1 6ea5 6ea7 6eb3 6eb5 6eb9 6ebd 6ec0
6ec1 6ec3 6ec6 6ec9 6eca 6ecf 6ed3 6ed6
6eda 6edc 6ee0 6ee3 6ee5 6ee9 6eed 6ef0
6ef2 6ef6 6efa 6efd 6f01 6f04 6f07 6f08
6f0d 6f11 6f14 6f17 6f18 6f1d 6f21 6f25
6f29 6f2d 6f31 6f35 6f39 6f3d 6f41 6f45
6f49 6f4d 6f51 6f52 6f54 6f58 6f5c 6f60
6f63 6f64 6f66 6f69 6f6c 6f6d 6f72 6f75
6f79 6f7c 6f7d 6f82 6f85 1 6f88 6f8d
6f91 6f95 6f99 6f9d 6fa1 6fa5 6fa9 6fad
6fb1 6fb4 6fb5 6fb7 6fbb 6fbd 6fc1 6fc4
6fc8 6fcb 6fcc 6fd1 6fd4 6fd8 6fdc 6fe0
6fe4 6fe7 6fe8 6fea 6fee 6ff0 6ff4 6ff8
6ffb 6ffe 6fff 7001 7004 7009 700a 700f
7013 7017 701b 701f 7022 7023 7025 7029
702b 702f 7033 7037 703b 703e 703f 7041
7045 7047 704b 704f 7052 7054 7058 705c
705f 7063 7066 7067 706c 706f 7073 7077
707a 707b 707d 7080 7083 7084 7089 708d
7091 7095 7098 709c 70a0 70a3 70a4 70a6
70aa 70ae 70b1 70b2 70b4 70b7 70bb 70bf
70c3 70c7 70cb 70cf 70d3 70d7 70db 70df
70e3 70ef 70f3 70f7 70fa 70fe 7102 7104
7108 710c 7110 7113 7117 711b 711d 711e
7123 1 7127 712b 712f 7132 7136 713a
713e 7142 7145 7149 714d 7150 7153 7158
715b 715e 7161 7162 7167 7168 1 716a
716f 7173 7177 717a 717f 7184 7187 718b
718c 7191 7194 7199 719a 719f 71a2 71a7
71a8 71ad 71b0 71b4 71b5 71ba 71bd 71c2
71c3 71c8 71cb 71cf 71d3 71d6 71d9 71da
71dc 71dd 71e2 71e3 71e8 71ea 71ee 71f1
71f3 71f7 71f9 7205 7207 7209 720a 720f
7213 7215 7221 7223 7225 7229 722d 7231
7235 7239 723d 7241 7245 7249 724d 7259
725d 7261 7264 7268 726c 726e 7272 7276
727a 727d 7281 7285 7287 7288 728d 1
7291 7295 7299 729c 72a0 72a4 72a8 72ac
72af 72b3 72b7 72ba 72bd 72c2 72c5 72c8
72cb 72cc 72d1 72d2 1 72d4 72d9 72dd
72e1 72e4 72e9 72ee 72f1 72f5 72f6 72fb
72fe 7303 7304 7309 730c 7311 7312 7317
731a 731e 731f 7324 7327 732c 732d 7332
7335 7339 733d 7340 7343 7344 7346 7347
734c 734d 7352 7354 7358 735b 735d 7361
7363 736f 7371 7373 7374 7379 737d 737f
738b 738d 738f 7393 7397 739a 739e 73a2
73a6 73a9 73aa 73ac 73af 73b3 73b7 73ba
73bb 73bd 73be 73c3 73c7 73c9 73cd 73d0
73d4 73d7 73db 73df 73e3 73e7 73eb 73ef
73f3 73f7 73fb 73ff 7403 7406 7407 7409
740d 7411 7414 7415 7417 7418 741a 741e
7422 7426 7429 742a 742c 742f 7432 7433
7438 743c 7440 7444 7448 744c 744f 7453
7457 745a 745d 7462 7465 7468 746b 746c
7471 7472 1 7474 7479 747d 7481 7484
7489 748e 7491 7495 7496 749b 749c 74a1
74a3 74a7 74aa 74ae 74b2 74b6 74b9 74bd
74c1 74c3 74c7 74ca 74cd 74ce 74d3 74d7
74db 74df 74e3 74ef 74f3 74f7 74fb 74ff
7503 7507 750b 750f 7513 7517 751b 751f
7523 7527 752b 752f 7533 7537 753b 753f
7543 7547 7553 7557 755c 7560 7563 7564
7569 756d 7571 7574 7577 757b 757d 7581
7585 7588 758b 758f 7591 7595 7599 759c
759e 75a2 75a6 75aa 75ad 75b1 75b5 75b7
75b8 75bd 1 75c1 75c5 75c9 75cc 75d0
75d4 75d8 75dc 75df 75e3 75e7 75ea 75ed
75f2 75f5 75f8 75fb 75fc 7601 7602 1
7604 7609 760d 7611 7614 7619 761e 7621
7625 7626 762b 762e 7633 7634 7639 763c
7641 7642 7647 764a 764e 764f 7654 7657
765c 765d 7662 7665 7669 766d 7670 7673
7674 7676 7677 767c 767d 7682 7684 7688
768b 768d 7691 7693 769f 76a1 76a3 76a4
76a9 76ad 76af 76bb 76bd 76bf 76c3 76c7
76ca 76ce 76d2 76d6 76d7 76d9 76dd 76e1
76e5 76e9 76ed 76f1 76f4 76f8 76fc 76ff
7702 7707 770a 770d 7710 7711 7716 7717
1 7719 771e 7722 7726 7729 772e 7733
7736 773a 773b 7740 7741 7746 7748 774c
774f 7753 7757 775b 775e 775f 7761 7765
7767 776b 776e 7772 7776 7779 777a 777c
7780 7783 7787 778a 778b 778d 778e 7793
7797 779a 779e 77a2 77a6 77aa 77ae 77b2
77b6 77ba 77be 77c2 77c6 77ca 77ce 77da
77de 77e2 77e5 77e9 77ed 77ef 77f3 77f7
77fb 77fe 7802 7806 7808 7809 780e 1
7812 7816 781a 781d 7821 7825 7829 782d
7830 7834 7838 783b 783e 7843 7846 7849
784c 784d 7852 7853 1 7855 785a 785e
7862 7865 786a 786f 7872 7876 7877 787c
787f 7884 7885 788a 788d 7892 7893 7898
789b 789f 78a0 78a5 78a8 78ad 78ae 78b3
78b6 78ba 78be 78c1 78c4 78c5 78c7 78c8
78cd 78ce 78d3 78d5 78d9 78dc 78de 78e2
78e4 78f0 78f2 78f4 78f5 78fa 78fe 7900
790c 790e 7912 7916 7919 791a 791c 791f
7922 7923 7928 792c 7930 7934 7938 793c
793f 7943 7947 794a 794d 7952 7955 7958
795b 795c 7961 7962 1 7964 7969 796d
7971 7974 7979 797e 7981 7985 7986 798b
798c 7991 7993 7997 799a 799e 79a2 79a6
79a9 79ad 79af 79b3 79b6 79ba 79be 79c2
79c5 79c6 79c8 79cc 79d0 79d4 79d8 79db
79dc 79de 79e2 79e6 79ea 79ed 79ee 79f0
79f4 79f7 79fb 79fe 79ff 7a01 7a02 7a07
7a0b 7a0f 7a12 7a13 7a15 7a19 7a1c 7a20
7a23 7a24 7a29 7a2d 7a31 7a34 7a35 7a37
7a3b 7a3e 7a42 7a45 7a46 1 7a4b 7a50
7a54 7a55 7a59 7a5d 7a61 7a65 7a69 7a6d
7a71 7a75 7a79 7a7d 7a81 7a85 7a89 7a95
7a99 7a9d 7aa0 7aa4 7aa8 7aaa 7aae 7ab2
7ab6 7ab9 7abd 7ac1 7ac3 7ac4 7ac9 1
7acd 7ad1 7ad5 7ad8 7adc 7ae0 7ae4 7ae8
7aeb 7aef 7af3 7af6 7af9 7afe 7b01 7b04
7b07 7b08 7b0d 7b0e 1 7b10 7b15 7b19
7b1d 7b20 7b25 7b2a 7b2d 7b31 7b32 7b37
7b3a 7b3f 7b40 7b45 7b48 7b4d 7b4e 7b53
7b56 7b5a 7b5b 7b60 7b63 7b68 7b69 7b6e
7b71 7b75 7b79 7b7c 7b7f 7b80 7b82 7b83
7b88 7b89 7b8e 7b90 7b94 7b97 7b99 7b9d
7b9f 7bab 7bad 7baf 7bb0 7bb5 7bb9 7bbb
7bc7 7bc9 7bcd 7bd0 7bd1 7bd6 7bd9 7bdd
7be1 7be5 7be7 7beb 7bee 7bf2 7bf6 7bf9
7bfa 7bfc 7bff 7c02 7c03 7c08 7c0c 7c0f
7c12 7c13 7c18 7c1c 7c20 7c24 7c28 7c2c
7c30 7c34 7c38 7c3c 7c40 7c44 7c48 7c4c
7c4d 7c4f 7c53 7c57 7c5b 7c5e 7c5f 7c61
7c64 7c67 7c68 7c6d 7c70 7c74 7c77 7c78
7c7d 7c80 1 7c83 7c88 7c8c 7c90 7c94
7c98 7c9c 7ca0 7ca4 7ca8 7cac 7cb0 7cb4
7cb8 7cc4 7cc8 7ccc 7ccf 7cd3 7cd7 7cd9
7cdd 7ce1 7ce5 7ce8 7cec 7cf0 7cf2 7cf3
7cf8 1 7cfc 7d00 7d04 7d07 7d0b 7d0f
7d13 7d17 7d1a 7d1e 7d22 7d25 7d28 7d2d
7d30 7d33 7d36 7d37 7d3c 7d3d 1 7d3f
7d44 7d48 7d4c 7d4f 7d54 7d59 7d5c 7d60
7d61 7d66 7d69 7d6e 7d6f 7d74 7d77 7d7c
7d7d 7d82 7d85 7d89 7d8a 7d8f 7d92 7d97
7d98 7d9d 7da0 7da4 7da8 7dab 7dae 7daf
7db1 7db2 7db7 7db8 7dbd 7dbf 7dc3 7dc6
7dc8 7dcc 7dce 7dda 7ddc 7dde 7ddf 7de4
7de8 7dea 7df6 7df8 7dfc 7e00 7e04 7e07
7e08 7e0a 7e0d 7e11 7e15 7e18 7e19 7e1b
7e1c 7e21 7e24 7e28 7e2c 7e2f 7e30 7e32
7e33 7e38 7e3c 7e3e 7e42 7e46 7e4a 7e4d
7e4e 7e50 7e53 7e57 7e5b 7e5e 7e5f 7e61
7e62 7e67 7e6b 7e6d 7e71 7e75 7e78 7e7c
7e7f 7e83 7e87 7e8b 7e8f 7e93 7e97 7e98
7e9a 7e9d 7e9e 7ea0 7ea3 7ea7 7eab 7eaf
7eb0 7eb2 7eb5 7eb6 7eb8 7eb9 7ebe 7ec1
7ec4 7ec7 7ec8 7ecd 7ece 7ed0 7ed4 7ed8
7edc 7ee0 7ee3 7ee4 7ee6 7ee9 7eed 7ef1
7ef4 7ef5 7ef7 7ef8 7efd 7f01 7f05 7f09
7f0c 7f0d 7f0f 7f13 7f16 7f1a 7f1d 7f1e
7f20 7f21 7f26 7f2a 7f2e 7f32 7f35 7f36
7f38 7f3b 7f3f 7f43 7f46 7f47 7f49 7f4a
7f4f 7f52 7f56 7f5a 7f5d 7f5e 7f60 7f61
7f66 7f6a 7f6c 7f70 7f74 7f78 7f7b 7f7c
7f7e 7f82 7f84 7f88 7f8c 7f8f 7f93 7f97
7f9b 7f9f 7fa3 7fa7 7fab 7faf 7fb3 7fb6
7fb7 7fb9 7fbd 7fc1 7fc5 7fc9 7fcd 7fd1
7fd2 7fd4 7fd7 7fd8 7fda 7fdd 7fe1 7fe5
7fe9 7fea 7fec 7fef 7ff0 7ff2 7ff3 7ff8
7ffb 7ffe 8001 8002 8007 8008 800a 800e
8012 8016 801a 801d 8021 8025 8028 8029
802b 802f 8033 8036 8037 8039 803d 8041
8045 8049 804d 8051 8055 8059 805c 805d
805f 8063 8067 806a 806b 806d 806e 8070
8074 8078 807b 807f 8083 8087 808b 808f
8093 8097 809b 809f 80a3 80a7 80ab 80af
80b0 80b2 80b6 80b8 80bc 80bf 80c1 80c5
80c8 80cc 80d0 80d4 80d8 80db 80dc 80de
80e2 80e6 80ea 80ee 80f2 80f6 80fa 80fe
8102 8106 810a 810e 8112 8116 811a 811e
8122 8126 812a 812e 8132 8136 813a 813e
8142 8146 814a 814e 8151 8152 8154 8158
815c 815f 8160 8162 8163 8165 8169 816d
8171 8175 8178 8179 817b 817f 8183 8187
818b 818e 818f 8191 8194 8198 819c 819f
81a0 81a2 81a3 81a8 81ac 81b0 81b4 81b8
81bc 81c0 81cc 81d0 81d4 81d7 81db 81df
81e1 81e5 81e9 81ed 81f0 81f4 81f8 81fa
81fb 8200 1 8204 8208 820c 820f 8213
8217 821b 821f 8222 8226 822a 822d 8230
8235 8238 823b 823e 823f 8244 8245 1
8247 824c 8250 8254 8257 825c 8261 8264
8268 8269 826e 8271 8276 8277 827c 827f
8284 8285 828a 828d 8291 8292 8297 829a
829f 82a0 82a5 82a8 82ac 82b0 82b3 82b6
82b7 82b9 82ba 82bf 82c0 82c5 82c7 82cb
82ce 82d0 82d4 82d6 82e2 82e4 82e6 82e7
82ec 82f0 82f2 82fe 8300 8304 8308 830c
8310 8314 8318 831c 8320 8324 8330 8334
8338 833b 833f 8343 8345 8349 834d 8351
8354 8358 835c 835e 835f 8364 1 8368
836c 8370 8373 8377 837b 837f 8383 8386
838a 838e 8391 8394 8399 839c 839f 83a2
83a3 83a8 83a9 1 83ab 83b0 83b4 83b8
83bb 83c0 83c5 83c8 83cc 83cd 83d2 83d5
83da 83db 83e0 83e3 83e8 83e9 83ee 83f1
83f5 83f6 83fb 83fe 8403 8404 8409 840c
8410 8414 8417 841a 841b 841d 841e 8423
8424 8429 842b 842f 8432 8434 8438 843a
8446 8448 844a 844b 8450 8454 8456 8462
8464 8468 846c 8470 8474 8478 847c 8480
8484 8488 848c 8490 8494 8498 849c 84a0
84a4 84a8 84ac 84b0 84bc 84c0 84c5 84c9
84cc 84cd 84d2 84d6 84da 84dd 84e0 84e4
84e6 84ea 84ee 84f1 84f4 84f8 84fa 84fe
8502 8505 8507 850b 850f 8513 8516 851a
851e 8520 8521 8526 1 852a 852e 8532
8535 8539 853d 8541 8545 8548 854c 8550
8553 8556 855b 855e 8561 8564 8565 856a
856b 1 856d 8572 8576 857a 857d 8582
8587 858a 858e 858f 8594 8597 859c 859d
85a2 85a5 85aa 85ab 85b0 85b3 85b7 85b8
85bd 85c0 85c5 85c6 85cb 85ce 85d2 85d6
85d9 85dc 85dd 85df 85e0 85e5 85e6 85eb
85ed 85f1 85f4 85f6 85fa 85fc 8608 860a
860c 860d 8612 8616 8618 8624 8626 862a
862e 8631 8635 8638 863c 863f 8640 8645
8648 864c 864f 8653 8657 865b 865f 8663
8667 866b 866f 8673 8676 867a 867e 8681
8682 8684 8685 8687 868b 868f 8693 8696
8697 8699 869c 869f 86a0 86a5 86a9 86ad
86b1 86b5 86b9 86bc 86c0 86c4 86c7 86ca
86cf 86d2 86d5 86d8 86d9 86de 86df 1
86e1 86e6 86ea 86ee 86f1 86f6 86fb 86fe
8702 8703 8708 8709 870e 8710 8714 8717
871b 871f 8723 8726 8727 8729 872d 872f
8733 8736 8738 873c 873f 8741 8745 8749
874c 8750 8754 8758 875b 875c 875e 8762
8766 8769 876d 876f 8773 8777 877b 877f
8783 8784 8786 8789 878a 878c 878f 8793
8797 879b 879c 879e 87a1 87a2 87a4 87a5
87aa 87ad 87b0 87b3 87b4 87b9 87bc 87bf
87c2 87c3 87c8 87c9 87cb 87cf 87d1 87d5
87d9 87dc 87e0 87e4 87e8 87ec 87f0 87f4
87f8 87fc 8800 8804 8808 880c 8810 8814
8818 881c 8820 8824 8828 882c 8830 8834
8838 883c 8840 8844 8848 884b 884c 884e
8852 8856 8859 885a 885c 885d 885f 8863
8867 886b 886f 8873 8877 887a 887e 8882
8885 8888 888d 8890 8893 8896 8897 889c
889d 1 889f 88a4 88a8 88ac 88af 88b4
88b9 88bc 88c0 88c1 88c6 88c7 88cc 88ce
88d2 88d5 88d9 88dd 88e1 88e4 88e5 88e7
88eb 88ef 88f1 88f5 88f9 88fc 88fd 88ff
8903 8906 890a 890d 890e 8910 8911 8916
891a 891e 8921 8922 8924 8927 892a 892b
8930 8933 8937 893b 893e 893f 8941 8944
8947 8948 894d 1 8950 8955 8959 895d
8961 8965 8969 896c 8970 8974 8977 897a
897f 8982 8985 8988 8989 898e 898f 1
8991 8996 899a 899e 89a1 89a6 89ab 89ae
89b2 89b3 89b8 89b9 89be 89c0 89c4 89c7
89cb 89cf 89d3 89d6 89da 89dc 89e0 89e3
89e7 89eb 89ef 89f3 89f7 89fb 89ff 8a03
8a07 8a0b 8a0f 8a1b 8a1f 8a24 8a28 8a2b
8a2c 8a31 8a35 8a39 8a3c 8a3f 8a43 8a45
8a49 8a4d 8a50 8a53 8a57 8a59 8a5d 8a61
8a64 8a66 8a6a 8a6e 8a72 8a75 8a79 8a7d
8a7f 8a80 8a85 1 8a89 8a8d 8a91 8a94
8a98 8a9c 8aa0 8aa4 8aa7 8aab 8aaf 8ab2
8ab5 8aba 8abd 8ac0 8ac3 8ac4 8ac9 8aca
1 8acc 8ad1 8ad5 8ad9 8adc 8ae1 8ae6
8ae9 8aed 8aee 8af3 8af6 8afb 8afc 8b01
8b04 8b09 8b0a 8b0f 8b12 8b16 8b17 8b1c
8b1f 8b24 8b25 8b2a 8b2d 8b31 8b35 8b38
8b3b 8b3c 8b3e 8b3f 8b44 8b45 8b4a 8b4c
8b50 8b53 8b55 8b59 8b5b 8b67 8b69 8b6b
8b6c 8b71 8b75 8b77 8b83 8b85 8b89 8b8d
8b91 8b95 8b99 8b9d 8ba1 8ba5 8ba9 8bad
8bb1 8bbd 8bc1 8bc6 8bca 8bcd 8bce 8bd3
8bd7 8bdb 8bde 8be1 8be5 8be7 8beb 8bef
8bf2 8bf5 8bf9 8bfb 8bff 8c03 8c06 8c08
8c0c 8c10 8c14 8c17 8c1b 8c1f 8c21 8c22
8c27 1 8c2b 8c2f 8c33 8c36 8c3a 8c3e
8c42 8c46 8c49 8c4d 8c51 8c54 8c57 8c5c
8c5f 8c62 8c65 8c66 8c6b 8c6c 1 8c6e
8c73 8c77 8c7b 8c7e 8c83 8c88 8c8b 8c8f
8c90 8c95 8c98 8c9d 8c9e 8ca3 8ca6 8cab
8cac 8cb1 8cb4 8cb8 8cb9 8cbe 8cc1 8cc6
8cc7 8ccc 8ccf 8cd3 8cd7 8cda 8cdd 8cde
8ce0 8ce1 8ce6 8ce7 8cec 8cee 8cf2 8cf5
8cf7 8cfb 8cfd 8d09 8d0b 8d0d 8d0e 8d13
8d17 8d19 8d25 8d27 8d29 8d2d 8d31 8d34
8d38 8d3c 8d40 8d41 8d43 8d47 8d4b 8d4f
8d53 8d57 8d5b 8d5e 8d62 8d66 8d69 8d6c
8d71 8d74 8d77 8d7a 8d7b 8d80 8d81 1
8d83 8d88 8d8c 8d90 8d93 8d98 8d9d 8da0
8da4 8da5 8daa 8dab 8db0 8db2 8db6 8db9
8dbd 8dc1 8dc5 8dc8 8dc9 8dcb 8dcf 8dd1
8dd5 8dd9 8ddd 8de1 8de5 8de9 8ded 8df1
8df5 8df9 8dfd 8e01 8e05 8e09 8e0d 8e11
8e15 8e19 8e1d 8e21 8e25 8e29 8e2d 8e31
8e35 8e39 8e3d 8e41 8e45 8e49 8e4d 8e51
8e55 8e61 8e65 8e69 8e6c 8e70 8e74 8e76
8e7a 8e7e 8e82 8e85 8e89 8e8d 8e8f 8e90
8e95 1 8e99 8e9d 8ea1 8ea4 8ea8 8eac
8eb0 8eb4 8eb7 8ebb 8ebf 8ec2 8ec5 8eca
8ecd 8ed0 8ed3 8ed4 8ed9 8eda 1 8edc
8ee1 8ee5 8ee9 8eec 8ef1 8ef6 8ef9 8efd
8efe 8f03 8f06 8f0b 8f0c 8f11 8f14 8f19
8f1a 8f1f 8f22 8f26 8f27 8f2c 8f2f 8f34
8f35 8f3a 8f3d 8f41 8f45 8f48 8f4b 8f4c
8f4e 8f4f 8f54 8f55 8f5a 8f5c 8f60 8f63
8f65 8f69 8f6b 8f77 8f79 8f7b 8f7c 8f81
8f85 8f87 8f93 8f95 8f99 8f9d 8fa0 8fa4
8fa7 8fab 8fae 8faf 8fb4 8fb7 8fba 8fbb
8fc0 8fc4 8fc8 8fcc 8fd0 8fd4 8fd7 8fdb
8fdf 8fe2 8fe5 8fea 8fed 8ff0 8ff3 8ff4
8ff9 8ffa 1 8ffc 9001 9005 9009 900c
9011 9016 9019 901d 901e 9023 9024 9029
902b 902f 9032 9036 903a 903e 9041 9045
9047 904b 904e 9052 9056 9059 905d 9061
9062 9064 9067 906a 906b 9070 9074 9078
907b 907e 9082 9086 908a 908e 9092 9096
9099 909d 90a1 90a4 90a7 90ac 90af 90b2
90b5 90b6 90bb 90bc 1 90be 90c3 90c7
90cb 90ce 90d3 90d8 90db 90df 90e0 90e5
90e6 90eb 90ed 90f1 90f4 90f8 90fc 9100
9103 9107 9109 910d 9110 9112 9116 911a
911d 911f 9123 9126 912a 912e 9132 9136
913a 913e 9142 9146 914a 914e 9152 9156
9159 915d 9161 9165 9168 916c 9170 9174
9178 917c 917d 917f 9183 9187 918b 918f
9193 9197 919a 919e 91a2 91a5 91a8 91ad
91b0 91b3 91b6 91b7 91bc 91bd 1 91bf
91c4 91c8 91cc 91cf 91d4 91d9 91dc 91e0
91e1 91e6 91e7 91ec 91ee 91f2 91f5 91f9
91fd 9201 9204 9208 920c 9210 9213 9217
921b 921e 9221 9226 9229 922c 922f 9230
9235 9236 1 9238 923d 9241 9245 9248
924d 9252 9255 9259 925a 925f 9262 9267
9268 926d 9270 9275 9276 927b 927e 9282
9286 9289 928a 928f 9290 9295 9297 929b
929e 92a2 92a6 92aa 92ad 92b1 92b3 92b7
92b9 92c5 92c9 92cb 92cc 92d5 
2a06
2
0 1 a 6 17 1b 22 :3 6
19 1d 24 :3 6 1b 1f 26 :3 6
1c 20 27 :3 6 13 :3 6 13 :3 6
1a :3 6 14 :3 6 14 18 1f :3 6
e 12 19 :2 6 1 3 a :2 1
4 :2 e 1d e :2 4 :2 e 1d e
:2 4 :2 15 24 15 :2 4 :2 f 1e f
:2 4 12 1b 1a :2 12 :2 4 11 1a
19 :2 11 :2 4 15 1e 1d :2 15 :2 4
17 20 1f :2 17 :2 4 14 1d 1c
:2 14 :2 4 10 19 18 :2 10 :2 4 18
21 20 :2 18 :2 4 12 1b 1a :2 12
:2 4 e 17 16 :2 e :2 4 14 1d
1c :2 14 :2 4 11 1a 19 :2 11 :2 4
11 1a 19 :2 11 :2 4 16 1f 1e
:2 16 :2 4 :3 13 :2 4 :3 11 :2 4 :3 12 :2 4
:3 12 :2 4 :3 13 :2 4 :3 f :2 4 :3 12 :2 4
:3 13 :2 4 :3 14 :2 4 :3 15 :2 4 :3 9 :2 4
:3 9 :2 4 :3 e :2 4 f 18 17 :2 f
:2 4 f 18 17 :2 f :2 4 :2 12 21
12 :2 4 :2 f 1e f :2 4 :2 16 25
16 :2 4 :2 11 20 11 :2 4 :3 10 :2 4
:3 15 :2 4 :2 17 26 17 :2 4 :2 13 22
13 :2 4 :2 12 21 12 :2 4 :2 12 21
12 :2 4 :2 14 23 14 :2 4 :2 15 24
15 :2 4 :2 12 21 12 :2 4 :2 d 1c
d :2 4 :2 11 20 11 :2 4 :2 13 22
13 :2 4 e 17 16 :2 e :2 4 d
16 15 :2 d :2 4 f 18 17 :2 f
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :2 c 1b c :2 4 :2 14 23 14
:2 4 :2 13 22 13 :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 13 22 13 :2 4 :2 10 1f 10
:2 4 :2 e 1d e :2 4 :2 10 1f 10
:2 4 :2 13 22 13 :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 c 1b c :2 4 :2 b 1a b
:2 4 :2 13 22 13 :2 4 :2 a 19 a
:2 4 :2 12 21 12 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 :2 c 1b c
:2 4 :2 10 1f 10 :2 4 :2 f 1e f
:2 4 :2 f 1e f :2 4 :2 10 1f 10
:2 4 14 1d 1c :2 14 :2 4 14 1d
1c :2 14 :2 4 :2 17 26 17 :2 4 17
20 1f :2 17 :2 4 :2 13 22 13 :2 4
:2 14 23 14 :2 4 :2 f 1e f :2 4
:2 f 19 f :2 4 :2 f 19 f :2 4
:2 10 1a 10 :2 4 :2 10 1a 10 :2 4
:2 11 1b 11 :2 4 :2 11 1b 11 :2 4
:2 12 1c 12 :2 4 :2 12 1c 12 :2 4
9 12 11 :2 9 :2 4 :3 f :2 4 :3 e
:2 4 :3 e 4 7 e 0 :2 7 20
36 3f 4c 5b 68 f 10 1d
26 32 40 11 15 19 13 a
:6 7 11 1a :3 11 :2 7 11 1a :3 11
:2 7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 58 5e 61
:2 58 6f 89 8 :2 6f d 10 :2 6f
1e 21 :2 6f b e :2 6f 13 16
:2 6f 1b 1e :2 6f 2e 31 :2 6f b
e :2 6f 13 16 1f 26 2b 2e
:2 26 40 43 :2 26 48 :2 1f 51 :2 16
:2 6f b e :2 6f 13 16 1f 26
2b 2e :2 26 41 44 :2 26 49 :2 1f
52 :2 16 :2 6f b e :2 6f 13 16
1f 27 :2 1f 36 :2 16 :2 6f b e
:2 6f 13 16 1f 27 :2 1f 36 :2 16
:2 6f b e :2 6f 13 16 1f 27
:2 1f 3d :2 16 :2 6f b e :2 6f 13
16 1f 27 :2 1f 37 :2 16 :2 6f b
e :2 6f 13 16 :2 6f 1b 1e :2 6f
29 2c :2 6f b e :2 6f 13 16
:2 6f 1b 1e :2 6f 23 26 :2 6f 2b
2e :2 6f :2 7 4e :2 4 7 :2 11 23
:2 2d 39 3c 50 53 54 :2 50 :2 23
:3 7 :2 d 12 1e 62 65 :2 1e :2 7
57 :3 4 13 :2 4 14 :2 4 12 :2 4
15 :2 4 11 4 e 11 24 27
34 37 43 46 11 14 11 14
7 a 7 a 16 19 c 21
30 3e :4 7 15 c 21 d 10
24 :2 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
57 5a 5b :2 57 :2 29 :3 d :2 13 18
24 68 6b :2 24 78 7b :2 24 7f
82 :2 24 8e 91 :2 24 99 9c :2 24
a8 ab b2 bb be :2 ab :2 24 :2 d
5e :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a 7 11 24
3b 47 54 63 a 1a 25 2f
37 3f 14 23 32 44 53 61
6e 80 14 28 3a 4a 5b a
12 19 34 3c 43 5f 69 a
18 26 34 a 1a 2a 3a a
1d 26 f 24 35 43 4c 58
a 1c 27 2f 38 40 a 1b
2b 3a 48 a 14 1d a 10
16 22 a 16 23 2f a 18
27 35 a 1a 25 f 10 24
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 5a
5d 5e :2 5a :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 7b 7e :2 27 82 85
:2 27 91 94 :2 27 9c 9f :2 27 ab
ae b5 be c1 :2 ae :2 27 :2 10 61
:2 d :2 a :4 16 :2 a 7 :3 35 b :2 14
1f 1d :2 28 :2 1d a 14 20 2b
3b 45 50 65 6f d 1b 1f
2c 3d 4b 59 5e 67 76 12
20 2d 38 46 55 61 6d d
1d 2a 39 43 53 5a 12 20
2d :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5d 60 61 :2 5d :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 94 97 :2 2a 9f a2 :2 2a
ae b1 b8 c1 c4 :2 b1 :2 2a :2 13
64 :2 10 :2 d :4 19 :2 d a :3 38 e
:2 17 22 20 :2 2b :2 20 :2 d 15 d
10 :2 1a 2c :2 36 42 45 59 5c
5d :2 59 :2 2c :3 10 :2 16 1b 27 6b
6e :2 27 :2 10 60 :3 d 14 :2 1d d
3b :2 a e 15 10 1d :2 15 21
:2 2a :2 e d 43 41 :2 4c :2 41 d
15 d 10 :2 1a 2c :2 36 42 45
59 5c 5d :2 59 :2 2c :3 10 :2 16 1b
27 6b 6e :2 27 :2 10 60 :3 d 14
:2 1d d 61 :3 a 1b :2 a 1c a
e :2 19 21 30 40 :2 e 44 46
:2 44 d 4e :2 59 10 20 2f :2 4e
33 36 :2 33 4d :3 d 15 d 10
:2 1a 2c :2 36 42 45 59 5c 5d
:2 59 :2 2c :3 10 :2 16 1b 27 6b 6e
:2 27 :2 10 60 :3 d 14 :2 1d d 39
:2 a :4 f e d 2d 36 40 :2 2d
43 45 4e 5d :2 45 :2 2d 2c 64
61 10 17 :2 64 :2 61 2b :3 d 15
d 10 :2 1a 2c :2 36 42 45 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 :2 10 60 :3 d 14 :2 1d
d 1b :2 a e :2 19 21 30 3e
:2 e 42 45 :2 42 d 4c :2 57 5f
12 21 :2 4c 25 28 :2 25 4b :2 d
10 19 29 :2 10 2c 2e :2 2c 13
:2 1e 26 35 43 :2 13 47 4a :2 47
1d 28 35 3f 4a 4f 58 69
7b 1b 1c 29 1a 25 2d 34
:2 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :3 4c 17 :2 20
2b 29 :2 34 :2 29 16 20 2b 38
40 47 5f 6a 7e 1e :2 19 :2 22
2e 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 69 6c 6d
:2 69 :2 3b :3 1f :2 25 2a 36 7a 7d
:2 36 8a 8d :2 36 91 94 :2 36 a0
a3 :2 36 ab ae :2 36 ba bd c4
cd d0 :2 bd :2 36 :2 1f 70 :2 1c :2 19
:4 25 :2 19 16 :4 44 :2 13 16 :2 21 29
38 48 :2 16 4c 4e :2 4c 16 28
16 50 :2 13 4c 1d 28 35 3f
4a 4f 58 68 7a 1b 1c 29
1a 25 2d 34 :2 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9d a0 :2 33
a8 ab :2 33 b7 ba c1 ca cd
:2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16
13 :3 10 17 :2 20 2b 29 :2 34 :2 29
16 20 2b 38 40 47 60 6b
7f 1e :2 19 :2 22 2e 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 69 6c 6d :2 69 :2 3b :3 1f :2 25
2a 36 7a 7d :2 36 8a 8d :2 36
91 94 :2 36 a0 a3 :2 36 ab ae
:2 36 ba bd c4 cd d0 :2 bd :2 36
:2 1f 70 :2 1c :2 19 :4 25 :2 19 16 :4 44
:3 13 21 13 :4 10 13 1c 29 :2 13
2e 2c :2 37 :2 2c 1d 29 37 46
55 65 76 1c 29 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :4 3d 1d 29
39 48 59 69 7c 1c 29 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 69 6a :2 66 :2 38 :3 1c :2 22
27 33 77 7a :2 33 87 8a :2 33
8e 91 :2 33 9d a0 :2 33 a8 ab
:2 33 b7 ba c1 ca cd :2 ba :2 33
:2 1c 6d :2 19 :2 16 :4 22 :2 16 13 :7 10
14 :2 1d 28 26 :2 31 :2 26 :2 13 21
2b :2 21 13 41 :2 10 30 10 1e
:2 10 1b 10 13 1c 29 :2 13 2e
2c :2 37 :2 2c 4c 16 23 :2 4c 28
26 :2 31 :2 26 :2 13 1d 23 32 1b
1c 29 1a 2b 33 3a 54 5c
63 :2 16 :2 1f 2b 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 69 6a :2 66 :2 38 :3 1c :2 22 27
33 77 7a :2 33 87 8a :2 33 8e
91 :2 33 9d a0 :2 33 a8 ab :2 33
b7 ba c1 ca cd :2 ba :2 33 :2 1c
6d :2 19 :2 16 :4 22 :2 16 13 :4 45 :2 10
13 :2 1e 26 35 43 :2 13 47 4a
:2 47 1d 28 35 3f 4a 4f 58
69 7b 1b 1c 29 1a 25 2d
34 :2 16 :2 1f 2b 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 69 6a :2 66 :2 38 :3 1c :2 22 27
33 77 7a :2 33 87 8a :2 33 8e
91 :2 33 9d a0 :2 33 a8 ab :2 33
b7 ba c1 ca cd :2 ba :2 33 :2 1c
6d :2 19 :2 16 :4 22 :2 16 13 :3 4c 17
:2 20 2b 29 :2 34 :2 29 16 20 2b
38 40 47 5f 6a 7e 1e :2 19
:2 22 2e 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 69 6c
6d :2 69 :2 3b :3 1f :2 25 2a 36 7a
7d :2 36 8a 8d :2 36 91 94 :2 36
a0 a3 :2 36 ab ae :2 36 ba bd
c4 cd d0 :2 bd :2 36 :2 1f 70 :2 1c
:2 19 :4 25 :2 19 16 :3 44 16 21 2a
33 :2 21 36 38 :2 21 16 44 :2 13
16 1f 2c :2 16 31 2f :2 3a :2 2f
4f 19 26 :2 4f 2b 29 :2 34 :2 29
:3 16 28 :2 16 24 16 48 :2 13 4c
16 1f 2e :2 16 31 33 :2 31 16
24 16 20 30 40 29 1f 2c
3d 47 1d 31 3c 44 4b :2 19
:2 22 2e 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 69 6c
6d :2 69 :2 3b :3 1f :2 25 2a 36 7a
7d :2 36 8a 8d :2 36 91 94 :2 36
a0 a3 :2 36 ab ae :2 36 ba bd
c4 cd d0 :2 bd :2 36 :2 1f 70 :2 1c
:2 19 :4 25 :2 19 16 :3 35 19 22 2e
:2 19 31 33 :2 31 23 33 43 2c
22 2f 40 4a 20 28 2f 43
4b 52 :2 1c :2 25 31 1c 19 21
1f :2 28 34 1f 2f :2 1c :2 21 1f
:2 28 34 1f 22 :2 2c 3e :2 48 54
58 6c 6f 70 :2 6c :2 3e :3 22 :2 28
2d 39 7d 80 :2 39 8d 90 :2 39
94 97 :2 39 a3 a6 :2 39 ae b1
:2 39 bd c0 c7 d0 d3 :2 c0 :2 39
:2 22 73 :2 1f :2 1c :4 28 :2 1c 19 :4 35
:2 16 19 22 2e :2 19 31 33 :2 31
19 21 19 1c :2 26 38 :2 42 4e
51 65 68 69 :2 65 :2 38 :3 1c :2 22
27 33 77 7a :2 33 :2 1c 6c :3 19
20 :2 29 19 35 :2 16 35 :2 13 1d
28 35 3f 4a 4f 58 68 7a
1b 1c 29 1a 25 2d 34 :2 16
:2 1f 2b 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 66 69
6a :2 66 :2 38 :3 1c :2 22 27 33 77
7a :2 33 87 8a :2 33 8e 91 :2 33
9d a0 :2 33 a8 ab :2 33 b7 ba
c1 ca cd :2 ba :2 33 :2 1c 6d :2 19
:2 16 :4 22 :2 16 13 :3 10 17 :2 20 2b
29 :2 34 :2 29 16 20 2b 38 40
47 60 6b 7f 1e :2 19 :2 22 2e
19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 69 6c 6d :2 69
:2 3b :3 1f :2 25 2a 36 7a 7d :2 36
8a 8d :2 36 91 94 :2 36 a0 a3
:2 36 ab ae :2 36 ba bd c4 cd
d0 :2 bd :2 36 :2 1f 70 :2 1c :2 19 :4 25
:2 19 16 :4 44 :2 13 16 1f 2e :2 16
31 33 :2 31 3a 43 50 :2 3a 55
53 :2 5e :2 53 1c 25 32 :2 1c 37
35 :2 40 :2 35 :2 3a 39 :3 16 27 :2 16
24 16 55 :2 13 :4 10 14 1d 26
:2 14 29 2b :2 29 31 3c 3e :2 3c
:2 14 13 46 16 23 :2 46 28 26
:2 31 :2 26 46 16 23 :2 46 28 26
:2 31 :2 26 :2 46 45 :3 13 21 34 42
51 5a :2 21 13 46 :3 10 1e 10
1a 2a 3a 23 34 19 1c 29
3a 3d 47 17 1a 23 34 19
1c 29 3a 3d 51 54 18 20
27 40 48 4f 52 67 6f 76
90 98 9f a2 :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 66 67 :2 63 :2 35
:3 19 :2 1f 24 30 74 77 :2 30 84
87 :2 30 8b 8e :2 30 9a 9d :2 30
a5 a8 :2 30 b4 b7 be c7 ca
:2 b7 :2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13
10 :3 d 13 1c 28 :2 13 2b 2d
:2 2b 13 1b 13 16 :2 20 32 :2 3c
48 4b 5f 62 63 :2 5f :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d :2 16 66
:3 13 1a :2 23 13 2f :3 10 1e 31
3f 4a 58 67 24 34 3f 4b
57 24 2d 3a :2 24 3e :2 1e 10
13 1c 28 :2 13 2b 2d :2 2b 13
21 2b :2 21 13 2f 13 1b 13
16 :2 20 32 :2 3c 48 4b 5f 62
63 :2 5f :2 32 :3 16 :2 1c 21 2d 71
74 :2 2d :2 16 66 :3 13 1a 23 2f
:2 1a 13 :4 10 :4 d a 2b 11 1a
26 :2 11 2c 29 35 44 :2 2c :2 29
10 4d 56 60 :2 4d 63 65 :2 63
4c :2 10 d 1d d 10 19 25
:2 10 2a 28 33 3d :2 2a :2 28 10
18 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 17
:2 20 10 d 40 13 1c 28 :2 13
2d 2b 36 40 :2 2d :2 2b 10 20
10 43 40 :3 d 1b d 17 27
15 24 26 36 47 4b 56 16
19 23 14 17 2b 2d 14 16
2b 2d 14 16 20 29 :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 60 63 64
:2 60 :2 32 :3 16 :2 1c 21 2d 71 74
:2 2d 81 84 :2 2d 88 8b :2 2d 97
9a :2 2d a2 a5 :2 2d b1 b4 bb
c4 c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10
:4 1c :2 10 d :3 68 10 19 25 :2 10
28 2a :2 28 10 18 10 13 :2 1d
2f :2 39 45 48 5c 5f 60 :2 5c
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
:2 13 63 :3 10 17 :2 20 10 2c :3 d
1b d 17 27 37 20 31 34
39 53 13 17 24 27 36 3a
48 4b 16 19 26 37 3a 44
11 19 20 23 46 4a :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 60 63 64
:2 60 :2 32 :3 16 :2 1c 21 2d 71 74
:2 2d 81 84 :2 2d 88 8b :2 2d 97
9a :2 2d a2 a5 :2 2d b1 b4 bb
c4 c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10
:4 1c :2 10 d :3 68 10 19 25 :2 10
28 2a :2 28 10 18 10 13 :2 1d
2f :2 39 45 48 5c 5f 60 :2 5c
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
:2 13 63 :3 10 17 :2 20 10 2c :3 d
1d 26 32 :2 1d :2 d 1b 2d 3b
46 54 60 21 2f :2 60 33 3c
47 :2 33 4b 54 61 :2 4b :2 1b d
68 2b :2 a d 16 22 :2 d 25
27 :2 25 d 1b 25 :2 1b d 29
:3 a 12 a d :2 17 29 :2 33 3f
42 56 59 5a :2 56 :2 29 :3 d :2 13
18 24 68 6b :2 24 :2 d 5d :3 a
11 1a 26 :2 11 a 7 38 :4 e
d :4 32 31 :2 d a 1b :2 a 1c
a e :2 19 21 30 40 :2 e 44
46 :2 44 d 4e :2 59 10 20 2f
:2 4e 33 36 :2 33 4d :3 d 15 d
10 :2 1a 2c :2 36 42 45 59 5c
5d :2 59 :2 2c :3 10 :2 16 1b 27 6b
6e :2 27 :2 10 60 :3 d 14 :2 1d d
39 :2 a :4 e d 17 29 3c 4b
5a 6a 15 16 2a :2 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 60 63 64 :2 60
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
81 84 :2 2d 88 8b :2 2d 97 9a
:2 2d a2 a5 :2 2d b1 b4 bb c4
c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c
:2 10 d :3 2b 11 :2 1a 26 23 :2 2f
:2 23 :2 10 18 10 13 :2 1d 2f :2 39
45 48 5c 5f 60 :2 5c :2 2f :3 13
:2 19 1e 2a 6e 71 :2 2a :2 13 63
:3 10 17 :2 20 10 3f :2 d 11 :2 1c
24 33 42 :2 11 46 48 :2 46 10
4f :2 5a 62 15 25 :2 4f 29 2b
:2 29 4e :3 10 18 10 13 :2 1d 2f
:2 39 45 48 5c 5f 60 :2 5c :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a :2 13
63 :3 10 17 :2 20 10 d 2e 14
:2 1f 27 37 46 :2 14 4a 4c :2 4a
13 53 :2 5e 13 23 33 :2 53 37
39 :2 37 52 :2 13 10 18 10 13
:2 1d 2f :2 39 45 48 5c 5f 60
:2 5c :2 2f :3 13 :2 19 1e 2a 6e 71
:2 2a :2 13 63 :3 10 17 :2 20 10 3c
2e :2 d 2b :2 a 14 24 2f 3c
46 51 12 1d 2a 39 4a 5c
12 13 20 31 3e :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5d 60 61 :2 5d
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 94 97
:2 2a 9f a2 :2 2a ae b1 b8 c1
c4 :2 b1 :2 2a :2 13 64 :2 10 :2 d :4 19
:2 d a :3 52 e 15 10 1d :2 15
21 :2 2a :2 e d 43 41 :2 4c :2 41
d 15 d 10 :2 1a 2c :2 36 42
45 59 5c 5d :2 59 :2 2c :3 10 :2 16
1b 27 6b 6e :2 27 :2 10 60 :3 d
14 :2 1d d 61 :2 a d 14 20
23 :2 d 26 28 :2 26 d 20 d
2c d 20 d :5 a 17 :2 a 17
a e :2 19 21 30 3e :2 e 42
45 :2 42 d 4c :2 57 5f 12 21
:2 4c 25 28 :2 25 4b :2 d 2f 38
43 :2 2f 49 46 52 5b :2 49 :2 46
2e :2 d 10 :2 1b 23 32 40 :2 10
44 47 :2 44 13 1c 2b :2 13 2e
30 :2 2e 36 :2 41 49 58 18 :2 36
1c 1e :2 1c :3 13 1b 13 16 :2 20
32 :2 3c 48 4b 5f 62 63 :2 5f
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
:2 16 66 :3 13 1a :2 23 13 20 :2 10
13 1c 29 :2 13 2e 2c :2 37 :2 2c
4c 16 23 :2 4c 28 26 :2 31 :2 26
:3 13 1e 13 1d 23 32 1b 1c
29 1a 2b 33 3a 57 5f 66
:2 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :3 45 17 :2 22
2a 39 4a :2 17 4e 50 :2 4e 16
57 :2 62 6a 1b 2d :2 57 31 33
:2 31 56 :3 16 27 :2 16 24 37 45
54 5d :2 24 16 36 :3 13 26 31
40 4e 5d 21 2f 3a 45 4b
51 5d 21 2d 38 49 55 21
34 40 4c 55 5f :2 4c 21 2a
39 :2 21 :2 26 :2 13 21 2b :2 21 :2 13
1b 13 16 :2 20 32 :2 3c 48 4b
5f 62 63 :2 5f :2 32 :3 16 :2 1c 21
2d 71 74 :2 2d :2 16 66 :3 13 1a
23 2f :2 1a 13 45 13 23 :2 13
1e :2 13 20 13 :4 10 d 49 13
:2 1e 26 36 45 :2 13 49 4c :2 49
1a 25 32 3a 41 5a 65 6a
:2 18 :2 13 :2 1c 28 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :3 4e 10
1d :2 28 2f 3f :2 1d :2 10 20 21
:2 20 :2 10 1e 35 43 4e 59 5f
65 28 34 42 55 :2 1e 10 14
1d 29 :2 14 2c 2e :2 2c 13 :4 37
36 35 :3 13 21 36 44 4f 59
6a 26 38 44 :2 21 13 56 :2 10
13 1a 26 29 :2 13 2c 2e :2 2c
13 22 13 32 13 22 13 :5 10
1f 28 32 :2 1f 35 37 40 4f
:2 37 :2 1f :2 10 1e 2b 39 44 4f
59 65 6b 1e 2c 3c 49 54
1e 2a 33 40 :2 2a 44 47 52
:2 1e 10 13 1c 28 :2 13 2b 2d
:2 2b 16 :2 21 29 3b 4b :2 16 4f
51 :2 4f 20 35 3a 43 4b 5b
6b 19 34 41 4e 5d 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 69 6c 6d :2 69 :2 3b :3 1f
:2 25 2a 36 7a 7d :2 36 8a 8d
:2 36 91 94 :2 36 a0 a3 :2 36 ab
ae :2 36 ba bd c4 cd d0 :2 bd
:2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19 16
:3 53 13 53 19 22 2f :2 19 32
34 :2 32 3a :2 45 4d 5f 1b :2 3a
1f 21 :2 1f :2 19 20 35 3a 43
4a 60 75 8a 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
69 6c 6d :2 69 :2 3b :3 1f :2 25 2a
36 7a 7d :2 36 8a 8d :2 36 91
94 :2 36 a0 a3 :2 36 ab ae :2 36
ba bd c4 cd d0 :2 bd :2 36 :2 1f
70 :2 1c :2 19 :4 25 :2 19 16 :4 23 53
:2 13 2f :2 10 1a 22 29 40 48
4f 68 72 83 91 18 1e 24
30 43 4f 18 19 2d :2 13 :2 1c
28 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 63 66 67
:2 63 :2 35 :3 19 :2 1f 24 30 74 77
:2 30 84 87 :2 30 8b 8e :2 30 9a
9d :2 30 a5 a8 :2 30 b4 b7 be
c7 ca :2 b7 :2 30 :2 19 6a :2 16 :2 13
:4 1f :2 13 10 :3 4e 10 20 :2 10 1e
35 43 4e 59 5f 65 28 34
42 55 :2 1e :2 10 1e 28 :2 1e :2 10
:2 19 25 :2 10 18 10 13 :2 1d 2f
:2 39 45 48 5c 5f 60 :2 5c :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a :2 13
63 :3 10 17 :2 20 10 d 4e 49
13 1c 25 :2 13 2a 28 33 3e
:2 2a :2 28 10 1b 24 2f :2 1b 32
34 3d 46 :2 34 :2 1b 10 13 1c
29 :2 13 2e 2c :2 37 :2 2c 4c 16
23 :2 4c 28 26 :2 31 :2 26 :2 13 17
1e 2a 2d :2 17 30 32 :2 30 :2 16
1e 16 37 16 1e 16 :5 13 21
2a 30 3f 48 :2 21 :2 13 25 :2 13
18 :3 13 19 24 :2 13 16 1c :2 16
:2 1f 2b 16 22 16 :2 1f 2b 16
:4 13 16 1c :3 16 :2 1f 2b 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:3 45 :4 17 16 19 :2 23 35 :2 3f 4b
4e 62 66 67 :2 62 :2 35 :3 19 :2 1f
24 30 75 78 :2 30 :2 19 6a :3 16
1d :2 26 16 2f :3 13 26 31 40
4e 5e 21 2f 3a 45 4b 51
5d 21 2d 38 49 55 21 34
40 4c 55 5f :2 4c 21 2a 39
:2 21 :2 26 :2 13 21 2b :2 21 :2 13 1b
13 16 :2 20 32 :2 3c 48 4b 5f
63 64 :2 5f :2 32 :3 16 :2 1c 21 2d
72 75 :2 2d :2 16 67 :3 13 1a 23
2f :2 1a 13 45 13 20 13 :4 10
d 41 49 13 1c 27 :2 13 2a
2c :2 2a 10 1b :2 10 1d 10 1a
28 18 19 26 :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 67 68 :2 63 :2 35
:3 19 :2 1f 24 30 75 78 :2 30 85
88 :2 30 8c 8f :2 30 9b 9e :2 30
a6 a9 :2 30 b5 b8 bf c8 cb
:2 b8 :2 30 :2 19 6b :2 16 :2 13 :4 1f :2 13
10 :3 2e d 2e 49 13 1c 25
:2 13 2a 28 33 3e :2 2a :2 28 10
1b 24 2d :2 1b 30 32 3b 46
:2 32 :2 1b :2 10 1f :2 10 18 10 13
1c 2d :2 13 30 32 :2 30 13 1b
1a 1d :2 1b 35 38 :2 1b 45 48
:2 1b 1f 22 :2 1b 2f 32 :2 1b 1a
1d :2 1b 46 49 51 5a 63 :2 51
:2 49 :2 1b :2 13 18 :2 26 13 34 13
1b 1a 1d :2 1b 35 38 :2 1b 41
44 :2 1b 6a 6d :2 1b 1f 22 :2 1b
1a 1d :2 1b 46 49 51 5a 63
:2 51 :2 49 :2 1b :2 13 18 :2 26 13 :5 10
16 1f 30 :2 16 33 35 :2 33 1c
2b :2 16 19 23 :2 19 :2 22 2e 19
29 19 :2 22 2e 19 :4 16 37 1c
2b :2 16 19 23 :2 19 :2 22 2e 19
29 19 :2 22 2e 19 :4 16 :4 13 17
:2 20 2c 29 :2 35 :2 29 :3 16 45 :2 13
10 14 41 13 1c 2d :2 13 30
32 :2 30 16 1c :3 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 6a 6b :2 66 :2 38
:3 1c :2 22 27 33 78 7b :2 33 88
8b :2 33 8f 92 :2 33 9e a1 :2 33
a9 ac :2 33 b8 bb c2 cb ce
:2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16
13 :4 34 16 1c :3 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 6a 6b :2 66 :2 38
:3 1c :2 22 27 33 78 7b :2 33 88
8b :2 33 8f 92 :2 33 9e a1 :2 33
a9 ac :2 33 b8 bb c2 cb ce
:2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16
13 :7 10 :4 14 13 16 1f 30 :2 16
33 35 :2 33 16 1e 16 19 :2 23
35 :2 3f 4b 4e 62 66 67 :2 62
:2 35 :3 19 :2 1f 24 30 75 78 :2 30
:2 19 6a :3 16 1d :2 26 16 37 16
1e 16 19 :2 23 35 :2 3f 4b 4e
62 66 67 :2 62 :2 35 :3 19 :2 1f 24
30 75 78 :2 30 :2 19 6a :3 16 1d
:2 26 16 :4 13 29 :2 10 1a 25 32
3a 41 57 62 67 :2 18 :2 13 :2 1c
28 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 63 67 68
:2 63 :2 35 :3 19 :2 1f 24 30 75 78
:2 30 85 88 :2 30 8c 8f :2 30 9b
9e :2 30 a6 a9 :2 30 b5 b8 bf
c8 cb :2 b8 :2 30 :2 19 6b :2 16 :2 13
:4 1f :2 13 10 :3 41 10 1b :2 10 1d
10 41 49 :2 d a 5f 10 19
24 :2 10 2a 27 33 44 :2 2a :2 27
10 19 25 :2 10 28 2a :2 28 30
39 44 :2 30 49 47 52 5e :2 49
:2 47 :3 10 18 10 13 :2 1d 2f :2 39
45 48 5c 60 61 :2 5c :2 2f :3 13
:2 19 1e 2a 6f 72 :2 2a :2 13 64
:3 10 17 :2 20 10 61 :2 d 10 19
28 :2 10 2d 2b 36 40 :2 2d :2 2b
10 18 10 13 :2 1d 2f :2 39 45
48 5c 60 61 :2 5c :2 2f :3 13 :2 19
1e 2a 6f 72 :2 2a :2 13 64 :3 10
17 :2 20 10 43 :2 d 10 19 24
:2 10 27 29 :2 27 10 23 10 2b
14 1d 28 :2 14 2b 2d :2 2b 13
34 3d 48 :2 34 4b 4d :2 4b 33
:3 13 1b 13 16 :2 20 32 :2 3c 48
4b 5f 63 64 :2 5f :2 32 :3 16 :2 1c
21 2d 72 75 :2 2d :2 16 67 :3 13
1a :2 23 13 58 :3 10 23 2c 37
:2 23 10 :5 d 1a 22 2b 36 :2 22
39 3b 44 55 :2 3b :2 22 21 59
5b :2 21 20 65 67 :2 20 :2 1a d
10 19 24 :2 10 29 27 32 3c
:2 29 :2 27 10 1e 10 1a 28 18
19 26 37 4b :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 67 68 :2 63 :2 35
:3 19 :2 1f 24 30 75 78 :2 30 85
88 :2 30 8c 8f :2 30 9b 9e :2 30
a6 a9 :2 30 b5 b8 bf c8 cb
:2 b8 :2 30 :2 19 6b :2 16 :2 13 :4 1f :2 13
10 :3 3f 13 1c 28 :2 13 2b 2d
:2 2b 13 1b 13 16 :2 20 32 :2 3c
48 4b 5f 63 64 :2 5f :2 32 :3 16
:2 1c 21 2d 72 75 :2 2d :2 16 67
:3 13 1a 13 2f :2 10 3f :2 d 10
19 26 :2 10 2b 29 :2 34 :2 29 49
13 20 :2 49 25 23 :2 2e :2 23 :3 10
20 21 :2 20 :2 10 23 3a 48 53
5e 64 6a 2d 39 47 5a :2 23
10 14 1d 29 :2 14 2c 2e :2 2c
13 :4 37 36 35 :2 13 1d 28 35
3d 44 5f 6a 6f :2 1b :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 6a 6b
:2 66 :2 38 :3 1c :2 22 27 33 78 7b
:2 33 88 8b :2 33 8f 92 :2 33 9e
a1 :2 33 a9 ac :2 33 b8 bb c2
cb ce :2 bb :2 33 :2 1c 6e :2 19 :2 16
:4 22 :2 16 13 :4 56 :3 10 1d 25 2e
3f :2 25 42 44 4d 58 :2 44 :2 25
24 5c 5e :2 24 23 68 6a :2 23
:2 1d :2 10 1e 2a 38 49 54 62
1d 28 33 :2 1e :2 10 1e :2 27 2e
37 48 :2 2e 4c :2 55 :2 1e :2 10 1e
2e 3c 47 53 56 :2 1e 10 1a
22 29 40 48 4f 68 72 83
91 18 1e 24 30 43 4f 18
19 2d :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 63 67 68 :2 63 :2 35 :3 19 :2 1f
24 30 75 78 :2 30 85 88 :2 30
8c 8f :2 30 9b 9e :2 30 a6 a9
:2 30 b5 b8 bf c8 cb :2 b8 :2 30
:2 19 6b :2 16 :2 13 :4 1f :2 13 10 :3 42
10 20 :2 10 1e 35 43 4e 59
5f 65 28 34 42 55 :2 1e :2 10
1e 28 :2 1e :2 10 18 10 13 :2 1d
2f :2 39 45 48 5c 60 61 :2 5c
:2 2f :3 13 :2 19 1e 2a 6f 72 :2 2a
:2 13 64 :3 10 17 20 2c :2 17 10
42 10 1b :2 10 1d 10 13 1c
27 :2 13 2a 2c :2 2a 13 20 13
2f :3 10 21 :2 2a 31 :2 3a 41 :2 4a
58 :2 61 :2 31 72 :2 7b :2 21 10 1a
2f 3d 49 13 21 2d 3c 13
21 2a 31 3d 19 2d 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 67 68 :2 63 :2 35 :3 19 :2 1f 24
30 75 78 :2 30 85 88 :2 30 8c
8f :2 30 9b 9e :2 30 a6 a9 :2 30
b5 b8 bf c8 cb :2 b8 :2 30 :2 19
6b :2 16 :2 13 :4 1f :2 13 10 :3 d 13
1c 27 :2 13 2a 2d :2 2a 13 20
13 2f :2 10 :4 d 47 5f :2 a d
17 19 :2 17 d 1d 1e :2 1d :2 d
20 37 45 50 5b 61 67 2d
39 47 5a :2 20 d 11 1a 26
:2 11 29 2b :2 29 10 :4 34 33 32
:3 10 1e 33 41 4c 56 67 26
38 44 :2 1e 10 53 :2 d :4 11 :2 10
23 33 41 4c :2 23 10 2e 13
1a 26 29 :2 13 2c 2e :2 2c 13
26 36 44 4f :2 26 13 32 13
26 36 44 4f :2 26 13 :4 10 :4 d
:4 11 10 13 1c 27 :2 13 2a 2c
:2 2a 13 21 :2 2a 31 3a 45 :2 31
49 :2 52 :2 21 20 13 1d 28 35
3d 44 5f 6a 6f :2 1b :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 6a 6b
:2 66 :2 38 :3 1c :2 22 27 33 78 7b
:2 33 88 8b :2 33 8f 92 :2 33 9e
a1 :2 33 a9 ac :2 33 b8 bb c2
cb ce :2 bb :2 33 :2 1c 6e :2 19 :2 16
:4 22 :2 16 13 :4 2e 1d 28 35 3d
44 5f 6a 6f :2 1b :2 16 :2 1f 2b
16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 6a 6b :2 66
:2 38 :3 1c :2 22 27 33 78 7b :2 33
88 8b :2 33 8f 92 :2 33 9e a1
:2 33 a9 ac :2 33 b8 bb c2 cb
ce :2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22
:2 16 13 :8 10 1c 25 2f :2 1c 32
34 3d 4c :2 34 :2 1c 10 2f :3 d
1f :2 d 20 2e 39 47 51 61
24 30 39 42 :2 30 46 4f 60
:2 46 :2 20 d 10 19 2a :2 10 2d
30 :2 2d 10 18 10 13 :2 1d 2f
:2 39 45 48 5c 60 61 :2 5c :2 2f
:3 13 :2 19 1e 2a 6f 72 :2 2a :2 13
64 :3 10 17 :2 20 10 d 32 13
1d 1f :2 1d 17 18 19 2d 10
1a 2f 3d 4b 54 5b 68 71
7e 87 13 22 2b 37 47 57
60 6d 13 27 19 2d 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 67 68 :2 63 :2 35 :3 19 :2 1f 24
30 75 78 :2 30 85 88 :2 30 8c
8f :2 30 9b 9e :2 30 a6 a9 :2 30
b5 b8 bf c8 cb :2 b8 :2 30 :2 19
6b :2 16 :2 13 :4 1f :2 13 10 :4 21 32
:3 d 1b 25 :2 1b :2 d 15 d 10
:2 1a 2c :2 36 42 45 59 5d 5e
:2 59 :2 2c :3 10 :2 16 1b 27 6c 6f
:2 27 :2 10 61 :3 d 14 1d 29 :2 14
d 1b :2 a d 16 22 :2 d 28
25 31 40 :2 28 :2 25 d 1b d
17 27 15 24 34 16 2a 14
29 14 1e 27 :2 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 64 65 :2 60 :2 32
:3 16 :2 1c 21 2d 72 75 :2 2d 82
85 :2 2d 89 8c :2 2d 98 9b :2 2d
a3 a6 :2 2d b2 b5 bc c5 c8
:2 b5 :2 2d :2 16 68 :2 13 :2 10 :4 1c :2 10
d :3 43 10 19 25 :2 10 28 2a
:2 28 10 18 10 13 :2 1d 2f :2 39
45 48 5c 60 61 :2 5c :2 2f :3 13
:2 19 1e 2a 6f 72 :2 2a :2 13 64
:3 10 17 :2 20 10 2c :3 d 1d 26
32 :2 1d :2 d 1f 28 32 :2 1f d
10 19 27 :2 10 2c 2a 35 3f
:2 2c :2 2a 13 1c 29 :2 13 2e 2c
:2 37 :2 2c 4e 16 23 :2 4e 28 26
:2 31 :2 26 :3 13 22 13 1d 23 2e
32 1b 24 1b 1c 29 1a 2e
1a :2 16 :2 1f 2b 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 6a 6b :2 66 :2 38 :3 1c :2 22 27
33 78 7b :2 33 88 8b :2 33 8f
92 :2 33 9e a1 :2 33 a9 ac :2 33
b8 bb c2 cb ce :2 bb :2 33 :2 1c
6e :2 19 :2 16 :4 22 :2 16 13 :3 43 :4 17
:2 16 26 16 30 :2 13 16 1f 28
:2 16 2b 2d :2 2b 16 26 27 :2 26
:2 16 29 40 4e 59 64 6a 70
2d 39 47 5a :2 29 16 1a 23
2f :2 1a 32 34 :2 32 19 :4 3d 3c
3b :2 19 23 2f 3f 21 22 2f
40 54 62 6d 75 7c :2 1c :2 25
31 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 6c 70 71
:2 6c :2 3e :3 22 :2 28 2d 39 7e 81
:2 39 8e 91 :2 39 95 98 :2 39 a4
a7 :2 39 af b2 :2 39 be c1 c8
d1 d4 :2 c1 :2 39 :2 22 74 :2 1f :2 1c
:4 28 :2 1c 19 :3 5c 19 25 2e 3c
:2 25 3f 41 4a 59 :2 41 :2 25 5c
5e 67 72 :2 5e :2 25 19 5c 19
25 2e 3c :2 25 3f 41 4a 59
:2 41 :2 25 19 :5 16 28 :2 16 23 2a
33 3d :2 33 48 :2 2a 4b 4d 56
60 :2 56 6a :2 4d :2 2a 29 6e 70
:2 29 :2 23 :2 16 24 2d 38 :2 24 3b
3d 46 4f :2 3d :2 24 16 19 22
2e :2 19 34 31 3d 47 :2 34 :2 31
19 2b 34 3f :2 2b 42 44 4d
59 :2 44 :2 2b 5c 5e 67 71 :2 5e
:2 2b 19 4a 19 2b 34 3f :2 2b
19 :5 16 24 30 3e 4f 5a 68
1e 2e 39 :2 24 :2 16 29 30 39
43 :2 39 4f :2 30 52 54 5d 67
:2 5d 73 :2 54 :2 30 2f 24 26 :2 2f
:2 29 :2 16 24 :2 2d 34 3d 4e :2 34
52 :2 5b :2 24 :2 16 24 34 42 4d
59 62 6d :2 59 71 1f 30 :2 71
:2 24 :2 16 26 :2 16 24 3b 49 54
5f 65 6b 28 34 42 55 :2 24
16 2f :2 13 43 13 25 :2 13 21
2a 34 :2 21 :2 13 26 3a 48 53
5d 2a 3c 48 52 2a 3a 49
59 2a 37 43 50 2a 39 47
2a 3d 49 55 2a 33 3e :2 2a
42 4b 58 :2 42 :2 26 :2 13 24 2d
37 :2 24 :2 13 1f 28 36 :2 1f 39
3b 44 53 :2 3b :2 1f 13 20 28
2f 4f 65 :2 16 :2 1f 2b 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 6a 6b :2 66 :2 38 :3 1c
:2 22 27 33 78 7b :2 33 88 8b
:2 33 8f 92 :2 33 9e a1 :2 33 a9
ac :2 33 b8 bb c2 cb ce :2 bb
:2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16 13
:3 10 20 2b 38 40 47 5f 6a
8b 9d :2 16 :2 1f 2b 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 6a 6b :2 66 :2 38 :3 1c :2 22
27 33 78 7b :2 33 88 8b :2 33
8f 92 :2 33 9e a1 :2 33 a9 ac
:2 33 b8 bb c2 cb ce :2 bb :2 33
:2 1c 6e :2 19 :2 16 :4 22 :2 16 13 :3 10
1d 32 40 4e 57 5e 6a 73
16 23 31 3f 4d 56 16 2d
45 1c 30 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 6a 6b
:2 66 :2 38 :3 1c :2 22 27 33 78 7b
:2 33 88 8b :2 33 8f 92 :2 33 9e
a1 :2 33 a9 ac :2 33 b8 bb c2
cb ce :2 bb :2 33 :2 1c 6e :2 19 :2 16
:4 22 :2 16 13 :3 10 17 :2 20 2b 29
:2 34 :2 29 :2 16 28 :2 16 24 32 3d
4b 55 65 70 1f 22 2b 3c
:2 22 :2 24 16 19 22 2e :2 19 31
34 :2 31 19 21 19 1c :2 26 38
:2 42 4e 51 65 69 6a :2 65 :2 38
:3 1c :2 22 27 33 78 7b :2 33 :2 1c
6d :3 19 20 29 35 :2 20 19 36
:2 16 44 :2 13 :5 10 1c 25 33 :2 1c
:2 10 1e 10 42 10 22 2a 33
3d :2 33 4c :2 2a 4f 51 5a 64
:2 5a 6f :2 51 :2 2a 29 24 26 :2 29
28 30 32 :2 28 :2 22 10 :5 d 1b
2f 3d 48 52 5d 25 31 3b
49 25 34 44 50 25 31 3e
4c 25 33 42 55 25 31 3d
46 51 :2 3d 55 23 30 :2 55 :2 1b
:2 d 15 d 10 :2 1a 2c :2 36 42
45 59 5d 5e :2 59 :2 2c :3 10 :2 16
1b 27 6c 6f :2 27 :2 10 61 :3 d
14 1d 29 :2 14 d a 43 10
19 2b :2 10 31 2e 3a 4a :2 31
:2 2e 11 1a 29 :2 11 2c 2e :2 2c
10 36 3f 51 :2 36 54 56 :2 54
35 :3 10 18 10 13 :2 1d 2f :2 39
45 48 5c 60 61 :2 5c :2 2f :3 13
:2 19 1e 2a 6f 72 :2 2a :2 13 64
:3 10 17 :2 20 10 59 :2 d 17 2c
40 10 1e 27 2e 3a 43 16
2a 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 64 65 :2 60 :2 32
:3 16 :2 1c 21 2d 72 75 :2 2d 82
85 :2 2d 89 8c :2 2d 98 9b :2 2d
a3 a6 :2 2d b2 b5 bc c5 c8
:2 b5 :2 2d :2 16 68 :2 13 :2 10 :4 1c :2 10
d :3 4d 17 23 31 3a 41 4d
56 16 23 34 41 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 60
64 65 :2 60 :2 32 :3 16 :2 1c 21 2d
72 75 :2 2d 82 85 :2 2d 89 8c
:2 2d 98 9b :2 2d a3 a6 :2 2d b2
b5 bc c5 c8 :2 b5 :2 2d :2 16 68
:2 13 :2 10 :4 1c :2 10 d :4 4d 43 :3 a
18 22 :2 18 :2 a 12 a d :2 17
29 :2 33 3f 42 56 5a 5b :2 56
:2 29 :3 d :2 13 18 24 69 6c :2 24
:2 d 5e :3 a 11 1a 26 :2 11 a
52 38 14 17 24 27 34 37
43 46 17 1a 17 1a d 10
d 10 1c 1f 12 21 30 3e
:4 d 1b 12 27 30 33 47 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5d 61
62 :2 5d :2 2f :3 13 :2 19 1e 2a 6f
72 :2 2a 7f 82 :2 2a 86 89 :2 2a
95 98 :2 2a a0 a3 :2 2a af b2
b9 c2 c5 :2 b2 :2 2a :2 13 65 :2 10
:2 d :4 19 :2 d a :3 7 12 :2 1b 26
24 :2 2f :2 24 11 :4 d 15 d 10
:2 1a 2c :2 36 42 45 59 5d 5e
:2 59 :2 2c :3 10 :2 16 1b 27 6c 6f
:2 27 :2 10 61 :3 d 14 :2 1d d 3f
:2 a d :2 18 1f 2e :2 d 3d 3f
:2 3d d :2 16 22 :2 d 15 d 10
:2 1a 2c :2 36 42 45 59 5d 5e
:2 59 :2 2c :3 10 :2 16 1b 27 6c 6f
:2 27 :2 10 61 :3 d 14 :2 1d d 41
:2 a :4 7 35 :3 4 11 :2 4 15 :2 4
12 :2 4 14 :2 1d :2 4 :2 d 19 30
3e 49 58 :2 19 :2 4 c 4 7
:2 11 23 :2 2d 39 3c 50 54 55
:2 50 :2 23 :3 7 :2 d 12 1e 63 66
:2 1e :2 7 58 :3 4 b :2 14 4 7
:2 11 23 :2 2d 39 3c 50 54 55
:2 50 :2 23 :3 7 :2 d 12 1e 63 66
:2 1e 73 76 :2 1e 7a 7d :2 1e 87
8a :2 93 :2 1e :2 7 58 :3 4 b :2 14
4 :9 1 
2a06
4
0 :2 1 :6 3 :6 4
:6 5 :6 6 :4 7 :4 8
:4 9 :4 a :6 b :6 c
2 :2 d :2 1 :6 f
:6 10 :6 11 :6 12 :7 13
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :7 1b
:7 1c :7 1d :7 1e :7 1f
:5 20 :5 21 :5 22 :5 23
:5 24 :5 25 :5 26 :5 27
:5 28 :5 29 :5 2a :5 2b
:5 2c :7 2d :7 2e :6 2f
:6 30 :6 31 :6 32 :5 33
:5 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :7 3f
:7 40 :7 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :6 5a :6 5b
:6 5c :6 5d :6 5e :6 5f
:7 60 :7 61 :6 62 :7 63
:6 64 :6 65 :6 66 :6 67
:6 68 :6 69 :6 6a :6 6b
:6 6c :6 6d :6 6e :7 6f
:5 70 :5 71 :5 72 :2 74
0 :2 74 :6 75 76
:5 77 :3 78 79 75
:5 74 :7 7c :7 7f :b 82
:11 83 84 :2 83 :2 84
:2 83 :2 84 :2 83 :2 85
:2 83 :2 85 :2 83 :2 85
:2 83 :2 85 :2 83 :2 86
:2 83 :12 86 :2 83 :2 87
:2 83 :12 87 :2 83 :2 88
:2 83 :9 88 :2 83 :2 89
:2 83 :9 89 :2 83 :2 8a
:2 83 :9 8a :2 83 :2 8b
:2 83 :9 8b :2 83 :2 8c
:2 83 :2 8c :2 83 :2 8c
:2 83 :2 8c :2 83 :2 8d
:2 83 :2 8d :2 83 :2 8d
:2 83 :2 8d :2 83 :2 8d
:4 83 :3 82 :11 90 :b 91
:3 90 :3 96 :3 97 :3 98
:3 99 :3 9c :8 9f :2 a0
:2 a1 :2 a2 :4 a3 :4 a4
a5 a6 a7 :2 a8
:2 a9 :3 aa 9f :5 ab
9e ad :5 ae :3 ad
:2 af :5 b1 :11 b2 :24 b3
:3 b2 :2 b0 :6 af ac
:3 81 :a b8 :6 ba :6 bb
:8 bc :5 bd :8 be :4 bf
:4 c0 :3 c1 :6 c2 :6 c3
:5 c4 :3 c5 :4 c6 :4 c7
:4 c8 :3 c9 ca :2 cb
ba :5 cc b9 ce
:5 cf :3 ce :2 d0 :5 d2
:11 d3 :24 d4 :3 d3 :2 d1
:6 d0 cd :3 b8 :a d9
:8 db :a dc :8 dd :7 de
:3 df db :5 e0 da
e2 :5 e3 :3 e2 :2 e4
:5 e6 :11 e7 :24 e8 :3 e7
:2 e5 :6 e4 e1 :3 d9
:a ed :3 ee :11 ef :b f0
:3 ef :5 f2 :3 ed :2 f4
:2 f5 :2 f4 :3 f5 :3 f4
:6 f5 :3 f6 :11 f7 :b f8
:3 f7 :5 fa f5 :2 f4
:3 fd :3 fe :10 ff :3 100
:2 ff :4 100 :3 ff :3 101
:11 102 :b 103 :3 102 :5 105
100 :2 ff :16 108 :2 109
:7 108 :3 10a :11 10b :b 10c
:3 10b :5 10e 109 :2 108
:11 111 :2 112 :2 111 :4 112
:3 111 :9 113 :c 114 :9 116
117 :2 118 :4 119 116
:5 11a 115 11c :5 11d
:3 11c :2 11e :5 120 :11 121
:24 122 :3 121 :2 11f :6 11e
11b :3 114 :a 127 :8 129
12a 129 :5 12b 128
12d :5 12e :3 12d :2 12f
:5 131 :11 132 :24 133 :3 132
:2 130 :6 12f 12c :6 127
:c 139 :3 13a :3 139 114
:9 13e 13f :2 140 :4 141
13e :5 142 13d 144
:5 145 :3 144 :2 146 :5 148
:11 149 :24 14a :3 149 :2 147
:6 146 143 :3 13c :a 14f
:8 151 152 151 :5 153
150 155 :5 156 :3 155
:2 157 :5 159 :11 15a :24 15b
:3 15a :2 158 :6 157 154
:6 14f :3 161 13c :3 114
:b 164 :7 166 :2 167 166
:6 168 :5 169 168 :5 16b
16a :3 168 165 16e
:5 16f :3 16e :2 170 :5 172
:11 173 :24 174 :3 173 :2 171
:6 170 16d :4 164 :7 17a
:2 17b 17a :6 17c :5 17d
17c :5 17f 17e :3 17c
179 182 :5 183 :3 182
:2 184 :5 186 :11 187 :24 188
:3 187 :2 185 :6 184 181
:4 178 :3 164 :a 18e :6 18f
:3 18e 113 :3 192 :3 193
:c 194 :2 195 :2 194 :6 195
:2 194 :3 197 198 :2 199
:7 19a 197 :5 19b 196
19d :5 19e :3 19d :2 19f
:5 1a1 :11 1a2 :24 1a3 :3 1a2
:2 1a0 :6 19f 19c :4 195
:2 194 :c 1a9 :9 1ab 1ac
:2 1ad :4 1ae 1ab :5 1af
1aa 1b1 :5 1b2 :3 1b1
:2 1b3 :5 1b5 :11 1b6 :24 1b7
:3 1b6 :2 1b4 :6 1b3 1b0
:3 1a9 :a 1bc :8 1be 1bf
1be :5 1c0 1bd 1c2
:5 1c3 :3 1c2 :2 1c4 :5 1c6
:11 1c7 :24 1c8 :3 1c7 :2 1c5
:6 1c4 1c1 :3 1bc :b 1cc
:3 1bc :c 1cf :2 1d0 :2 1cf
:6 1d0 :2 1cf :3 1d1 :3 1d2
1d0 :2 1cf 1a9 :9 1d5
:3 1d6 :3 1d8 1d9 :4 1da
:5 1db 1d8 :5 1dc 1d7
1de :5 1df :3 1de :2 1e0
:5 1e2 :11 1e3 :24 1e4 :3 1e3
:2 1e1 :6 1e0 1dd :3 1d5
:9 1e9 :3 1eb 1ec :4 1ed
:6 1ee 1eb :5 1ef 1ea
1f1 :5 1f2 :3 1f1 :2 1f3
:5 1f5 :11 1f6 :24 1f7 :3 1f6
:2 1f4 :6 1f3 1f0 :6 1e9
:9 1fd :3 1fe :11 1ff :b 200
:3 1ff :5 202 :3 1fd :3 1d5
:9 207 208 :2 209 :4 20a
207 :5 20b 206 20d
:5 20e :3 20d :2 20f :5 211
:11 212 :24 213 :3 212 :2 210
:6 20f 20c :3 1d4 :a 218
:8 21a 21b 21a :5 21c
219 21e :5 21f :3 21e
:2 220 :5 222 :11 223 :24 224
:3 223 :2 221 :6 220 21d
:6 218 :14 22a :b 22b :5 22a
:3 22c :3 22d 22b :2 22a
1d4 :3 1a9 :12 232 :2 233
:2 232 :7 233 :2 234 :2 233
:6 234 :5 232 :9 235 234
:2 232 :3 238 :3 23a :2 23b
:6 23c :2 23d :2 23e :7 23f
:e 240 23a :5 241 239
243 :5 244 :3 243 :2 245
:5 247 :11 248 :24 249 :3 248
:2 246 :6 245 242 :3 191
:9 24e :3 24f :11 250 :b 251
:3 250 :5 253 :3 24e :7 256
:5 257 :6 258 :3 256 :9 259
:6 25a 259 :3 25c :11 25d
:b 25e :3 25d :7 260 25b
:3 259 191 :3 113 263
112 :1a 263 :3 264 :d 265
:3 266 :11 267 :b 268 :3 267
:5 26a 26c 265 :d 26c
:3 26d 26c :3 265 :3 271
:2 273 274 :6 275 :3 276
:4 277 :4 278 :4 279 273
:5 27a 272 27c :5 27d
:3 27c :2 27e :5 280 :11 281
:24 282 :3 281 :2 27f :6 27e
27b :3 263 :9 287 :3 288
:11 289 :b 28a :3 289 :5 28c
:3 287 :3 290 :3 292 :5 293
:8 294 :6 295 :6 296 292
:5 297 291 299 :5 29a
:3 299 :2 29b :5 29d :11 29e
:24 29f :3 29e :2 29c :6 29b
298 :3 263 :9 2a4 :3 2a5
:11 2a6 :b 2a7 :3 2a6 :5 2a9
:3 2a4 :7 2ac :7 2ae :2 2af
:2 2ae :a 2af :3 2ae 263
112 :2 111 :9 2b2 :6 2b3
:3 2b2 :3 2b6 :11 2b7 :b 2b8
:3 2b7 :7 2ba 2bb d9
:c 2bb :3 2bc :3 2bd :10 2bf
:3 2c0 :2 2bf :4 2c0 :3 2bf
:3 2c1 :11 2c2 :b 2c3 :3 2c2
:5 2c5 2c0 :2 2bf :5 2c7
:6 2c9 2ca :2 2cb 2c9
:5 2cc 2c8 2ce :5 2cf
:3 2ce :2 2d0 :5 2d2 :11 2d3
:24 2d4 :3 2d3 :2 2d1 :6 2d0
2cd :3 2c7 :a 2d9 :3 2da
:11 2db :b 2dc :3 2db :5 2de
:3 2d9 :11 2e1 :2 2e2 :2 2e1
:4 2e2 :3 2e1 :3 2e3 :11 2e4
:b 2e5 :3 2e4 :5 2e7 2e8
2e2 :10 2e8 :3 2e9 :2 2e8
:4 2e9 :3 2e8 :3 2ea :11 2eb
:b 2ec :3 2eb :5 2ee 2e9
2e2 :2 2e1 :3 2c7 :6 2f3
:6 2f4 2f5 :4 2f6 2f3
:5 2f7 2f2 2f9 :5 2fa
:3 2f9 :2 2fb :5 2fd :11 2fe
:24 2ff :3 2fe :2 2fc :6 2fb
2f8 :3 2bb :2 304 :2 305
:2 304 :3 305 :3 304 :6 305
:3 306 :11 307 :b 308 :3 307
:5 30a 305 :2 304 :a 30d
:3 30e 30d :3 310 30f
:3 30d :3 313 :3 314 :11 316
:2 317 :2 316 :4 317 :3 316
:e 317 :2 316 :c 318 :e 319
31a :2 319 :4 31a :2 319
:3 31b :11 31c :b 31d :3 31c
:5 31f 31a :2 319 :c 322
:2 323 :2 322 :6 323 :2 322
:3 324 :3 326 327 :2 328
:7 329 326 :5 32a 325
32c :5 32d :3 32c :2 32e
:5 330 :11 331 :24 332 :3 331
:2 32f :6 32e 32b :3 323
:11 337 :2 338 :2 337 :4 338
:3 337 :3 33a :9 33b 338
:2 337 :6 33e :7 33f :5 340
:8 341 :5 342 :3 33e :6 344
:3 345 :11 346 :b 347 :3 346
:7 349 323 :3 34b :3 34c
:3 34d 34a :3 322 34f
318 :c 34f :8 351 352
353 351 :5 354 350
356 :5 357 :3 356 :2 358
:5 35a :11 35b :24 35c :3 35b
:2 359 :6 358 355 :3 34f
:9 361 :6 363 :8 364 :4 365
:3 364 :12 367 :7 368 :3 369
:3 368 :3 367 :a 36c :3 36d
36c :3 36f 36e :3 36c
:f 372 :9 374 :5 375 :9 376
:3 374 :9 378 :c 379 :7 37b
:5 37c :2 37d 37b :6 37e
:5 37f 37e :5 381 380
:3 37e 37a 384 :5 385
:3 384 :2 386 :5 388 :11 389
:24 38a :3 389 :2 387 :6 386
383 :3 379 38e 379
:e 38e 38f :2 38e :4 38f
:2 38e :8 391 :2 392 391
:6 393 :5 394 393 :5 396
395 :3 393 390 399
:5 39a :3 399 :2 39b :5 39d
:11 39e :24 39f :3 39e :2 39c
:6 39b 398 :4 38f :3 379
:3 378 :a 3a7 :6 3a8 3a9
:2 3aa 3a7 :5 3ab 3a6
3ad :5 3ae :3 3ad :2 3af
:5 3b1 :11 3b2 :24 3b3 :3 3b2
:2 3b0 :6 3af 3ac :3 34f
:3 3b8 :8 3b9 :4 3ba :3 3b9
:6 3bc :5 3be :3 3bf :11 3c0
:b 3c1 :3 3c0 :5 3c3 3c5
34f 318 :d 3c5 :f 3c6
:c 3c7 :2 3c8 :2 3c7 :6 3c8
:2 3c7 :b 3c9 :3 3ca 3c9
:3 3cc 3cb :3 3c9 :9 3cf
:3 3d1 :5 3d3 :4 3d5 :3 3d6
:5 3d7 3d6 :5 3d9 3d8
:3 3d6 :4 3dd :5 3de 3dc
3e0 :5 3e1 :3 3e0 :2 3e2
:5 3e4 :11 3e5 :24 3e6 :3 3e5
:2 3e3 :6 3e2 3df :3 3c8
:5 3eb :11 3ec :b 3ed :3 3ec
:5 3ef :3 3eb :6 3f2 :7 3f3
:5 3f4 :8 3f5 :5 3f6 :3 3f2
:6 3f8 :3 3f9 :11 3fa :b 3fb
:3 3fa :7 3fd 3c8 :3 3ff
3fe :3 3c7 401 3c5
318 :9 401 :3 402 :3 403
:2 406 407 :2 408 406
:5 409 405 40b :5 40c
:3 40b :2 40d :5 40f :11 410
:24 411 :3 410 :2 40e :6 40d
40a :3 401 415 401
318 :d 415 :f 416 :3 417
:3 418 :9 41a :2 41b :2 41c
:2 41b :2 41c :2 41b :2 41c
:2 41b :2 41d :2 41b :2 41d
:2 41b :2 41e :2 41b :9 41e
:3 41b :5 420 41a :2 422
:2 423 :2 422 :2 423 :2 422
:2 423 :2 422 :2 423 :2 422
:2 424 :2 422 :2 425 :2 422
:9 425 :3 422 :5 427 421
:3 41a 42a :9 42b :4 42c
:3 42d :5 42e 42d :5 430
42f :3 42d 42b :4 433
:3 434 :5 435 434 :5 437
436 :3 434 432 :3 42b
:a 43b :2 43c :3 43b 42a
43e 415 :9 440 :4 442
:5 443 441 445 :5 446
:3 445 :2 447 :5 449 :11 44a
:24 44b :3 44a :2 448 :6 447
444 :4 440 :4 451 :5 452
450 454 :5 455 :3 454
:2 456 :5 458 :11 459 :24 45a
:3 459 :2 457 :6 456 453
:4 44f :3 440 :5 460 :9 461
:3 462 :11 463 :b 464 :3 463
:5 466 461 :3 468 :11 469
:b 46a :3 469 :5 46c 467
:3 461 :3 460 :8 471 472
473 471 :5 474 470
476 :5 477 :3 476 :2 478
:5 47a :11 47b :24 47c :3 47b
:2 479 :6 478 475 :3 415
:3 480 :3 481 415 :3 318
483 317 :d 483 :18 484
:3 485 :11 486 :b 487 :3 486
:5 489 :3 484 :d 48c :3 48d
:11 48e :b 48f :3 48e :5 491
:3 48c :9 494 :3 495 494
:16 497 :3 498 :11 499 :b 49a
:3 499 :5 49c :3 497 :7 4a0
496 :3 494 :1c 4a3 :d 4a4
:3 4a5 :2 4a7 4a8 :4 4a9
4a7 :5 4aa 4a6 4ac
:5 4ad :3 4ac :2 4ae :5 4b0
:11 4b1 :24 4b2 :3 4b1 :2 4af
:6 4ae 4ab :3 4a4 :9 4b7
:3 4bf :11 4c0 :b 4c1 :3 4c0
:3 4c3 :3 4b7 :3 4a4 :c 4c7
:2 4c8 :2 4c7 :6 4c8 :2 4c7
:6 4c9 :8 4ca :4 4cb :3 4ca
:12 4cd :8 4d7 4d8 4d9
4d7 :5 4da 4d6 4dc
:5 4dd :3 4dc :2 4de :5 4e0
:11 4e1 :24 4e2 :3 4e1 :2 4df
:6 4de 4db :6 4cd :1c 4e8
:7 4e9 :3 4ea :3 4e9 :f 4ec
:a 4ed :a 4f0 :6 4f1 4f2
:2 4f3 4f0 :5 4f4 4ef
4f6 :5 4f7 :3 4f6 :2 4f8
:5 4fa :11 4fb :24 4fc :3 4fb
:2 4f9 :6 4f8 4f5 :3 4c8
:3 501 :8 502 :4 503 :3 502
:6 505 :3 506 :11 507 :b 508
:3 507 :7 50a 4c8 :3 50c
:3 50d :9 50e :3 50f :3 50e
:15 514 :4 516 :4 517 :5 518
:2 519 516 :6 51a :5 51b
51a :5 51d 51c :3 51a
515 520 :5 521 :3 520
:2 522 :5 524 :11 525 :24 526
:3 525 :2 523 :6 522 51f
:3 50b :9 52b :3 52c :3 52b
50b :3 4c7 483 317
:2 316 :5 531 :6 532 :8 533
:4 534 :3 533 :12 536 :7 537
:3 538 :3 537 :3 536 :5 53b
:8 53c 53b :a 53e :8 53f
53e :8 541 540 :3 53e
53d :3 53b :5 545 :9 546
:10 547 :8 54a 54b 54c
54a :5 54d 549 54f
:5 550 :3 54f :2 551 :5 553
:11 554 :24 555 :3 554 :2 552
:6 551 54e :4 546 :8 55b
55c 55d 55b :5 55e
55a 560 :5 561 :3 560
:2 562 :5 564 :11 565 :24 566
:3 565 :2 563 :6 562 55f
:4 559 :3 546 :f 56c :3 545
:3 56f :7 570 :b 571 :3 570
:9 573 :3 574 :11 575 :b 576
:3 575 :5 578 579 573
:5 579 57a 57b :2 57c
57a :a 57f :8 580 :2 581
:2 582 57f :6 583 :5 584
583 :5 586 585 :3 583
57e 589 :5 58a :3 589
:2 58b :5 58d :11 58e :24 58f
:3 58e :2 58c :6 58b 588
:4 579 :3 573 :6 595 :3 596
:11 597 :b 598 :3 597 :7 59a
:3 531 :d 59d :3 59f :2 5a1
5a2 :2 5a3 :2 5a4 :2 5a5
:3 5a6 5a1 :5 5a7 5a0
5a9 :5 5aa :3 5a9 :2 5ab
:5 5ad :11 5ae :24 5af :3 5ae
:2 5ac :6 5ab 5a8 :3 59d
:9 5b4 :3 5b5 :11 5b6 :b 5b7
:3 5b6 :5 5b9 :3 5b4 :7 5bc
:7 5be :d 5bf :c 5c0 :2 5c1
:2 5c0 :6 5c1 :2 5c0 :3 5c2
:4 5c4 :2 5c5 5c6 :2 5c7
:2 5c8 5c9 5c4 :5 5ca
5c3 5cc :5 5cd :3 5cc
:2 5ce :5 5d0 :11 5d1 :24 5d2
:3 5d1 :2 5cf :6 5ce 5cb
:3 5c1 :5 5d7 :3 5d8 :3 5d7
:9 5db :6 5dc :8 5dd :4 5de
:3 5dd :12 5e0 :3 5e2 5e3
:8 5e4 5e2 :5 5e5 5e1
5e7 :5 5e8 :3 5e7 :2 5e9
:5 5eb :11 5ec :24 5ed :3 5ec
:2 5ea :6 5e9 5e6 :3 5e0
:17 5f2 5e0 :f 5f4 5f3
:3 5e0 :3 5f6 :1d 5f8 :f 5f9
:d 5fa :17 5fb 5fa :7 5fd
5fc :3 5fa :7 600 :3 601
:3 600 :16 604 :2 605 :5 604
:f 606 :b 607 :2 608 :5 607
:3 60a :8 60b :4 60c :3 60b
:3 5db 5c1 :3 64d :7 64e
:6 64f :4 650 :4 651 :4 652
:3 653 :4 654 :a 655 :3 64f
:7 657 :f 658 :6 65a :5 65b
659 65d :5 65e :3 65d
:2 65f :5 661 :11 662 :24 663
:3 662 :2 660 :6 65f 65c
:3 60e :a 668 :5 669 667
66b :5 66c :3 66b :2 66d
:5 66f :11 670 :24 671 :3 670
:2 66e :6 66d 66a :3 60e
:8 677 :6 678 :3 679 :2 67a
677 :6 67b :5 67c 67b
:5 67e 67d :3 67b 676
681 :5 682 :3 681 :2 683
:5 685 :11 686 :24 687 :3 686
:2 684 :6 683 680 :3 60e
:a 68c :3 68d :8 68e :6 68f
:3 68e :9 691 :3 692 :11 693
:b 694 :3 693 :7 696 :3 691
:3 68c 60e :3 5c0 :7 69b
:3 69c 5bf :16 69e :2 69f
:3 69e :2 69f :5 69e 69d
:3 5bf :7 6a2 :4 6a3 :4 6a4
:4 6a5 :4 6a6 :8 6a7 :2 6a8
:2 6a7 :3 6a2 :3 6aa :11 6ab
:b 6ac :3 6ab :7 6ae 6af
59d :d 6af :16 6b0 :3 6b1
:11 6b2 :b 6b3 :3 6b2 :5 6b5
:3 6b0 :3 6da :6 6db :2 6dc
6da :6 6dd :5 6de 6dd
:5 6e0 6df :3 6dd 6d9
6e3 :5 6e4 :3 6e3 :2 6e5
:5 6e7 :11 6e8 :24 6e9 :3 6e8
:2 6e6 :6 6e5 6e2 :3 6af
:7 6f3 :4 6f4 6f3 :6 6f5
:5 6f6 6f5 :5 6f8 6f7
:3 6f5 6f2 6fb :5 6fc
:3 6fb :2 6fd :5 6ff :11 700
:24 701 :3 700 :2 6fe :6 6fd
6fa :4 6af :3 59d :6 709
:3 70a :11 70b :b 70c :3 70b
:7 70e 2bb d9 :8 711
:2 712 :2 713 :2 714 :4 715
:4 716 717 718 719
:2 71a :5 71b 711 :5 71c
710 71e :5 71f :3 71e
:2 720 :5 722 :11 723 :24 724
:3 723 :2 721 :6 720 71d
:3 70f :d 72a :3 72b :11 72c
:b 72d :3 72c :5 72f :3 72a
:b 732 :5 733 :3 734 :11 735
:b 736 :3 735 :5 738 :3 732
70f :3 d9 :3 b8 :3 73d
:3 73e :3 73f :5 741 :b 742
:3 744 :11 745 :b 746 :3 745
:5 748 :11 74a :19 74b :3 74a
:5 74d :2 81 :7 1 
92d7
4
:3 0 1 :3 0 2
:a 0 2a01 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
9 :3 0 8 :5 0
1 13 12 :3 0
d 98 0 b
4 :3 0 5 :3 0
9 :3 0 a :5 0
1 19 18 :3 0
c :3 0 b :7 0
1d 1c :3 0 11
be 0 f c
:3 0 d :7 0 21
20 :3 0 c :3 0
e :7 0 25 24
:3 0 15 eb 0
13 c :3 0 f
:7 0 29 28 :3 0
4 :3 0 5 :3 0
6 :3 0 10 :5 0
1 2f 2e :3 0
22 117 0 17
4 :3 0 5 :3 0
6 :3 0 11 :5 0
1 35 34 :3 0
12 :3 0 c :3 0
37 39 0 2a01
2 3a :2 0 26
153 0 24 c
:3 0 3d :7 0 b
:3 0 41 3e 3f
29ff 0 13 :6 0
c :3 0 43 :7 0
d :3 0 47 44
45 29ff 0 14
:6 0 18 :2 0 28
c :3 0 49 :7 0
e :3 0 4d 4a
4b 29ff 0 15
:6 0 c :3 0 4f
:7 0 f :3 0 53
50 51 29ff 0
16 :6 0 18 :2 0
2c 6 :3 0 2a
55 57 :6 0 5a
58 0 29ff 0
17 :6 0 1b :2 0
30 6 :3 0 2e
5c 5e :6 0 61
5f 0 29ff 0
19 :6 0 1b :2 0
34 6 :3 0 32
63 65 :6 0 68
66 0 29ff 0
1a :6 0 18 :2 0
38 6 :3 0 36
6a 6c :6 0 6f
6d 0 29ff 0
1c :6 0 1b :2 0
3c 6 :3 0 3a
71 73 :6 0 76
74 0 29ff 0
1d :6 0 18 :2 0
40 6 :3 0 3e
78 7a :6 0 7d
7b 0 29ff 0
1e :6 0 18 :2 0
44 6 :3 0 42
7f 81 :6 0 84
82 0 29ff 0
1f :6 0 18 :2 0
48 6 :3 0 46
86 88 :6 0 8b
89 0 29ff 0
20 :6 0 18 :2 0
4c 6 :3 0 4a
8d 8f :6 0 92
90 0 29ff 0
21 :6 0 18 :2 0
50 6 :3 0 4e
94 96 :6 0 99
97 0 29ff 0
22 :6 0 18 :2 0
54 6 :3 0 52
9b 9d :6 0 a0
9e 0 29ff 0
23 :6 0 18 :2 0
58 6 :3 0 56
a2 a4 :6 0 a7
a5 0 29ff 0
24 :6 0 5e 308
0 5c 6 :3 0
5a a9 ab :6 0
ae ac 0 29ff
0 25 :6 0 62
33c 0 60 9
:3 0 b0 :7 0 b3
b1 0 29ff 0
26 :6 0 9 :3 0
b5 :7 0 b8 b6
0 29ff 0 27
:6 0 66 370 0
64 9 :3 0 ba
:7 0 bd bb 0
29ff 0 28 :6 0
9 :3 0 bf :7 0
c2 c0 0 29ff
0 29 :6 0 6a
3a4 0 68 9
:3 0 c4 :7 0 c7
c5 0 29ff 0
2a :6 0 9 :3 0
c9 :7 0 cc ca
0 29ff 0 2b
:6 0 6e 3d8 0
6c 9 :3 0 ce
:7 0 d1 cf 0
29ff 0 2c :6 0
9 :3 0 d3 :7 0
d6 d4 0 29ff
0 2d :6 0 72
40c 0 70 9
:3 0 d8 :7 0 db
d9 0 29ff 0
2e :6 0 9 :3 0
dd :7 0 e0 de
0 29ff 0 2f
:6 0 76 440 0
74 31 :3 0 e2
:7 0 e5 e3 0
29ff 0 30 :6 0
31 :3 0 e7 :7 0
ea e8 0 29ff
0 32 :6 0 35
:2 0 7a 31 :3 0
ec :7 0 ef ed
0 29ff 0 33
:6 0 6 :3 0 35
:2 0 78 f1 f3
:6 0 f6 f4 0
29ff 0 34 :6 0
38 :2 0 7e 6
:3 0 7c f8 fa
:6 0 fd fb 0
29ff 0 36 :6 0
38 :2 0 80 c
:3 0 ff :7 0 103
100 101 29ff 0
37 :6 0 38 :2 0
82 c :3 0 105
:7 0 109 106 107
29ff 0 39 :6 0
38 :2 0 84 c
:3 0 10b :7 0 10f
10c 10d 29ff 0
3a :6 0 88 505
0 86 c :3 0
111 :7 0 115 112
113 29ff 0 3b
:6 0 38 :2 0 8a
31 :3 0 117 :7 0
11a 118 0 29ff
0 3c :6 0 31
:3 0 11c :7 0 11f
11d 0 29ff 0
3d :6 0 38 :2 0
8c c :3 0 121
:7 0 125 122 123
29ff 0 3e :6 0
38 :2 0 8e c
:3 0 127 :7 0 12b
128 129 29ff 0
3f :6 0 38 :2 0
90 c :3 0 12d
:7 0 131 12e 12f
29ff 0 40 :6 0
38 :2 0 92 c
:3 0 133 :7 0 137
134 135 29ff 0
41 :6 0 38 :2 0
94 c :3 0 139
:7 0 13d 13a 13b
29ff 0 42 :6 0
38 :2 0 96 c
:3 0 13f :7 0 143
140 141 29ff 0
43 :6 0 38 :2 0
98 c :3 0 145
:7 0 149 146 147
29ff 0 44 :6 0
38 :2 0 9a c
:3 0 14b :7 0 14f
14c 14d 29ff 0
45 :6 0 38 :2 0
9c c :3 0 151
:7 0 155 152 153
29ff 0 46 :6 0
18 :2 0 9e c
:3 0 157 :7 0 15b
158 159 29ff 0
47 :6 0 18 :2 0
a2 6 :3 0 a0
15d 15f :6 0 162
160 0 29ff 0
48 :6 0 18 :2 0
a6 6 :3 0 a4
164 166 :6 0 169
167 0 29ff 0
49 :6 0 38 :2 0
aa 6 :3 0 a8
16b 16d :6 0 170
16e 0 29ff 0
4a :6 0 38 :2 0
ac c :3 0 172
:7 0 176 173 174
29ff 0 4b :6 0
38 :2 0 ae c
:3 0 178 :7 0 17c
179 17a 29ff 0
4c :6 0 38 :2 0
b0 c :3 0 17e
:7 0 182 17f 180
29ff 0 4d :6 0
38 :2 0 b2 c
:3 0 184 :7 0 188
185 186 29ff 0
4e :6 0 38 :2 0
b4 c :3 0 18a
:7 0 18e 18b 18c
29ff 0 4f :6 0
38 :2 0 b6 c
:3 0 190 :7 0 194
191 192 29ff 0
50 :6 0 38 :2 0
b8 c :3 0 196
:7 0 19a 197 198
29ff 0 51 :6 0
38 :2 0 ba c
:3 0 19c :7 0 1a0
19d 19e 29ff 0
52 :6 0 38 :2 0
bc c :3 0 1a2
:7 0 1a6 1a3 1a4
29ff 0 53 :6 0
38 :2 0 be c
:3 0 1a8 :7 0 1ac
1a9 1aa 29ff 0
54 :6 0 38 :2 0
c0 c :3 0 1ae
:7 0 1b2 1af 1b0
29ff 0 55 :6 0
38 :2 0 c2 c
:3 0 1b4 :7 0 1b8
1b5 1b6 29ff 0
56 :6 0 38 :2 0
c4 c :3 0 1ba
:7 0 1be 1bb 1bc
29ff 0 57 :6 0
38 :2 0 c6 c
:3 0 1c0 :7 0 1c4
1c1 1c2 29ff 0
58 :6 0 38 :2 0
c8 c :3 0 1c6
:7 0 1ca 1c7 1c8
29ff 0 59 :6 0
38 :2 0 ca c
:3 0 1cc :7 0 1d0
1cd 1ce 29ff 0
5a :6 0 38 :2 0
cc c :3 0 1d2
:7 0 1d6 1d3 1d4
29ff 0 5b :6 0
38 :2 0 ce c
:3 0 1d8 :7 0 1dc
1d9 1da 29ff 0
5c :6 0 38 :2 0
d0 c :3 0 1de
:7 0 1e2 1df 1e0
29ff 0 5d :6 0
38 :2 0 d2 c
:3 0 1e4 :7 0 1e8
1e5 1e6 29ff 0
5e :6 0 38 :2 0
d4 c :3 0 1ea
:7 0 1ee 1eb 1ec
29ff 0 5f :6 0
38 :2 0 d6 c
:3 0 1f0 :7 0 1f4
1f1 1f2 29ff 0
60 :6 0 38 :2 0
d8 c :3 0 1f6
:7 0 1fa 1f7 1f8
29ff 0 61 :6 0
38 :2 0 da c
:3 0 1fc :7 0 200
1fd 1fe 29ff 0
62 :6 0 38 :2 0
dc c :3 0 202
:7 0 206 203 204
29ff 0 63 :6 0
38 :2 0 de c
:3 0 208 :7 0 20c
209 20a 29ff 0
64 :6 0 38 :2 0
e0 c :3 0 20e
:7 0 212 20f 210
29ff 0 65 :6 0
38 :2 0 e2 c
:3 0 214 :7 0 218
215 216 29ff 0
66 :6 0 38 :2 0
e4 c :3 0 21a
:7 0 21e 21b 21c
29ff 0 67 :6 0
6a :2 0 e6 c
:3 0 220 :7 0 224
221 222 29ff 0
68 :6 0 35 :2 0
ea 6 :3 0 e8
226 228 :6 0 22b
229 0 29ff 0
69 :6 0 38 :2 0
ee 6 :3 0 ec
22d 22f :6 0 232
230 0 29ff 0
6b :6 0 18 :2 0
f0 c :3 0 234
:7 0 238 235 236
29ff 0 6c :6 0
38 :2 0 f4 6
:3 0 f2 23a 23c
:6 0 23f 23d 0
29ff 0 6d :6 0
38 :2 0 f6 c
:3 0 241 :7 0 245
242 243 29ff 0
6e :6 0 38 :2 0
f8 c :3 0 247
:7 0 24b 248 249
29ff 0 6f :6 0
38 :2 0 fa c
:3 0 24d :7 0 251
24e 24f 29ff 0
70 :6 0 38 :2 0
fc 72 :3 0 253
:7 0 257 254 255
29ff 0 71 :6 0
38 :2 0 fe 72
:3 0 259 :7 0 25d
25a 25b 29ff 0
73 :6 0 38 :2 0
100 72 :3 0 25f
:7 0 263 260 261
29ff 0 74 :6 0
38 :2 0 102 72
:3 0 265 :7 0 269
266 267 29ff 0
75 :6 0 38 :2 0
104 72 :3 0 26b
:7 0 26f 26c 26d
29ff 0 76 :6 0
38 :2 0 106 72
:3 0 271 :7 0 275
272 273 29ff 0
77 :6 0 38 :2 0
108 72 :3 0 277
:7 0 27b 278 279
29ff 0 78 :6 0
7b :2 0 10a 72
:3 0 27d :7 0 281
27e 27f 29ff 0
79 :6 0 110 bb4
0 10e 6 :3 0
10c 283 285 :6 0
288 286 0 29ff
0 7a :6 0 114
be8 0 112 c
:3 0 28a :7 0 28d
28b 0 29ff 0
7c :6 0 c :3 0
28f :7 0 292 290
0 29ff 0 7d
:6 0 7f :3 0 c
:3 0 294 :7 0 297
295 0 29ff 0
7e :6 0 80 :a 0
2 2ae :5 0 299
29c 0 29a :3 0
81 :3 0 81 :3 0
82 :3 0 83 :3 0
81 :3 0 84 :3 0
85 :3 0 86 :3 0
11 :3 0 81 :3 0
30 :3 0 81 :3 0
87 :3 0 84 :3 0
4d :3 0 88 :4 0
89 1 :8 0 2af
299 29c 2b0 0
29ff 116 2b0 2b2
2af 2b1 :6 0 2ae
:7 0 2b0 2bb 2bc
0 118 8b :3 0
8c :2 0 4 2b4
2b5 0 2b6 :7 0
2b9 2b7 0 29ff
0 8a :6 0 2c1
2c2 0 11a 8b
:3 0 8c :2 0 4
2bd :7 0 2c0 2be
0 29ff 0 8d
:6 0 8e :3 0 8f
:3 0 8e :3 0 90
:3 0 2c4 2c5 0
2 :4 0 11c 2c6
2c8 2c3 2ca 2c9
:2 0 91 :3 0 92
:3 0 2cc 2cd 0
93 :4 0 8e :3 0
94 :3 0 2d0 2d1
0 2 :4 0 11e
2d2 2d4 95 :4 0
96 :2 0 97 :3 0
120 2d7 2d9 :3 0
98 :4 0 96 :2 0
99 :4 0 123 2dc
2de :3 0 96 :2 0
3 :3 0 126 2e0
2e2 :3 0 96 :2 0
99 :4 0 129 2e4
2e6 :3 0 96 :2 0
9a :4 0 12c 2e8
2ea :3 0 96 :2 0
99 :4 0 12f 2ec
2ee :3 0 96 :2 0
7 :3 0 132 2f0
2f2 :3 0 96 :2 0
99 :4 0 135 2f4
2f6 :3 0 96 :2 0
9a :4 0 138 2f8
2fa :3 0 96 :2 0
9b :3 0 9c :3 0
99 :4 0 96 :2 0
8 :3 0 13b 300
302 :3 0 96 :2 0
99 :4 0 13e 304
306 :3 0 9d :4 0
141 2fe 309 9e
:4 0 144 2fd 30c
147 2fc 30e :3 0
96 :2 0 9a :4 0
14a 310 312 :3 0
96 :2 0 9b :3 0
9c :3 0 99 :4 0
96 :2 0 a :3 0
14d 318 31a :3 0
96 :2 0 99 :4 0
150 31c 31e :3 0
9d :4 0 153 316
321 9e :4 0 156
315 324 159 314
326 :3 0 96 :2 0
9a :4 0 15c 328
32a :3 0 96 :2 0
9b :3 0 9f :3 0
b :3 0 15f 32e
330 9e :4 0 161
32d 333 164 32c
335 :3 0 96 :2 0
9a :4 0 167 337
339 :3 0 96 :2 0
9b :3 0 9f :3 0
d :3 0 16a 33d
33f 9e :4 0 16c
33c 342 16f 33b
344 :3 0 96 :2 0
9a :4 0 172 346
348 :3 0 96 :2 0
9b :3 0 9f :3 0
e :3 0 175 34c
34e 9e :4 0 177
34b 351 17a 34a
353 :3 0 96 :2 0
9a :4 0 17d 355
357 :3 0 96 :2 0
9b :3 0 9f :3 0
f :3 0 180 35b
35d 9e :4 0 182
35a 360 185 359
362 :3 0 96 :2 0
9a :4 0 188 364
366 :3 0 96 :2 0
99 :4 0 18b 368
36a :3 0 96 :2 0
10 :3 0 18e 36c
36e :3 0 96 :2 0
99 :4 0 191 370
372 :3 0 96 :2 0
9a :4 0 194 374
376 :3 0 96 :2 0
99 :4 0 197 378
37a :3 0 96 :2 0
11 :3 0 19a 37c
37e :3 0 96 :2 0
99 :4 0 19d 380
382 :3 0 96 :2 0
a0 :4 0 1a0 384
386 :3 0 1a3 2ce
388 :2 0 38a 1a8
38b 2cb 38a 0
38c 1aa 0 29fd
8e :3 0 8f :3 0
38d 38e 0 8e
:3 0 a1 :3 0 390
391 0 35 :2 0
2 :4 0 a2 :2 0
a3 :2 0 35 :2 0
1ac 396 398 :3 0
1af 392 39a 38f
39c 39b :2 0 91
:3 0 a4 :3 0 39e
39f 0 93 :4 0
a5 :4 0 96 :2 0
97 :3 0 1b3 3a3
3a5 :3 0 1b6 3a0
3a7 :2 0 3a9 1b9
3aa 39d 3a9 0
3ab 1bb 0 29fd
56 :3 0 38 :2 0
3ac 3ad 0 29fd
23 :3 0 a6 :4 0
3af 3b0 0 29fd
4a :3 0 10 :3 0
3b2 3b3 0 29fd
20 :3 0 7 :3 0
3b5 3b6 0 29fd
21 :3 0 3 :3 0
3b8 3b9 0 29fd
a7 :3 0 a8 :3 0
a7 :3 0 a9 :3 0
a7 :3 0 86 :3 0
a7 :3 0 aa :3 0
a7 :3 0 ab :3 0
a7 :3 0 ac :3 0
a7 :3 0 ad :3 0
a7 :3 0 ae :3 0
a7 :3 0 af :3 0
1f :3 0 41 :3 0
19 :3 0 3f :3 0
42 :3 0 47 :3 0
1a :3 0 24 :3 0
46 :3 0 b0 :3 0
a7 :3 0 a7 :3 0
a8 :3 0 21 :4 0
b1 1 :8 0 3e1
8b :3 0 b2 :3 0
3dc 3dd 0 b3
:3 0 3de 3df 0
3e1 1bd 434 b4
:3 0 8b :3 0 b2
:3 0 3e3 3e4 0
b3 :3 0 3e5 3e6
0 3e8 1c0 3ea
1c2 3e9 3e8 :2 0
432 b5 :3 0 8b
:3 0 b2 :3 0 3ed
3ee 0 b3 :3 0
3ef 3f0 0 42a
8e :3 0 8f :3 0
3f2 3f3 0 8e
:3 0 a1 :3 0 3f5
3f6 0 b6 :2 0
2 :4 0 b7 :2 0
a3 :2 0 35 :2 0
1c4 3fb 3fd :3 0
1c7 3f7 3ff 3f4
401 400 :2 0 91
:3 0 a4 :3 0 403
404 0 93 :4 0
b8 :4 0 96 :2 0
97 :3 0 1cb 408
40a :3 0 96 :2 0
b9 :4 0 1ce 40c
40e :3 0 96 :2 0
ba :4 0 1d1 410
412 :3 0 96 :2 0
b3 :3 0 1d4 414
416 :3 0 96 :2 0
bb :4 0 1d7 418
41a :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
1da 41d 421 1de
41c 423 :3 0 1e1
405 425 :2 0 427
1e4 428 402 427
0 429 1e6 0
42a 1e8 42d :3 0
42d 0 42d 42c
42a 42b :6 0 42f
3 :3 0 1eb 431
1ed 430 42f :2 0
432 1ef :2 0 434
0 434 433 3e1
432 :6 0 29fd 1
:3 0 8b :3 0 b2
:3 0 436 437 0
8b :3 0 bf :2 0
c0 :3 0 439 43b
0 1f4 43a 43d
:3 0 43e :2 0 a8
:3 0 c1 :3 0 ae
:3 0 ad :3 0 ab
:3 0 c2 :3 0 c3
:3 0 c4 :3 0 c5
:3 0 c6 :3 0 c7
:3 0 c8 :3 0 c9
:3 0 ca :3 0 c9
:3 0 ca :3 0 cb
:3 0 cc :3 0 cd
:3 0 ce :3 0 c2
:3 0 cf :3 0 d0
:3 0 d1 :3 0 d2
:3 0 d3 :3 0 bc
:3 0 cd :3 0 d3
:3 0 bc :3 0 ce
:3 0 d4 :3 0 d5
:3 0 d6 :3 0 d7
:3 0 d8 :3 0 d9
:3 0 da :3 0 db
:3 0 dc :3 0 dd
:3 0 de :3 0 df
:3 0 e0 :3 0 1f
:3 0 22 :3 0 24
:3 0 49 :3 0 36
:3 0 34 :3 0 3d
:3 0 4c :3 0 52
:3 0 5d :3 0 5e
:3 0 5b :3 0 4e
:3 0 26 :3 0 50
:3 0 27 :3 0 28
:3 0 4b :3 0 4d
:3 0 53 :3 0 30
:3 0 32 :3 0 39
:3 0 3a :3 0 71
:3 0 74 :3 0 73
:3 0 75 :3 0 76
:3 0 78 :3 0 77
:3 0 79 :3 0 4f
:3 0 48 :3 0 61
:3 0 e1 :3 0 e2
:3 0 21 :4 0 e3
1 :8 0 498 8b
:3 0 b2 :3 0 493
494 0 b3 :3 0
495 496 0 498
1f7 4eb b4 :3 0
8b :3 0 b2 :3 0
49a 49b 0 b3
:3 0 49c 49d 0
49f 1fa 4a1 1fc
4a0 49f :2 0 4e9
b5 :3 0 8b :3 0
b2 :3 0 4a4 4a5
0 b3 :3 0 4a6
4a7 0 4e1 8e
:3 0 8f :3 0 4a9
4aa 0 8e :3 0
a1 :3 0 4ac 4ad
0 b6 :2 0 2
:4 0 e4 :2 0 a3
:2 0 35 :2 0 1fe
4b2 4b4 :3 0 201
4ae 4b6 4ab 4b8
4b7 :2 0 91 :3 0
a4 :3 0 4ba 4bb
0 93 :4 0 e5
:4 0 96 :2 0 97
:3 0 205 4bf 4c1
:3 0 96 :2 0 b9
:4 0 208 4c3 4c5
:3 0 96 :2 0 ba
:4 0 20b 4c7 4c9
:3 0 96 :2 0 b3
:3 0 20e 4cb 4cd
:3 0 96 :2 0 bb
:4 0 211 4cf 4d1
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 214
4d4 4d8 218 4d3
4da :3 0 21b 4bc
4dc :2 0 4de 21e
4df 4b9 4de 0
4e0 220 0 4e1
222 4e4 :3 0 4e4
0 4e4 4e3 4e1
4e2 :6 0 4e6 5
:3 0 225 4e8 227
4e7 4e6 :2 0 4e9
229 :2 0 4eb 0
4eb 4ea 498 4e9
:6 0 2988 1 :3 0
8b :3 0 b2 :3 0
4ed 4ee 0 8b
:3 0 bf :2 0 c0
:3 0 4f0 4f2 0
22e 4f1 4f4 :3 0
4f5 :2 0 ae :3 0
e6 :3 0 e7 :3 0
e8 :3 0 e9 :3 0
ea :3 0 eb :3 0
ec :3 0 ed :3 0
ee :3 0 cc :3 0
ef :3 0 f0 :3 0
f1 :3 0 f2 :3 0
9b :3 0 f3 :3 0
f4 :3 0 24 :3 0
56 :3 0 57 :3 0
27 :3 0 28 :3 0
5a :3 0 66 :3 0
68 :3 0 59 :3 0
58 :3 0 50 :3 0
4b :3 0 4f :3 0
60 :3 0 2b :3 0
f5 :3 0 86 :3 0
21 :4 0 f6 1
:8 0 521 8b :3 0
b2 :3 0 51c 51d
0 b3 :3 0 51e
51f 0 521 231
574 b4 :3 0 8b
:3 0 b2 :3 0 523
524 0 b3 :3 0
525 526 0 528
234 52a 236 529
528 :2 0 572 b5
:3 0 8b :3 0 b2
:3 0 52d 52e 0
b3 :3 0 52f 530
0 56a 8e :3 0
8f :3 0 532 533
0 8e :3 0 a1
:3 0 535 536 0
b6 :2 0 2 :4 0
f7 :2 0 a3 :2 0
35 :2 0 238 53b
53d :3 0 23b 537
53f 534 541 540
:2 0 91 :3 0 a4
:3 0 543 544 0
93 :4 0 f8 :4 0
96 :2 0 97 :3 0
23f 548 54a :3 0
96 :2 0 b9 :4 0
242 54c 54e :3 0
96 :2 0 ba :4 0
245 550 552 :3 0
96 :2 0 b3 :3 0
248 554 556 :3 0
96 :2 0 bb :4 0
24b 558 55a :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 24e 55d
561 252 55c 563
:3 0 255 545 565
:2 0 567 258 568
542 567 0 569
25a 0 56a 25c
56d :3 0 56d 0
56d 56c 56a 56b
:6 0 56f 7 :3 0
25f 571 261 570
56f :2 0 572 263
:2 0 574 0 574
573 521 572 :6 0
10b5 1 :3 0 8b
:3 0 b2 :3 0 576
577 0 8b :3 0
bf :2 0 c0 :3 0
579 57b 0 268
57a 57d :3 0 57e
:2 0 11 :3 0 21
:3 0 580 581 0
5a7 8e :3 0 8f
:3 0 583 584 0
8e :3 0 a1 :3 0
586 587 0 35
:2 0 2 :4 0 f9
:2 0 a3 :2 0 35
:2 0 26b 58c 58e
:3 0 26e 588 590
585 592 591 :2 0
91 :3 0 a4 :3 0
594 595 0 93
:4 0 fa :4 0 96
:2 0 97 :3 0 272
599 59b :3 0 275
596 59d :2 0 59f
278 5a0 593 59f
0 5a1 27a 0
5a7 12 :3 0 fb
:3 0 fc :3 0 5a3
5a4 0 5a5 :2 0
5a7 27c 5a8 57f
5a7 0 5a9 280
0 10b5 fd :3 0
9b :3 0 68 :3 0
38 :2 0 282 5ab
5ae fb :3 0 fe
:3 0 5b0 5b1 0
285 5aa 5b3 5b4
:2 0 fb :3 0 bf
:2 0 fe :3 0 5b6
5b8 0 28a 5b7
5ba :3 0 11 :3 0
21 :3 0 5bc 5bd
0 5e3 8e :3 0
8f :3 0 5bf 5c0
0 8e :3 0 a1
:3 0 5c2 5c3 0
35 :2 0 2 :4 0
ff :2 0 a3 :2 0
35 :2 0 28d 5c8
5ca :3 0 290 5c4
5cc 5c1 5ce 5cd
:2 0 91 :3 0 a4
:3 0 5d0 5d1 0
93 :4 0 100 :4 0
96 :2 0 97 :3 0
294 5d5 5d7 :3 0
297 5d2 5d9 :2 0
5db 29a 5dc 5cf
5db 0 5dd 29c
0 5e3 12 :3 0
fb :3 0 101 :3 0
5df 5e0 0 5e1
:2 0 5e3 29e 5e4
5bb 5e3 0 5e5
2a2 0 10b5 29
:3 0 8 :3 0 5e6
5e7 0 10b5 2a
:3 0 a :3 0 5e9
5ea 0 10b5 102
:3 0 103 :3 0 5ec
5ed 0 29 :3 0
2a :3 0 104 :2 0
2a4 5ee 5f2 105
:2 0 38 :2 0 2aa
5f4 5f6 :3 0 5f7
:2 0 102 :3 0 103
:3 0 5f9 5fa 0
2a :3 0 28 :3 0
104 :2 0 2ad 5fb
5ff 106 :2 0 38
:2 0 2b3 601 603
:3 0 604 :2 0 5f8
606 605 :2 0 11
:3 0 21 :3 0 608
609 0 62f 8e
:3 0 8f :3 0 60b
60c 0 8e :3 0
a1 :3 0 60e 60f
0 35 :2 0 2
:4 0 107 :2 0 a3
:2 0 35 :2 0 2b6
614 616 :3 0 2b9
610 618 60d 61a
619 :2 0 91 :3 0
a4 :3 0 61c 61d
0 93 :4 0 108
:4 0 96 :2 0 97
:3 0 2bd 621 623
:3 0 2c0 61e 625
:2 0 627 2c3 628
61b 627 0 629
2c5 0 62f 12
:3 0 fb :3 0 109
:3 0 62b 62c 0
62d :2 0 62f 2c7
630 607 62f 0
631 2cb 0 10b5
2b :3 0 10a :2 0
2cd 633 634 :3 0
635 :2 0 636 :2 0
9b :3 0 4b :3 0
38 :2 0 2cf 638
63b 10b :2 0 9b
:3 0 50 :3 0 38
:2 0 2d2 63e 641
2d5 63d 643 :3 0
644 :2 0 9b :3 0
106 :2 0 60 :3 0
38 :2 0 2d8 646
64a 2dd 647 64c
:3 0 64d :2 0 637
64f 64e :2 0 11
:3 0 21 :3 0 651
652 0 678 8e
:3 0 8f :3 0 654
655 0 8e :3 0
a1 :3 0 657 658
0 35 :2 0 2
:4 0 10c :2 0 a3
:2 0 35 :2 0 2e0
65d 65f :3 0 2e3
659 661 656 663
662 :2 0 91 :3 0
a4 :3 0 665 666
0 93 :4 0 10d
:4 0 96 :2 0 97
:3 0 2e7 66a 66c
:3 0 2ea 667 66e
:2 0 670 2ed 671
664 670 0 672
2ef 0 678 12
:3 0 fb :3 0 10e
:3 0 674 675 0
676 :2 0 678 2f1
679 650 678 0
67a 2f5 0 10b5
102 :3 0 103 :3 0
67b 67c 0 29
:3 0 27 :3 0 104
:2 0 2f7 67d 681
106 :2 0 38 :2 0
2fd 683 685 :3 0
686 :2 0 102 :3 0
103 :3 0 688 689
0 2a :3 0 28
:3 0 104 :2 0 300
68a 68e 106 :2 0
38 :2 0 306 690
692 :3 0 693 :2 0
687 695 694 :2 0
9b :3 0 59 :3 0
38 :2 0 309 697
69a bf :2 0 38
:2 0 30e 69c 69e
:3 0 102 :3 0 103
:3 0 6a0 6a1 0
29 :3 0 27 :3 0
104 :2 0 311 6a2
6a6 106 :2 0 38
:2 0 317 6a8 6aa
:3 0 102 :3 0 10f
:3 0 81 :3 0 102
:3 0 110 :3 0 111
:3 0 112 :3 0 113
:3 0 29 :3 0 85
:3 0 86 :3 0 24
:3 0 81 :3 0 d3
:3 0 bc :3 0 29
:4 0 114 1 :8 0
6c2 8b :3 0 b2
:3 0 6bd 6be 0
b3 :3 0 6bf 6c0
0 6c2 31a 715
b4 :3 0 8b :3 0
b2 :3 0 6c4 6c5
0 b3 :3 0 6c6
6c7 0 6c9 31d
6cb 31f 6ca 6c9
:2 0 713 b5 :3 0
8b :3 0 b2 :3 0
6ce 6cf 0 b3
:3 0 6d0 6d1 0
70b 8e :3 0 8f
:3 0 6d3 6d4 0
8e :3 0 a1 :3 0
6d6 6d7 0 b6
:2 0 2 :4 0 115
:2 0 a3 :2 0 35
:2 0 321 6dc 6de
:3 0 324 6d8 6e0
6d5 6e2 6e1 :2 0
91 :3 0 a4 :3 0
6e4 6e5 0 93
:4 0 116 :4 0 96
:2 0 97 :3 0 328
6e9 6eb :3 0 96
:2 0 b9 :4 0 32b
6ed 6ef :3 0 96
:2 0 ba :4 0 32e
6f1 6f3 :3 0 96
:2 0 b3 :3 0 331
6f5 6f7 :3 0 96
:2 0 bb :4 0 334
6f9 6fb :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 337 6fe 702
33b 6fd 704 :3 0
33e 6e6 706 :2 0
708 341 709 6e3
708 0 70a 343
0 70b 345 70e
:3 0 70e 0 70e
70d 70b 70c :6 0
710 9 :3 0 348
712 34a 711 710
:2 0 713 34c :2 0
715 0 715 714
6c2 713 :6 0 79a
1 :3 0 8b :3 0
b2 :3 0 717 718
0 8b :3 0 bf
:2 0 c0 :3 0 71a
71c 0 351 71b
71e :3 0 71f :2 0
102 :3 0 10f :3 0
d3 :3 0 bc :3 0
29 :3 0 102 :3 0
110 :3 0 29 :3 0
117 :4 0 118 1
:8 0 730 8b :3 0
b2 :3 0 72b 72c
0 b3 :3 0 72d
72e 0 730 354
783 b4 :3 0 8b
:3 0 b2 :3 0 732
733 0 b3 :3 0
734 735 0 737
357 739 359 738
737 :2 0 781 b5
:3 0 8b :3 0 b2
:3 0 73c 73d 0
b3 :3 0 73e 73f
0 779 8e :3 0
8f :3 0 741 742
0 8e :3 0 a1
:3 0 744 745 0
b6 :2 0 2 :4 0
119 :2 0 a3 :2 0
35 :2 0 35b 74a
74c :3 0 35e 746
74e 743 750 74f
:2 0 91 :3 0 a4
:3 0 752 753 0
93 :4 0 11a :4 0
96 :2 0 97 :3 0
362 757 759 :3 0
96 :2 0 b9 :4 0
365 75b 75d :3 0
96 :2 0 ba :4 0
368 75f 761 :3 0
96 :2 0 b3 :3 0
36b 763 765 :3 0
96 :2 0 bb :4 0
36e 767 769 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 371 76c
770 375 76b 772
:3 0 378 754 774
:2 0 776 37b 777
751 776 0 778
37d 0 779 37f
77c :3 0 77c 0
77c 77b 779 77a
:6 0 77e b :3 0
382 780 384 77f
77e :2 0 781 386
:2 0 783 0 783
782 730 781 :6 0
785 1 :3 0 389
786 720 785 0
787 38b 0 79a
102 :3 0 103 :3 0
788 789 0 29
:3 0 2a :3 0 104
:2 0 38d 78a 78e
105 :2 0 38 :2 0
393 790 792 :3 0
2a :4 0 794 795
0 797 396 798
793 797 0 799
398 0 79a 39a
87b 102 :3 0 10f
:3 0 81 :3 0 102
:3 0 110 :3 0 111
:3 0 11b :3 0 113
:3 0 2a :3 0 85
:3 0 86 :3 0 24
:3 0 81 :3 0 d3
:3 0 bc :3 0 2a
:4 0 11c 1 :8 0
7b1 8b :3 0 b2
:3 0 7ac 7ad 0
b3 :3 0 7ae 7af
0 7b1 39e 804
b4 :3 0 8b :3 0
b2 :3 0 7b3 7b4
0 b3 :3 0 7b5
7b6 0 7b8 3a1
7ba 3a3 7b9 7b8
:2 0 802 b5 :3 0
8b :3 0 b2 :3 0
7bd 7be 0 b3
:3 0 7bf 7c0 0
7fa 8e :3 0 8f
:3 0 7c2 7c3 0
8e :3 0 a1 :3 0
7c5 7c6 0 b6
:2 0 2 :4 0 11d
:2 0 a3 :2 0 35
:2 0 3a5 7cb 7cd
:3 0 3a8 7c7 7cf
7c4 7d1 7d0 :2 0
91 :3 0 a4 :3 0
7d3 7d4 0 93
:4 0 11e :4 0 96
:2 0 97 :3 0 3ac
7d8 7da :3 0 96
:2 0 b9 :4 0 3af
7dc 7de :3 0 96
:2 0 ba :4 0 3b2
7e0 7e2 :3 0 96
:2 0 b3 :3 0 3b5
7e4 7e6 :3 0 96
:2 0 bb :4 0 3b8
7e8 7ea :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 3bb 7ed 7f1
3bf 7ec 7f3 :3 0
3c2 7d5 7f5 :2 0
7f7 3c5 7f8 7d2
7f7 0 7f9 3c7
0 7fa 3c9 7fd
:3 0 7fd 0 7fd
7fc 7fa 7fb :6 0
7ff d :3 0 3cc
801 3ce 800 7ff
:2 0 802 3d0 :2 0
804 0 804 803
7b1 802 :6 0 87a
1 :3 0 8b :3 0
b2 :3 0 806 807
0 8b :3 0 bf
:2 0 c0 :3 0 809
80b 0 3d5 80a
80d :3 0 80e :2 0
102 :3 0 10f :3 0
d3 :3 0 bc :3 0
2a :3 0 102 :3 0
110 :3 0 2a :3 0
117 :4 0 11f 1
:8 0 81f 8b :3 0
b2 :3 0 81a 81b
0 b3 :3 0 81c
81d 0 81f 3d8
872 b4 :3 0 8b
:3 0 b2 :3 0 821
822 0 b3 :3 0
823 824 0 826
3db 828 3dd 827
826 :2 0 870 b5
:3 0 8b :3 0 b2
:3 0 82b 82c 0
b3 :3 0 82d 82e
0 868 8e :3 0
8f :3 0 830 831
0 8e :3 0 a1
:3 0 833 834 0
b6 :2 0 2 :4 0
120 :2 0 a3 :2 0
35 :2 0 3df 839
83b :3 0 3e2 835
83d 832 83f 83e
:2 0 91 :3 0 a4
:3 0 841 842 0
93 :4 0 121 :4 0
96 :2 0 97 :3 0
3e6 846 848 :3 0
96 :2 0 b9 :4 0
3e9 84a 84c :3 0
96 :2 0 ba :4 0
3ec 84e 850 :3 0
96 :2 0 b3 :3 0
3ef 852 854 :3 0
96 :2 0 bb :4 0
3f2 856 858 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 3f5 85b
85f 3f9 85a 861
:3 0 3fc 843 863
:2 0 865 3ff 866
840 865 0 867
401 0 868 403
86b :3 0 86b 0
86b 86a 868 869
:6 0 86d f :3 0
406 86f 408 86e
86d :2 0 870 40a
:2 0 872 0 872
871 81f 870 :6 0
874 1 :3 0 40d
875 80f 874 0
876 40f 0 87a
5a :3 0 38 :2 0
877 878 0 87a
411 87c 6ab 79a
0 87d 0 87a
0 87d 415 0
989 9b :3 0 58
:3 0 38 :2 0 418
87e 881 fb :3 0
bf :2 0 122 :3 0
883 885 0 41d
884 887 :3 0 f5
:3 0 123 :3 0 29
:3 0 124 :3 0 2a
:3 0 125 :3 0 5a
:3 0 86 :3 0 21
:4 0 126 1 :8 0
8a8 127 :4 0 893
:3 0 128 :3 0 bf
:2 0 422 896 897
:3 0 8b :3 0 b2
:3 0 899 89a 0
38 :2 0 89b 89c
0 89e 425 8a5
8b :3 0 b2 :3 0
89f 8a0 0 129
:2 0 8a1 8a2 0
8a4 427 8a6 898
89e 0 8a7 0
8a4 0 8a7 429
0 8a8 42c 8fb
b4 :3 0 8b :3 0
b2 :3 0 8aa 8ab
0 b3 :3 0 8ac
8ad 0 8af 42f
8b1 431 8b0 8af
:2 0 8f9 b5 :3 0
8b :3 0 b2 :3 0
8b4 8b5 0 b3
:3 0 8b6 8b7 0
8f1 8e :3 0 8f
:3 0 8b9 8ba 0
8e :3 0 a1 :3 0
8bc 8bd 0 b6
:2 0 2 :4 0 12a
:2 0 a3 :2 0 35
:2 0 433 8c2 8c4
:3 0 436 8be 8c6
8bb 8c8 8c7 :2 0
91 :3 0 a4 :3 0
8ca 8cb 0 93
:4 0 12b :4 0 96
:2 0 97 :3 0 43a
8cf 8d1 :3 0 96
:2 0 b9 :4 0 43d
8d3 8d5 :3 0 96
:2 0 ba :4 0 440
8d7 8d9 :3 0 96
:2 0 b3 :3 0 443
8db 8dd :3 0 96
:2 0 bb :4 0 446
8df 8e1 :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 449 8e4 8e8
44d 8e3 8ea :3 0
450 8cc 8ec :2 0
8ee 453 8ef 8c9
8ee 0 8f0 455
0 8f1 457 8f4
:3 0 8f4 0 8f4
8f3 8f1 8f2 :6 0
8f6 11 :3 0 45a
8f8 45c 8f7 8f6
:2 0 8f9 45e :2 0
8fb 0 8fb 8fa
8a8 8f9 :6 0 8fd
1 :3 0 461 973
f5 :3 0 12c :3 0
29 :3 0 12d :3 0
2a :3 0 12e :3 0
5a :3 0 86 :3 0
21 :4 0 12f 1
:8 0 91d 127 :4 0
908 :3 0 128 :3 0
bf :2 0 465 90b
90c :3 0 8b :3 0
b2 :3 0 90e 90f
0 38 :2 0 910
911 0 913 468
91a 8b :3 0 b2
:3 0 914 915 0
129 :2 0 916 917
0 919 46a 91b
90d 913 0 91c
0 919 0 91c
46c 0 91d 46f
970 b4 :3 0 8b
:3 0 b2 :3 0 91f
920 0 b3 :3 0
921 922 0 924
472 926 474 925
924 :2 0 96e b5
:3 0 8b :3 0 b2
:3 0 929 92a 0
b3 :3 0 92b 92c
0 966 8e :3 0
8f :3 0 92e 92f
0 8e :3 0 a1
:3 0 931 932 0
b6 :2 0 2 :4 0
130 :2 0 a3 :2 0
35 :2 0 476 937
939 :3 0 479 933
93b 930 93d 93c
:2 0 91 :3 0 a4
:3 0 93f 940 0
93 :4 0 131 :4 0
96 :2 0 97 :3 0
47d 944 946 :3 0
96 :2 0 b9 :4 0
480 948 94a :3 0
96 :2 0 ba :4 0
483 94c 94e :3 0
96 :2 0 b3 :3 0
486 950 952 :3 0
96 :2 0 bb :4 0
489 954 956 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 48c 959
95d 490 958 95f
:3 0 493 941 961
:2 0 963 496 964
93e 963 0 965
498 0 966 49a
969 :3 0 969 0
969 968 966 967
:6 0 96b 13 :3 0
49d 96d 49f 96c
96b :2 0 96e 4a1
:2 0 970 0 970
96f 91d 96e :6 0
972 1 :3 0 4a4
974 888 8fd 0
975 0 972 0
975 4a6 0 989
8b :3 0 b2 :3 0
976 977 0 8b
:3 0 bf :2 0 132
:3 0 979 97b 0
4ab 97a 97d :3 0
97e :2 0 70 :3 0
133 :3 0 24 :3 0
4ae 981 983 980
984 0 986 4b0
987 97f 986 0
988 4b2 0 989
4b4 e94 7c :3 0
38 :2 0 98a 98b
0 e93 64 :3 0
38 :2 0 98d 98e
0 e93 9b :3 0
56 :3 0 38 :2 0
4b8 990 993 fb
:3 0 bf :2 0 134
:3 0 995 997 0
4bd 996 999 :3 0
9b :3 0 56 :3 0
38 :2 0 4c0 99b
99e fb :3 0 bf
:2 0 135 :3 0 9a0
9a2 0 4c5 9a1
9a4 :3 0 99a 9a6
9a5 :2 0 136 :3 0
81 :3 0 64 :3 0
85 :3 0 86 :3 0
24 :3 0 81 :3 0
d3 :3 0 bc :3 0
27 :3 0 d3 :3 0
bc :3 0 28 :4 0
137 1 :8 0 9bb
8b :3 0 b2 :3 0
9b6 9b7 0 b3
:3 0 9b8 9b9 0
9bb 4c8 a0e b4
:3 0 8b :3 0 b2
:3 0 9bd 9be 0
b3 :3 0 9bf 9c0
0 9c2 4cb 9c4
4cd 9c3 9c2 :2 0
a0c b5 :3 0 8b
:3 0 b2 :3 0 9c7
9c8 0 b3 :3 0
9c9 9ca 0 a04
8e :3 0 8f :3 0
9cc 9cd 0 8e
:3 0 a1 :3 0 9cf
9d0 0 b6 :2 0
2 :4 0 138 :2 0
a3 :2 0 35 :2 0
4cf 9d5 9d7 :3 0
4d2 9d1 9d9 9ce
9db 9da :2 0 91
:3 0 a4 :3 0 9dd
9de 0 93 :4 0
139 :4 0 96 :2 0
97 :3 0 4d6 9e2
9e4 :3 0 96 :2 0
b9 :4 0 4d9 9e6
9e8 :3 0 96 :2 0
ba :4 0 4dc 9ea
9ec :3 0 96 :2 0
b3 :3 0 4df 9ee
9f0 :3 0 96 :2 0
bb :4 0 4e2 9f2
9f4 :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
4e5 9f7 9fb 4e9
9f6 9fd :3 0 4ec
9df 9ff :2 0 a01
4ef a02 9dc a01
0 a03 4f1 0
a04 4f3 a07 :3 0
a07 0 a07 a06
a04 a05 :6 0 a09
15 :3 0 4f6 a0b
4f8 a0a a09 :2 0
a0c 4fa :2 0 a0e
0 a0e a0d 9bb
a0c :6 0 a10 1
:3 0 4fd a11 9a7
a10 0 a12 4ff
0 e93 102 :3 0
103 :3 0 a13 a14
0 29 :3 0 27
:3 0 104 :2 0 501
a15 a19 106 :2 0
38 :2 0 507 a1b
a1d :3 0 102 :3 0
10f :3 0 81 :3 0
102 :3 0 110 :3 0
111 :3 0 112 :3 0
113 :3 0 29 :3 0
85 :3 0 86 :3 0
24 :3 0 81 :3 0
d3 :3 0 bc :3 0
29 :4 0 114 1
:8 0 a35 8b :3 0
b2 :3 0 a30 a31
0 b3 :3 0 a32
a33 0 a35 50a
a88 b4 :3 0 8b
:3 0 b2 :3 0 a37
a38 0 b3 :3 0
a39 a3a 0 a3c
50d a3e 50f a3d
a3c :2 0 a86 b5
:3 0 8b :3 0 b2
:3 0 a41 a42 0
b3 :3 0 a43 a44
0 a7e 8e :3 0
8f :3 0 a46 a47
0 8e :3 0 a1
:3 0 a49 a4a 0
b6 :2 0 2 :4 0
13a :2 0 a3 :2 0
35 :2 0 511 a4f
a51 :3 0 514 a4b
a53 a48 a55 a54
:2 0 91 :3 0 a4
:3 0 a57 a58 0
93 :4 0 13b :4 0
96 :2 0 97 :3 0
518 a5c a5e :3 0
96 :2 0 b9 :4 0
51b a60 a62 :3 0
96 :2 0 ba :4 0
51e a64 a66 :3 0
96 :2 0 b3 :3 0
521 a68 a6a :3 0
96 :2 0 bb :4 0
524 a6c a6e :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 527 a71
a75 52b a70 a77
:3 0 52e a59 a79
:2 0 a7b 531 a7c
a56 a7b 0 a7d
533 0 a7e 535
a81 :3 0 a81 0
a81 a80 a7e a7f
:6 0 a83 17 :3 0
538 a85 53a a84
a83 :2 0 a86 53c
:2 0 a88 0 a88
a87 a35 a86 :6 0
b27 1 :3 0 8b
:3 0 b2 :3 0 a8a
a8b 0 8b :3 0
bf :2 0 c0 :3 0
a8d a8f 0 541
a8e a91 :3 0 a92
:2 0 102 :3 0 10f
:3 0 d3 :3 0 bc
:3 0 29 :3 0 102
:3 0 110 :3 0 29
:3 0 117 :4 0 118
1 :8 0 aa3 8b
:3 0 b2 :3 0 a9e
a9f 0 b3 :3 0
aa0 aa1 0 aa3
544 af6 b4 :3 0
8b :3 0 b2 :3 0
aa5 aa6 0 b3
:3 0 aa7 aa8 0
aaa 547 aac 549
aab aaa :2 0 af4
b5 :3 0 8b :3 0
b2 :3 0 aaf ab0
0 b3 :3 0 ab1
ab2 0 aec 8e
:3 0 8f :3 0 ab4
ab5 0 8e :3 0
a1 :3 0 ab7 ab8
0 b6 :2 0 2
:4 0 13c :2 0 a3
:2 0 35 :2 0 54b
abd abf :3 0 54e
ab9 ac1 ab6 ac3
ac2 :2 0 91 :3 0
a4 :3 0 ac5 ac6
0 93 :4 0 13d
:4 0 96 :2 0 97
:3 0 552 aca acc
:3 0 96 :2 0 b9
:4 0 555 ace ad0
:3 0 96 :2 0 ba
:4 0 558 ad2 ad4
:3 0 96 :2 0 b3
:3 0 55b ad6 ad8
:3 0 96 :2 0 bb
:4 0 55e ada adc
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 561
adf ae3 565 ade
ae5 :3 0 568 ac7
ae7 :2 0 ae9 56b
aea ac4 ae9 0
aeb 56d 0 aec
56f aef :3 0 aef
0 aef aee aec
aed :6 0 af1 19
:3 0 572 af3 574
af2 af1 :2 0 af4
576 :2 0 af6 0
af6 af5 aa3 af4
:6 0 b03 1 :3 0
64 :3 0 9b :3 0
64 :3 0 38 :2 0
579 af9 afc 10b
:2 0 35 :2 0 57c
afe b00 :3 0 af8
b01 0 b03 57f
b04 a93 b03 0
b05 582 0 b27
9b :3 0 56 :3 0
38 :2 0 584 b06
b09 fb :3 0 bf
:2 0 134 :3 0 b0b
b0d 0 589 b0c
b0f :3 0 9b :3 0
56 :3 0 38 :2 0
58c b11 b14 fb
:3 0 bf :2 0 135
:3 0 b16 b18 0
591 b17 b1a :3 0
b10 b1c b1b :2 0
2a :3 0 a6 :4 0
b1e b1f 0 b24
7c :3 0 35 :2 0
b21 b22 0 b24
594 b25 b1d b24
0 b26 597 0
b27 599 d51 9b
:3 0 50 :3 0 38
:2 0 59d b28 b2b
105 :2 0 38 :2 0
5a2 b2d b2f :3 0
70 :3 0 38 :2 0
b31 b32 0 c44
136 :3 0 70 :3 0
117 :3 0 13e :3 0
ae :3 0 24 :3 0
df :3 0 21 :3 0
13f :3 0 81 :3 0
d3 :3 0 bc :3 0
2a :4 0 140 1
:8 0 b47 8b :3 0
b2 :3 0 b42 b43
0 b3 :3 0 b44
b45 0 b47 5a5
b9a b4 :3 0 8b
:3 0 b2 :3 0 b49
b4a 0 b3 :3 0
b4b b4c 0 b4e
5a8 b50 5aa b4f
b4e :2 0 b98 b5
:3 0 8b :3 0 b2
:3 0 b53 b54 0
b3 :3 0 b55 b56
0 b90 8e :3 0
8f :3 0 b58 b59
0 8e :3 0 a1
:3 0 b5b b5c 0
b6 :2 0 2 :4 0
141 :2 0 a3 :2 0
35 :2 0 5ac b61
b63 :3 0 5af b5d
b65 b5a b67 b66
:2 0 91 :3 0 a4
:3 0 b69 b6a 0
93 :4 0 142 :4 0
96 :2 0 97 :3 0
5b3 b6e b70 :3 0
96 :2 0 b9 :4 0
5b6 b72 b74 :3 0
96 :2 0 ba :4 0
5b9 b76 b78 :3 0
96 :2 0 b3 :3 0
5bc b7a b7c :3 0
96 :2 0 bb :4 0
5bf b7e b80 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 5c2 b83
b87 5c6 b82 b89
:3 0 5c9 b6b b8b
:2 0 b8d 5cc b8e
b68 b8d 0 b8f
5ce 0 b90 5d0
b93 :3 0 b93 0
b93 b92 b90 b91
:6 0 b95 1b :3 0
5d3 b97 5d5 b96
b95 :2 0 b98 5d7
:2 0 b9a 0 b9a
b99 b47 b98 :6 0
c44 1 :3 0 9b
:3 0 70 :3 0 38
:2 0 5da b9c b9f
bf :2 0 38 :2 0
5df ba1 ba3 :3 0
136 :3 0 70 :3 0
117 :3 0 e1 :3 0
ae :3 0 24 :3 0
df :3 0 21 :3 0
d3 :3 0 bc :3 0
e8 :3 0 d3 :3 0
bc :3 0 2a :4 0
143 1 :8 0 bb9
8b :3 0 b2 :3 0
bb4 bb5 0 b3
:3 0 bb6 bb7 0
bb9 5e2 c0c b4
:3 0 8b :3 0 b2
:3 0 bbb bbc 0
b3 :3 0 bbd bbe
0 bc0 5e5 bc2
5e7 bc1 bc0 :2 0
c0a b5 :3 0 8b
:3 0 b2 :3 0 bc5
bc6 0 b3 :3 0
bc7 bc8 0 c02
8e :3 0 8f :3 0
bca bcb 0 8e
:3 0 a1 :3 0 bcd
bce 0 b6 :2 0
2 :4 0 144 :2 0
a3 :2 0 35 :2 0
5e9 bd3 bd5 :3 0
5ec bcf bd7 bcc
bd9 bd8 :2 0 91
:3 0 a4 :3 0 bdb
bdc 0 93 :4 0
145 :4 0 96 :2 0
97 :3 0 5f0 be0
be2 :3 0 96 :2 0
b9 :4 0 5f3 be4
be6 :3 0 96 :2 0
ba :4 0 5f6 be8
bea :3 0 96 :2 0
b3 :3 0 5f9 bec
bee :3 0 96 :2 0
bb :4 0 5fc bf0
bf2 :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
5ff bf5 bf9 603
bf4 bfb :3 0 606
bdd bfd :2 0 bff
609 c00 bda bff
0 c01 60b 0
c02 60d c05 :3 0
c05 0 c05 c04
c02 c03 :6 0 c07
1d :3 0 610 c09
612 c08 c07 :2 0
c0a 614 :2 0 c0c
0 c0c c0b bb9
c0a :6 0 c0e 1
:3 0 617 c0f ba4
c0e 0 c10 619
0 c44 9b :3 0
70 :3 0 38 :2 0
61b c11 c14 105
:2 0 38 :2 0 620
c16 c18 :3 0 11
:3 0 21 :3 0 c1a
c1b 0 c41 8e
:3 0 8f :3 0 c1d
c1e 0 8e :3 0
a1 :3 0 c20 c21
0 35 :2 0 2
:4 0 146 :2 0 a3
:2 0 35 :2 0 623
c26 c28 :3 0 626
c22 c2a c1f c2c
c2b :2 0 91 :3 0
a4 :3 0 c2e c2f
0 93 :4 0 147
:4 0 96 :2 0 97
:3 0 62a c33 c35
:3 0 62d c30 c37
:2 0 c39 630 c3a
c2d c39 0 c3b
632 0 c41 12
:3 0 fb :3 0 148
:3 0 c3d c3e 0
c3f :2 0 c41 634
c42 c19 c41 0
c43 638 0 c44
63a c45 b30 c44
0 c46 63f 0
d50 102 :3 0 10f
:3 0 81 :3 0 102
:3 0 110 :3 0 111
:3 0 11b :3 0 113
:3 0 2a :3 0 85
:3 0 86 :3 0 24
:3 0 81 :3 0 d3
:3 0 bc :3 0 2a
:4 0 11c 1 :8 0
c5d 8b :3 0 b2
:3 0 c58 c59 0
b3 :3 0 c5a c5b
0 c5d 641 cb0
b4 :3 0 8b :3 0
b2 :3 0 c5f c60
0 b3 :3 0 c61
c62 0 c64 644
c66 646 c65 c64
:2 0 cae b5 :3 0
8b :3 0 b2 :3 0
c69 c6a 0 b3
:3 0 c6b c6c 0
ca6 8e :3 0 8f
:3 0 c6e c6f 0
8e :3 0 a1 :3 0
c71 c72 0 b6
:2 0 2 :4 0 149
:2 0 a3 :2 0 35
:2 0 648 c77 c79
:3 0 64b c73 c7b
c70 c7d c7c :2 0
91 :3 0 a4 :3 0
c7f c80 0 93
:4 0 14a :4 0 96
:2 0 97 :3 0 64f
c84 c86 :3 0 96
:2 0 b9 :4 0 652
c88 c8a :3 0 96
:2 0 ba :4 0 655
c8c c8e :3 0 96
:2 0 b3 :3 0 658
c90 c92 :3 0 96
:2 0 bb :4 0 65b
c94 c96 :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 65e c99 c9d
662 c98 c9f :3 0
665 c81 ca1 :2 0
ca3 668 ca4 c7e
ca3 0 ca5 66a
0 ca6 66c ca9
:3 0 ca9 0 ca9
ca8 ca6 ca7 :6 0
cab 1f :3 0 66f
cad 671 cac cab
:2 0 cae 673 :2 0
cb0 0 cb0 caf
c5d cae :6 0 d50
1 :3 0 8b :3 0
b2 :3 0 cb2 cb3
0 8b :3 0 bf
:2 0 c0 :3 0 cb5
cb7 0 678 cb6
cb9 :3 0 cba :2 0
102 :3 0 10f :3 0
d3 :3 0 bc :3 0
2a :3 0 102 :3 0
110 :3 0 2a :3 0
117 :4 0 11f 1
:8 0 ccb 8b :3 0
b2 :3 0 cc6 cc7
0 b3 :3 0 cc8
cc9 0 ccb 67b
d1e b4 :3 0 8b
:3 0 b2 :3 0 ccd
cce 0 b3 :3 0
ccf cd0 0 cd2
67e cd4 680 cd3
cd2 :2 0 d1c b5
:3 0 8b :3 0 b2
:3 0 cd7 cd8 0
b3 :3 0 cd9 cda
0 d14 8e :3 0
8f :3 0 cdc cdd
0 8e :3 0 a1
:3 0 cdf ce0 0
b6 :2 0 2 :4 0
14b :2 0 a3 :2 0
35 :2 0 682 ce5
ce7 :3 0 685 ce1
ce9 cde ceb cea
:2 0 91 :3 0 a4
:3 0 ced cee 0
93 :4 0 14c :4 0
96 :2 0 97 :3 0
689 cf2 cf4 :3 0
96 :2 0 b9 :4 0
68c cf6 cf8 :3 0
96 :2 0 ba :4 0
68f cfa cfc :3 0
96 :2 0 b3 :3 0
692 cfe d00 :3 0
96 :2 0 bb :4 0
695 d02 d04 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 698 d07
d0b 69c d06 d0d
:3 0 69f cef d0f
:2 0 d11 6a2 d12
cec d11 0 d13
6a4 0 d14 6a6
d17 :3 0 d17 0
d17 d16 d14 d15
:6 0 d19 21 :3 0
6a9 d1b 6ab d1a
d19 :2 0 d1c 6ad
:2 0 d1e 0 d1e
d1d ccb d1c :6 0
d20 1 :3 0 6b0
d21 cbb d20 0
d22 6b2 0 d50
9b :3 0 50 :3 0
38 :2 0 6b4 d23
d26 bf :2 0 38
:2 0 6b9 d28 d2a
:3 0 9b :3 0 56
:3 0 38 :2 0 6bc
d2c d2f fb :3 0
bf :2 0 134 :3 0
d31 d33 0 6c1
d32 d35 :3 0 9b
:3 0 56 :3 0 38
:2 0 6c4 d37 d3a
fb :3 0 bf :2 0
135 :3 0 d3c d3e
0 6c9 d3d d40
:3 0 d36 d42 d41
:2 0 d43 :2 0 d2b
d45 d44 :2 0 29
:3 0 a6 :4 0 d47
d48 0 d4d 7c
:3 0 35 :2 0 d4a
d4b 0 d4d 6cc
d4e d46 d4d 0
d4f 6cf 0 d50
6d1 d52 a1e b27
0 d53 0 d50
0 d53 6d6 0
e93 9b :3 0 64
:3 0 38 :2 0 6d9
d54 d57 105 :2 0
38 :2 0 6de d59
d5b :3 0 7c :3 0
bf :2 0 35 :2 0
6e3 d5e d60 :3 0
d5c d62 d61 :2 0
d63 :2 0 9b :3 0
56 :3 0 38 :2 0
6e6 d65 d68 fb
:3 0 bf :2 0 134
:3 0 d6a d6c 0
6eb d6b d6e :3 0
9b :3 0 56 :3 0
38 :2 0 6ee d70
d73 fb :3 0 bf
:2 0 135 :3 0 d75
d77 0 6f3 d76
d79 :3 0 d6f d7b
d7a :2 0 d7c :2 0
d64 d7e d7d :2 0
70 :3 0 14d :3 0
24 :3 0 29 :3 0
64 :3 0 2a :3 0
6f6 d81 d86 d80
d87 0 d89 6fb
d8a d7f d89 0
d8b 6fd 0 e93
70 :3 0 38 :2 0
d8c d8d 0 e93
136 :3 0 70 :3 0
117 :3 0 e1 :3 0
14e :3 0 14e :3 0
ae :3 0 24 :3 0
14e :3 0 df :3 0
21 :3 0 14e :3 0
c1 :3 0 e1 :3 0
14f :3 0 14f :3 0
ae :3 0 24 :3 0
14f :3 0 e2 :3 0
14e :3 0 c1 :3 0
d3 :3 0 bc :3 0
29 :3 0 d3 :3 0
bc :3 0 14f :3 0
e8 :3 0 d3 :3 0
bc :3 0 2a :3 0
d3 :3 0 bc :3 0
14f :3 0 e9 :4 0
150 1 :8 0 db9
8b :3 0 b2 :3 0
db4 db5 0 b3
:3 0 db6 db7 0
db9 6ff e0c b4
:3 0 8b :3 0 b2
:3 0 dbb dbc 0
b3 :3 0 dbd dbe
0 dc0 702 dc2
704 dc1 dc0 :2 0
e0a b5 :3 0 8b
:3 0 b2 :3 0 dc5
dc6 0 b3 :3 0
dc7 dc8 0 e02
8e :3 0 8f :3 0
dca dcb 0 8e
:3 0 a1 :3 0 dcd
dce 0 b6 :2 0
2 :4 0 151 :2 0
a3 :2 0 35 :2 0
706 dd3 dd5 :3 0
709 dcf dd7 dcc
dd9 dd8 :2 0 91
:3 0 a4 :3 0 ddb
ddc 0 93 :4 0
152 :4 0 96 :2 0
97 :3 0 70d de0
de2 :3 0 96 :2 0
b9 :4 0 710 de4
de6 :3 0 96 :2 0
ba :4 0 713 de8
dea :3 0 96 :2 0
b3 :3 0 716 dec
dee :3 0 96 :2 0
bb :4 0 719 df0
df2 :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
71c df5 df9 720
df4 dfb :3 0 723
ddd dfd :2 0 dff
726 e00 dda dff
0 e01 728 0
e02 72a e05 :3 0
e05 0 e05 e04
e02 e03 :6 0 e07
23 :3 0 72d e09
72f e08 e07 :2 0
e0a 731 :2 0 e0c
0 e0c e0b db9
e0a :6 0 e93 1
:3 0 9b :3 0 70
:3 0 38 :2 0 734
e0e e11 105 :2 0
38 :2 0 739 e13
e15 :3 0 11 :3 0
21 :3 0 e17 e18
0 e3e 8e :3 0
8f :3 0 e1a e1b
0 8e :3 0 a1
:3 0 e1d e1e 0
35 :2 0 2 :4 0
153 :2 0 a3 :2 0
35 :2 0 73c e23
e25 :3 0 73f e1f
e27 e1c e29 e28
:2 0 91 :3 0 a4
:3 0 e2b e2c 0
93 :4 0 154 :4 0
96 :2 0 97 :3 0
743 e30 e32 :3 0
746 e2d e34 :2 0
e36 749 e37 e2a
e36 0 e38 74b
0 e3e 12 :3 0
fb :3 0 155 :3 0
e3a e3b 0 e3c
:2 0 e3e 74d e3f
e16 e3e 0 e40
751 0 e93 70
:3 0 156 :3 0 24
:3 0 21 :3 0 27
:3 0 28 :3 0 29
:3 0 2a :3 0 57
:3 0 66 :3 0 70
:3 0 4a :3 0 9b
:3 0 56 :3 0 38
:2 0 753 e4d e50
38 :2 0 756 e42
e53 e41 e54 0
e93 9b :3 0 70
:3 0 38 :2 0 763
e56 e59 bf :2 0
38 :2 0 768 e5b
e5d :3 0 70 :3 0
133 :3 0 24 :3 0
76b e60 e62 e5f
e63 0 e65 76d
e90 11 :3 0 21
:3 0 e66 e67 0
e8f 8e :3 0 8f
:3 0 e69 e6a 0
8e :3 0 a1 :3 0
e6c e6d 0 35
:2 0 2 :4 0 157
:2 0 a3 :2 0 35
:2 0 76f e72 e74
:3 0 772 e6e e76
e6b e78 e77 :2 0
91 :3 0 a4 :3 0
e7a e7b 0 93
:4 0 158 :4 0 96
:2 0 97 :3 0 776
e7f e81 :3 0 779
e7c e83 :2 0 e85
77c e86 e79 e85
0 e87 77e 0
e8f 12 :3 0 9b
:3 0 70 :3 0 38
:2 0 780 e89 e8c
e8d :2 0 e8f 783
e91 e5e e65 0
e92 0 e8f 0
e92 787 0 e93
78a e95 69f 989
0 e96 0 e93
0 e96 795 0
e98 159 :3 0 798
1077 9b :3 0 16
:3 0 38 :2 0 79a
e99 e9c 9b :3 0
106 :2 0 50 :3 0
38 :2 0 79d e9e
ea2 7a2 e9f ea4
:3 0 ea5 :2 0 9b
:3 0 4b :3 0 38
:2 0 7a5 ea7 eaa
105 :2 0 38 :2 0
7aa eac eae :3 0
eaf :2 0 ea6 eb1
eb0 :2 0 62 :3 0
38 :2 0 eb3 eb4
0 1075 9b :3 0
16 :3 0 38 :2 0
7ad eb6 eb9 9b
:3 0 105 :2 0 4b
:3 0 38 :2 0 7b0
ebb ebf 7b5 ebc
ec1 :3 0 11 :3 0
21 :3 0 ec3 ec4
0 eeb 8e :3 0
8f :3 0 ec6 ec7
0 8e :3 0 a1
:3 0 ec9 eca 0
35 :2 0 2 :4 0
15a :2 0 a3 :2 0
35 :2 0 7b8 ecf
ed1 :3 0 7bb ecb
ed3 ec8 ed5 ed4
:2 0 91 :3 0 a4
:3 0 ed7 ed8 0
93 :4 0 15b :4 0
96 :2 0 97 :3 0
7bf edc ede :3 0
7c2 ed9 ee0 :2 0
ee2 7c5 ee3 ed6
ee2 0 ee4 7c7
0 eeb 12 :3 0
fb :3 0 15c :3 0
ee6 ee7 0 ee8
:2 0 eeb 159 :3 0
7c9 efe 9b :3 0
16 :3 0 38 :2 0
7cd eec eef 9b
:3 0 bf :2 0 4b
:3 0 38 :2 0 7d0
ef1 ef5 7d5 ef2
ef7 :3 0 62 :3 0
35 :2 0 ef9 efa
0 efc 7d8 efd
ef8 efc 0 eff
ec2 eeb 0 eff
7da 0 1075 70
:3 0 38 :2 0 f00
f01 0 1075 136
:3 0 70 :3 0 117
:3 0 15d :3 0 86
:3 0 e1 :3 0 14e
:3 0 15e :3 0 15d
:3 0 14e :3 0 df
:3 0 21 :3 0 14e
:3 0 e2 :3 0 15d
:3 0 e2 :3 0 15d
:3 0 e2 :3 0 15d
:3 0 86 :3 0 15d
:3 0 15f :3 0 fb
:3 0 160 :4 0 161
1 :8 0 f21 8b
:3 0 b2 :3 0 f1c
f1d 0 b3 :3 0
f1e f1f 0 f21
7dd f74 b4 :3 0
8b :3 0 b2 :3 0
f23 f24 0 b3
:3 0 f25 f26 0
f28 7e0 f2a 7e2
f29 f28 :2 0 f72
b5 :3 0 8b :3 0
b2 :3 0 f2d f2e
0 b3 :3 0 f2f
f30 0 f6a 8e
:3 0 8f :3 0 f32
f33 0 8e :3 0
a1 :3 0 f35 f36
0 b6 :2 0 2
:4 0 162 :2 0 a3
:2 0 35 :2 0 7e4
f3b f3d :3 0 7e7
f37 f3f f34 f41
f40 :2 0 91 :3 0
a4 :3 0 f43 f44
0 93 :4 0 163
:4 0 96 :2 0 97
:3 0 7eb f48 f4a
:3 0 96 :2 0 b9
:4 0 7ee f4c f4e
:3 0 96 :2 0 ba
:4 0 7f1 f50 f52
:3 0 96 :2 0 b3
:3 0 7f4 f54 f56
:3 0 96 :2 0 bb
:4 0 7f7 f58 f5a
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 7fa
f5d f61 7fe f5c
f63 :3 0 801 f45
f65 :2 0 f67 804
f68 f42 f67 0
f69 806 0 f6a
808 f6d :3 0 f6d
0 f6d f6c f6a
f6b :6 0 f6f 25
:3 0 80b f71 80d
f70 f6f :2 0 f72
80f :2 0 f74 0
f74 f73 f21 f72
:6 0 1075 1 :3 0
9b :3 0 70 :3 0
38 :2 0 812 f76
f79 105 :2 0 38
:2 0 817 f7b f7d
:3 0 11 :3 0 21
:3 0 f7f f80 0
fa6 8e :3 0 8f
:3 0 f82 f83 0
8e :3 0 a1 :3 0
f85 f86 0 35
:2 0 2 :4 0 164
:2 0 a3 :2 0 35
:2 0 81a f8b f8d
:3 0 81d f87 f8f
f84 f91 f90 :2 0
91 :3 0 a4 :3 0
f93 f94 0 93
:4 0 165 :4 0 96
:2 0 97 :3 0 821
f98 f9a :3 0 824
f95 f9c :2 0 f9e
827 f9f f92 f9e
0 fa0 829 0
fa6 12 :3 0 fb
:3 0 101 :3 0 fa2
fa3 0 fa4 :2 0
fa6 82b fa7 f7e
fa6 0 fa8 82f
0 1075 70 :3 0
38 :2 0 fa9 faa
0 1075 136 :3 0
70 :3 0 117 :3 0
e1 :3 0 14e :3 0
166 :3 0 167 :3 0
168 :3 0 168 :3 0
86 :3 0 14e :3 0
ae :3 0 168 :3 0
ad :3 0 14e :3 0
ad :3 0 14e :3 0
ae :3 0 24 :3 0
14e :3 0 df :3 0
21 :3 0 d3 :3 0
bc :3 0 14e :3 0
cb :3 0 168 :3 0
169 :4 0 16a 1
:8 0 fce 8b :3 0
b2 :3 0 fc9 fca
0 b3 :3 0 fcb
fcc 0 fce 831
1021 b4 :3 0 8b
:3 0 b2 :3 0 fd0
fd1 0 b3 :3 0
fd2 fd3 0 fd5
834 fd7 836 fd6
fd5 :2 0 101f b5
:3 0 8b :3 0 b2
:3 0 fda fdb 0
b3 :3 0 fdc fdd
0 1017 8e :3 0
8f :3 0 fdf fe0
0 8e :3 0 a1
:3 0 fe2 fe3 0
b6 :2 0 2 :4 0
16b :2 0 a3 :2 0
35 :2 0 838 fe8
fea :3 0 83b fe4
fec fe1 fee fed
:2 0 91 :3 0 a4
:3 0 ff0 ff1 0
93 :4 0 16c :4 0
96 :2 0 97 :3 0
83f ff5 ff7 :3 0
96 :2 0 b9 :4 0
842 ff9 ffb :3 0
96 :2 0 ba :4 0
845 ffd fff :3 0
96 :2 0 b3 :3 0
848 1001 1003 :3 0
96 :2 0 bb :4 0
84b 1005 1007 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 84e 100a
100e 852 1009 1010
:3 0 855 ff2 1012
:2 0 1014 858 1015
fef 1014 0 1016
85a 0 1017 85c
101a :3 0 101a 0
101a 1019 1017 1018
:6 0 101c 27 :3 0
85f 101e 861 101d
101c :2 0 101f 863
:2 0 1021 0 1021
1020 fce 101f :6 0
1075 1 :3 0 9b
:3 0 70 :3 0 38
:2 0 866 1023 1026
105 :2 0 38 :2 0
86b 1028 102a :3 0
11 :3 0 21 :3 0
102c 102d 0 1053
8e :3 0 8f :3 0
102f 1030 0 8e
:3 0 a1 :3 0 1032
1033 0 35 :2 0
2 :4 0 16d :2 0
a3 :2 0 35 :2 0
86e 1038 103a :3 0
871 1034 103c 1031
103e 103d :2 0 91
:3 0 a4 :3 0 1040
1041 0 93 :4 0
16e :4 0 96 :2 0
97 :3 0 875 1045
1047 :3 0 878 1042
1049 :2 0 104b 87b
104c 103f 104b 0
104d 87d 0 1053
12 :3 0 fb :3 0
16f :3 0 104f 1050
0 1051 :2 0 1053
87f 1054 102b 1053
0 1055 883 0
1075 51 :3 0 9b
:3 0 16 :3 0 38
:2 0 885 1057 105a
1056 105b 0 1075
70 :3 0 170 :3 0
24 :3 0 21 :3 0
51 :3 0 4a :3 0
9b :3 0 62 :3 0
38 :2 0 888 1063
1066 9b :3 0 57
:3 0 38 :2 0 88b
1068 106b 9b :3 0
56 :3 0 38 :2 0
88e 106d 1070 891
105e 1072 105d 1073
0 1075 899 1076
eb2 1075 0 1078
696 e98 0 1078
8a4 0 10b5 9b
:3 0 70 :3 0 38
:2 0 8a7 1079 107c
bf :2 0 38 :2 0
8ac 107e 1080 :3 0
70 :3 0 133 :3 0
24 :3 0 8af 1083
1085 1082 1086 0
1088 8b1 1089 1081
1088 0 108a 8b3
0 10b5 11 :3 0
21 :3 0 108b 108c
0 10b5 8e :3 0
8f :3 0 108e 108f
0 8e :3 0 a1
:3 0 1091 1092 0
35 :2 0 2 :4 0
171 :2 0 a3 :2 0
35 :2 0 8b5 1097
1099 :3 0 8b8 1093
109b 1090 109d 109c
:2 0 91 :3 0 a4
:3 0 109f 10a0 0
93 :4 0 172 :4 0
96 :2 0 97 :3 0
8bc 10a4 10a6 :3 0
8bf 10a1 10a8 :2 0
10aa 8c2 10ab 109e
10aa 0 10ac 8c4
0 10b5 12 :3 0
9b :3 0 70 :3 0
38 :2 0 8c6 10ae
10b1 10b2 :2 0 10b5
159 :3 0 8c9 2985
8 :3 0 10a :2 0
8d6 10b7 10b8 :3 0
10b9 :2 0 a :3 0
10a :2 0 8d8 10bc
10bd :3 0 10be :2 0
10ba 10c0 10bf :2 0
29 :3 0 8 :3 0
10c2 10c3 0 2896
2a :3 0 a :3 0
10c5 10c6 0 2896
102 :3 0 103 :3 0
10c8 10c9 0 29
:3 0 2a :3 0 104
:2 0 8da 10ca 10ce
105 :2 0 38 :2 0
8e0 10d0 10d2 :3 0
10d3 :2 0 102 :3 0
103 :3 0 10d5 10d6
0 2a :3 0 28
:3 0 104 :2 0 8e3
10d7 10db 106 :2 0
38 :2 0 8e9 10dd
10df :3 0 10e0 :2 0
10d4 10e2 10e1 :2 0
11 :3 0 21 :3 0
10e4 10e5 0 110b
8e :3 0 8f :3 0
10e7 10e8 0 8e
:3 0 a1 :3 0 10ea
10eb 0 35 :2 0
2 :4 0 173 :2 0
a3 :2 0 35 :2 0
8ec 10f0 10f2 :3 0
8ef 10ec 10f4 10e9
10f6 10f5 :2 0 91
:3 0 a4 :3 0 10f8
10f9 0 93 :4 0
174 :4 0 96 :2 0
97 :3 0 8f3 10fd
10ff :3 0 8f6 10fa
1101 :2 0 1103 8f9
1104 10f7 1103 0
1105 8fb 0 110b
12 :3 0 fb :3 0
109 :3 0 1107 1108
0 1109 :2 0 110b
8fd 110c 10e3 110b
0 110d 901 0
2896 22 :3 0 10a
:2 0 903 110f 1110
:3 0 1111 :2 0 cd
:3 0 ce :3 0 ca
:3 0 2c :3 0 2d
:3 0 67 :3 0 e1
:3 0 e2 :3 0 22
:4 0 175 1 :8 0
1122 8b :3 0 b2
:3 0 111d 111e 0
b3 :3 0 111f 1120
0 1122 905 1175
b4 :3 0 8b :3 0
b2 :3 0 1124 1125
0 b3 :3 0 1126
1127 0 1129 908
112b 90a 112a 1129
:2 0 1173 b5 :3 0
8b :3 0 b2 :3 0
112e 112f 0 b3
:3 0 1130 1131 0
116b 8e :3 0 8f
:3 0 1133 1134 0
8e :3 0 a1 :3 0
1136 1137 0 b6
:2 0 2 :4 0 176
:2 0 a3 :2 0 35
:2 0 90c 113c 113e
:3 0 90f 1138 1140
1135 1142 1141 :2 0
91 :3 0 a4 :3 0
1144 1145 0 93
:4 0 177 :4 0 96
:2 0 97 :3 0 913
1149 114b :3 0 96
:2 0 b9 :4 0 916
114d 114f :3 0 96
:2 0 ba :4 0 919
1151 1153 :3 0 96
:2 0 b3 :3 0 91c
1155 1157 :3 0 96
:2 0 bb :4 0 91f
1159 115b :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 922 115e 1162
926 115d 1164 :3 0
929 1146 1166 :2 0
1168 92c 1169 1143
1168 0 116a 92e
0 116b 930 116e
:3 0 116e 0 116e
116d 116b 116c :6 0
1170 29 :3 0 933
1172 935 1171 1170
:2 0 1173 937 :2 0
1175 0 1175 1174
1122 1173 :6 0 1237
1 :3 0 8b :3 0
b2 :3 0 1177 1178
0 8b :3 0 106
:2 0 132 :3 0 117a
117c 0 93c 117b
117e :3 0 117f :2 0
11 :3 0 22 :3 0
1181 1182 0 11a8
8e :3 0 8f :3 0
1184 1185 0 8e
:3 0 a1 :3 0 1187
1188 0 35 :2 0
2 :4 0 178 :2 0
a3 :2 0 35 :2 0
93f 118d 118f :3 0
942 1189 1191 1186
1193 1192 :2 0 91
:3 0 a4 :3 0 1195
1196 0 93 :4 0
179 :4 0 96 :2 0
97 :3 0 946 119a
119c :3 0 949 1197
119e :2 0 11a0 94c
11a1 1194 11a0 0
11a2 94e 0 11a8
12 :3 0 fb :3 0
155 :3 0 11a4 11a5
0 11a6 :2 0 11a8
950 11a9 1180 11a8
0 11aa 954 0
1237 102 :3 0 103
:3 0 11ab 11ac 0
29 :3 0 2c :3 0
104 :2 0 956 11ad
11b1 17a :2 0 38
:2 0 95c 11b3 11b5
:3 0 11b6 :2 0 102
:3 0 103 :3 0 11b8
11b9 0 29 :3 0
2d :3 0 104 :2 0
95f 11ba 11be 105
:2 0 38 :2 0 965
11c0 11c2 :3 0 11c3
:2 0 11b7 11c5 11c4
:2 0 11 :3 0 22
:3 0 11c7 11c8 0
11ef 8e :3 0 8f
:3 0 11ca 11cb 0
8e :3 0 a1 :3 0
11cd 11ce 0 35
:2 0 2 :4 0 17b
:2 0 a3 :2 0 35
:2 0 968 11d3 11d5
:3 0 96b 11cf 11d7
11cc 11d9 11d8 :2 0
91 :3 0 a4 :3 0
11db 11dc 0 93
:4 0 17c :4 0 96
:2 0 97 :3 0 96f
11e0 11e2 :3 0 972
11dd 11e4 :2 0 11e6
975 11e7 11da 11e6
0 11e8 977 0
11ef 12 :3 0 fb
:3 0 155 :3 0 11ea
11eb 0 11ec :2 0
11ef 159 :3 0 979
1235 102 :3 0 103
:3 0 11f0 11f1 0
2a :3 0 2c :3 0
104 :2 0 97d 11f2
11f6 17a :2 0 38
:2 0 983 11f8 11fa
:3 0 11fb :2 0 102
:3 0 103 :3 0 11fd
11fe 0 2a :3 0
2d :3 0 104 :2 0
986 11ff 1203 105
:2 0 38 :2 0 98c
1205 1207 :3 0 1208
:2 0 11fc 120a 1209
:2 0 11 :3 0 22
:3 0 120c 120d 0
1233 8e :3 0 8f
:3 0 120f 1210 0
8e :3 0 a1 :3 0
1212 1213 0 35
:2 0 2 :4 0 17d
:2 0 a3 :2 0 35
:2 0 98f 1218 121a
:3 0 992 1214 121c
1211 121e 121d :2 0
91 :3 0 a4 :3 0
1220 1221 0 93
:4 0 17e :4 0 96
:2 0 97 :3 0 996
1225 1227 :3 0 999
1222 1229 :2 0 122b
99c 122c 121f 122b
0 122d 99e 0
1233 12 :3 0 fb
:3 0 155 :3 0 122f
1230 0 1231 :2 0
1233 9a0 1234 120b
1233 0 1236 11c6
11ef 0 1236 9a4
0 1237 9a7 1238
1112 1237 0 1239
9ab 0 2896 e7
:3 0 e6 :3 0 cc
:3 0 e8 :3 0 e9
:3 0 ec :3 0 57
:3 0 56 :3 0 37
:3 0 2e :3 0 2f
:3 0 68 :3 0 f5
:3 0 ae :3 0 24
:3 0 86 :3 0 48
:4 0 17f 1 :8 0
1251 8b :3 0 b2
:3 0 124c 124d 0
b3 :3 0 124e 124f
0 1251 9ad 12a4
b4 :3 0 8b :3 0
b2 :3 0 1253 1254
0 b3 :3 0 1255
1256 0 1258 9b0
125a 9b2 1259 1258
:2 0 12a2 b5 :3 0
8b :3 0 b2 :3 0
125d 125e 0 b3
:3 0 125f 1260 0
129a 8e :3 0 8f
:3 0 1262 1263 0
8e :3 0 a1 :3 0
1265 1266 0 b6
:2 0 2 :4 0 180
:2 0 a3 :2 0 35
:2 0 9b4 126b 126d
:3 0 9b7 1267 126f
1264 1271 1270 :2 0
91 :3 0 a4 :3 0
1273 1274 0 93
:4 0 181 :4 0 96
:2 0 97 :3 0 9bb
1278 127a :3 0 96
:2 0 b9 :4 0 9be
127c 127e :3 0 96
:2 0 ba :4 0 9c1
1280 1282 :3 0 96
:2 0 b3 :3 0 9c4
1284 1286 :3 0 96
:2 0 bb :4 0 9c7
1288 128a :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 9ca 128d 1291
9ce 128c 1293 :3 0
9d1 1275 1295 :2 0
1297 9d4 1298 1272
1297 0 1299 9d6
0 129a 9d8 129d
:3 0 129d 0 129d
129c 129a 129b :6 0
129f 2b :3 0 9db
12a1 9dd 12a0 129f
:2 0 12a2 9df :2 0
12a4 0 12a4 12a3
1251 12a2 :6 0 2896
1 :3 0 fd :3 0
9b :3 0 68 :3 0
38 :2 0 9e2 12a7
12aa fb :3 0 fe
:3 0 12ac 12ad 0
9e5 12a6 12af 12b0
:2 0 fb :3 0 bf
:2 0 fe :3 0 12b2
12b4 0 9ea 12b3
12b6 :3 0 11 :3 0
48 :3 0 12b8 12b9
0 12df 8e :3 0
8f :3 0 12bb 12bc
0 8e :3 0 a1
:3 0 12be 12bf 0
35 :2 0 2 :4 0
182 :2 0 a3 :2 0
35 :2 0 9ed 12c4
12c6 :3 0 9f0 12c0
12c8 12bd 12ca 12c9
:2 0 91 :3 0 a4
:3 0 12cc 12cd 0
93 :4 0 183 :4 0
96 :2 0 97 :3 0
9f4 12d1 12d3 :3 0
9f7 12ce 12d5 :2 0
12d7 9fa 12d8 12cb
12d7 0 12d9 9fc
0 12df 12 :3 0
fb :3 0 101 :3 0
12db 12dc 0 12dd
:2 0 12df 9fe 12e0
12b7 12df 0 12e1
a02 0 2896 bc
:3 0 36 :3 0 35
:2 0 35 :2 0 a04
12e2 12e6 bf :2 0
35 :4 0 a0a 12e8
12ea :3 0 42 :3 0
35 :2 0 12ec 12ed
0 12ef a0d 12f4
42 :3 0 38 :2 0
12f0 12f1 0 12f3
a0f 12f5 12eb 12ef
0 12f6 0 12f3
0 12f6 a11 0
2896 7d :3 0 38
:2 0 12f7 12f8 0
2896 7e :3 0 38
:2 0 12fa 12fb 0
2896 102 :3 0 103
:3 0 12fd 12fe 0
29 :3 0 27 :3 0
104 :2 0 a14 12ff
1303 106 :2 0 38
:2 0 a1a 1305 1307
:3 0 1308 :2 0 102
:3 0 103 :3 0 130a
130b 0 2a :3 0
28 :3 0 104 :2 0
a1d 130c 1310 106
:2 0 38 :2 0 a23
1312 1314 :3 0 1315
:2 0 1309 1317 1316
:2 0 9b :3 0 13
:3 0 38 :2 0 a26
1319 131c 9b :3 0
106 :2 0 4d :3 0
38 :2 0 a29 131e
1322 a2e 131f 1324
:3 0 1325 :2 0 1318
1327 1326 :2 0 102
:3 0 103 :3 0 1329
132a 0 29 :3 0
27 :3 0 104 :2 0
a31 132b 132f 106
:2 0 38 :2 0 a37
1331 1333 :3 0 9b
:3 0 37 :3 0 38
:2 0 a3a 1335 1338
105 :2 0 38 :2 0
a3f 133a 133c :3 0
102 :3 0 103 :3 0
133e 133f 0 29
:3 0 2e :3 0 104
:2 0 a42 1340 1344
17a :2 0 38 :2 0
a48 1346 1348 :3 0
133d 134a 1349 :2 0
11 :3 0 21 :3 0
134c 134d 0 1373
8e :3 0 8f :3 0
134f 1350 0 8e
:3 0 a1 :3 0 1352
1353 0 35 :2 0
2 :4 0 184 :2 0
a3 :2 0 35 :2 0
a4b 1358 135a :3 0
a4e 1354 135c 1351
135e 135d :2 0 91
:3 0 a4 :3 0 1360
1361 0 93 :4 0
185 :4 0 96 :2 0
97 :3 0 a52 1365
1367 :3 0 a55 1362
1369 :2 0 136b a58
136c 135f 136b 0
136d a5a 0 1373
12 :3 0 fb :3 0
148 :3 0 136f 1370
0 1371 :2 0 1373
a5c 1374 134b 1373
0 1375 a60 0
1484 9b :3 0 56
:3 0 38 :2 0 a62
1376 1379 fb :3 0
bf :2 0 134 :3 0
137b 137d 0 a67
137c 137f :3 0 9b
:3 0 56 :3 0 38
:2 0 a6a 1381 1384
fb :3 0 bf :2 0
135 :3 0 1386 1388
0 a6f 1387 138a
:3 0 1380 138c 138b
:2 0 64 :3 0 38
:2 0 138e 138f 0
1475 136 :3 0 81
:3 0 64 :3 0 85
:3 0 86 :3 0 24
:3 0 81 :3 0 d3
:3 0 bc :3 0 2e
:3 0 d3 :3 0 bc
:3 0 2f :4 0 186
1 :8 0 13a4 8b
:3 0 b2 :3 0 139f
13a0 0 b3 :3 0
13a1 13a2 0 13a4
a72 13f7 b4 :3 0
8b :3 0 b2 :3 0
13a6 13a7 0 b3
:3 0 13a8 13a9 0
13ab a75 13ad a77
13ac 13ab :2 0 13f5
b5 :3 0 8b :3 0
b2 :3 0 13b0 13b1
0 b3 :3 0 13b2
13b3 0 13ed 8e
:3 0 8f :3 0 13b5
13b6 0 8e :3 0
a1 :3 0 13b8 13b9
0 b6 :2 0 2
:4 0 187 :2 0 a3
:2 0 35 :2 0 a79
13be 13c0 :3 0 a7c
13ba 13c2 13b7 13c4
13c3 :2 0 91 :3 0
a4 :3 0 13c6 13c7
0 93 :4 0 188
:4 0 96 :2 0 97
:3 0 a80 13cb 13cd
:3 0 96 :2 0 b9
:4 0 a83 13cf 13d1
:3 0 96 :2 0 ba
:4 0 a86 13d3 13d5
:3 0 96 :2 0 b3
:3 0 a89 13d7 13d9
:3 0 96 :2 0 bb
:4 0 a8c 13db 13dd
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 a8f
13e0 13e4 a93 13df
13e6 :3 0 a96 13c8
13e8 :2 0 13ea a99
13eb 13c5 13ea 0
13ec a9b 0 13ed
a9d 13f0 :3 0 13f0
0 13f0 13ef 13ed
13ee :6 0 13f2 2d
:3 0 aa0 13f4 aa2
13f3 13f2 :2 0 13f5
aa4 :2 0 13f7 0
13f7 13f6 13a4 13f5
:6 0 1475 1 :3 0
102 :3 0 103 :3 0
13f9 13fa 0 29
:3 0 2e :3 0 104
:2 0 aa7 13fb 13ff
17a :2 0 38 :2 0
aad 1401 1403 :3 0
1404 :2 0 102 :3 0
103 :3 0 1406 1407
0 29 :3 0 2f
:3 0 104 :2 0 ab0
1408 140c 105 :2 0
38 :2 0 ab6 140e
1410 :3 0 1411 :2 0
1405 1413 1412 :2 0
28 :3 0 a6 :4 0
1415 1416 0 1421
70 :3 0 14d :3 0
24 :3 0 29 :3 0
64 :3 0 28 :3 0
ab9 1419 141e 1418
141f 0 1421 abe
1422 1414 1421 0
1423 ac1 0 1475
6f :3 0 189 :3 0
29 :3 0 27 :3 0
28 :3 0 22 :3 0
24 :3 0 48 :3 0
21 :3 0 30 :3 0
32 :3 0 34 :3 0
49 :3 0 36 :3 0
57 :3 0 4e :3 0
71 :3 0 73 :3 0
3a :3 0 39 :3 0
4a :3 0 9b :3 0
4b :3 0 38 :2 0
ac3 1439 143c 9b
:3 0 50 :3 0 38
:2 0 ac6 143e 1441
ac9 1425 1443 1424
1444 0 1475 70
:3 0 133 :3 0 24
:3 0 adf 1447 1449
1446 144a 0 1475
11 :3 0 1f :3 0
144c 144d 0 1475
8e :3 0 8f :3 0
144f 1450 0 8e
:3 0 a1 :3 0 1452
1453 0 35 :2 0
2 :4 0 18a :2 0
a3 :2 0 35 :2 0
ae1 1458 145a :3 0
ae4 1454 145c 1451
145e 145d :2 0 91
:3 0 a4 :3 0 1460
1461 0 93 :4 0
18b :4 0 96 :2 0
97 :3 0 ae8 1465
1467 :3 0 aeb 1462
1469 :2 0 146b aee
146c 145f 146b 0
146d af0 0 1475
12 :3 0 9b :3 0
70 :3 0 38 :2 0
af2 146f 1472 1473
:2 0 1475 af5 1480
27 :3 0 29 :3 0
1476 1477 0 147f
4d :3 0 38 :2 0
1479 147a 0 147f
7d :3 0 35 :2 0
147c 147d 0 147f
afe 1481 138d 1475
0 1482 0 147f
0 1482 b02 0
1484 159 :3 0 b05
1b83 102 :3 0 103
:3 0 1485 1486 0
2a :3 0 28 :3 0
104 :2 0 b08 1487
148b 106 :2 0 38
:2 0 b0e 148d 148f
:3 0 102 :3 0 10f
:3 0 d3 :3 0 bc
:3 0 2a :3 0 102
:3 0 110 :3 0 28
:3 0 2a :3 0 117
:4 0 18c 1 :8 0
14a1 8b :3 0 b2
:3 0 149c 149d 0
b3 :3 0 149e 149f
0 14a1 b11 14f4
b4 :3 0 8b :3 0
b2 :3 0 14a3 14a4
0 b3 :3 0 14a5
14a6 0 14a8 b14
14aa b16 14a9 14a8
:2 0 14f2 b5 :3 0
8b :3 0 b2 :3 0
14ad 14ae 0 b3
:3 0 14af 14b0 0
14ea 8e :3 0 8f
:3 0 14b2 14b3 0
8e :3 0 a1 :3 0
14b5 14b6 0 b6
:2 0 2 :4 0 18d
:2 0 a3 :2 0 35
:2 0 b18 14bb 14bd
:3 0 b1b 14b7 14bf
14b4 14c1 14c0 :2 0
91 :3 0 a4 :3 0
14c3 14c4 0 93
:4 0 18e :4 0 96
:2 0 97 :3 0 b1f
14c8 14ca :3 0 96
:2 0 b9 :4 0 b22
14cc 14ce :3 0 96
:2 0 ba :4 0 b25
14d0 14d2 :3 0 96
:2 0 b3 :3 0 b28
14d4 14d6 :3 0 96
:2 0 bb :4 0 b2b
14d8 14da :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 b2e 14dd 14e1
b32 14dc 14e3 :3 0
b35 14c5 14e5 :2 0
14e7 b38 14e8 14c2
14e7 0 14e9 b3a
0 14ea b3c 14ed
:3 0 14ed 0 14ed
14ec 14ea 14eb :6 0
14ef 2f :3 0 b3f
14f1 b41 14f0 14ef
:2 0 14f2 b43 :2 0
14f4 0 14f4 14f3
14a1 14f2 :6 0 174a
1 :3 0 7e :3 0
102 :3 0 18f :3 0
14f7 14f8 0 2a
:3 0 28 :3 0 b46
14f9 14fc 14f6 14fd
0 174a 3b :3 0
10b :2 0 35 :2 0
b49 1500 1502 :3 0
14ff 1503 0 174a
70 :3 0 190 :3 0
24 :3 0 48 :3 0
21 :3 0 30 :3 0
32 :3 0 71 :3 0
73 :3 0 3b :3 0
3a :3 0 39 :3 0
b4b 1506 1511 1505
1512 0 174a 9b
:3 0 53 :3 0 38
:2 0 b56 1514 1517
105 :2 0 38 :2 0
b5b 1519 151b :3 0
151c :2 0 3d :3 0
10a :2 0 b5e 151f
1520 :3 0 1521 :2 0
1522 :2 0 151d 1524
1523 :2 0 70 :3 0
191 :3 0 24 :3 0
48 :3 0 49 :3 0
22 :3 0 21 :3 0
3d :3 0 53 :3 0
38 :2 0 b60 1527
1530 1526 1531 0
1533 b69 1534 1525
1533 0 1535 b6b
0 174a bc :3 0
34 :3 0 35 :2 0
35 :2 0 b6d 1536
153a bf :2 0 192
:4 0 b73 153c 153e
:3 0 58 :3 0 192
:2 0 1540 1541 0
1543 b76 1548 58
:3 0 38 :2 0 1544
1545 0 1547 b78
1549 153f 1543 0
154a 0 1547 0
154a b7a 0 174a
65 :3 0 9b :3 0
4b :3 0 38 :2 0
b7d 154c 154f 10b
:2 0 9b :3 0 50
:3 0 38 :2 0 b80
1552 1555 b83 1551
1557 :3 0 154b 1558
0 174a 70 :3 0
193 :3 0 24 :3 0
48 :3 0 21 :3 0
49 :3 0 36 :3 0
30 :3 0 32 :3 0
27 :3 0 2a :3 0
58 :3 0 57 :3 0
4e :3 0 4a :3 0
9b :3 0 65 :3 0
38 :2 0 b86 1569
156c 192 :2 0 7e
:3 0 38 :2 0 b89
155b 1571 155a 1572
0 174a 9b :3 0
70 :3 0 38 :2 0
b9b 1574 1577 bf
:2 0 38 :2 0 ba0
1579 157b :3 0 102
:3 0 103 :3 0 157d
157e 0 3d :3 0
2a :3 0 104 :2 0
ba3 157f 1583 bf
:2 0 38 :2 0 ba9
1585 1587 :3 0 e1
:3 0 194 :3 0 fb
:3 0 195 :3 0 196
:3 0 2a :3 0 f2
:3 0 de :3 0 d0
:3 0 cc :3 0 124
:3 0 2a :3 0 e2
:3 0 21 :4 0 197
1 :8 0 15ad 127
:4 0 1598 :3 0 128
:3 0 bf :2 0 bae
159b 159c :3 0 8b
:3 0 b2 :3 0 159e
159f 0 38 :2 0
15a0 15a1 0 15a3
bb1 15aa 8b :3 0
b2 :3 0 15a4 15a5
0 129 :2 0 15a6
15a7 0 15a9 bb3
15ab 159d 15a3 0
15ac 0 15a9 0
15ac bb5 0 15ad
bb8 1600 b4 :3 0
8b :3 0 b2 :3 0
15af 15b0 0 b3
:3 0 15b1 15b2 0
15b4 bbb 15b6 bbd
15b5 15b4 :2 0 15fe
b5 :3 0 8b :3 0
b2 :3 0 15b9 15ba
0 b3 :3 0 15bb
15bc 0 15f6 8e
:3 0 8f :3 0 15be
15bf 0 8e :3 0
a1 :3 0 15c1 15c2
0 b6 :2 0 2
:4 0 198 :2 0 a3
:2 0 35 :2 0 bbf
15c7 15c9 :3 0 bc2
15c3 15cb 15c0 15cd
15cc :2 0 91 :3 0
a4 :3 0 15cf 15d0
0 93 :4 0 199
:4 0 96 :2 0 97
:3 0 bc6 15d4 15d6
:3 0 96 :2 0 b9
:4 0 bc9 15d8 15da
:3 0 96 :2 0 ba
:4 0 bcc 15dc 15de
:3 0 96 :2 0 b3
:3 0 bcf 15e0 15e2
:3 0 96 :2 0 bb
:4 0 bd2 15e4 15e6
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 bd5
15e9 15ed bd9 15e8
15ef :3 0 bdc 15d1
15f1 :2 0 15f3 bdf
15f4 15ce 15f3 0
15f5 be1 0 15f6
be3 15f9 :3 0 15f9
0 15f9 15f8 15f6
15f7 :6 0 15fb 31
:3 0 be6 15fd be8
15fc 15fb :2 0 15fe
bea :2 0 1600 0
1600 15ff 15ad 15fe
:6 0 1603 1 :3 0
159 :3 0 bed 1692
9b :3 0 65 :3 0
38 :2 0 bef 1604
1607 bf :2 0 38
:2 0 bf4 1609 160b
:3 0 102 :3 0 103
:3 0 160d 160e 0
3d :3 0 2a :3 0
104 :2 0 bf7 160f
1613 17a :2 0 38
:2 0 bfd 1615 1617
:3 0 160c 1619 1618
:2 0 e1 :3 0 194
:3 0 fb :3 0 19a
:3 0 196 :3 0 de
:3 0 cc :3 0 d0
:3 0 e2 :3 0 21
:4 0 19b 1 :8 0
163b 127 :4 0 1626
:3 0 128 :3 0 bf
:2 0 c02 1629 162a
:3 0 8b :3 0 b2
:3 0 162c 162d 0
38 :2 0 162e 162f
0 1631 c05 1638
8b :3 0 b2 :3 0
1632 1633 0 129
:2 0 1634 1635 0
1637 c07 1639 162b
1631 0 163a 0
1637 0 163a c09
0 163b c0c 168e
b4 :3 0 8b :3 0
b2 :3 0 163d 163e
0 b3 :3 0 163f
1640 0 1642 c0f
1644 c11 1643 1642
:2 0 168c b5 :3 0
8b :3 0 b2 :3 0
1647 1648 0 b3
:3 0 1649 164a 0
1684 8e :3 0 8f
:3 0 164c 164d 0
8e :3 0 a1 :3 0
164f 1650 0 b6
:2 0 2 :4 0 19c
:2 0 a3 :2 0 35
:2 0 c13 1655 1657
:3 0 c16 1651 1659
164e 165b 165a :2 0
91 :3 0 a4 :3 0
165d 165e 0 93
:4 0 19d :4 0 96
:2 0 97 :3 0 c1a
1662 1664 :3 0 96
:2 0 b9 :4 0 c1d
1666 1668 :3 0 96
:2 0 ba :4 0 c20
166a 166c :3 0 96
:2 0 b3 :3 0 c23
166e 1670 :3 0 96
:2 0 bb :4 0 c26
1672 1674 :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 c29 1677 167b
c2d 1676 167d :3 0
c30 165f 167f :2 0
1681 c33 1682 165c
1681 0 1683 c35
0 1684 c37 1687
:3 0 1687 0 1687
1686 1684 1685 :6 0
1689 33 :3 0 c3a
168b c3c 168a 1689
:2 0 168c c3e :2 0
168e 0 168e 168d
163b 168c :6 0 1690
1 :3 0 c41 1691
161a 1690 0 1693
1588 1603 0 1693
c43 0 1694 c46
1695 157c 1694 0
1696 c48 0 174a
d3 :3 0 bc :3 0
27 :3 0 d3 :3 0
bc :3 0 2a :3 0
d4 :3 0 d5 :3 0
d6 :3 0 d8 :3 0
30 :3 0 32 :3 0
39 :3 0 3a :3 0
71 :3 0 73 :3 0
e1 :3 0 e2 :3 0
21 :4 0 19e 1
:8 0 16b0 8b :3 0
b2 :3 0 16ab 16ac
0 b3 :3 0 16ad
16ae 0 16b0 c4a
1703 b4 :3 0 8b
:3 0 b2 :3 0 16b2
16b3 0 b3 :3 0
16b4 16b5 0 16b7
c4d 16b9 c4f 16b8
16b7 :2 0 1701 b5
:3 0 8b :3 0 b2
:3 0 16bc 16bd 0
b3 :3 0 16be 16bf
0 16f9 8e :3 0
8f :3 0 16c1 16c2
0 8e :3 0 a1
:3 0 16c4 16c5 0
b6 :2 0 2 :4 0
19f :2 0 a3 :2 0
35 :2 0 c51 16ca
16cc :3 0 c54 16c6
16ce 16c3 16d0 16cf
:2 0 91 :3 0 a4
:3 0 16d2 16d3 0
93 :4 0 1a0 :4 0
96 :2 0 97 :3 0
c58 16d7 16d9 :3 0
96 :2 0 b9 :4 0
c5b 16db 16dd :3 0
96 :2 0 ba :4 0
c5e 16df 16e1 :3 0
96 :2 0 b3 :3 0
c61 16e3 16e5 :3 0
96 :2 0 bb :4 0
c64 16e7 16e9 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 c67 16ec
16f0 c6b 16eb 16f2
:3 0 c6e 16d4 16f4
:2 0 16f6 c71 16f7
16d1 16f6 0 16f8
c73 0 16f9 c75
16fc :3 0 16fc 0
16fc 16fb 16f9 16fa
:6 0 16fe 35 :3 0
c78 1700 c7a 16ff
16fe :2 0 1701 c7c
:2 0 1703 0 1703
1702 16b0 1701 :6 0
174a 1 :3 0 3b
:3 0 38 :2 0 1705
1706 0 174a 70
:3 0 190 :3 0 24
:3 0 48 :3 0 21
:3 0 30 :3 0 32
:3 0 71 :3 0 73
:3 0 3b :3 0 3a
:3 0 39 :3 0 c7f
1709 1714 1708 1715
0 174a 70 :3 0
133 :3 0 24 :3 0
c8a 1718 171a 1717
171b 0 174a 8b
:3 0 b2 :3 0 171d
171e 0 38 :2 0
171f 1720 0 174a
11 :3 0 1f :3 0
1722 1723 0 174a
8e :3 0 8f :3 0
1725 1726 0 8e
:3 0 a1 :3 0 1728
1729 0 35 :2 0
2 :4 0 1a1 :2 0
a3 :2 0 35 :2 0
c8c 172e 1730 :3 0
c8f 172a 1732 1727
1734 1733 :2 0 91
:3 0 a4 :3 0 1736
1737 0 93 :4 0
1a2 :4 0 96 :2 0
97 :3 0 c93 173b
173d :3 0 c96 1738
173f :2 0 1741 c99
1742 1735 1741 0
1743 c9b 0 174a
12 :3 0 8b :3 0
b2 :3 0 1745 1746
0 1747 :2 0 174a
159 :3 0 c9d 174b
1490 174a 0 1b84
9b :3 0 4d :3 0
38 :2 0 caf 174c
174f 9b :3 0 17a
:2 0 13 :3 0 38
:2 0 cb2 1751 1755
cb7 1752 1757 :3 0
4d :3 0 9b :3 0
13 :3 0 38 :2 0
cba 175a 175d 10b
:2 0 9b :3 0 4d
:3 0 38 :2 0 cbd
1760 1763 cc0 175f
1765 :3 0 1759 1766
0 18a1 9b :3 0
56 :3 0 38 :2 0
cc3 1768 176b fb
:3 0 bf :2 0 134
:3 0 176d 176f 0
cc8 176e 1771 :3 0
9b :3 0 56 :3 0
38 :2 0 ccb 1773
1776 fb :3 0 bf
:2 0 135 :3 0 1778
177a 0 cd0 1779
177c :3 0 1772 177e
177d :2 0 bc :3 0
36 :3 0 35 :2 0
35 :2 0 cd3 1780
1784 bf :2 0 38
:4 0 cd9 1786 1788
:3 0 1789 :2 0 11
:3 0 49 :3 0 178b
178c 0 178e cdc
1793 11 :3 0 24
:3 0 178f 1790 0
1792 cde 1794 178a
178e 0 1795 0
1792 0 1795 ce0
0 1898 70 :3 0
1a3 :3 0 11 :3 0
29 :3 0 4d :3 0
2c :3 0 ce3 1797
179c 1796 179d 0
1898 2d :4 0 179f
17a0 0 1898 1a4
:3 0 80 :4 0 17a5
:2 0 1898 17a3 17a6
:3 0 80 :3 0 2d
:4 0 17aa :2 0 1898
17a7 17a8 :3 0 80
:3 0 127 :3 0 17ab
17ac :3 0 8b :3 0
b2 :3 0 17ae 17af
0 38 :2 0 17b0
17b1 0 17b3 ce8
17ba 8b :3 0 b2
:3 0 17b4 17b5 0
129 :2 0 17b6 17b7
0 17b9 cea 17bb
17ad 17b3 0 17bc
0 17b9 0 17bc
cec 0 1898 1a5
:3 0 80 :4 0 17c0
:2 0 17c6 17be 0
8b :3 0 b2 :3 0
17c1 17c2 0 b3
:3 0 17c3 17c4 0
17c6 cef 1819 b4
:3 0 8b :3 0 b2
:3 0 17c8 17c9 0
b3 :3 0 17ca 17cb
0 17cd cf2 17cf
cf4 17ce 17cd :2 0
1817 b5 :3 0 8b
:3 0 b2 :3 0 17d2
17d3 0 b3 :3 0
17d4 17d5 0 180f
8e :3 0 8f :3 0
17d7 17d8 0 8e
:3 0 a1 :3 0 17da
17db 0 b6 :2 0
2 :4 0 1a6 :2 0
a3 :2 0 35 :2 0
cf6 17e0 17e2 :3 0
cf9 17dc 17e4 17d9
17e6 17e5 :2 0 91
:3 0 a4 :3 0 17e8
17e9 0 93 :4 0
1a7 :4 0 96 :2 0
97 :3 0 cfd 17ed
17ef :3 0 96 :2 0
b9 :4 0 d00 17f1
17f3 :3 0 96 :2 0
ba :4 0 d03 17f5
17f7 :3 0 96 :2 0
b3 :3 0 d06 17f9
17fb :3 0 96 :2 0
bb :4 0 d09 17fd
17ff :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
d0c 1802 1806 d10
1801 1808 :3 0 d13
17ea 180a :2 0 180c
d16 180d 17e7 180c
0 180e d18 0
180f d1a 1812 :3 0
1812 0 1812 1811
180f 1810 :6 0 1814
37 :3 0 d1d 1816
d1f 1815 1814 :2 0
1817 d21 :2 0 1819
0 1819 1818 17c6
1817 :6 0 1898 1
:3 0 2d :3 0 1a8
:2 0 d24 181c 181d
:3 0 181e :2 0 8e
:3 0 8f :3 0 1820
1821 0 8e :3 0
a1 :3 0 1823 1824
0 35 :2 0 2
:4 0 1a9 :2 0 a3
:2 0 35 :2 0 d26
1829 182b :3 0 d29
1825 182d 1822 182f
182e :2 0 91 :3 0
a4 :3 0 1831 1832
0 93 :4 0 1aa
:4 0 96 :2 0 97
:3 0 d2d 1836 1838
:3 0 d30 1833 183a
:2 0 183c d33 183d
1830 183c 0 183e
d35 0 1844 12
:3 0 fb :3 0 1ab
:3 0 1840 1841 0
1842 :2 0 1844 d37
1845 181f 1844 0
1846 d3a 0 1898
6f :3 0 189 :3 0
2c :3 0 27 :3 0
2d :3 0 22 :3 0
24 :3 0 48 :3 0
21 :3 0 30 :3 0
32 :3 0 34 :3 0
49 :3 0 36 :3 0
57 :3 0 4e :3 0
71 :3 0 73 :3 0
3a :3 0 39 :3 0
4a :3 0 9b :3 0
4b :3 0 38 :2 0
d3c 185c 185f 9b
:3 0 50 :3 0 38
:2 0 d3f 1861 1864
d42 1848 1866 1847
1867 0 1898 70
:3 0 133 :3 0 24
:3 0 d58 186a 186c
1869 186d 0 1898
11 :3 0 1f :3 0
186f 1870 0 1898
8e :3 0 8f :3 0
1872 1873 0 8e
:3 0 a1 :3 0 1875
1876 0 35 :2 0
2 :4 0 1ac :2 0
a3 :2 0 35 :2 0
d5a 187b 187d :3 0
d5d 1877 187f 1874
1881 1880 :2 0 91
:3 0 a4 :3 0 1883
1884 0 93 :4 0
1ad :4 0 96 :2 0
97 :3 0 d61 1888
188a :3 0 d64 1885
188c :2 0 188e d67
188f 1882 188e 0
1890 d69 0 1898
12 :3 0 9b :3 0
70 :3 0 38 :2 0
d6b 1892 1895 1896
:2 0 1898 d6e 189d
7d :3 0 35 :2 0
1899 189a 0 189c
d7c 189e 177f 1898
0 189f 0 189c
0 189f d7e 0
18a1 159 :3 0 d81
18a2 1758 18a1 0
1b84 9b :3 0 13
:3 0 38 :2 0 d84
18a3 18a6 bf :2 0
38 :2 0 d89 18a8
18aa :3 0 4d :3 0
38 :2 0 18ac 18ad
0 1913 7d :3 0
35 :2 0 18af 18b0
0 1913 e8 :3 0
27 :3 0 f5 :3 0
86 :3 0 48 :4 0
1ae 1 :8 0 18bd
8b :3 0 b2 :3 0
18b8 18b9 0 b3
:3 0 18ba 18bb 0
18bd d8c 1910 b4
:3 0 8b :3 0 b2
:3 0 18bf 18c0 0
b3 :3 0 18c1 18c2
0 18c4 d8f 18c6
d91 18c5 18c4 :2 0
190e b5 :3 0 8b
:3 0 b2 :3 0 18c9
18ca 0 b3 :3 0
18cb 18cc 0 1906
8e :3 0 8f :3 0
18ce 18cf 0 8e
:3 0 a1 :3 0 18d1
18d2 0 b6 :2 0
2 :4 0 1af :2 0
a3 :2 0 35 :2 0
d93 18d7 18d9 :3 0
d96 18d3 18db 18d0
18dd 18dc :2 0 91
:3 0 a4 :3 0 18df
18e0 0 93 :4 0
1b0 :4 0 96 :2 0
97 :3 0 d9a 18e4
18e6 :3 0 96 :2 0
b9 :4 0 d9d 18e8
18ea :3 0 96 :2 0
ba :4 0 da0 18ec
18ee :3 0 96 :2 0
b3 :3 0 da3 18f0
18f2 :3 0 96 :2 0
bb :4 0 da6 18f4
18f6 :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
da9 18f9 18fd dad
18f8 18ff :3 0 db0
18e1 1901 :2 0 1903
db3 1904 18de 1903
0 1905 db5 0
1906 db7 1909 :3 0
1909 0 1909 1908
1906 1907 :6 0 190b
39 :3 0 dba 190d
dbc 190c 190b :2 0
190e dbe :2 0 1910
0 1910 190f 18bd
190e :6 0 1913 1
:3 0 159 :3 0 dc1
1914 18ab 1913 0
1b84 9b :3 0 4d
:3 0 38 :2 0 dc5
1915 1918 9b :3 0
105 :2 0 13 :3 0
38 :2 0 dc8 191a
191e dcd 191b 1920
:3 0 4d :3 0 9b
:3 0 4d :3 0 38
:2 0 dd0 1923 1926
10b :2 0 9b :3 0
13 :3 0 38 :2 0
dd3 1929 192c dd6
1928 192e :3 0 1922
192f 0 1b81 3c
:4 0 1931 1932 0
1b81 7a :3 0 a6
:4 0 1934 1935 0
1b81 9b :3 0 42
:3 0 38 :2 0 dd9
1937 193a bf :2 0
35 :2 0 dde 193c
193e :3 0 7a :3 0
1b1 :4 0 96 :2 0
1b2 :4 0 de1 1942
1944 :3 0 96 :2 0
24 :3 0 de4 1946
1948 :3 0 96 :2 0
1b3 :4 0 de7 194a
194c :3 0 96 :2 0
27 :3 0 dea 194e
1950 :3 0 96 :2 0
1b4 :4 0 ded 1952
1954 :3 0 96 :2 0
1b5 :4 0 df0 1956
1958 :3 0 96 :2 0
9f :3 0 9b :3 0
4d :3 0 38 :2 0
df3 195c 195f df6
195b 1961 df8 195a
1963 :3 0 1940 1964
0 196b 1a4 :3 0
8a :3 0 7a :3 0
1967 1968 0 1969
:2 0 196b dfb 1998
7a :3 0 1b1 :4 0
96 :2 0 1b2 :4 0
dfe 196e 1970 :3 0
96 :2 0 49 :3 0
e01 1972 1974 :3 0
96 :2 0 1b3 :4 0
e04 1976 1978 :3 0
96 :2 0 27 :3 0
e07 197a 197c :3 0
96 :2 0 1b4 :4 0
e0a 197e 1980 :3 0
96 :2 0 1b5 :4 0
e0d 1982 1984 :3 0
96 :2 0 9f :3 0
9b :3 0 4d :3 0
38 :2 0 e10 1988
198b e13 1987 198d
e15 1986 198f :3 0
196c 1990 0 1997
1a4 :3 0 8d :3 0
7a :3 0 1993 1994
0 1995 :2 0 1997
e18 1999 193f 196b
0 199a 0 1997
0 199a e1b 0
1b81 1b6 :3 0 9b
:3 0 42 :3 0 38
:2 0 e1e 199c 199f
bf :2 0 35 :2 0
e23 19a1 19a3 :3 0
8a :3 0 3c :4 0
19a8 :2 0 19bb 19a5
19a6 :3 0 8a :3 0
127 :3 0 19a9 19aa
:3 0 8b :3 0 b2
:3 0 19ac 19ad 0
38 :2 0 19ae 19af
0 19b1 e26 19b8
8b :3 0 b2 :3 0
19b2 19b3 0 129
:2 0 19b4 19b5 0
19b7 e28 19b9 19ab
19b1 0 19ba 0
19b7 0 19ba e2a
0 19bb e2d 19d3
8d :3 0 3c :4 0
19bf :2 0 19d2 19bc
19bd :3 0 8d :3 0
127 :3 0 19c0 19c1
:3 0 8b :3 0 b2
:3 0 19c3 19c4 0
38 :2 0 19c5 19c6
0 19c8 e30 19cf
8b :3 0 b2 :3 0
19c9 19ca 0 129
:2 0 19cb 19cc 0
19ce e32 19d0 19c2
19c8 0 19d1 0
19ce 0 19d1 e34
0 19d2 e37 19d4
19a4 19bb 0 19d5
0 19d2 0 19d5
e3a 0 19e5 8b
:3 0 b2 :3 0 19d6
19d7 0 8b :3 0
106 :2 0 132 :3 0
19d9 19db 0 e3f
19da 19dd :3 0 19de
:2 0 1b7 :8 0 19e2
e42 19e3 19df 19e2
0 19e4 e44 0
19e5 e46 19e7 1b6
:4 0 19e5 :4 0 1b81
9b :3 0 42 :3 0
38 :2 0 e49 19e8
19eb bf :2 0 35
:2 0 e4e 19ed 19ef
:3 0 1a5 :3 0 8a
:4 0 19f4 :2 0 19fa
19f2 0 8b :3 0
b2 :3 0 19f5 19f6
0 b3 :3 0 19f7
19f8 0 19fa e51
1a4d b4 :3 0 8b
:3 0 b2 :3 0 19fc
19fd 0 b3 :3 0
19fe 19ff 0 1a01
e54 1a03 e56 1a02
1a01 :2 0 1a4b b5
:3 0 8b :3 0 b2
:3 0 1a06 1a07 0
b3 :3 0 1a08 1a09
0 1a43 8e :3 0
8f :3 0 1a0b 1a0c
0 8e :3 0 a1
:3 0 1a0e 1a0f 0
b6 :2 0 2 :4 0
1b8 :2 0 a3 :2 0
35 :2 0 e58 1a14
1a16 :3 0 e5b 1a10
1a18 1a0d 1a1a 1a19
:2 0 91 :3 0 a4
:3 0 1a1c 1a1d 0
93 :4 0 1b9 :4 0
96 :2 0 97 :3 0
e5f 1a21 1a23 :3 0
96 :2 0 b9 :4 0
e62 1a25 1a27 :3 0
96 :2 0 ba :4 0
e65 1a29 1a2b :3 0
96 :2 0 b3 :3 0
e68 1a2d 1a2f :3 0
96 :2 0 bb :4 0
e6b 1a31 1a33 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 e6e 1a36
1a3a e72 1a35 1a3c
:3 0 e75 1a1e 1a3e
:2 0 1a40 e78 1a41
1a1b 1a40 0 1a42
e7a 0 1a43 e7c
1a46 :3 0 1a46 0
1a46 1a45 1a43 1a44
:6 0 1a48 3c :3 0
e7f 1a4a e81 1a49
1a48 :2 0 1a4b e83
:2 0 1a4d 0 1a4d
1a4c 19fa 1a4b :6 0
1a4f 1 :3 0 e86
1aaf 1a5 :3 0 8d
:4 0 1a53 :2 0 1a59
1a51 0 8b :3 0
b2 :3 0 1a54 1a55
0 b3 :3 0 1a56
1a57 0 1a59 e88
1aac b4 :3 0 8b
:3 0 b2 :3 0 1a5b
1a5c 0 b3 :3 0
1a5d 1a5e 0 1a60
e8b 1a62 e8d 1a61
1a60 :2 0 1aaa b5
:3 0 8b :3 0 b2
:3 0 1a65 1a66 0
b3 :3 0 1a67 1a68
0 1aa2 8e :3 0
8f :3 0 1a6a 1a6b
0 8e :3 0 a1
:3 0 1a6d 1a6e 0
b6 :2 0 2 :4 0
1ba :2 0 a3 :2 0
35 :2 0 e8f 1a73
1a75 :3 0 e92 1a6f
1a77 1a6c 1a79 1a78
:2 0 91 :3 0 a4
:3 0 1a7b 1a7c 0
93 :4 0 1bb :4 0
96 :2 0 97 :3 0
e96 1a80 1a82 :3 0
96 :2 0 b9 :4 0
e99 1a84 1a86 :3 0
96 :2 0 ba :4 0
e9c 1a88 1a8a :3 0
96 :2 0 b3 :3 0
e9f 1a8c 1a8e :3 0
96 :2 0 bb :4 0
ea2 1a90 1a92 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 ea5 1a95
1a99 ea9 1a94 1a9b
:3 0 eac 1a7d 1a9d
:2 0 1a9f eaf 1aa0
1a7a 1a9f 0 1aa1
eb1 0 1aa2 eb3
1aa5 :3 0 1aa5 0
1aa5 1aa4 1aa2 1aa3
:6 0 1aa7 3e :3 0
eb6 1aa9 eb8 1aa8
1aa7 :2 0 1aaa eba
:2 0 1aac 0 1aac
1aab 1a59 1aaa :6 0
1aae 1 :3 0 ebd
1ab0 19f0 1a4f 0
1ab1 0 1aae 0
1ab1 ebf 0 1b81
3c :3 0 1a8 :2 0
ec2 1ab3 1ab4 :3 0
1ab5 :2 0 9b :3 0
42 :3 0 38 :2 0
ec4 1ab7 1aba bf
:2 0 35 :2 0 ec9
1abc 1abe :3 0 11
:3 0 24 :3 0 1ac0
1ac1 0 1ae7 8e
:3 0 8f :3 0 1ac3
1ac4 0 8e :3 0
a1 :3 0 1ac6 1ac7
0 35 :2 0 2
:4 0 1bc :2 0 a3
:2 0 35 :2 0 ecc
1acc 1ace :3 0 ecf
1ac8 1ad0 1ac5 1ad2
1ad1 :2 0 91 :3 0
a4 :3 0 1ad4 1ad5
0 93 :4 0 1bd
:4 0 96 :2 0 97
:3 0 ed3 1ad9 1adb
:3 0 ed6 1ad6 1add
:2 0 1adf ed9 1ae0
1ad3 1adf 0 1ae1
edb 0 1ae7 12
:3 0 fb :3 0 fc
:3 0 1ae3 1ae4 0
1ae5 :2 0 1ae7 edd
1b10 11 :3 0 49
:3 0 1ae8 1ae9 0
1b0f 8e :3 0 8f
:3 0 1aeb 1aec 0
8e :3 0 a1 :3 0
1aee 1aef 0 35
:2 0 2 :4 0 1be
:2 0 a3 :2 0 35
:2 0 ee1 1af4 1af6
:3 0 ee4 1af0 1af8
1aed 1afa 1af9 :2 0
91 :3 0 a4 :3 0
1afc 1afd 0 93
:4 0 1bf :4 0 96
:2 0 97 :3 0 ee8
1b01 1b03 :3 0 eeb
1afe 1b05 :2 0 1b07
eee 1b08 1afb 1b07
0 1b09 ef0 0
1b0f 12 :3 0 fb
:3 0 fc :3 0 1b0b
1b0c 0 1b0d :2 0
1b0f ef2 1b11 1abf
1ae7 0 1b12 0
1b0f 0 1b12 ef6
0 1b13 ef9 1b14
1ab6 1b13 0 1b15
efb 0 1b81 102
:3 0 10f :3 0 d3
:3 0 bc :3 0 3c
:3 0 102 :3 0 110
:3 0 27 :3 0 27
:3 0 117 :4 0 1c0
1 :8 0 1b26 8b
:3 0 b2 :3 0 1b21
1b22 0 b3 :3 0
1b23 1b24 0 1b26
efd 1b79 b4 :3 0
8b :3 0 b2 :3 0
1b28 1b29 0 b3
:3 0 1b2a 1b2b 0
1b2d f00 1b2f f02
1b2e 1b2d :2 0 1b77
b5 :3 0 8b :3 0
b2 :3 0 1b32 1b33
0 b3 :3 0 1b34
1b35 0 1b6f 8e
:3 0 8f :3 0 1b37
1b38 0 8e :3 0
a1 :3 0 1b3a 1b3b
0 b6 :2 0 2
:4 0 1c1 :2 0 a3
:2 0 35 :2 0 f04
1b40 1b42 :3 0 f07
1b3c 1b44 1b39 1b46
1b45 :2 0 91 :3 0
a4 :3 0 1b48 1b49
0 93 :4 0 1c2
:4 0 96 :2 0 97
:3 0 f0b 1b4d 1b4f
:3 0 96 :2 0 b9
:4 0 f0e 1b51 1b53
:3 0 96 :2 0 ba
:4 0 f11 1b55 1b57
:3 0 96 :2 0 b3
:3 0 f14 1b59 1b5b
:3 0 96 :2 0 bb
:4 0 f17 1b5d 1b5f
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 f1a
1b62 1b66 f1e 1b61
1b68 :3 0 f21 1b4a
1b6a :2 0 1b6c f24
1b6d 1b47 1b6c 0
1b6e f26 0 1b6f
f28 1b72 :3 0 1b72
0 1b72 1b71 1b6f
1b70 :6 0 1b74 40
:3 0 f2b 1b76 f2d
1b75 1b74 :2 0 1b77
f2f :2 0 1b79 0
1b79 1b78 1b26 1b77
:6 0 1b81 1 :3 0
4d :3 0 38 :2 0
1b7b 1b7c 0 1b81
7d :3 0 35 :2 0
1b7e 1b7f 0 1b81
f32 1b82 1921 1b81
0 1b84 1334 1484
0 1b84 f3d 0
1b86 159 :3 0 f43
1f79 9b :3 0 14
:3 0 38 :2 0 f45
1b87 1b8a 9b :3 0
106 :2 0 4e :3 0
38 :2 0 f48 1b8c
1b90 f4d 1b8d 1b92
:3 0 9b :3 0 67
:3 0 38 :2 0 f50
1b94 1b97 105 :2 0
38 :2 0 f55 1b99
1b9b :3 0 9b :3 0
14 :3 0 38 :2 0
f58 1b9d 1ba0 9b
:3 0 105 :2 0 67
:3 0 38 :2 0 f5b
1ba2 1ba6 f60 1ba3
1ba8 :3 0 1b9c 1baa
1ba9 :2 0 11 :3 0
22 :3 0 1bac 1bad
0 1bd3 8e :3 0
8f :3 0 1baf 1bb0
0 8e :3 0 a1
:3 0 1bb2 1bb3 0
35 :2 0 2 :4 0
1c3 :2 0 a3 :2 0
35 :2 0 f63 1bb8
1bba :3 0 f66 1bb4
1bbc 1bb1 1bbe 1bbd
:2 0 91 :3 0 a4
:3 0 1bc0 1bc1 0
93 :4 0 1c4 :4 0
96 :2 0 97 :3 0
f6a 1bc5 1bc7 :3 0
f6d 1bc2 1bc9 :2 0
1bcb f70 1bcc 1bbf
1bcb 0 1bcd f72
0 1bd3 12 :3 0
fb :3 0 155 :3 0
1bcf 1bd0 0 1bd1
:2 0 1bd3 f74 1bd4
1bab 1bd3 0 1bd5
f78 0 1f77 9b
:3 0 50 :3 0 38
:2 0 f7a 1bd6 1bd9
9b :3 0 bf :2 0
4b :3 0 38 :2 0
f7d 1bdb 1bdf f82
1bdc 1be1 :3 0 11
:3 0 21 :3 0 1be3
1be4 0 1c0a 8e
:3 0 8f :3 0 1be6
1be7 0 8e :3 0
a1 :3 0 1be9 1bea
0 35 :2 0 2
:4 0 1c5 :2 0 a3
:2 0 35 :2 0 f85
1bef 1bf1 :3 0 f88
1beb 1bf3 1be8 1bf5
1bf4 :2 0 91 :3 0
a4 :3 0 1bf7 1bf8
0 93 :4 0 1c6
:4 0 96 :2 0 97
:3 0 f8c 1bfc 1bfe
:3 0 f8f 1bf9 1c00
:2 0 1c02 f92 1c03
1bf6 1c02 0 1c04
f94 0 1c0a 12
:3 0 8b :3 0 b2
:3 0 1c06 1c07 0
1c08 :2 0 1c0a f96
1c0b 1be2 1c0a 0
1c0c f9a 0 1f77
9b :3 0 14 :3 0
38 :2 0 f9c 1c0d
1c10 bf :2 0 38
:2 0 fa1 1c12 1c14
:3 0 4e :3 0 129
:2 0 1c16 1c17 0
1c19 fa4 1c62 9b
:3 0 14 :3 0 38
:2 0 fa6 1c1a 1c1d
17a :2 0 35 :2 0
fab 1c1f 1c21 :3 0
1c22 :2 0 9b :3 0
14 :3 0 38 :2 0
fae 1c24 1c27 105
:2 0 1c7 :2 0 fb3
1c29 1c2b :3 0 1c2c
:2 0 1c23 1c2e 1c2d
:2 0 11 :3 0 21
:3 0 1c30 1c31 0
1c57 8e :3 0 8f
:3 0 1c33 1c34 0
8e :3 0 a1 :3 0
1c36 1c37 0 35
:2 0 2 :4 0 1c8
:2 0 a3 :2 0 35
:2 0 fb6 1c3c 1c3e
:3 0 fb9 1c38 1c40
1c35 1c42 1c41 :2 0
91 :3 0 a4 :3 0
1c44 1c45 0 93
:4 0 1c9 :4 0 96
:2 0 97 :3 0 fbd
1c49 1c4b :3 0 fc0
1c46 1c4d :2 0 1c4f
fc3 1c50 1c43 1c4f
0 1c51 fc5 0
1c57 12 :3 0 fb
:3 0 1ca :3 0 1c53
1c54 0 1c55 :2 0
1c57 fc7 1c58 1c2f
1c57 0 1c59 fcb
0 1c61 4e :3 0
9b :3 0 14 :3 0
38 :2 0 fcd 1c5b
1c5e 1c5a 1c5f 0
1c61 fd0 1c63 1c15
1c19 0 1c64 0
1c61 0 1c64 fd3
0 1f77 63 :3 0
1cb :3 0 9b :3 0
57 :3 0 38 :2 0
fd6 1c67 1c6a 1cc
:2 0 9b :3 0 4e
:3 0 38 :2 0 fd9
1c6d 1c70 fdc 1c6c
1c72 :3 0 1c73 :2 0
1cd :2 0 1ce :2 0
fdf 1c75 1c77 :3 0
1c78 :2 0 a3 :2 0
1cf :2 0 fe2 1c7a
1c7c :3 0 fe5 1c66
1c7e 1c65 1c7f 0
1f77 9b :3 0 63
:3 0 38 :2 0 fe7
1c81 1c84 9b :3 0
105 :2 0 4b :3 0
38 :2 0 fea 1c86
1c8a fef 1c87 1c8c
:3 0 70 :3 0 38
:2 0 1c8e 1c8f 0
1d24 136 :3 0 70
:3 0 13e :3 0 ae
:3 0 24 :3 0 e2
:3 0 21 :4 0 1d0
1 :8 0 1c9e 8b
:3 0 b2 :3 0 1c99
1c9a 0 b3 :3 0
1c9b 1c9c 0 1c9e
ff2 1cf1 b4 :3 0
8b :3 0 b2 :3 0
1ca0 1ca1 0 b3
:3 0 1ca2 1ca3 0
1ca5 ff5 1ca7 ff7
1ca6 1ca5 :2 0 1cef
b5 :3 0 8b :3 0
b2 :3 0 1caa 1cab
0 b3 :3 0 1cac
1cad 0 1ce7 8e
:3 0 8f :3 0 1caf
1cb0 0 8e :3 0
a1 :3 0 1cb2 1cb3
0 b6 :2 0 2
:4 0 1d1 :2 0 a3
:2 0 35 :2 0 ff9
1cb8 1cba :3 0 ffc
1cb4 1cbc 1cb1 1cbe
1cbd :2 0 91 :3 0
a4 :3 0 1cc0 1cc1
0 93 :4 0 1d2
:4 0 96 :2 0 97
:3 0 1000 1cc5 1cc7
:3 0 96 :2 0 b9
:4 0 1003 1cc9 1ccb
:3 0 96 :2 0 ba
:4 0 1006 1ccd 1ccf
:3 0 96 :2 0 b3
:3 0 1009 1cd1 1cd3
:3 0 96 :2 0 bb
:4 0 100c 1cd5 1cd7
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 100f
1cda 1cde 1013 1cd9
1ce0 :3 0 1016 1cc2
1ce2 :2 0 1ce4 1019
1ce5 1cbf 1ce4 0
1ce6 101b 0 1ce7
101d 1cea :3 0 1cea
0 1cea 1ce9 1ce7
1ce8 :6 0 1cec 42
:3 0 1020 1cee 1022
1ced 1cec :2 0 1cef
1024 :2 0 1cf1 0
1cf1 1cf0 1c9e 1cef
:6 0 1d24 1 :3 0
9b :3 0 70 :3 0
38 :2 0 1027 1cf3
1cf6 bf :2 0 35
:2 0 102c 1cf8 1cfa
:3 0 11 :3 0 21
:3 0 1cfc 1cfd 0
1d21 8e :3 0 8f
:3 0 1cff 1d00 0
8e :3 0 a1 :3 0
1d02 1d03 0 35
:2 0 2 :4 0 1d3
:2 0 a3 :2 0 35
:2 0 102f 1d08 1d0a
:3 0 1032 1d04 1d0c
1d01 1d0e 1d0d :2 0
91 :3 0 a4 :3 0
1d10 1d11 0 93
:4 0 1d4 :4 0 96
:2 0 97 :3 0 1036
1d15 1d17 :3 0 1039
1d12 1d19 :2 0 1d1b
103c 1d1c 1d0f 1d1b
0 1d1d 103e 0
1d21 12 :3 0 38
:2 0 1d1f :2 0 1d21
1040 1d22 1cfb 1d21
0 1d23 1044 0
1d24 1046 1d25 1c8d
1d24 0 1d26 104a
0 1f77 9b :3 0
56 :3 0 38 :2 0
104c 1d27 1d2a fb
:3 0 bf :2 0 134
:3 0 1d2c 1d2e 0
1051 1d2d 1d30 :3 0
9b :3 0 56 :3 0
38 :2 0 1054 1d32
1d35 fb :3 0 bf
:2 0 135 :3 0 1d37
1d39 0 1059 1d38
1d3b :3 0 1d31 1d3d
1d3c :2 0 3b :3 0
10b :2 0 35 :2 0
105c 1d40 1d42 :3 0
1d3f 1d43 0 1ebf
6f :3 0 190 :3 0
24 :3 0 48 :3 0
21 :3 0 30 :3 0
32 :3 0 71 :3 0
73 :3 0 3b :3 0
3a :3 0 39 :3 0
105e 1d46 1d51 1d45
1d52 0 1ebf 9b
:3 0 53 :3 0 38
:2 0 1069 1d54 1d57
105 :2 0 38 :2 0
106e 1d59 1d5b :3 0
1d5c :2 0 3d :3 0
10a :2 0 1071 1d5f
1d60 :3 0 1d61 :2 0
1d62 :2 0 1d5d 1d64
1d63 :2 0 102 :3 0
10f :3 0 d3 :3 0
bc :3 0 3d :3 0
102 :3 0 110 :3 0
27 :3 0 27 :3 0
117 :4 0 1d5 1
:8 0 1d76 8b :3 0
b2 :3 0 1d71 1d72
0 b3 :3 0 1d73
1d74 0 1d76 1073
1dc9 b4 :3 0 8b
:3 0 b2 :3 0 1d78
1d79 0 b3 :3 0
1d7a 1d7b 0 1d7d
1076 1d7f 1078 1d7e
1d7d :2 0 1dc7 b5
:3 0 8b :3 0 b2
:3 0 1d82 1d83 0
b3 :3 0 1d84 1d85
0 1dbf 8e :3 0
8f :3 0 1d87 1d88
0 8e :3 0 a1
:3 0 1d8a 1d8b 0
b6 :2 0 2 :4 0
1d6 :2 0 a3 :2 0
35 :2 0 107a 1d90
1d92 :3 0 107d 1d8c
1d94 1d89 1d96 1d95
:2 0 91 :3 0 a4
:3 0 1d98 1d99 0
93 :4 0 1d7 :4 0
96 :2 0 97 :3 0
1081 1d9d 1d9f :3 0
96 :2 0 b9 :4 0
1084 1da1 1da3 :3 0
96 :2 0 ba :4 0
1087 1da5 1da7 :3 0
96 :2 0 b3 :3 0
108a 1da9 1dab :3 0
96 :2 0 bb :4 0
108d 1dad 1daf :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 1090 1db2
1db6 1094 1db1 1db8
:3 0 1097 1d9a 1dba
:2 0 1dbc 109a 1dbd
1d97 1dbc 0 1dbe
109c 0 1dbf 109e
1dc2 :3 0 1dc2 0
1dc2 1dc1 1dbf 1dc0
:6 0 1dc4 44 :3 0
10a1 1dc6 10a3 1dc5
1dc4 :2 0 1dc7 10a5
:2 0 1dc9 0 1dc9
1dc8 1d76 1dc7 :6 0
1dcb 1 :3 0 10a8
1dcc 1d65 1dcb 0
1dcd 10aa 0 1ebf
54 :3 0 1cb :3 0
9b :3 0 4e :3 0
38 :2 0 10ac 1dd0
1dd3 1cc :2 0 9b
:3 0 57 :3 0 38
:2 0 10af 1dd6 1dd9
10b2 1dd5 1ddb :3 0
1ddc :2 0 1cd :2 0
1ce :2 0 10b5 1dde
1de0 :3 0 1de1 :2 0
a3 :2 0 1d8 :2 0
10b8 1de3 1de5 :3 0
10bb 1dcf 1de7 1dce
1de8 0 1ebf 70
:3 0 1d9 :3 0 24
:3 0 22 :3 0 21
:3 0 27 :3 0 28
:3 0 54 :3 0 54
:3 0 38 :2 0 10bd
1deb 1df4 1dea 1df5
0 1ebf 70 :3 0
1da :3 0 1db :3 0
1df8 1df9 0 9b
:3 0 4e :3 0 38
:2 0 10c6 1dfb 1dfe
fb :3 0 1dc :3 0
1e00 1e01 0 10c9
1dfa 1e03 1df7 1e04
0 1ebf 70 :3 0
1dd :3 0 24 :3 0
21 :3 0 70 :3 0
38 :2 0 38 :2 0
10cc 1e07 1e0d 1e06
1e0e 0 1ebf d3
:3 0 bc :3 0 27
:3 0 d3 :3 0 bc
:3 0 2a :3 0 d4
:3 0 d5 :3 0 d6
:3 0 d8 :3 0 30
:3 0 32 :3 0 39
:3 0 3a :3 0 71
:3 0 73 :3 0 e1
:3 0 e2 :3 0 21
:4 0 19e 1 :8 0
1e29 8b :3 0 b2
:3 0 1e24 1e25 0
b3 :3 0 1e26 1e27
0 1e29 10d2 1e7c
b4 :3 0 8b :3 0
b2 :3 0 1e2b 1e2c
0 b3 :3 0 1e2d
1e2e 0 1e30 10d5
1e32 10d7 1e31 1e30
:2 0 1e7a b5 :3 0
8b :3 0 b2 :3 0
1e35 1e36 0 b3
:3 0 1e37 1e38 0
1e72 8e :3 0 8f
:3 0 1e3a 1e3b 0
8e :3 0 a1 :3 0
1e3d 1e3e 0 b6
:2 0 2 :4 0 1de
:2 0 a3 :2 0 35
:2 0 10d9 1e43 1e45
:3 0 10dc 1e3f 1e47
1e3c 1e49 1e48 :2 0
91 :3 0 a4 :3 0
1e4b 1e4c 0 93
:4 0 1df :4 0 96
:2 0 97 :3 0 10e0
1e50 1e52 :3 0 96
:2 0 b9 :4 0 10e3
1e54 1e56 :3 0 96
:2 0 ba :4 0 10e6
1e58 1e5a :3 0 96
:2 0 b3 :3 0 10e9
1e5c 1e5e :3 0 96
:2 0 bb :4 0 10ec
1e60 1e62 :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 10ef 1e65 1e69
10f3 1e64 1e6b :3 0
10f6 1e4d 1e6d :2 0
1e6f 10f9 1e70 1e4a
1e6f 0 1e71 10fb
0 1e72 10fd 1e75
:3 0 1e75 0 1e75
1e74 1e72 1e73 :6 0
1e77 46 :3 0 1100
1e79 1102 1e78 1e77
:2 0 1e7a 1104 :2 0
1e7c 0 1e7c 1e7b
1e29 1e7a :6 0 1ebf
1 :3 0 3b :3 0
38 :2 0 1e7e 1e7f
0 1ebf 70 :3 0
190 :3 0 24 :3 0
48 :3 0 21 :3 0
30 :3 0 32 :3 0
71 :3 0 73 :3 0
3b :3 0 3a :3 0
39 :3 0 1107 1e82
1e8d 1e81 1e8e 0
1ebf 70 :3 0 133
:3 0 24 :3 0 1112
1e91 1e93 1e90 1e94
0 1ebf 11 :3 0
21 :3 0 1e96 1e97
0 1ebf 8e :3 0
8f :3 0 1e99 1e9a
0 8e :3 0 a1
:3 0 1e9c 1e9d 0
35 :2 0 2 :4 0
1e0 :2 0 a3 :2 0
35 :2 0 1114 1ea2
1ea4 :3 0 1117 1e9e
1ea6 1e9b 1ea8 1ea7
:2 0 91 :3 0 a4
:3 0 1eaa 1eab 0
93 :4 0 1e1 :4 0
96 :2 0 97 :3 0
111b 1eaf 1eb1 :3 0
111e 1eac 1eb3 :2 0
1eb5 1121 1eb6 1ea9
1eb5 0 1eb7 1123
0 1ebf 12 :3 0
9b :3 0 70 :3 0
38 :2 0 1125 1eb9
1ebc 1ebd :2 0 1ebf
1128 1f74 4d :3 0
38 :2 0 1ec0 1ec1
0 1f73 7d :3 0
192 :2 0 1ec3 1ec4
0 1f73 9b :3 0
5b :3 0 38 :2 0
1137 1ec6 1ec9 17a
:2 0 1e2 :2 0 113c
1ecb 1ecd :3 0 5b
:3 0 35 :2 0 1ecf
1ed0 0 1ed2 113f
1ed3 1ece 1ed2 0
1ed4 1141 0 1f73
61 :3 0 1da :3 0
1db :3 0 1ed6 1ed7
0 1da :3 0 1db
:3 0 1ed9 1eda 0
fb :3 0 1e3 :3 0
1edc 1edd 0 fb
:3 0 1e4 :3 0 1edf
1ee0 0 1143 1edb
1ee2 fb :3 0 1e5
:3 0 1ee4 1ee5 0
1146 1ed8 1ee7 1ed5
1ee8 0 1f73 e1
:3 0 1e6 :3 0 ca
:3 0 4e :3 0 c5
:3 0 c7 :3 0 c4
:3 0 c8 :3 0 e0
:3 0 111 :3 0 1db
:3 0 e0 :3 0 61
:3 0 e2 :3 0 21
:4 0 1e7 1 :8 0
1f0f 127 :4 0 1efa
:3 0 128 :3 0 bf
:2 0 114b 1efd 1efe
:3 0 8b :3 0 b2
:3 0 1f00 1f01 0
38 :2 0 1f02 1f03
0 1f05 114e 1f0c
8b :3 0 b2 :3 0
1f06 1f07 0 129
:2 0 1f08 1f09 0
1f0b 1150 1f0d 1eff
1f05 0 1f0e 0
1f0b 0 1f0e 1152
0 1f0f 1155 1f62
b4 :3 0 8b :3 0
b2 :3 0 1f11 1f12
0 b3 :3 0 1f13
1f14 0 1f16 1158
1f18 115a 1f17 1f16
:2 0 1f60 b5 :3 0
8b :3 0 b2 :3 0
1f1b 1f1c 0 b3
:3 0 1f1d 1f1e 0
1f58 8e :3 0 8f
:3 0 1f20 1f21 0
8e :3 0 a1 :3 0
1f23 1f24 0 b6
:2 0 2 :4 0 1e8
:2 0 a3 :2 0 35
:2 0 115c 1f29 1f2b
:3 0 115f 1f25 1f2d
1f22 1f2f 1f2e :2 0
91 :3 0 a4 :3 0
1f31 1f32 0 93
:4 0 1e9 :4 0 96
:2 0 97 :3 0 1163
1f36 1f38 :3 0 96
:2 0 b9 :4 0 1166
1f3a 1f3c :3 0 96
:2 0 ba :4 0 1169
1f3e 1f40 :3 0 96
:2 0 b3 :3 0 116c
1f42 1f44 :3 0 96
:2 0 bb :4 0 116f
1f46 1f48 :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 1172 1f4b 1f4f
1176 1f4a 1f51 :3 0
1179 1f33 1f53 :2 0
1f55 117c 1f56 1f30
1f55 0 1f57 117e
0 1f58 1180 1f5b
:3 0 1f5b 0 1f5b
1f5a 1f58 1f59 :6 0
1f5d 48 :3 0 1183
1f5f 1185 1f5e 1f5d
:2 0 1f60 1187 :2 0
1f62 0 1f62 1f61
1f0f 1f60 :6 0 1f73
1 :3 0 9b :3 0
4c :3 0 38 :2 0
118a 1f64 1f67 106
:2 0 38 :2 0 118f
1f69 1f6b :3 0 4c
:3 0 38 :2 0 1f6d
1f6e 0 1f70 1192
1f71 1f6c 1f70 0
1f72 1194 0 1f73
1196 1f75 1d3e 1ebf
0 1f76 0 1f73
0 1f76 119d 0
1f77 11a0 1f78 1b93
1f77 0 1f7a 1328
1b86 0 1f7a 11a7
0 2896 7d :3 0
105 :2 0 38 :2 0
11ac 1f7c 1f7e :3 0
3b :3 0 10b :2 0
35 :2 0 11af 1f81
1f83 :3 0 1f80 1f84
0 21ef 6f :3 0
190 :3 0 24 :3 0
48 :3 0 21 :3 0
30 :3 0 32 :3 0
71 :3 0 73 :3 0
3b :3 0 3a :3 0
39 :3 0 11b1 1f87
1f92 1f86 1f93 0
21ef 9b :3 0 53
:3 0 38 :2 0 11bc
1f95 1f98 105 :2 0
38 :2 0 11c1 1f9a
1f9c :3 0 1f9d :2 0
3d :3 0 10a :2 0
11c4 1fa0 1fa1 :3 0
1fa2 :2 0 1fa3 :2 0
1f9e 1fa5 1fa4 :2 0
70 :3 0 191 :3 0
24 :3 0 48 :3 0
49 :3 0 22 :3 0
21 :3 0 3d :3 0
53 :3 0 38 :2 0
11c6 1fa8 1fb1 1fa7
1fb2 0 1fb4 11cf
1fb5 1fa6 1fb4 0
1fb6 11d1 0 21ef
22 :3 0 10a :2 0
11d3 1fb8 1fb9 :3 0
1fba :2 0 6f :3 0
1ea :3 0 24 :3 0
21 :3 0 192 :2 0
11d5 1fbd 1fc1 1fbc
1fc2 0 1fc4 11d9
1fe5 bc :3 0 34
:3 0 35 :2 0 35
:2 0 11db 1fc5 1fc9
bf :2 0 192 :4 0
11e1 1fcb 1fcd :3 0
6f :3 0 1ea :3 0
24 :3 0 21 :3 0
38 :2 0 11e4 1fd0
1fd4 1fcf 1fd5 0
1fd7 11e8 1fe1 6f
:3 0 1ea :3 0 24
:3 0 21 :3 0 35
:2 0 11ea 1fd9 1fdd
1fd8 1fde 0 1fe0
11ee 1fe2 1fce 1fd7
0 1fe3 0 1fe0
0 1fe3 11f0 0
1fe4 11f3 1fe6 1fbb
1fc4 0 1fe7 0
1fe4 0 1fe7 11f5
0 21ef 3d :3 0
10a :2 0 11f8 1fe9
1fea :3 0 1feb :2 0
9b :3 0 4c :3 0
38 :2 0 11fa 1fed
1ff0 105 :2 0 38
:2 0 11ff 1ff2 1ff4
:3 0 4c :3 0 1da
:3 0 1db :3 0 1ff7
1ff8 0 9b :3 0
4c :3 0 38 :2 0
1202 1ffa 1ffd fb
:3 0 1eb :3 0 1fff
2000 0 1205 1ff9
2002 2003 :2 0 1ff6
2004 0 206b 102
:3 0 10f :3 0 d3
:3 0 bc :3 0 3d
:3 0 102 :3 0 110
:3 0 27 :3 0 27
:3 0 117 :4 0 1d5
1 :8 0 2016 8b
:3 0 b2 :3 0 2011
2012 0 b3 :3 0
2013 2014 0 2016
1208 2069 b4 :3 0
8b :3 0 b2 :3 0
2018 2019 0 b3
:3 0 201a 201b 0
201d 120b 201f 120d
201e 201d :2 0 2067
b5 :3 0 8b :3 0
b2 :3 0 2022 2023
0 b3 :3 0 2024
2025 0 205f 8e
:3 0 8f :3 0 2027
2028 0 8e :3 0
a1 :3 0 202a 202b
0 b6 :2 0 2
:4 0 1ec :2 0 a3
:2 0 35 :2 0 120f
2030 2032 :3 0 1212
202c 2034 2029 2036
2035 :2 0 91 :3 0
a4 :3 0 2038 2039
0 93 :4 0 1ed
:4 0 96 :2 0 97
:3 0 1216 203d 203f
:3 0 96 :2 0 b9
:4 0 1219 2041 2043
:3 0 96 :2 0 ba
:4 0 121c 2045 2047
:3 0 96 :2 0 b3
:3 0 121f 2049 204b
:3 0 96 :2 0 bb
:4 0 1222 204d 204f
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 1225
2052 2056 1229 2051
2058 :3 0 122c 203a
205a :2 0 205c 122f
205d 2037 205c 0
205e 1231 0 205f
1233 2062 :3 0 2062
0 2062 2061 205f
2060 :6 0 2064 4a
:3 0 1236 2066 1238
2065 2064 :2 0 2067
123a :2 0 2069 0
2069 2068 2016 2067
:6 0 206b 1 :3 0
123d 20d2 102 :3 0
10f :3 0 d3 :3 0
bc :3 0 3d :3 0
102 :3 0 110 :3 0
27 :3 0 27 :3 0
117 :4 0 1ee 1
:8 0 207c 8b :3 0
b2 :3 0 2077 2078
0 b3 :3 0 2079
207a 0 207c 1240
20cf b4 :3 0 8b
:3 0 b2 :3 0 207e
207f 0 b3 :3 0
2080 2081 0 2083
1243 2085 1245 2084
2083 :2 0 20cd b5
:3 0 8b :3 0 b2
:3 0 2088 2089 0
b3 :3 0 208a 208b
0 20c5 8e :3 0
8f :3 0 208d 208e
0 8e :3 0 a1
:3 0 2090 2091 0
b6 :2 0 2 :4 0
1ef :2 0 a3 :2 0
35 :2 0 1247 2096
2098 :3 0 124a 2092
209a 208f 209c 209b
:2 0 91 :3 0 a4
:3 0 209e 209f 0
93 :4 0 1f0 :4 0
96 :2 0 97 :3 0
124e 20a3 20a5 :3 0
96 :2 0 b9 :4 0
1251 20a7 20a9 :3 0
96 :2 0 ba :4 0
1254 20ab 20ad :3 0
96 :2 0 b3 :3 0
1257 20af 20b1 :3 0
96 :2 0 bb :4 0
125a 20b3 20b5 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 125d 20b8
20bc 1261 20b7 20be
:3 0 1264 20a0 20c0
:2 0 20c2 1267 20c3
209d 20c2 0 20c4
1269 0 20c5 126b
20c8 :3 0 20c8 0
20c8 20c7 20c5 20c6
:6 0 20ca 4c :3 0
126e 20cc 1270 20cb
20ca :2 0 20cd 1272
:2 0 20cf 0 20cf
20ce 207c 20cd :6 0
20d1 1 :3 0 1275
20d3 1ff5 206b 0
20d4 0 20d1 0
20d4 1277 0 20e4
4b :3 0 9b :3 0
4b :3 0 38 :2 0
127a 20d6 20d9 10b
:2 0 9b :3 0 50
:3 0 38 :2 0 127d
20dc 20df 1280 20db
20e1 :3 0 20d5 20e2
0 20e4 1283 20e5
1fec 20e4 0 20e6
1286 0 21ef 6e
:3 0 192 :2 0 20e7
20e8 0 21ef 6f
:3 0 1f1 :3 0 21
:3 0 27 :3 0 4b
:3 0 6e :3 0 4c
:3 0 4a :3 0 9b
:3 0 4d :3 0 38
:2 0 1288 20f2 20f5
9b :3 0 4e :3 0
38 :2 0 128b 20f7
20fa 128e 20eb 20fc
20ea 20fd 0 21ef
9b :3 0 6f :3 0
38 :2 0 1297 20ff
2102 106 :2 0 38
:2 0 129c 2104 2106
:3 0 11 :3 0 21
:3 0 2108 2109 0
2130 8e :3 0 8f
:3 0 210b 210c 0
8e :3 0 a1 :3 0
210e 210f 0 35
:2 0 2 :4 0 1f2
:2 0 a3 :2 0 35
:2 0 129f 2114 2116
:3 0 12a2 2110 2118
210d 211a 2119 :2 0
91 :3 0 a4 :3 0
211c 211d 0 93
:4 0 1f3 :4 0 96
:2 0 97 :3 0 12a6
2121 2123 :3 0 12a9
211e 2125 :2 0 2127
12ac 2128 211b 2127
0 2129 12ae 0
2130 12 :3 0 fb
:3 0 155 :3 0 212b
212c 0 212d :2 0
2130 159 :3 0 12b0
21be 7d :3 0 bf
:2 0 35 :2 0 12b6
2132 2134 :3 0 e1
:3 0 1f4 :3 0 e2
:3 0 21 :4 0 1f5
1 :8 0 21bc e1
:3 0 1e6 :3 0 e0
:3 0 111 :3 0 1db
:3 0 e0 :3 0 fb
:3 0 1e3 :3 0 fb
:3 0 1e4 :3 0 1f6
:3 0 9b :3 0 123
:3 0 12c :3 0 1f7
:3 0 9b :3 0 124
:3 0 12d :3 0 1f4
:3 0 1f8 :3 0 e2
:3 0 21 :4 0 1f9
1 :8 0 2167 127
:4 0 2152 :3 0 128
:3 0 bf :2 0 12bb
2155 2156 :3 0 8b
:3 0 b2 :3 0 2158
2159 0 38 :2 0
215a 215b 0 215d
12be 2164 8b :3 0
b2 :3 0 215e 215f
0 129 :2 0 2160
2161 0 2163 12c0
2165 2157 215d 0
2166 0 2163 0
2166 12c2 0 2167
12c5 21ba b4 :3 0
8b :3 0 b2 :3 0
2169 216a 0 b3
:3 0 216b 216c 0
216e 12c8 2170 12ca
216f 216e :2 0 21b8
b5 :3 0 8b :3 0
b2 :3 0 2173 2174
0 b3 :3 0 2175
2176 0 21b0 8e
:3 0 8f :3 0 2178
2179 0 8e :3 0
a1 :3 0 217b 217c
0 b6 :2 0 2
:4 0 1fa :2 0 a3
:2 0 35 :2 0 12cc
2181 2183 :3 0 12cf
217d 2185 217a 2187
2186 :2 0 91 :3 0
a4 :3 0 2189 218a
0 93 :4 0 1fb
:4 0 96 :2 0 97
:3 0 12d3 218e 2190
:3 0 96 :2 0 b9
:4 0 12d6 2192 2194
:3 0 96 :2 0 ba
:4 0 12d9 2196 2198
:3 0 96 :2 0 b3
:3 0 12dc 219a 219c
:3 0 96 :2 0 bb
:4 0 12df 219e 21a0
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 12e2
21a3 21a7 12e6 21a2
21a9 :3 0 12e9 218b
21ab :2 0 21ad 12ec
21ae 2188 21ad 0
21af 12ee 0 21b0
12f0 21b3 :3 0 21b3
0 21b3 21b2 21b0
21b1 :6 0 21b5 4e
:3 0 12f3 21b7 12f5
21b6 21b5 :2 0 21b8
12f7 :2 0 21ba 0
21ba 21b9 2167 21b8
:6 0 21bc 1 :3 0
12fa 21bd 2135 21bc
0 21bf 2107 2130
0 21bf 12fd 0
21ef 70 :3 0 133
:3 0 24 :3 0 1300
21c1 21c3 21c0 21c4
0 21ef 11 :3 0
21 :3 0 21c6 21c7
0 21ef 8e :3 0
8f :3 0 21c9 21ca
0 8e :3 0 a1
:3 0 21cc 21cd 0
35 :2 0 2 :4 0
1fc :2 0 a3 :2 0
35 :2 0 1302 21d2
21d4 :3 0 1305 21ce
21d6 21cb 21d8 21d7
:2 0 91 :3 0 a4
:3 0 21da 21db 0
93 :4 0 1fd :4 0
96 :2 0 97 :3 0
1309 21df 21e1 :3 0
130c 21dc 21e3 :2 0
21e5 130f 21e6 21d9
21e5 0 21e7 1311
0 21ef 12 :3 0
9b :3 0 70 :3 0
38 :2 0 1313 21e9
21ec 21ed :2 0 21ef
1316 21f0 1f7f 21ef
0 21f1 1323 0
2896 9b :3 0 16
:3 0 38 :2 0 1325
21f2 21f5 9b :3 0
106 :2 0 50 :3 0
38 :2 0 1328 21f7
21fb 132d 21f8 21fd
:3 0 70 :3 0 38
:2 0 21ff 2200 0
2729 136 :3 0 70
:3 0 117 :3 0 86
:3 0 15e :3 0 e2
:3 0 21 :3 0 e2
:3 0 86 :3 0 15f
:3 0 fb :3 0 160
:4 0 1fe 1 :8 0
2214 8b :3 0 b2
:3 0 220f 2210 0
b3 :3 0 2211 2212
0 2214 1330 2267
b4 :3 0 8b :3 0
b2 :3 0 2216 2217
0 b3 :3 0 2218
2219 0 221b 1333
221d 1335 221c 221b
:2 0 2265 b5 :3 0
8b :3 0 b2 :3 0
2220 2221 0 b3
:3 0 2222 2223 0
225d 8e :3 0 8f
:3 0 2225 2226 0
8e :3 0 a1 :3 0
2228 2229 0 b6
:2 0 2 :4 0 1ff
:2 0 a3 :2 0 35
:2 0 1337 222e 2230
:3 0 133a 222a 2232
2227 2234 2233 :2 0
91 :3 0 a4 :3 0
2236 2237 0 93
:4 0 200 :4 0 96
:2 0 97 :3 0 133e
223b 223d :3 0 96
:2 0 b9 :4 0 1341
223f 2241 :3 0 96
:2 0 ba :4 0 1344
2243 2245 :3 0 96
:2 0 b3 :3 0 1347
2247 2249 :3 0 96
:2 0 bb :4 0 134a
224b 224d :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 134d 2250 2254
1351 224f 2256 :3 0
1354 2238 2258 :2 0
225a 1357 225b 2235
225a 0 225c 1359
0 225d 135b 2260
:3 0 2260 0 2260
225f 225d 225e :6 0
2262 50 :3 0 135e
2264 1360 2263 2262
:2 0 2265 1362 :2 0
2267 0 2267 2266
2214 2265 :6 0 2729
1 :3 0 9b :3 0
70 :3 0 38 :2 0
1365 2269 226c 105
:2 0 38 :2 0 136a
226e 2270 :3 0 11
:3 0 21 :3 0 2272
2273 0 2299 8e
:3 0 8f :3 0 2275
2276 0 8e :3 0
a1 :3 0 2278 2279
0 35 :2 0 2
:4 0 201 :2 0 a3
:2 0 35 :2 0 136d
227e 2280 :3 0 1370
227a 2282 2277 2284
2283 :2 0 91 :3 0
a4 :3 0 2286 2287
0 93 :4 0 202
:4 0 96 :2 0 97
:3 0 1374 228b 228d
:3 0 1377 2288 228f
:2 0 2291 137a 2292
2285 2291 0 2293
137c 0 2299 12
:3 0 fb :3 0 101
:3 0 2295 2296 0
2297 :2 0 2299 137e
229a 2271 2299 0
229b 1382 0 2729
51 :3 0 9b :3 0
16 :3 0 38 :2 0
1384 229d 22a0 229c
22a1 0 2729 5f
:3 0 9b :3 0 4b
:3 0 38 :2 0 1387
22a4 22a7 22a3 22a8
0 2729 9b :3 0
51 :3 0 38 :2 0
138a 22aa 22ad 9b
:3 0 105 :2 0 4b
:3 0 38 :2 0 138d
22af 22b3 1392 22b0
22b5 :3 0 9b :3 0
56 :3 0 38 :2 0
1395 22b7 22ba fb
:3 0 bf :2 0 135
:3 0 22bc 22be 0
139a 22bd 22c0 :3 0
9b :3 0 56 :3 0
38 :2 0 139d 22c2
22c5 fb :3 0 bf
:2 0 134 :3 0 22c7
22c9 0 13a2 22c8
22cb :3 0 22c1 22cd
22cc :2 0 3c :4 0
22cf 22d0 0 24c5
136 :3 0 81 :3 0
203 :3 0 81 :3 0
64 :3 0 3c :3 0
13e :3 0 ae :3 0
24 :3 0 e2 :3 0
21 :3 0 13f :4 0
204 1 :8 0 22e4
8b :3 0 b2 :3 0
22df 22e0 0 b3
:3 0 22e1 22e2 0
22e4 13a5 2337 b4
:3 0 8b :3 0 b2
:3 0 22e6 22e7 0
b3 :3 0 22e8 22e9
0 22eb 13a8 22ed
13aa 22ec 22eb :2 0
2335 b5 :3 0 8b
:3 0 b2 :3 0 22f0
22f1 0 b3 :3 0
22f2 22f3 0 232d
8e :3 0 8f :3 0
22f5 22f6 0 8e
:3 0 a1 :3 0 22f8
22f9 0 b6 :2 0
2 :4 0 205 :2 0
a3 :2 0 35 :2 0
13ac 22fe 2300 :3 0
13af 22fa 2302 22f7
2304 2303 :2 0 91
:3 0 a4 :3 0 2306
2307 0 93 :4 0
206 :4 0 96 :2 0
97 :3 0 13b3 230b
230d :3 0 96 :2 0
b9 :4 0 13b6 230f
2311 :3 0 96 :2 0
ba :4 0 13b9 2313
2315 :3 0 96 :2 0
b3 :3 0 13bc 2317
2319 :3 0 96 :2 0
bb :4 0 13bf 231b
231d :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
13c2 2320 2324 13c6
231f 2326 :3 0 13c9
2308 2328 :2 0 232a
13cc 232b 2305 232a
0 232c 13ce 0
232d 13d0 2330 :3 0
2330 0 2330 232f
232d 232e :6 0 2332
52 :3 0 13d3 2334
13d5 2333 2332 :2 0
2335 13d7 :2 0 2337
0 2337 2336 22e4
2335 :6 0 24c5 1
:3 0 3c :3 0 10a
:2 0 13da 233a 233b
:3 0 233c :2 0 27
:3 0 3c :3 0 233e
233f 0 2341 13dc
2342 233d 2341 0
2343 13de 0 24c5
9b :3 0 64 :3 0
38 :2 0 13e0 2344
2347 105 :2 0 38
:2 0 13e5 2349 234b
:3 0 3b :3 0 10b
:2 0 35 :2 0 13e8
234e 2350 :3 0 234d
2351 0 24c2 6f
:3 0 190 :3 0 24
:3 0 48 :3 0 21
:3 0 30 :3 0 32
:3 0 71 :3 0 73
:3 0 3b :3 0 3a
:3 0 39 :3 0 13ea
2354 235f 2353 2360
0 24c2 9b :3 0
53 :3 0 38 :2 0
13f5 2362 2365 105
:2 0 38 :2 0 13fa
2367 2369 :3 0 236a
:2 0 3d :3 0 10a
:2 0 13fd 236d 236e
:3 0 236f :2 0 2370
:2 0 236b 2372 2371
:2 0 207 :3 0 208
:3 0 54 :3 0 13e
:3 0 ae :3 0 24
:3 0 e2 :3 0 21
:3 0 81 :3 0 d3
:3 0 bc :3 0 3d
:4 0 209 1 :8 0
2386 8b :3 0 b2
:3 0 2381 2382 0
b3 :3 0 2383 2384
0 2386 13ff 23d9
b4 :3 0 8b :3 0
b2 :3 0 2388 2389
0 b3 :3 0 238a
238b 0 238d 1402
238f 1404 238e 238d
:2 0 23d7 b5 :3 0
8b :3 0 b2 :3 0
2392 2393 0 b3
:3 0 2394 2395 0
23cf 8e :3 0 8f
:3 0 2397 2398 0
8e :3 0 a1 :3 0
239a 239b 0 b6
:2 0 2 :4 0 20a
:2 0 a3 :2 0 35
:2 0 1406 23a0 23a2
:3 0 1409 239c 23a4
2399 23a6 23a5 :2 0
91 :3 0 a4 :3 0
23a8 23a9 0 93
:4 0 20b :4 0 96
:2 0 97 :3 0 140d
23ad 23af :3 0 96
:2 0 b9 :4 0 1410
23b1 23b3 :3 0 96
:2 0 ba :4 0 1413
23b5 23b7 :3 0 96
:2 0 b3 :3 0 1416
23b9 23bb :3 0 96
:2 0 bb :4 0 1419
23bd 23bf :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 141c 23c2 23c6
1420 23c1 23c8 :3 0
1423 23aa 23ca :2 0
23cc 1426 23cd 23a7
23cc 0 23ce 1428
0 23cf 142a 23d2
:3 0 23d2 0 23d2
23d1 23cf 23d0 :6 0
23d4 54 :3 0 142d
23d6 142f 23d5 23d4
:2 0 23d7 1431 :2 0
23d9 0 23d9 23d8
2386 23d7 :6 0 23f2
1 :3 0 4b :3 0
9b :3 0 51 :3 0
38 :2 0 1434 23dc
23df 10b :2 0 9b
:3 0 50 :3 0 38
:2 0 1437 23e2 23e5
143a 23e1 23e7 :3 0
10b :2 0 9b :3 0
54 :3 0 38 :2 0
143d 23ea 23ed 1440
23e9 23ef :3 0 23db
23f0 0 23f2 1443
2403 4b :3 0 9b
:3 0 51 :3 0 38
:2 0 1446 23f4 23f7
10b :2 0 9b :3 0
50 :3 0 38 :2 0
1449 23fa 23fd 144c
23f9 23ff :3 0 23f3
2400 0 2402 144f
2404 2373 23f2 0
2405 0 2402 0
2405 1451 0 24c2
4f :3 0 20c :2 0
2406 2407 0 24c2
54 :3 0 1cb :3 0
9b :3 0 20d :3 0
4b :3 0 1454 240c
240e 38 :2 0 1456
240b 2411 1cd :2 0
9b :3 0 20d :3 0
64 :3 0 1459 2415
2417 38 :2 0 145b
2414 241a 145e 2413
241c :3 0 241d :2 0
a3 :2 0 1d8 :2 0
1461 241f 2421 :3 0
1464 240a 2423 2409
2424 0 24c2 70
:3 0 9b :3 0 54
:3 0 38 :2 0 1466
2427 242a 1cc :2 0
9b :3 0 64 :3 0
38 :2 0 1469 242d
2430 146c 242c 2432
:3 0 2426 2433 0
24c2 9b :3 0 70
:3 0 38 :2 0 146f
2435 2438 9b :3 0
106 :2 0 4b :3 0
38 :2 0 1472 243a
243e 1477 243b 2440
:3 0 55 :3 0 9b
:3 0 54 :3 0 38
:2 0 147a 2443 2446
a3 :2 0 9b :3 0
70 :3 0 38 :2 0
147d 2449 244c 1480
2448 244e :3 0 10b
:2 0 9b :3 0 4b
:3 0 38 :2 0 1483
2451 2454 1486 2450
2456 :3 0 2442 2457
0 2459 1489 2462
55 :3 0 9b :3 0
54 :3 0 38 :2 0
148b 245b 245e 245a
245f 0 2461 148e
2463 2441 2459 0
2464 0 2461 0
2464 1490 0 24c2
70 :3 0 1d9 :3 0
24 :3 0 22 :3 0
21 :3 0 27 :3 0
28 :3 0 55 :3 0
54 :3 0 38 :2 0
1493 2466 246f 2465
2470 0 24c2 4e
:3 0 1cb :3 0 9b
:3 0 20d :3 0 54
:3 0 149c 2475 2477
38 :2 0 149e 2474
247a 1cd :2 0 9b
:3 0 20d :3 0 57
:3 0 14a1 247e 2480
38 :2 0 14a3 247d
2483 14a6 247c 2485
:3 0 2486 :2 0 1cc
:2 0 1ce :2 0 14a9
2488 248a :3 0 14ac
2473 248c 2472 248d
0 24c2 70 :3 0
1da :3 0 1db :3 0
2490 2491 0 9b
:3 0 4e :3 0 38
:2 0 14ae 2493 2496
fb :3 0 1eb :3 0
2498 2499 0 14b1
2492 249b 248f 249c
0 24c2 70 :3 0
1dd :3 0 24 :3 0
21 :3 0 70 :3 0
9b :3 0 57 :3 0
38 :2 0 14b4 24a3
24a6 9b :3 0 4e
:3 0 38 :2 0 14b7
24a8 24ab 14ba 249f
24ad 249e 24ae 0
24c2 3b :3 0 38
:2 0 24b0 24b1 0
24c2 70 :3 0 190
:3 0 24 :3 0 48
:3 0 21 :3 0 30
:3 0 32 :3 0 71
:3 0 73 :3 0 3b
:3 0 3a :3 0 39
:3 0 14c0 24b4 24bf
24b3 24c0 0 24c2
14cb 24c3 234c 24c2
0 24c4 14d9 0
24c5 14db 26a5 4f
:3 0 20c :2 0 24c6
24c7 0 26a4 70
:3 0 9b :3 0 4b
:3 0 38 :2 0 14e0
24ca 24cd 24c9 24ce
0 26a4 6f :3 0
20e :3 0 24 :3 0
48 :3 0 49 :3 0
21 :3 0 3d :3 0
34 :3 0 4b :3 0
70 :3 0 5f :3 0
50 :3 0 4f :3 0
71 :3 0 74 :3 0
73 :3 0 75 :3 0
76 :3 0 78 :3 0
77 :3 0 79 :3 0
3a :3 0 39 :3 0
53 :3 0 4a :3 0
9b :3 0 57 :3 0
38 :2 0 14e3 24e9
24ec 9b :3 0 56
:3 0 38 :2 0 14e6
24ee 24f1 14e9 24d1
24f3 24d0 24f4 0
26a4 50 :3 0 9b
:3 0 4b :3 0 38
:2 0 1503 24f7 24fa
24f6 24fb 0 26a4
4b :3 0 9b :3 0
51 :3 0 38 :2 0
1506 24fe 2501 10b
:2 0 9b :3 0 50
:3 0 38 :2 0 1509
2504 2507 150c 2503
2509 :3 0 24fd 250a
0 26a4 d3 :3 0
bc :3 0 28 :3 0
3d :3 0 117 :4 0
20f 1 :8 0 2517
8b :3 0 b2 :3 0
2512 2513 0 b3
:3 0 2514 2515 0
2517 150f 256a b4
:3 0 8b :3 0 b2
:3 0 2519 251a 0
b3 :3 0 251b 251c
0 251e 1512 2520
1514 251f 251e :2 0
2568 b5 :3 0 8b
:3 0 b2 :3 0 2523
2524 0 b3 :3 0
2525 2526 0 2560
8e :3 0 8f :3 0
2528 2529 0 8e
:3 0 a1 :3 0 252b
252c 0 b6 :2 0
2 :4 0 210 :2 0
a3 :2 0 35 :2 0
1516 2531 2533 :3 0
1519 252d 2535 252a
2537 2536 :2 0 91
:3 0 a4 :3 0 2539
253a 0 93 :4 0
211 :4 0 96 :2 0
97 :3 0 151d 253e
2540 :3 0 96 :2 0
b9 :4 0 1520 2542
2544 :3 0 96 :2 0
ba :4 0 1523 2546
2548 :3 0 96 :2 0
b3 :3 0 1526 254a
254c :3 0 96 :2 0
bb :4 0 1529 254e
2550 :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
152c 2553 2557 1530
2552 2559 :3 0 1533
253b 255b :2 0 255d
1536 255e 2538 255d
0 255f 1538 0
2560 153a 2563 :3 0
2563 0 2563 2562
2560 2561 :6 0 2565
56 :3 0 153d 2567
153f 2566 2565 :2 0
2568 1541 :2 0 256a
0 256a 2569 2517
2568 :6 0 26a4 1
:3 0 102 :3 0 10f
:3 0 d3 :3 0 bc
:3 0 28 :3 0 102
:3 0 110 :3 0 27
:3 0 117 :4 0 212
1 :8 0 257b 8b
:3 0 b2 :3 0 2576
2577 0 b3 :3 0
2578 2579 0 257b
1544 25ce b4 :3 0
8b :3 0 b2 :3 0
257d 257e 0 b3
:3 0 257f 2580 0
2582 1547 2584 1549
2583 2582 :2 0 25cc
b5 :3 0 8b :3 0
b2 :3 0 2587 2588
0 b3 :3 0 2589
258a 0 25c4 8e
:3 0 8f :3 0 258c
258d 0 8e :3 0
a1 :3 0 258f 2590
0 b6 :2 0 2
:4 0 213 :2 0 a3
:2 0 35 :2 0 154b
2595 2597 :3 0 154e
2591 2599 258e 259b
259a :2 0 91 :3 0
a4 :3 0 259d 259e
0 93 :4 0 214
:4 0 96 :2 0 97
:3 0 1552 25a2 25a4
:3 0 96 :2 0 b9
:4 0 1555 25a6 25a8
:3 0 96 :2 0 ba
:4 0 1558 25aa 25ac
:3 0 96 :2 0 b3
:3 0 155b 25ae 25b0
:3 0 96 :2 0 bb
:4 0 155e 25b2 25b4
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 1561
25b7 25bb 1565 25b6
25bd :3 0 1568 259f
25bf :2 0 25c1 156b
25c2 259c 25c1 0
25c3 156d 0 25c4
156f 25c7 :3 0 25c7
0 25c7 25c6 25c4
25c5 :6 0 25c9 58
:3 0 1572 25cb 1574
25ca 25c9 :2 0 25cc
1576 :2 0 25ce 0
25ce 25cd 257b 25cc
:6 0 26a4 1 :3 0
e1 :3 0 1e6 :3 0
e0 :3 0 111 :3 0
1db :3 0 e0 :3 0
fb :3 0 1e3 :3 0
d0 :3 0 51 :3 0
cc :3 0 51 :3 0
f2 :3 0 de :3 0
f3 :3 0 f4 :3 0
215 :3 0 e2 :3 0
21 :4 0 216 1
:8 0 25f9 127 :4 0
25e4 :3 0 128 :3 0
bf :2 0 157b 25e7
25e8 :3 0 8b :3 0
b2 :3 0 25ea 25eb
0 38 :2 0 25ec
25ed 0 25ef 157e
25f6 8b :3 0 b2
:3 0 25f0 25f1 0
129 :2 0 25f2 25f3
0 25f5 1580 25f7
25e9 25ef 0 25f8
0 25f5 0 25f8
1582 0 25f9 1585
264c b4 :3 0 8b
:3 0 b2 :3 0 25fb
25fc 0 b3 :3 0
25fd 25fe 0 2600
1588 2602 158a 2601
2600 :2 0 264a b5
:3 0 8b :3 0 b2
:3 0 2605 2606 0
b3 :3 0 2607 2608
0 2642 8e :3 0
8f :3 0 260a 260b
0 8e :3 0 a1
:3 0 260d 260e 0
b6 :2 0 2 :4 0
217 :2 0 a3 :2 0
35 :2 0 158c 2613
2615 :3 0 158f 260f
2617 260c 2619 2618
:2 0 91 :3 0 a4
:3 0 261b 261c 0
93 :4 0 218 :4 0
96 :2 0 97 :3 0
1593 2620 2622 :3 0
96 :2 0 b9 :4 0
1596 2624 2626 :3 0
96 :2 0 ba :4 0
1599 2628 262a :3 0
96 :2 0 b3 :3 0
159c 262c 262e :3 0
96 :2 0 bb :4 0
159f 2630 2632 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 15a2 2635
2639 15a6 2634 263b
:3 0 15a9 261d 263d
:2 0 263f 15ac 2640
261a 263f 0 2641
15ae 0 2642 15b0
2645 :3 0 2645 0
2645 2644 2642 2643
:6 0 2647 5a :3 0
15b3 2649 15b5 2648
2647 :2 0 264a 15b7
:2 0 264c 0 264c
264b 25f9 264a :6 0
26a4 1 :3 0 8b
:3 0 b2 :3 0 264e
264f 0 8b :3 0
bf :2 0 132 :3 0
2651 2653 0 15bc
2652 2655 :3 0 2656
:2 0 6e :3 0 192
:2 0 2658 2659 0
26a1 70 :3 0 1f1
:3 0 21 :3 0 27
:3 0 4b :3 0 6e
:3 0 4c :3 0 4a
:3 0 38 :2 0 9b
:3 0 4e :3 0 38
:2 0 15bf 2664 2667
15c2 265c 2669 265b
266a 0 26a1 9b
:3 0 70 :3 0 38
:2 0 15cb 266c 266f
106 :2 0 38 :2 0
15d0 2671 2673 :3 0
11 :3 0 21 :3 0
2675 2676 0 269e
8e :3 0 8f :3 0
2678 2679 0 8e
:3 0 a1 :3 0 267b
267c 0 35 :2 0
2 :4 0 219 :2 0
a3 :2 0 35 :2 0
15d3 2681 2683 :3 0
15d6 267d 2685 267a
2687 2686 :2 0 91
:3 0 a4 :3 0 2689
268a 0 93 :4 0
21a :4 0 96 :2 0
97 :3 0 15da 268e
2690 :3 0 15dd 268b
2692 :2 0 2694 15e0
2695 2688 2694 0
2696 15e2 0 269e
12 :3 0 9b :3 0
70 :3 0 38 :2 0
15e4 2698 269b 269c
:2 0 269e 15e7 269f
2674 269e 0 26a0
15eb 0 26a1 15ed
26a2 2657 26a1 0
26a3 15f1 0 26a4
15f3 26a6 22ce 24c5
0 26a7 0 26a4
0 26a7 15fd 0
26b2 4b :3 0 9b
:3 0 51 :3 0 38
:2 0 1600 26a9 26ac
26a8 26ad 0 26b2
53 :3 0 38 :2 0
26af 26b0 0 26b2
1603 26d6 4f :3 0
1cb :3 0 9b :3 0
20d :3 0 51 :3 0
1607 26b6 26b8 38
:2 0 1609 26b5 26bb
1cd :2 0 9b :3 0
20d :3 0 4b :3 0
160c 26bf 26c1 38
:2 0 160e 26be 26c4
1611 26bd 26c6 :3 0
26c7 :2 0 1cc :2 0
1ce :2 0 1614 26c9
26cb :3 0 26cc :2 0
a3 :2 0 1d8 :2 0
1617 26ce 26d0 :3 0
161a 26b4 26d2 26b3
26d3 0 26d5 161c
26d7 22b6 26b2 0
26d8 0 26d5 0
26d8 161e 0 2729
70 :3 0 20e :3 0
24 :3 0 48 :3 0
49 :3 0 21 :3 0
3d :3 0 34 :3 0
4b :3 0 51 :3 0
5f :3 0 50 :3 0
4f :3 0 71 :3 0
74 :3 0 73 :3 0
75 :3 0 76 :3 0
78 :3 0 77 :3 0
79 :3 0 3a :3 0
39 :3 0 53 :3 0
4a :3 0 9b :3 0
57 :3 0 38 :2 0
1621 26f2 26f5 9b
:3 0 56 :3 0 38
:2 0 1624 26f7 26fa
1627 26da 26fc 26d9
26fd 0 2729 11
:3 0 21 :3 0 26ff
2700 0 2729 8e
:3 0 8f :3 0 2702
2703 0 8e :3 0
a1 :3 0 2705 2706
0 35 :2 0 2
:4 0 21b :2 0 a3
:2 0 35 :2 0 1641
270b 270d :3 0 1644
2707 270f 2704 2711
2710 :2 0 91 :3 0
a4 :3 0 2713 2714
0 93 :4 0 21c
:4 0 96 :2 0 97
:3 0 1648 2718 271a
:3 0 164b 2715 271c
:2 0 271e 164e 271f
2712 271e 0 2720
1650 0 2729 12
:3 0 9b :3 0 70
:3 0 38 :2 0 1652
2722 2725 2726 :2 0
2729 159 :3 0 1655
2865 9b :3 0 15
:3 0 38 :2 0 1660
272a 272d 9b :3 0
106 :2 0 4f :3 0
38 :2 0 1663 272f
2733 1668 2730 2735
:3 0 9b :3 0 50
:3 0 38 :2 0 166b
2737 273a 105 :2 0
38 :2 0 1670 273c
273e :3 0 273f :2 0
9b :3 0 15 :3 0
38 :2 0 1673 2741
2744 bf :2 0 38
:2 0 1678 2746 2748
:3 0 2749 :2 0 2740
274b 274a :2 0 11
:3 0 21 :3 0 274d
274e 0 2774 8e
:3 0 8f :3 0 2750
2751 0 8e :3 0
a1 :3 0 2753 2754
0 35 :2 0 2
:4 0 21d :2 0 a3
:2 0 35 :2 0 167b
2759 275b :3 0 167e
2755 275d 2752 275f
275e :2 0 91 :3 0
a4 :3 0 2761 2762
0 93 :4 0 21e
:4 0 96 :2 0 97
:3 0 1682 2766 2768
:3 0 1685 2763 276a
:2 0 276c 1688 276d
2760 276c 0 276e
168a 0 2774 12
:3 0 8b :3 0 b2
:3 0 2770 2771 0
2772 :2 0 2774 168c
2775 274c 2774 0
2776 1690 0 2863
e1 :3 0 de :3 0
15 :3 0 e0 :3 0
111 :3 0 1db :3 0
e0 :3 0 fb :3 0
21f :3 0 e2 :3 0
21 :4 0 220 1
:8 0 2798 127 :4 0
2783 :3 0 128 :3 0
bf :2 0 1694 2786
2787 :3 0 8b :3 0
b2 :3 0 2789 278a
0 38 :2 0 278b
278c 0 278e 1697
2795 8b :3 0 b2
:3 0 278f 2790 0
129 :2 0 2791 2792
0 2794 1699 2796
2788 278e 0 2797
0 2794 0 2797
169b 0 2798 169e
27eb b4 :3 0 8b
:3 0 b2 :3 0 279a
279b 0 b3 :3 0
279c 279d 0 279f
16a1 27a1 16a3 27a0
279f :2 0 27e9 b5
:3 0 8b :3 0 b2
:3 0 27a4 27a5 0
b3 :3 0 27a6 27a7
0 27e1 8e :3 0
8f :3 0 27a9 27aa
0 8e :3 0 a1
:3 0 27ac 27ad 0
b6 :2 0 2 :4 0
221 :2 0 a3 :2 0
35 :2 0 16a5 27b2
27b4 :3 0 16a8 27ae
27b6 27ab 27b8 27b7
:2 0 91 :3 0 a4
:3 0 27ba 27bb 0
93 :4 0 222 :4 0
96 :2 0 97 :3 0
16ac 27bf 27c1 :3 0
96 :2 0 b9 :4 0
16af 27c3 27c5 :3 0
96 :2 0 ba :4 0
16b2 27c7 27c9 :3 0
96 :2 0 b3 :3 0
16b5 27cb 27cd :3 0
96 :2 0 bb :4 0
16b8 27cf 27d1 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 16bb 27d4
27d8 16bf 27d3 27da
:3 0 16c2 27bc 27dc
:2 0 27de 16c5 27df
27b9 27de 0 27e0
16c7 0 27e1 16c9
27e4 :3 0 27e4 0
27e4 27e3 27e1 27e2
:6 0 27e6 5c :3 0
16cc 27e8 16ce 27e7
27e6 :2 0 27e9 16d0
:2 0 27eb 0 27eb
27ea 2798 27e9 :6 0
2863 1 :3 0 f5
:3 0 e0 :3 0 111
:3 0 1db :3 0 e0
:3 0 fb :3 0 21f
:3 0 ae :3 0 24
:3 0 86 :3 0 48
:4 0 223 1 :8 0
280e 127 :4 0 27f9
:3 0 128 :3 0 bf
:2 0 16d5 27fc 27fd
:3 0 8b :3 0 b2
:3 0 27ff 2800 0
38 :2 0 2801 2802
0 2804 16d8 280b
8b :3 0 b2 :3 0
2805 2806 0 129
:2 0 2807 2808 0
280a 16da 280c 27fe
2804 0 280d 0
280a 0 280d 16dc
0 280e 16df 2861
b4 :3 0 8b :3 0
b2 :3 0 2810 2811
0 b3 :3 0 2812
2813 0 2815 16e2
2817 16e4 2816 2815
:2 0 285f b5 :3 0
8b :3 0 b2 :3 0
281a 281b 0 b3
:3 0 281c 281d 0
2857 8e :3 0 8f
:3 0 281f 2820 0
8e :3 0 a1 :3 0
2822 2823 0 b6
:2 0 2 :4 0 224
:2 0 a3 :2 0 35
:2 0 16e6 2828 282a
:3 0 16e9 2824 282c
2821 282e 282d :2 0
91 :3 0 a4 :3 0
2830 2831 0 93
:4 0 225 :4 0 96
:2 0 97 :3 0 16ed
2835 2837 :3 0 96
:2 0 b9 :4 0 16f0
2839 283b :3 0 96
:2 0 ba :4 0 16f3
283d 283f :3 0 96
:2 0 b3 :3 0 16f6
2841 2843 :3 0 96
:2 0 bb :4 0 16f9
2845 2847 :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 16fc 284a 284e
1700 2849 2850 :3 0
1703 2832 2852 :2 0
2854 1706 2855 282f
2854 0 2856 1708
0 2857 170a 285a
:3 0 285a 0 285a
2859 2857 2858 :6 0
285c 5e :3 0 170d
285e 170f 285d 285c
:2 0 285f 1711 :2 0
2861 0 2861 2860
280e 285f :6 0 2863
1 :3 0 1714 2864
2736 2863 0 2866
21fe 2729 0 2866
1718 0 2896 70
:3 0 133 :3 0 24
:3 0 171b 2868 286a
2867 286b 0 2896
11 :3 0 21 :3 0
286d 286e 0 2896
8e :3 0 8f :3 0
2870 2871 0 8e
:3 0 a1 :3 0 2873
2874 0 35 :2 0
2 :4 0 226 :2 0
a3 :2 0 35 :2 0
171d 2879 287b :3 0
1720 2875 287d 2872
287f 287e :2 0 91
:3 0 a4 :3 0 2881
2882 0 93 :4 0
227 :4 0 96 :2 0
97 :3 0 1724 2886
2888 :3 0 1727 2883
288a :2 0 288c 172a
288d 2880 288c 0
288e 172c 0 2896
12 :3 0 9b :3 0
70 :3 0 38 :2 0
172e 2890 2893 2894
:2 0 2896 1731 2897
10c1 2896 0 2987
a7 :3 0 228 :3 0
a7 :3 0 a9 :3 0
a7 :3 0 86 :3 0
a7 :3 0 aa :3 0
a7 :3 0 ab :3 0
a7 :3 0 ac :3 0
a7 :3 0 ad :3 0
a7 :3 0 ae :3 0
a7 :3 0 af :3 0
17 :3 0 41 :3 0
19 :3 0 3f :3 0
42 :3 0 47 :3 0
1a :3 0 24 :3 0
46 :3 0 b0 :3 0
a7 :3 0 a7 :3 0
a8 :3 0 1f :4 0
229 1 :8 0 28be
8b :3 0 b2 :3 0
28b9 28ba 0 b3
:3 0 28bb 28bc 0
28be 1742 2911 b4
:3 0 8b :3 0 b2
:3 0 28c0 28c1 0
b3 :3 0 28c2 28c3
0 28c5 1745 28c7
1747 28c6 28c5 :2 0
290f b5 :3 0 8b
:3 0 b2 :3 0 28ca
28cb 0 b3 :3 0
28cc 28cd 0 2907
8e :3 0 8f :3 0
28cf 28d0 0 8e
:3 0 a1 :3 0 28d2
28d3 0 b6 :2 0
2 :4 0 22a :2 0
a3 :2 0 35 :2 0
1749 28d8 28da :3 0
174c 28d4 28dc 28d1
28de 28dd :2 0 91
:3 0 a4 :3 0 28e0
28e1 0 93 :4 0
22b :4 0 96 :2 0
97 :3 0 1750 28e5
28e7 :3 0 96 :2 0
b9 :4 0 1753 28e9
28eb :3 0 96 :2 0
ba :4 0 1756 28ed
28ef :3 0 96 :2 0
b3 :3 0 1759 28f1
28f3 :3 0 96 :2 0
bb :4 0 175c 28f5
28f7 :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
175f 28fa 28fe 1763
28f9 2900 :3 0 1766
28e2 2902 :2 0 2904
1769 2905 28df 2904
0 2906 176b 0
2907 176d 290a :3 0
290a 0 290a 2909
2907 2908 :6 0 290c
60 :3 0 1770 290e
1772 290d 290c :2 0
290f 1774 :2 0 2911
0 2911 2910 28be
290f :6 0 2984 1
:3 0 8b :3 0 b2
:3 0 2913 2914 0
8b :3 0 bf :2 0
132 :3 0 2916 2918
0 1779 2917 291a
:3 0 291b :2 0 22c
:2 0 177c 291d 291e
:3 0 11 :3 0 1f
:3 0 2920 2921 0
2947 8e :3 0 8f
:3 0 2923 2924 0
8e :3 0 a1 :3 0
2926 2927 0 35
:2 0 2 :4 0 22d
:2 0 a3 :2 0 35
:2 0 177e 292c 292e
:3 0 1781 2928 2930
2925 2932 2931 :2 0
91 :3 0 a4 :3 0
2934 2935 0 93
:4 0 22e :4 0 96
:2 0 97 :3 0 1785
2939 293b :3 0 1788
2936 293d :2 0 293f
178b 2940 2933 293f
0 2941 178d 0
2947 12 :3 0 fb
:3 0 fc :3 0 2943
2944 0 2945 :2 0
2947 178f 2948 291f
2947 0 2949 1793
0 2984 102 :3 0
18f :3 0 294a 294b
0 20 :3 0 17
:3 0 1795 294c 294f
bf :2 0 38 :2 0
179a 2951 2953 :3 0
8b :3 0 b2 :3 0
2955 2956 0 38
:2 0 2957 2958 0
2981 11 :3 0 1f
:3 0 295a 295b 0
2981 8e :3 0 8f
:3 0 295d 295e 0
8e :3 0 a1 :3 0
2960 2961 0 35
:2 0 2 :4 0 22f
:2 0 a3 :2 0 35
:2 0 179d 2966 2968
:3 0 17a0 2962 296a
295f 296c 296b :2 0
91 :3 0 a4 :3 0
296e 296f 0 93
:4 0 230 :4 0 96
:2 0 97 :3 0 17a4
2973 2975 :3 0 17a7
2970 2977 :2 0 2979
17aa 297a 296d 2979
0 297b 17ac 0
2981 12 :3 0 8b
:3 0 b2 :3 0 297d
297e 0 297f :2 0
2981 17ae 2982 2954
2981 0 2983 17b3
0 2984 17b5 2986
4f6 10b5 0 2987
0 2984 0 2987
17b9 0 2988 17bd
2989 43f 2988 0
298a 17c0 0 29fd
21 :3 0 3 :3 0
298b 298c 0 29fd
20 :3 0 7 :3 0
298e 298f 0 29fd
4a :3 0 10 :3 0
2991 2992 0 29fd
46 :3 0 fb :3 0
231 :3 0 2995 2996
0 2994 2997 0
29fd 8b :3 0 b2
:3 0 2999 299a 0
232 :3 0 46 :3 0
21 :3 0 20 :3 0
4a :3 0 17c2 299c
29a1 299b 29a2 0
29fd 11 :3 0 21
:3 0 29a4 29a5 0
29fd 8e :3 0 8f
:3 0 29a7 29a8 0
8e :3 0 a1 :3 0
29aa 29ab 0 35
:2 0 2 :4 0 233
:2 0 a3 :2 0 35
:2 0 17c7 29b0 29b2
:3 0 17ca 29ac 29b4
29a9 29b6 29b5 :2 0
91 :3 0 a4 :3 0
29b8 29b9 0 93
:4 0 234 :4 0 96
:2 0 97 :3 0 17ce
29bd 29bf :3 0 17d1
29ba 29c1 :2 0 29c3
17d4 29c4 29b7 29c3
0 29c5 17d6 0
29fd 12 :3 0 8b
:3 0 b2 :3 0 29c7
29c8 0 29c9 :2 0
29fd 8e :3 0 8f
:3 0 29cb 29cc 0
8e :3 0 a1 :3 0
29ce 29cf 0 35
:2 0 2 :4 0 235
:2 0 a3 :2 0 35
:2 0 17d8 29d4 29d6
:3 0 17db 29d0 29d8
29cd 29da 29d9 :2 0
91 :3 0 a4 :3 0
29dc 29dd 0 93
:4 0 236 :4 0 96
:2 0 97 :3 0 17df
29e1 29e3 :3 0 96
:2 0 b9 :4 0 17e2
29e5 29e7 :3 0 96
:2 0 237 :4 0 17e5
29e9 29eb :3 0 96
:2 0 8b :3 0 b2
:3 0 29ee 29ef 0
17e8 29ed 29f1 :3 0
17eb 29de 29f3 :2 0
29f5 17ee 29f6 29db
29f5 0 29f7 17f0
0 29fd 12 :3 0
8b :3 0 b2 :3 0
29f9 29fa 0 29fb
:2 0 29fd 17f2 2a00
:3 0 2a00 1806 2a00
29ff 29fd 29fe :6 0
2a01 :2 0 2 3a
2a00 2a04 :3 0 2a03
2a01 2a05 :8 0 
186e
4
:3 0 1 3 1
9 1 f 1
15 1 1b 1
1f 1 23 1
27 1 2b 1
31 a 8 e
14 1a 1e 22
26 2a 30 36
1 3c 1 42
1 48 1 4e
1 56 1 54
1 5d 1 5b
1 64 1 62
1 6b 1 69
1 72 1 70
1 79 1 77
1 80 1 7e
1 87 1 85
1 8e 1 8c
1 95 1 93
1 9c 1 9a
1 a3 1 a1
1 aa 1 a8
1 af 1 b4
1 b9 1 be
1 c3 1 c8
1 cd 1 d2
1 d7 1 dc
1 e1 1 e6
1 eb 1 f2
1 f0 1 f9
1 f7 1 fe
1 104 1 10a
1 110 1 116
1 11b 1 120
1 126 1 12c
1 132 1 138
1 13e 1 144
1 14a 1 150
1 156 1 15e
1 15c 1 165
1 163 1 16c
1 16a 1 171
1 177 1 17d
1 183 1 189
1 18f 1 195
1 19b 1 1a1
1 1a7 1 1ad
1 1b3 1 1b9
1 1bf 1 1c5
1 1cb 1 1d1
1 1d7 1 1dd
1 1e3 1 1e9
1 1ef 1 1f5
1 1fb 1 201
1 207 1 20d
1 213 1 219
1 21f 1 227
1 225 1 22e
1 22c 1 233
1 23b 1 239
1 240 1 246
1 24c 1 252
1 258 1 25e
1 264 1 26a
1 270 1 276
1 27c 1 284
1 282 1 289
1 28e 1 293
1 2ad 1 2b3
1 2ba 1 2c7
1 2d3 2 2d6
2d8 2 2db 2dd
2 2df 2e1 2
2e3 2e5 2 2e7
2e9 2 2eb 2ed
2 2ef 2f1 2
2f3 2f5 2 2f7
2f9 2 2ff 301
2 303 305 2
307 308 2 30a
30b 2 2fb 30d
2 30f 311 2
317 319 2 31b
31d 2 31f 320
2 322 323 2
313 325 2 327
329 1 32f 2
331 332 2 32b
334 2 336 338
1 33e 2 340
341 2 33a 343
2 345 347 1
34d 2 34f 350
2 349 352 2
354 356 1 35c
2 35e 35f 2
358 361 2 363
365 2 367 369
2 36b 36d 2
36f 371 2 373
375 2 377 379
2 37b 37d 2
37f 381 2 383
385 4 2cf 2d5
2da 387 1 389
1 38b 2 395
397 3 393 394
399 2 3a2 3a4
2 3a1 3a6 1
3a8 1 3aa 2
3db 3e0 1 3e7
1 3e2 2 3fa
3fc 3 3f8 3f9
3fe 2 407 409
2 40b 40d 2
40f 411 2 413
415 2 417 419
3 41e 41f 420
2 41b 422 2
406 424 1 426
1 428 2 3f1
429 1 42d 1
3ec 2 3ea 431
1 43c 2 438
43c 2 492 497
1 49e 1 499
2 4b1 4b3 3
4af 4b0 4b5 2
4be 4c0 2 4c2
4c4 2 4c6 4c8
2 4ca 4cc 2
4ce 4d0 3 4d5
4d6 4d7 2 4d2
4d9 2 4bd 4db
1 4dd 1 4df
2 4a8 4e0 1
4e4 1 4a3 2
4a1 4e8 1 4f3
2 4ef 4f3 2
51b 520 1 527
1 522 2 53a
53c 3 538 539
53e 2 547 549
2 54b 54d 2
54f 551 2 553
555 2 557 559
3 55e 55f 560
2 55b 562 2
546 564 1 566
1 568 2 531
569 1 56d 1
52c 2 52a 571
1 57c 2 578
57c 2 58b 58d
3 589 58a 58f
2 598 59a 2
597 59c 1 59e
1 5a0 3 582
5a1 5a6 1 5a8
2 5ac 5ad 2
5af 5b2 1 5b9
2 5b5 5b9 2
5c7 5c9 3 5c5
5c6 5cb 2 5d4
5d6 2 5d3 5d8
1 5da 1 5dc
3 5be 5dd 5e2
1 5e4 3 5ef
5f0 5f1 1 5f5
2 5f3 5f5 3
5fc 5fd 5fe 1
602 2 600 602
2 613 615 3
611 612 617 2
620 622 2 61f
624 1 626 1
628 3 60a 629
62e 1 630 1
632 2 639 63a
2 63f 640 2
63c 642 2 648
649 1 64b 2
645 64b 2 65c
65e 3 65a 65b
660 2 669 66b
2 668 66d 1
66f 1 671 3
653 672 677 1
679 3 67e 67f
680 1 684 2
682 684 3 68b
68c 68d 1 691
2 68f 691 2
698 699 1 69d
2 69b 69d 3
6a3 6a4 6a5 1
6a9 2 6a7 6a9
2 6bc 6c1 1
6c8 1 6c3 2
6db 6dd 3 6d9
6da 6df 2 6e8
6ea 2 6ec 6ee
2 6f0 6f2 2
6f4 6f6 2 6f8
6fa 3 6ff 700
701 2 6fc 703
2 6e7 705 1
707 1 709 2
6d2 70a 1 70e
1 6cd 2 6cb
712 1 71d 2
719 71d 2 72a
72f 1 736 1
731 2 749 74b
3 747 748 74d
2 756 758 2
75a 75c 2 75e
760 2 762 764
2 766 768 3
76d 76e 76f 2
76a 771 2 755
773 1 775 1
777 2 740 778
1 77c 1 73b
2 739 780 1
783 1 786 3
78b 78c 78d 1
791 2 78f 791
1 796 1 798
3 715 787 799
2 7ab 7b0 1
7b7 1 7b2 2
7ca 7cc 3 7c8
7c9 7ce 2 7d7
7d9 2 7db 7dd
2 7df 7e1 2
7e3 7e5 2 7e7
7e9 3 7ee 7ef
7f0 2 7eb 7f2
2 7d6 7f4 1
7f6 1 7f8 2
7c1 7f9 1 7fd
1 7bc 2 7ba
801 1 80c 2
808 80c 2 819
81e 1 825 1
820 2 838 83a
3 836 837 83c
2 845 847 2
849 84b 2 84d
84f 2 851 853
2 855 857 3
85c 85d 85e 2
859 860 2 844
862 1 864 1
866 2 82f 867
1 86b 1 82a
2 828 86f 1
872 1 875 3
804 876 879 2
87b 87c 2 87f
880 1 886 2
882 886 1 895
2 894 895 1
89d 1 8a3 2
8a5 8a6 2 892
8a7 1 8ae 1
8a9 2 8c1 8c3
3 8bf 8c0 8c5
2 8ce 8d0 2
8d2 8d4 2 8d6
8d8 2 8da 8dc
2 8de 8e0 3
8e5 8e6 8e7 2
8e2 8e9 2 8cd
8eb 1 8ed 1
8ef 2 8b8 8f0
1 8f4 1 8b3
2 8b1 8f8 1
8fb 1 90a 2
909 90a 1 912
1 918 2 91a
91b 2 907 91c
1 923 1 91e
2 936 938 3
934 935 93a 2
943 945 2 947
949 2 94b 94d
2 94f 951 2
953 955 3 95a
95b 95c 2 957
95e 2 942 960
1 962 1 964
2 92d 965 1
969 1 928 2
926 96d 1 970
2 973 974 1
97c 2 978 97c
1 982 1 985
1 987 3 87d
975 988 2 991
992 1 998 2
994 998 2 99c
99d 1 9a3 2
99f 9a3 2 9b5
9ba 1 9c1 1
9bc 2 9d4 9d6
3 9d2 9d3 9d8
2 9e1 9e3 2
9e5 9e7 2 9e9
9eb 2 9ed 9ef
2 9f1 9f3 3
9f8 9f9 9fa 2
9f5 9fc 2 9e0
9fe 1 a00 1
a02 2 9cb a03
1 a07 1 9c6
2 9c4 a0b 1
a0e 1 a11 3
a16 a17 a18 1
a1c 2 a1a a1c
2 a2f a34 1
a3b 1 a36 2
a4e a50 3 a4c
a4d a52 2 a5b
a5d 2 a5f a61
2 a63 a65 2
a67 a69 2 a6b
a6d 3 a72 a73
a74 2 a6f a76
2 a5a a78 1
a7a 1 a7c 2
a45 a7d 1 a81
1 a40 2 a3e
a85 1 a90 2
a8c a90 2 a9d
aa2 1 aa9 1
aa4 2 abc abe
3 aba abb ac0
2 ac9 acb 2
acd acf 2 ad1
ad3 2 ad5 ad7
2 ad9 adb 3
ae0 ae1 ae2 2
add ae4 2 ac8
ae6 1 ae8 1
aea 2 ab3 aeb
1 aef 1 aae
2 aac af3 2
afa afb 2 afd
aff 2 af6 b02
1 b04 2 b07
b08 1 b0e 2
b0a b0e 2 b12
b13 1 b19 2
b15 b19 2 b20
b23 1 b25 3
a88 b05 b26 2
b29 b2a 1 b2e
2 b2c b2e 2
b41 b46 1 b4d
1 b48 2 b60
b62 3 b5e b5f
b64 2 b6d b6f
2 b71 b73 2
b75 b77 2 b79
b7b 2 b7d b7f
3 b84 b85 b86
2 b81 b88 2
b6c b8a 1 b8c
1 b8e 2 b57
b8f 1 b93 1
b52 2 b50 b97
2 b9d b9e 1
ba2 2 ba0 ba2
2 bb3 bb8 1
bbf 1 bba 2
bd2 bd4 3 bd0
bd1 bd6 2 bdf
be1 2 be3 be5
2 be7 be9 2
beb bed 2 bef
bf1 3 bf6 bf7
bf8 2 bf3 bfa
2 bde bfc 1
bfe 1 c00 2
bc9 c01 1 c05
1 bc4 2 bc2
c09 1 c0c 1
c0f 2 c12 c13
1 c17 2 c15
c17 2 c25 c27
3 c23 c24 c29
2 c32 c34 2
c31 c36 1 c38
1 c3a 3 c1c
c3b c40 1 c42
4 b33 b9a c10
c43 1 c45 2
c57 c5c 1 c63
1 c5e 2 c76
c78 3 c74 c75
c7a 2 c83 c85
2 c87 c89 2
c8b c8d 2 c8f
c91 2 c93 c95
3 c9a c9b c9c
2 c97 c9e 2
c82 ca0 1 ca2
1 ca4 2 c6d
ca5 1 ca9 1
c68 2 c66 cad
1 cb8 2 cb4
cb8 2 cc5 cca
1 cd1 1 ccc
2 ce4 ce6 3
ce2 ce3 ce8 2
cf1 cf3 2 cf5
cf7 2 cf9 cfb
2 cfd cff 2
d01 d03 3 d08
d09 d0a 2 d05
d0c 2 cf0 d0e
1 d10 1 d12
2 cdb d13 1
d17 1 cd6 2
cd4 d1b 1 d1e
1 d21 2 d24
d25 1 d29 2
d27 d29 2 d2d
d2e 1 d34 2
d30 d34 2 d38
d39 1 d3f 2
d3b d3f 2 d49
d4c 1 d4e 4
c46 cb0 d22 d4f
2 d51 d52 2
d55 d56 1 d5a
2 d58 d5a 1
d5f 2 d5d d5f
2 d66 d67 1
d6d 2 d69 d6d
2 d71 d72 1
d78 2 d74 d78
4 d82 d83 d84
d85 1 d88 1
d8a 2 db3 db8
1 dbf 1 dba
2 dd2 dd4 3
dd0 dd1 dd6 2
ddf de1 2 de3
de5 2 de7 de9
2 deb ded 2
def df1 3 df6
df7 df8 2 df3
dfa 2 dde dfc
1 dfe 1 e00
2 dc9 e01 1
e05 1 dc4 2
dc2 e09 2 e0f
e10 1 e14 2
e12 e14 2 e22
e24 3 e20 e21
e26 2 e2f e31
2 e2e e33 1
e35 1 e37 3
e19 e38 e3d 1
e3f 2 e4e e4f
c e43 e44 e45
e46 e47 e48 e49
e4a e4b e4c e51
e52 2 e57 e58
1 e5c 2 e5a
e5c 1 e61 1
e64 2 e71 e73
3 e6f e70 e75
2 e7e e80 2
e7d e82 1 e84
1 e86 2 e8a
e8b 3 e68 e87
e8e 2 e90 e91
a 98c 98f a12
d53 d8b d8e e0c
e40 e55 e92 2
e94 e95 1 e96
2 e9a e9b 2
ea0 ea1 1 ea3
2 e9d ea3 2
ea8 ea9 1 ead
2 eab ead 2
eb7 eb8 2 ebd
ebe 1 ec0 2
eba ec0 2 ece
ed0 3 ecc ecd
ed2 2 edb edd
2 eda edf 1
ee1 1 ee3 3
ec5 ee4 ee9 2
eed eee 2 ef3
ef4 1 ef6 2
ef0 ef6 1 efb
2 efe efd 2
f1b f20 1 f27
1 f22 2 f3a
f3c 3 f38 f39
f3e 2 f47 f49
2 f4b f4d 2
f4f f51 2 f53
f55 2 f57 f59
3 f5e f5f f60
2 f5b f62 2
f46 f64 1 f66
1 f68 2 f31
f69 1 f6d 1
f2c 2 f2a f71
2 f77 f78 1
f7c 2 f7a f7c
2 f8a f8c 3
f88 f89 f8e 2
f97 f99 2 f96
f9b 1 f9d 1
f9f 3 f81 fa0
fa5 1 fa7 2
fc8 fcd 1 fd4
1 fcf 2 fe7
fe9 3 fe5 fe6
feb 2 ff4 ff6
2 ff8 ffa 2
ffc ffe 2 1000
1002 2 1004 1006
3 100b 100c 100d
2 1008 100f 2
ff3 1011 1 1013
1 1015 2 fde
1016 1 101a 1
fd9 2 fd7 101e
2 1024 1025 1
1029 2 1027 1029
2 1037 1039 3
1035 1036 103b 2
1044 1046 2 1043
1048 1 104a 1
104c 3 102e 104d
1052 1 1054 2
1058 1059 2 1064
1065 2 1069 106a
2 106e 106f 7
105f 1060 1061 1062
1067 106c 1071 a
eb5 eff f02 f74
fa8 fab 1021 1055
105c 1074 2 1077
1076 2 107a 107b
1 107f 2 107d
107f 1 1084 1
1087 1 1089 2
1096 1098 3 1094
1095 109a 2 10a3
10a5 2 10a2 10a7
1 10a9 1 10ab
2 10af 10b0 c
574 5a9 5e5 5e8
5eb 631 67a 1078
108a 108d 10ac 10b3
1 10b6 1 10bb
3 10cb 10cc 10cd
1 10d1 2 10cf
10d1 3 10d8 10d9
10da 1 10de 2
10dc 10de 2 10ef
10f1 3 10ed 10ee
10f3 2 10fc 10fe
2 10fb 1100 1
1102 1 1104 3
10e6 1105 110a 1
110c 1 110e 2
111c 1121 1 1128
1 1123 2 113b
113d 3 1139 113a
113f 2 1148 114a
2 114c 114e 2
1150 1152 2 1154
1156 2 1158 115a
3 115f 1160 1161
2 115c 1163 2
1147 1165 1 1167
1 1169 2 1132
116a 1 116e 1
112d 2 112b 1172
1 117d 2 1179
117d 2 118c 118e
3 118a 118b 1190
2 1199 119b 2
1198 119d 1 119f
1 11a1 3 1183
11a2 11a7 1 11a9
3 11ae 11af 11b0
1 11b4 2 11b2
11b4 3 11bb 11bc
11bd 1 11c1 2
11bf 11c1 2 11d2
11d4 3 11d0 11d1
11d6 2 11df 11e1
2 11de 11e3 1
11e5 1 11e7 3
11c9 11e8 11ed 3
11f3 11f4 11f5 1
11f9 2 11f7 11f9
3 1200 1201 1202
1 1206 2 1204
1206 2 1217 1219
3 1215 1216 121b
2 1224 1226 2
1223 1228 1 122a
1 122c 3 120e
122d 1232 2 1235
1234 3 1175 11aa
1236 1 1238 2
124b 1250 1 1257
1 1252 2 126a
126c 3 1268 1269
126e 2 1277 1279
2 127b 127d 2
127f 1281 2 1283
1285 2 1287 1289
3 128e 128f 1290
2 128b 1292 2
1276 1294 1 1296
1 1298 2 1261
1299 1 129d 1
125c 2 125a 12a1
2 12a8 12a9 2
12ab 12ae 1 12b5
2 12b1 12b5 2
12c3 12c5 3 12c1
12c2 12c7 2 12d0
12d2 2 12cf 12d4
1 12d6 1 12d8
3 12ba 12d9 12de
1 12e0 3 12e3
12e4 12e5 1 12e9
2 12e7 12e9 1
12ee 1 12f2 2
12f4 12f5 3 1300
1301 1302 1 1306
2 1304 1306 3
130d 130e 130f 1
1313 2 1311 1313
2 131a 131b 2
1320 1321 1 1323
2 131d 1323 3
132c 132d 132e 1
1332 2 1330 1332
2 1336 1337 1
133b 2 1339 133b
3 1341 1342 1343
1 1347 2 1345
1347 2 1357 1359
3 1355 1356 135b
2 1364 1366 2
1363 1368 1 136a
1 136c 3 134e
136d 1372 1 1374
2 1377 1378 1
137e 2 137a 137e
2 1382 1383 1
1389 2 1385 1389
2 139e 13a3 1
13aa 1 13a5 2
13bd 13bf 3 13bb
13bc 13c1 2 13ca
13cc 2 13ce 13d0
2 13d2 13d4 2
13d6 13d8 2 13da
13dc 3 13e1 13e2
13e3 2 13de 13e5
2 13c9 13e7 1
13e9 1 13eb 2
13b4 13ec 1 13f0
1 13af 2 13ad
13f4 3 13fc 13fd
13fe 1 1402 2
1400 1402 3 1409
140a 140b 1 140f
2 140d 140f 4
141a 141b 141c 141d
2 1417 1420 1
1422 2 143a 143b
2 143f 1440 15
1426 1427 1428 1429
142a 142b 142c 142d
142e 142f 1430 1431
1432 1433 1434 1435
1436 1437 1438 143d
1442 1 1448 2
1457 1459 3 1455
1456 145b 2 1464
1466 2 1463 1468
1 146a 1 146c
2 1470 1471 8
1390 13f7 1423 1445
144b 144e 146d 1474
3 1478 147b 147e
2 1480 1481 2
1375 1482 3 1488
1489 148a 1 148e
2 148c 148e 2
149b 14a0 1 14a7
1 14a2 2 14ba
14bc 3 14b8 14b9
14be 2 14c7 14c9
2 14cb 14cd 2
14cf 14d1 2 14d3
14d5 2 14d7 14d9
3 14de 14df 14e0
2 14db 14e2 2
14c6 14e4 1 14e6
1 14e8 2 14b1
14e9 1 14ed 1
14ac 2 14aa 14f1
2 14fa 14fb 1
1501 a 1507 1508
1509 150a 150b 150c
150d 150e 150f 1510
2 1515 1516 1
151a 2 1518 151a
1 151e 8 1528
1529 152a 152b 152c
152d 152e 152f 1
1532 1 1534 3
1537 1538 1539 1
153d 2 153b 153d
1 1542 1 1546
2 1548 1549 2
154d 154e 2 1553
1554 2 1550 1556
2 156a 156b 11
155c 155d 155e 155f
1560 1561 1562 1563
1564 1565 1566 1567
1568 156d 156e 156f
1570 2 1575 1576
1 157a 2 1578
157a 3 1580 1581
1582 1 1586 2
1584 1586 1 159a
2 1599 159a 1
15a2 1 15a8 2
15aa 15ab 2 1597
15ac 1 15b3 1
15ae 2 15c6 15c8
3 15c4 15c5 15ca
2 15d3 15d5 2
15d7 15d9 2 15db
15dd 2 15df 15e1
2 15e3 15e5 3
15ea 15eb 15ec 2
15e7 15ee 2 15d2
15f0 1 15f2 1
15f4 2 15bd 15f5
1 15f9 1 15b8
2 15b6 15fd 1
1600 2 1605 1606
1 160a 2 1608
160a 3 1610 1611
1612 1 1616 2
1614 1616 1 1628
2 1627 1628 1
1630 1 1636 2
1638 1639 2 1625
163a 1 1641 1
163c 2 1654 1656
3 1652 1653 1658
2 1661 1663 2
1665 1667 2 1669
166b 2 166d 166f
2 1671 1673 3
1678 1679 167a 2
1675 167c 2 1660
167e 1 1680 1
1682 2 164b 1683
1 1687 1 1646
2 1644 168b 1
168e 2 1692 1691
1 1693 1 1695
2 16aa 16af 1
16b6 1 16b1 2
16c9 16cb 3 16c7
16c8 16cd 2 16d6
16d8 2 16da 16dc
2 16de 16e0 2
16e2 16e4 2 16e6
16e8 3 16ed 16ee
16ef 2 16ea 16f1
2 16d5 16f3 1
16f5 1 16f7 2
16c0 16f8 1 16fc
1 16bb 2 16b9
1700 a 170a 170b
170c 170d 170e 170f
1710 1711 1712 1713
1 1719 2 172d
172f 3 172b 172c
1731 2 173a 173c
2 1739 173e 1
1740 1 1742 11
14f4 14fe 1504 1513
1535 154a 1559 1573
1696 1703 1707 1716
171c 1721 1724 1743
1748 2 174d 174e
2 1753 1754 1
1756 2 1750 1756
2 175b 175c 2
1761 1762 2 175e
1764 2 1769 176a
1 1770 2 176c
1770 2 1774 1775
1 177b 2 1777
177b 3 1781 1782
1783 1 1787 2
1785 1787 1 178d
1 1791 2 1793
1794 4 1798 1799
179a 179b 1 17b2
1 17b8 2 17ba
17bb 2 17bf 17c5
1 17cc 1 17c7
2 17df 17e1 3
17dd 17de 17e3 2
17ec 17ee 2 17f0
17f2 2 17f4 17f6
2 17f8 17fa 2
17fc 17fe 3 1803
1804 1805 2 1800
1807 2 17eb 1809
1 180b 1 180d
2 17d6 180e 1
1812 1 17d1 2
17cf 1816 1 181b
2 1828 182a 3
1826 1827 182c 2
1835 1837 2 1834
1839 1 183b 1
183d 2 183e 1843
1 1845 2 185d
185e 2 1862 1863
15 1849 184a 184b
184c 184d 184e 184f
1850 1851 1852 1853
1854 1855 1856 1857
1858 1859 185a 185b
1860 1865 1 186b
2 187a 187c 3
1878 1879 187e 2
1887 1889 2 1886
188b 1 188d 1
188f 2 1893 1894
d 1795 179e 17a1
17a4 17a9 17bc 1819
1846 1868 186e 1871
1890 1897 1 189b
2 189d 189e 2
1767 189f 2 18a4
18a5 1 18a9 2
18a7 18a9 2 18b7
18bc 1 18c3 1
18be 2 18d6 18d8
3 18d4 18d5 18da
2 18e3 18e5 2
18e7 18e9 2 18eb
18ed 2 18ef 18f1
2 18f3 18f5 3
18fa 18fb 18fc 2
18f7 18fe 2 18e2
1900 1 1902 1
1904 2 18cd 1905
1 1909 1 18c8
2 18c6 190d 3
18ae 18b1 1910 2
1916 1917 2 191c
191d 1 191f 2
1919 191f 2 1924
1925 2 192a 192b
2 1927 192d 2
1938 1939 1 193d
2 193b 193d 2
1941 1943 2 1945
1947 2 1949 194b
2 194d 194f 2
1951 1953 2 1955
1957 2 195d 195e
1 1960 2 1959
1962 2 1965 196a
2 196d 196f 2
1971 1973 2 1975
1977 2 1979 197b
2 197d 197f 2
1981 1983 2 1989
198a 1 198c 2
1985 198e 2 1991
1996 2 1998 1999
2 199d 199e 1
19a2 2 19a0 19a2
1 19b0 1 19b6
2 19b8 19b9 2
19a7 19ba 1 19c7
1 19cd 2 19cf
19d0 2 19be 19d1
2 19d3 19d4 1
19dc 2 19d8 19dc
1 19e1 1 19e3
2 19d5 19e4 2
19e9 19ea 1 19ee
2 19ec 19ee 2
19f3 19f9 1 1a00
1 19fb 2 1a13
1a15 3 1a11 1a12
1a17 2 1a20 1a22
2 1a24 1a26 2
1a28 1a2a 2 1a2c
1a2e 2 1a30 1a32
3 1a37 1a38 1a39
2 1a34 1a3b 2
1a1f 1a3d 1 1a3f
1 1a41 2 1a0a
1a42 1 1a46 1
1a05 2 1a03 1a4a
1 1a4d 2 1a52
1a58 1 1a5f 1
1a5a 2 1a72 1a74
3 1a70 1a71 1a76
2 1a7f 1a81 2
1a83 1a85 2 1a87
1a89 2 1a8b 1a8d
2 1a8f 1a91 3
1a96 1a97 1a98 2
1a93 1a9a 2 1a7e
1a9c 1 1a9e 1
1aa0 2 1a69 1aa1
1 1aa5 1 1a64
2 1a62 1aa9 1
1aac 2 1aaf 1ab0
1 1ab2 2 1ab8
1ab9 1 1abd 2
1abb 1abd 2 1acb
1acd 3 1ac9 1aca
1acf 2 1ad8 1ada
2 1ad7 1adc 1
1ade 1 1ae0 3
1ac2 1ae1 1ae6 2
1af3 1af5 3 1af1
1af2 1af7 2 1b00
1b02 2 1aff 1b04
1 1b06 1 1b08
3 1aea 1b09 1b0e
2 1b10 1b11 1
1b12 1 1b14 2
1b20 1b25 1 1b2c
1 1b27 2 1b3f
1b41 3 1b3d 1b3e
1b43 2 1b4c 1b4e
2 1b50 1b52 2
1b54 1b56 2 1b58
1b5a 2 1b5c 1b5e
3 1b63 1b64 1b65
2 1b60 1b67 2
1b4b 1b69 1 1b6b
1 1b6d 2 1b36
1b6e 1 1b72 1
1b31 2 1b2f 1b76
a 1930 1933 1936
199a 19e7 1ab1 1b15
1b79 1b7d 1b80 5
1b83 174b 18a2 1914
1b82 1 1b84 2
1b88 1b89 2 1b8e
1b8f 1 1b91 2
1b8b 1b91 2 1b95
1b96 1 1b9a 2
1b98 1b9a 2 1b9e
1b9f 2 1ba4 1ba5
1 1ba7 2 1ba1
1ba7 2 1bb7 1bb9
3 1bb5 1bb6 1bbb
2 1bc4 1bc6 2
1bc3 1bc8 1 1bca
1 1bcc 3 1bae
1bcd 1bd2 1 1bd4
2 1bd7 1bd8 2
1bdd 1bde 1 1be0
2 1bda 1be0 2
1bee 1bf0 3 1bec
1bed 1bf2 2 1bfb
1bfd 2 1bfa 1bff
1 1c01 1 1c03
3 1be5 1c04 1c09
1 1c0b 2 1c0e
1c0f 1 1c13 2
1c11 1c13 1 1c18
2 1c1b 1c1c 1
1c20 2 1c1e 1c20
2 1c25 1c26 1
1c2a 2 1c28 1c2a
2 1c3b 1c3d 3
1c39 1c3a 1c3f 2
1c48 1c4a 2 1c47
1c4c 1 1c4e 1
1c50 3 1c32 1c51
1c56 1 1c58 2
1c5c 1c5d 2 1c59
1c60 2 1c62 1c63
2 1c68 1c69 2
1c6e 1c6f 2 1c6b
1c71 2 1c74 1c76
2 1c79 1c7b 1
1c7d 2 1c82 1c83
2 1c88 1c89 1
1c8b 2 1c85 1c8b
2 1c98 1c9d 1
1ca4 1 1c9f 2
1cb7 1cb9 3 1cb5
1cb6 1cbb 2 1cc4
1cc6 2 1cc8 1cca
2 1ccc 1cce 2
1cd0 1cd2 2 1cd4
1cd6 3 1cdb 1cdc
1cdd 2 1cd8 1cdf
2 1cc3 1ce1 1
1ce3 1 1ce5 2
1cae 1ce6 1 1cea
1 1ca9 2 1ca7
1cee 2 1cf4 1cf5
1 1cf9 2 1cf7
1cf9 2 1d07 1d09
3 1d05 1d06 1d0b
2 1d14 1d16 2
1d13 1d18 1 1d1a
1 1d1c 3 1cfe
1d1d 1d20 1 1d22
3 1c90 1cf1 1d23
1 1d25 2 1d28
1d29 1 1d2f 2
1d2b 1d2f 2 1d33
1d34 1 1d3a 2
1d36 1d3a 1 1d41
a 1d47 1d48 1d49
1d4a 1d4b 1d4c 1d4d
1d4e 1d4f 1d50 2
1d55 1d56 1 1d5a
2 1d58 1d5a 1
1d5e 2 1d70 1d75
1 1d7c 1 1d77
2 1d8f 1d91 3
1d8d 1d8e 1d93 2
1d9c 1d9e 2 1da0
1da2 2 1da4 1da6
2 1da8 1daa 2
1dac 1dae 3 1db3
1db4 1db5 2 1db0
1db7 2 1d9b 1db9
1 1dbb 1 1dbd
2 1d86 1dbe 1
1dc2 1 1d81 2
1d7f 1dc6 1 1dc9
1 1dcc 2 1dd1
1dd2 2 1dd7 1dd8
2 1dd4 1dda 2
1ddd 1ddf 2 1de2
1de4 1 1de6 8
1dec 1ded 1dee 1def
1df0 1df1 1df2 1df3
2 1dfc 1dfd 2
1dff 1e02 5 1e08
1e09 1e0a 1e0b 1e0c
2 1e23 1e28 1
1e2f 1 1e2a 2
1e42 1e44 3 1e40
1e41 1e46 2 1e4f
1e51 2 1e53 1e55
2 1e57 1e59 2
1e5b 1e5d 2 1e5f
1e61 3 1e66 1e67
1e68 2 1e63 1e6a
2 1e4e 1e6c 1
1e6e 1 1e70 2
1e39 1e71 1 1e75
1 1e34 2 1e32
1e79 a 1e83 1e84
1e85 1e86 1e87 1e88
1e89 1e8a 1e8b 1e8c
1 1e92 2 1ea1
1ea3 3 1e9f 1ea0
1ea5 2 1eae 1eb0
2 1ead 1eb2 1
1eb4 1 1eb6 2
1eba 1ebb e 1d44
1d53 1dcd 1de9 1df6
1e05 1e0f 1e7c 1e80
1e8f 1e95 1e98 1eb7
1ebe 2 1ec7 1ec8
1 1ecc 2 1eca
1ecc 1 1ed1 1
1ed3 2 1ede 1ee1
2 1ee3 1ee6 1
1efc 2 1efb 1efc
1 1f04 1 1f0a
2 1f0c 1f0d 2
1ef9 1f0e 1 1f15
1 1f10 2 1f28
1f2a 3 1f26 1f27
1f2c 2 1f35 1f37
2 1f39 1f3b 2
1f3d 1f3f 2 1f41
1f43 2 1f45 1f47
3 1f4c 1f4d 1f4e
2 1f49 1f50 2
1f34 1f52 1 1f54
1 1f56 2 1f1f
1f57 1 1f5b 1
1f1a 2 1f18 1f5f
2 1f65 1f66 1
1f6a 2 1f68 1f6a
1 1f6f 1 1f71
6 1ec2 1ec5 1ed4
1ee9 1f62 1f72 2
1f74 1f75 6 1bd5
1c0c 1c64 1c80 1d26
1f76 2 1f79 1f78
1 1f7d 2 1f7b
1f7d 1 1f82 a
1f88 1f89 1f8a 1f8b
1f8c 1f8d 1f8e 1f8f
1f90 1f91 2 1f96
1f97 1 1f9b 2
1f99 1f9b 1 1f9f
8 1fa9 1faa 1fab
1fac 1fad 1fae 1faf
1fb0 1 1fb3 1
1fb5 1 1fb7 3
1fbe 1fbf 1fc0 1
1fc3 3 1fc6 1fc7
1fc8 1 1fcc 2
1fca 1fcc 3 1fd1
1fd2 1fd3 1 1fd6
3 1fda 1fdb 1fdc
1 1fdf 2 1fe1
1fe2 1 1fe3 2
1fe5 1fe6 1 1fe8
2 1fee 1fef 1
1ff3 2 1ff1 1ff3
2 1ffb 1ffc 2
1ffe 2001 2 2010
2015 1 201c 1
2017 2 202f 2031
3 202d 202e 2033
2 203c 203e 2
2040 2042 2 2044
2046 2 2048 204a
2 204c 204e 3
2053 2054 2055 2
2050 2057 2 203b
2059 1 205b 1
205d 2 2026 205e
1 2062 1 2021
2 201f 2066 2
2005 2069 2 2076
207b 1 2082 1
207d 2 2095 2097
3 2093 2094 2099
2 20a2 20a4 2
20a6 20a8 2 20aa
20ac 2 20ae 20b0
2 20b2 20b4 3
20b9 20ba 20bb 2
20b6 20bd 2 20a1
20bf 1 20c1 1
20c3 2 208c 20c4
1 20c8 1 2087
2 2085 20cc 1
20cf 2 20d2 20d3
2 20d7 20d8 2
20dd 20de 2 20da
20e0 2 20d4 20e3
1 20e5 2 20f3
20f4 2 20f8 20f9
8 20ec 20ed 20ee
20ef 20f0 20f1 20f6
20fb 2 2100 2101
1 2105 2 2103
2105 2 2113 2115
3 2111 2112 2117
2 2120 2122 2
211f 2124 1 2126
1 2128 3 210a
2129 212e 1 2133
2 2131 2133 1
2154 2 2153 2154
1 215c 1 2162
2 2164 2165 2
2151 2166 1 216d
1 2168 2 2180
2182 3 217e 217f
2184 2 218d 218f
2 2191 2193 2
2195 2197 2 2199
219b 2 219d 219f
3 21a4 21a5 21a6
2 21a1 21a8 2
218c 21aa 1 21ac
1 21ae 2 2177
21af 1 21b3 1
2172 2 2170 21b7
2 213a 21ba 2
21be 21bd 1 21c2
2 21d1 21d3 3
21cf 21d0 21d5 2
21de 21e0 2 21dd
21e2 1 21e4 1
21e6 2 21ea 21eb
c 1f85 1f94 1fb6
1fe7 20e6 20e9 20fe
21bf 21c5 21c8 21e7
21ee 1 21f0 2
21f3 21f4 2 21f9
21fa 1 21fc 2
21f6 21fc 2 220e
2213 1 221a 1
2215 2 222d 222f
3 222b 222c 2231
2 223a 223c 2
223e 2240 2 2242
2244 2 2246 2248
2 224a 224c 3
2251 2252 2253 2
224e 2255 2 2239
2257 1 2259 1
225b 2 2224 225c
1 2260 1 221f
2 221d 2264 2
226a 226b 1 226f
2 226d 226f 2
227d 227f 3 227b
227c 2281 2 228a
228c 2 2289 228e
1 2290 1 2292
3 2274 2293 2298
1 229a 2 229e
229f 2 22a5 22a6
2 22ab 22ac 2
22b1 22b2 1 22b4
2 22ae 22b4 2
22b8 22b9 1 22bf
2 22bb 22bf 2
22c3 22c4 1 22ca
2 22c6 22ca 2
22de 22e3 1 22ea
1 22e5 2 22fd
22ff 3 22fb 22fc
2301 2 230a 230c
2 230e 2310 2
2312 2314 2 2316
2318 2 231a 231c
3 2321 2322 2323
2 231e 2325 2
2309 2327 1 2329
1 232b 2 22f4
232c 1 2330 1
22ef 2 22ed 2334
1 2339 1 2340
1 2342 2 2345
2346 1 234a 2
2348 234a 1 234f
a 2355 2356 2357
2358 2359 235a 235b
235c 235d 235e 2
2363 2364 1 2368
2 2366 2368 1
236c 2 2380 2385
1 238c 1 2387
2 239f 23a1 3
239d 239e 23a3 2
23ac 23ae 2 23b0
23b2 2 23b4 23b6
2 23b8 23ba 2
23bc 23be 3 23c3
23c4 23c5 2 23c0
23c7 2 23ab 23c9
1 23cb 1 23cd
2 2396 23ce 1
23d2 1 2391 2
238f 23d6 2 23dd
23de 2 23e3 23e4
2 23e0 23e6 2
23eb 23ec 2 23e8
23ee 2 23d9 23f1
2 23f5 23f6 2
23fb 23fc 2 23f8
23fe 1 2401 2
2403 2404 1 240d
2 240f 2410 1
2416 2 2418 2419
2 2412 241b 2
241e 2420 1 2422
2 2428 2429 2
242e 242f 2 242b
2431 2 2436 2437
2 243c 243d 1
243f 2 2439 243f
2 2444 2445 2
244a 244b 2 2447
244d 2 2452 2453
2 244f 2455 1
2458 2 245c 245d
1 2460 2 2462
2463 8 2467 2468
2469 246a 246b 246c
246d 246e 1 2476
2 2478 2479 1
247f 2 2481 2482
2 247b 2484 2
2487 2489 1 248b
2 2494 2495 2
2497 249a 2 24a4
24a5 2 24a9 24aa
5 24a0 24a1 24a2
24a7 24ac a 24b5
24b6 24b7 24b8 24b9
24ba 24bb 24bc 24bd
24be d 2352 2361
2405 2408 2425 2434
2464 2471 248e 249d
24af 24b2 24c1 1
24c3 4 22d1 2337
2343 24c4 2 24cb
24cc 2 24ea 24eb
2 24ef 24f0 19
24d2 24d3 24d4 24d5
24d6 24d7 24d8 24d9
24da 24db 24dc 24dd
24de 24df 24e0 24e1
24e2 24e3 24e4 24e5
24e6 24e7 24e8 24ed
24f2 2 24f8 24f9
2 24ff 2500 2
2505 2506 2 2502
2508 2 2511 2516
1 251d 1 2518
2 2530 2532 3
252e 252f 2534 2
253d 253f 2 2541
2543 2 2545 2547
2 2549 254b 2
254d 254f 3 2554
2555 2556 2 2551
2558 2 253c 255a
1 255c 1 255e
2 2527 255f 1
2563 1 2522 2
2520 2567 2 2575
257a 1 2581 1
257c 2 2594 2596
3 2592 2593 2598
2 25a1 25a3 2
25a5 25a7 2 25a9
25ab 2 25ad 25af
2 25b1 25b3 3
25b8 25b9 25ba 2
25b5 25bc 2 25a0
25be 1 25c0 1
25c2 2 258b 25c3
1 25c7 1 2586
2 2584 25cb 1
25e6 2 25e5 25e6
1 25ee 1 25f4
2 25f6 25f7 2
25e3 25f8 1 25ff
1 25fa 2 2612
2614 3 2610 2611
2616 2 261f 2621
2 2623 2625 2
2627 2629 2 262b
262d 2 262f 2631
3 2636 2637 2638
2 2633 263a 2
261e 263c 1 263e
1 2640 2 2609
2641 1 2645 1
2604 2 2602 2649
1 2654 2 2650
2654 2 2665 2666
8 265d 265e 265f
2660 2661 2662 2663
2668 2 266d 266e
1 2672 2 2670
2672 2 2680 2682
3 267e 267f 2684
2 268d 268f 2
268c 2691 1 2693
1 2695 2 2699
269a 3 2677 2696
269d 1 269f 3
265a 266b 26a0 1
26a2 9 24c8 24cf
24f5 24fc 250b 256a
25ce 264c 26a3 2
26a5 26a6 2 26aa
26ab 3 26a7 26ae
26b1 1 26b7 2
26b9 26ba 1 26c0
2 26c2 26c3 2
26bc 26c5 2 26c8
26ca 2 26cd 26cf
1 26d1 1 26d4
2 26d6 26d7 2
26f3 26f4 2 26f8
26f9 19 26db 26dc
26dd 26de 26df 26e0
26e1 26e2 26e3 26e4
26e5 26e6 26e7 26e8
26e9 26ea 26eb 26ec
26ed 26ee 26ef 26f0
26f1 26f6 26fb 2
270a 270c 3 2708
2709 270e 2 2717
2719 2 2716 271b
1 271d 1 271f
2 2723 2724 a
2201 2267 229b 22a2
22a9 26d8 26fe 2701
2720 2727 2 272b
272c 2 2731 2732
1 2734 2 272e
2734 2 2738 2739
1 273d 2 273b
273d 2 2742 2743
1 2747 2 2745
2747 2 2758 275a
3 2756 2757 275c
2 2765 2767 2
2764 2769 1 276b
1 276d 3 274f
276e 2773 1 2775
1 2785 2 2784
2785 1 278d 1
2793 2 2795 2796
2 2782 2797 1
279e 1 2799 2
27b1 27b3 3 27af
27b0 27b5 2 27be
27c0 2 27c2 27c4
2 27c6 27c8 2
27ca 27cc 2 27ce
27d0 3 27d5 27d6
27d7 2 27d2 27d9
2 27bd 27db 1
27dd 1 27df 2
27a8 27e0 1 27e4
1 27a3 2 27a1
27e8 1 27fb 2
27fa 27fb 1 2803
1 2809 2 280b
280c 2 27f8 280d
1 2814 1 280f
2 2827 2829 3
2825 2826 282b 2
2834 2836 2 2838
283a 2 283c 283e
2 2840 2842 2
2844 2846 3 284b
284c 284d 2 2848
284f 2 2833 2851
1 2853 1 2855
2 281e 2856 1
285a 1 2819 2
2817 285e 3 2776
27eb 2861 2 2865
2864 1 2869 2
2878 287a 3 2876
2877 287c 2 2885
2887 2 2884 2889
1 288b 1 288d
2 2891 2892 10
10c4 10c7 110d 1239
12a4 12e1 12f6 12f9
12fc 1f7a 21f1 2866
286c 286f 288e 2895
2 28b8 28bd 1
28c4 1 28bf 2
28d7 28d9 3 28d5
28d6 28db 2 28e4
28e6 2 28e8 28ea
2 28ec 28ee 2
28f0 28f2 2 28f4
28f6 3 28fb 28fc
28fd 2 28f8 28ff
2 28e3 2901 1
2903 1 2905 2
28ce 2906 1 290a
1 28c9 2 28c7
290e 1 2919 2
2915 2919 1 291c
2 292b 292d 3
2929 292a 292f 2
2938 293a 2 2937
293c 1 293e 1
2940 3 2922 2941
2946 1 2948 2
294d 294e 1 2952
2 2950 2952 2
2965 2967 3 2963
2964 2969 2 2972
2974 2 2971 2976
1 2978 1 297a
4 2959 295c 297b
2980 1 2982 3
2911 2949 2983 3
2985 2897 2986 2
4eb 2987 1 2989
4 299d 299e 299f
29a0 2 29af 29b1
3 29ad 29ae 29b3
2 29bc 29be 2
29bb 29c0 1 29c2
1 29c4 2 29d3
29d5 3 29d1 29d2
29d7 2 29e0 29e2
2 29e4 29e6 2
29e8 29ea 2 29ec
29f0 2 29df 29f2
1 29f4 1 29f6
13 38c 3ab 3ae
3b1 3b4 3b7 3ba
434 298a 298d 2990
2993 2998 29a3 29a6
29c5 29ca 29f7 29fc
67 40 46 4c
52 59 60 67
6e 75 7c 83
8a 91 98 9f
a6 ad b2 b7
bc c1 c6 cb
d0 d5 da df
e4 e9 ee f5
fc 102 108 10e
114 119 11e 124
12a 130 136 13c
142 148 14e 154
15a 161 168 16f
175 17b 181 187
18d 193 199 19f
1a5 1ab 1b1 1b7
1bd 1c3 1c9 1cf
1d5 1db 1e1 1e7
1ed 1f3 1f9 1ff
205 20b 211 217
21d 223 22a 231
237 23e 244 24a
250 256 25c 262
268 26e 274 27a
280 287 28c 291
296 2ae 2b8 2bf

1
4
0 
2a04
0
1
a0
61
72
0 1 1 3 1 5 1 7
1 9 1 b 1 d 1 f
1 11 1 13 1 15 1 17
1 19 1 1b 1 1d 1 1f
1 21 1 23 1 25 1 27
1 29 1 2b 1 2d 1 2f
1 31 1 33 1 35 1 37
1 39 1 1 3c 1 3e 1
40 1 42 1 44 1 46 1
48 1 4a 1 4c 1 4e 1
50 1 52 1 54 1 56 1
58 1 5a 1 5c 1 5e 1
60 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

1e9 1 0
69 1 0
233 1 0
12c 1 0
27c 1 0
c3 1 0
20d 1 0
17d 1 0
24c 1 0
9 1 0
13e 1 0
3c 1 0
1d7 1 0
2 0 1
293 1 0
b9 1 0
15 1 0
23 1 0
1fb 1 0
110 1 0
239 1 0
195 1 0
1ef 1 0
1a1 1 0
f7 1 0
1f 1 0
207 1 0
be 1 0
258 1 0
2b3 1 0
f 1 0
22c 1 0
14a 1 0
282 1 0
25e 1 0
62 1 0
201 1 0
144 1 0
116 1 0
246 1 0
1a7 1 0
183 1 0
1c5 1 0
1e3 1 0
11b 1 0
171 1 0
d7 1 0
c8 1 0
289 1 0
21f 1 0
8c 1 0
219 1 0
189 1 0
cd 1 0
138 1 0
b4 1 0
26a 1 0
156 1 0
104 1 0
7e 1 0
54 1 0
1d1 1 0
1ad 1 0
9a 1 0
28e 1 0
2ba 1 0
1f5 1 0
e6 1 0
dc 1 0
48 1 0
240 1 0
126 1 0
276 1 0
fe 1 0
5b 1 0
10a 1 0
1b 1 0
132 1 0
15c 1 0
31 1 0
d2 1 0
af 1 0
18f 1 0
1dd 1 0
4e 1 0
19b 1 0
213 1 0
1bf 1 0
f0 1 0
a8 1 0
27 1 0
42 1 0
eb 1 0
264 1 0
1b3 1 0
150 1 0
163 1 0
a1 1 0
1b9 1 0
93 1 0
85 1 0
120 1 0
252 1 0
e1 1 0
2b 1 0
77 1 0
1cb 1 0
16a 1 0
225 1 0
70 1 0
177 1 0
299 1 2
270 1 0
3 1 0
0

/
SHOW ERRORS FUNCTION FC_U_PARTICIPANT;
ALTER FUNCTION FC_U_PARTICIPANT COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_PARTICIPANT ==
CREATE OR REPLACE FUNCTION SP_U_PARTICIPANT wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
58
2 :e:
1FUNCTION:
1SP_U_PARTICIPANT:
1ASSIGN_ID:
1VARCHAR2:
1SECURITY_ID001:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1P_DELAY:
1PLS_INTEGER:
1P_UNITS:
1P_WORK_PERCENT:
1P_ACTUAL:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_P_ASSIGN_ID:
132:
1H_P_SECURITY_ID:
1H_P_PLANNED_START:
1H_P_PLANNED_FINISH:
1H_P_DELAY:
10:
1H_P_UNITS:
1H_P_WORK_PERCENT:
1H_P_ACTUAL:
1H_P_RES_ID:
1H_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_PARTICIPANT(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
11:
140:
1+:
1FPUT:
1               ENTER:: SP_U_PARTICIPANT(41) :: cplan.sql(18616) :: :
1SC_STATE:
1FC_U_PARTICIPANT:
14:
160:
1       RETURN_STATUS:: SP_U_PARTICIPANT(61) :: cplan.sql(18636) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
167:
1           EXCEPTION:: SP_U_PARTICIPANT(68) :: cplan.sql(18643) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
179:
1           EXCEPTION:: SP_U_PARTICIPANT(80) :: cplan.sql(18655) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
26f
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 6e a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :2 a0
6e 7e a0 b4 2e 7e 6e b4
2e 6e a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 6b :b a0 a5 b
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 a0 6b
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e a5 57 b7 19 3c :9 a0 12a
e9 dd :2 a0 65 b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c :7 a0 12a e9 dd
:2 a0 65 b7 a4 b1 11 4f b7
a6 9 a4 b1 11 68 4f 1d
17 b5 
26f
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 a2
c8 cc d0 d4 d7 db f8 e3
e7 ea eb f3 e2 115 103 df
107 108 110 102 131 120 124 12c
ff 149 138 13c 144 11f 165 154
158 11c 160 153 181 170 174 150
17c 16f 19d 18c 190 16c 198 18b
1b9 1a8 1ac 188 1b4 1a7 1d6 1c4
1a4 1c8 1c9 1d1 1c3 1f3 1e1 1c0
1e5 1e6 1ee 1e0 213 1fe 202 1dd
206 20e 1fd 21a 21e 1fa 222 226
22a 22d 232 233 1 235 23a 23e
242 245 24a 24e 252 255 25a 25b
25d 262 265 269 26a 26f 274 277
27c 27d 282 285 289 28a 28f 292
297 298 29d 2a0 2a5 2a6 2ab 2ae
2b3 2b4 2b9 2bc 2c0 2c1 2c6 2c9
2ce 2cf 2d4 2d7 2dc 2dd 2e2 2e5
2e9 2ed 2f2 2f5 2f9 2fa 2ff 302
307 308 30d 312 313 315 31a 31b
31d 31e 323 326 32b 32c 331 334
338 33c 341 344 348 349 34e 351
356 357 35c 361 362 364 369 36a
36c 36d 372 375 37a 37b 380 383
387 38b 38f 390 392 397 398 39a
39b 3a0 3a3 3a8 3a9 3ae 3b1 3b5
3b9 3bd 3be 3c0 3c5 3c6 3c8 3c9
3ce 3d1 3d6 3d7 3dc 3df 3e3 3e7
3eb 3ec 3ee 3f3 3f4 3f6 3f7 3fc
3ff 404 405 40a 40d 411 415 419
41a 41c 421 422 424 425 42a 42d
432 433 438 43b 440 441 446 449
44d 44e 453 456 45b 45c 461 464
469 46a 46f 470 475 477 47b 47e
482 486 489 48d 491 494 497 49c
49f 4a2 4a5 4a6 4ab 4ac 1 4ae
4b3 4b7 4bb 4be 4c3 4c8 4cb 4cf
4d0 4d5 4d6 4db 4dd 4e1 4e4 4e8
4ec 4f0 4f4 4f8 4fc 500 504 508
50c 510 514 518 51c 520 524 528
52c 530 534 538 53c 540 544 548
54c 550 554 558 55b 55f 563 567
56b 56f 573 577 57b 57f 583 587
588 58a 58e 592 596 599 59d 5a1
5a4 5a7 5ac 5af 5b2 5b5 5b6 5bb
5bc 1 5be 5c3 5c7 5cb 5ce 5d3
5d8 5db 5df 5e0 5e5 5e8 5ed 5ee
5f3 5f6 5fb 5fc 601 604 608 60c
610 614 617 618 61a 61f 620 622
623 628 62b 630 631 636 639 63e
63f 644 647 64b 64c 651 654 659
65a 65f 660 665 667 66b 66e 672
676 679 67d 681 684 688 68c 68d
692 694 698 69c 69f 6a3 6a7 6aa
6ae 6b2 6b5 6b8 6bd 6c0 6c3 6c6
6c7 6cc 6cd 1 6cf 6d4 6d8 6dc
6df 6e4 6e9 6ec 6f0 6f1 6f6 6f7
6fc 700 704 707 70c 711 714 718
71c 71f 720 725 728 72d 72e 733
736 73a 73e 741 742 747 748 74d
74f 753 756 75a 75e 762 766 76a
76e 772 776 77a 786 78b 78f 793
797 79b 79d 79e 7a3 1 7a7 7ab
7af 7b2 7b6 7ba 7be 7c2 7c5 7c9
7cd 7d0 7d3 7d8 7db 7de 7e1 7e2
7e7 7e8 1 7ea 7ef 7f3 7f7 7fa
7ff 804 807 80b 80c 811 812 817
81b 81f 822 827 82c 82f 833 834
839 83c 841 842 847 84a 84e 852
855 858 859 85b 85c 861 862 867
869 86d 870 874 878 87c 880 884
888 88c 898 89d 8a1 8a5 8a9 8ad
8af 8b3 8b5 8c1 8c3 8c5 8c6 8cb
8cf 8d1 8dd 8e1 8e3 8e4 8ed 
26f
2
0 1 a 6 10 :3 6 15 :3 6
16 :3 6 17 :3 6 e :3 6 e :3 6
15 :3 6 f :3 6 10 :2 6 1 3
a 13 a :2 1 4 12 1b 1a
:2 12 :2 4 14 1d 1c :2 14 :2 4 :3 16
:2 4 :3 17 :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 15 24 15 :2 4 :2 f
1e f :2 4 f 18 17 :2 f :2 4
9 12 11 :2 9 :2 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 58 5e
61 :2 58 6f 89 8 :2 6f d 10
:2 6f 1a 1d :2 6f b e :2 6f 13
16 :2 6f 1b 1e :2 6f 2d 30 :2 6f
b e :2 6f 13 16 1f 26 2b
2e :2 26 3e 41 :2 26 46 :2 1f 4f
:2 16 :2 6f b e :2 6f 13 16 1f
26 2b 2e :2 26 3f 42 :2 26 47
:2 1f 50 :2 16 :2 6f b e :2 6f 13
16 1f 27 :2 1f 31 :2 16 :2 6f b
e :2 6f 13 16 1f 27 :2 1f 31
:2 16 :2 6f b e :2 6f 13 16 1f
27 :2 1f 38 :2 16 :2 6f b e :2 6f
13 16 1f 27 :2 1f 32 :2 16 :2 6f
b e :2 6f 13 16 :2 6f 1b 1e
:2 6f 28 2b :2 6f 30 33 :2 6f :2 7
4e :2 4 7 :2 11 23 :2 2d 39 3c
50 52 53 :2 50 :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :2 7 56 :3 4 15
:2 4 17 :2 4 19 :2 4 1a :2 4 11
:2 4 11 :2 4 18 :2 4 12 :2 4 12
:2 4 :2 d 19 2a 39 4a 29 3d
48 53 29 35 41 :2 19 4 7
:2 11 23 :2 2d 39 3c 50 52 53
:2 50 :2 23 :3 7 :2 d 12 1e 61 64
:2 1e 71 74 :2 1e 78 7b :2 1e 85
88 91 99 :2 a2 :2 91 ad :2 88 :2 1e
b5 b8 :2 1e c0 c3 :2 1e c8 cb
:2 1e d0 d3 :2 1e :2 7 56 :3 4 :2 f
21 :2 2a 34 3a :2 4 1 9 12
9 a :2 14 26 :2 30 3c 40 54
56 57 :2 54 :2 26 :3 a :2 10 15 21
64 67 :2 21 :3 a :2 10 15 39 5c
5f :2 68 :2 39 76 79 :2 39 81 84
:2 8d :2 39 :2 a 5a :3 7 c 15 1e
2c a 13 1e f e 7 e
7 e 7 29 :2 4 :2 9 7 :2 10
1c :2 7 :2 11 23 :2 2d 39 3d 51
53 54 :2 51 :2 23 :3 7 :2 d 12 1e
61 64 :2 1e :3 7 :2 d 12 36 42
45 :2 36 4d 50 :2 36 5c 5f 66
6f 72 :2 5f :2 36 :2 7 57 :2 4 7
c 1b a 13 1e f e 7
e 7 e 7 :2 4 :4 10 :2 4 :8 1

26f
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b 2
:4 c :2 1 :7 e :7 f
:5 10 :5 11 :6 12 :6 13
:6 14 :6 15 :7 16 :7 17
:7 19 :b 1b :11 1c 1d
:2 1c :2 1d :2 1c :2 1d
:2 1c :2 1e :2 1c :2 1e
:2 1c :2 1e :2 1c :2 1e
:2 1c :2 1f :2 1c :12 1f
:2 1c :2 20 :2 1c :12 20
:2 1c :2 21 :2 1c :9 21
:2 1c :2 22 :2 1c :9 22
:2 1c :2 23 :2 1c :9 23
:2 1c :2 24 :2 1c :9 24
:2 1c :2 25 :2 1c :2 25
:2 1c :2 25 :2 1c :2 25
:2 1c :2 25 :4 1c :3 1b
:11 28 :b 29 :3 28 :3 2e
:3 2f :3 30 :3 31 :3 32
:3 33 :3 34 :3 35 :3 36
:7 38 :4 39 :3 3a :3 38
:11 3c :30 3d :3 3c :a 3f
1a :3 42 :11 43 :b 44
:17 45 :3 43 :2 47 :3 48
:3 49 4a 48 47
48 :3 4b :3 42 :2 4c
:5 4e :11 4f :b 50 :18 51
:3 4f :2 53 54 :3 55
56 54 53 54
:3 57 :2 4d :6 4c 41
:7 1 
8ef
4
:3 0 1 :3 0 2
:a 0 26a 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 7 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 7 :3 0 8
:7 0 11 10 :3 0
a :3 0 9 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 b :7 0 19
18 :3 0 a :3 0
c :7 0 1d 1c
:3 0 15 :2 0 13
a :3 0 d :7 0
21 20 :3 0 4
:3 0 e :7 0 25
24 :3 0 f :3 0
10 :3 0 11 :2 0
4 29 2a 0
27 2b 0 26a
2 2c :2 0 13
:2 0 21 4 :3 0
13 :2 0 1f 2f
31 :6 0 34 32
0 268 0 12
:6 0 27 11c 0
25 4 :3 0 23
36 38 :6 0 3b
39 0 268 0
14 :6 0 18 :2 0
29 7 :3 0 3d
:7 0 40 3e 0
268 0 15 :6 0
7 :3 0 42 :7 0
45 43 0 268
0 16 :6 0 18
:2 0 2b a :3 0
47 :7 0 4b 48
49 268 0 17
:6 0 18 :2 0 2d
a :3 0 4d :7 0
51 4e 4f 268
0 19 :6 0 18
:2 0 2f a :3 0
53 :7 0 57 54
55 268 0 1a
:6 0 13 :2 0 31
a :3 0 59 :7 0
5d 5a 5b 268
0 1b :6 0 13
:2 0 35 4 :3 0
33 5f 61 :6 0
64 62 0 268
0 1c :6 0 6d
6e 0 39 4
:3 0 37 66 68
:6 0 6b 69 0
268 0 1d :6 0
73 74 0 3b
10 :3 0 11 :2 0
4 6f :7 0 72
70 0 268 0
1e :6 0 1f :3 0
20 :3 0 1f :3 0
21 :3 0 76 77
0 2 :4 0 3d
78 7a 75 7c
7b :2 0 22 :3 0
23 :3 0 7e 7f
0 24 :4 0 1f
:3 0 25 :3 0 82
83 0 2 :4 0
3f 84 86 26
:4 0 27 :2 0 28
:3 0 41 89 8b
:3 0 29 :4 0 27
:2 0 2a :4 0 44
8e 90 :3 0 27
:2 0 3 :3 0 47
92 94 :3 0 27
:2 0 2a :4 0 4a
96 98 :3 0 27
:2 0 2b :4 0 4d
9a 9c :3 0 27
:2 0 2a :4 0 50
9e a0 :3 0 27
:2 0 5 :3 0 53
a2 a4 :3 0 27
:2 0 2a :4 0 56
a6 a8 :3 0 27
:2 0 2b :4 0 59
aa ac :3 0 27
:2 0 2c :3 0 2d
:3 0 2a :4 0 27
:2 0 6 :3 0 5c
b2 b4 :3 0 27
:2 0 2a :4 0 5f
b6 b8 :3 0 2e
:4 0 62 b0 bb
2f :4 0 65 af
be 68 ae c0
:3 0 27 :2 0 2b
:4 0 6b c2 c4
:3 0 27 :2 0 2c
:3 0 2d :3 0 2a
:4 0 27 :2 0 8
:3 0 6e ca cc
:3 0 27 :2 0 2a
:4 0 71 ce d0
:3 0 2e :4 0 74
c8 d3 2f :4 0
77 c7 d6 7a
c6 d8 :3 0 27
:2 0 2b :4 0 7d
da dc :3 0 27
:2 0 2c :3 0 30
:3 0 9 :3 0 80
e0 e2 2f :4 0
82 df e5 85
de e7 :3 0 27
:2 0 2b :4 0 88
e9 eb :3 0 27
:2 0 2c :3 0 30
:3 0 b :3 0 8b
ef f1 2f :4 0
8d ee f4 90
ed f6 :3 0 27
:2 0 2b :4 0 93
f8 fa :3 0 27
:2 0 2c :3 0 30
:3 0 c :3 0 96
fe 100 2f :4 0
98 fd 103 9b
fc 105 :3 0 27
:2 0 2b :4 0 9e
107 109 :3 0 27
:2 0 2c :3 0 30
:3 0 d :3 0 a1
10d 10f 2f :4 0
a3 10c 112 a6
10b 114 :3 0 27
:2 0 2b :4 0 a9
116 118 :3 0 27
:2 0 2a :4 0 ac
11a 11c :3 0 27
:2 0 e :3 0 af
11e 120 :3 0 27
:2 0 2a :4 0 b2
122 124 :3 0 27
:2 0 31 :4 0 b5
126 128 :3 0 b8
80 12a :2 0 12c
bd 12d 7d 12c
0 12e bf 0
1c8 1f :3 0 20
:3 0 12f 130 0
1f :3 0 32 :3 0
132 133 0 33
:2 0 2 :4 0 34
:2 0 35 :2 0 33
:2 0 c1 138 13a
:3 0 c4 134 13c
131 13e 13d :2 0
22 :3 0 36 :3 0
140 141 0 24
:4 0 37 :4 0 27
:2 0 28 :3 0 c8
145 147 :3 0 cb
142 149 :2 0 14b
ce 14c 13f 14b
0 14d d0 0
1c8 12 :3 0 3
:3 0 14e 14f 0
1c8 14 :3 0 5
:3 0 151 152 0
1c8 15 :3 0 6
:3 0 154 155 0
1c8 16 :3 0 8
:3 0 157 158 0
1c8 17 :3 0 9
:3 0 15a 15b 0
1c8 19 :3 0 b
:3 0 15d 15e 0
1c8 1a :3 0 c
:3 0 160 161 0
1c8 1b :3 0 d
:3 0 163 164 0
1c8 1c :3 0 e
:3 0 166 167 0
1c8 10 :3 0 38
:3 0 169 16a 0
39 :3 0 12 :3 0
14 :3 0 15 :3 0
16 :3 0 17 :3 0
19 :3 0 1a :3 0
1b :3 0 1c :3 0
1d :3 0 d2 16c
177 16b 178 0
1c8 1f :3 0 20
:3 0 17a 17b 0
1f :3 0 32 :3 0
17d 17e 0 3a
:2 0 2 :4 0 3b
:2 0 35 :2 0 33
:2 0 dd 183 185
:3 0 e0 17f 187
17c 189 188 :2 0
22 :3 0 36 :3 0
18b 18c 0 24
:4 0 3c :4 0 27
:2 0 28 :3 0 e4
190 192 :3 0 27
:2 0 3d :4 0 e7
194 196 :3 0 27
:2 0 3e :4 0 ea
198 19a :3 0 27
:2 0 2c :3 0 30
:3 0 10 :3 0 38
:3 0 19f 1a0 0
ed 19e 1a2 2f
:4 0 ef 19d 1a5
f2 19c 1a7 :3 0
27 :2 0 3f :4 0
f5 1a9 1ab :3 0
27 :2 0 2a :4 0
f8 1ad 1af :3 0
27 :2 0 1d :3 0
fb 1b1 1b3 :3 0
27 :2 0 2a :4 0
fe 1b5 1b7 :3 0
101 18d 1b9 :2 0
1bb 104 1bc 18a
1bb 0 1bd 106
0 1c8 40 :3 0
41 :3 0 1be 1bf
0 10 :3 0 38
:3 0 1c1 1c2 0
1d :3 0 42 :3 0
108 1c0 1c6 :2 0
1c8 10c 269 10
:3 0 43 :2 0 4
1c9 1ca 0 1f
:3 0 20 :3 0 1cc
1cd 0 1f :3 0
32 :3 0 1cf 1d0
0 44 :2 0 2
:4 0 45 :2 0 35
:2 0 33 :2 0 11b
1d5 1d7 :3 0 11e
1d1 1d9 1ce 1db
1da :2 0 22 :3 0
36 :3 0 1dd 1de
0 24 :4 0 46
:4 0 27 :2 0 28
:3 0 122 1e2 1e4
:3 0 125 1df 1e6
:2 0 1ff 22 :3 0
36 :3 0 1e8 1e9
0 24 :4 0 47
:4 0 27 :2 0 10
:3 0 48 :3 0 1ee
1ef 0 128 1ed
1f1 :3 0 27 :2 0
3f :4 0 12b 1f3
1f5 :3 0 27 :2 0
10 :3 0 49 :3 0
1f8 1f9 0 12e
1f7 1fb :3 0 131
1ea 1fd :2 0 1ff
134 200 1dc 1ff
0 201 137 0
211 4a :3 0 1e
:3 0 10 :3 0 48
:3 0 4b :3 0 10
:3 0 49 :3 0 4c
:3 0 4d :4 0 4e
1 :a 0 20d :2 0
211 203 20b :2 0
f :3 0 1e :3 0
20f :2 0 211 139
213 13d 212 211
:2 0 267 4f :3 0
10 :3 0 38 :3 0
216 217 0 50
:3 0 218 219 0
25f 1f :3 0 20
:3 0 21b 21c 0
1f :3 0 32 :3 0
21e 21f 0 44
:2 0 2 :4 0 51
:2 0 35 :2 0 33
:2 0 13f 224 226
:3 0 142 220 228
21d 22a 229 :2 0
22 :3 0 36 :3 0
22c 22d 0 24
:4 0 52 :4 0 27
:2 0 28 :3 0 146
231 233 :3 0 149
22e 235 :2 0 24f
22 :3 0 36 :3 0
237 238 0 24
:4 0 53 :4 0 27
:2 0 50 :3 0 14c
23c 23e :3 0 27
:2 0 54 :4 0 14f
240 242 :3 0 27
:2 0 55 :3 0 56
:3 0 33 :2 0 57
:2 0 152 245 249
156 244 24b :3 0
159 239 24d :2 0
24f 15c 250 22b
24f 0 251 15f
0 25f 4a :3 0
1e :3 0 4b :3 0
10 :3 0 49 :3 0
4c :3 0 4d :4 0
58 1 :a 0 25b
:2 0 25f 253 259
:2 0 f :3 0 1e
:3 0 25d :2 0 25f
161 262 :3 0 262
0 262 261 25f
260 :6 0 264 1
:3 0 166 266 168
265 264 :2 0 267
16a :2 0 269 16d
269 268 1c8 267
:6 0 26a :2 0 2
2c 269 26d :3 0
26c 26a 26e :8 0

179
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 9
6 a e 12
16 1a 1e 22
26 1 30 1
2e 1 37 1
35 1 3c 1
41 1 46 1
4c 1 52 1
58 1 60 1
5e 1 67 1
65 1 6c 1
79 1 85 2
88 8a 2 8d
8f 2 91 93
2 95 97 2
99 9b 2 9d
9f 2 a1 a3
2 a5 a7 2
a9 ab 2 b1
b3 2 b5 b7
2 b9 ba 2
bc bd 2 ad
bf 2 c1 c3
2 c9 cb 2
cd cf 2 d1
d2 2 d4 d5
2 c5 d7 2
d9 db 1 e1
2 e3 e4 2
dd e6 2 e8
ea 1 f0 2
f2 f3 2 ec
f5 2 f7 f9
1 ff 2 101
102 2 fb 104
2 106 108 1
10e 2 110 111
2 10a 113 2
115 117 2 119
11b 2 11d 11f
2 121 123 2
125 127 4 81
87 8c 129 1
12b 1 12d 2
137 139 3 135
136 13b 2 144
146 2 143 148
1 14a 1 14c
a 16d 16e 16f
170 171 172 173
174 175 176 2
182 184 3 180
181 186 2 18f
191 2 193 195
2 197 199 1
1a1 2 1a3 1a4
2 19b 1a6 2
1a8 1aa 2 1ac
1ae 2 1b0 1b2
2 1b4 1b6 2
18e 1b8 1 1ba
1 1bc 3 1c3
1c4 1c5 e 12e
14d 150 153 156
159 15c 15f 162
165 168 179 1bd
1c7 2 1d4 1d6
3 1d2 1d3 1d8
2 1e1 1e3 2
1e0 1e5 2 1ec
1f0 2 1f2 1f4
2 1f6 1fa 2
1eb 1fc 2 1e7
1fe 1 200 3
201 20c 210 1
1cb 2 223 225
3 221 222 227
2 230 232 2
22f 234 2 23b
23d 2 23f 241
3 246 247 248
2 243 24a 2
23a 24c 2 236
24e 1 250 4
21a 251 25a 25e
1 262 1 215
2 213 266 b
33 3a 3f 44
4a 50 56 5c
63 6a 71 
1
4
0 
26d
0
1
14
2
15
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
35 1 0
f 1 0
46 1 0
41 1 0
13 1 0
23 1 0
7 1 0
3c 1 0
52 1 0
3 1 0
65 1 0
58 1 0
4c 1 0
b 1 0
17 1 0
1b 1 0
5e 1 0
1f 1 0
2 0 1
6c 1 0
2e 1 0
0

/
SHOW ERRORS FUNCTION SP_U_PARTICIPANT;
ALTER FUNCTION SP_U_PARTICIPANT COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_CRI_SECURITY ==
CREATE OR REPLACE FUNCTION SP_U_CRI_SECURITY wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
71
2 :e:
1FUNCTION:
1SP_U_CRI_SECURITY:
1ASSIGN_ID:
1VARCHAR2:
1SECURITY_ID001:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1P_DELAY:
1PLS_INTEGER:
1P_UNITS:
1P_WORK_PERCENT:
1P_ACTUAL:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1A_ELEMENT_ID:
132:
1A_PARTICIPANT_ID:
1255:
1A_PARTICIPANT_NAME:
1A_SECURITY_NAME:
1H_FULL_NAME:
1A_RES_ASSIGNMENT_ID:
1A_SECURITY_ID:
1A_TEMP_ID:
1H_CREATED_BY:
1H_PROJECT_ID:
1A_ASSIGNMENT_COUNT:
10:
1A_ELEMENT_TYPE:
1H_RESPONSIBLE:
1A_PARTICIPANT:
1A_RESOURCE_TYPE:
1A_SECURITY_VALUE:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_ASSIGN_STRING:
18192:
1H_TEMP_RES_TYPE:
11:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_WBS_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TRANSFED_CRI:
1H_CRI_TABLE:
1H_CRI_ELEMENT_TYPE:
1H_REC_USER:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_CRI_SECURITY(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_U_CRI_SECURITY(61) :: cplan.sql(18737) :: :
1:
1PMO_CNST:
1SC_TABLE_CRI:
1SC_STATE:
1FC_U_ASSIGNED_SECURITY:
14:
176:
1       RETURN_STATUS:: SP_U_CRI_SECURITY(77) :: cplan.sql(18753) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
183:
1           EXCEPTION:: SP_U_CRI_SECURITY(84) :: cplan.sql(18760) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
195:
1           EXCEPTION:: SP_U_CRI_SECURITY(96) :: cplan.sql(18772) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2e4
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :2 a0 6e 7e
a0 b4 2e 7e 6e b4 2e 6e
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :2 a0 6e 7e a0
b4 2e 7e 6e b4 2e 6e a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 6e
d :2 a0 d :2 a0 d :2 a0 d :3 a0
6b d :2 a0 6b :5 a0 a5 b d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
2e4
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 a2
c8 cc d0 d4 d7 db f8 e3
e7 ea eb f3 e2 115 103 df
107 108 110 102 132 120 ff 124
125 12d 11f 14f 13d 11c 141 142
14a 13c 16c 15a 139 15e 15f 167
159 189 177 156 17b 17c 184 176
1a6 194 173 198 199 1a1 193 1c3
1b1 190 1b5 1b6 1be 1b0 1e0 1ce
1ad 1d2 1d3 1db 1cd 1fd 1eb 1ca
1ef 1f0 1f8 1ea 219 208 20c 1e7
214 207 235 224 228 204 230 223
251 240 244 220 24c 23f 26d 25c
260 23c 268 25b 289 278 27c 258
284 277 2a5 294 298 274 2a0 293
2c1 2b0 2b4 290 2bc 2af 2dd 2cc
2d0 2ac 2d8 2cb 2f9 2e8 2ec 2c8
2f4 2e7 316 304 2e4 308 309 311
303 333 321 300 325 326 32e 320
34f 33e 342 31d 34a 33d 36c 35a
33a 35e 35f 367 359 389 377 356
37b 37c 384 376 3a5 394 398 373
3a0 393 3c1 3b0 3b4 390 3bc 3af
3dd 3cc 3d0 3ac 3d8 3cb 3f9 3e8
3ec 3c8 3f4 3e7 415 404 408 3e4
410 403 432 420 400 424 425 42d
41f 452 43d 441 41c 445 44d 43c
459 45d 439 461 465 469 46c 471
472 1 474 479 47d 481 484 489
48d 491 494 499 49a 49c 4a1 4a4
4a8 4a9 4ae 4b3 4b6 4bb 4bc 4c1
4c4 4c8 4c9 4ce 4d1 4d6 4d7 4dc
4df 4e4 4e5 4ea 4ed 4f2 4f3 4f8
4fb 4ff 500 505 508 50d 50e 513
516 51b 51c 521 524 528 52c 531
534 538 539 53e 541 546 547 54c
551 552 554 559 55a 55c 55d 562
565 56a 56b 570 573 577 57b 580
583 587 588 58d 590 595 596 59b
5a0 5a1 5a3 5a8 5a9 5ab 5ac 5b1
5b4 5b9 5ba 5bf 5c2 5c6 5ca 5ce
5cf 5d1 5d6 5d7 5d9 5da 5df 5e2
5e7 5e8 5ed 5f0 5f4 5f8 5fc 5fd
5ff 604 605 607 608 60d 610 615
616 61b 61e 622 626 62a 62b 62d
632 633 635 636 63b 63e 643 644
649 64c 650 654 658 659 65b 660
661 663 664 669 66c 671 672 677
67a 67f 680 685 688 68c 68d 692
695 69a 69b 6a0 6a3 6a8 6a9 6ae
6af 6b4 6b6 6ba 6bd 6c1 6c5 6c8
6cc 6d0 6d3 6d6 6db 6de 6e1 6e4
6e5 6ea 6eb 1 6ed 6f2 6f6 6fa
6fd 702 707 70a 70e 70f 714 715
71a 71c 720 723 727 72c 730 734
738 73c 740 744 748 74c 750 754
758 75c 760 763 767 76b 76f 772
776 77a 77e 782 786 787 789 78d
791 795 798 79c 7a0 7a3 7a6 7ab
7ae 7b1 7b4 7b5 7ba 7bb 1 7bd
7c2 7c6 7ca 7cd 7d2 7d7 7da 7de
7df 7e4 7e7 7ec 7ed 7f2 7f5 7fa
7fb 800 803 807 80b 80f 813 816
817 819 81e 81f 821 822 827 82a
82f 830 835 838 83d 83e 843 846
84a 84b 850 853 858 859 85e 85f
864 866 86a 86d 871 875 878 87c
880 883 887 88b 88c 891 893 897
89b 89e 8a2 8a6 8a9 8ad 8b1 8b4
8b7 8bc 8bf 8c2 8c5 8c6 8cb 8cc
1 8ce 8d3 8d7 8db 8de 8e3 8e8
8eb 8ef 8f0 8f5 8f6 8fb 8ff 903
906 90b 910 913 917 91b 91e 91f
924 927 92c 92d 932 935 939 93d
940 941 946 947 94c 94e 952 955
959 95d 961 965 969 96d 971 975
979 985 98a 98e 992 996 99a 99c
99d 9a2 1 9a6 9aa 9ae 9b1 9b5
9b9 9bd 9c1 9c4 9c8 9cc 9cf 9d2
9d7 9da 9dd 9e0 9e1 9e6 9e7 1
9e9 9ee 9f2 9f6 9f9 9fe a03 a06
a0a a0b a10 a11 a16 a1a a1e a21
a26 a2b a2e a32 a33 a38 a3b a40
a41 a46 a49 a4d a51 a54 a57 a58
a5a a5b a60 a61 a66 a68 a6c a6f
a73 a77 a7b a7f a83 a87 a8b a97
a9c aa0 aa4 aa8 aac aae ab2 ab4
ac0 ac2 ac4 ac5 aca ace ad0 adc
ae0 ae2 ae3 aec 
2e4
2
0 1 a 6 10 :3 6 15 :3 6
16 :3 6 17 :3 6 e :3 6 e :3 6
15 :3 6 f :3 6 10 :2 6 1 3
a 13 a :2 1 4 11 1a 19
:2 11 :2 4 15 1e 1d :2 15 :2 4 17
20 1f :2 17 :2 4 14 1d 1c :2 14
:2 4 10 19 18 :2 10 :2 4 18 21
20 :2 18 :2 4 12 1b 1a :2 12 :2 4
e 17 16 :2 e :2 4 11 1a 19
:2 11 :2 4 11 1a 19 :2 11 :2 4 :2 17
26 17 :2 4 :2 13 22 13 :2 4 :2 12
21 12 :2 4 :2 12 21 12 :2 4 :2 14
23 14 :2 4 :2 15 24 15 :2 4 :2 12
21 12 :2 4 :2 d 1c d :2 4 :2 11
20 11 :2 4 14 1d 1c :2 14 :2 4
14 1d 1c :2 14 :2 4 :2 17 26 17
:2 4 17 20 1f :2 17 :2 4 16 1f
1e :2 16 :2 4 :2 13 22 13 :2 4 :2 14
23 14 :2 4 :2 13 22 13 :2 4 :2 10
1f 10 :2 4 :2 17 26 17 :2 4 f
18 17 :2 f :2 4 e 17 :3 e 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 59 5f 62
:2 59 70 8b 8 :2 70 d 10 :2 70
1a 1d :2 70 b e :2 70 13 16
:2 70 1b 1e :2 70 2d 30 :2 70 b
e :2 70 13 16 1f 26 2b 2e
:2 26 3e 41 :2 26 46 :2 1f 4f :2 16
:2 70 b e :2 70 13 16 1f 26
2b 2e :2 26 3f 42 :2 26 47 :2 1f
50 :2 16 :2 70 b e :2 70 13 16
1f 27 :2 1f 31 :2 16 :2 70 b e
:2 70 13 16 1f 27 :2 1f 31 :2 16
:2 70 b e :2 70 13 16 1f 27
:2 1f 38 :2 16 :2 70 b e :2 70 13
16 1f 27 :2 1f 32 :2 16 :2 70 b
e :2 70 13 16 :2 70 1b 1e :2 70
28 2b :2 70 30 33 :2 70 :2 7 4f
:2 4 7 :2 11 23 :2 2d 39 3c 51
53 54 :2 51 :2 23 :3 7 :2 d 12 1e
62 65 :2 1e :2 7 57 :3 4 14 :2 4
11 :2 4 15 :2 4 12 :2 4 14 :2 1d
:2 4 :2 d 19 30 3e 49 58 :2 19
4 7 :2 11 23 :2 2d 39 3c 51
53 54 :2 51 :2 23 :3 7 :2 d 12 1e
62 65 :2 1e 72 75 :2 1e 79 7c
:2 1e 86 89 92 9a :2 a3 :2 92 ae
:2 89 :2 1e b6 b9 :2 1e c1 c4 :2 1e
c9 cc :2 1e d6 d9 :2 1e :2 7 57
:3 4 :2 f 21 :2 2a 34 3f :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 55 57 58 :2 55 :2 26 :3 a :2 10
15 21 65 68 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 5b :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 52 54 55 :2 52 :2 23 :3 7 :2 d
12 1e 62 65 :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 58
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
2e4
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b 2
:4 c :2 1 :7 e :7 f
:7 10 :7 11 :7 12 :7 13
:7 14 :7 15 :7 16 :7 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :7 21 :7 22 :6 23
:7 24 :7 25 :6 26 :6 27
:6 28 :6 29 :6 2a :7 2b
:7 2d :b 2f :11 30 31
:2 30 :2 31 :2 30 :2 31
:2 30 :2 32 :2 30 :2 32
:2 30 :2 32 :2 30 :2 32
:2 30 :2 33 :2 30 :12 33
:2 30 :2 34 :2 30 :12 34
:2 30 :2 35 :2 30 :9 35
:2 30 :2 36 :2 30 :9 36
:2 30 :2 37 :2 30 :9 37
:2 30 :2 38 :2 30 :9 38
:2 30 :2 39 :2 30 :2 39
:2 30 :2 39 :2 30 :2 39
:2 30 :2 39 :4 30 :3 2f
:11 3c :b 3d :3 3c :3 42
:3 45 :3 46 :3 47 :5 49
:b 4a :11 4c :30 4d :3 4c
:a 4f 2e :3 52 :11 53
:b 54 :17 55 :3 53 :2 57
:3 58 :3 59 5a 58
57 58 :3 5b :3 52
:2 5c :5 5e :11 5f :b 60
:18 61 :3 5f :2 63 64
:3 65 66 64 63
64 :3 67 :2 5d :6 5c
51 :7 1 
aee
4
:3 0 1 :3 0 2
:a 0 2df 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 7 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 7 :3 0 8
:7 0 11 10 :3 0
a :3 0 9 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 b :7 0 19
18 :3 0 a :3 0
c :7 0 1d 1c
:3 0 15 :2 0 13
a :3 0 d :7 0
21 20 :3 0 4
:3 0 e :7 0 25
24 :3 0 f :3 0
10 :3 0 11 :2 0
4 29 2a 0
27 2b 0 2df
2 2c :2 0 15
:2 0 21 4 :3 0
13 :2 0 1f 2f
31 :6 0 34 32
0 2dd 0 12
:6 0 15 :2 0 25
4 :3 0 23 36
38 :6 0 3b 39
0 2dd 0 14
:6 0 13 :2 0 29
4 :3 0 27 3d
3f :6 0 42 40
0 2dd 0 16
:6 0 15 :2 0 2d
4 :3 0 2b 44
46 :6 0 49 47
0 2dd 0 17
:6 0 13 :2 0 31
4 :3 0 2f 4b
4d :6 0 50 4e
0 2dd 0 18
:6 0 13 :2 0 35
4 :3 0 33 52
54 :6 0 57 55
0 2dd 0 19
:6 0 13 :2 0 39
4 :3 0 37 59
5b :6 0 5e 5c
0 2dd 0 1a
:6 0 13 :2 0 3d
4 :3 0 3b 60
62 :6 0 65 63
0 2dd 0 1b
:6 0 13 :2 0 41
4 :3 0 3f 67
69 :6 0 6c 6a
0 2dd 0 1c
:6 0 1f :2 0 45
4 :3 0 43 6e
70 :6 0 73 71
0 2dd 0 1d
:6 0 1f :2 0 47
a :3 0 75 :7 0
79 76 77 2dd
0 1e :6 0 1f
:2 0 49 a :3 0
7b :7 0 7f 7c
7d 2dd 0 20
:6 0 1f :2 0 4b
a :3 0 81 :7 0
85 82 83 2dd
0 21 :6 0 1f
:2 0 4d a :3 0
87 :7 0 8b 88
89 2dd 0 22
:6 0 1f :2 0 4f
a :3 0 8d :7 0
91 8e 8f 2dd
0 23 :6 0 1f
:2 0 51 a :3 0
93 :7 0 97 94
95 2dd 0 24
:6 0 1f :2 0 53
a :3 0 99 :7 0
9d 9a 9b 2dd
0 25 :6 0 1f
:2 0 55 a :3 0
9f :7 0 a3 a0
a1 2dd 0 26
:6 0 29 :2 0 57
a :3 0 a5 :7 0
a9 a6 a7 2dd
0 27 :6 0 2b
:2 0 5b 4 :3 0
59 ab ad :6 0
b0 ae 0 2dd
0 28 :6 0 1f
:2 0 5f 4 :3 0
5d b2 b4 :6 0
b7 b5 0 2dd
0 2a :6 0 13
:2 0 61 a :3 0
b9 :7 0 bd ba
bb 2dd 0 2c
:6 0 13 :2 0 65
4 :3 0 63 bf
c1 :6 0 c4 c2
0 2dd 0 2d
:6 0 1f :2 0 69
4 :3 0 67 c6
c8 :6 0 cb c9
0 2dd 0 2e
:6 0 1f :2 0 6b
a :3 0 cd :7 0
d1 ce cf 2dd
0 2f :6 0 1f
:2 0 6d a :3 0
d3 :7 0 d7 d4
d5 2dd 0 30
:6 0 1f :2 0 6f
a :3 0 d9 :7 0
dd da db 2dd
0 31 :6 0 1f
:2 0 71 a :3 0
df :7 0 e3 e0
e1 2dd 0 32
:6 0 13 :2 0 73
a :3 0 e5 :7 0
e9 e6 e7 2dd
0 33 :6 0 f2
f3 0 77 4
:3 0 75 eb ed
:6 0 f0 ee 0
2dd 0 34 :6 0
f8 f9 0 79
10 :3 0 11 :2 0
4 f4 :7 0 f7
f5 0 2dd 0
35 :6 0 36 :3 0
37 :3 0 36 :3 0
38 :3 0 fb fc
0 2 :4 0 7b
fd ff fa 101
100 :2 0 39 :3 0
3a :3 0 103 104
0 3b :4 0 36
:3 0 3c :3 0 107
108 0 2 :4 0
7d 109 10b 3d
:4 0 3e :2 0 3f
:3 0 7f 10e 110
:3 0 40 :4 0 3e
:2 0 41 :4 0 82
113 115 :3 0 3e
:2 0 3 :3 0 85
117 119 :3 0 3e
:2 0 41 :4 0 88
11b 11d :3 0 3e
:2 0 42 :4 0 8b
11f 121 :3 0 3e
:2 0 41 :4 0 8e
123 125 :3 0 3e
:2 0 5 :3 0 91
127 129 :3 0 3e
:2 0 41 :4 0 94
12b 12d :3 0 3e
:2 0 42 :4 0 97
12f 131 :3 0 3e
:2 0 43 :3 0 44
:3 0 41 :4 0 3e
:2 0 6 :3 0 9a
137 139 :3 0 3e
:2 0 41 :4 0 9d
13b 13d :3 0 45
:4 0 a0 135 140
46 :4 0 a3 134
143 a6 133 145
:3 0 3e :2 0 42
:4 0 a9 147 149
:3 0 3e :2 0 43
:3 0 44 :3 0 41
:4 0 3e :2 0 8
:3 0 ac 14f 151
:3 0 3e :2 0 41
:4 0 af 153 155
:3 0 45 :4 0 b2
14d 158 46 :4 0
b5 14c 15b b8
14b 15d :3 0 3e
:2 0 42 :4 0 bb
15f 161 :3 0 3e
:2 0 43 :3 0 47
:3 0 9 :3 0 be
165 167 46 :4 0
c0 164 16a c3
163 16c :3 0 3e
:2 0 42 :4 0 c6
16e 170 :3 0 3e
:2 0 43 :3 0 47
:3 0 b :3 0 c9
174 176 46 :4 0
cb 173 179 ce
172 17b :3 0 3e
:2 0 42 :4 0 d1
17d 17f :3 0 3e
:2 0 43 :3 0 47
:3 0 c :3 0 d4
183 185 46 :4 0
d6 182 188 d9
181 18a :3 0 3e
:2 0 42 :4 0 dc
18c 18e :3 0 3e
:2 0 43 :3 0 47
:3 0 d :3 0 df
192 194 46 :4 0
e1 191 197 e4
190 199 :3 0 3e
:2 0 42 :4 0 e7
19b 19d :3 0 3e
:2 0 41 :4 0 ea
19f 1a1 :3 0 3e
:2 0 e :3 0 ed
1a3 1a5 :3 0 3e
:2 0 41 :4 0 f0
1a7 1a9 :3 0 3e
:2 0 48 :4 0 f3
1ab 1ad :3 0 f6
105 1af :2 0 1b1
fb 1b2 102 1b1
0 1b3 fd 0
23d 36 :3 0 37
:3 0 1b4 1b5 0
36 :3 0 49 :3 0
1b7 1b8 0 2b
:2 0 2 :4 0 4a
:2 0 4b :2 0 2b
:2 0 ff 1bd 1bf
:3 0 102 1b9 1c1
1b6 1c3 1c2 :2 0
39 :3 0 4c :3 0
1c5 1c6 0 3b
:4 0 4d :4 0 3e
:2 0 3f :3 0 106
1ca 1cc :3 0 109
1c7 1ce :2 0 1d0
10c 1d1 1c4 1d0
0 1d2 10e 0
23d 1c :3 0 4e
:4 0 1d3 1d4 0
23d 1b :3 0 3
:3 0 1d6 1d7 0
23d 1a :3 0 5
:3 0 1d9 1da 0
23d 34 :3 0 e
:3 0 1dc 1dd 0
23d 27 :3 0 4f
:3 0 50 :3 0 1e0
1e1 0 1df 1e2
0 23d 10 :3 0
51 :3 0 1e4 1e5
0 52 :3 0 27
:3 0 1b :3 0 1a
:3 0 34 :3 0 110
1e7 1ec 1e6 1ed
0 23d 36 :3 0
37 :3 0 1ef 1f0
0 36 :3 0 49
:3 0 1f2 1f3 0
53 :2 0 2 :4 0
54 :2 0 4b :2 0
2b :2 0 115 1f8
1fa :3 0 118 1f4
1fc 1f1 1fe 1fd
:2 0 39 :3 0 4c
:3 0 200 201 0
3b :4 0 55 :4 0
3e :2 0 3f :3 0
11c 205 207 :3 0
3e :2 0 56 :4 0
11f 209 20b :3 0
3e :2 0 57 :4 0
122 20d 20f :3 0
3e :2 0 43 :3 0
47 :3 0 10 :3 0
51 :3 0 214 215
0 125 213 217
46 :4 0 127 212
21a 12a 211 21c
:3 0 3e :2 0 58
:4 0 12d 21e 220
:3 0 3e :2 0 41
:4 0 130 222 224
:3 0 3e :2 0 1b
:3 0 133 226 228
:3 0 3e :2 0 41
:4 0 136 22a 22c
:3 0 139 202 22e
:2 0 230 13c 231
1ff 230 0 232
13e 0 23d 59
:3 0 5a :3 0 233
234 0 10 :3 0
51 :3 0 236 237
0 1b :3 0 5b
:3 0 140 235 23b
:2 0 23d 144 2de
10 :3 0 5c :2 0
4 23e 23f 0
36 :3 0 37 :3 0
241 242 0 36
:3 0 49 :3 0 244
245 0 5d :2 0
2 :4 0 5e :2 0
4b :2 0 2b :2 0
14f 24a 24c :3 0
152 246 24e 243
250 24f :2 0 39
:3 0 4c :3 0 252
253 0 3b :4 0
5f :4 0 3e :2 0
3f :3 0 156 257
259 :3 0 159 254
25b :2 0 274 39
:3 0 4c :3 0 25d
25e 0 3b :4 0
60 :4 0 3e :2 0
10 :3 0 61 :3 0
263 264 0 15c
262 266 :3 0 3e
:2 0 58 :4 0 15f
268 26a :3 0 3e
:2 0 10 :3 0 62
:3 0 26d 26e 0
162 26c 270 :3 0
165 25f 272 :2 0
274 168 275 251
274 0 276 16b
0 286 63 :3 0
35 :3 0 10 :3 0
61 :3 0 64 :3 0
10 :3 0 62 :3 0
65 :3 0 66 :4 0
67 1 :a 0 282
:2 0 286 278 280
:2 0 f :3 0 35
:3 0 284 :2 0 286
16d 288 171 287
286 :2 0 2dc 68
:3 0 10 :3 0 51
:3 0 28b 28c 0
69 :3 0 28d 28e
0 2d4 36 :3 0
37 :3 0 290 291
0 36 :3 0 49
:3 0 293 294 0
5d :2 0 2 :4 0
6a :2 0 4b :2 0
2b :2 0 173 299
29b :3 0 176 295
29d 292 29f 29e
:2 0 39 :3 0 4c
:3 0 2a1 2a2 0
3b :4 0 6b :4 0
3e :2 0 3f :3 0
17a 2a6 2a8 :3 0
17d 2a3 2aa :2 0
2c4 39 :3 0 4c
:3 0 2ac 2ad 0
3b :4 0 6c :4 0
3e :2 0 69 :3 0
180 2b1 2b3 :3 0
3e :2 0 6d :4 0
183 2b5 2b7 :3 0
3e :2 0 6e :3 0
6f :3 0 2b :2 0
70 :2 0 186 2ba
2be 18a 2b9 2c0
:3 0 18d 2ae 2c2
:2 0 2c4 190 2c5
2a0 2c4 0 2c6
193 0 2d4 63
:3 0 35 :3 0 64
:3 0 10 :3 0 62
:3 0 65 :3 0 66
:4 0 71 1 :a 0
2d0 :2 0 2d4 2c8
2ce :2 0 f :3 0
35 :3 0 2d2 :2 0
2d4 195 2d7 :3 0
2d7 0 2d7 2d6
2d4 2d5 :6 0 2d9
1 :3 0 19a 2db
19c 2da 2d9 :2 0
2dc 19e :2 0 2de
1a1 2de 2dd 23d
2dc :6 0 2df :2 0
2 2c 2de 2e2
:3 0 2e1 2df 2e3
:8 0 
1c1
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 9
6 a e 12
16 1a 1e 22
26 1 30 1
2e 1 37 1
35 1 3e 1
3c 1 45 1
43 1 4c 1
4a 1 53 1
51 1 5a 1
58 1 61 1
5f 1 68 1
66 1 6f 1
6d 1 74 1
7a 1 80 1
86 1 8c 1
92 1 98 1
9e 1 a4 1
ac 1 aa 1
b3 1 b1 1
b8 1 c0 1
be 1 c7 1
c5 1 cc 1
d2 1 d8 1
de 1 e4 1
ec 1 ea 1
f1 1 fe 1
10a 2 10d 10f
2 112 114 2
116 118 2 11a
11c 2 11e 120
2 122 124 2
126 128 2 12a
12c 2 12e 130
2 136 138 2
13a 13c 2 13e
13f 2 141 142
2 132 144 2
146 148 2 14e
150 2 152 154
2 156 157 2
159 15a 2 14a
15c 2 15e 160
1 166 2 168
169 2 162 16b
2 16d 16f 1
175 2 177 178
2 171 17a 2
17c 17e 1 184
2 186 187 2
180 189 2 18b
18d 1 193 2
195 196 2 18f
198 2 19a 19c
2 19e 1a0 2
1a2 1a4 2 1a6
1a8 2 1aa 1ac
4 106 10c 111
1ae 1 1b0 1
1b2 2 1bc 1be
3 1ba 1bb 1c0
2 1c9 1cb 2
1c8 1cd 1 1cf
1 1d1 4 1e8
1e9 1ea 1eb 2
1f7 1f9 3 1f5
1f6 1fb 2 204
206 2 208 20a
2 20c 20e 1
216 2 218 219
2 210 21b 2
21d 21f 2 221
223 2 225 227
2 229 22b 2
203 22d 1 22f
1 231 3 238
239 23a a 1b3
1d2 1d5 1d8 1db
1de 1e3 1ee 232
23c 2 249 24b
3 247 248 24d
2 256 258 2
255 25a 2 261
265 2 267 269
2 26b 26f 2
260 271 2 25c
273 1 275 3
276 281 285 1
240 2 298 29a
3 296 297 29c
2 2a5 2a7 2
2a4 2a9 2 2b0
2b2 2 2b4 2b6
3 2bb 2bc 2bd
2 2b8 2bf 2
2af 2c1 2 2ab
2c3 1 2c5 4
28f 2c6 2cf 2d3
1 2d7 1 28a
2 288 2db 1f
33 3a 41 48
4f 56 5d 64
6b 72 78 7e
84 8a 90 96
9c a2 a8 af
b6 bc c3 ca
d0 d6 dc e2
e8 ef f6 
1
4
0 
2e2
0
1
14
2
29
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
3c 1 0
b8 1 0
80 1 0
f 1 0
92 1 0
be 1 0
13 1 0
23 1 0
7 1 0
b1 1 0
9e 1 0
35 1 0
98 1 0
d2 1 0
c5 1 0
e4 1 0
5f 1 0
8c 1 0
d8 1 0
51 1 0
66 1 0
cc 1 0
7a 1 0
2e 1 0
3 1 0
86 1 0
de 1 0
2 0 1
a4 1 0
6d 1 0
b 1 0
58 1 0
17 1 0
74 1 0
1b 1 0
1f 1 0
4a 1 0
ea 1 0
aa 1 0
43 1 0
f1 1 0
0

/
SHOW ERRORS FUNCTION SP_U_CRI_SECURITY;
ALTER FUNCTION SP_U_CRI_SECURITY COMPILE DEBUG;
/****************************************************************************************
 id = TSK_ASSIGN_ID
 bitflag:
        1 = Copy Schedule to Baseline (includes budgets)
        2 = Copy Planned to Schedule
        3 = Copy Proposed to Schedule
        4 = Copy Forecast to Schedule (includes budgets)
        5 = Copy Forecast  Scheduled to Planned
        6 = Move Planned to Schedule
        7 = Append Planned to Schedule
 bussiness rules:
    1. Do not copy date for completed tasks (MILESTONE_PERCENT = 100)
    2. If the task has ACTUAL do not change ETC, WORK_TODATE, SD, FD
    3. When copy Forecast Date to ..., ETC is Forecast Effort, and clear Forcast dates after copy
    4. If both Forcast dates exists ignor forcast start, consider only forcast finish and ETC
    5. Calculated Forecast Start should not be in the past (is >= NOW)
    6. When copy Forcast to and assignments exists forcast rollup wins, and clear Forcast dates after copy
    7. Actual Finish date does not rollup from Assignments to Task
    8. When copy Planned to Schedule clear Planned Dates, Duration  Effort
****************************************************************************************/
Prompt == FUNCTION FC_COMMIT_ASSIGN ==
CREATE OR REPLACE FUNCTION FC_COMMIT_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
190
2 :e:
1FUNCTION:
1FC_COMMIT_ASSIGN:
1H_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1SH_H_BITFLAG:
1PLS_INTEGER:
1SH_H_ROLLUP_FLAG:
11:
1RETURN:
1H_BITFLAG:
1H_ROLLUP_FLAG:
1COALESCE:
10:
1H_BITID:
1RAW:
136:
1PMO_CNST:
1SC_ZERO_BIT:
1H_BITID1:
1H_PROJECT_ID:
132:
1H_DAYOFYEAR:
1DATE:
1H_RES_ID:
1H_TASK_ID:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_SCHED_WORK:
1H_BILLABLE:
1H_TOTAL:
1H_DAY_MIN:
1H_MIN_PER_DAY:
1H_CHANGE_FLAG:
1H_TYPE_ID:
1H_FROM_PRJ:
1H_TSK_PRJ:
1H_WORK:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1STMT:
17999:
1H_REC_STATUS:
1CURSOR:
1C270:
1TA:
1TSK_ASSIGNMENT_ID:
1RESOURCE_ID:
1TASK_ASSIGNMENTS:
1JOIN:
1TMT_WBS:
1W:
1PROJECT_ID:
1ELEMENT_ID:
1TASK_ID:
1BIT_FLAG:
1RESOURCE_TYPE:
1PROJECT_ASSIGNMENT_ID:
1SELECT TA.TSK_ASSIGNMENT_ID, TA.RESOURCE_ID:n         FROM TASK_ASSIGNMENTS T+
1A JOIN TMT_WBS W:n         ON W.PROJECT_ID = TA.PROJECT_ID AND W.ELEMENT_ID =+
1 TA.TASK_ID:n         WHERE W.PROJECT_ID = h_project_id AND TA.BIT_FLAG = '0'+
1:n         AND TA.RESOURCE_TYPE = '0' AND TA.PROJECT_ASSIGNMENT_ID IS Null:
1CMM1:
1PMO_DB2M:
1REF_CURSOR:
1C27:
1DAY_YEAR:
1SCHED_MIN:
1BIT_SCHED:
1TASK_DAY_OF_YEAR:
1SELECT DAY_YEAR, SCHED_MIN, BIT_SCHED FROM TASK_DAY_OF_YEAR:n         WHERE P+
1ROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_id AND BIT_FLAG = '0':
1C54:
1SELECT TASK_ID, TSK_ASSIGNMENT_ID:n         FROM TASK_ASSIGNMENTS:n         W+
1HERE BIT_FLAG = '0' AND PROJECT_ASSIGNMENT_ID = h_id:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_COMMIT_ASSIGN(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
164:
1+:
1FPUT:
1               ENTER:: FC_COMMIT_ASSIGN(65) :: cplan.sql(18874) :: :
1MINUTE_PER_DAY:
1REC_STATUS:
1SELECT COALESCE(MINUTE_PER_DAY, 480), REC_STATUS:n      INTO h_min_per_day, h+
1_rec_status:n      FROM TMT_WBS :n      WHERE ELEMENT_ID = h_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
182:
1           EXCEPTION:: FC_COMMIT_ASSIGN(83) :: cplan.sql(18892) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1T:
190:
1        RETURN_ERROR:: FC_COMMIT_ASSIGN(91) :: cplan.sql(18900) :: :
1STATE:: :
1CANNOT_UPDATE_LOCKED_RECORD:
1 ID:: :
193:
1                EXIT:: FC_COMMIT_ASSIGN(94) :: cplan.sql(18903) :: :
1PMODEFINES:
1PMO_RETURN_ERROR:
1FALSE:
1SC_SQL_NO_DATA:
1MILESTONE_PERCENT:
1SELECT PROJECT_ID, CASE WHEN PROJECT_ID = TASK_ID THEN 1 ELSE 0 END, CASE WHE+
1N PROJECT_ASSIGNMENT_ID IS NuLL THEN 0 ELSE 1 END:n         INTO h_project_id+
1,h_tsk_prj,h_from_prj:n         FROM TASK_ASSIGNMENTS WHERE MILESTONE_PERCENT+
1 < 10000 AND RESOURCE_TYPE='0' AND TSK_ASSIGNMENT_ID = h_id:
1111:
1           EXCEPTION:: FC_COMMIT_ASSIGN(112) :: cplan.sql(18921) :: :
18:
1118:
1      RETURN_INVALID:: FC_COMMIT_ASSIGN(119) :: cplan.sql(18928) :: :
1RECORD_NOT_FOUND:
1121:
1                EXIT:: FC_COMMIT_ASSIGN(122) :: cplan.sql(18931) :: :
1PMO_RETURN_INVALID:
1ELSIF:
1126:
1        RETURN_ERROR:: FC_COMMIT_ASSIGN(127) :: cplan.sql(18936) :: :
1PROJECT_ASSIGNMENT_EXISTS:
1129:
1                EXIT:: FC_COMMIT_ASSIGN(130) :: cplan.sql(18939) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480) INTO h_min_per_day FROM TMT_WBS WHERE EL+
1EMENT_ID = h_project_id:
1144:
1           EXCEPTION:: FC_COMMIT_ASSIGN(145) :: cplan.sql(18954) :: :
1SELECT TSK_ASSIGNMENT_ID, RESOURCE_ID, TASK_ID, C_EFFORT FROM TASK_ASSIGNMENT+
1S :
1WHERE TSK_ASSIGNMENT_ID = ':
1' AND MILESTONE_PERCENT < 10000 AND RESOURCE_TYPE='0' AND BIT_FLAG = '0' :
13:
1TYPE_ID:
1SC_PROPOSAL:
1SC_PROJECT:
1SCHED_START:
1PLANNED_START:
1SCHED_FINISH:
1PLANNED_FINISH:
1SCHED_DURATION:
1PLANNED_DURATION:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1FORECAST_FINISH:
1FORECAST_EFFORT:
1ETC:
1FORECAST_DURATION:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1ASSIGN_COUNT:
1WORK_TODATE:
1UPDATE TMT_WBS SET:n            TYPE_ID         = CASE WHEN TYPE_ID = pmo_cns+
1t.SC_PROPOSAL THEN pmo_cnst.SC_PROJECT ELSE TYPE_ID END,:n            SCHED_S+
1TART     = COALESCE(PLANNED_START, SCHED_START),:n            SCHED_FINISH   +
1 = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n            SCHED_DURATION  = CAS+
1E WHEN PLANNED_DURATION = 0 THEN SCHED_DURATION ELSE PLANNED_DURATION END,:n +
1           SCHED_EFFORT    = PLANNED_EFFORT,:n            PLANNED_START   = N+
1ull,:n            PLANNED_FINISH  = Null,:n            PLANNED_DURATION = 0,+
1:n            FORECAST_START  = Null,:n            FORECAST_FINISH = Null,:n +
1           FORECAST_EFFORT = PLANNED_EFFORT,:n            ETC             = P+
1LANNED_EFFORT,:n            FORECAST_DURATION = 0:n            WHERE PROJECT_+
1ID = h_project_id AND TYPE_ID IN (pmo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,pmo+
1_cnst.SC_TASK_TYPE2,pmo_cnst.SC_TASK_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.SC_+
1PERSONAL_TASK,pmo_cnst.SC_ACTIVE_ADM_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pmo_c+
1nst.SC_WBS_CHANGE_REQUEST_TASK,pmo_cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.SC_W+
1BS_RISK_TASK,pmo_cnst.SC_WBS_ISSUE_TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,pmo_+
1cnst.SC_WBS_DEFECT_TASK,pmo_cnst.SC_WBS_SERVICE_REQUEST_TASK) AND ASSIGN_COUN+
1T = 0 AND WORK_TODATE = 0 AND SCHED_EFFORT = 0:
1FOUND:
1TRUE:
1100:
1186:
1           EXCEPTION:: FC_COMMIT_ASSIGN(187) :: cplan.sql(18996) :: :
1OPEN:
1LOOP:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
1SCHED_WORK:
1PLANNED_WORK:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1SCHED_LABOR_COST:
1PLANNED_LABOR_COST:
1SCHED_LABOR_REVENUE:
1PLANNED_LABOR_REVENUE:
1FORECAST_LABOR_COST:
1BILLABLE:
1REGULAR_COST:
1ACTUAL_LABOR_COST:
1FORECAST_LABOR_REVENUE:
1REGULAR_RATE:
1ACTUAL_LABOR_REVENUE:
1UPDATE TASK_ASSIGNMENTS SET:n               BIT_FLAG = '2',:n               S+
1CHED_START = COALESCE(PLANNED_START, SCHED_START),:n               SCHED_FINI+
1SH = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n               SCHED_DURATION =+
1 CASE WHEN PLANNED_DURATION > 0 THEN PLANNED_DURATION ELSE SCHED_DURATION END+
1,:n               SCHED_WORK = PLANNED_WORK,:n               ETC = PLANNED_WO+
1RK,:n               BAK_START_DT = COALESCE(PLANNED_START, SCHED_START),:n   +
1            BAK_FINISH_DT = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n        +
1       BAK_WORK = PLANNED_WORK,:n               SCHED_LABOR_COST = CASE WHEN +
1PLANNED_LABOR_COST > 0.00 THEN PLANNED_LABOR_COST ELSE SCHED_LABOR_COST END,+
1:n               SCHED_LABOR_REVENUE = CASE WHEN PLANNED_LABOR_REVENUE > 0.00+
1 THEN PLANNED_LABOR_REVENUE ELSE SCHED_LABOR_REVENUE END,:n               FOR+
1ECAST_LABOR_COST = CASE WHEN BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/6+
10.00) * REGULAR_COST) + ACTUAL_LABOR_COST END,:n               FORECAST_LABOR+
1_REVENUE = CASE WHEN BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * +
1REGULAR_RATE) + ACTUAL_LABOR_REVENUE END,:n               PLANNED_START = Nul+
1l, PLANNED_FINISH = Null, PLANNED_DURATION = 0, PLANNED_WORK = 0,:n          +
1     FORECAST_START = Null, FORECAST_FINISH = Null, FORECAST_DURATION = 0:n  +
1             WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1234:
1           EXCEPTION:: FC_COMMIT_ASSIGN(235) :: cplan.sql(19044) :: :
1UPDATE TASK_DAY_OF_YEAR SET BIT_FLAG = '2':n               WHERE PROJECT_ID =+
1 h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1254:
1           EXCEPTION:: FC_COMMIT_ASSIGN(255) :: cplan.sql(19064) :: :
1CLOSE:
1271:
1           EXCEPTION:: FC_COMMIT_ASSIGN(272) :: cplan.sql(19081) :: :
1ROLLUP_BITS:
1SC_ASSIGNMENT_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = pmo_cnst.SC_ASSIGNMENT_BIT:n         WHERE P+
1ROJECT_ID = h_project_id AND ASSIGN_COUNT > 0 AND WORK_TODATE = 0 AND SCHED_E+
1FFORT = 0:
1292:
1           EXCEPTION:: FC_COMMIT_ASSIGN(293) :: cplan.sql(19102) :: :
12:
1SELECT TSK_ASSIGNMENT_ID, RESOURCE_ID, TASK_ID, C_EFFORT FROM TASK_ASSIGNMENT+
1S WHERE PROJECT_ID = TASK_ID AND :
1PROJECT_ID = ':
1BUDGETS:
1B:
1ESTIMATED_BASELINE3:
1ESTIMATED_BASELINE2:
1ESTIMATED_BASELINE1:
1ESTIMATED_BUDGET:
1BUDGET_BASELINE3:
1BUDGET_BASELINE2:
1BUDGET_BASELINE1:
1BUDGET:
1UPDATE BUDGETS B SET:n               B.ESTIMATED_BASELINE3 = B.ESTIMATED_BASE+
1LINE2,:n               B.ESTIMATED_BASELINE2 = B.ESTIMATED_BASELINE1,:n      +
1         B.ESTIMATED_BASELINE1 = B.ESTIMATED_BUDGET,:n               B.BUDGET+
1_BASELINE3 = B.BUDGET_BASELINE2,:n               B.BUDGET_BASELINE2 = B.BUDGE+
1T_BASELINE1,:n               B.BUDGET_BASELINE1 = B.BUDGET:n               WH+
1ERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1352:
1           EXCEPTION:: FC_COMMIT_ASSIGN(353) :: cplan.sql(19162) :: :
1BASELINE3_START:
1BASELINE2_START:
1BASELINE3_FINISH:
1BASELINE2_FINISH:
1BASELINE3_DURATION:
1BASELINE2_DURATION:
1BASELINE3_WORK:
1BASELINE2_WORK:
1BASELINE3_LABOR_COST:
1BASELINE2_LABOR_COST:
1BASELINE3_LABOR_REVENUE:
1BASELINE2_LABOR_REVENUE:
1BASELINE1_START:
1BASELINE1_FINISH:
1BASELINE1_DURATION:
1BASELINE1_WORK:
1BASELINE1_LABOR_COST:
1BASELINE1_LABOR_REVENUE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1UNRESOLVED_DURATION:
1B_REGULAR_COST:
1B_REGULAR_RATE:
1B_SPECIAL_COST:
1SPECIAL_COST:
1B_SPECIAL_RATE:
1SPECIAL_RATE:
1UPDATE TASK_ASSIGNMENTS TA SET:n               TA.BASELINE3_START = TA.BASELI+
1NE2_START, TA.BASELINE3_FINISH = TA.BASELINE2_FINISH, TA.BASELINE3_DURATION =+
1 TA.BASELINE2_DURATION, TA.BASELINE3_WORK = TA.BASELINE2_WORK,:n             +
1  TA.BASELINE3_LABOR_COST = TA.BASELINE2_LABOR_COST, TA.BASELINE3_LABOR_REVEN+
1UE = TA.BASELINE2_LABOR_REVENUE,:n               TA.BASELINE2_START = TA.BASE+
1LINE1_START, TA.BASELINE2_FINISH = TA.BASELINE1_FINISH, TA.BASELINE2_DURATION+
1 = TA.BASELINE1_DURATION, TA.BASELINE2_WORK = TA.BASELINE1_WORK,:n           +
1    TA.BASELINE2_LABOR_COST = TA.BASELINE1_LABOR_COST, TA.BASELINE2_LABOR_REV+
1ENUE = TA.BASELINE1_LABOR_REVENUE,:n               TA.BASELINE1_START = TA.UN+
1RESOLVED_START, TA.BASELINE1_FINISH = TA.UNRESOLVED_FINISH, TA.BASELINE1_DURA+
1TION = TA.UNRESOLVED_DURATION, TA.BASELINE1_WORK = TA.SCHED_WORK + TA.PLANNED+
1_WORK,:n               TA.BASELINE1_LABOR_COST = TA.SCHED_LABOR_COST + TA.PLA+
1NNED_LABOR_COST, TA.BASELINE1_LABOR_REVENUE = TA.SCHED_LABOR_REVENUE + TA.PLA+
1NNED_LABOR_REVENUE,:n               TA.B_REGULAR_COST = TA.REGULAR_COST, TA.B+
1_REGULAR_RATE = TA.REGULAR_RATE, TA.B_SPECIAL_COST = TA.SPECIAL_COST, TA.B_SP+
1ECIAL_RATE = TA.SPECIAL_RATE:n               WHERE TSK_ASSIGNMENT_ID = h_id:
1380:
1           EXCEPTION:: FC_COMMIT_ASSIGN(381) :: cplan.sql(19190) :: :
1PROJECT_ASSIGNMENTS:
1ESTIMATED_BASELINE3_START:
1ESTIMATED_BASELINE2_START:
1ESTIMATED_BASELINE1_START:
1ESTIMATED_SCHED_START:
1ESTIMATED_PLANNED_START:
1ESTIMATED_BASELINE3_FINISH:
1ESTIMATED_BASELINE2_FINISH:
1ESTIMATED_BASELINE1_FINISH:
1ESTIMATED_SCHED_FINISH:
1ESTIMATED_PLANNED_FINISH:
1ESTIMATED_BASELINE3_EFFORT:
1ESTIMATED_BASELINE2_EFFORT:
1ESTIMATED_BASELINE1_EFFORT:
1ESTIMATED_SCHED_EFFORT:
1ESTIMATED_PLANNED_EFFORT:
1ESTIMATED_BASELINE3_COST:
1ESTIMATED_BASELINE2_COST:
1ESTIMATED_BASELINE1_COST:
1ESTIMATED_SCHED_COST:
1ESTIMATED_PLANNED_COST:
1ESTIMATED_BASELINE3_REVENUE:
1ESTIMATED_BASELINE2_REVENUE:
1ESTIMATED_BASELINE1_REVENUE:
1ESTIMATED_SCHED_REVENUE:
1ESTIMATED_PLANNED_REVENUE:
1BASELINE_START:
1BASELINE_FINISH:
1BASELINE_DURATION:
1BASELINE_WORK:
1BASELINE_LABOR_COST:
1BASELINE_LABOR_REVENUE:
1UPDATE PROJECT_ASSIGNMENTS SET:n               ESTIMATED_BASELINE3_START = ES+
1TIMATED_BASELINE2_START,:n               ESTIMATED_BASELINE2_START = ESTIMATE+
1D_BASELINE1_START,:n               ESTIMATED_BASELINE1_START = CASE WHEN ESTI+
1MATED_SCHED_START IS NOT NULL THEN ESTIMATED_SCHED_START ELSE ESTIMATED_PLANN+
1ED_START END,:n               ESTIMATED_BASELINE3_FINISH = ESTIMATED_BASELINE+
12_FINISH,:n               ESTIMATED_BASELINE2_FINISH = ESTIMATED_BASELINE1_FI+
1NISH,:n               ESTIMATED_BASELINE1_FINISH = CASE WHEN ESTIMATED_SCHED_+
1FINISH IS NOT NULL THEN ESTIMATED_SCHED_FINISH ELSE ESTIMATED_PLANNED_FINISH +
1END,:n               ESTIMATED_BASELINE3_EFFORT = ESTIMATED_BASELINE2_EFFORT,+
1:n               ESTIMATED_BASELINE2_EFFORT = ESTIMATED_BASELINE1_EFFORT,:n  +
1             ESTIMATED_BASELINE1_EFFORT = CASE WHEN ESTIMATED_SCHED_EFFORT > +
10 THEN ESTIMATED_SCHED_EFFORT ELSE ESTIMATED_PLANNED_EFFORT END,:n           +
1    ESTIMATED_BASELINE3_COST = ESTIMATED_BASELINE2_COST,:n               ESTI+
1MATED_BASELINE2_COST = ESTIMATED_BASELINE1_COST,:n               ESTIMATED_BA+
1SELINE1_COST = CASE WHEN ESTIMATED_SCHED_COST > 0.00 THEN ESTIMATED_SCHED_COS+
1T ELSE ESTIMATED_PLANNED_COST END,:n               ESTIMATED_BASELINE3_REVENU+
1E = ESTIMATED_BASELINE2_REVENUE,:n               ESTIMATED_BASELINE2_REVENUE +
1= ESTIMATED_BASELINE1_REVENUE,:n               ESTIMATED_BASELINE1_REVENUE = +
1CASE WHEN ESTIMATED_SCHED_REVENUE > 0.00 THEN ESTIMATED_SCHED_REVENUE ELSE ES+
1TIMATED_PLANNED_REVENUE END,:n               BASELINE_START = UNRESOLVED_STAR+
1T,:n               BASELINE_FINISH = UNRESOLVED_FINISH,:n               BASEL+
1INE_DURATION = UNRESOLVED_DURATION,:n               BASELINE_WORK = SCHED_WOR+
1K + PLANNED_WORK,:n               BASELINE_LABOR_COST = SCHED_LABOR_COST + PL+
1ANNED_LABOR_COST,:n               BASELINE_LABOR_REVENUE = SCHED_LABOR_REVENU+
1E + PLANNED_LABOR_REVENUE:n               WHERE PROJECT_ID = h_project_id:
1421:
1           EXCEPTION:: FC_COMMIT_ASSIGN(422) :: cplan.sql(19231) :: :
1SELECT PLANNED_WORK INTO h_day_min FROM TASK_ASSIGNMENTS WHERE BIT_FLAG = '0'+
1 AND TSK_ASSIGNMENT_ID = h_id:
1442:
1           EXCEPTION:: FC_COMMIT_ASSIGN(443) :: cplan.sql(19252) :: :
1IS NULL:
1CASEEND0000:
1C_EFFORT:
1SELECT TSK_ASSIGNMENT_ID, CASE WHEN C_EFFORT = 0 THEN 0 ELSE C_EFFORT + h_wor+
1k END:n               INTO h_prj_assignment_id, h_work:n               FROM T+
1ASK_ASSIGNMENTS WHERE BIT_FLAG = '2' AND TASK_ID = h_project_id AND RESOURCE_+
1ID = h_res_id:
1463:
1           EXCEPTION:: FC_COMMIT_ASSIGN(464) :: cplan.sql(19273) :: :
1IS NOT NULL:
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_id:
1488:
1           EXCEPTION:: FC_COMMIT_ASSIGN(489) :: cplan.sql(19298) :: :
1EFFORT_WEEK:
1DELETE FROM EFFORT_WEEK WHERE TSK_ASSIGNMENT_ID = h_id:
1507:
1           EXCEPTION:: FC_COMMIT_ASSIGN(508) :: cplan.sql(19317) :: :
1RESOURCE_ASSIGN_ROLES:
1RES_ASSIGNMENT_ID:
1DELETE FROM RESOURCE_ASSIGN_ROLES WHERE RES_ASSIGNMENT_ID = h_id:
1526:
1           EXCEPTION:: FC_COMMIT_ASSIGN(527) :: cplan.sql(19336) :: :
1RESOURCE_ASSIGN_SKILLS:
1DELETE FROM RESOURCE_ASSIGN_SKILLS WHERE RES_ASSIGNMENT_ID = h_id:
1545:
1           EXCEPTION:: FC_COMMIT_ASSIGN(546) :: cplan.sql(19355) :: :
1UTL_RAW:
1BIT_OR:
1UPDATE TASK_DAY_OF_YEAR SET SCHED_MIN = SCHED_MIN + h_day_min,:n             +
1        BIT_SCHED = UTL_RAW.BIT_OR(BIT_SCHED, h_bitID):n                     +
1WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_prj_assignment_id A+
1ND DAY_YEAR = h_dayofyear:
1594:
1           EXCEPTION:: FC_COMMIT_ASSIGN(595) :: cplan.sql(19404) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_id AND DAY_YEAR = h_dayofyear:
1615:
1           EXCEPTION:: FC_COMMIT_ASSIGN(616) :: cplan.sql(19425) :: :
1UPDATE TASK_DAY_OF_YEAR SET TSK_ASSIGNMENT_ID = h_prj_assignment_id WHERE PRO+
1JECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_id AND DAY_YEAR = h_dayofyea+
1r:
1634:
1           EXCEPTION:: FC_COMMIT_ASSIGN(635) :: cplan.sql(19444) :: :
1654:
1           EXCEPTION:: FC_COMMIT_ASSIGN(655) :: cplan.sql(19464) :: :
1670:
1           EXCEPTION:: FC_COMMIT_ASSIGN(671) :: cplan.sql(19480) :: :
1PARENT_ID:
1UPDATE TASK_DAY_OF_YEAR SET BIT_FLAG = '2', PARENT_ID = h_prj_assignment_id:n+
1               WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_id:
1690:
1           EXCEPTION:: FC_COMMIT_ASSIGN(691) :: cplan.sql(19500) :: :
1SD:
1SC_SS:
1FD:
1SC_SF:
1UPDATE TASK_ASSIGNMENTS SET:n                  BIT_FLAG = '2',:n             +
1     SD = pmo_cnst.SC_SS, FD = pmo_cnst.SC_SF,:n                  SCHED_START+
1 = PLANNED_START,:n                  SCHED_FINISH = PLANNED_FINISH,:n        +
1          SCHED_DURATION = PLANNED_DURATION,:n                  SCHED_WORK = +
1PLANNED_WORK,:n                  BAK_START_DT = PLANNED_START,:n             +
1     BAK_FINISH_DT = PLANNED_FINISH,:n                  BAK_WORK = PLANNED_WO+
1RK,:n                  SCHED_LABOR_COST = CASE WHEN PLANNED_LABOR_COST > 0.00+
1 THEN PLANNED_LABOR_COST ELSE SCHED_LABOR_COST END,:n                  SCHED_+
1LABOR_REVENUE = CASE WHEN PLANNED_LABOR_REVENUE > 0.00 THEN PLANNED_LABOR_REV+
1ENUE ELSE SCHED_LABOR_REVENUE END,:n                  ETC = PLANNED_WORK,:n  +
1                FORECAST_LABOR_COST = ((ETC+PLANNED_WORK/60.00) * REGULAR_COS+
1T) + ACTUAL_LABOR_COST,:n                  FORECAST_LABOR_REVENUE = CASE WHEN+
1 BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * REGULAR_RATE) + ACTU+
1AL_LABOR_REVENUE END,:n                  PLANNED_START = NuLL, PLANNED_FINISH+
1 = NuLL, PLANNED_DURATION = 0, PLANNED_WORK = 0,:n                  FORECAST_+
1START = NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION = 0,:n               +
1   PROJECT_ASSIGNMENT_ID = NuLL:n                  WHERE TSK_ASSIGNMENT_ID = +
1h_id AND SCHED_WORK = 0 AND PLANNED_WORK > 0:
1728:
1           EXCEPTION:: FC_COMMIT_ASSIGN(729) :: cplan.sql(19538) :: :
1U_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n                     BIT_FLAG = '2',:n          +
1           SD = pmo_cnst.SC_SS,:n                     FD = pmo_cnst.SC_SF,:n +
1                    SCHED_START = PLANNED_START,:n                     SCHED_+
1FINISH = PLANNED_FINISH,:n                     SCHED_DURATION = PLANNED_DURAT+
1ION,:n                     SCHED_WORK = PLANNED_WORK,:n                     B+
1AK_START_DT = PLANNED_START,:n                     BAK_FINISH_DT = PLANNED_FI+
1NISH,:n                     BAK_WORK = PLANNED_WORK,:n                     SC+
1HED_LABOR_COST = CASE WHEN PLANNED_LABOR_COST > 0.00 THEN PLANNED_LABOR_COST +
1ELSE SCHED_LABOR_COST END,:n                     SCHED_LABOR_REVENUE = CASE W+
1HEN PLANNED_LABOR_REVENUE > 0.00 THEN PLANNED_LABOR_REVENUE ELSE SCHED_LABOR_+
1REVENUE END,:n                     ETC = PLANNED_WORK,:n                     +
1FORECAST_LABOR_COST = ((ETC+PLANNED_WORK/60.00) * REGULAR_COST) + ACTUAL_LABO+
1R_COST,:n                     FORECAST_LABOR_REVENUE = CASE WHEN BILLABLE = 0+
1 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * REGULAR_RATE) + ACTUAL_LABOR_REVE+
1NUE END,:n                     PLANNED_START = NuLL, PLANNED_FINISH = NuLL, P+
1LANNED_DURATION = 0, PLANNED_WORK = 0,:n                     FORECAST_START =+
1 NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION = 0,:n                     P+
1ROJECT_ASSIGNMENT_ID = h_prj_assignment_id:n                     WHERE TSK_AS+
1SIGNMENT_ID = h_tsk_assignment_id:
1787:
1           EXCEPTION:: FC_COMMIT_ASSIGN(788) :: cplan.sql(19597) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = pmo_cnst.SC_ASSIGNMENT_BIT WHERE ELEMENT_ID +
1= h_task_id:
1808:
1           EXCEPTION:: FC_COMMIT_ASSIGN(809) :: cplan.sql(19618) :: :
1824:
1           EXCEPTION:: FC_COMMIT_ASSIGN(825) :: cplan.sql(19634) :: :
1>:
1UPDATE TASK_ASSIGNMENTS SET C_EFFORT = h_work WHERE TSK_ASSIGNMENT_ID = h_prj+
1_assignment_id:
1844:
1           EXCEPTION:: FC_COMMIT_ASSIGN(845) :: cplan.sql(19654) :: :
1BEST:
1SELECT PROJECT_ASSIGNMENT_ID, BEST, SCHED_START, SCHED_FINISH, BILLABLE, REGU+
1LAR_COST, REGULAR_RATE:n                  INTO h_prj_assignment_id, h_sched_w+
1ork, h_start_date, h_finish_date, h_billable, h_reg_cost, h_reg_sale:n       +
1           FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID   = h_prj_assignment+
1_id:
1866:
1           EXCEPTION:: FC_COMMIT_ASSIGN(867) :: cplan.sql(19676) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                     ESTIMATED_PLANNED_START +
1= NuLL,:n                     ESTIMATED_PLANNED_FINISH = NuLL,:n             +
1        ESTIMATED_PLANNED_EFFORT = 0,:n                     ESTIMATED_PLANNED+
1_COST = 0.00,:n                     ESTIMATED_PLANNED_REVENUE = 0.00,:n      +
1               ESTIMATED_SCHED_START = h_start_date,:n                     ES+
1TIMATED_SCHED_FINISH = h_finish_date,:n                     ESTIMATED_SCHED_E+
1FFORT = h_sched_work,:n                     ESTIMATED_SCHED_COST = (h_sched_w+
1ork / 60.0) * h_reg_cost,:n                     ESTIMATED_SCHED_REVENUE = 0.0+
10:n                     WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h_r+
1es_id:
1898:
1           EXCEPTION:: FC_COMMIT_ASSIGN(899) :: cplan.sql(19708) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                     ESTIMATED_PLANNED_START +
1= NuLL,:n                     ESTIMATED_PLANNED_FINISH = NuLL,:n             +
1        ESTIMATED_PLANNED_EFFORT = 0,:n                     ESTIMATED_PLANNED+
1_COST = 0.00,:n                     ESTIMATED_PLANNED_REVENUE = 0.00,:n      +
1               ESTIMATED_SCHED_START = h_start_date,:n                     ES+
1TIMATED_SCHED_FINISH = h_finish_date,:n                     ESTIMATED_SCHED_E+
1FFORT = h_sched_work,:n                     ESTIMATED_SCHED_COST = (h_sched_w+
1ork / 60.0) * h_reg_cost,:n                     ESTIMATED_SCHED_REVENUE = (h_+
1sched_work / 60.0) * h_reg_sale:n                     WHERE PROJECT_ID = h_pr+
1oject_id AND RESOURCE_ID = h_res_id:
1928:
1           EXCEPTION:: FC_COMMIT_ASSIGN(929) :: cplan.sql(19738) :: :
1957:
1           EXCEPTION:: FC_COMMIT_ASSIGN(958) :: cplan.sql(19767) :: :
1975:
1           EXCEPTION:: FC_COMMIT_ASSIGN(976) :: cplan.sql(19785) :: :
1FC_ROLLUP:
1SC_NS:
1SC_NF:
1SELECT CASE WHEN (SD <> pmo_cnst.SC_NS) AND (FD <> pmo_cnst.SC_NF) AND (TYPE_+
1ID = pmo_cnst.SC_PROPOSAL) THEN 1 ELSE 0 END:n      INTO h_change_flag:n     +
1 FROM TMT_WBS WHERE ELEMENT_ID = h_project_id:
1997:
1           EXCEPTION:: FC_COMMIT_ASSIGN(998) :: cplan.sql(19807) :: :
1FC_CHANGE_PROJ_TYPE:
1RESOURCE_ASSIGNMENTS:
1ELEMENT_TYPE:
1UPDATE RESOURCE_ASSIGNMENTS SET:n      ELEMENT_TYPE  = (SELECT TYPE_ID FROM T+
1MT_WBS WHERE ELEMENT_ID = h_project_id):n      WHERE ELEMENT_ID = h_project_i+
1d:
11023:
1           EXCEPTION:: FC_COMMIT_ASSIGN(1024) :: cplan.sql(19833) :: :
11033:
1                EXIT:: FC_COMMIT_ASSIGN(1034) :: cplan.sql(19843) :: :
0

0
0
15cc
2
0 a0 8d 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 51 b0 3d
b4 :2 a0 2c 6a a3 a0 1c a0
81 b0 a3 a0 1c :2 a0 51 a5
b 81 b0 a3 a0 51 a5 1c
:2 a0 6b 81 b0 a3 a0 51 a5
1c :2 a0 6b 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a0 f4 b4 bf c8 :1a a0 12a
bd b7 11 a4 b1 a3 :2 a0 6b
1c 81 b0 a0 f4 b4 bf c8
:9 a0 12a bd b7 11 a4 b1 a0
f4 b4 bf c8 :6 a0 12a bd b7
11 a4 b1 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :8 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 :2 51
a5 b 7e 6e b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
:2 a0 6b :2 a0 a5 b 65 b7 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a :c a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b :2 a0
6b a0 a5 b 65 a0 b7 :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b :2 a0 6b :2 a0
a5 b 65 b7 :2 19 3c :6 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d b7
:2 a0 d :2 a0 51 a5 b 7e 51
b4 2e :44 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 e9 dd b3 :4 a0 e9
d3 5 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 2b b7 19 3c :39 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :6 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 a0
47 :2 a0 e9 c1 :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
51 d a0 51 d a0 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e d b7 :2 19 3c :3 a0
11c 11d :6 a0 e9 d3 5 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 2b b7
19 3c a0 51 :1e a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :62 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3a a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a6 9 51
:6 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 7e b4 2e :2 5a
52 10 a0 3b b7 19 3c :c a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 7e b4 2e :2 5a a
10 :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 51 d
b7 :2 19 3c b7 :2 a0 d a0 51
d b7 :2 19 3c a0 51 d :2 a0
e9 dd b3 :5 a0 e9 d3 5 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a a0 2b
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :7 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :8 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :37 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e a0 51 d :5 a0 :2 51
a5 b d b7 19 3c b7 :2 a0
e9 dd b3 :4 a0 e9 d3 5 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a a0 2b
b7 19 3c :36 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :6 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a0 47 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :5 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
a0 51 d :5 a0 :2 51 a5 b d
:11 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :14 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :16 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :2 19
3c 93 4f b0 46 b7 a6 9
4f b7 9 a4 14 :6 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e 51 b4 2e
:3 a0 a5 b d b7 19 3c :d a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :3 a0 6b d :2 a0 6b :4 a0 a5
b d b7 19 3c :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b 7e
51 b4 2e :2 a0 6b 51 d b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
15cc
2
0 3 7 2b 1f 23 27 1e
32 3f 3b 1b 47 53 4c 50
3a 5b 37 60 64 68 6c 89
74 78 80 84 73 b0 94 98
a0 a4 70 a8 a9 ab 93 d8
bb 90 bf c0 c8 cc d0 d3
ba 100 e3 b7 e7 e8 f0 f4
f8 fb e2 11d 10b df 10f 110
118 10a 139 128 12c 134 107 155
140 144 147 148 150 127 172 160
124 164 165 16d 15f 18f 17d 15c
181 182 18a 17c 1ac 19a 179 19e
19f 1a7 199 1c8 1b7 1bb 1c3 196
1e0 1cf 1d3 1db 1b6 1fc 1eb 1ef
1b3 1f7 1ea 218 207 20b 1e7 213
206 234 223 227 203 22f 222 250
23f 243 21f 24b 23e 26c 25b 25f
23b 267 25a 288 277 27b 257 283
276 2a4 293 297 273 29f 292 2c0
2af 2b3 28f 2bb 2ae 2dc 2cb 2cf
2ab 2d7 2ca 2f8 2e7 2eb 2c7 2f3
2e6 314 303 307 2e3 30f 302 330
31f 323 2ff 32b 31e 34c 33b 33f
31b 347 33a 368 357 35b 337 363
356 385 373 353 377 378 380 372
3a2 390 36f 394 395 39d 38f 3a9
3ad 38c 3be 3c1 3c5 3c9 3cd 3d1
3d5 3d9 3dd 3e1 3e5 3e9 3ed 3f1
3f5 3f9 3fd 401 405 409 40d 411
415 419 41d 421 425 429 42d 439
43e 440 44c 450 46e 456 45a 45e
461 469 455 475 479 452 48a 48d
491 495 499 49d 4a1 4a5 4a9 4ad
4b1 4b5 4c1 4c6 4c8 4d4 4d8 4da
4de 4ef 4f0 4f3 4f7 4fb 4ff 503
507 50b 50f 51b 520 522 52e 532
534 538 53c 53f 543 547 54a 54f
550 1 552 557 55b 55f 562 567
56b 56f 572 577 578 57a 57f 582
586 587 58c 591 594 599 59a 59f
5a2 5a6 5a7 5ac 5af 5b4 5b5 5ba
5bd 5c2 5c3 5c8 5cb 5cf 5d3 5d7
5d8 5da 5df 5e0 5e2 5e3 5e8 5eb
5f0 5f1 5f6 5f9 5fd 601 605 606
608 60d 60e 610 611 616 619 61e
61f 624 625 62a 62c 630 633 637
63b 63e 642 646 649 64c 651 654
657 65a 65b 660 661 1 663 668
66c 670 673 678 67d 680 684 685
68a 68b 690 692 696 699 69d 6a1
6a5 6a9 6ad 6b1 6b5 6b9 6c5 6c9
6cd 6d0 6d4 6d8 6da 6de 6e2 6e6
6e9 6ed 6f1 6f3 6f4 6f9 1 6fd
701 705 708 70c 710 714 718 71b
71f 723 726 729 72e 731 734 737
738 73d 73e 1 740 745 749 74d
750 755 75a 75d 761 762 767 76a
76f 770 775 778 77d 77e 783 786
78a 78b 790 793 798 799 79e 7a1
7a5 7a9 7ac 7af 7b0 7b2 7b3 7b8
7b9 7be 7c0 7c4 7c7 7c9 7cd 7cf
7db 7dd 7df 7e0 7e5 7e9 7eb 7f7
7f9 7fd 801 804 807 808 80a 80d
812 813 818 81c 820 823 827 82b
82e 831 836 839 83c 83f 840 845
846 1 848 84d 851 855 858 85d
862 865 869 86a 86f 872 877 878
87d 880 885 886 88b 88e 892 896
89a 89e 8a1 8a2 8a4 8a9 8aa 8ac
8ad 8b2 8b5 8ba 8bb 8c0 8c3 8c8
8c9 8ce 8d1 8d5 8d6 8db 8de 8e3
8e4 8e9 8ea 8ef 8f1 8f5 8f8 8fc
900 903 907 90b 90e 911 916 919
91c 91f 920 925 926 1 928 92d
931 935 938 93d 942 945 949 94a
94f 950 955 957 95b 95e 962 966
96a 96d 971 975 978 97c 980 981
983 987 989 98d 990 994 998 99b
99f 9a2 9a6 9a9 9aa 9af 9b2 9b6
9ba 9be 9c2 9c6 9ca 9ce 9d2 9d6
9da 9de 9e2 9ee 9f2 9f6 9f9 9fd
a01 a03 a07 a0b a0f a12 a16 a1a
a1c a1d a22 1 a26 a2a a2e a31
a35 a39 a3d a41 a44 a48 a4c a4f
a52 a57 a5a a5d a60 a61 a66 a67
1 a69 a6e a72 a76 a79 a7e a83
a86 a8a a8b a90 a93 a98 a99 a9e
aa1 aa6 aa7 aac aaf ab3 ab4 ab9
abc ac1 ac2 ac7 aca ace ad2 ad5
ad8 ad9 adb adc ae1 ae2 ae7 ae9
aed af0 af2 af6 af8 b04 b06 b08
b09 b0e b12 b14 b20 b22 b26 b2a
b2d b31 b34 b38 b3b b3c b41 b44
b48 b4c b4f b53 b57 b5a b5d b62
b65 b68 b6b b6c b71 b72 1 b74
b79 b7d b81 b84 b89 b8e b91 b95
b96 b9b b9e ba3 ba4 ba9 bac bb1
bb2 bb7 bba bbe bc2 bc6 bca bcd
bce bd0 bd5 bd6 bd8 bd9 bde bdf
be4 be6 bea bed bf1 bf5 bf8 bfc
c00 c03 c06 c0b c0e c11 c14 c15
c1a c1b 1 c1d c22 c26 c2a c2d
c32 c37 c3a c3e c3f c44 c45 c4a
c4c c50 c53 c57 c5b c5f c62 c66
c6a c6d c71 c72 c74 c78 c7c c7e
c82 c86 c89 c8a c8c c8f c92 c93
c98 c9b c9f ca3 ca6 ca7 ca9 cac
caf cb0 cb5 1 cb8 cbd cc1 cc5
cc8 ccc cd0 cd3 cd6 cdb cde ce1
ce4 ce5 cea ceb 1 ced cf2 cf6
cfa cfd d02 d07 d0a d0e d0f d14
d17 d1c d1d d22 d25 d2a d2b d30
d33 d37 d3b d3f d43 d46 d47 d49
d4e d4f d51 d52 d57 d5a d5f d60
d65 d68 d6d d6e d73 d76 d7a d7b
d80 d83 d88 d89 d8e d8f d94 d96
d9a d9d da1 da5 da8 dac db0 db3
db6 dbb dbe dc1 dc4 dc5 dca dcb
1 dcd dd2 dd6 dda ddd de2 de7
dea dee def df4 df5 dfa dfc e00
e03 e07 e0b e0f e12 e16 e1a e1d
e21 e25 e26 e28 e2c e2e e32 e36
e39 e3d e41 e45 e49 e4d e51 e5d
e61 e65 e68 e6c e70 e72 e76 e7a
e7e e81 e85 e89 e8b e8c e91 1
e95 e99 e9d ea0 ea4 ea8 eac eb0
eb3 eb7 ebb ebe ec1 ec6 ec9 ecc
ecf ed0 ed5 ed6 1 ed8 edd ee1
ee5 ee8 eed ef2 ef5 ef9 efa eff
f02 f07 f08 f0d f10 f15 f16 f1b
f1e f22 f23 f28 f2b f30 f31 f36
f39 f3d f41 f44 f47 f48 f4a f4b
f50 f51 f56 f58 f5c f5f f61 f65
f67 f73 f75 f77 f78 f7d f81 f83
f8f f91 f95 f9a f9d fa2 fa3 fa8
fab faf fb0 fb5 fb8 fbd fbe fc3
fc7 fc9 fcd fd1 fd5 fd9 fdd fe0
fe1 fe3 fe6 fe9 fea fef ff3 ff7
ffb fff 1003 1007 100b 100f 1013 1017
101b 101f 1023 1027 102b 102f 1033 1037
103b 103f 1043 1047 104b 104f 1053 1057
105b 105f 1063 1067 106b 106f 1073 1077
107b 107f 1083 1087 108b 108f 1093 1097
109b 109f 10a3 10a7 10ab 10af 10b3 10b7
10bb 10bf 10c3 10c7 10cb 10cf 10d3 10d7
10db 10df 10e3 10e7 10eb 10ef 10f3 10f7
10fb 10ff 110b 110f 1114 1118 111b 111c
1121 1125 1129 112c 112f 1133 1135 1139
113d 1140 1143 1147 1149 114d 1151 1154
1156 115a 115e 1162 1165 1169 116d 116f
1170 1175 1 1179 117d 1181 1184 1188
118c 1190 1194 1197 119b 119f 11a2 11a5
11aa 11ad 11b0 11b3 11b4 11b9 11ba 1
11bc 11c1 11c5 11c9 11cc 11d1 11d6 11d9
11dd 11de 11e3 11e6 11eb 11ec 11f1 11f4
11f9 11fa 11ff 1202 1206 1207 120c 120f
1214 1215 121a 121d 1221 1225 1228 122b
122c 122e 122f 1234 1235 123a 123c 1240
1243 1245 1249 124b 1257 1259 125b 125c
1261 1265 1267 1273 1275 1279 127d 1282
1286 1287 128b 128f 1293 1297 129c 12a1
12a5 12a9 12ad 12b2 12b6 12ba 12bd 12c0
12c4 12c6 12ca 12ce 12d1 12d4 12d8 12da
12de 12e2 12e5 12e9 12ed 12f0 12f4 12f7
12fb 12fe 12ff 1304 1307 130b 1311 1313
1317 131a 131e 1322 1326 132a 132e 1332
1336 133a 133e 1342 1346 134a 134e 1352
1356 135a 135e 1362 1366 136a 136e 1372
1376 137a 137e 1382 1386 138a 138e 1392
1396 139a 139e 13a2 13a6 13aa 13ae 13b2
13b6 13ba 13be 13c2 13c6 13ca 13ce 13d2
13d6 13da 13de 13e2 13e6 13ea 13ee 13f2
13f6 13fa 13fe 140a 140e 1413 1417 141a
141b 1420 1424 1428 142b 142e 1432 1434
1438 143c 143f 1442 1446 1448 144c 1450
1453 1455 1459 145d 1461 1464 1468 146c
146e 146f 1474 1 1478 147c 1480 1483
1487 148b 148f 1493 1496 149a 149e 14a1
14a4 14a9 14ac 14af 14b2 14b3 14b8 14b9
1 14bb 14c0 14c4 14c8 14cb 14d0 14d5
14d8 14dc 14dd 14e2 14e5 14ea 14eb 14f0
14f3 14f8 14f9 14fe 1501 1505 1506 150b
150e 1513 1514 1519 151c 1520 1524 1527
152a 152b 152d 152e 1533 1534 1539 153b
153f 1542 1544 1548 154a 1556 1558 155a
155b 1560 1564 1566 1572 1574 1578 157c
1580 1584 1588 158c 1598 159c 15a1 15a5
15a8 15a9 15ae 15b2 15b6 15b9 15bc 15c0
15c2 15c6 15ca 15cd 15d0 15d4 15d6 15da
15de 15e1 15e3 15e7 15eb 15ef 15f2 15f6
15fa 15fc 15fd 1602 1 1606 160a 160e
1611 1615 1619 161d 1621 1624 1628 162c
162f 1632 1637 163a 163d 1640 1641 1646
1647 1 1649 164e 1652 1656 1659 165e
1663 1666 166a 166b 1670 1673 1678 1679
167e 1681 1686 1687 168c 168f 1693 1694
1699 169c 16a1 16a2 16a7 16aa 16ae 16b2
16b5 16b8 16b9 16bb 16bc 16c1 16c2 16c7
16c9 16cd 16d0 16d2 16d6 16d8 16e4 16e6
16e8 16e9 16ee 16f2 16f4 1700 1702 1704
1708 170f 1713 1717 171c 171e 1722 1726
1729 172d 1731 1733 1737 173b 173f 1742
1746 174a 174c 174d 1752 1 1756 175a
175e 1761 1765 1769 176d 1771 1774 1778
177c 177f 1782 1787 178a 178d 1790 1791
1796 1797 1 1799 179e 17a2 17a6 17a9
17ae 17b3 17b6 17ba 17bb 17c0 17c3 17c8
17c9 17ce 17d1 17d6 17d7 17dc 17df 17e3
17e4 17e9 17ec 17f1 17f2 17f7 17fa 17fe
1802 1805 1808 1809 180b 180c 1811 1812
1817 1819 181d 1820 1822 1826 1828 1834
1836 1838 1839 183e 1842 1844 1850 1852
1854 1858 185b 185f 1863 1867 186b 186f
1873 1877 187b 187f 188b 188f 1894 1898
189b 189c 18a1 18a5 18a9 18ac 18af 18b3
18b5 18b9 18bd 18c0 18c3 18c7 18c9 18cd
18d1 18d4 18d6 18da 18de 18e2 18e5 18e9
18ed 18ef 18f0 18f5 1 18f9 18fd 1901
1904 1908 190c 1910 1914 1917 191b 191f
1922 1925 192a 192d 1930 1933 1934 1939
193a 1 193c 1941 1945 1949 194c 1951
1956 1959 195d 195e 1963 1966 196b 196c
1971 1974 1979 197a 197f 1982 1986 1987
198c 198f 1994 1995 199a 199d 19a1 19a5
19a8 19ab 19ac 19ae 19af 19b4 19b5 19ba
19bc 19c0 19c3 19c5 19c9 19cb 19d7 19d9
19db 19dc 19e1 19e5 19e7 19f3 19f5 19f9
19fc 1a00 1a04 1a07 1a0b 1a0f 1a14 1a17
1a1c 1a1d 1a22 1a25 1a29 1a2a 1a2f 1a32
1a37 1a38 1a3d 1a41 1a43 1a47 1a4b 1a4e
1a52 1a56 1a5a 1a5d 1a61 1a65 1a69 1a6d
1a71 1a75 1a79 1a7e 1a83 1a87 1a8b 1a8f
1a94 1a98 1a9c 1a9f 1aa2 1aa6 1aa8 1aac
1ab0 1ab3 1ab6 1aba 1abc 1ac0 1ac4 1ac7
1acb 1acf 1ad2 1ad6 1ad9 1add 1ae0 1ae1
1ae6 1ae9 1aed 1af3 1af5 1af9 1afc 1b00
1b03 1b07 1b0b 1b0f 1b13 1b17 1b1b 1b1f
1b23 1b27 1b2b 1b2f 1b33 1b37 1b3b 1b3f
1b43 1b47 1b4b 1b4f 1b53 1b57 1b5b 1b5f
1b63 1b67 1b6b 1b6f 1b73 1b77 1b7b 1b87
1b8b 1b90 1b94 1b97 1b98 1b9d 1ba1 1ba5
1ba8 1bab 1baf 1bb1 1bb5 1bb9 1bbc 1bbf
1bc3 1bc5 1bc9 1bcd 1bd0 1bd2 1bd6 1bda
1bde 1be1 1be5 1be9 1beb 1bec 1bf1 1
1bf5 1bf9 1bfd 1c00 1c04 1c08 1c0c 1c10
1c13 1c17 1c1b 1c1e 1c21 1c26 1c29 1c2c
1c2f 1c30 1c35 1c36 1 1c38 1c3d 1c41
1c45 1c48 1c4d 1c52 1c55 1c59 1c5a 1c5f
1c62 1c67 1c68 1c6d 1c70 1c75 1c76 1c7b
1c7e 1c82 1c83 1c88 1c8b 1c90 1c91 1c96
1c99 1c9d 1ca1 1ca4 1ca7 1ca8 1caa 1cab
1cb0 1cb1 1cb6 1cb8 1cbc 1cbf 1cc1 1cc5
1cc7 1cd3 1cd5 1cd7 1cd8 1cdd 1ce1 1ce3
1cef 1cf1 1cf5 1cf9 1cfd 1d01 1d05 1d09
1d0d 1d11 1d15 1d19 1d1d 1d21 1d25 1d29
1d2d 1d31 1d35 1d39 1d3d 1d41 1d45 1d49
1d4d 1d51 1d55 1d59 1d5d 1d61 1d65 1d69
1d6d 1d71 1d75 1d79 1d7d 1d81 1d85 1d89
1d8d 1d91 1d95 1d99 1d9d 1da1 1da5 1da9
1dad 1db1 1db5 1db9 1dbd 1dc1 1dc5 1dc9
1dcd 1dd1 1dd5 1dd9 1ddd 1de1 1de5 1de9
1ded 1df1 1df5 1df9 1dfd 1e01 1e05 1e09
1e0d 1e11 1e15 1e19 1e1d 1e21 1e25 1e29
1e2d 1e31 1e35 1e39 1e3d 1e41 1e45 1e49
1e4d 1e51 1e55 1e59 1e5d 1e61 1e65 1e69
1e6d 1e71 1e75 1e79 1e85 1e89 1e8e 1e92
1e95 1e96 1e9b 1e9f 1ea3 1ea6 1ea9 1ead
1eaf 1eb3 1eb7 1eba 1ebd 1ec1 1ec3 1ec7
1ecb 1ece 1ed0 1ed4 1ed8 1edc 1edf 1ee3
1ee7 1ee9 1eea 1eef 1 1ef3 1ef7 1efb
1efe 1f02 1f06 1f0a 1f0e 1f11 1f15 1f19
1f1c 1f1f 1f24 1f27 1f2a 1f2d 1f2e 1f33
1f34 1 1f36 1f3b 1f3f 1f43 1f46 1f4b
1f50 1f53 1f57 1f58 1f5d 1f60 1f65 1f66
1f6b 1f6e 1f73 1f74 1f79 1f7c 1f80 1f81
1f86 1f89 1f8e 1f8f 1f94 1f97 1f9b 1f9f
1fa2 1fa5 1fa6 1fa8 1fa9 1fae 1faf 1fb4
1fb6 1fba 1fbd 1fbf 1fc3 1fc5 1fd1 1fd3
1fd5 1fd6 1fdb 1fdf 1fe1 1fed 1fef 1ff3
1ff7 1ffb 1fff 2003 2007 200b 200f 2013
2017 201b 201f 2023 2027 202b 202f 2033
2037 203b 203f 2043 2047 204b 204f 2053
2057 205b 205f 2063 2067 206b 206f 2073
2077 207b 207f 2083 2087 208b 208f 2093
2097 209b 209f 20a3 20a7 20ab 20af 20b3
20b7 20bb 20bf 20c3 20c7 20cb 20cf 20d3
20d7 20e3 20e7 20ec 20f0 20f3 20f4 20f9
20fd 2101 2104 2107 210b 210d 2111 2115
2118 211b 211f 2121 2125 2129 212c 212e
2132 2136 213a 213d 2141 2145 2147 2148
214d 1 2151 2155 2159 215c 2160 2164
2168 216c 216f 2173 2177 217a 217d 2182
2185 2188 218b 218c 2191 2192 1 2194
2199 219d 21a1 21a4 21a9 21ae 21b1 21b5
21b6 21bb 21be 21c3 21c4 21c9 21cc 21d1
21d2 21d7 21da 21de 21df 21e4 21e7 21ec
21ed 21f2 21f5 21f9 21fd 2200 2203 2204
2206 2207 220c 220d 2212 2214 2218 221b
221d 2221 2223 222f 2231 2233 2234 2239
223d 223f 224b 224d 224f 2250 2255 2258
225c 2260 2264 2268 226c 2270 227c 2280
2284 2287 228b 228f 2291 2295 2299 229d
22a0 22a4 22a8 22aa 22ab 22b0 1 22b4
22b8 22bc 22bf 22c3 22c7 22cb 22cf 22d2
22d6 22da 22dd 22e0 22e5 22e8 22eb 22ee
22ef 22f4 22f5 1 22f7 22fc 2300 2304
2307 230c 2311 2314 2318 2319 231e 2321
2326 2327 232c 232f 2334 2335 233a 233d
2341 2342 2347 234a 234f 2350 2355 2358
235c 2360 2363 2366 2367 2369 236a 236f
2370 2375 2377 237b 237e 2380 2384 2386
2392 2394 2396 2397 239c 23a0 23a2 23ae
23b0 23b4 23b8 23bb 23bf 23c2 23c6 23c9
23ca 23cf 23d2 23d6 23d9 23da 23df 23e2
1 23e5 23ea 23ee 23f4 23f6 23fa 23fd
2401 2405 2409 240d 2411 2415 2419 241d
2421 2425 2429 242d 2439 243d 2441 2444
2448 244c 244e 2452 2456 245a 245d 2461
2465 2467 2468 246d 1 2471 2475 2479
247c 2480 2484 2488 248c 248f 2493 2497
249a 249d 24a2 24a5 24a8 24ab 24ac 24b1
24b2 1 24b4 24b9 24bd 24c1 24c4 24c9
24ce 24d1 24d5 24d6 24db 24de 24e3 24e4
24e9 24ec 24f1 24f2 24f7 24fa 24fe 24ff
2504 2507 250c 250d 2512 2515 2519 251d
2520 2523 2524 2526 2527 252c 252d 2532
2534 2538 253b 253d 2541 2543 254f 2551
2553 2554 2559 255d 255f 256b 256d 2571
2575 2578 257c 257f 2583 2586 2587 258c
258f 2593 2596 2597 259c 259f 1 25a2
25a7 25ab 25af 25b2 25b3 25b5 25b8 25bb
25bc 25c1 25c5 25c8 25cc 25ce 25d2 25d6
25da 25e6 25ea 25ef 25f3 25f6 25f7 25fc
2600 2604 2607 260a 260e 2610 2614 2618
261b 261e 2622 2624 2628 262c 262f 2631
2635 2639 263d 2640 2644 2648 264a 264b
2650 1 2654 2658 265c 265f 2663 2667
266b 266f 2672 2676 267a 267d 2680 2685
2688 268b 268e 268f 2694 2695 1 2697
269c 26a0 26a4 26a7 26ac 26b1 26b4 26b8
26b9 26be 26c1 26c6 26c7 26cc 26cf 26d4
26d5 26da 26dd 26e1 26e2 26e7 26ea 26ef
26f0 26f5 26f8 26fc 2700 2703 2706 2707
2709 270a 270f 2710 2715 2717 271b 271e
2720 2724 2726 2732 2734 2736 2737 273c
2740 2742 274e 2750 2754 2758 275c 2768
276c 2771 2775 2778 2779 277e 2782 2786
2789 278c 2790 2792 2796 279a 279d 27a0
27a4 27a6 27aa 27ae 27b1 27b3 27b7 27bb
27bf 27c2 27c6 27ca 27cc 27cd 27d2 1
27d6 27da 27de 27e1 27e5 27e9 27ed 27f1
27f4 27f8 27fc 27ff 2802 2807 280a 280d
2810 2811 2816 2817 1 2819 281e 2822
2826 2829 282e 2833 2836 283a 283b 2840
2843 2848 2849 284e 2851 2856 2857 285c
285f 2863 2864 2869 286c 2871 2872 2877
287a 287e 2882 2885 2888 2889 288b 288c
2891 2892 2897 2899 289d 28a0 28a2 28a6
28a8 28b4 28b6 28b8 28b9 28be 28c2 28c4
28d0 28d2 28d6 28da 28de 28ea 28ee 28f3
28f7 28fa 28fb 2900 2904 2908 290b 290e
2912 2914 2918 291c 291f 2922 2926 2928
292c 2930 2933 2935 2939 293d 2941 2944
2948 294c 294e 294f 2954 1 2958 295c
2960 2963 2967 296b 296f 2973 2976 297a
297e 2981 2984 2989 298c 298f 2992 2993
2998 2999 1 299b 29a0 29a4 29a8 29ab
29b0 29b5 29b8 29bc 29bd 29c2 29c5 29ca
29cb 29d0 29d3 29d8 29d9 29de 29e1 29e5
29e6 29eb 29ee 29f3 29f4 29f9 29fc 2a00
2a04 2a07 2a0a 2a0b 2a0d 2a0e 2a13 2a14
2a19 2a1b 2a1f 2a22 2a24 2a28 2a2a 2a36
2a38 2a3a 2a3b 2a40 2a44 2a46 2a52 2a54
2a58 2a5c 2a60 2a6c 2a70 2a75 2a79 2a7c
2a7d 2a82 2a86 2a8a 2a8d 2a90 2a94 2a96
2a9a 2a9e 2aa1 2aa4 2aa8 2aaa 2aae 2ab2
2ab5 2ab7 2abb 2abf 2ac3 2ac6 2aca 2ace
2ad0 2ad1 2ad6 1 2ada 2ade 2ae2 2ae5
2ae9 2aed 2af1 2af5 2af8 2afc 2b00 2b03
2b06 2b0b 2b0e 2b11 2b14 2b15 2b1a 2b1b
1 2b1d 2b22 2b26 2b2a 2b2d 2b32 2b37
2b3a 2b3e 2b3f 2b44 2b47 2b4c 2b4d 2b52
2b55 2b5a 2b5b 2b60 2b63 2b67 2b68 2b6d
2b70 2b75 2b76 2b7b 2b7e 2b82 2b86 2b89
2b8c 2b8d 2b8f 2b90 2b95 2b96 2b9b 2b9d
2ba1 2ba4 2ba6 2baa 2bac 2bb8 2bba 2bbc
2bbd 2bc2 2bc6 2bc8 2bd4 2bd6 2bda 2bdd
2be1 2be3 2be7 2beb 2bee 2bf0 2bf4 2bf8
2bfc 2c00 2c03 2c07 2c09 2c0d 2c11 2c14
2c18 2c1b 2c1f 2c23 2c27 2c2c 2c30 2c31
2c35 2c39 2c3d 2c41 2c45 2c4a 2c4f 2c53
2c57 2c5b 2c60 2c64 2c68 2c6b 2c6e 2c72
2c74 2c78 2c7c 2c7f 2c82 2c86 2c88 2c8c
2c90 2c93 2c97 2c9b 2c9e 2ca2 2ca5 2ca9
2cac 2cad 2cb2 2cb5 2cb9 2cbf 2cc1 2cc5
2cc8 2ccc 2cd0 2cd3 2cd4 2cd6 2cd9 2cdc
2cdd 2ce2 2ce6 2cea 2cee 2cf2 2cf6 2cfa
2cfe 2d02 2d06 2d0a 2d0e 2d12 2d16 2d1a
2d1e 2d2a 2d2e 2d33 2d37 2d3a 2d3b 2d40
2d44 2d48 2d4b 2d4e 2d52 2d54 2d58 2d5c
2d5f 2d62 2d66 2d68 2d6c 2d70 2d73 2d75
2d79 2d7d 2d81 2d84 2d88 2d8c 2d8e 2d8f
2d94 1 2d98 2d9c 2da0 2da3 2da7 2dab
2daf 2db3 2db6 2dba 2dbe 2dc1 2dc4 2dc9
2dcc 2dcf 2dd2 2dd3 2dd8 2dd9 1 2ddb
2de0 2de4 2de8 2deb 2df0 2df5 2df8 2dfc
2dfd 2e02 2e05 2e0a 2e0b 2e10 2e13 2e18
2e19 2e1e 2e21 2e25 2e26 2e2b 2e2e 2e33
2e34 2e39 2e3c 2e40 2e44 2e47 2e4a 2e4b
2e4d 2e4e 2e53 2e54 2e59 2e5b 2e5f 2e62
2e64 2e68 2e6a 2e76 2e78 2e7a 2e7b 2e80
2e84 2e86 2e92 2e94 2e98 2e9c 2e9f 2ea3
2ea6 2eaa 2ead 2eae 2eb3 2eb6 2eba 2ebe
2ec2 2ec6 2eca 2ece 2ed2 2ede 2ee2 2ee7
2eeb 2eee 2eef 2ef4 2ef8 2efc 2eff 2f02
2f06 2f08 2f0c 2f10 2f13 2f16 2f1a 2f1c
2f20 2f24 2f27 2f29 2f2d 2f31 2f35 2f38
2f3c 2f40 2f42 2f43 2f48 1 2f4c 2f50
2f54 2f57 2f5b 2f5f 2f63 2f67 2f6a 2f6e
2f72 2f75 2f78 2f7d 2f80 2f83 2f86 2f87
2f8c 2f8d 1 2f8f 2f94 2f98 2f9c 2f9f
2fa4 2fa9 2fac 2fb0 2fb1 2fb6 2fb9 2fbe
2fbf 2fc4 2fc7 2fcc 2fcd 2fd2 2fd5 2fd9
2fda 2fdf 2fe2 2fe7 2fe8 2fed 2ff0 2ff4
2ff8 2ffb 2ffe 2fff 3001 3002 3007 3008
300d 300f 3013 3016 3018 301c 301e 302a
302c 302e 302f 3034 3038 303a 3046 3048
304a 304e 3052 3056 305a 305e 3062 3066
306a 306e 307a 307e 3083 3087 308a 308b
3090 3094 3098 309b 309e 30a2 30a4 30a8
30ac 30af 30b2 30b6 30b8 30bc 30c0 30c3
30c5 30c9 30cd 30d1 30d4 30d8 30dc 30de
30df 30e4 1 30e8 30ec 30f0 30f3 30f7
30fb 30ff 3103 3106 310a 310e 3111 3114
3119 311c 311f 3122 3123 3128 3129 1
312b 3130 3134 3138 313b 3140 3145 3148
314c 314d 3152 3155 315a 315b 3160 3163
3168 3169 316e 3171 3175 3176 317b 317e
3183 3184 3189 318c 3190 3194 3197 319a
319b 319d 319e 31a3 31a4 31a9 31ab 31af
31b2 31b4 31b8 31ba 31c6 31c8 31ca 31cb
31d0 31d4 31d6 31e2 31e4 31e6 31ea 31ee
31f1 31f5 31f7 31fb 31ff 3202 3203 3205
3208 320b 320c 3211 3215 3219 321d 3221
3225 3229 322d 3231 3235 3241 3245 324a
324e 3251 3252 3257 325b 325f 3262 3265
3269 326b 326f 3273 3276 3279 327d 327f
3283 3287 328a 328c 3290 3294 3298 329b
329f 32a3 32a5 32a6 32ab 1 32af 32b3
32b7 32ba 32be 32c2 32c6 32ca 32cd 32d1
32d5 32d8 32db 32e0 32e3 32e6 32e9 32ea
32ef 32f0 1 32f2 32f7 32fb 32ff 3302
3307 330c 330f 3313 3314 3319 331c 3321
3322 3327 332a 332f 3330 3335 3338 333c
333d 3342 3345 334a 334b 3350 3353 3357
335b 335e 3361 3362 3364 3365 336a 336b
3370 3372 3376 3379 337b 337f 3381 338d
338f 3391 3392 3397 339b 339d 33a9 33ab
33ad 33b1 33b5 33b8 33ba 33be 33c5 33c9
33cd 33d2 33d4 33d8 33dc 33df 33e3 33e7
33e9 33ed 33f1 33f5 33f8 33fc 3400 3402
3403 3408 1 340c 3410 3414 3417 341b
341f 3423 3427 342a 342e 3432 3435 3438
343d 3440 3443 3446 3447 344c 344d 1
344f 3454 3458 345c 345f 3464 3469 346c
3470 3471 3476 3479 347e 347f 3484 3487
348c 348d 3492 3495 3499 349a 349f 34a2
34a7 34a8 34ad 34b0 34b4 34b8 34bb 34be
34bf 34c1 34c2 34c7 34c8 34cd 34cf 34d3
34d6 34d8 34dc 34de 34ea 34ec 34ee 34ef
34f4 34f8 34fa 3506 3508 350c 3510 3514
3518 351c 3520 3524 3528 3534 3538 353d
3541 3544 3545 354a 354e 3552 3555 3558
355c 355e 3562 3566 3569 356c 3570 3572
3576 357a 357d 357f 3583 3587 358b 358e
3592 3596 3598 3599 359e 1 35a2 35a6
35aa 35ad 35b1 35b5 35b9 35bd 35c0 35c4
35c8 35cb 35ce 35d3 35d6 35d9 35dc 35dd
35e2 35e3 1 35e5 35ea 35ee 35f2 35f5
35fa 35ff 3602 3606 3607 360c 360f 3614
3615 361a 361d 3622 3623 3628 362b 362f
3630 3635 3638 363d 363e 3643 3646 364a
364e 3651 3654 3655 3657 3658 365d 365e
3663 3665 3669 366c 366e 3672 3674 3680
3682 3684 3685 368a 368e 3690 369c 369e
36a2 36a6 36a9 36aa 36ac 36af 36b2 36b3
36b8 36bc 36c0 36c4 36c8 36cc 36d0 36d4
36d8 36dc 36e0 36e4 36e8 36ec 36f0 36f4
36f8 36fc 3700 3704 3708 370c 3710 3714
3718 371c 3720 3724 3728 372c 3730 3734
3738 373c 3740 3744 3748 374c 3750 3754
3758 375c 3760 3764 3768 376c 3770 3774
3778 377c 3780 3784 3788 378c 3790 3794
37a0 37a4 37a9 37ad 37b0 37b1 37b6 37ba
37be 37c1 37c4 37c8 37ca 37ce 37d2 37d5
37d8 37dc 37de 37e2 37e6 37e9 37eb 37ef
37f3 37f7 37fa 37fe 3802 3804 3805 380a
1 380e 3812 3816 3819 381d 3821 3825
3829 382c 3830 3834 3837 383a 383f 3842
3845 3848 3849 384e 384f 1 3851 3856
385a 385e 3861 3866 386b 386e 3872 3873
3878 387b 3880 3881 3886 3889 388e 388f
3894 3897 389b 389c 38a1 38a4 38a9 38aa
38af 38b2 38b6 38ba 38bd 38c0 38c1 38c3
38c4 38c9 38ca 38cf 38d1 38d5 38d8 38da
38de 38e0 38ec 38ee 38f0 38f1 38f6 38fa
38fc 3908 390a 390e 3912 3915 3916 3918
391b 391e 391f 3924 3928 392b 392f 3933
3937 393b 393f 3943 3946 3949 394a 394c
3950 3952 3956 3959 395b 395f 3963 3968
396c 396d 3971 3975 3979 397d 3982 3987
398b 398f 3993 3998 399c 39a0 39a3 39a6
39aa 39ac 39b0 39b4 39b7 39ba 39be 39c0
39c4 39c8 39cb 39cf 39d3 39d6 39da 39dd
39e1 39e4 39e5 39ea 39ed 39f1 39f7 39f9
39fd 3a00 3a04 3a08 3a0c 3a10 3a14 3a18
3a1c 3a20 3a24 3a28 3a2c 3a30 3a34 3a38
3a3c 3a40 3a44 3a48 3a4c 3a50 3a54 3a58
3a5c 3a60 3a64 3a68 3a6c 3a70 3a74 3a78
3a7c 3a80 3a84 3a88 3a8c 3a90 3a94 3a98
3a9c 3aa0 3aa4 3aa8 3aac 3ab0 3ab4 3ab8
3abc 3ac0 3ac4 3ac8 3acc 3ad0 3ad4 3ad8
3ae4 3ae8 3aed 3af1 3af4 3af5 3afa 3afe
3b02 3b05 3b08 3b0c 3b0e 3b12 3b16 3b19
3b1c 3b20 3b22 3b26 3b2a 3b2d 3b2f 3b33
3b37 3b3b 3b3e 3b42 3b46 3b48 3b49 3b4e
1 3b52 3b56 3b5a 3b5d 3b61 3b65 3b69
3b6d 3b70 3b74 3b78 3b7b 3b7e 3b83 3b86
3b89 3b8c 3b8d 3b92 3b93 1 3b95 3b9a
3b9e 3ba2 3ba5 3baa 3baf 3bb2 3bb6 3bb7
3bbc 3bbf 3bc4 3bc5 3bca 3bcd 3bd2 3bd3
3bd8 3bdb 3bdf 3be0 3be5 3be8 3bed 3bee
3bf3 3bf6 3bfa 3bfe 3c01 3c04 3c05 3c07
3c08 3c0d 3c0e 3c13 3c15 3c19 3c1c 3c1e
3c22 3c24 3c30 3c32 3c34 3c35 3c3a 3c3e
3c40 3c4c 3c4e 3c52 3c56 3c5a 3c5e 3c62
3c66 3c72 3c76 3c7b 3c7f 3c82 3c83 3c88
3c8c 3c90 3c93 3c96 3c9a 3c9c 3ca0 3ca4
3ca7 3caa 3cae 3cb0 3cb4 3cb8 3cbb 3cbd
3cc1 3cc5 3cc9 3ccc 3cd0 3cd4 3cd6 3cd7
3cdc 1 3ce0 3ce4 3ce8 3ceb 3cef 3cf3
3cf7 3cfb 3cfe 3d02 3d06 3d09 3d0c 3d11
3d14 3d17 3d1a 3d1b 3d20 3d21 1 3d23
3d28 3d2c 3d30 3d33 3d38 3d3d 3d40 3d44
3d45 3d4a 3d4d 3d52 3d53 3d58 3d5b 3d60
3d61 3d66 3d69 3d6d 3d6e 3d73 3d76 3d7b
3d7c 3d81 3d84 3d88 3d8c 3d8f 3d92 3d93
3d95 3d96 3d9b 3d9c 3da1 3da3 3da7 3daa
3dac 3db0 3db2 3dbe 3dc0 3dc2 3dc3 3dc8
3dcc 3dce 3dda 3ddc 3dde 3de2 3de9 3ded
3df1 3df6 3df8 3dfc 3e00 3e03 3e07 3e0b
3e0d 3e11 3e15 3e19 3e1c 3e20 3e24 3e26
3e27 3e2c 1 3e30 3e34 3e38 3e3b 3e3f
3e43 3e47 3e4b 3e4e 3e52 3e56 3e59 3e5c
3e61 3e64 3e67 3e6a 3e6b 3e70 3e71 1
3e73 3e78 3e7c 3e80 3e83 3e88 3e8d 3e90
3e94 3e95 3e9a 3e9d 3ea2 3ea3 3ea8 3eab
3eb0 3eb1 3eb6 3eb9 3ebd 3ebe 3ec3 3ec6
3ecb 3ecc 3ed1 3ed4 3ed8 3edc 3edf 3ee2
3ee3 3ee5 3ee6 3eeb 3eec 3ef1 3ef3 3ef7
3efa 3efc 3f00 3f02 3f0e 3f10 3f12 3f13
3f18 3f1c 3f1e 3f2a 3f2c 3f30 3f34 3f37
3f38 3f3a 3f3d 3f40 3f41 3f46 3f49 3f4d
3f51 3f54 3f55 3f57 3f5a 3f5d 3f5e 3f63
1 3f66 3f6b 3f6f 3f73 3f77 3f7b 3f7f
3f8b 3f8f 3f94 3f98 3f9b 3f9c 3fa1 3fa5
3fa9 3fac 3faf 3fb3 3fb5 3fb9 3fbd 3fc0
3fc3 3fc7 3fc9 3fcd 3fd1 3fd4 3fd6 3fda
3fde 3fe2 3fe5 3fe9 3fed 3fef 3ff0 3ff5
1 3ff9 3ffd 4001 4004 4008 400c 4010
4014 4017 401b 401f 4022 4025 402a 402d
4030 4033 4034 4039 403a 1 403c 4041
4045 4049 404c 4051 4056 4059 405d 405e
4063 4066 406b 406c 4071 4074 4079 407a
407f 4082 4086 4087 408c 408f 4094 4095
409a 409d 40a1 40a5 40a8 40ab 40ac 40ae
40af 40b4 40b5 40ba 40bc 40c0 40c3 40c5
40c9 40cb 40d7 40d9 40db 40dc 40e1 40e5
40e7 40f3 40f5 40f7 40fb 40fe 4102 4105
4109 410d 4111 4115 4119 411d 4120 4123
4124 4126 412a 412e 4132 4136 413a 413e
4142 4146 414a 414e 4152 4156 415a 415e
4162 4166 416a 416e 417a 417e 4182 4185
4189 418d 418f 4193 4197 419b 419e 41a2
41a6 41a8 41a9 41ae 1 41b2 41b6 41ba
41bd 41c1 41c5 41c9 41cd 41d0 41d4 41d8
41db 41de 41e3 41e6 41e9 41ec 41ed 41f2
41f3 1 41f5 41fa 41fe 4202 4205 420a
420f 4212 4216 4217 421c 421f 4224 4225
422a 422d 4232 4233 4238 423b 423f 4240
4245 4248 424d 424e 4253 4256 425a 425e
4261 4264 4265 4267 4268 426d 426e 4273
4275 4279 427c 427e 4282 4284 4290 4292
4294 4295 429a 429e 42a0 42ac 42ae 42b2
42b6 42b9 42ba 42bc 42bf 42c2 42c3 42c8
42cc 42d0 42d4 42d8 42dc 42e0 42e4 42e8
42ec 42f0 42f4 42f8 42fc 4300 4304 4308
430c 4310 4314 4318 4324 4328 432d 4331
4334 4335 433a 433e 4342 4345 4348 434c
434e 4352 4356 4359 435c 4360 4362 4366
436a 436d 436f 4373 4377 437b 437e 4382
4386 4388 4389 438e 1 4392 4396 439a
439d 43a1 43a5 43a9 43ad 43b0 43b4 43b8
43bb 43be 43c3 43c6 43c9 43cc 43cd 43d2
43d3 1 43d5 43da 43de 43e2 43e5 43ea
43ef 43f2 43f6 43f7 43fc 43ff 4404 4405
440a 440d 4412 4413 4418 441b 441f 4420
4425 4428 442d 442e 4433 4436 443a 443e
4441 4444 4445 4447 4448 444d 444e 4453
4455 4459 445c 445e 4462 4464 4470 4472
4474 4475 447a 447e 4480 448c 448e 4490
4494 4498 449c 44a0 44a4 44a8 44ac 44b0
44b4 44b8 44bc 44c0 44c4 44c8 44cc 44d0
44d4 44d8 44dc 44e0 44e4 44e8 44f4 44f8
44fd 4501 4504 4505 450a 450e 4512 4515
4518 451c 451e 4522 4526 4529 452c 4530
4532 4536 453a 453d 453f 4543 4547 454b
454e 4552 4556 4558 4559 455e 1 4562
4566 456a 456d 4571 4575 4579 457d 4580
4584 4588 458b 458e 4593 4596 4599 459c
459d 45a2 45a3 1 45a5 45aa 45ae 45b2
45b5 45ba 45bf 45c2 45c6 45c7 45cc 45cf
45d4 45d5 45da 45dd 45e2 45e3 45e8 45eb
45ef 45f0 45f5 45f8 45fd 45fe 4603 4606
460a 460e 4611 4614 4615 4617 4618 461d
461e 4623 4625 4629 462c 462e 4632 4634
4640 4642 4644 4645 464a 464e 4650 465c
465e 4660 4664 4668 466b 466d 4671 4675
4678 4680 4682 4683 4686 4688 4689 468e
4690 4692 4697 469b 46a0 46a4 46a8 46ac
46b0 46b4 46b8 46c4 46c8 46cd 46d1 46d4
46d5 46da 46de 46e2 46e5 46e8 46ec 46ee
46f2 46f6 46f9 46fc 4700 4702 4706 470a
470d 470f 4713 4717 471b 471e 4722 4726
4728 4729 472e 1 4732 4736 473a 473d
4741 4745 4749 474d 4750 4754 4758 475b
475e 4763 4766 4769 476c 476d 4772 4773
1 4775 477a 477e 4782 4785 478a 478f
4792 4796 4797 479c 479f 47a4 47a5 47aa
47ad 47b2 47b3 47b8 47bb 47bf 47c0 47c5
47c8 47cd 47ce 47d3 47d6 47da 47de 47e1
47e4 47e5 47e7 47e8 47ed 47ee 47f3 47f5
47f9 47fc 47fe 4802 4804 4810 4812 4814
4815 481a 481e 4820 482c 482e 4830 4834
483b 483f 4843 4848 484a 484e 4852 4855
4859 485d 485f 4863 4867 486b 486e 4872
4876 4878 4879 487e 1 4882 4886 488a
488d 4891 4895 4899 489d 48a0 48a4 48a8
48ab 48ae 48b3 48b6 48b9 48bc 48bd 48c2
48c3 1 48c5 48ca 48ce 48d2 48d5 48da
48df 48e2 48e6 48e7 48ec 48ef 48f4 48f5
48fa 48fd 4902 4903 4908 490b 490f 4910
4915 4918 491d 491e 4923 4926 492a 492e
4931 4934 4935 4937 4938 493d 493e 4943
4945 4949 494c 494e 4952 4954 4960 4962
4964 4965 496a 496e 4970 497c 497e 4982
4985 4988 4989 498e 4992 4996 499a 499b
499d 49a1 49a3 49a7 49aa 49ae 49b2 49b6
49ba 49be 49c2 49c6 49ca 49ce 49d2 49d6
49da 49de 49ea 49ee 49f2 49f5 49f9 49fd
49ff 4a03 4a07 4a0b 4a0e 4a12 4a16 4a18
4a19 4a1e 1 4a22 4a26 4a2a 4a2d 4a31
4a35 4a39 4a3d 4a40 4a44 4a48 4a4b 4a4e
4a53 4a56 4a59 4a5c 4a5d 4a62 4a63 1
4a65 4a6a 4a6e 4a72 4a75 4a7a 4a7f 4a82
4a86 4a87 4a8c 4a8f 4a94 4a95 4a9a 4a9d
4aa2 4aa3 4aa8 4aab 4aaf 4ab0 4ab5 4ab8
4abd 4abe 4ac3 4ac6 4aca 4ace 4ad1 4ad4
4ad5 4ad7 4ad8 4add 4ade 4ae3 4ae5 4ae9
4aec 4aee 4af2 4af4 4b00 4b02 4b04 4b05
4b0a 4b0e 4b10 4b1c 4b1e 4b22 4b26 4b29
4b2a 4b2c 4b2f 4b32 4b33 4b38 4b3c 4b40
4b44 4b47 4b4b 4b4f 4b53 4b56 4b5a 4b5e
4b62 4b66 4b67 4b69 4b6d 4b6f 4b73 4b76
4b7a 4b7e 4b82 4b86 4b8a 4b8e 4b92 4b96
4ba2 4ba6 4bab 4baf 4bb2 4bb3 4bb8 4bbc
4bc0 4bc3 4bc6 4bca 4bcc 4bd0 4bd4 4bd7
4bda 4bde 4be0 4be4 4be8 4beb 4bed 4bf1
4bf5 4bf9 4bfc 4c00 4c04 4c06 4c07 4c0c
1 4c10 4c14 4c18 4c1b 4c1f 4c23 4c27
4c2b 4c2e 4c32 4c36 4c39 4c3c 4c41 4c44
4c47 4c4a 4c4b 4c50 4c51 1 4c53 4c58
4c5c 4c60 4c63 4c68 4c6d 4c70 4c74 4c75
4c7a 4c7d 4c82 4c83 4c88 4c8b 4c90 4c91
4c96 4c99 4c9d 4c9e 4ca3 4ca6 4cab 4cac
4cb1 4cb4 4cb8 4cbc 4cbf 4cc2 4cc3 4cc5
4cc6 4ccb 4ccc 4cd1 4cd3 4cd7 4cda 4cdc
4ce0 4ce2 4cee 4cf0 4cf2 4cf3 4cf8 4cfc
4cfe 4d0a 4d0c 4d10 4d14 4d17 4d1a 4d1d
4d1e 4d23 4d27 4d2b 4d2e 4d31 4d35 4d37
4d3b 4d3e 4d42 4d46 4d49 4d4d 4d51 4d54
4d57 4d5c 4d5f 4d62 4d65 4d66 4d6b 4d6c
1 4d6e 4d73 4d77 4d7b 4d7e 4d83 4d88
4d8b 4d8f 4d90 4d95 4d98 4d9d 4d9e 4da3
4da6 4dab 4dac 4db1 4db4 4db8 4dbc 4dbf
4dc0 4dc5 4dc6 4dcb 4dcd 4dd1 4dd4 4dd8
4ddc 4de0 4de3 4de7 4de9 4ded 4def 4dfb
4dff 4e01 4e02 4e0b 
15cc
2
0 1 a 6 e 12 19 :3 6
13 :3 6 17 26 :2 6 1 3 a
:2 1 4 :2 e 1d e :2 4 :2 12 21
2a 3c :2 21 12 :2 4 c 10 f
c 20 :2 29 c :2 4 d 11 10
d 21 :2 2a d :2 4 11 1a 19
:2 11 :2 4 :3 10 :2 4 d 16 15 :2 d
:2 4 e 17 16 :2 e :2 4 18 21
20 :2 18 :2 4 18 21 20 :2 18 :2 4
:3 11 :2 4 :3 12 :2 4 :2 11 20 11 :2 4
:2 f 1e f :2 4 :2 c 1b c :2 4
:2 e 1d e :2 4 :2 12 21 12 :2 4
:2 12 21 12 :2 4 :2 e 1d e :2 4
:2 f 1e f :2 4 :2 e 1d e :2 4
:2 b 1a b :2 4 :2 f 1e f :2 4
:2 14 23 14 :2 4 :2 f 19 f :2 4
:2 f 19 f :2 4 9 12 11 :2 9
:2 4 11 1a 19 :2 11 4 7 e
0 :2 7 11 14 27 2a f 20
23 28 30 d f 1c 1f 2e
30 3d 40 10 12 1f 30 33
e 11 29 2c a :6 7 c 15
:3 c :2 7 e 0 :2 7 11 1b 26
35 10 1d 2e 42 4b a :6 7
e 0 :2 7 11 1a f 10 23
3b a :6 7 :2 11 23 :2 2d 3a :2 23
:3 7 :2 d 19 25 :2 2f 43 :2 25 58
5e 61 :2 58 6f 89 8 :2 6f d
10 :2 6f 15 18 :2 6f b e :2 6f
13 16 1f 27 :2 1f 36 :2 16 :2 6f
b e :2 6f 13 16 1f 27 :2 1f
3a :2 16 :2 6f 42 45 :2 6f :2 7 4e
:2 4 7 :2 11 23 :2 2d 39 3c 50
52 53 :2 50 :2 23 :3 7 :2 d 12 1e
61 64 :2 1e :2 7 56 :2 4 e 17
2d c 1b c d 1a :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 57 59 5a
:2 57 :2 29 :3 d :2 13 18 24 67 6a
:2 24 77 7a :2 24 7e 81 :2 24 8d
90 :2 24 98 9b :2 24 a7 aa b1
ba bd :2 aa :2 24 :2 d 5d :2 a :2 7
:4 13 :2 7 4 :3 1 7 e 1c 1f
:2 7 22 24 :2 22 a :2 14 26 :2 30
3c 40 54 56 57 :2 54 :2 26 :3 a
:2 10 15 21 64 67 :2 21 74 77
:2 21 7b 7e :2 21 88 8b 94 9c
:2 a5 :2 94 c3 :2 8b :2 21 cb ce :2 21
d6 d9 :2 21 de e1 :2 21 e6 e9
:2 21 :2 a 5a :2 7 a :2 14 26 :2 30
3c 3f 53 55 56 :2 53 :2 26 :3 a
:2 10 15 21 64 67 :2 21 :2 a 59
:3 7 e :2 19 2a :2 33 50 56 :2 e
7 28 :2 4 8 :2 11 1c 1a :2 25
:2 1a 7 11 27 34 59 f 1c
26 f 26 44 5a 6e :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 5a 5d 5e
:2 5a :2 2c :3 10 :2 16 1b 27 6b 6e
:2 27 7b 7e :2 27 82 85 :2 27 91
94 :2 27 9c 9f :2 27 ab ae b5
be c1 :2 ae :2 27 :2 10 61 :2 d :2 a
:4 16 :2 a 7 :3 35 b :2 14 1f 1d
:2 28 :2 1d a d :2 17 29 :2 33 3f
42 56 59 5a :2 56 :2 29 :3 d :2 13
18 24 68 6b :2 24 78 7b :2 24
7f 82 :2 24 8c 8f 98 a0 :2 a9
:2 98 bc :2 8f :2 24 :2 d 5d :2 a d
:2 17 29 :2 33 3f 42 56 59 5a
:2 56 :2 29 :3 d :2 13 18 24 68 6b
:2 24 :2 d 5d :3 a 11 :2 1c 2f :2 38
4a :2 11 a 7 38 e 17 22
:2 e 25 27 :2 25 d 2f 38 44
:2 2f 47 49 :2 47 2e :3 d :2 17 29
:2 33 3f 43 57 5a 5b :2 57 :2 29
:3 d :2 13 18 24 68 6b :2 24 78
7b :2 24 7f 82 :2 24 8c 8f 98
a0 :2 a9 :2 98 c5 :2 8f :2 24 cd d0
:2 24 d8 db :2 24 e0 e3 :2 24 e8
eb :2 24 :2 d 5e :2 a d :2 17 29
:2 33 3f 42 56 59 5a :2 56 :2 29
:3 d :2 13 18 24 68 6b :2 24 :2 d
5d :3 a 11 :2 1c 2d :2 36 51 57
:2 11 a 4c 38 :2 7 11 1a 34
47 55 62 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 5a 5d 5e :2 5a :2 2c :3 10
:2 16 1b 27 6b 6e :2 27 7b 7e
:2 27 82 85 :2 27 91 94 :2 27 9c
9f :2 27 ab ae b5 be c1 :2 ae
:2 27 :2 10 61 :2 d :2 a :4 16 :2 a 7
:3 35 7 f e 11 :2 f 30 33
:2 f 13 16 :2 f 7 35 7 17
7 a 13 1e :2 a 21 23 :2 21
14 d 29 33 3c 4d 56 66
d 1f 28 37 d 1f 28 38
d 29 43 57 d 1f :6 d 1f
d 1f d 13 20 31 3d 46
4e 57 65 6e 7c 85 93 9c
a9 b2 c3 cc df e8 fd 106
121 12a 142 14b 15c 165 177 180
198 1a1 1b4 1bd 1de 1f3 207 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5d 60 61 :2 5d :2 2f :3 13 :2 19
1e 2a 6e 71 :2 2a 7e 81 :2 2a
85 88 :2 2a 94 97 :2 2a 9f a2
:2 2a ae b1 b8 c1 c4 :2 b1 :2 2a
:2 13 64 :2 10 :2 d :4 19 :2 d a :3 25
a f :4 a 13 1d 32 :3 d 10
15 :2 10 :2 19 25 10 1b 10 :2 19
25 10 :4 d 11 :2 1a 26 23 :2 2f
:2 23 :3 10 3f :2 d 17 :2 10 1e 27
36 10 1f 28 38 10 2b 45
5b 10 1d 10 16 10 1f 28
37 10 20 29 39 10 1b 10
2d 4c 64 10 30 52 6d 10
30 4e 52 68 78 10 33 51
55 6b 7b 10 26 3d 53 10
27 3f 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 60 63
64 :2 60 :2 32 :3 16 :2 1c 21 2d 71
74 :2 2d 81 84 :2 2d 88 8b :2 2d
97 9a :2 2d a2 a5 :2 2d b1 b4
bb c4 c7 :2 b4 :2 2d :2 16 67 :2 13
:2 10 :4 1c :2 10 d :3 a 17 2c 16
23 34 48 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 60 63 64
:2 60 :2 32 :3 16 :2 1c 21 2d 71 74
:2 2d 81 84 :2 2d 88 8b :2 2d 97
9a :2 2d a2 a5 :2 2d b1 b4 bb
c4 c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10
:4 1c :2 10 d :4 a e 25 d 13
:3 d :2 16 22 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5d
60 61 :2 5d :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a 7e 81 :2 2a 85 88
:2 2a 94 97 :2 2a 9f a2 :2 2a ae
b1 b8 c1 c4 :2 b1 :2 2a :2 13 64
:2 10 :2 d :4 19 :2 d a :4 25 :2 7 11
1d 2b 34 10 1d 2e 43 57
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 5a 5d 5e :2 5a :2 2c :3 10
:2 16 1b 27 6b 6e :2 27 7b 7e
:2 27 82 85 :2 27 91 94 :2 27 9c
9f :2 27 ab ae b5 be c1 :2 ae
:2 27 :2 10 61 :2 d :2 a :4 16 :2 a 7
:3 4 7 14 :2 7 14 :2 7 d e
11 :2 d 23 26 :2 d 13 16 :2 d
7 :5 4 9 :2 12 :2 4 d 17 1d
27 32 :3 7 a f :2 a :2 13 1f
a 15 a :2 13 1f a :4 7 b
:2 14 20 1d :2 29 :2 1d :3 a 39 :2 7
c f 17 1f 10 12 28 2a
10 12 28 2a 10 12 28 2a
10 12 25 27 10 12 25 27
10 12 25 27 16 23 34 41
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 60 63 64 :2 60 :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d 81 84
:2 2d 88 8b :2 2d 97 9a :2 2d a2
a5 :2 2d b1 b4 bb c4 c7 :2 b4
:2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10 d
:3 11 17 28 10 13 25 28 39
3c 4f 52 64 67 7c 7f 93
96 a7 aa 10 13 2a 2d 43
46 60 63 10 13 25 28 39
3c 4f 52 64 67 7c 7f 93
96 a7 aa 10 13 2a 2d 43
46 60 63 10 13 25 28 3a
3d 50 53 66 69 7e 81 96
99 aa ad ba bd 10 13 2a
2d 40 43 57 5a 74 77 8d
90 10 13 24 27 35 38 49
4c 5a 5d 6e 71 7f 82 93
96 16 2a 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 60 63 64
:2 60 :2 32 :3 16 :2 1c 21 2d 71 74
:2 2d 81 84 :2 2d 88 8b :2 2d 97
9a :2 2d a2 a5 :2 2d b1 b4 bb
c4 c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10
:4 1c :2 10 d :3 11 17 10 2c 10
2c 10 36 5d 78 10 2d 10
2d 10 37 5f 7b 10 2d 10
2d 10 37 57 73 10 2b 10
2b 10 35 56 70 10 2e 10
2e 10 38 5c 79 10 21 10
22 10 24 10 20 2d 10 26
39 10 29 3f 16 23 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
60 63 64 :2 60 :2 32 :3 16 :2 1c 21
2d 71 74 :2 2d 81 84 :2 2d 88
8b :2 2d 97 9a :2 2d a2 a5 :2 2d
b1 b4 bb c4 c7 :2 b4 :2 2d :2 16
67 :2 13 :2 10 :4 1c :2 10 d :4 11 :2 a
f 17 29 38 4f 62 76 :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 60 63
64 :2 60 :2 32 :3 16 :2 1c 21 2d 71
74 :2 2d 81 84 :2 2d 88 8b :2 2d
97 9a :2 2d a2 a5 :2 2d b1 b4
bb c4 c7 :2 b4 :2 2d :2 16 67 :2 13
:2 10 :4 1c :2 10 d :4 11 :2 1a 26 23
:2 2f :2 23 10 :4 44 43 42 :2 10 15
10 58 :2 d 17 34 4d 58 15
2a 15 2c 3f 49 5a 68 :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 60 63
64 :2 60 :2 32 :3 16 :2 1c 21 2d 71
74 :2 2d 81 84 :2 2d 88 8b :2 2d
97 9a :2 2d a2 a5 :2 2d b1 b4
bb c4 c7 :2 b4 :2 2d :2 16 67 :2 13
:2 10 :4 1c :2 10 d :4 11 :2 1a 25 23
:2 2e :2 23 10 :4 44 43 42 :2 10 13
1c 27 :2 13 2a 2c :2 2a 13 1e
13 2e 22 39 4d 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :3 10 22 34
48 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9d a0 :2 33
a8 ab :2 33 b7 ba c1 ca cd
:2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16
13 :3 10 22 3e 52 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :3 10 22 3f
53 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9d a0 :2 33
a8 ab :2 33 b7 ba c1 ca cd
:2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16
13 :3 10 13 1e 13 :4 10 66 10
27 :2 10 1b 10 :5 d 1a :2 d 12
:4 d 16 1f 2c 37 :3 10 13 17
:2 13 :2 1c 28 13 1d 13 :2 1c 28
13 :4 10 14 :2 1d 29 26 :2 32 :2 26
:3 13 42 :2 10 13 1c 25 :2 13 28
2a :2 28 1d 32 3e 4a 16 22
2a 31 3c 1c 29 3a 4e 66
71 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9d a0 :2 33
a8 ab :2 33 b7 ba c1 ca cd
:2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16
13 :3 2c 17 :2 20 2b 29 :2 34 :2 29
16 25 3c 49 5a 6e 77 82
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 69 6c 6d :2 69 :2 3b :3 1f
:2 25 2a 36 7a 7d :2 36 8a 8d
:2 36 91 94 :2 36 a0 a3 :2 36 ab
ae :2 36 ba bd c4 cd d0 :2 bd
:2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19 16
:4 44 20 35 49 63 70 81 95
9e a9 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 69 6c 6d :2 69
:2 3b :3 1f :2 25 2a 36 7a 7d :2 36
8a 8d :2 36 91 94 :2 36 a0 a3
:2 36 ab ae :2 36 ba bd c4 cd
d0 :2 bd :2 36 :2 1f 70 :2 1c :2 19 :4 25
:2 19 16 :7 13 10 2c 16 1f 28
:2 16 2b 2d :2 2b 1d 32 46 60
6d 7e 92 9b a6 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :4 2f 2c :2 10
d :2 11 10 16 :3 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :3 11 17 2c 3c 48 16 23
34 40 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 60 63 64 :2 60
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
81 84 :2 2d 88 8b :2 2d 97 9a
:2 2d a2 a5 :2 2d b1 b4 bb c4
c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c
:2 10 d :3 11 10 19 24 :2 10 27
29 :2 27 1a :2 13 18 21 28 2d
36 13 21 13 22 13 24 13
20 13 22 13 23 13 1e 13
30 4f 67 13 33 55 70 13
19 13 2b 2f 45 55 13 36
54 58 6e 7e 13 29 40 56
13 2a 42 13 19 2d 36 49
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 63 66 67 :2 63 :2 35 :3 19
:2 1f 24 30 74 77 :2 30 84 87
:2 30 8b 8e :2 30 9a 9d :2 30 a5
a8 :2 30 b4 b7 be c7 ca :2 b7
:2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13 10
:3 2b 13 1c 25 :2 13 28 2a :2 28
13 21 :2 13 26 36 44 59 65
68 :2 26 13 2c :2 10 2b 10 15
:4 10 19 22 2d :3 13 16 1a :2 16
:2 1f 2b 16 20 16 :2 1f 2b 16
:4 13 17 :2 20 2c 29 :2 35 :2 29 :3 16
45 :2 13 1d :2 16 1b 24 16 1b
24 16 24 16 25 16 27 16
23 16 25 16 26 16 21 16
33 52 6a 16 36 58 73 16
1c 16 2e 32 48 58 16 39
57 5b 71 81 16 2c 43 59
16 2d 45 16 2e 1c 30 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 69 6a :2 66 :2 38 :3 1c :2 22
27 33 77 7a :2 33 87 8a :2 33
8e 91 :2 33 9d a0 :2 33 a8 ab
:2 33 b7 ba c1 ca cd :2 ba :2 33
:2 1c 6d :2 19 :2 16 :4 22 :2 16 13 :3 10
1d 29 37 40 58 65 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 69 6a :2 66 :2 38 :3 1c :2 22 27
33 77 7a :2 33 87 8a :2 33 8e
91 :2 33 9d a0 :2 33 a8 ab :2 33
b7 ba c1 ca cd :2 ba :2 33 :2 1c
6d :2 19 :2 16 :4 22 :2 16 13 :4 10 14
d 13 19 :3 13 :2 1c 28 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 63 66 67 :2 63 :2 35 :3 19
:2 1f 24 30 74 77 :2 30 84 87
:2 30 8b 8e :2 30 9a 9d :2 30 a5
a8 :2 30 b4 b7 be c7 ca :2 b7
:2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13 10
:3 d 14 1d 28 :2 14 2b 2d :2 2b
13 35 3e 46 :2 35 49 4b :2 49
34 :2 13 1d 32 3d 4a 5e 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 69 6a :2 66 :2 38 :3 1c :2 22
27 33 77 7a :2 33 87 8a :2 33
8e 91 :2 33 9d a0 :2 33 a8 ab
:2 33 b7 ba c1 ca cd :2 ba :2 33
:2 1c 6d :2 19 :2 16 :4 22 :2 16 13 :4 4e
:3 10 1e :2 10 23 33 41 56 62
65 :2 23 10 1a 31 37 44 52
5c 6a 18 2d 3b 49 58 64
70 18 2f 45 :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 66 67 :2 63 :2 35
:3 19 :2 1f 24 30 74 77 :2 30 84
87 :2 30 8b 8e :2 30 9a 9d :2 30
a5 a8 :2 30 b4 b7 be c7 ca
:2 b7 :2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13
10 :3 d 13 1c 28 :2 13 2b 2d
:2 2b 1d :6 16 2e 16 2f 16 2f
16 2e 45 16 1c 29 3a 48
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:4 2f 1d :6 16 2e 16 2f 16 2f
16 2e 45 16 31 48 1c 29
3a 48 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :7 10 :4 d f d :3 11 :2 a
d a :3 7 11 1d 2b 34 4c
59 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 5a 5d 5e :2 5a :2 2c
:3 10 :2 16 1b 27 6b 6e :2 27 7b
7e :2 27 82 85 :2 27 91 94 :2 27
9c 9f :2 27 ab ae b5 be c1
:2 ae :2 27 :2 10 61 :2 d :2 a :4 16 :2 a
7 :4 4 8 1 7 d :3 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 57 5a 5b
:2 57 :2 29 :3 d :2 13 18 24 68 6b
:2 24 78 7b :2 24 7f 82 :2 24 8e
91 :2 24 99 9c :2 24 a8 ab b2
bb be :2 ab :2 24 :2 d 5e :2 a :2 7
:4 13 :2 7 4 :3 1 7 15 17 :2 15
7 1a 24 :2 1a 7 19 :2 4 19
1f 28 34 3a 43 4f 59 62
:2 c 1a 27 :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 57 5a 5b :2 57 :2 29 :3 d
:2 13 18 24 68 6b :2 24 78 7b
:2 24 7f 82 :2 24 8e 91 :2 24 99
9c :2 24 a8 ab b2 bb be :2 ab
:2 24 :2 d 5e :2 a :2 7 :4 13 :2 7 4
:3 1 7 10 1f :2 7 22 24 :2 22
7 14 :2 1d :2 7 :2 10 1c 30 3e
4d :2 1c 7 26 :2 4 e 7 1f
2c 3a 47 d 1a 7 e a
16 :3 14 a :2 13 1f a 1b a
:2 13 1f a :4 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 57
5b 5c :2 57 :2 29 :3 d :2 13 18 24
69 6c :2 24 79 7c :2 24 80 83
:2 24 8f 92 :2 24 9a 9d :2 24 a9
ac b3 bc bf :2 ac :2 24 :2 d 5f
:2 a :2 7 :4 13 :2 7 4 :3 1 7 :2 10
19 1b :2 19 7 :2 10 1c 7 1f
:2 4 7 :2 11 23 :2 2d 39 3c 50
54 55 :2 50 :2 23 :3 7 :2 d 12 1e
63 66 :2 1e 73 76 :2 1e 7a 7d
:2 1e 87 8a :2 93 :2 1e :2 7 58 :3 4
b :2 14 4 :9 1 
15cc
4
0 :2 1 :6 3 :4 4
:5 5 2 :2 6 :2 1
:6 8 :a 9 :a a :a b
:7 c :5 d :7 e :7 f
:7 10 :7 11 :5 12 :5 13
:6 14 :6 15 :6 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :6 21 :7 22 :7 23
:2 25 0 :2 25 :4 26
:5 27 :8 28 :5 29 :4 2a
26 :5 25 :7 2d :2 2f
0 :2 2f :4 30 :5 31
30 :5 2f :2 33 0
:2 33 :2 34 35 :3 36
34 :5 33 :b 39 :11 3a
3b :2 3a :2 3b :2 3a
:2 3b :2 3a :2 3c :2 3a
:9 3c :2 3a :2 3d :2 3a
:9 3d :2 3a :2 3d :4 3a
:3 39 :11 40 :b 41 :3 40
:3 47 :2 48 49 :2 4a
47 :5 4b 46 4d
:5 4e :3 4d :2 4f :5 51
:11 52 :24 53 :3 52 :2 50
:6 4f 4c :3 38 :a 59
:11 5a :30 5b :3 5a :11 5d
:b 5e :3 5d :c 60 :3 59
:a 63 :4 65 :3 66 :5 67
65 :5 68 64 6a
:5 6b :3 6a :2 6c :5 6e
:11 6f :24 70 :3 6f :2 6d
:6 6c 69 :3 63 :a 75
:11 76 :20 77 :3 76 :11 79
:b 7a :3 79 :b 7c 7d
75 :16 7d :11 7e :30 7f
:3 7e :11 81 :b 82 :3 81
:c 84 7d :3 75 :7 88
:5 89 87 8b :5 8c
:3 8b :2 8d :5 8f :11 90
:24 91 :3 90 :2 8e :6 8d
8a :3 63 :2 96 :2 97
:2 96 :2 97 :2 96 :2 98
:3 96 63 :3 9a :9 9d
a0 :7 a1 :4 a2 :4 a3
:4 a4 :2 a5 a6 a7
a8 a9 aa :2 ab
:2 ac ad :24 ae a0
:6 af :5 b0 af :5 b2
b1 :3 af 9f b5
:5 b6 :3 b5 :2 b7 :5 b9
:11 ba :24 bb :3 ba :2 b8
:6 b7 b4 :3 9d :5 c0
c2 :6 c3 :3 c4 :5 c5
c4 :5 c7 c6 :3 c4
:a c9 :2 ca :3 c9 ce
cf :4 d0 :4 d1 :4 d2
:2 d3 :2 d4 :4 d5 :4 d6
:2 d7 :4 d8 :4 d9 :6 da
:6 db :4 dc :3 dd :2 de
ce :6 df :5 e0 df
:5 e2 e1 :3 df cd
e5 :5 e6 :3 e5 :2 e7
:5 e9 :11 ea :24 eb :3 ea
:2 e8 :6 e7 e4 :3 c2
:2 f1 :4 f2 f1 :6 f3
:5 f4 f3 :5 f6 f5
:3 f3 f0 f9 :5 fa
:3 f9 :2 fb :5 fd :11 fe
:24 ff :3 fe :2 fc :6 fb
f8 :4 c2 103 9d
:4 107 :5 108 106 10a
:5 10b :3 10a :2 10c :5 10e
:11 10f :24 110 :3 10f :2 10d
:6 10c 109 :6 9d :4 117
:5 118 117 :6 119 :5 11a
119 :5 11c 11b :3 119
116 11f :5 120 :3 11f
:2 121 :5 123 :11 124 :24 125
:3 124 :2 122 :6 121 11e
:3 99 :3 12a :3 12b 12d
12e :2 12f :2 12e :2 12f
:2 12e :2 130 :2 12e 12d
99 :3 63 :5 137 139
:8 13a :3 13b :5 13c 13b
:5 13e 13d :3 13b :a 141
:2 142 :3 141 146 148
:2 14d :4 14e :4 14f :4 150
:4 151 :4 152 :4 153 :4 154
14d :6 155 :5 156 155
:5 158 157 :3 155 14c
15b :5 15c :3 15b :2 15d
:5 15f :11 160 :24 161 :3 160
:2 15e :6 15d 15a :3 148
:2 168 :10 169 :8 16a :10 16b
:8 16c :12 16d :c 16e :10 16f
:2 170 168 :6 171 :5 172
171 :5 174 173 :3 171
167 177 :5 178 :3 177
:2 179 :5 17b :11 17c :24 17d
:3 17c :2 17a :6 179 176
:3 148 183 :2 184 :2 185
:4 186 :2 187 :2 188 :4 189
:2 18a :2 18b :4 18c :2 18d
:2 18e :4 18f :2 190 :2 191
:4 192 :2 193 :2 194 :2 195
:3 196 :3 197 :3 198 :2 199
183 :6 19a :5 19b 19a
:5 19d 19c :3 19a 182
1a0 :5 1a1 :3 1a0 :2 1a2
:5 1a4 :11 1a5 :24 1a6 :3 1a5
:2 1a3 :6 1a2 19f :6 148
1ad :7 1b2 :5 1b3 1b1
1b5 :5 1b6 :3 1b5 :2 1b7
:5 1b9 :11 1ba :24 1bb :3 1ba
:2 1b8 :6 1b7 1b4 :3 1ad
:12 1c0 :2 1c1 :3 1c0 :4 1c5
:2 1c6 :6 1c7 1c5 :5 1c8
1c4 1ca :5 1cb :3 1ca
:2 1cc :5 1ce :11 1cf :24 1d0
:3 1cf :2 1cd :6 1cc 1c9
:3 1ad :12 1d6 :9 1d7 :3 1d8
1d7 :4 1dc :6 1dd :5 1de
1dd :5 1e0 1df :3 1dd
1db 1e3 :5 1e4 :3 1e3
:2 1e5 :5 1e7 :11 1e8 :24 1e9
:3 1e8 :2 1e6 :6 1e5 1e2
:3 1d9 :4 1ef :6 1f0 :5 1f1
1f0 :5 1f3 1f2 :3 1f0
1ee 1f6 :5 1f7 :3 1f6
:2 1f8 :5 1fa :11 1fb :24 1fc
:3 1fb :2 1f9 :6 1f8 1f5
:3 1d9 :4 202 :6 203 :5 204
203 :5 206 205 :3 203
201 209 :5 20a :3 209
:2 20b :5 20d :11 20e :24 20f
:3 20e :2 20c :6 20b 208
:3 1d9 :4 215 :6 216 :5 217
216 :5 219 218 :3 216
214 21c :5 21d :3 21c
:2 21e :5 220 :11 221 :24 222
:3 221 :2 21f :6 21e 21b
:3 1d9 :3 227 1d9 :3 1d7
1d6 :3 22a :3 22b 229
:3 1d6 :3 22e :5 233 235
:7 236 :3 237 :5 238 237
:5 23a 239 :3 237 :a 23d
:2 23e :3 23d :9 242 :4 244
:5 245 :6 246 244 :6 247
:5 248 247 :5 24a 249
:3 247 243 24d :5 24e
:3 24d :2 24f :5 251 :11 252
:24 253 :3 252 :2 250 :6 24f
24c :3 242 :a 259 :8 25b
:6 25c :5 25d 25c :5 25f
25e :3 25c 25a 262
:5 263 :3 262 :2 264 :5 266
:11 267 :24 268 :3 267 :2 265
:6 264 261 :4 259 :a 26e
:6 26f :5 270 26f :5 272
271 :3 26f 26d 275
:5 276 :3 275 :2 277 :5 279
:11 27a :24 27b :3 27a :2 278
:6 277 274 :4 26c :3 259
280 242 :9 280 :a 282
:6 283 :5 284 283 :5 286
285 :3 283 281 289
:5 28a :3 289 :2 28b :5 28d
:11 28e :24 28f :3 28e :2 28c
:6 28b 288 :4 280 :3 242
235 294 1ad :4 296
:5 297 295 299 :5 29a
:3 299 :2 29b :5 29d :11 29e
:24 29f :3 29e :2 29c :6 29b
298 :3 1ad :4 2a5 :4 2a6
2a5 :6 2a7 :5 2a8 2a7
:5 2aa 2a9 :3 2a7 2a4
2ad :5 2ae :3 2ad :2 2af
:5 2b1 :11 2b2 :24 2b3 :3 2b2
:2 2b0 :6 2af 2ac :3 1ad
:9 2b8 2ba 2bb :6 2bc
:2 2bd :2 2be :2 2bf :2 2c0
:2 2c1 :2 2c2 :2 2c3 :4 2c4
:4 2c5 :2 2c6 :5 2c7 :6 2c8
:4 2c9 :3 2ca 2cb :4 2cc
2ba :6 2cd :5 2ce 2cd
:5 2d0 2cf :3 2cd 2b9
2d3 :5 2d4 :3 2d3 :2 2d5
:5 2d7 :11 2d8 :24 2d9 :3 2d8
:2 2d6 :6 2d5 2d2 :3 2b8
:9 2de :3 2e0 :a 2e1 :3 2de
2b8 :5 2e6 2e8 :6 2e9
:3 2ea :5 2eb 2ea :5 2ed
2ec :3 2ea :a 2ef :2 2f0
:3 2ef 2f4 2f5 :3 2f6
:3 2f7 :2 2f8 :2 2f9 :2 2fa
:2 2fb :2 2fc :2 2fd :2 2fe
:4 2ff :4 300 :2 301 :5 302
:6 303 :4 304 :3 305 :2 306
:2 307 2f4 :6 308 :5 309
308 :5 30b 30a :3 308
2f3 30e :5 30f :3 30e
:2 310 :5 312 :11 313 :24 314
:3 313 :2 311 :6 310 30d
:3 2e8 :7 31c :6 31d :5 31e
31d :5 320 31f :3 31d
31b 323 :5 324 :3 323
:2 325 :5 327 :11 328 :24 329
:3 328 :2 326 :6 325 322
:4 2e8 32d 2e3 :4 330
:5 331 32f 333 :5 334
:3 333 :2 335 :5 337 :11 338
:24 339 :3 338 :2 336 :6 335
332 :3 2e3 :16 33e :6 340
:6 341 :5 342 341 :5 344
343 :3 341 33f 347
:5 348 :3 347 :2 349 :5 34b
:11 34c :24 34d :3 34c :2 34a
:6 349 346 :6 33e :3 354
:a 355 :7 358 :7 359 :3 35a
358 :5 35b 357 35d
:5 35e :3 35d :2 35f :5 361
:11 362 :24 363 :3 362 :2 360
:6 35f 35c :3 2e3 :9 369
36b 36c 36d 36e
36f 370 :2 371 :2 372
:2 373 :3 374 375 :4 376
36b :6 377 :5 378 377
:5 37a 379 :3 377 36a
37d :5 37e :3 37d :2 37f
:5 381 :11 382 :24 383 :3 382
:2 380 :6 37f 37c :4 369
389 38a 38b 38c
38d 38e :2 38f :2 390
:2 391 :3 392 :3 393 :4 394
389 :6 395 :5 396 395
:5 398 397 :3 395 388
39b :5 39c :3 39b :2 39d
:5 39f :11 3a0 :24 3a1 :3 3a0
:2 39e :6 39d 39a :4 387
:3 369 2e3 :3 2b8 3a9
3aa :5 1ad 3ac 3ab
:3 146 :7 3b1 :6 3b2 :5 3b3
3b2 :5 3b5 3b4 :3 3b2
3b0 3b8 :5 3b9 :3 3b8
:2 3ba :5 3bc :11 3bd :24 3be
:3 3bd :2 3bb :6 3ba 3b7
:4 139 3c3 38 :4 3c7
:5 3c8 3c6 3ca :5 3cb
:3 3ca :2 3cc :5 3ce :11 3cf
:24 3d0 :3 3cf :2 3cd :6 3cc
3c9 :3 38 :5 3d5 :6 3d6
:3 3d5 :9 3db 3dc :3 3dd
3db :5 3de 3da 3e0
:5 3e1 :3 3e0 :2 3e2 :5 3e4
:11 3e5 :24 3e6 :3 3e5 :2 3e3
:6 3e2 3df :3 38 :9 3eb
:5 3ec :a 3ed :3 3eb 3f1
:5 3f2 :2 3f3 3f1 :6 3f4
:5 3f5 3f4 :5 3f7 3f6
:3 3f4 3f0 3fa :5 3fb
:3 3fa :2 3fc :5 3fe :11 3ff
:24 400 :3 3ff :2 3fd :6 3fc
3f9 :3 38 :7 405 :5 406
:3 405 :11 409 :19 40a :3 409
:5 40c :2 38 :7 1 
4e0d
4
:3 0 1 :3 0 2
:a 0 15c7 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 :2 0 7 8
:3 0 7 :7 0 b
a :3 0 8 :3 0
a :2 0 9 :7 0
10 e f :2 0
b :3 0 8 :3 0
12 14 0 15c7
2 15 :2 0 f
:2 0 d 8 :3 0
18 :7 0 7 :3 0
1c 19 1a 15c5
0 c :6 0 12
:2 0 12 8 :3 0
1e :7 0 e :3 0
9 :3 0 f 20
23 26 1f 24
15c5 0 d :6 0
12 :2 0 16 11
:3 0 14 28 2a
2 :5 0 13 :3 0
14 :3 0 2c 2d
0 30 2b 2e
15c5 0 10 :6 0
17 :2 0 1a 11
:3 0 18 32 34
2 :5 0 13 :3 0
14 :3 0 36 37
0 3a 35 38
15c5 0 15 :6 0
20 124 0 1e
6 :3 0 1c 3c
3e :6 0 41 3f
0 15c5 0 16
:6 0 17 :2 0 24
19 :3 0 43 :7 0
46 44 0 15c5
0 18 :6 0 6
:3 0 17 :2 0 22
48 4a :6 0 4d
4b 0 15c5 0
1a :6 0 17 :2 0
28 6 :3 0 26
4f 51 :6 0 54
52 0 15c5 0
1b :6 0 17 :2 0
2c 6 :3 0 2a
56 58 :6 0 5b
59 0 15c5 0
1c :6 0 32 1b3
0 30 6 :3 0
2e 5d 5f :6 0
62 60 0 15c5
0 1d :6 0 f
:2 0 34 1f :3 0
64 :7 0 67 65
0 15c5 0 1e
:6 0 1f :3 0 69
:7 0 6c 6a 0
15c5 0 20 :6 0
f :2 0 36 8
:3 0 6e :7 0 72
6f 70 15c5 0
21 :6 0 f :2 0
38 8 :3 0 74
:7 0 78 75 76
15c5 0 22 :6 0
f :2 0 3a 8
:3 0 7a :7 0 7e
7b 7c 15c5 0
23 :6 0 f :2 0
3c 8 :3 0 80
:7 0 84 81 82
15c5 0 24 :6 0
f :2 0 3e 8
:3 0 86 :7 0 8a
87 88 15c5 0
25 :6 0 f :2 0
40 8 :3 0 8c
:7 0 90 8d 8e
15c5 0 26 :6 0
f :2 0 42 8
:3 0 92 :7 0 96
93 94 15c5 0
27 :6 0 f :2 0
44 8 :3 0 98
:7 0 9c 99 9a
15c5 0 28 :6 0
f :2 0 46 8
:3 0 9e :7 0 a2
9f a0 15c5 0
29 :6 0 f :2 0
48 8 :3 0 a4
:7 0 a8 a5 a6
15c5 0 2a :6 0
f :2 0 4a 8
:3 0 aa :7 0 ae
ab ac 15c5 0
2b :6 0 2f :2 0
4c 8 :3 0 b0
:7 0 b4 b1 b2
15c5 0 2c :6 0
2f :2 0 4e 2e
:3 0 b6 :7 0 ba
b7 b8 15c5 0
2d :6 0 32 :2 0
50 2e :3 0 bc
:7 0 c0 bd be
15c5 0 30 :6 0
a :2 0 54 6
:3 0 52 c2 c4
:6 0 c7 c5 0
15c5 0 31 :9 0
58 6 :3 0 56
c9 cb :6 0 ce
cc 0 15c5 0
33 :6 0 34 :3 0
35 :a 0 2 ef
:4 0 d0 d3 0
d1 :3 0 36 :3 0
37 :3 0 36 :3 0
38 :3 0 39 :3 0
36 :3 0 3a :3 0
3b :3 0 3c :3 0
3c :3 0 3d :3 0
36 :3 0 3d :3 0
3c :3 0 3e :3 0
36 :3 0 3f :3 0
3c :3 0 3d :3 0
16 :3 0 36 :3 0
40 :3 0 36 :3 0
41 :3 0 36 :3 0
42 :4 0 43 1
:8 0 f0 d0 d3
f1 0 15c5 5a
f1 f3 f0 f2
:6 0 ef :7 0 f1
:3 0 5c 45 :3 0
46 :2 0 4 f5
f6 0 f7 :7 0
fa f8 0 15c5
0 44 :6 0 34
:3 0 47 :a 0 3
10a :4 0 fc ff
0 fd :3 0 48
:3 0 49 :3 0 4a
:3 0 4b :3 0 3d
:3 0 16 :3 0 37
:3 0 3 :3 0 40
:4 0 4c 1 :8 0
10b fc ff 10c
0 15c5 5e 10c
10e 10b 10d :6 0
10a :7 0 10c 34
:3 0 4d :a 0 4
11b :5 0 110 113
0 111 :3 0 3f
:3 0 37 :3 0 39
:3 0 40 :3 0 42
:3 0 3 :4 0 4e
1 :8 0 11c 110
113 11d 0 15c5
60 11d 11f 11c
11e :6 0 11b :7 0
11d 4f :3 0 50
:3 0 120 121 0
4f :3 0 51 :3 0
123 124 0 2
:4 0 62 125 127
122 129 128 :2 0
52 :3 0 53 :3 0
12b 12c 0 54
:4 0 4f :3 0 55
:3 0 12f 130 0
2 :4 0 64 131
133 56 :4 0 57
:2 0 58 :3 0 66
136 138 :3 0 59
:4 0 57 :2 0 5a
:4 0 69 13b 13d
:3 0 57 :2 0 3
:3 0 6c 13f 141
:3 0 57 :2 0 5a
:4 0 6f 143 145
:3 0 57 :2 0 5b
:4 0 72 147 149
:3 0 57 :2 0 e
:3 0 5c :3 0 7
:3 0 75 14d 14f
5d :4 0 77 14c
152 7a 14b 154
:3 0 57 :2 0 5b
:4 0 7d 156 158
:3 0 57 :2 0 e
:3 0 5c :3 0 9
:3 0 80 15c 15e
5d :4 0 82 15b
161 85 15a 163
:3 0 57 :2 0 5e
:4 0 88 165 167
:3 0 8b 12d 169
:2 0 16b 90 16c
12a 16b 0 16d
92 0 15c3 4f
:3 0 50 :3 0 16e
16f 0 4f :3 0
5f :3 0 171 172
0 a :2 0 2
:4 0 60 :2 0 61
:2 0 a :2 0 94
177 179 :3 0 97
173 17b 170 17d
17c :2 0 52 :3 0
62 :3 0 17f 180
0 54 :4 0 63
:4 0 57 :2 0 58
:3 0 9b 184 186
:3 0 9e 181 188
:2 0 18a a1 18b
17e 18a 0 18c
a3 0 15c3 e
:3 0 64 :3 0 65
:3 0 25 :3 0 33
:3 0 3b :3 0 3e
:3 0 3 :4 0 66
1 :8 0 19b 45
:3 0 67 :3 0 196
197 0 68 :3 0
198 199 0 19b
a5 1ee 69 :3 0
45 :3 0 67 :3 0
19d 19e 0 68
:3 0 19f 1a0 0
1a2 a8 1a4 aa
1a3 1a2 :2 0 1ec
6a :3 0 45 :3 0
67 :3 0 1a7 1a8
0 68 :3 0 1a9
1aa 0 1e4 4f
:3 0 50 :3 0 1ac
1ad 0 4f :3 0
5f :3 0 1af 1b0
0 6b :2 0 2
:4 0 6c :2 0 61
:2 0 a :2 0 ac
1b5 1b7 :3 0 af
1b1 1b9 1ae 1bb
1ba :2 0 52 :3 0
62 :3 0 1bd 1be
0 54 :4 0 6d
:4 0 57 :2 0 58
:3 0 b3 1c2 1c4
:3 0 57 :2 0 6e
:4 0 b6 1c6 1c8
:3 0 57 :2 0 6f
:4 0 b9 1ca 1cc
:3 0 57 :2 0 68
:3 0 bc 1ce 1d0
:3 0 57 :2 0 70
:4 0 bf 1d2 1d4
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 c2
1d7 1db c6 1d6
1dd :3 0 c9 1bf
1df :2 0 1e1 cc
1e2 1bc 1e1 0
1e3 ce 0 1e4
d0 1e7 :3 0 1e7
0 1e7 1e6 1e4
1e5 :6 0 1e9 5
:3 0 d3 1eb d5
1ea 1e9 :2 0 1ec
d7 :2 0 1ee 0
1ee 1ed 19b 1ec
:6 0 15c3 1 :3 0
71 :3 0 33 :3 0
a :2 0 a :2 0
da 1f0 1f4 74
:2 0 75 :4 0 e0
1f6 1f8 :3 0 4f
:3 0 50 :3 0 1fa
1fb 0 4f :3 0
5f :3 0 1fd 1fe
0 17 :2 0 2
:4 0 76 :2 0 61
:2 0 a :2 0 e3
203 205 :3 0 e6
1ff 207 1fc 209
208 :2 0 52 :3 0
62 :3 0 20b 20c
0 54 :4 0 77
:4 0 57 :2 0 58
:3 0 ea 210 212
:3 0 57 :2 0 6e
:4 0 ed 214 216
:3 0 57 :2 0 78
:4 0 f0 218 21a
:3 0 57 :2 0 e
:3 0 5c :3 0 13
:3 0 79 :3 0 21f
220 0 f3 21e
222 5d :4 0 f5
21d 225 f8 21c
227 :3 0 57 :2 0
7a :4 0 fb 229
22b :3 0 57 :2 0
5a :4 0 fe 22d
22f :3 0 57 :2 0
3 :3 0 101 231
233 :3 0 57 :2 0
5a :4 0 104 235
237 :3 0 107 20d
239 :2 0 23b 10a
23c 20a 23b 0
23d 10c 0 269
4f :3 0 50 :3 0
23e 23f 0 4f
:3 0 5f :3 0 241
242 0 a :2 0
2 :4 0 7b :2 0
61 :2 0 a :2 0
10e 247 249 :3 0
111 243 24b 240
24d 24c :2 0 52
:3 0 62 :3 0 24f
250 0 54 :4 0
7c :4 0 57 :2 0
58 :3 0 115 254
256 :3 0 118 251
258 :2 0 25a 11b
25b 24e 25a 0
25c 11d 0 269
b :3 0 7d :3 0
7e :3 0 25e 25f
0 13 :3 0 79
:3 0 261 262 0
3 :3 0 7f :3 0
11f 260 266 267
:2 0 269 123 26a
1f9 269 0 26b
127 0 15c3 45
:3 0 67 :3 0 26c
26d 0 45 :3 0
74 :2 0 80 :3 0
26f 271 0 12b
270 273 :3 0 274
:2 0 3d :3 0 3d
:3 0 3f :3 0 42
:3 0 16 :3 0 29
:3 0 28 :3 0 39
:3 0 81 :3 0 41
:3 0 37 :3 0 3
:4 0 82 1 :8 0
288 45 :3 0 67
:3 0 283 284 0
68 :3 0 285 286
0 288 12e 2db
69 :3 0 45 :3 0
67 :3 0 28a 28b
0 68 :3 0 28c
28d 0 28f 131
291 133 290 28f
:2 0 2d9 6a :3 0
45 :3 0 67 :3 0
294 295 0 68
:3 0 296 297 0
2d1 4f :3 0 50
:3 0 299 29a 0
4f :3 0 5f :3 0
29c 29d 0 6b
:2 0 2 :4 0 83
:2 0 61 :2 0 a
:2 0 135 2a2 2a4
:3 0 138 29e 2a6
29b 2a8 2a7 :2 0
52 :3 0 62 :3 0
2aa 2ab 0 54
:4 0 84 :4 0 57
:2 0 58 :3 0 13c
2af 2b1 :3 0 57
:2 0 6e :4 0 13f
2b3 2b5 :3 0 57
:2 0 6f :4 0 142
2b7 2b9 :3 0 57
:2 0 68 :3 0 145
2bb 2bd :3 0 57
:2 0 70 :4 0 148
2bf 2c1 :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 14b 2c4 2c8
14f 2c3 2ca :3 0
152 2ac 2cc :2 0
2ce 155 2cf 2a9
2ce 0 2d0 157
0 2d1 159 2d4
:3 0 2d4 0 2d4
2d3 2d1 2d2 :6 0
2d6 7 :3 0 15c
2d8 15e 2d7 2d6
:2 0 2d9 160 :2 0
2db 0 2db 2da
288 2d9 :6 0 440
1 :3 0 45 :3 0
67 :3 0 2dd 2de
0 45 :3 0 74
:2 0 80 :3 0 2e0
2e2 0 165 2e1
2e4 :3 0 2e5 :2 0
4f :3 0 50 :3 0
2e7 2e8 0 4f
:3 0 5f :3 0 2ea
2eb 0 85 :2 0
2 :4 0 86 :2 0
61 :2 0 a :2 0
168 2f0 2f2 :3 0
16b 2ec 2f4 2e9
2f6 2f5 :2 0 52
:3 0 62 :3 0 2f8
2f9 0 54 :4 0
87 :4 0 57 :2 0
58 :3 0 16f 2fd
2ff :3 0 57 :2 0
6e :4 0 172 301
303 :3 0 57 :2 0
78 :4 0 175 305
307 :3 0 57 :2 0
e :3 0 5c :3 0
13 :3 0 88 :3 0
30c 30d 0 178
30b 30f 5d :4 0
17a 30a 312 17d
309 314 :3 0 180
2fa 316 :2 0 318
183 319 2f7 318
0 31a 185 0
346 4f :3 0 50
:3 0 31b 31c 0
4f :3 0 5f :3 0
31e 31f 0 a
:2 0 2 :4 0 89
:2 0 61 :2 0 a
:2 0 187 324 326
:3 0 18a 320 328
31d 32a 329 :2 0
52 :3 0 62 :3 0
32c 32d 0 54
:4 0 8a :4 0 57
:2 0 58 :3 0 18e
331 333 :3 0 191
32e 335 :2 0 337
194 338 32b 337
0 339 196 0
346 b :3 0 7d
:3 0 8b :3 0 33b
33c 0 13 :3 0
88 :3 0 33e 33f
0 7f :3 0 198
33d 342 343 :2 0
346 8c :3 0 19b
3ce e :3 0 29
:3 0 f :2 0 19f
347 34a 74 :2 0
f :2 0 1a4 34c
34e :3 0 34f :2 0
e :3 0 28 :3 0
f :2 0 1a7 351
354 74 :2 0 a
:2 0 1ac 356 358
:3 0 359 :2 0 350
35b 35a :2 0 4f
:3 0 50 :3 0 35d
35e 0 4f :3 0
5f :3 0 360 361
0 17 :2 0 2
:4 0 8d :2 0 61
:2 0 a :2 0 1af
366 368 :3 0 1b2
362 36a 35f 36c
36b :2 0 52 :3 0
62 :3 0 36e 36f
0 54 :4 0 8e
:4 0 57 :2 0 58
:3 0 1b6 373 375
:3 0 57 :2 0 6e
:4 0 1b9 377 379
:3 0 57 :2 0 78
:4 0 1bc 37b 37d
:3 0 57 :2 0 e
:3 0 5c :3 0 13
:3 0 8f :3 0 382
383 0 1bf 381
385 5d :4 0 1c1
380 388 1c4 37f
38a :3 0 57 :2 0
7a :4 0 1c7 38c
38e :3 0 57 :2 0
5a :4 0 1ca 390
392 :3 0 57 :2 0
3 :3 0 1cd 394
396 :3 0 57 :2 0
5a :4 0 1d0 398
39a :3 0 1d3 370
39c :2 0 39e 1d6
39f 36d 39e 0
3a0 1d8 0 3cc
4f :3 0 50 :3 0
3a1 3a2 0 4f
:3 0 5f :3 0 3a4
3a5 0 a :2 0
2 :4 0 90 :2 0
61 :2 0 a :2 0
1da 3aa 3ac :3 0
1dd 3a6 3ae 3a3
3b0 3af :2 0 52
:3 0 62 :3 0 3b2
3b3 0 54 :4 0
91 :4 0 57 :2 0
58 :3 0 1e1 3b7
3b9 :3 0 1e4 3b4
3bb :2 0 3bd 1e7
3be 3b1 3bd 0
3bf 1e9 0 3cc
b :3 0 7d :3 0
7e :3 0 3c1 3c2
0 13 :3 0 8f
:3 0 3c4 3c5 0
3 :3 0 7f :3 0
1eb 3c3 3c9 3ca
:2 0 3cc 1ef 3cd
35c 3cc 0 3cf
2e6 346 0 3cf
1f3 0 440 e
:3 0 64 :3 0 25
:3 0 3b :3 0 3e
:3 0 16 :4 0 92
1 :8 0 3dc 45
:3 0 67 :3 0 3d7
3d8 0 68 :3 0
3d9 3da 0 3dc
1f6 42f 69 :3 0
45 :3 0 67 :3 0
3de 3df 0 68
:3 0 3e0 3e1 0
3e3 1f9 3e5 1fb
3e4 3e3 :2 0 42d
6a :3 0 45 :3 0
67 :3 0 3e8 3e9
0 68 :3 0 3ea
3eb 0 425 4f
:3 0 50 :3 0 3ed
3ee 0 4f :3 0
5f :3 0 3f0 3f1
0 6b :2 0 2
:4 0 93 :2 0 61
:2 0 a :2 0 1fd
3f6 3f8 :3 0 200
3f2 3fa 3ef 3fc
3fb :2 0 52 :3 0
62 :3 0 3fe 3ff
0 54 :4 0 94
:4 0 57 :2 0 58
:3 0 204 403 405
:3 0 57 :2 0 6e
:4 0 207 407 409
:3 0 57 :2 0 6f
:4 0 20a 40b 40d
:3 0 57 :2 0 68
:3 0 20d 40f 411
:3 0 57 :2 0 70
:4 0 210 413 415
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 213
418 41c 217 417
41e :3 0 21a 400
420 :2 0 422 21d
423 3fd 422 0
424 21f 0 425
221 428 :3 0 428
0 428 427 425
426 :6 0 42a 9
:3 0 224 42c 226
42b 42a :2 0 42d
228 :2 0 42f 0
42f 42e 3dc 42d
:6 0 440 1 :3 0
31 :3 0 95 :4 0
57 :2 0 96 :4 0
22b 433 435 :3 0
57 :2 0 3 :3 0
22e 437 439 :3 0
57 :2 0 97 :4 0
231 43b 43d :3 0
431 43e 0 440
234 72c 16 :3 0
3 :3 0 441 442
0 72b e :3 0
c :3 0 f :2 0
239 444 447 74
:2 0 98 :2 0 23e
449 44b :3 0 3b
:3 0 99 :3 0 99
:3 0 13 :3 0 9a
:3 0 13 :3 0 9b
:3 0 99 :3 0 9c
:3 0 e :3 0 9d
:3 0 9c :3 0 9e
:3 0 e :3 0 9f
:3 0 9e :3 0 a0
:3 0 a1 :3 0 a0
:3 0 a1 :3 0 a2
:3 0 a3 :3 0 9d
:3 0 9f :3 0 a1
:3 0 a4 :3 0 a5
:3 0 a6 :3 0 a3
:3 0 a7 :3 0 a3
:3 0 a8 :3 0 3d
:3 0 16 :3 0 99
:3 0 13 :3 0 a9
:3 0 13 :3 0 aa
:3 0 13 :3 0 ab
:3 0 13 :3 0 ac
:3 0 13 :3 0 ad
:3 0 13 :3 0 ae
:3 0 13 :3 0 af
:3 0 13 :3 0 b0
:3 0 13 :3 0 b1
:3 0 13 :3 0 b2
:3 0 13 :3 0 b3
:3 0 13 :3 0 b4
:3 0 13 :3 0 b5
:3 0 13 :3 0 b6
:3 0 13 :3 0 b7
:3 0 b8 :3 0 b9
:3 0 a2 :4 0 ba
1 :8 0 4a7 bb
:4 0 492 :3 0 bc
:3 0 74 :2 0 243
495 496 :3 0 45
:3 0 67 :3 0 498
499 0 f :2 0
49a 49b 0 49d
246 4a4 45 :3 0
67 :3 0 49e 49f
0 bd :2 0 4a0
4a1 0 4a3 248
4a5 497 49d 0
4a6 0 4a3 0
4a6 24a 0 4a7
24d 4fa 69 :3 0
45 :3 0 67 :3 0
4a9 4aa 0 68
:3 0 4ab 4ac 0
4ae 250 4b0 252
4af 4ae :2 0 4f8
6a :3 0 45 :3 0
67 :3 0 4b3 4b4
0 68 :3 0 4b5
4b6 0 4f0 4f
:3 0 50 :3 0 4b8
4b9 0 4f :3 0
5f :3 0 4bb 4bc
0 6b :2 0 2
:4 0 be :2 0 61
:2 0 a :2 0 254
4c1 4c3 :3 0 257
4bd 4c5 4ba 4c7
4c6 :2 0 52 :3 0
62 :3 0 4c9 4ca
0 54 :4 0 bf
:4 0 57 :2 0 58
:3 0 25b 4ce 4d0
:3 0 57 :2 0 6e
:4 0 25e 4d2 4d4
:3 0 57 :2 0 6f
:4 0 261 4d6 4d8
:3 0 57 :2 0 68
:3 0 264 4da 4dc
:3 0 57 :2 0 70
:4 0 267 4de 4e0
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 26a
4e3 4e7 26e 4e2
4e9 :3 0 271 4cb
4eb :2 0 4ed 274
4ee 4c8 4ed 0
4ef 276 0 4f0
278 4f3 :3 0 4f3
0 4f3 4f2 4f0
4f1 :6 0 4f5 b
:3 0 27b 4f7 27d
4f6 4f5 :2 0 4f8
27f :2 0 4fa 0
4fa 4f9 4a7 4f8
:6 0 69f 1 :3 0
c0 :3 0 35 :4 0
4ff :2 0 69f 4fd
500 :3 0 c1 :3 0
35 :3 0 1c :3 0
1a :4 0 506 :2 0
63e 502 507 :3 0
282 :3 0 35 :3 0
bb :3 0 508 509
:3 0 45 :3 0 67
:3 0 50b 50c 0
f :2 0 50d 50e
0 510 285 517
45 :3 0 67 :3 0
511 512 0 bd
:2 0 513 514 0
516 287 518 50a
510 0 519 0
516 0 519 289
0 63e 45 :3 0
67 :3 0 51a 51b
0 45 :3 0 c2
:2 0 c3 :3 0 51d
51f 0 28e 51e
521 :3 0 522 :2 0
c4 :8 0 526 291
527 523 526 0
528 293 0 63e
39 :3 0 40 :3 0
9c :3 0 e :3 0
9d :3 0 9c :3 0
9e :3 0 e :3 0
9f :3 0 9e :3 0
a0 :3 0 a1 :3 0
a1 :3 0 a0 :3 0
c5 :3 0 c6 :3 0
a7 :3 0 c6 :3 0
c7 :3 0 e :3 0
9d :3 0 9c :3 0
c8 :3 0 e :3 0
9f :3 0 9e :3 0
c9 :3 0 c6 :3 0
ca :3 0 cb :3 0
cb :3 0 ca :3 0
cc :3 0 cd :3 0
cd :3 0 cc :3 0
ce :3 0 cf :3 0
a7 :3 0 c6 :3 0
d0 :3 0 d1 :3 0
d2 :3 0 cf :3 0
a7 :3 0 c6 :3 0
d3 :3 0 d4 :3 0
9d :3 0 9f :3 0
a1 :3 0 c6 :3 0
a4 :3 0 a5 :3 0
a8 :3 0 37 :3 0
1c :4 0 d5 1
:8 0 578 bb :4 0
563 :3 0 bc :3 0
74 :2 0 297 566
567 :3 0 45 :3 0
67 :3 0 569 56a
0 f :2 0 56b
56c 0 56e 29a
575 45 :3 0 67
:3 0 56f 570 0
bd :2 0 571 572
0 574 29c 576
568 56e 0 577
0 574 0 577
29e 0 578 2a1
5cb 69 :3 0 45
:3 0 67 :3 0 57a
57b 0 68 :3 0
57c 57d 0 57f
2a4 581 2a6 580
57f :2 0 5c9 6a
:3 0 45 :3 0 67
:3 0 584 585 0
68 :3 0 586 587
0 5c1 4f :3 0
50 :3 0 589 58a
0 4f :3 0 5f
:3 0 58c 58d 0
6b :2 0 2 :4 0
d6 :2 0 61 :2 0
a :2 0 2a8 592
594 :3 0 2ab 58e
596 58b 598 597
:2 0 52 :3 0 62
:3 0 59a 59b 0
54 :4 0 d7 :4 0
57 :2 0 58 :3 0
2af 59f 5a1 :3 0
57 :2 0 6e :4 0
2b2 5a3 5a5 :3 0
57 :2 0 6f :4 0
2b5 5a7 5a9 :3 0
57 :2 0 68 :3 0
2b8 5ab 5ad :3 0
57 :2 0 70 :4 0
2bb 5af 5b1 :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 2be 5b4
5b8 2c2 5b3 5ba
:3 0 2c5 59c 5bc
:2 0 5be 2c8 5bf
599 5be 0 5c0
2ca 0 5c1 2cc
5c4 :3 0 5c4 0
5c4 5c3 5c1 5c2
:6 0 5c6 e :3 0
2cf 5c8 2d1 5c7
5c6 :2 0 5c9 2d3
:2 0 5cb 0 5cb
5ca 578 5c9 :6 0
63e d :3 0 4b
:3 0 40 :3 0 3d
:3 0 16 :3 0 37
:3 0 1c :4 0 d8
1 :8 0 5e9 bb
:4 0 5d4 :3 0 bc
:3 0 74 :2 0 2d8
5d7 5d8 :3 0 45
:3 0 67 :3 0 5da
5db 0 f :2 0
5dc 5dd 0 5df
2db 5e6 45 :3 0
67 :3 0 5e0 5e1
0 bd :2 0 5e2
5e3 0 5e5 2dd
5e7 5d9 5df 0
5e8 0 5e5 0
5e8 2df 0 5e9
2e2 63c 69 :3 0
45 :3 0 67 :3 0
5eb 5ec 0 68
:3 0 5ed 5ee 0
5f0 2e5 5f2 2e7
5f1 5f0 :2 0 63a
6a :3 0 45 :3 0
67 :3 0 5f5 5f6
0 68 :3 0 5f7
5f8 0 632 4f
:3 0 50 :3 0 5fa
5fb 0 4f :3 0
5f :3 0 5fd 5fe
0 6b :2 0 2
:4 0 d9 :2 0 61
:2 0 a :2 0 2e9
603 605 :3 0 2ec
5ff 607 5fc 609
608 :2 0 52 :3 0
62 :3 0 60b 60c
0 54 :4 0 da
:4 0 57 :2 0 58
:3 0 2f0 610 612
:3 0 57 :2 0 6e
:4 0 2f3 614 616
:3 0 57 :2 0 6f
:4 0 2f6 618 61a
:3 0 57 :2 0 68
:3 0 2f9 61c 61e
:3 0 57 :2 0 70
:4 0 2fc 620 622
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 2ff
625 629 303 624
62b :3 0 306 60d
62d :2 0 62f 309
630 60a 62f 0
631 30b 0 632
30d 635 :3 0 635
0 635 634 632
633 :6 0 637 10
:3 0 310 639 312
638 637 :2 0 63a
314 :2 0 63c 0
63c 63b 5e9 63a
:6 0 63e d :3 0
317 640 c1 :4 0
63e :4 0 69f db
:3 0 35 :4 0 644
:2 0 64a 642 0
45 :3 0 67 :3 0
645 646 0 68
:3 0 647 648 0
64a 31d 69d 69
:3 0 45 :3 0 67
:3 0 64c 64d 0
68 :3 0 64e 64f
0 651 320 653
322 652 651 :2 0
69b 6a :3 0 45
:3 0 67 :3 0 656
657 0 68 :3 0
658 659 0 693
4f :3 0 50 :3 0
65b 65c 0 4f
:3 0 5f :3 0 65e
65f 0 6b :2 0
2 :4 0 dc :2 0
61 :2 0 a :2 0
324 664 666 :3 0
327 660 668 65d
66a 669 :2 0 52
:3 0 62 :3 0 66c
66d 0 54 :4 0
dd :4 0 57 :2 0
58 :3 0 32b 671
673 :3 0 57 :2 0
6e :4 0 32e 675
677 :3 0 57 :2 0
6f :4 0 331 679
67b :3 0 57 :2 0
68 :3 0 334 67d
67f :3 0 57 :2 0
70 :4 0 337 681
683 :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
33a 686 68a 33e
685 68c :3 0 341
66e 68e :2 0 690
344 691 66b 690
0 692 346 0
693 348 696 :3 0
696 0 696 695
693 694 :6 0 698
12 :3 0 34b 69a
34d 699 698 :2 0
69b 34f :2 0 69d
0 69d 69c 64a
69b :6 0 69f 1
:3 0 352 6a0 44c
69f 0 6a1 357
0 72b 3b :3 0
de :3 0 13 :3 0
df :3 0 3d :3 0
16 :3 0 b8 :3 0
b9 :3 0 a2 :4 0
e0 1 :8 0 6c1
bb :4 0 6ac :3 0
bc :3 0 74 :2 0
35b 6af 6b0 :3 0
45 :3 0 67 :3 0
6b2 6b3 0 f
:2 0 6b4 6b5 0
6b7 35e 6be 45
:3 0 67 :3 0 6b8
6b9 0 bd :2 0
6ba 6bb 0 6bd
360 6bf 6b1 6b7
0 6c0 0 6bd
0 6c0 362 0
6c1 365 714 69
:3 0 45 :3 0 67
:3 0 6c3 6c4 0
68 :3 0 6c5 6c6
0 6c8 368 6ca
36a 6c9 6c8 :2 0
712 6a :3 0 45
:3 0 67 :3 0 6cd
6ce 0 68 :3 0
6cf 6d0 0 70a
4f :3 0 50 :3 0
6d2 6d3 0 4f
:3 0 5f :3 0 6d5
6d6 0 6b :2 0
2 :4 0 e1 :2 0
61 :2 0 a :2 0
36c 6db 6dd :3 0
36f 6d7 6df 6d4
6e1 6e0 :2 0 52
:3 0 62 :3 0 6e3
6e4 0 54 :4 0
e2 :4 0 57 :2 0
58 :3 0 373 6e8
6ea :3 0 57 :2 0
6e :4 0 376 6ec
6ee :3 0 57 :2 0
6f :4 0 379 6f0
6f2 :3 0 57 :2 0
68 :3 0 37c 6f4
6f6 :3 0 57 :2 0
70 :4 0 37f 6f8
6fa :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
382 6fd 701 386
6fc 703 :3 0 389
6e5 705 :2 0 707
38c 708 6e2 707
0 709 38e 0
70a 390 70d :3 0
70d 0 70d 70c
70a 70b :6 0 70f
14 :3 0 393 711
395 710 70f :2 0
712 397 :2 0 714
0 714 713 6c1
712 :6 0 72b 1
:3 0 29 :3 0 a
:2 0 716 717 0
72b c :3 0 e3
:2 0 719 71a 0
72b 31 :3 0 e4
:4 0 57 :2 0 e5
:4 0 39a 71e 720
:3 0 57 :2 0 3
:3 0 39d 722 724
:3 0 57 :2 0 97
:4 0 3a0 726 728
:3 0 71c 729 0
72b 3a3 72d 275
440 0 72e 0
72b 0 72e 3aa
0 15c3 c0 :3 0
44 :3 0 31 :3 0
730 731 0 732
:2 0 15c3 c1 :3 0
44 :3 0 3 :3 0
1a :3 0 1b :3 0
2a :4 0 73b :2 0
141d 735 73c :3 0
3ad :3 0 44 :3 0
bb :3 0 73d 73e
:3 0 45 :3 0 67
:3 0 740 741 0
f :2 0 742 743
0 745 3b2 74c
45 :3 0 67 :3 0
746 747 0 bd
:2 0 748 749 0
74b 3b4 74d 73f
745 0 74e 0
74b 0 74e 3b6
0 141d 45 :3 0
67 :3 0 74f 750
0 45 :3 0 c2
:2 0 c3 :3 0 752
754 0 3bb 753
756 :3 0 757 :2 0
c4 :8 0 75b 3be
75c 758 75b 0
75d 3c0 0 141d
c :3 0 a :2 0
e6 :3 0 e7 :3 0
e7 :3 0 e8 :3 0
e7 :3 0 e9 :3 0
e7 :3 0 e9 :3 0
e7 :3 0 ea :3 0
e7 :3 0 ea :3 0
e7 :3 0 eb :3 0
e7 :3 0 ec :3 0
e7 :3 0 ed :3 0
e7 :3 0 ed :3 0
e7 :3 0 ee :3 0
e7 :3 0 ee :3 0
e7 :3 0 ef :3 0
3d :3 0 16 :3 0
3e :3 0 1b :4 0
f0 1 :8 0 794
bb :4 0 77f :3 0
bc :3 0 74 :2 0
3c4 782 783 :3 0
45 :3 0 67 :3 0
785 786 0 f
:2 0 787 788 0
78a 3c7 791 45
:3 0 67 :3 0 78b
78c 0 bd :2 0
78d 78e 0 790
3c9 792 784 78a
0 793 0 790
0 793 3cb 0
794 3ce 7e7 69
:3 0 45 :3 0 67
:3 0 796 797 0
68 :3 0 798 799
0 79b 3d1 79d
3d3 79c 79b :2 0
7e5 6a :3 0 45
:3 0 67 :3 0 7a0
7a1 0 68 :3 0
7a2 7a3 0 7dd
4f :3 0 50 :3 0
7a5 7a6 0 4f
:3 0 5f :3 0 7a8
7a9 0 6b :2 0
2 :4 0 f1 :2 0
61 :2 0 a :2 0
3d5 7ae 7b0 :3 0
3d8 7aa 7b2 7a7
7b4 7b3 :2 0 52
:3 0 62 :3 0 7b6
7b7 0 54 :4 0
f2 :4 0 57 :2 0
58 :3 0 3dc 7bb
7bd :3 0 57 :2 0
6e :4 0 3df 7bf
7c1 :3 0 57 :2 0
6f :4 0 3e2 7c3
7c5 :3 0 57 :2 0
68 :3 0 3e5 7c7
7c9 :3 0 57 :2 0
70 :4 0 3e8 7cb
7cd :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
3eb 7d0 7d4 3ef
7cf 7d6 :3 0 3f2
7b8 7d8 :2 0 7da
3f5 7db 7b5 7da
0 7dc 3f7 0
7dd 3f9 7e0 :3 0
7e0 0 7e0 7df
7dd 7de :6 0 7e2
17 :3 0 3fc 7e4
3fe 7e3 7e2 :2 0
7e5 400 :2 0 7e7
0 7e7 7e6 794
7e5 :6 0 95b 16
:3 0 39 :3 0 36
:3 0 36 :3 0 f3
:3 0 36 :3 0 f4
:3 0 36 :3 0 f5
:3 0 36 :3 0 f6
:3 0 36 :3 0 f7
:3 0 36 :3 0 f8
:3 0 36 :3 0 f9
:3 0 36 :3 0 fa
:3 0 36 :3 0 fb
:3 0 36 :3 0 fc
:3 0 36 :3 0 fd
:3 0 36 :3 0 fe
:3 0 36 :3 0 f4
:3 0 36 :3 0 ff
:3 0 36 :3 0 f6
:3 0 36 :3 0 100
:3 0 36 :3 0 f8
:3 0 36 :3 0 101
:3 0 36 :3 0 fa
:3 0 36 :3 0 102
:3 0 36 :3 0 fc
:3 0 36 :3 0 103
:3 0 36 :3 0 fe
:3 0 36 :3 0 104
:3 0 36 :3 0 ff
:3 0 36 :3 0 105
:3 0 36 :3 0 100
:3 0 36 :3 0 106
:3 0 36 :3 0 101
:3 0 36 :3 0 107
:3 0 36 :3 0 102
:3 0 36 :3 0 c5
:3 0 36 :3 0 c6
:3 0 36 :3 0 103
:3 0 36 :3 0 ca
:3 0 36 :3 0 cb
:3 0 36 :3 0 104
:3 0 36 :3 0 cc
:3 0 36 :3 0 cd
:3 0 36 :3 0 108
:3 0 36 :3 0 d0
:3 0 36 :3 0 109
:3 0 36 :3 0 d3
:3 0 36 :3 0 10a
:3 0 36 :3 0 10b
:3 0 36 :3 0 10c
:3 0 36 :3 0 10d
:3 0 37 :3 0 3
:4 0 10e 1 :8 0
861 bb :4 0 84c
:3 0 bc :3 0 74
:2 0 405 84f 850
:3 0 45 :3 0 67
:3 0 852 853 0
f :2 0 854 855
0 857 408 85e
45 :3 0 67 :3 0
858 859 0 bd
:2 0 85a 85b 0
85d 40a 85f 851
857 0 860 0
85d 0 860 40c
0 861 40f 8b4
69 :3 0 45 :3 0
67 :3 0 863 864
0 68 :3 0 865
866 0 868 412
86a 414 869 868
:2 0 8b2 6a :3 0
45 :3 0 67 :3 0
86d 86e 0 68
:3 0 86f 870 0
8aa 4f :3 0 50
:3 0 872 873 0
4f :3 0 5f :3 0
875 876 0 6b
:2 0 2 :4 0 10f
:2 0 61 :2 0 a
:2 0 416 87b 87d
:3 0 419 877 87f
874 881 880 :2 0
52 :3 0 62 :3 0
883 884 0 54
:4 0 110 :4 0 57
:2 0 58 :3 0 41d
888 88a :3 0 57
:2 0 6e :4 0 420
88c 88e :3 0 57
:2 0 6f :4 0 423
890 892 :3 0 57
:2 0 68 :3 0 426
894 896 :3 0 57
:2 0 70 :4 0 429
898 89a :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 42c 89d 8a1
430 89c 8a3 :3 0
433 885 8a5 :2 0
8a7 436 8a8 882
8a7 0 8a9 438
0 8aa 43a 8ad
:3 0 8ad 0 8ad
8ac 8aa 8ab :6 0
8af 19 :3 0 43d
8b1 43f 8b0 8af
:2 0 8b2 441 :2 0
8b4 0 8b4 8b3
861 8b2 :6 0 95b
16 :3 0 111 :3 0
112 :3 0 113 :3 0
113 :3 0 114 :3 0
114 :3 0 115 :3 0
115 :3 0 116 :3 0
117 :3 0 118 :3 0
118 :3 0 119 :3 0
119 :3 0 11a :3 0
11a :3 0 11b :3 0
11c :3 0 11d :3 0
11d :3 0 11e :3 0
11e :3 0 11f :3 0
11f :3 0 120 :3 0
121 :3 0 122 :3 0
122 :3 0 123 :3 0
123 :3 0 124 :3 0
124 :3 0 125 :3 0
126 :3 0 127 :3 0
127 :3 0 128 :3 0
128 :3 0 129 :3 0
129 :3 0 12a :3 0
12b :3 0 105 :3 0
12c :3 0 106 :3 0
12d :3 0 107 :3 0
12e :3 0 c5 :3 0
c6 :3 0 12f :3 0
ca :3 0 cb :3 0
130 :3 0 cc :3 0
cd :3 0 3d :3 0
16 :4 0 131 1
:8 0 906 bb :4 0
8f1 :3 0 bc :3 0
74 :2 0 446 8f4
8f5 :3 0 45 :3 0
67 :3 0 8f7 8f8
0 f :2 0 8f9
8fa 0 8fc 449
903 45 :3 0 67
:3 0 8fd 8fe 0
bd :2 0 8ff 900
0 902 44b 904
8f6 8fc 0 905
0 902 0 905
44d 0 906 450
959 69 :3 0 45
:3 0 67 :3 0 908
909 0 68 :3 0
90a 90b 0 90d
453 90f 455 90e
90d :2 0 957 6a
:3 0 45 :3 0 67
:3 0 912 913 0
68 :3 0 914 915
0 94f 4f :3 0
50 :3 0 917 918
0 4f :3 0 5f
:3 0 91a 91b 0
6b :2 0 2 :4 0
132 :2 0 61 :2 0
a :2 0 457 920
922 :3 0 45a 91c
924 919 926 925
:2 0 52 :3 0 62
:3 0 928 929 0
54 :4 0 133 :4 0
57 :2 0 58 :3 0
45e 92d 92f :3 0
57 :2 0 6e :4 0
461 931 933 :3 0
57 :2 0 6f :4 0
464 935 937 :3 0
57 :2 0 68 :3 0
467 939 93b :3 0
57 :2 0 70 :4 0
46a 93d 93f :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 46d 942
946 471 941 948
:3 0 474 92a 94a
:2 0 94c 477 94d
927 94c 0 94e
479 0 94f 47b
952 :3 0 952 0
952 951 94f 950
:6 0 954 1b :3 0
47e 956 480 955
954 :2 0 957 482
:2 0 959 0 959
958 906 957 :6 0
95b 16 :3 0 485
95d 489 95c 95b
:2 0 13aa e3 :2 0
c6 :3 0 24 :3 0
39 :3 0 40 :3 0
37 :3 0 3 :4 0
134 1 :8 0 96b
45 :3 0 67 :3 0
966 967 0 68
:3 0 968 969 0
96b 48b 9be 69
:3 0 45 :3 0 67
:3 0 96d 96e 0
68 :3 0 96f 970
0 972 48e 974
490 973 972 :2 0
9bc 6a :3 0 45
:3 0 67 :3 0 977
978 0 68 :3 0
979 97a 0 9b4
4f :3 0 50 :3 0
97c 97d 0 4f
:3 0 5f :3 0 97f
980 0 6b :2 0
2 :4 0 135 :2 0
61 :2 0 a :2 0
492 985 987 :3 0
495 981 989 97e
98b 98a :2 0 52
:3 0 62 :3 0 98d
98e 0 54 :4 0
136 :4 0 57 :2 0
58 :3 0 499 992
994 :3 0 57 :2 0
6e :4 0 49c 996
998 :3 0 57 :2 0
6f :4 0 49f 99a
99c :3 0 57 :2 0
68 :3 0 4a2 99e
9a0 :3 0 57 :2 0
70 :4 0 4a5 9a2
9a4 :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
4a8 9a7 9ab 4ac
9a6 9ad :3 0 4af
98f 9af :2 0 9b1
4b2 9b2 98c 9b1
0 9b3 4b4 0
9b4 4b6 9b7 :3 0
9b7 0 9b7 9b6
9b4 9b5 :6 0 9b9
1d :3 0 4b9 9bb
4bb 9ba 9b9 :2 0
9bc 4bd :2 0 9be
0 9be 9bd 96b
9bc :6 0 13a4 16
:3 0 45 :3 0 67
:3 0 9c0 9c1 0
45 :3 0 c2 :2 0
c3 :3 0 9c3 9c5
0 4c2 9c4 9c7
:3 0 9c8 :2 0 24
:3 0 137 :2 0 4c5
9cb 9cc :3 0 9cd
:2 0 9ce :2 0 9c9
9d0 9cf :2 0 138
:3 0 9d2 :4 0 9d4
4c7 9d5 9d1 9d4
0 9d6 4c9 0
13a4 37 :3 0 139
:3 0 139 :3 0 2a
:3 0 1d :3 0 2a
:3 0 39 :3 0 40
:3 0 3f :3 0 16
:3 0 38 :3 0 1a
:4 0 13a 1 :8 0
9e9 45 :3 0 67
:3 0 9e4 9e5 0
68 :3 0 9e6 9e7
0 9e9 4cb a3c
69 :3 0 45 :3 0
67 :3 0 9eb 9ec
0 68 :3 0 9ed
9ee 0 9f0 4ce
9f2 4d0 9f1 9f0
:2 0 a3a 6a :3 0
45 :3 0 67 :3 0
9f5 9f6 0 68
:3 0 9f7 9f8 0
a32 4f :3 0 50
:3 0 9fa 9fb 0
4f :3 0 5f :3 0
9fd 9fe 0 6b
:2 0 2 :4 0 13b
:2 0 61 :2 0 a
:2 0 4d2 a03 a05
:3 0 4d5 9ff a07
9fc a09 a08 :2 0
52 :3 0 62 :3 0
a0b a0c 0 54
:4 0 13c :4 0 57
:2 0 58 :3 0 4d9
a10 a12 :3 0 57
:2 0 6e :4 0 4dc
a14 a16 :3 0 57
:2 0 6f :4 0 4df
a18 a1a :3 0 57
:2 0 68 :3 0 4e2
a1c a1e :3 0 57
:2 0 70 :4 0 4e5
a20 a22 :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 4e8 a25 a29
4ec a24 a2b :3 0
4ef a0d a2d :2 0
a2f 4f2 a30 a0a
a2f 0 a31 4f4
0 a32 4f6 a35
:3 0 a35 0 a35
a34 a32 a33 :6 0
a37 1f :3 0 4f9
a39 4fb a38 a37
:2 0 a3a 4fd :2 0
a3c 0 a3c a3b
9e9 a3a :6 0 13a4
16 :3 0 45 :3 0
67 :3 0 a3e a3f
0 45 :3 0 74
:2 0 c3 :3 0 a41
a43 0 502 a42
a45 :3 0 a46 :2 0
1d :3 0 13d :2 0
505 a49 a4a :3 0
a4b :2 0 a4c :2 0
a47 a4e a4d :2 0
e :3 0 29 :3 0
f :2 0 507 a50
a53 74 :2 0 f
:2 0 50c a55 a57
:3 0 23 :3 0 e3
:2 0 a59 a5a 0
a5c 50f c19 39
:3 0 37 :3 0 3
:4 0 13e 1 :8 0
a76 bb :4 0 a61
:3 0 bc :3 0 74
:2 0 513 a64 a65
:3 0 45 :3 0 67
:3 0 a67 a68 0
f :2 0 a69 a6a
0 a6c 516 a73
45 :3 0 67 :3 0
a6d a6e 0 bd
:2 0 a6f a70 0
a72 518 a74 a66
a6c 0 a75 0
a72 0 a75 51a
0 a76 51d ac9
69 :3 0 45 :3 0
67 :3 0 a78 a79
0 68 :3 0 a7a
a7b 0 a7d 520
a7f 522 a7e a7d
:2 0 ac7 6a :3 0
45 :3 0 67 :3 0
a82 a83 0 68
:3 0 a84 a85 0
abf 4f :3 0 50
:3 0 a87 a88 0
4f :3 0 5f :3 0
a8a a8b 0 6b
:2 0 2 :4 0 13f
:2 0 61 :2 0 a
:2 0 524 a90 a92
:3 0 527 a8c a94
a89 a96 a95 :2 0
52 :3 0 62 :3 0
a98 a99 0 54
:4 0 140 :4 0 57
:2 0 58 :3 0 52b
a9d a9f :3 0 57
:2 0 6e :4 0 52e
aa1 aa3 :3 0 57
:2 0 6f :4 0 531
aa5 aa7 :3 0 57
:2 0 68 :3 0 534
aa9 aab :3 0 57
:2 0 70 :4 0 537
aad aaf :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 53a ab2 ab6
53e ab1 ab8 :3 0
541 a9a aba :2 0
abc 544 abd a97
abc 0 abe 546
0 abf 548 ac2
:3 0 ac2 0 ac2
ac1 abf ac0 :6 0
ac4 21 :3 0 54b
ac6 54d ac5 ac4
:2 0 ac7 54f :2 0
ac9 0 ac9 ac8
a76 ac7 :6 0 c18
16 :3 0 141 :3 0
37 :3 0 3 :4 0
142 1 :8 0 ae4
bb :4 0 acf :3 0
bc :3 0 74 :2 0
554 ad2 ad3 :3 0
45 :3 0 67 :3 0
ad5 ad6 0 f
:2 0 ad7 ad8 0
ada 557 ae1 45
:3 0 67 :3 0 adb
adc 0 bd :2 0
add ade 0 ae0
559 ae2 ad4 ada
0 ae3 0 ae0
0 ae3 55b 0
ae4 55e b37 69
:3 0 45 :3 0 67
:3 0 ae6 ae7 0
68 :3 0 ae8 ae9
0 aeb 561 aed
563 aec aeb :2 0
b35 6a :3 0 45
:3 0 67 :3 0 af0
af1 0 68 :3 0
af2 af3 0 b2d
4f :3 0 50 :3 0
af5 af6 0 4f
:3 0 5f :3 0 af8
af9 0 6b :2 0
2 :4 0 143 :2 0
61 :2 0 a :2 0
565 afe b00 :3 0
568 afa b02 af7
b04 b03 :2 0 52
:3 0 62 :3 0 b06
b07 0 54 :4 0
144 :4 0 57 :2 0
58 :3 0 56c b0b
b0d :3 0 57 :2 0
6e :4 0 56f b0f
b11 :3 0 57 :2 0
6f :4 0 572 b13
b15 :3 0 57 :2 0
68 :3 0 575 b17
b19 :3 0 57 :2 0
70 :4 0 578 b1b
b1d :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
57b b20 b24 57f
b1f b26 :3 0 582
b08 b28 :2 0 b2a
585 b2b b05 b2a
0 b2c 587 0
b2d 589 b30 :3 0
b30 0 b30 b2f
b2d b2e :6 0 b32
23 :3 0 58c b34
58e b33 b32 :2 0
b35 590 :2 0 b37
0 b37 b36 ae4
b35 :6 0 c18 16
:3 0 145 :3 0 146
:3 0 3 :4 0 147
1 :8 0 b52 bb
:4 0 b3d :3 0 bc
:3 0 74 :2 0 595
b40 b41 :3 0 45
:3 0 67 :3 0 b43
b44 0 f :2 0
b45 b46 0 b48
598 b4f 45 :3 0
67 :3 0 b49 b4a
0 bd :2 0 b4b
b4c 0 b4e 59a
b50 b42 b48 0
b51 0 b4e 0
b51 59c 0 b52
59f ba5 69 :3 0
45 :3 0 67 :3 0
b54 b55 0 68
:3 0 b56 b57 0
b59 5a2 b5b 5a4
b5a b59 :2 0 ba3
6a :3 0 45 :3 0
67 :3 0 b5e b5f
0 68 :3 0 b60
b61 0 b9b 4f
:3 0 50 :3 0 b63
b64 0 4f :3 0
5f :3 0 b66 b67
0 6b :2 0 2
:4 0 148 :2 0 61
:2 0 a :2 0 5a6
b6c b6e :3 0 5a9
b68 b70 b65 b72
b71 :2 0 52 :3 0
62 :3 0 b74 b75
0 54 :4 0 149
:4 0 57 :2 0 58
:3 0 5ad b79 b7b
:3 0 57 :2 0 6e
:4 0 5b0 b7d b7f
:3 0 57 :2 0 6f
:4 0 5b3 b81 b83
:3 0 57 :2 0 68
:3 0 5b6 b85 b87
:3 0 57 :2 0 70
:4 0 5b9 b89 b8b
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 5bc
b8e b92 5c0 b8d
b94 :3 0 5c3 b76
b96 :2 0 b98 5c6
b99 b73 b98 0
b9a 5c8 0 b9b
5ca b9e :3 0 b9e
0 b9e b9d b9b
b9c :6 0 ba0 25
:3 0 5cd ba2 5cf
ba1 ba0 :2 0 ba3
5d1 :2 0 ba5 0
ba5 ba4 b52 ba3
:6 0 c18 16 :3 0
14a :3 0 146 :3 0
3 :4 0 14b 1
:8 0 bc0 bb :4 0
bab :3 0 bc :3 0
74 :2 0 5d6 bae
baf :3 0 45 :3 0
67 :3 0 bb1 bb2
0 f :2 0 bb3
bb4 0 bb6 5d9
bbd 45 :3 0 67
:3 0 bb7 bb8 0
bd :2 0 bb9 bba
0 bbc 5db bbe
bb0 bb6 0 bbf
0 bbc 0 bbf
5dd 0 bc0 5e0
c13 69 :3 0 45
:3 0 67 :3 0 bc2
bc3 0 68 :3 0
bc4 bc5 0 bc7
5e3 bc9 5e5 bc8
bc7 :2 0 c11 6a
:3 0 45 :3 0 67
:3 0 bcc bcd 0
68 :3 0 bce bcf
0 c09 4f :3 0
50 :3 0 bd1 bd2
0 4f :3 0 5f
:3 0 bd4 bd5 0
6b :2 0 2 :4 0
14c :2 0 61 :2 0
a :2 0 5e7 bda
bdc :3 0 5ea bd6
bde bd3 be0 bdf
:2 0 52 :3 0 62
:3 0 be2 be3 0
54 :4 0 14d :4 0
57 :2 0 58 :3 0
5ee be7 be9 :3 0
57 :2 0 6e :4 0
5f1 beb bed :3 0
57 :2 0 6f :4 0
5f4 bef bf1 :3 0
57 :2 0 68 :3 0
5f7 bf3 bf5 :3 0
57 :2 0 70 :4 0
5fa bf7 bf9 :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 5fd bfc
c00 601 bfb c02
:3 0 604 be4 c04
:2 0 c06 607 c07
be1 c06 0 c08
609 0 c09 60b
c0c :3 0 c0c 0
c0c c0b c09 c0a
:6 0 c0e 27 :3 0
60e c10 610 c0f
c0e :2 0 c11 612
:2 0 c13 0 c13
c12 bc0 c11 :6 0
c18 16 :3 0 23
:3 0 a :2 0 c15
c16 0 c18 615
c1a a58 a5c 0
c1b 0 c18 0
c1b 61b 0 c1c
61e c24 1d :3 0
3 :3 0 c1d c1e
0 c23 23 :3 0
f :2 0 c20 c21
0 c23 620 c25
a4f c1c 0 c26
0 c23 0 c26
623 0 13a4 24
:3 0 f :2 0 c27
c28 0 13a4 c0
:3 0 47 :4 0 c2d
:2 0 13a4 c2b c2e
:3 0 c1 :3 0 47
:3 0 18 :3 0 24
:3 0 10 :4 0 c35
:2 0 e53 c30 c36
:3 0 626 :3 0 47
:3 0 bb :3 0 c37
c38 :3 0 45 :3 0
67 :3 0 c3a c3b
0 f :2 0 c3c
c3d 0 c3f 62a
c46 45 :3 0 67
:3 0 c40 c41 0
bd :2 0 c42 c43
0 c45 62c c47
c39 c3f 0 c48
0 c45 0 c48
62e 0 e53 45
:3 0 67 :3 0 c49
c4a 0 45 :3 0
c2 :2 0 c3 :3 0
c4c c4e 0 633
c4d c50 :3 0 c51
:2 0 c4 :8 0 c55
636 c56 c52 c55
0 c57 638 0
e53 e :3 0 23
:3 0 f :2 0 63a
c58 c5b 74 :2 0
a :2 0 63f c5d
c5f :3 0 4b :3 0
49 :3 0 49 :3 0
24 :3 0 4a :3 0
14e :3 0 14f :3 0
4a :3 0 10 :3 0
3d :3 0 16 :3 0
37 :3 0 1d :3 0
48 :3 0 18 :4 0
150 1 :8 0 c86
bb :4 0 c71 :3 0
bc :3 0 74 :2 0
644 c74 c75 :3 0
45 :3 0 67 :3 0
c77 c78 0 f
:2 0 c79 c7a 0
c7c 647 c83 45
:3 0 67 :3 0 c7d
c7e 0 bd :2 0
c7f c80 0 c82
649 c84 c76 c7c
0 c85 0 c82
0 c85 64b 0
c86 64e cd9 69
:3 0 45 :3 0 67
:3 0 c88 c89 0
68 :3 0 c8a c8b
0 c8d 651 c8f
653 c8e c8d :2 0
cd7 6a :3 0 45
:3 0 67 :3 0 c92
c93 0 68 :3 0
c94 c95 0 ccf
4f :3 0 50 :3 0
c97 c98 0 4f
:3 0 5f :3 0 c9a
c9b 0 6b :2 0
2 :4 0 151 :2 0
61 :2 0 a :2 0
655 ca0 ca2 :3 0
658 c9c ca4 c99
ca6 ca5 :2 0 52
:3 0 62 :3 0 ca8
ca9 0 54 :4 0
152 :4 0 57 :2 0
58 :3 0 65c cad
caf :3 0 57 :2 0
6e :4 0 65f cb1
cb3 :3 0 57 :2 0
6f :4 0 662 cb5
cb7 :3 0 57 :2 0
68 :3 0 665 cb9
cbb :3 0 57 :2 0
70 :4 0 668 cbd
cbf :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
66b cc2 cc6 66f
cc1 cc8 :3 0 672
caa cca :2 0 ccc
675 ccd ca7 ccc
0 cce 677 0
ccf 679 cd2 :3 0
cd2 0 cd2 cd1
ccf cd0 :6 0 cd4
2a :3 0 67c cd6
67e cd5 cd4 :2 0
cd7 680 :2 0 cd9
0 cd9 cd8 c86
cd7 :6 0 dd1 29
:3 0 45 :3 0 67
:3 0 cdb cdc 0
45 :3 0 74 :2 0
c3 :3 0 cde ce0
0 685 cdf ce2
:3 0 ce3 :2 0 4b
:3 0 3d :3 0 16
:3 0 37 :3 0 3
:3 0 48 :3 0 18
:4 0 153 1 :8 0
d02 bb :4 0 ced
:3 0 bc :3 0 74
:2 0 68a cf0 cf1
:3 0 45 :3 0 67
:3 0 cf3 cf4 0
f :2 0 cf5 cf6
0 cf8 68d cff
45 :3 0 67 :3 0
cf9 cfa 0 bd
:2 0 cfb cfc 0
cfe 68f d00 cf2
cf8 0 d01 0
cfe 0 d01 691
0 d02 694 d55
69 :3 0 45 :3 0
67 :3 0 d04 d05
0 68 :3 0 d06
d07 0 d09 697
d0b 699 d0a d09
:2 0 d53 6a :3 0
45 :3 0 67 :3 0
d0e d0f 0 68
:3 0 d10 d11 0
d4b 4f :3 0 50
:3 0 d13 d14 0
4f :3 0 5f :3 0
d16 d17 0 6b
:2 0 2 :4 0 154
:2 0 61 :2 0 a
:2 0 69b d1c d1e
:3 0 69e d18 d20
d15 d22 d21 :2 0
52 :3 0 62 :3 0
d24 d25 0 54
:4 0 155 :4 0 57
:2 0 58 :3 0 6a2
d29 d2b :3 0 57
:2 0 6e :4 0 6a5
d2d d2f :3 0 57
:2 0 6f :4 0 6a8
d31 d33 :3 0 57
:2 0 68 :3 0 6ab
d35 d37 :3 0 57
:2 0 70 :4 0 6ae
d39 d3b :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 6b1 d3e d42
6b5 d3d d44 :3 0
6b8 d26 d46 :2 0
d48 6bb d49 d23
d48 0 d4a 6bd
0 d4b 6bf d4e
:3 0 d4e 0 d4e
d4d d4b d4c :6 0
d50 2c :3 0 6c2
d52 6c4 d51 d50
:2 0 d53 6c6 :2 0
d55 0 d55 d54
d02 d53 :6 0 d57
29 :3 0 6c9 dcd
4b :3 0 37 :3 0
1d :3 0 3d :3 0
16 :3 0 37 :3 0
3 :3 0 48 :3 0
18 :4 0 156 1
:8 0 d77 bb :4 0
d62 :3 0 bc :3 0
74 :2 0 6cd d65
d66 :3 0 45 :3 0
67 :3 0 d68 d69
0 f :2 0 d6a
d6b 0 d6d 6d0
d74 45 :3 0 67
:3 0 d6e d6f 0
bd :2 0 d70 d71
0 d73 6d2 d75
d67 d6d 0 d76
0 d73 0 d76
6d4 0 d77 6d7
dca 69 :3 0 45
:3 0 67 :3 0 d79
d7a 0 68 :3 0
d7b d7c 0 d7e
6da d80 6dc d7f
d7e :2 0 dc8 6a
:3 0 45 :3 0 67
:3 0 d83 d84 0
68 :3 0 d85 d86
0 dc0 4f :3 0
50 :3 0 d88 d89
0 4f :3 0 5f
:3 0 d8b d8c 0
6b :2 0 2 :4 0
157 :2 0 61 :2 0
a :2 0 6de d91
d93 :3 0 6e1 d8d
d95 d8a d97 d96
:2 0 52 :3 0 62
:3 0 d99 d9a 0
54 :4 0 158 :4 0
57 :2 0 58 :3 0
6e5 d9e da0 :3 0
57 :2 0 6e :4 0
6e8 da2 da4 :3 0
57 :2 0 6f :4 0
6eb da6 da8 :3 0
57 :2 0 68 :3 0
6ee daa dac :3 0
57 :2 0 70 :4 0
6f1 dae db0 :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 6f4 db3
db7 6f8 db2 db9
:3 0 6fb d9b dbb
:2 0 dbd 6fe dbe
d98 dbd 0 dbf
700 0 dc0 702
dc3 :3 0 dc3 0
dc3 dc2 dc0 dc1
:6 0 dc5 2e :3 0
705 dc7 707 dc6
dc5 :2 0 dc8 709
:2 0 dca 0 dca
dc9 d77 dc8 :6 0
dcc 29 :3 0 70c
dce ce4 d57 0
dcf 0 dcc 0
dcf 70e 0 dd1
8c :3 0 711 e51
e :3 0 23 :3 0
f :2 0 714 dd2
dd5 74 :2 0 e3
:2 0 719 dd7 dd9
:3 0 4b :3 0 37
:3 0 1d :3 0 3d
:3 0 16 :3 0 37
:3 0 3 :3 0 48
:3 0 18 :4 0 156
1 :8 0 dfa bb
:4 0 de5 :3 0 bc
:3 0 74 :2 0 71e
de8 de9 :3 0 45
:3 0 67 :3 0 deb
dec 0 f :2 0
ded dee 0 df0
721 df7 45 :3 0
67 :3 0 df1 df2
0 bd :2 0 df3
df4 0 df6 723
df8 dea df0 0
df9 0 df6 0
df9 725 0 dfa
728 e4d 69 :3 0
45 :3 0 67 :3 0
dfc dfd 0 68
:3 0 dfe dff 0
e01 72b e03 72d
e02 e01 :2 0 e4b
6a :3 0 45 :3 0
67 :3 0 e06 e07
0 68 :3 0 e08
e09 0 e43 4f
:3 0 50 :3 0 e0b
e0c 0 4f :3 0
5f :3 0 e0e e0f
0 6b :2 0 2
:4 0 159 :2 0 61
:2 0 a :2 0 72f
e14 e16 :3 0 732
e10 e18 e0d e1a
e19 :2 0 52 :3 0
62 :3 0 e1c e1d
0 54 :4 0 15a
:4 0 57 :2 0 58
:3 0 736 e21 e23
:3 0 57 :2 0 6e
:4 0 739 e25 e27
:3 0 57 :2 0 6f
:4 0 73c e29 e2b
:3 0 57 :2 0 68
:3 0 73f e2d e2f
:3 0 57 :2 0 70
:4 0 742 e31 e33
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 745
e36 e3a 749 e35
e3c :3 0 74c e1e
e3e :2 0 e40 74f
e41 e1b e40 0
e42 751 0 e43
753 e46 :3 0 e46
0 e46 e45 e43
e44 :6 0 e48 30
:3 0 756 e4a 758
e49 e48 :2 0 e4b
75a :2 0 e4d 0
e4d e4c dfa e4b
:6 0 e4f 29 :3 0
75d e50 dda e4f
0 e52 c60 dd1
0 e52 75f 0
e53 762 e55 c1
:4 0 e53 :4 0 13a4
db :3 0 47 :4 0
e59 :2 0 e5f e57
0 45 :3 0 67
:3 0 e5a e5b 0
68 :3 0 e5c e5d
0 e5f 767 eb2
69 :3 0 45 :3 0
67 :3 0 e61 e62
0 68 :3 0 e63
e64 0 e66 76a
e68 76c e67 e66
:2 0 eb0 6a :3 0
45 :3 0 67 :3 0
e6b e6c 0 68
:3 0 e6d e6e 0
ea8 4f :3 0 50
:3 0 e70 e71 0
4f :3 0 5f :3 0
e73 e74 0 6b
:2 0 2 :4 0 15b
:2 0 61 :2 0 a
:2 0 76e e79 e7b
:3 0 771 e75 e7d
e72 e7f e7e :2 0
52 :3 0 62 :3 0
e81 e82 0 54
:4 0 15c :4 0 57
:2 0 58 :3 0 775
e86 e88 :3 0 57
:2 0 6e :4 0 778
e8a e8c :3 0 57
:2 0 6f :4 0 77b
e8e e90 :3 0 57
:2 0 68 :3 0 77e
e92 e94 :3 0 57
:2 0 70 :4 0 781
e96 e98 :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 784 e9b e9f
788 e9a ea1 :3 0
78b e83 ea3 :2 0
ea5 78e ea6 e80
ea5 0 ea7 790
0 ea8 792 eab
:3 0 eab 0 eab
eaa ea8 ea9 :6 0
ead 32 :3 0 795
eaf 797 eae ead
:2 0 eb0 799 :2 0
eb2 0 eb2 eb1
e5f eb0 :6 0 13a4
16 :3 0 4b :3 0
40 :3 0 15d :3 0
1d :3 0 3d :3 0
16 :3 0 15d :3 0
3 :4 0 15e 1
:8 0 ed2 bb :4 0
ebd :3 0 bc :3 0
74 :2 0 79e ec0
ec1 :3 0 45 :3 0
67 :3 0 ec3 ec4
0 f :2 0 ec5
ec6 0 ec8 7a1
ecf 45 :3 0 67
:3 0 ec9 eca 0
bd :2 0 ecb ecc
0 ece 7a3 ed0
ec2 ec8 0 ed1
0 ece 0 ed1
7a5 0 ed2 7a8
f25 69 :3 0 45
:3 0 67 :3 0 ed4
ed5 0 68 :3 0
ed6 ed7 0 ed9
7ab edb 7ad eda
ed9 :2 0 f23 6a
:3 0 45 :3 0 67
:3 0 ede edf 0
68 :3 0 ee0 ee1
0 f1b 4f :3 0
50 :3 0 ee3 ee4
0 4f :3 0 5f
:3 0 ee6 ee7 0
6b :2 0 2 :4 0
15f :2 0 61 :2 0
a :2 0 7af eec
eee :3 0 7b2 ee8
ef0 ee5 ef2 ef1
:2 0 52 :3 0 62
:3 0 ef4 ef5 0
54 :4 0 160 :4 0
57 :2 0 58 :3 0
7b6 ef9 efb :3 0
57 :2 0 6e :4 0
7b9 efd eff :3 0
57 :2 0 6f :4 0
7bc f01 f03 :3 0
57 :2 0 68 :3 0
7bf f05 f07 :3 0
57 :2 0 70 :4 0
7c2 f09 f0b :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 7c5 f0e
f12 7c9 f0d f14
:3 0 7cc ef6 f16
:2 0 f18 7cf f19
ef3 f18 0 f1a
7d1 0 f1b 7d3
f1e :3 0 f1e 0
f1e f1d f1b f1c
:6 0 f20 34 :3 0
7d6 f22 7d8 f21
f20 :2 0 f23 7da
:2 0 f25 0 f25
f24 ed2 f23 :6 0
13a4 16 :3 0 e
:3 0 29 :3 0 f
:2 0 7dd f27 f2a
74 :2 0 f :2 0
7e2 f2c f2e :3 0
39 :3 0 40 :3 0
161 :3 0 13 :3 0
162 :3 0 163 :3 0
13 :3 0 164 :3 0
9c :3 0 9d :3 0
9e :3 0 9f :3 0
a0 :3 0 a1 :3 0
c5 :3 0 c6 :3 0
c7 :3 0 9d :3 0
c8 :3 0 9f :3 0
c9 :3 0 c6 :3 0
ca :3 0 cb :3 0
cb :3 0 ca :3 0
cc :3 0 cd :3 0
cd :3 0 cc :3 0
a7 :3 0 c6 :3 0
ce :3 0 a7 :3 0
c6 :3 0 d0 :3 0
d1 :3 0 d2 :3 0
cf :3 0 a7 :3 0
c6 :3 0 d3 :3 0
d4 :3 0 9d :3 0
9f :3 0 a1 :3 0
c6 :3 0 a4 :3 0
a5 :3 0 a8 :3 0
42 :3 0 37 :3 0
3 :3 0 c5 :3 0
c6 :4 0 165 1
:8 0 f7d bb :4 0
f68 :3 0 bc :3 0
74 :2 0 7e7 f6b
f6c :3 0 45 :3 0
67 :3 0 f6e f6f
0 f :2 0 f70
f71 0 f73 7ea
f7a 45 :3 0 67
:3 0 f74 f75 0
bd :2 0 f76 f77
0 f79 7ec f7b
f6d f73 0 f7c
0 f79 0 f7c
7ee 0 f7d 7f1
fd0 69 :3 0 45
:3 0 67 :3 0 f7f
f80 0 68 :3 0
f81 f82 0 f84
7f4 f86 7f6 f85
f84 :2 0 fce 6a
:3 0 45 :3 0 67
:3 0 f89 f8a 0
68 :3 0 f8b f8c
0 fc6 4f :3 0
50 :3 0 f8e f8f
0 4f :3 0 5f
:3 0 f91 f92 0
6b :2 0 2 :4 0
166 :2 0 61 :2 0
a :2 0 7f8 f97
f99 :3 0 7fb f93
f9b f90 f9d f9c
:2 0 52 :3 0 62
:3 0 f9f fa0 0
54 :4 0 167 :4 0
57 :2 0 58 :3 0
7ff fa4 fa6 :3 0
57 :2 0 6e :4 0
802 fa8 faa :3 0
57 :2 0 6f :4 0
805 fac fae :3 0
57 :2 0 68 :3 0
808 fb0 fb2 :3 0
57 :2 0 70 :4 0
80b fb4 fb6 :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 80e fb9
fbd 812 fb8 fbf
:3 0 815 fa1 fc1
:2 0 fc3 818 fc4
f9e fc3 0 fc5
81a 0 fc6 81c
fc9 :3 0 fc9 0
fc9 fc8 fc6 fc7
:6 0 fcb 36 :3 0
81f fcd 821 fcc
fcb :2 0 fce 823
:2 0 fd0 0 fd0
fcf f7d fce :6 0
feb 16 :3 0 e
:3 0 23 :3 0 f
:2 0 826 fd2 fd5
74 :2 0 e3 :2 0
82b fd7 fd9 :3 0
2b :3 0 98 :2 0
fdb fdc 0 fe8
2c :3 0 168 :3 0
16 :3 0 1d :3 0
2b :3 0 f :2 0
f :2 0 82e fdf
fe5 fde fe6 0
fe8 834 fe9 fda
fe8 0 fea 837
0 feb 839 139d
c0 :3 0 4d :4 0
fef :2 0 139c fed
ff0 :3 0 c1 :3 0
4d :3 0 1b :3 0
1c :4 0 ff6 :2 0
112b ff2 ff7 :3 0
83c :3 0 4d :3 0
bb :3 0 ff8 ff9
:3 0 45 :3 0 67
:3 0 ffb ffc 0
f :2 0 ffd ffe
0 1000 83f 1007
45 :3 0 67 :3 0
1001 1002 0 bd
:2 0 1003 1004 0
1006 841 1008 ffa
1000 0 1009 0
1006 0 1009 843
0 112b 45 :3 0
67 :3 0 100a 100b
0 45 :3 0 c2
:2 0 c3 :3 0 100d
100f 0 848 100e
1011 :3 0 1012 :2 0
c4 :8 0 1016 84b
1017 1013 1016 0
1018 84d 0 112b
39 :3 0 40 :3 0
161 :3 0 13 :3 0
162 :3 0 163 :3 0
13 :3 0 164 :3 0
9c :3 0 9d :3 0
9e :3 0 9f :3 0
a0 :3 0 a1 :3 0
c5 :3 0 c6 :3 0
c7 :3 0 9d :3 0
c8 :3 0 9f :3 0
c9 :3 0 c6 :3 0
ca :3 0 cb :3 0
cb :3 0 ca :3 0
cc :3 0 cd :3 0
cd :3 0 cc :3 0
a7 :3 0 c6 :3 0
ce :3 0 a7 :3 0
c6 :3 0 d0 :3 0
d1 :3 0 d2 :3 0
cf :3 0 a7 :3 0
c6 :3 0 d3 :3 0
d4 :3 0 9d :3 0
9f :3 0 a1 :3 0
c6 :3 0 a4 :3 0
a5 :3 0 a8 :3 0
42 :3 0 1d :3 0
37 :3 0 1c :4 0
169 1 :8 0 1065
bb :4 0 1050 :3 0
bc :3 0 74 :2 0
851 1053 1054 :3 0
45 :3 0 67 :3 0
1056 1057 0 f
:2 0 1058 1059 0
105b 854 1062 45
:3 0 67 :3 0 105c
105d 0 bd :2 0
105e 105f 0 1061
856 1063 1055 105b
0 1064 0 1061
0 1064 858 0
1065 85b 10b8 69
:3 0 45 :3 0 67
:3 0 1067 1068 0
68 :3 0 1069 106a
0 106c 85e 106e
860 106d 106c :2 0
10b6 6a :3 0 45
:3 0 67 :3 0 1071
1072 0 68 :3 0
1073 1074 0 10ae
4f :3 0 50 :3 0
1076 1077 0 4f
:3 0 5f :3 0 1079
107a 0 6b :2 0
2 :4 0 16a :2 0
61 :2 0 a :2 0
862 107f 1081 :3 0
865 107b 1083 1078
1085 1084 :2 0 52
:3 0 62 :3 0 1087
1088 0 54 :4 0
16b :4 0 57 :2 0
58 :3 0 869 108c
108e :3 0 57 :2 0
6e :4 0 86c 1090
1092 :3 0 57 :2 0
6f :4 0 86f 1094
1096 :3 0 57 :2 0
68 :3 0 872 1098
109a :3 0 57 :2 0
70 :4 0 875 109c
109e :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
878 10a1 10a5 87c
10a0 10a7 :3 0 87f
1089 10a9 :2 0 10ab
882 10ac 1086 10ab
0 10ad 884 0
10ae 886 10b1 :3 0
10b1 0 10b1 10b0
10ae 10af :6 0 10b3
39 :3 0 889 10b5
88b 10b4 10b3 :2 0
10b6 88d :2 0 10b8
0 10b8 10b7 1065
10b6 :6 0 112b 38
:3 0 3b :3 0 de
:3 0 13 :3 0 df
:3 0 3e :3 0 1b
:4 0 16c 1 :8 0
10d6 bb :4 0 10c1
:3 0 bc :3 0 74
:2 0 892 10c4 10c5
:3 0 45 :3 0 67
:3 0 10c7 10c8 0
f :2 0 10c9 10ca
0 10cc 895 10d3
45 :3 0 67 :3 0
10cd 10ce 0 bd
:2 0 10cf 10d0 0
10d2 897 10d4 10c6
10cc 0 10d5 0
10d2 0 10d5 899
0 10d6 89c 1129
69 :3 0 45 :3 0
67 :3 0 10d8 10d9
0 68 :3 0 10da
10db 0 10dd 89f
10df 8a1 10de 10dd
:2 0 1127 6a :3 0
45 :3 0 67 :3 0
10e2 10e3 0 68
:3 0 10e4 10e5 0
111f 4f :3 0 50
:3 0 10e7 10e8 0
4f :3 0 5f :3 0
10ea 10eb 0 6b
:2 0 2 :4 0 16d
:2 0 61 :2 0 a
:2 0 8a3 10f0 10f2
:3 0 8a6 10ec 10f4
10e9 10f6 10f5 :2 0
52 :3 0 62 :3 0
10f8 10f9 0 54
:4 0 16e :4 0 57
:2 0 58 :3 0 8aa
10fd 10ff :3 0 57
:2 0 6e :4 0 8ad
1101 1103 :3 0 57
:2 0 6f :4 0 8b0
1105 1107 :3 0 57
:2 0 68 :3 0 8b3
1109 110b :3 0 57
:2 0 70 :4 0 8b6
110d 110f :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 8b9 1112 1116
8bd 1111 1118 :3 0
8c0 10fa 111a :2 0
111c 8c3 111d 10f7
111c 0 111e 8c5
0 111f 8c7 1122
:3 0 1122 0 1122
1121 111f 1120 :6 0
1124 3b :3 0 8ca
1126 8cc 1125 1124
:2 0 1127 8ce :2 0
1129 0 1129 1128
10d6 1127 :6 0 112b
38 :3 0 8d1 112d
c1 :4 0 112b :4 0
139c db :3 0 4d
:4 0 1131 :2 0 1137
112f 0 45 :3 0
67 :3 0 1132 1133
0 68 :3 0 1134
1135 0 1137 8d7
118a 69 :3 0 45
:3 0 67 :3 0 1139
113a 0 68 :3 0
113b 113c 0 113e
8da 1140 8dc 113f
113e :2 0 1188 6a
:3 0 45 :3 0 67
:3 0 1143 1144 0
68 :3 0 1145 1146
0 1180 4f :3 0
50 :3 0 1148 1149
0 4f :3 0 5f
:3 0 114b 114c 0
6b :2 0 2 :4 0
16f :2 0 61 :2 0
a :2 0 8de 1151
1153 :3 0 8e1 114d
1155 114a 1157 1156
:2 0 52 :3 0 62
:3 0 1159 115a 0
54 :4 0 170 :4 0
57 :2 0 58 :3 0
8e5 115e 1160 :3 0
57 :2 0 6e :4 0
8e8 1162 1164 :3 0
57 :2 0 6f :4 0
8eb 1166 1168 :3 0
57 :2 0 68 :3 0
8ee 116a 116c :3 0
57 :2 0 70 :4 0
8f1 116e 1170 :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 8f4 1173
1177 8f8 1172 1179
:3 0 8fb 115b 117b
:2 0 117d 8fe 117e
1158 117d 0 117f
900 0 1180 902
1183 :3 0 1183 0
1183 1182 1180 1181
:6 0 1185 3d :3 0
905 1187 907 1186
1185 :2 0 1188 909
:2 0 118a 0 118a
1189 1137 1188 :6 0
139c 16 :3 0 e
:3 0 29 :3 0 f
:2 0 90c 118c 118f
74 :2 0 a :2 0
911 1191 1193 :3 0
1194 :2 0 e :3 0
2a :3 0 f :2 0
914 1196 1199 171
:2 0 f :2 0 919
119b 119d :3 0 119e
:2 0 1195 11a0 119f
:2 0 39 :3 0 139
:3 0 2a :3 0 37
:3 0 1d :4 0 172
1 :8 0 11bd bb
:4 0 11a8 :3 0 bc
:3 0 74 :2 0 91e
11ab 11ac :3 0 45
:3 0 67 :3 0 11ae
11af 0 f :2 0
11b0 11b1 0 11b3
921 11ba 45 :3 0
67 :3 0 11b4 11b5
0 bd :2 0 11b6
11b7 0 11b9 923
11bb 11ad 11b3 0
11bc 0 11b9 0
11bc 925 0 11bd
928 1210 69 :3 0
45 :3 0 67 :3 0
11bf 11c0 0 68
:3 0 11c1 11c2 0
11c4 92b 11c6 92d
11c5 11c4 :2 0 120e
6a :3 0 45 :3 0
67 :3 0 11c9 11ca
0 68 :3 0 11cb
11cc 0 1206 4f
:3 0 50 :3 0 11ce
11cf 0 4f :3 0
5f :3 0 11d1 11d2
0 6b :2 0 2
:4 0 173 :2 0 61
:2 0 a :2 0 92f
11d7 11d9 :3 0 932
11d3 11db 11d0 11dd
11dc :2 0 52 :3 0
62 :3 0 11df 11e0
0 54 :4 0 174
:4 0 57 :2 0 58
:3 0 936 11e4 11e6
:3 0 57 :2 0 6e
:4 0 939 11e8 11ea
:3 0 57 :2 0 6f
:4 0 93c 11ec 11ee
:3 0 57 :2 0 68
:3 0 93f 11f0 11f2
:3 0 57 :2 0 70
:4 0 942 11f4 11f6
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 945
11f9 11fd 949 11f8
11ff :3 0 94c 11e1
1201 :2 0 1203 94f
1204 11de 1203 0
1205 951 0 1206
953 1209 :3 0 1209
0 1209 1208 1206
1207 :6 0 120b 3f
:3 0 956 120d 958
120c 120b :2 0 120e
95a :2 0 1210 0
1210 120f 11bd 120e
:6 0 1212 16 :3 0
95d 1213 11a1 1212
0 1214 95f 0
139c 2b :3 0 98
:2 0 1215 1216 0
139c 2c :3 0 168
:3 0 16 :3 0 1d
:3 0 2b :3 0 f
:2 0 f :2 0 961
1219 121f 1218 1220
0 139c 42 :3 0
175 :3 0 9c :3 0
9e :3 0 cf :3 0
d0 :3 0 d3 :3 0
1d :3 0 21 :3 0
1e :3 0 20 :3 0
22 :3 0 2d :3 0
30 :3 0 39 :3 0
37 :3 0 1d :4 0
176 1 :8 0 1239
45 :3 0 67 :3 0
1234 1235 0 68
:3 0 1236 1237 0
1239 967 128c 69
:3 0 45 :3 0 67
:3 0 123b 123c 0
68 :3 0 123d 123e
0 1240 96a 1242
96c 1241 1240 :2 0
128a 6a :3 0 45
:3 0 67 :3 0 1245
1246 0 68 :3 0
1247 1248 0 1282
4f :3 0 50 :3 0
124a 124b 0 4f
:3 0 5f :3 0 124d
124e 0 6b :2 0
2 :4 0 177 :2 0
61 :2 0 a :2 0
96e 1253 1255 :3 0
971 124f 1257 124c
1259 1258 :2 0 52
:3 0 62 :3 0 125b
125c 0 54 :4 0
178 :4 0 57 :2 0
58 :3 0 975 1260
1262 :3 0 57 :2 0
6e :4 0 978 1264
1266 :3 0 57 :2 0
6f :4 0 97b 1268
126a :3 0 57 :2 0
68 :3 0 97e 126c
126e :3 0 57 :2 0
70 :4 0 981 1270
1272 :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
984 1275 1279 988
1274 127b :3 0 98b
125d 127d :2 0 127f
98e 1280 125a 127f
0 1281 990 0
1282 992 1285 :3 0
1285 0 1285 1284
1282 1283 :6 0 1287
41 :3 0 995 1289
997 1288 1287 :2 0
128a 999 :2 0 128c
0 128c 128b 1239
128a :6 0 139c 16
:3 0 e :3 0 22
:3 0 f :2 0 99c
128e 1291 74 :2 0
f :2 0 9a1 1293
1295 :3 0 111 :3 0
116 :3 0 11b :3 0
120 :3 0 125 :3 0
12a :3 0 115 :3 0
1e :3 0 11a :3 0
20 :3 0 11f :3 0
21 :3 0 124 :3 0
21 :3 0 2d :3 0
129 :3 0 3d :3 0
16 :3 0 38 :3 0
1a :4 0 179 1
:8 0 12c1 bb :4 0
12ac :3 0 bc :3 0
74 :2 0 9a6 12af
12b0 :3 0 45 :3 0
67 :3 0 12b2 12b3
0 f :2 0 12b4
12b5 0 12b7 9a9
12be 45 :3 0 67
:3 0 12b8 12b9 0
bd :2 0 12ba 12bb
0 12bd 9ab 12bf
12b1 12b7 0 12c0
0 12bd 0 12c0
9ad 0 12c1 9b0
1314 69 :3 0 45
:3 0 67 :3 0 12c3
12c4 0 68 :3 0
12c5 12c6 0 12c8
9b3 12ca 9b5 12c9
12c8 :2 0 1312 6a
:3 0 45 :3 0 67
:3 0 12cd 12ce 0
68 :3 0 12cf 12d0
0 130a 4f :3 0
50 :3 0 12d2 12d3
0 4f :3 0 5f
:3 0 12d5 12d6 0
6b :2 0 2 :4 0
17a :2 0 61 :2 0
a :2 0 9b7 12db
12dd :3 0 9ba 12d7
12df 12d4 12e1 12e0
:2 0 52 :3 0 62
:3 0 12e3 12e4 0
54 :4 0 17b :4 0
57 :2 0 58 :3 0
9be 12e8 12ea :3 0
57 :2 0 6e :4 0
9c1 12ec 12ee :3 0
57 :2 0 6f :4 0
9c4 12f0 12f2 :3 0
57 :2 0 68 :3 0
9c7 12f4 12f6 :3 0
57 :2 0 70 :4 0
9ca 12f8 12fa :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 9cd 12fd
1301 9d1 12fc 1303
:3 0 9d4 12e5 1305
:2 0 1307 9d7 1308
12e2 1307 0 1309
9d9 0 130a 9db
130d :3 0 130d 0
130d 130c 130a 130b
:6 0 130f 43 :3 0
9de 1311 9e0 1310
130f :2 0 1312 9e2
:2 0 1314 0 1314
1313 12c1 1312 :6 0
1316 16 :3 0 9e5
1399 111 :3 0 116
:3 0 11b :3 0 120
:3 0 125 :3 0 12a
:3 0 115 :3 0 1e
:3 0 11a :3 0 20
:3 0 11f :3 0 21
:3 0 124 :3 0 21
:3 0 2d :3 0 129
:3 0 21 :3 0 30
:3 0 3d :3 0 16
:3 0 38 :3 0 1a
:4 0 17c 1 :8 0
1343 bb :4 0 132e
:3 0 bc :3 0 74
:2 0 9e9 1331 1332
:3 0 45 :3 0 67
:3 0 1334 1335 0
f :2 0 1336 1337
0 1339 9ec 1340
45 :3 0 67 :3 0
133a 133b 0 bd
:2 0 133c 133d 0
133f 9ee 1341 1333
1339 0 1342 0
133f 0 1342 9f0
0 1343 9f3 1396
69 :3 0 45 :3 0
67 :3 0 1345 1346
0 68 :3 0 1347
1348 0 134a 9f6
134c 9f8 134b 134a
:2 0 1394 6a :3 0
45 :3 0 67 :3 0
134f 1350 0 68
:3 0 1351 1352 0
138c 4f :3 0 50
:3 0 1354 1355 0
4f :3 0 5f :3 0
1357 1358 0 6b
:2 0 2 :4 0 17d
:2 0 61 :2 0 a
:2 0 9fa 135d 135f
:3 0 9fd 1359 1361
1356 1363 1362 :2 0
52 :3 0 62 :3 0
1365 1366 0 54
:4 0 17e :4 0 57
:2 0 58 :3 0 a01
136a 136c :3 0 57
:2 0 6e :4 0 a04
136e 1370 :3 0 57
:2 0 6f :4 0 a07
1372 1374 :3 0 57
:2 0 68 :3 0 a0a
1376 1378 :3 0 57
:2 0 70 :4 0 a0d
137a 137c :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 a10 137f 1383
a14 137e 1385 :3 0
a17 1367 1387 :2 0
1389 a1a 138a 1364
1389 0 138b a1c
0 138c a1e 138f
:3 0 138f 0 138f
138e 138c 138d :6 0
1391 45 :3 0 a21
1393 a23 1392 1391
:2 0 1394 a25 :2 0
1396 0 1396 1395
1343 1394 :6 0 1398
16 :3 0 a28 139a
1296 1316 0 139b
0 1398 0 139b
a2a 0 139c a2d
139e f2f feb 0
139f 0 139c 0
139f a36 0 13a4
138 :5 0 13a2 47
0 13a3 a39 13a2
13a1 13a4 a3b 13a6
a47 13a5 13a4 :2 0
13aa 0 13a8 a49
13a9 0 13a8 :2 0
13aa a4b :2 0 13ab
75e 13aa 0 141d
0 3b :3 0 de
:3 0 13 :3 0 df
:3 0 3e :3 0 1b
:4 0 16c 1 :8 0
13c8 bb :4 0 13b3
:3 0 bc :3 0 74
:2 0 a51 13b6 13b7
:3 0 45 :3 0 67
:3 0 13b9 13ba 0
f :2 0 13bb 13bc
0 13be a54 13c5
45 :3 0 67 :3 0
13bf 13c0 0 bd
:2 0 13c1 13c2 0
13c4 a56 13c6 13b8
13be 0 13c7 0
13c4 0 13c7 a58
0 13c8 a5b 141b
69 :3 0 45 :3 0
67 :3 0 13ca 13cb
0 68 :3 0 13cc
13cd 0 13cf a5e
13d1 a60 13d0 13cf
:2 0 1419 6a :3 0
45 :3 0 67 :3 0
13d4 13d5 0 68
:3 0 13d6 13d7 0
1411 4f :3 0 50
:3 0 13d9 13da 0
4f :3 0 5f :3 0
13dc 13dd 0 6b
:2 0 2 :4 0 17f
:2 0 61 :2 0 a
:2 0 a62 13e2 13e4
:3 0 a65 13de 13e6
13db 13e8 13e7 :2 0
52 :3 0 62 :3 0
13ea 13eb 0 54
:4 0 180 :4 0 57
:2 0 58 :3 0 a69
13ef 13f1 :3 0 57
:2 0 6e :4 0 a6c
13f3 13f5 :3 0 57
:2 0 6f :4 0 a6f
13f7 13f9 :3 0 57
:2 0 68 :3 0 a72
13fb 13fd :3 0 57
:2 0 70 :4 0 a75
13ff 1401 :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 a78 1404 1408
a7c 1403 140a :3 0
a7f 13ec 140c :2 0
140e a82 140f 13e9
140e 0 1410 a84
0 1411 a86 1414
:3 0 1414 0 1414
1413 1411 1412 :6 0
1416 47 :3 0 a89
1418 a8b 1417 1416
:2 0 1419 a8d :2 0
141b 0 141b 141a
13c8 1419 :6 0 141d
16 :3 0 a90 141f
c1 :4 0 141d :4 0
15c3 db :3 0 44
:4 0 1423 :2 0 1429
1421 0 45 :3 0
67 :3 0 1424 1425
0 68 :3 0 1426
1427 0 1429 a96
147c 69 :3 0 45
:3 0 67 :3 0 142b
142c 0 68 :3 0
142d 142e 0 1430
a99 1432 a9b 1431
1430 :2 0 147a 6a
:3 0 45 :3 0 67
:3 0 1435 1436 0
68 :3 0 1437 1438
0 1472 4f :3 0
50 :3 0 143a 143b
0 4f :3 0 5f
:3 0 143d 143e 0
6b :2 0 2 :4 0
181 :2 0 61 :2 0
a :2 0 a9d 1443
1445 :3 0 aa0 143f
1447 143c 1449 1448
:2 0 52 :3 0 62
:3 0 144b 144c 0
54 :4 0 182 :4 0
57 :2 0 58 :3 0
aa4 1450 1452 :3 0
57 :2 0 6e :4 0
aa7 1454 1456 :3 0
57 :2 0 6f :4 0
aaa 1458 145a :3 0
57 :2 0 68 :3 0
aad 145c 145e :3 0
57 :2 0 70 :4 0
ab0 1460 1462 :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 ab3 1465
1469 ab7 1464 146b
:3 0 aba 144d 146d
:2 0 146f abd 1470
144a 146f 0 1471
abf 0 1472 ac1
1475 :3 0 1475 0
1475 1474 1472 1473
:6 0 1477 49 :3 0
ac4 1479 ac6 1478
1477 :2 0 147a ac8
:2 0 147c 0 147c
147b 1429 147a :6 0
15c3 1 :3 0 d
:3 0 74 :2 0 a
:2 0 acd 147f 1481
:3 0 2c :3 0 183
:3 0 16 :3 0 ad0
1484 1486 1483 1487
0 1489 ad2 148a
1482 1489 0 148b
ad4 0 15c3 161
:3 0 13 :3 0 184
:3 0 163 :3 0 13
:3 0 185 :3 0 99
:3 0 13 :3 0 9a
:3 0 26 :3 0 3b
:3 0 3e :3 0 16
:4 0 186 1 :8 0
149f 45 :3 0 67
:3 0 149a 149b 0
68 :3 0 149c 149d
0 149f ad6 14f2
69 :3 0 45 :3 0
67 :3 0 14a1 14a2
0 68 :3 0 14a3
14a4 0 14a6 ad9
14a8 adb 14a7 14a6
:2 0 14f0 6a :3 0
45 :3 0 67 :3 0
14ab 14ac 0 68
:3 0 14ad 14ae 0
14e8 4f :3 0 50
:3 0 14b0 14b1 0
4f :3 0 5f :3 0
14b3 14b4 0 6b
:2 0 2 :4 0 187
:2 0 61 :2 0 a
:2 0 add 14b9 14bb
:3 0 ae0 14b5 14bd
14b2 14bf 14be :2 0
52 :3 0 62 :3 0
14c1 14c2 0 54
:4 0 188 :4 0 57
:2 0 58 :3 0 ae4
14c6 14c8 :3 0 57
:2 0 6e :4 0 ae7
14ca 14cc :3 0 57
:2 0 6f :4 0 aea
14ce 14d0 :3 0 57
:2 0 68 :3 0 aed
14d2 14d4 :3 0 57
:2 0 70 :4 0 af0
14d6 14d8 :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 af3 14db 14df
af7 14da 14e1 :3 0
afa 14c3 14e3 :2 0
14e5 afd 14e6 14c0
14e5 0 14e7 aff
0 14e8 b01 14eb
:3 0 14eb 0 14eb
14ea 14e8 14e9 :6 0
14ed 4b :3 0 b04
14ef b06 14ee 14ed
:2 0 14f0 b08 :2 0
14f2 0 14f2 14f1
149f 14f0 :6 0 15c3
1 :3 0 e :3 0
26 :3 0 f :2 0
b0b 14f4 14f7 74
:2 0 a :2 0 b10
14f9 14fb :3 0 27
:3 0 13 :3 0 9a
:3 0 14fe 14ff 0
14fd 1500 0 150c
45 :3 0 67 :3 0
1502 1503 0 189
:3 0 16 :3 0 26
:3 0 27 :3 0 b13
1505 1509 1504 150a
0 150c b17 150d
14fc 150c 0 150e
b1a 0 15c3 18a
:3 0 18b :3 0 99
:3 0 3b :3 0 3e
:3 0 16 :3 0 3e
:3 0 16 :4 0 18c
1 :8 0 152d bb
:4 0 1518 :3 0 bc
:3 0 74 :2 0 b1e
151b 151c :3 0 45
:3 0 67 :3 0 151e
151f 0 f :2 0
1520 1521 0 1523
b21 152a 45 :3 0
67 :3 0 1524 1525
0 bd :2 0 1526
1527 0 1529 b23
152b 151d 1523 0
152c 0 1529 0
152c b25 0 152d
b28 1580 69 :3 0
45 :3 0 67 :3 0
152f 1530 0 68
:3 0 1531 1532 0
1534 b2b 1536 b2d
1535 1534 :2 0 157e
6a :3 0 45 :3 0
67 :3 0 1539 153a
0 68 :3 0 153b
153c 0 1576 4f
:3 0 50 :3 0 153e
153f 0 4f :3 0
5f :3 0 1541 1542
0 6b :2 0 2
:4 0 18d :2 0 61
:2 0 a :2 0 b2f
1547 1549 :3 0 b32
1543 154b 1540 154d
154c :2 0 52 :3 0
62 :3 0 154f 1550
0 54 :4 0 18e
:4 0 57 :2 0 58
:3 0 b36 1554 1556
:3 0 57 :2 0 6e
:4 0 b39 1558 155a
:3 0 57 :2 0 6f
:4 0 b3c 155c 155e
:3 0 57 :2 0 68
:3 0 b3f 1560 1562
:3 0 57 :2 0 70
:4 0 b42 1564 1566
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 b45
1569 156d b49 1568
156f :3 0 b4c 1551
1571 :2 0 1573 b4f
1574 154e 1573 0
1575 b51 0 1576
b53 1579 :3 0 1579
0 1579 1578 1576
1577 :6 0 157b 4d
:3 0 b56 157d b58
157c 157b :2 0 157e
b5a :2 0 1580 0
1580 157f 152d 157e
:6 0 15c3 1 :3 0
45 :3 0 67 :3 0
1582 1583 0 74
:2 0 bd :2 0 b5f
1585 1587 :3 0 45
:3 0 67 :3 0 1589
158a 0 f :2 0
158b 158c 0 158e
b62 158f 1588 158e
0 1590 b64 0
15c3 4f :3 0 50
:3 0 1591 1592 0
4f :3 0 5f :3 0
1594 1595 0 a
:2 0 2 :4 0 18f
:2 0 61 :2 0 a
:2 0 b66 159a 159c
:3 0 b69 1596 159e
1593 15a0 159f :2 0
52 :3 0 62 :3 0
15a2 15a3 0 54
:4 0 190 :4 0 57
:2 0 58 :3 0 b6d
15a7 15a9 :3 0 57
:2 0 6e :4 0 b70
15ab 15ad :3 0 57
:2 0 78 :4 0 b73
15af 15b1 :3 0 57
:2 0 45 :3 0 67
:3 0 15b4 15b5 0
b76 15b3 15b7 :3 0
b79 15a4 15b9 :2 0
15bb b7c 15bc 15a1
15bb 0 15bd b7e
0 15c3 b :3 0
45 :3 0 67 :3 0
15bf 15c0 0 15c1
:2 0 15c3 b80 15c6
:3 0 15c6 b90 15c6
15c5 15c3 15c4 :6 0
15c7 :2 0 2 15
15c6 15ca :3 0 15c9
15c7 15cb :8 0 
bb1
4
:3 0 1 3 1
9 1 d 3
8 c 11 1
17 2 21 22
1 1d 1 29
1 27 1 33
1 31 1 3d
1 3b 1 42
1 49 1 47
1 50 1 4e
1 57 1 55
1 5e 1 5c
1 63 1 68
1 6d 1 73
1 79 1 7f
1 85 1 8b
1 91 1 97
1 9d 1 a3
1 a9 1 af
1 b5 1 bb
1 c3 1 c1
1 ca 1 c8
1 ee 1 f4
1 109 1 11a
1 126 1 132
2 135 137 2
13a 13c 2 13e
140 2 142 144
2 146 148 1
14e 2 150 151
2 14a 153 2
155 157 1 15d
2 15f 160 2
159 162 2 164
166 4 12e 134
139 168 1 16a
1 16c 2 176
178 3 174 175
17a 2 183 185
2 182 187 1
189 1 18b 2
195 19a 1 1a1
1 19c 2 1b4
1b6 3 1b2 1b3
1b8 2 1c1 1c3
2 1c5 1c7 2
1c9 1cb 2 1cd
1cf 2 1d1 1d3
3 1d8 1d9 1da
2 1d5 1dc 2
1c0 1de 1 1e0
1 1e2 2 1ab
1e3 1 1e7 1
1a6 2 1a4 1eb
3 1f1 1f2 1f3
1 1f7 2 1f5
1f7 2 202 204
3 200 201 206
2 20f 211 2
213 215 2 217
219 1 221 2
223 224 2 21b
226 2 228 22a
2 22c 22e 2
230 232 2 234
236 2 20e 238
1 23a 1 23c
2 246 248 3
244 245 24a 2
253 255 2 252
257 1 259 1
25b 3 263 264
265 3 23d 25c
268 1 26a 1
272 2 26e 272
2 282 287 1
28e 1 289 2
2a1 2a3 3 29f
2a0 2a5 2 2ae
2b0 2 2b2 2b4
2 2b6 2b8 2
2ba 2bc 2 2be
2c0 3 2c5 2c6
2c7 2 2c2 2c9
2 2ad 2cb 1
2cd 1 2cf 2
298 2d0 1 2d4
1 293 2 291
2d8 1 2e3 2
2df 2e3 2 2ef
2f1 3 2ed 2ee
2f3 2 2fc 2fe
2 300 302 2
304 306 1 30e
2 310 311 2
308 313 2 2fb
315 1 317 1
319 2 323 325
3 321 322 327
2 330 332 2
32f 334 1 336
1 338 2 340
341 3 31a 339
344 2 348 349
1 34d 2 34b
34d 2 352 353
1 357 2 355
357 2 365 367
3 363 364 369
2 372 374 2
376 378 2 37a
37c 1 384 2
386 387 2 37e
389 2 38b 38d
2 38f 391 2
393 395 2 397
399 2 371 39b
1 39d 1 39f
2 3a9 3ab 3
3a7 3a8 3ad 2
3b6 3b8 2 3b5
3ba 1 3bc 1
3be 3 3c6 3c7
3c8 3 3a0 3bf
3cb 2 3ce 3cd
2 3d6 3db 1
3e2 1 3dd 2
3f5 3f7 3 3f3
3f4 3f9 2 402
404 2 406 408
2 40a 40c 2
40e 410 2 412
414 3 419 41a
41b 2 416 41d
2 401 41f 1
421 1 423 2
3ec 424 1 428
1 3e7 2 3e5
42c 2 432 434
2 436 438 2
43a 43c 4 2db
3cf 42f 43f 2
445 446 1 44a
2 448 44a 1
494 2 493 494
1 49c 1 4a2
2 4a4 4a5 2
491 4a6 1 4ad
1 4a8 2 4c0
4c2 3 4be 4bf
4c4 2 4cd 4cf
2 4d1 4d3 2
4d5 4d7 2 4d9
4db 2 4dd 4df
3 4e4 4e5 4e6
2 4e1 4e8 2
4cc 4ea 1 4ec
1 4ee 2 4b7
4ef 1 4f3 1
4b2 2 4b0 4f7
2 503 504 1
50f 1 515 2
517 518 1 520
2 51c 520 1
525 1 527 1
565 2 564 565
1 56d 1 573
2 575 576 2
562 577 1 57e
1 579 2 591
593 3 58f 590
595 2 59e 5a0
2 5a2 5a4 2
5a6 5a8 2 5aa
5ac 2 5ae 5b0
3 5b5 5b6 5b7
2 5b2 5b9 2
59d 5bb 1 5bd
1 5bf 2 588
5c0 1 5c4 1
583 2 581 5c8
1 5d6 2 5d5
5d6 1 5de 1
5e4 2 5e6 5e7
2 5d3 5e8 1
5ef 1 5ea 2
602 604 3 600
601 606 2 60f
611 2 613 615
2 617 619 2
61b 61d 2 61f
621 3 626 627
628 2 623 62a
2 60e 62c 1
62e 1 630 2
5f9 631 1 635
1 5f4 2 5f2
639 5 505 519
528 5cb 63c 2
643 649 1 650
1 64b 2 663
665 3 661 662
667 2 670 672
2 674 676 2
678 67a 2 67c
67e 2 680 682
3 687 688 689
2 684 68b 2
66f 68d 1 68f
1 691 2 65a
692 1 696 1
655 2 653 69a
4 4fa 4fe 640
69d 1 6a0 1
6ae 2 6ad 6ae
1 6b6 1 6bc
2 6be 6bf 2
6ab 6c0 1 6c7
1 6c2 2 6da
6dc 3 6d8 6d9
6de 2 6e7 6e9
2 6eb 6ed 2
6ef 6f1 2 6f3
6f5 2 6f7 6f9
3 6fe 6ff 700
2 6fb 702 2
6e6 704 1 706
1 708 2 6d1
709 1 70d 1
6cc 2 6ca 711
2 71d 71f 2
721 723 2 725
727 6 443 6a1
714 718 71b 72a
2 72c 72d 4
736 737 738 739
1 744 1 74a
2 74c 74d 1
755 2 751 755
1 75a 1 75c
1 781 2 780
781 1 789 1
78f 2 791 792
2 77e 793 1
79a 1 795 2
7ad 7af 3 7ab
7ac 7b1 2 7ba
7bc 2 7be 7c0
2 7c2 7c4 2
7c6 7c8 2 7ca
7cc 3 7d1 7d2
7d3 2 7ce 7d5
2 7b9 7d7 1
7d9 1 7db 2
7a4 7dc 1 7e0
1 79f 2 79d
7e4 1 84e 2
84d 84e 1 856
1 85c 2 85e
85f 2 84b 860
1 867 1 862
2 87a 87c 3
878 879 87e 2
887 889 2 88b
88d 2 88f 891
2 893 895 2
897 899 3 89e
89f 8a0 2 89b
8a2 2 886 8a4
1 8a6 1 8a8
2 871 8a9 1
8ad 1 86c 2
86a 8b1 1 8f3
2 8f2 8f3 1
8fb 1 901 2
903 904 2 8f0
905 1 90c 1
907 2 91f 921
3 91d 91e 923
2 92c 92e 2
930 932 2 934
936 2 938 93a
2 93c 93e 3
943 944 945 2
940 947 2 92b
949 1 94b 1
94d 2 916 94e
1 952 1 911
2 90f 956 3
7e7 8b4 959 1
75f 2 965 96a
1 971 1 96c
2 984 986 3
982 983 988 2
991 993 2 995
997 2 999 99b
2 99d 99f 2
9a1 9a3 3 9a8
9a9 9aa 2 9a5
9ac 2 990 9ae
1 9b0 1 9b2
2 97b 9b3 1
9b7 1 976 2
974 9bb 1 9c6
2 9c2 9c6 1
9ca 1 9d3 1
9d5 2 9e3 9e8
1 9ef 1 9ea
2 a02 a04 3
a00 a01 a06 2
a0f a11 2 a13
a15 2 a17 a19
2 a1b a1d 2
a1f a21 3 a26
a27 a28 2 a23
a2a 2 a0e a2c
1 a2e 1 a30
2 9f9 a31 1
a35 1 9f4 2
9f2 a39 1 a44
2 a40 a44 1
a48 2 a51 a52
1 a56 2 a54
a56 1 a5b 1
a63 2 a62 a63
1 a6b 1 a71
2 a73 a74 2
a60 a75 1 a7c
1 a77 2 a8f
a91 3 a8d a8e
a93 2 a9c a9e
2 aa0 aa2 2
aa4 aa6 2 aa8
aaa 2 aac aae
3 ab3 ab4 ab5
2 ab0 ab7 2
a9b ab9 1 abb
1 abd 2 a86
abe 1 ac2 1
a81 2 a7f ac6
1 ad1 2 ad0
ad1 1 ad9 1
adf 2 ae1 ae2
2 ace ae3 1
aea 1 ae5 2
afd aff 3 afb
afc b01 2 b0a
b0c 2 b0e b10
2 b12 b14 2
b16 b18 2 b1a
b1c 3 b21 b22
b23 2 b1e b25
2 b09 b27 1
b29 1 b2b 2
af4 b2c 1 b30
1 aef 2 aed
b34 1 b3f 2
b3e b3f 1 b47
1 b4d 2 b4f
b50 2 b3c b51
1 b58 1 b53
2 b6b b6d 3
b69 b6a b6f 2
b78 b7a 2 b7c
b7e 2 b80 b82
2 b84 b86 2
b88 b8a 3 b8f
b90 b91 2 b8c
b93 2 b77 b95
1 b97 1 b99
2 b62 b9a 1
b9e 1 b5d 2
b5b ba2 1 bad
2 bac bad 1
bb5 1 bbb 2
bbd bbe 2 baa
bbf 1 bc6 1
bc1 2 bd9 bdb
3 bd7 bd8 bdd
2 be6 be8 2
bea bec 2 bee
bf0 2 bf2 bf4
2 bf6 bf8 3
bfd bfe bff 2
bfa c01 2 be5
c03 1 c05 1
c07 2 bd0 c08
1 c0c 1 bcb
2 bc9 c10 5
ac9 b37 ba5 c13
c17 2 c19 c1a
1 c1b 2 c1f
c22 2 c24 c25
3 c31 c32 c33
1 c3e 1 c44
2 c46 c47 1
c4f 2 c4b c4f
1 c54 1 c56
2 c59 c5a 1
c5e 2 c5c c5e
1 c73 2 c72
c73 1 c7b 1
c81 2 c83 c84
2 c70 c85 1
c8c 1 c87 2
c9f ca1 3 c9d
c9e ca3 2 cac
cae 2 cb0 cb2
2 cb4 cb6 2
cb8 cba 2 cbc
cbe 3 cc3 cc4
cc5 2 cc0 cc7
2 cab cc9 1
ccb 1 ccd 2
c96 cce 1 cd2
1 c91 2 c8f
cd6 1 ce1 2
cdd ce1 1 cef
2 cee cef 1
cf7 1 cfd 2
cff d00 2 cec
d01 1 d08 1
d03 2 d1b d1d
3 d19 d1a d1f
2 d28 d2a 2
d2c d2e 2 d30
d32 2 d34 d36
2 d38 d3a 3
d3f d40 d41 2
d3c d43 2 d27
d45 1 d47 1
d49 2 d12 d4a
1 d4e 1 d0d
2 d0b d52 1
d55 1 d64 2
d63 d64 1 d6c
1 d72 2 d74
d75 2 d61 d76
1 d7d 1 d78
2 d90 d92 3
d8e d8f d94 2
d9d d9f 2 da1
da3 2 da5 da7
2 da9 dab 2
dad daf 3 db4
db5 db6 2 db1
db8 2 d9c dba
1 dbc 1 dbe
2 d87 dbf 1
dc3 1 d82 2
d80 dc7 1 dca
2 dcd dce 2
cd9 dcf 2 dd3
dd4 1 dd8 2
dd6 dd8 1 de7
2 de6 de7 1
def 1 df5 2
df7 df8 2 de4
df9 1 e00 1
dfb 2 e13 e15
3 e11 e12 e17
2 e20 e22 2
e24 e26 2 e28
e2a 2 e2c e2e
2 e30 e32 3
e37 e38 e39 2
e34 e3b 2 e1f
e3d 1 e3f 1
e41 2 e0a e42
1 e46 1 e05
2 e03 e4a 1
e4d 2 e51 e50
4 c34 c48 c57
e52 2 e58 e5e
1 e65 1 e60
2 e78 e7a 3
e76 e77 e7c 2
e85 e87 2 e89
e8b 2 e8d e8f
2 e91 e93 2
e95 e97 3 e9c
e9d e9e 2 e99
ea0 2 e84 ea2
1 ea4 1 ea6
2 e6f ea7 1
eab 1 e6a 2
e68 eaf 1 ebf
2 ebe ebf 1
ec7 1 ecd 2
ecf ed0 2 ebc
ed1 1 ed8 1
ed3 2 eeb eed
3 ee9 eea eef
2 ef8 efa 2
efc efe 2 f00
f02 2 f04 f06
2 f08 f0a 3
f0f f10 f11 2
f0c f13 2 ef7
f15 1 f17 1
f19 2 ee2 f1a
1 f1e 1 edd
2 edb f22 2
f28 f29 1 f2d
2 f2b f2d 1
f6a 2 f69 f6a
1 f72 1 f78
2 f7a f7b 2
f67 f7c 1 f83
1 f7e 2 f96
f98 3 f94 f95
f9a 2 fa3 fa5
2 fa7 fa9 2
fab fad 2 faf
fb1 2 fb3 fb5
3 fba fbb fbc
2 fb7 fbe 2
fa2 fc0 1 fc2
1 fc4 2 f8d
fc5 1 fc9 1
f88 2 f86 fcd
2 fd3 fd4 1
fd8 2 fd6 fd8
5 fe0 fe1 fe2
fe3 fe4 2 fdd
fe7 1 fe9 2
fd0 fea 2 ff3
ff4 1 fff 1
1005 2 1007 1008
1 1010 2 100c
1010 1 1015 1
1017 1 1052 2
1051 1052 1 105a
1 1060 2 1062
1063 2 104f 1064
1 106b 1 1066
2 107e 1080 3
107c 107d 1082 2
108b 108d 2 108f
1091 2 1093 1095
2 1097 1099 2
109b 109d 3 10a2
10a3 10a4 2 109f
10a6 2 108a 10a8
1 10aa 1 10ac
2 1075 10ad 1
10b1 1 1070 2
106e 10b5 1 10c3
2 10c2 10c3 1
10cb 1 10d1 2
10d3 10d4 2 10c0
10d5 1 10dc 1
10d7 2 10ef 10f1
3 10ed 10ee 10f3
2 10fc 10fe 2
1100 1102 2 1104
1106 2 1108 110a
2 110c 110e 3
1113 1114 1115 2
1110 1117 2 10fb
1119 1 111b 1
111d 2 10e6 111e
1 1122 1 10e1
2 10df 1126 5
ff5 1009 1018 10b8
1129 2 1130 1136
1 113d 1 1138
2 1150 1152 3
114e 114f 1154 2
115d 115f 2 1161
1163 2 1165 1167
2 1169 116b 2
116d 116f 3 1174
1175 1176 2 1171
1178 2 115c 117a
1 117c 1 117e
2 1147 117f 1
1183 1 1142 2
1140 1187 2 118d
118e 1 1192 2
1190 1192 2 1197
1198 1 119c 2
119a 119c 1 11aa
2 11a9 11aa 1
11b2 1 11b8 2
11ba 11bb 2 11a7
11bc 1 11c3 1
11be 2 11d6 11d8
3 11d4 11d5 11da
2 11e3 11e5 2
11e7 11e9 2 11eb
11ed 2 11ef 11f1
2 11f3 11f5 3
11fa 11fb 11fc 2
11f7 11fe 2 11e2
1200 1 1202 1
1204 2 11cd 1205
1 1209 1 11c8
2 11c6 120d 1
1210 1 1213 5
121a 121b 121c 121d
121e 2 1233 1238
1 123f 1 123a
2 1252 1254 3
1250 1251 1256 2
125f 1261 2 1263
1265 2 1267 1269
2 126b 126d 2
126f 1271 3 1276
1277 1278 2 1273
127a 2 125e 127c
1 127e 1 1280
2 1249 1281 1
1285 1 1244 2
1242 1289 2 128f
1290 1 1294 2
1292 1294 1 12ae
2 12ad 12ae 1
12b6 1 12bc 2
12be 12bf 2 12ab
12c0 1 12c7 1
12c2 2 12da 12dc
3 12d8 12d9 12de
2 12e7 12e9 2
12eb 12ed 2 12ef
12f1 2 12f3 12f5
2 12f7 12f9 3
12fe 12ff 1300 2
12fb 1302 2 12e6
1304 1 1306 1
1308 2 12d1 1309
1 130d 1 12cc
2 12ca 1311 1
1314 1 1330 2
132f 1330 1 1338
1 133e 2 1340
1341 2 132d 1342
1 1349 1 1344
2 135c 135e 3
135a 135b 1360 2
1369 136b 2 136d
136f 2 1371 1373
2 1375 1377 2
1379 137b 3 1380
1381 1382 2 137d
1384 2 1368 1386
1 1388 1 138a
2 1353 138b 1
138f 1 134e 2
134c 1393 1 1396
2 1399 139a 8
fee 112d 118a 1214
1217 1221 128c 139b
2 139d 139e 1
13a0 b 9be 9d6
a3c c26 c29 c2c
e55 eb2 f25 139f
13a3 1 95e 1
13a7 3 95d 13a6
13a9 1 13b5 2
13b4 13b5 1 13bd
1 13c3 2 13c5
13c6 2 13b2 13c7
1 13ce 1 13c9
2 13e1 13e3 3
13df 13e0 13e5 2
13ee 13f0 2 13f2
13f4 2 13f6 13f8
2 13fa 13fc 2
13fe 1400 3 1405
1406 1407 2 1402
1409 2 13ed 140b
1 140d 1 140f
2 13d8 1410 1
1414 1 13d3 2
13d1 1418 5 73a
74e 75d 13ab 141b
2 1422 1428 1
142f 1 142a 2
1442 1444 3 1440
1441 1446 2 144f
1451 2 1453 1455
2 1457 1459 2
145b 145d 2 145f
1461 3 1466 1467
1468 2 1463 146a
2 144e 146c 1
146e 1 1470 2
1439 1471 1 1475
1 1434 2 1432
1479 1 1480 2
147e 1480 1 1485
1 1488 1 148a
2 1499 149e 1
14a5 1 14a0 2
14b8 14ba 3 14b6
14b7 14bc 2 14c5
14c7 2 14c9 14cb
2 14cd 14cf 2
14d1 14d3 2 14d5
14d7 3 14dc 14dd
14de 2 14d9 14e0
2 14c4 14e2 1
14e4 1 14e6 2
14af 14e7 1 14eb
1 14aa 2 14a8
14ef 2 14f5 14f6
1 14fa 2 14f8
14fa 3 1506 1507
1508 2 1501 150b
1 150d 1 151a
2 1519 151a 1
1522 1 1528 2
152a 152b 2 1517
152c 1 1533 1
152e 2 1546 1548
3 1544 1545 154a
2 1553 1555 2
1557 1559 2 155b
155d 2 155f 1561
2 1563 1565 3
156a 156b 156c 2
1567 156e 2 1552
1570 1 1572 1
1574 2 153d 1575
1 1579 1 1538
2 1536 157d 1
1586 2 1584 1586
1 158d 1 158f
2 1599 159b 3
1597 1598 159d 2
15a6 15a8 2 15aa
15ac 2 15ae 15b0
2 15b2 15b6 2
15a5 15b8 1 15ba
1 15bc f 16d
18c 1ee 26b 72e
733 141f 147c 148b
14f2 150e 1580 1590
15bd 15c2 20 1b
25 2f 39 40
45 4c 53 5a
61 66 6b 71
77 7d 83 89
8f 95 9b a1
a7 ad b3 b9
bf c6 cd ef
f9 10a 11b 
1
4
0 
15ca
0
1
50
4e
25
0 1 1 1 1 5 1 7
1 9 1 b 1 d e d
10 1 12 1 14 1 16 17
16 19 16 1b 16 1d 16 1f
16 21 16 23 16 25 16 27
16 29 2a 29 2c 29 2e 29
30 16 32 16 34 16 36 16
38 39 38 3b 16 3d 16 3f
16 41 16 43 16 45 16 47
1 49 1 4b 1 4d 0 0

8b 1 0
a9 1 0
9 1 0
85 1 0
68 1 0
55 1 0
5c 1 0
fc 1 3
31 1 0
110 1 4
2 0 1
bb 1 0
c1 1 0
27 1 0
7f 1 0
42 1 0
af 1 0
9d 1 0
91 1 0
f4 1 0
c8 1 0
63 1 0
73 1 0
1d 1 0
17 1 0
6d 1 0
79 1 0
97 1 0
4e 1 0
3 1 0
a3 1 0
47 1 0
3b 1 0
13a0 16 47
d 1 0
b5 1 0
d0 1 2
0

/
SHOW ERRORS FUNCTION FC_COMMIT_ASSIGN;
ALTER FUNCTION FC_COMMIT_ASSIGN COMPILE DEBUG;
Prompt == FUNCTION SP_COMMIT_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_COMMIT_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
45
2 :e:
1FUNCTION:
1SP_COMMIT_ASSIGN:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_BITFLAG:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_COMMIT_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
118:
1+:
1FPUT:
1               ENTER:: SP_COMMIT_ASSIGN(19) :: cplan.sql(19870) :: :
1SC_STATE:
1FC_COMMIT_ASSIGN:
14:
129:
1       RETURN_STATUS:: SP_COMMIT_ASSIGN(30) :: cplan.sql(19881) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
136:
1           EXCEPTION:: SP_COMMIT_ASSIGN(37) :: cplan.sql(19888) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
148:
1           EXCEPTION:: SP_COMMIT_ASSIGN(49) :: cplan.sql(19900) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
189
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d :2 a0 d :2 a0 6b :3 a0 51 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
189
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 72 5d 61 64 65 6d
5c 8e 7d 81 59 89 7c ae
99 9d 79 a1 a9 98 b5 b9
95 bd c1 c5 c8 cd ce 1
d0 d5 d9 dd e0 e5 e9 ed
f0 f5 f6 f8 fd 100 104 105
10a 10f 112 117 118 11d 120 124
125 12a 12d 132 133 138 13b 140
141 146 149 14d 151 155 156 158
15d 15e 160 161 166 169 16e 16f
174 175 17a 17c 180 183 187 18b
18e 192 196 199 19c 1a1 1a4 1a7
1aa 1ab 1b0 1b1 1 1b3 1b8 1bc
1c0 1c3 1c8 1cd 1d0 1d4 1d5 1da
1db 1e0 1e2 1e6 1e9 1ed 1f1 1f5
1f9 1fd 201 205 209 20c 210 214
218 21b 21c 21e 222 226 22a 22d
231 235 238 23b 240 243 246 249
24a 24f 250 1 252 257 25b 25f
262 267 26c 26f 273 274 279 27c
281 282 287 28a 28f 290 295 298
29c 2a0 2a4 2a8 2ab 2ac 2ae 2b3
2b4 2b6 2b7 2bc 2bf 2c4 2c5 2ca
2cd 2d2 2d3 2d8 2db 2df 2e0 2e5
2e8 2ed 2ee 2f3 2f4 2f9 2fb 2ff
302 306 30a 30d 311 315 318 31c
320 321 326 328 32c 330 333 337
33b 33e 342 346 349 34c 351 354
357 35a 35b 360 361 1 363 368
36c 370 373 378 37d 380 384 385
38a 38b 390 394 398 39b 3a0 3a5
3a8 3ac 3b0 3b3 3b4 3b9 3bc 3c1
3c2 3c7 3ca 3ce 3d2 3d5 3d6 3db
3dc 3e1 3e3 3e7 3ea 3ee 3f2 3f6
3fa 3fe 402 406 40a 40e 41a 41f
423 427 42b 42f 431 432 437 1
43b 43f 443 446 44a 44e 452 456
459 45d 461 464 467 46c 46f 472
475 476 47b 47c 1 47e 483 487
48b 48e 493 498 49b 49f 4a0 4a5
4a6 4ab 4af 4b3 4b6 4bb 4c0 4c3
4c7 4c8 4cd 4d0 4d5 4d6 4db 4de
4e2 4e6 4e9 4ec 4ed 4ef 4f0 4f5
4f6 4fb 4fd 501 504 508 50c 510
514 518 51c 520 52c 531 535 539
53d 541 543 547 549 555 557 559
55a 55f 563 565 571 575 577 578
581 
189
2
0 1 a 6 9 :3 6 11 :2 6
1 3 a 13 a :2 1 4 9
12 11 :2 9 :2 4 :2 e 1d e :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 58 5e 61 :2 58 6f 89 8
:2 6f d 10 :2 6f 13 16 :2 6f b
e :2 6f 13 16 1f 27 :2 1f 34
:2 16 :2 6f 3c 3f :2 6f :2 7 4e :2 4
7 :2 11 23 :2 2d 39 3c 50 52
53 :2 50 :2 23 :3 7 :2 d 12 1e 61
64 :2 1e :2 7 56 :3 4 11 :2 4 c
:2 4 :2 d 19 2a 30 3b :2 19 4
7 :2 11 23 :2 2d 39 3c 50 52
53 :2 50 :2 23 :3 7 :2 d 12 1e 61
64 :2 1e 71 74 :2 1e 78 7b :2 1e
85 88 91 99 :2 a2 :2 91 ad :2 88
:2 1e b5 b8 :2 1e c0 c3 :2 1e c8
cb :2 1e d0 d3 :2 1e :2 7 56 :3 4
:2 f 21 :2 2a 34 3a :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
54 56 57 :2 54 :2 26 :3 a :2 10 15
21 64 67 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 5a :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
51 53 54 :2 51 :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 57 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
189
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :7 7
:6 8 :7 a :b c :11 d
e :2 d :2 e :2 d
:2 e :2 d :2 f :2 d
:9 f :2 d :2 f :4 d
:3 c :11 12 :b 13 :3 12
:3 18 :3 19 :a 1b :11 1d
:30 1e :3 1d :a 20 b
:3 23 :11 24 :b 25 :17 26
:3 24 :2 28 :3 29 :3 2a
2b 29 28 29
:3 2c :3 23 :2 2d :5 2f
:11 30 :b 31 :18 32 :3 30
:2 34 35 :3 36 37
35 34 35 :3 38
:2 2e :6 2d 22 :7 1

583
4
:3 0 1 :3 0 2
:a 0 184 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 6
:3 0 5 :7 0 9
8 :3 0 7 :3 0
8 :3 0 9 :2 0
4 b f 0
184 2 10 :2 0
d :2 0 c 4
:3 0 b :2 0 a
13 15 :6 0 18
16 0 182 0
a :6 0 20 21
0 e 6 :3 0
1a :7 0 1e 1b
1c 182 0 c
:6 0 26 27 0
10 8 :3 0 9
:2 0 4 22 :7 0
25 23 0 182
0 e :6 0 f
:3 0 10 :3 0 f
:3 0 11 :3 0 29
2a 0 2 :4 0
12 2b 2d 28
2f 2e :2 0 12
:3 0 13 :3 0 31
32 0 14 :4 0
f :3 0 15 :3 0
35 36 0 2
:4 0 14 37 39
16 :4 0 17 :2 0
18 :3 0 16 3c
3e :3 0 19 :4 0
17 :2 0 1a :4 0
19 41 43 :3 0
17 :2 0 3 :3 0
1c 45 47 :3 0
17 :2 0 1a :4 0
1f 49 4b :3 0
17 :2 0 1b :4 0
22 4d 4f :3 0
17 :2 0 1c :3 0
1d :3 0 5 :3 0
25 53 55 1e
:4 0 27 52 58
2a 51 5a :3 0
17 :2 0 1f :4 0
2d 5c 5e :3 0
30 33 60 :2 0
62 35 63 30
62 0 64 37
0 e2 f :3 0
10 :3 0 65 66
0 f :3 0 20
:3 0 68 69 0
21 :2 0 2 :4 0
22 :2 0 23 :2 0
21 :2 0 39 6e
70 :3 0 3c 6a
72 67 74 73
:2 0 12 :3 0 24
:3 0 76 77 0
14 :4 0 25 :4 0
17 :2 0 18 :3 0
40 7b 7d :3 0
43 78 7f :2 0
81 46 82 75
81 0 83 48
0 e2 c :3 0
5 :3 0 84 85
0 e2 a :3 0
3 :3 0 87 88
0 e2 8 :3 0
26 :3 0 8a 8b
0 27 :3 0 a
:3 0 c :3 0 21
:2 0 4a 8d 91
8c 92 0 e2
f :3 0 10 :3 0
94 95 0 f
:3 0 20 :3 0 97
98 0 28 :2 0
2 :4 0 29 :2 0
23 :2 0 21 :2 0
4e 9d 9f :3 0
51 99 a1 96
a3 a2 :2 0 12
:3 0 24 :3 0 a5
a6 0 14 :4 0
2a :4 0 17 :2 0
18 :3 0 55 aa
ac :3 0 17 :2 0
2b :4 0 58 ae
b0 :3 0 17 :2 0
2c :4 0 5b b2
b4 :3 0 17 :2 0
1c :3 0 1d :3 0
8 :3 0 26 :3 0
b9 ba 0 5e
b8 bc 1e :4 0
60 b7 bf 63
b6 c1 :3 0 17
:2 0 2d :4 0 66
c3 c5 :3 0 17
:2 0 1a :4 0 69
c7 c9 :3 0 17
:2 0 a :3 0 6c
cb cd :3 0 17
:2 0 1a :4 0 6f
cf d1 :3 0 72
a7 d3 :2 0 d5
75 d6 a4 d5
0 d7 77 0
e2 2e :3 0 2f
:3 0 d8 d9 0
8 :3 0 26 :3 0
db dc 0 a
:3 0 30 :3 0 79
da e0 :2 0 e2
7d 183 8 :3 0
31 :2 0 4 e3
e4 0 f :3 0
10 :3 0 e6 e7
0 f :3 0 20
:3 0 e9 ea 0
32 :2 0 2 :4 0
33 :2 0 23 :2 0
21 :2 0 85 ef
f1 :3 0 88 eb
f3 e8 f5 f4
:2 0 12 :3 0 24
:3 0 f7 f8 0
14 :4 0 34 :4 0
17 :2 0 18 :3 0
8c fc fe :3 0
8f f9 100 :2 0
119 12 :3 0 24
:3 0 102 103 0
14 :4 0 35 :4 0
17 :2 0 8 :3 0
36 :3 0 108 109
0 92 107 10b
:3 0 17 :2 0 2d
:4 0 95 10d 10f
:3 0 17 :2 0 8
:3 0 37 :3 0 112
113 0 98 111
115 :3 0 9b 104
117 :2 0 119 9e
11a f6 119 0
11b a1 0 12b
38 :3 0 e :3 0
8 :3 0 36 :3 0
39 :3 0 8 :3 0
37 :3 0 3 :3 0
3a :4 0 3b 1
:a 0 127 :2 0 12b
11d 125 :2 0 7
:3 0 e :3 0 129
:2 0 12b a3 12d
a7 12c 12b :2 0
181 3c :3 0 8
:3 0 26 :3 0 130
131 0 3d :3 0
132 133 0 179
f :3 0 10 :3 0
135 136 0 f
:3 0 20 :3 0 138
139 0 32 :2 0
2 :4 0 3e :2 0
23 :2 0 21 :2 0
a9 13e 140 :3 0
ac 13a 142 137
144 143 :2 0 12
:3 0 24 :3 0 146
147 0 14 :4 0
3f :4 0 17 :2 0
18 :3 0 b0 14b
14d :3 0 b3 148
14f :2 0 169 12
:3 0 24 :3 0 151
152 0 14 :4 0
40 :4 0 17 :2 0
3d :3 0 b6 156
158 :3 0 17 :2 0
41 :4 0 b9 15a
15c :3 0 17 :2 0
42 :3 0 43 :3 0
21 :2 0 44 :2 0
bc 15f 163 c0
15e 165 :3 0 c3
153 167 :2 0 169
c6 16a 145 169
0 16b c9 0
179 38 :3 0 e
:3 0 39 :3 0 8
:3 0 37 :3 0 3
:3 0 3a :4 0 45
1 :a 0 175 :2 0
179 16d 173 :2 0
7 :3 0 e :3 0
177 :2 0 179 cb
17c :3 0 17c 0
17c 17b 179 17a
:6 0 17e 1 :3 0
d0 180 d2 17f
17e :2 0 181 d4
:2 0 183 d7 183
182 e2 181 :6 0
184 :2 0 2 10
183 187 :3 0 186
184 188 :8 0 
db
4
:3 0 1 3 1
7 2 6 a
1 14 1 12
1 19 1 1f
1 2c 1 38
2 3b 3d 2
40 42 2 44
46 2 48 4a
2 4c 4e 1
54 2 56 57
2 50 59 2
5b 5d 4 34
3a 3f 5f 1
61 1 63 2
6d 6f 3 6b
6c 71 2 7a
7c 2 79 7e
1 80 1 82
3 8e 8f 90
2 9c 9e 3
9a 9b a0 2
a9 ab 2 ad
af 2 b1 b3
1 bb 2 bd
be 2 b5 c0
2 c2 c4 2
c6 c8 2 ca
cc 2 ce d0
2 a8 d2 1
d4 1 d6 3
dd de df 7
64 83 86 89
93 d7 e1 2
ee f0 3 ec
ed f2 2 fb
fd 2 fa ff
2 106 10a 2
10c 10e 2 110
114 2 105 116
2 101 118 1
11a 3 11b 126
12a 1 e5 2
13d 13f 3 13b
13c 141 2 14a
14c 2 149 14e
2 155 157 2
159 15b 3 160
161 162 2 15d
164 2 154 166
2 150 168 1
16a 4 134 16b
174 178 1 17c
1 12f 2 12d
180 3 17 1d
24 
1
4
0 
187
0
1
14
2
6
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
3 1 0
19 1 0
12 1 0
7 1 0
1f 1 0
0

/
SHOW ERRORS FUNCTION SP_COMMIT_ASSIGN;
ALTER FUNCTION SP_COMMIT_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Accept ETC and/or FORECAST_START, Assign level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_ACPT_ETC_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_ACPT_ETC_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ab
2 :e:
1FUNCTION:
1SP_ACPT_ETC_ASSIGN:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PRJ_ASSIGNMENT_ID:
1H_REC_USER:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_TA_START_DT:
1TIMESTAMP:
1H_TA_FINISH_DT:
1H_START_DATE:
1H_FINISH_DATE:
1H_FINISH_D:
1DATE:
1H_LAST_SUBMITTED:
1H_WEEK_OF:
1H_BIT_FLAG:
1H_EFFORT:
10:
1H_CONTOUR:
1H_BITFLAG:
1H_REMAINING:
1H_TOTAL:
1H_CONSTR_DT:
1H_DAYOFYEAR:
1H_FINISH_TIME:
18:
1H_MINUTE:
1H_CONSTR_TYPE:
1H_FF_FLAG:
1H_ETC:
1H_SCHED_WORK:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_SD:
1H_FD:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_MLST_PERCENT:
1H_PROJAFFECTED_START:
1H_WORK_TODATE:
1H_PASSED:
1H_NOT_EFFORT_PA:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ACPT_ETC_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_ACPT_ETC_ASSIGN(61) :: cplan.sql(19983) :: :
1PROJECT_ID:
1TASK_ID:
1PROJECT_ASSIGNMENT_ID:
1SCHED_WORK:
1PLANNED_WORK:
1FORECAST_START:
1FORECAST_FINISH:
1ETC:
1WORK_TODATE:
1C_CONTOUR:
1LAST_SUBMITTED:
1PLANNED_START:
1SCHED_START:
1PLANNED_FINISH:
1SCHED_FINISH:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1BIT_FLAG:
1MILESTONE_PERCENT:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT:n      PROJECT_ID,:n      TASK_ID,:n      PROJECT_ASSIGNMENT_ID,:n    +
1  SCHED_WORK+PLANNED_WORK,:n      FORECAST_START,:n      FORECAST_FINISH,:n  +
1    CASE WHEN h_bitflag = 2 AND FORECAST_START IS NuLL THEN 0 ELSE ETC END,:n+
1      SCHED_WORK+PLANNED_WORK - WORK_TODATE,:n      ETC,:n      C_CONTOUR,:n +
1     LAST_SUBMITTED,:n      CASE WHEN FORECAST_FINISH IS NOT NuLL AND FORECAS+
1T_START IS NuLL AND FORECAST_FINISH BETWEEN COALESCE(PLANNED_START, SCHED_STA+
1RT) AND COALESCE(PLANNED_FINISH, SCHED_FINISH) THEN 1 ELSE 0 END,:n      UNRE+
1SOLVED_START,:n      UNRESOLVED_FINISH,:n      BILLABLE,:n      CAPITAL_EXPEN+
1SE,:n      REGULAR_COST,:n      REGULAR_RATE,:n      BIT_FLAG,:n      MILESTO+
1NE_PERCENT,:n      RESOURCE_ID,:n      RESOURCE_TYPE,:n      WORK_TODATE:n   +
1   INTO:n      h_project_id,:n      h_task_id,:n      h_prj_assignment_id,:n +
1     h_sched_work,:n      h_start_date,:n      h_finish_date,:n      h_effort+
1,:n      h_remaining,:n      h_etc,:n      h_contour,:n      h_last_submitted+
1,:n      h_FF_flag,:n      h_ta_start_DT,:n      h_ta_finish_DT,:n      h_bil+
1lable,:n      h_capital_expense,:n      h_reg_cost,:n      h_reg_sale,:n     +
1 h_bit_flag,:n      h_mlst_percent,:n      h_res_id,:n      h_res_type,:n    +
1  h_work_todate:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID =+
1 h_tsk_assignment_id:n      AND (((SCHED_WORK+PLANNED_WORK) > 0:n      AND (S+
1CHED_WORK+PLANNED_WORK - WORK_TODATE) <> ETC):n      OR FORECAST_START IS NOT+
1 NULL OR FORECAST_FINISH IS NOT NULL):
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1140:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(141) :: cplan.sql(20063) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1147:
1        RETURN_ERROR:: SP_ACPT_ETC_ASSIGN(148) :: cplan.sql(20070) :: :
1STATE:: :
1PMO_CNST:
1RECORD_NOT_FOUND:
1 ID:: :
1150:
1                EXIT:: SP_ACPT_ETC_ASSIGN(151) :: cplan.sql(20073) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1FC_ACPT_EFFORT:
1>:
1200000:
1169:
1        RETURN_ERROR:: SP_ACPT_ETC_ASSIGN(170) :: cplan.sql(20092) :: :
1172:
1                EXIT:: SP_ACPT_ETC_ASSIGN(173) :: cplan.sql(20095) :: :
1!=:
1SELECT ETC INTO h_total:n            FROM TASK_ASSIGNMENTS:n            WHERE+
1 TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1193:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(194) :: cplan.sql(20116) :: :
1UPDATE TASK_ASSIGNMENTS:n               SET ETC  = h_etc:n               WHER+
1E TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1FOUND:
1100:
1215:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(216) :: cplan.sql(20138) :: :
1FC_ROLLUP:
14:
1226:
1       RETURN_STATUS:: SP_ACPT_ETC_ASSIGN(227) :: cplan.sql(20149) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1233:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(234) :: cplan.sql(20156) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1245:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(246) :: cplan.sql(20168) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
532
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d :2 a0 d :2 a0 d a0 4d d
a0 4d d :46 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:1c a0 a5 b d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 a0 51 d
:2 a0 51 a5 b 7e 51 b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c b7 19 3c :3 a0 a5 b d
b7 :2 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
532
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
134 122 101 126 127 12f 121 150
13f 143 14b 11e 168 157 15b 163
13e 184 173 177 17f 13b 19c 18b
18f 197 172 1b8 1a7 1ab 1b3 16f
1d0 1bf 1c3 1cb 1a6 1ec 1db 1df
1e7 1a3 208 1f3 1f7 1fa 1fb 203
1da 224 213 217 1d7 21f 212 240
22f 233 20f 23b 22e 25c 24b 24f
22b 257 24a 278 267 26b 247 273
266 294 283 287 263 28f 282 2b0
29f 2a3 2ab 27f 2c8 2b7 2bb 2c3
29e 2e5 2d3 29b 2d7 2d8 2e0 2d2
301 2f0 2f4 2cf 2fc 2ef 31d 30c
310 2ec 318 30b 339 328 32c 308
334 327 355 344 348 324 350 343
371 360 364 340 36c 35f 38d 37c
380 35c 388 37b 3a9 398 39c 378
3a4 397 3c5 3b4 3b8 394 3c0 3b3
3e1 3d0 3d4 3b0 3dc 3cf 3fd 3ec
3f0 3f8 3cc 415 404 408 410 3eb
431 420 424 3e8 42c 41f 44d 43c
440 41c 448 43b 469 458 45c 438
464 457 485 474 478 454 480 473
4a1 490 494 49c 470 4bc 4a8 4ac
4b4 4b7 48f 4d8 4c7 4cb 48c 4d3
4c6 4f4 4e3 4e7 4c3 4ef 4e2 514
4ff 503 4df 507 50f 4fe 51b 51f
4fb 523 527 52b 52e 533 534 1
536 53b 53f 543 546 54b 54f 553
556 55b 55c 55e 563 566 56a 56b
570 575 578 57d 57e 583 586 58a
58b 590 593 598 599 59e 5a1 5a6
5a7 5ac 5af 5b3 5b7 5bb 5bc 5be
5c3 5c4 5c6 5c7 5cc 5cf 5d4 5d5
5da 5dd 5e2 5e3 5e8 5eb 5ef 5f0
5f5 5f8 5fd 5fe 603 606 60b 60c
611 612 617 619 61d 620 624 628
62b 62f 633 636 639 63e 641 644
647 648 64d 64e 1 650 655 659
65d 660 665 66a 66d 671 672 677
678 67d 67f 683 686 68a 68e 692
696 69a 69e 6a2 6a6 6aa 6ae 6af
6b3 6b7 6b8 6bc 6c0 6c4 6c8 6cc
6d0 6d4 6d8 6dc 6e0 6e4 6e8 6ec
6f0 6f4 6f8 6fc 700 704 708 70c
710 714 718 71c 720 724 728 72c
730 734 738 73c 740 744 748 74c
750 754 758 75c 760 764 768 76c
770 774 778 77c 780 784 788 78c
790 794 798 79c 7a0 7a4 7a8 7ac
7b0 7b4 7b8 7bc 7c0 7c4 7c8 7cc
7d0 7d4 7e0 7e4 7e8 7eb 7ef 7f3
7f5 7f9 7fd 801 804 808 80c 80e
80f 814 1 818 81c 820 823 827
82b 82f 833 836 83a 83e 841 844
849 84c 84f 852 853 858 859 1
85b 860 864 868 86b 870 875 878
87c 87d 882 885 88a 88b 890 893
898 899 89e 8a1 8a5 8a6 8ab 8ae
8b3 8b4 8b9 8bc 8c0 8c4 8c7 8ca
8cb 8cd 8ce 8d3 8d4 8d9 8db 8df
8e2 8e4 8e8 8ea 8f6 8f8 8fa 8fb
900 904 906 912 914 918 91c 91f
923 926 92a 92d 92e 933 936 93a
93e 941 945 949 94c 94f 954 957
95a 95d 95e 963 964 1 966 96b
96f 973 976 97b 980 983 987 988
98d 990 995 996 99b 99e 9a3 9a4
9a9 9ac 9b0 9b4 9b8 9bc 9bf 9c0
9c2 9c7 9c8 9ca 9cb 9d0 9d3 9d8
9d9 9de 9e1 9e6 9e7 9ec 9ef 9f3
9f4 9f9 9fc a01 a02 a07 a08 a0d
a0f a13 a16 a1a a1e a21 a25 a29
a2c a2f a34 a37 a3a a3d a3e a43
a44 1 a46 a4b a4f a53 a56 a5b
a60 a63 a67 a68 a6d a6e a73 a75
a79 a7c a80 a84 a87 a8b a8f a92
a96 a9a a9b aa0 aa2 aa6 aa9 aad
ab1 ab5 ab9 abd ac1 ac5 ac9 acd
ad1 ad5 ad9 add ae1 ae5 ae9 aed
af1 af5 af9 afd b01 b05 b09 b0d
b11 b15 b19 b1a b1c b20 b24 b28
b2b b2c b2e b31 b34 b35 b3a b3e
b42 b45 b49 b4d b50 b53 b58 b5b
b5e b61 b62 b67 b68 1 b6a b6f
b73 b77 b7a b7f b84 b87 b8b b8c
b91 b94 b99 b9a b9f ba2 ba7 ba8
bad bb0 bb4 bb8 bbc bbd bbf bc4
bc5 bc7 bc8 bcd bd0 bd5 bd6 bdb
bde be3 be4 be9 bec bf0 bf1 bf6
bf9 bfe bff c04 c05 c0a c0c c10
c13 c17 c1b c1e c22 c26 c29 c2c
c31 c34 c37 c3a c3b c40 c41 1
c43 c48 c4c c50 c53 c58 c5d c60
c64 c65 c6a c6b c70 c72 c76 c79
c7d c81 c84 c88 c8c c8f c90 c92
c96 c9a c9b ca0 ca2 ca6 ca9 cad
cb1 cb5 cb8 cb9 cbb cbe cc1 cc2
cc7 ccb ccf cd3 cd7 cdb ce7 ceb
cef cf2 cf6 cfa cfc d00 d04 d08
d0b d0f d13 d15 d16 d1b 1 d1f
d23 d27 d2a d2e d32 d36 d3a d3d
d41 d45 d48 d4b d50 d53 d56 d59
d5a d5f d60 1 d62 d67 d6b d6f
d72 d77 d7c d7f d83 d84 d89 d8c
d91 d92 d97 d9a d9f da0 da5 da8
dac dad db2 db5 dba dbb dc0 dc3
dc7 dcb dce dd1 dd2 dd4 dd5 dda
ddb de0 de2 de6 de9 deb def df1
dfd dff e01 e02 e07 e0b e0d e19
e1b e1f e23 e26 e27 e29 e2d e30
e34 e37 e38 e3a e3b e40 e44 e48
e4c e50 e54 e60 e64 e69 e6d e70
e71 e76 e7a e7e e81 e84 e88 e8a
e8e e92 e95 e98 e9c e9e ea2 ea6
ea9 eab eaf eb3 eb7 eba ebe ec2
ec4 ec5 eca 1 ece ed2 ed6 ed9
edd ee1 ee5 ee9 eec ef0 ef4 ef7
efa eff f02 f05 f08 f09 f0e f0f
1 f11 f16 f1a f1e f21 f26 f2b
f2e f32 f33 f38 f3b f40 f41 f46
f49 f4e f4f f54 f57 f5b f5c f61
f64 f69 f6a f6f f72 f76 f7a f7d
f80 f81 f83 f84 f89 f8a f8f f91
f95 f98 f9a f9e fa0 fac fae fb0
fb1 fb6 fba fbc fc8 fca fcc fd0
fd3 fd5 fd9 fdc fe0 fe4 fe8 fe9
feb fef ff1 ff5 ff9 ffc 1000 1004
1007 100b 100f 1012 1015 101a 101d 1020
1023 1024 1029 102a 1 102c 1031 1035
1039 103c 1041 1046 1049 104d 104e 1053
1056 105b 105c 1061 1064 1069 106a 106f
1072 1076 107a 107e 1082 1085 1086 1088
108d 108e 1090 1091 1096 1099 109e 109f
10a4 10a7 10ac 10ad 10b2 10b5 10b9 10ba
10bf 10c2 10c7 10c8 10cd 10ce 10d3 10d5
10d9 10dc 10e0 10e4 10e7 10eb 10ef 10f2
10f6 10fa 10fb 1100 1102 1106 110a 110d
1111 1115 1118 111c 1120 1123 1126 112b
112e 1131 1134 1135 113a 113b 1 113d
1142 1146 114a 114d 1152 1157 115a 115e
115f 1164 1165 116a 116e 1172 1175 117a
117f 1182 1186 118a 118d 118e 1193 1196
119b 119c 11a1 11a4 11a8 11ac 11af 11b0
11b5 11b6 11bb 11bd 11c1 11c4 11c8 11cc
11d0 11d4 11d8 11dc 11e0 11e4 11e8 11f4
11f9 11fd 1201 1205 1209 120b 120c 1211
1 1215 1219 121d 1220 1224 1228 122c
1230 1233 1237 123b 123e 1241 1246 1249
124c 124f 1250 1255 1256 1 1258 125d
1261 1265 1268 126d 1272 1275 1279 127a
127f 1280 1285 1289 128d 1290 1295 129a
129d 12a1 12a2 12a7 12aa 12af 12b0 12b5
12b8 12bc 12c0 12c3 12c6 12c7 12c9 12ca
12cf 12d0 12d5 12d7 12db 12de 12e2 12e6
12ea 12ee 12f2 12f6 12fa 1306 130b 130f
1313 1317 131b 131d 1321 1323 132f 1331
1333 1334 1339 133d 133f 134b 134f 1351
1352 135b 
532
2
0 1 a 6 9 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 18 21
20 :2 18 :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 e 17 16
:2 e :2 4 d 16 15 :2 d :2 4 f
18 17 :2 f :2 4 :3 12 :2 4 :3 13 :2 4
:3 11 :2 4 :3 12 :2 4 :3 f :2 4 :3 15 :2 4
:3 e :2 4 f 18 17 :2 f :2 4 :2 d
1c d :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 10 1f 10 :2 4 :2 c
1b c :2 4 :3 10 :2 4 :3 10 :2 4 12
1b 1a :2 12 :2 4 :2 d 1c d :2 4
:2 12 21 12 :2 4 :2 e 1d e :2 4
:2 a 19 a :2 4 :2 11 20 11 :2 4
:2 f 1e f :2 4 :2 14 23 14 :2 4
:2 f 19 f :2 4 :2 f 19 f :2 4
:3 9 :2 4 :3 9 :2 4 :2 f 1e f :2 4
:2 16 25 16 :2 4 :2 11 20 11 :2 4
:2 13 22 13 :2 4 :3 19 :2 4 :2 12 21
12 :2 4 :2 d 1c d :2 4 :2 14 23
14 :2 4 e 17 :3 e 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 5a 60 63 :2 5a 71
8d 8 :2 71 d 10 :2 71 13 16
:2 71 b e :2 71 13 16 1f 27
:2 1f 34 :2 16 :2 71 b e :2 71 13
16 :2 71 1b 1e :2 71 2a 2d :2 71
32 35 :2 71 :2 7 50 :2 4 7 :2 11
23 :2 2d 39 3c 52 54 55 :2 52
:2 23 :3 7 :2 d 12 1e 63 66 :2 1e
:2 7 58 :3 4 11 :2 4 1b :2 4 12
:2 4 14 :2 4 15 4 :4 7 12 :2 7
11 23 46 7 12 21 :3 7 11
31 4c 64 6d 7c 8d 96 a6
:22 7 c d 21 e 19 c 17
26 36 a 28 fffa 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 59 5c 5d :2 59
:2 29 :3 d :2 13 18 24 6a 6d :2 24
7a 7d :2 24 81 84 :2 24 90 93
:2 24 9b 9e :2 24 aa ad b4 bd
c0 :2 ad :2 24 :2 d 60 :2 a :2 7 :4 13
:2 7 4 :3 1 8 :2 11 1c 1a :2 25
:2 1a 7 a :2 14 26 :2 30 3c 40
56 59 5a :2 56 :2 26 :3 a :2 10 15
21 67 6a :2 21 77 7a :2 21 7e
81 :2 21 8b 8e 97 9f :2 a8 :2 97
bb :2 8e :2 21 c3 c6 :2 21 ce d1
:2 21 d6 d9 :2 21 ed f0 :2 21 :2 a
5d :2 7 a :2 14 26 :2 30 3c 3f
55 58 59 :2 55 :2 26 :3 a :2 10 15
21 67 6a :2 21 :2 a 5c :3 7 :2 12
26 :2 2f 41 f :2 7 35 :3 4 17
26 34 3f 54 25 33 41 50
5a 25 2c 37 49 54 25 35
41 54 25 31 3d 4d 57 25
34 3f :2 17 4 7 10 21 :2 7
24 26 :2 24 a :2 14 26 :2 30 3c
40 56 59 5a :2 56 :2 26 :3 a :2 10
15 21 67 6a :2 21 77 7a :2 21
7e 81 :2 21 8b 8e 97 9f :2 97
b1 :2 8e :2 21 b9 bc :2 21 c4 c7
:2 21 cc cf :2 21 e3 e6 :2 21 :2 a
5d :2 7 a :2 14 26 :2 30 3c 3f
55 58 59 :2 55 :2 26 :3 a :2 10 15
21 67 6a :2 21 :2 a 5c :3 7 :2 12
26 2f 40 :2 26 44 f :2 7 2d
7 12 7 a 13 1e :2 a 21
24 :2 21 14 1d 12 13 27 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5f 62
63 :2 5f :2 2f :3 13 :2 19 1e 2a 70
73 :2 2a 80 83 :2 2a 87 8a :2 2a
96 99 :2 2a a1 a4 :2 2a b0 b3
ba c3 c6 :2 b3 :2 2a :2 13 66 :2 10
:2 d :4 19 :2 d a :3 26 d 16 1d
:2 d 22 20 2b 34 :2 22 :2 20 17
14 1b 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 62 65
66 :2 62 :2 32 :3 16 :2 1c 21 2d 73
76 :2 2d 83 86 :2 2d 8a 8d :2 2d
99 9c :2 2d a4 a7 :2 2d b3 b6
bd c6 c9 :2 b6 :2 2d :2 16 69 :2 13
:2 10 :4 1c :2 10 d :4 37 :2 a 26 :3 7
1a 24 :2 1a 7 :4 4 7 :2 11 23
:2 2d 39 3c 52 55 56 :2 52 :2 23
:3 7 :2 d 12 1e 64 67 :2 1e 74
77 :2 1e 7b 7e :2 1e 88 8b 94
9c :2 a5 :2 94 b0 :2 8b :2 1e b8 bb
:2 1e c3 c6 :2 1e cb ce :2 1e d1
d4 :2 1e :2 7 59 :3 4 :2 f 21 :2 2a
34 38 :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 56 59 5a
:2 56 :2 26 :3 a :2 10 15 21 67 6a
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 5d :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 53 56 57
:2 53 :2 23 :3 7 :2 d 12 1e 64 67
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 5a :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
532
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :7 e :5 f
:5 10 :5 11 :5 12 :5 13
:5 14 :5 15 :7 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:5 1c :5 1d :7 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:5 28 :5 29 :6 2a :6 2b
:6 2c :6 2d :5 2e :6 2f
:6 30 :6 31 :7 33 :b 35
:11 36 37 :2 36 :2 37
:2 36 :2 37 :2 36 :2 38
:2 36 :9 38 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:4 36 :3 35 :11 3c :b 3d
:3 3c :3 44 :3 45 :3 46
:3 4a :3 4c 51 52
53 :2 54 55 56
:3 57 :3 58 59 5a
5b :9 5c 5d 5e
5f 60 61 62
63 64 65 66
67 69 6a 6b
6c 6d 6e 6f
70 71 72 73
74 75 76 77
78 79 7a 7b
7c 7d 7e 7f
80 :2 81 :2 82 :4 83
:2 84 51 :5 85 4f
87 :5 88 :3 87 :2 89
:5 8b :11 8c :24 8d :3 8c
:2 8a :6 89 86 :3 34
:a 92 :11 93 :30 94 :3 93
:11 96 :b 97 :3 96 :7 99
9a :2 99 :3 92 :6 9d
:5 9e :5 9f :4 a0 :5 a1
:3 a2 :3 9d :9 a6 :11 a9
:2e aa :3 a9 :11 ac :b ad
:3 ac :9 af b0 :2 af
a6 :3 b2 :9 b5 :2 b7
b8 :2 b9 b7 :5 ba
b6 bc :5 bd :3 bc
:2 be :5 c0 :11 c1 :24 c2
:3 c1 :2 bf :6 be bb
:3 b5 :d c7 c9 :2 ca
:2 cb c9 :6 cc :5 cd
cc :5 cf ce :3 cc
c8 d2 :5 d3 :3 d2
:2 d4 :5 d6 :11 d7 :24 d8
:3 d7 :2 d5 :6 d4 d1
:6 c7 :3 b5 :6 df b1
:3 a6 :11 e2 :30 e3 :3 e2
:a e5 34 :3 e8 :11 e9
:b ea :17 eb :3 e9 :2 ed
:3 ee :3 ef f0 ee
ed ee :3 f1 :3 e8
:2 f2 :5 f4 :11 f5 :b f6
:18 f7 :3 f5 :2 f9 fa
:3 fb fc fa f9
fa :3 fd :2 f3 :6 f2
e7 :7 1 
135d
4
:3 0 1 :3 0 2
:a 0 52d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 52d 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 52b
0 b :6 0 c
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 52b
0 d :6 0 c
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 52b
0 e :6 0 c
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 52b
0 f :6 0 c
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 52b
0 10 :6 0 13
:2 0 23 4 :3 0
21 3a 3c :6 0
3f 3d 0 52b
0 11 :6 0 29
13b 0 27 4
:3 0 25 41 43
:6 0 46 44 0
52b 0 12 :6 0
2d 16f 0 2b
15 :3 0 48 :7 0
4b 49 0 52b
0 14 :6 0 15
:3 0 4d :7 0 50
4e 0 52b 0
16 :6 0 31 1a3
0 2f 15 :3 0
52 :7 0 55 53
0 52b 0 17
:6 0 15 :3 0 57
:7 0 5a 58 0
52b 0 18 :6 0
35 1d7 0 33
1a :3 0 5c :7 0
5f 5d 0 52b
0 19 :6 0 1a
:3 0 61 :7 0 64
62 0 52b 0
1b :6 0 1f :2 0
39 1a :3 0 66
:7 0 69 67 0
52b 0 1c :6 0
4 :3 0 13 :2 0
37 6b 6d :6 0
70 6e 0 52b
0 1d :6 0 1f
:2 0 3b 6 :3 0
72 :7 0 76 73
74 52b 0 1e
:6 0 1f :2 0 3d
6 :3 0 78 :7 0
7c 79 7a 52b
0 20 :6 0 1f
:2 0 3f 6 :3 0
7e :7 0 82 7f
80 52b 0 21
:6 0 1f :2 0 41
6 :3 0 84 :7 0
88 85 86 52b
0 22 :6 0 45
29b 0 43 6
:3 0 8a :7 0 8e
8b 8c 52b 0
23 :6 0 27 :2 0
47 15 :3 0 90
:7 0 93 91 0
52b 0 24 :6 0
1a :3 0 95 :7 0
98 96 0 52b
0 25 :6 0 1f
:2 0 4b 4 :3 0
49 9a 9c :6 0
9f 9d 0 52b
0 26 :6 0 1f
:2 0 4d 6 :3 0
a1 :7 0 a5 a2
a3 52b 0 28
:6 0 1f :2 0 4f
6 :3 0 a7 :7 0
ab a8 a9 52b
0 29 :6 0 1f
:2 0 51 6 :3 0
ad :7 0 b1 ae
af 52b 0 2a
:6 0 1f :2 0 53
6 :3 0 b3 :7 0
b7 b4 b5 52b
0 2b :6 0 1f
:2 0 55 6 :3 0
b9 :7 0 bd ba
bb 52b 0 2c
:6 0 1f :2 0 57
6 :3 0 bf :7 0
c3 c0 c1 52b
0 2d :6 0 31
:2 0 59 6 :3 0
c5 :7 0 c9 c6
c7 52b 0 2e
:6 0 31 :2 0 5b
30 :3 0 cb :7 0
cf cc cd 52b
0 2f :6 0 5f
3e8 0 5d 30
:3 0 d1 :7 0 d5
d2 d3 52b 0
32 :6 0 1f :2 0
61 1a :3 0 d7
:7 0 da d8 0
52b 0 33 :6 0
1a :3 0 dc :7 0
df dd 0 52b
0 34 :6 0 1f
:2 0 63 6 :3 0
e1 :7 0 e5 e2
e3 52b 0 35
:6 0 1f :2 0 65
6 :3 0 e7 :7 0
eb e8 e9 52b
0 36 :6 0 1f
:2 0 67 6 :3 0
ed :7 0 f1 ee
ef 52b 0 37
:6 0 6b 48c 0
69 6 :3 0 f3
:7 0 f7 f4 f5
52b 0 38 :6 0
1f :2 0 6d 1a
:3 0 f9 :7 0 fc
fa 0 52b 0
39 :6 0 6 :3 0
fe :7 0 1f :2 0
102 ff 100 52b
0 3a :6 0 1f
:2 0 6f 6 :3 0
104 :7 0 108 105
106 52b 0 3b
:6 0 110 111 0
71 6 :3 0 10a
:7 0 10e 10b 10c
52b 0 3c :6 0
116 117 0 73
9 :3 0 a :2 0
4 112 :7 0 115
113 0 52b 0
3d :6 0 3e :3 0
3f :3 0 3e :3 0
40 :3 0 119 11a
0 2 :4 0 75
11b 11d 118 11f
11e :2 0 41 :3 0
42 :3 0 121 122
0 43 :4 0 3e
:3 0 44 :3 0 125
126 0 2 :4 0
77 127 129 45
:4 0 46 :2 0 47
:3 0 79 12c 12e
:3 0 48 :4 0 46
:2 0 49 :4 0 7c
131 133 :3 0 46
:2 0 3 :3 0 7f
135 137 :3 0 46
:2 0 49 :4 0 82
139 13b :3 0 46
:2 0 4a :4 0 85
13d 13f :3 0 46
:2 0 4b :3 0 4c
:3 0 5 :3 0 88
143 145 4d :4 0
8a 142 148 8d
141 14a :3 0 46
:2 0 4a :4 0 90
14c 14e :3 0 46
:2 0 49 :4 0 93
150 152 :3 0 46
:2 0 7 :3 0 96
154 156 :3 0 46
:2 0 49 :4 0 99
158 15a :3 0 46
:2 0 4e :4 0 9c
15c 15e :3 0 9f
123 160 :2 0 162
a4 163 120 162
0 164 a6 0
48b 3e :3 0 3f
:3 0 165 166 0
3e :3 0 4f :3 0
168 169 0 13
:2 0 2 :4 0 50
:2 0 51 :2 0 13
:2 0 a8 16e 170
:3 0 ab 16a 172
167 174 173 :2 0
41 :3 0 52 :3 0
176 177 0 43
:4 0 53 :4 0 46
:2 0 47 :3 0 af
17b 17d :3 0 b2
178 17f :2 0 181
b5 182 175 181
0 183 b7 0
48b 21 :3 0 5
:3 0 184 185 0
48b b :3 0 3
:3 0 187 188 0
48b e :3 0 7
:3 0 18a 18b 0
48b 17 :4 0 18d
18e 0 48b 18
:4 0 190 191 0
48b 54 :3 0 55
:3 0 56 :3 0 57
:3 0 58 :3 0 59
:3 0 5a :3 0 21
:3 0 59 :3 0 5b
:3 0 57 :3 0 58
:3 0 5c :3 0 5b
:3 0 5d :3 0 5e
:3 0 5a :3 0 59
:3 0 5a :3 0 4b
:3 0 5f :3 0 60
:3 0 4b :3 0 61
:3 0 62 :3 0 63
:3 0 64 :3 0 65
:3 0 66 :3 0 67
:3 0 68 :3 0 69
:3 0 6a :3 0 6b
:3 0 6c :3 0 5c
:3 0 f :3 0 10
:3 0 d :3 0 2c
:3 0 17 :3 0 18
:3 0 1e :3 0 22
:3 0 2b :3 0 20
:3 0 1b :3 0 2a
:3 0 14 :3 0 16
:3 0 35 :3 0 36
:3 0 2f :3 0 32
:3 0 1d :3 0 38
:3 0 11 :3 0 12
:3 0 3a :3 0 6d
:3 0 6e :3 0 b
:3 0 57 :3 0 58
:3 0 57 :3 0 58
:3 0 5c :3 0 5b
:3 0 59 :3 0 5a
:4 0 6f 1 :8 0
1df 9 :3 0 70
:3 0 1da 1db 0
71 :3 0 1dc 1dd
0 1df b9 232
72 :3 0 9 :3 0
70 :3 0 1e1 1e2
0 71 :3 0 1e3
1e4 0 1e6 bc
1e8 be 1e7 1e6
:2 0 230 73 :3 0
9 :3 0 70 :3 0
1eb 1ec 0 71
:3 0 1ed 1ee 0
228 3e :3 0 3f
:3 0 1f0 1f1 0
3e :3 0 4f :3 0
1f3 1f4 0 74
:2 0 2 :4 0 75
:2 0 51 :2 0 13
:2 0 c0 1f9 1fb
:3 0 c3 1f5 1fd
1f2 1ff 1fe :2 0
41 :3 0 52 :3 0
201 202 0 43
:4 0 76 :4 0 46
:2 0 47 :3 0 c7
206 208 :3 0 46
:2 0 77 :4 0 ca
20a 20c :3 0 46
:2 0 78 :4 0 cd
20e 210 :3 0 46
:2 0 71 :3 0 d0
212 214 :3 0 46
:2 0 79 :4 0 d3
216 218 :3 0 46
:2 0 7a :3 0 7b
:3 0 13 :2 0 7c
:2 0 d6 21b 21f
da 21a 221 :3 0
dd 203 223 :2 0
225 e0 226 200
225 0 227 e2
0 228 e4 22b
:3 0 22b 0 22b
22a 228 229 :6 0
22d 2 :3 0 e7
22f e9 22e 22d
:2 0 230 eb :2 0
232 0 232 231
1df 230 :6 0 48b
1 :3 0 9 :3 0
70 :3 0 234 235
0 9 :3 0 7d
:2 0 7e :3 0 237
239 0 f0 238
23b :3 0 23c :2 0
3e :3 0 3f :3 0
23e 23f 0 3e
:3 0 4f :3 0 241
242 0 c :2 0
2 :4 0 7f :2 0
51 :2 0 13 :2 0
f3 247 249 :3 0
f6 243 24b 240
24d 24c :2 0 41
:3 0 52 :3 0 24f
250 0 43 :4 0
80 :4 0 46 :2 0
47 :3 0 fa 254
256 :3 0 46 :2 0
77 :4 0 fd 258
25a :3 0 46 :2 0
81 :4 0 100 25c
25e :3 0 46 :2 0
4b :3 0 4c :3 0
82 :3 0 83 :3 0
263 264 0 103
262 266 4d :4 0
105 261 269 108
260 26b :3 0 46
:2 0 84 :4 0 10b
26d 26f :3 0 46
:2 0 49 :4 0 10e
271 273 :3 0 46
:2 0 b :3 0 111
275 277 :3 0 46
:2 0 49 :4 0 114
279 27b :3 0 117
251 27d :2 0 27f
11a 280 24e 27f
0 281 11c 0
2ab 3e :3 0 3f
:3 0 282 283 0
3e :3 0 4f :3 0
285 286 0 13
:2 0 2 :4 0 85
:2 0 51 :2 0 13
:2 0 11e 28b 28d
:3 0 121 287 28f
284 291 290 :2 0
41 :3 0 52 :3 0
293 294 0 43
:4 0 86 :4 0 46
:2 0 47 :3 0 125
298 29a :3 0 128
295 29c :2 0 29e
12b 29f 292 29e
0 2a0 12d 0
2ab 87 :3 0 88
:3 0 2a1 2a2 0
82 :3 0 83 :3 0
2a4 2a5 0 b
:3 0 89 :3 0 12f
2a3 2a9 :2 0 2ab
133 2ac 23d 2ab
0 2ad 137 0
48b 2e :3 0 8a
:3 0 f :3 0 10
:3 0 b :3 0 d
:3 0 2c :3 0 17
:3 0 18 :3 0 1e
:3 0 22 :3 0 2b
:3 0 20 :3 0 1b
:3 0 2a :3 0 14
:3 0 16 :3 0 35
:3 0 36 :3 0 2f
:3 0 32 :3 0 1d
:3 0 38 :3 0 11
:3 0 12 :3 0 3a
:3 0 21 :3 0 e
:3 0 139 2af 2ca
2ae 2cb 0 48b
4b :3 0 2e :3 0
1f :2 0 154 2cd
2d0 8b :2 0 8c
:2 0 159 2d2 2d4
:3 0 3e :3 0 3f
:3 0 2d6 2d7 0
3e :3 0 4f :3 0
2d9 2da 0 c
:2 0 2 :4 0 8d
:2 0 51 :2 0 13
:2 0 15c 2df 2e1
:3 0 15f 2db 2e3
2d8 2e5 2e4 :2 0
41 :3 0 52 :3 0
2e7 2e8 0 43
:4 0 8e :4 0 46
:2 0 47 :3 0 163
2ec 2ee :3 0 46
:2 0 77 :4 0 166
2f0 2f2 :3 0 46
:2 0 81 :4 0 169
2f4 2f6 :3 0 46
:2 0 4b :3 0 4c
:3 0 2e :3 0 16c
2fa 2fc 4d :4 0
16e 2f9 2ff 171
2f8 301 :3 0 46
:2 0 84 :4 0 174
303 305 :3 0 46
:2 0 49 :4 0 177
307 309 :3 0 46
:2 0 b :3 0 17a
30b 30d :3 0 46
:2 0 49 :4 0 17d
30f 311 :3 0 180
2e9 313 :2 0 315
183 316 2e6 315
0 317 185 0
343 3e :3 0 3f
:3 0 318 319 0
3e :3 0 4f :3 0
31b 31c 0 13
:2 0 2 :4 0 8f
:2 0 51 :2 0 13
:2 0 187 321 323
:3 0 18a 31d 325
31a 327 326 :2 0
41 :3 0 52 :3 0
329 32a 0 43
:4 0 90 :4 0 46
:2 0 47 :3 0 18e
32e 330 :3 0 191
32b 332 :2 0 334
194 335 328 334
0 336 196 0
343 87 :3 0 88
:3 0 337 338 0
4b :3 0 2e :3 0
1f :2 0 198 33a
33d b :3 0 89
:3 0 19b 339 341
:2 0 343 19f 43a
23 :3 0 1f :2 0
344 345 0 439
4b :3 0 2a :3 0
1f :2 0 1a3 347
34a 91 :2 0 13
:2 0 1a8 34c 34e
:3 0 5b :3 0 23
:3 0 6d :3 0 6e
:3 0 b :4 0 92
1 :8 0 35b 9
:3 0 70 :3 0 356
357 0 71 :3 0
358 359 0 35b
1ab 3ae 72 :3 0
9 :3 0 70 :3 0
35d 35e 0 71
:3 0 35f 360 0
362 1ae 364 1b0
363 362 :2 0 3ac
73 :3 0 9 :3 0
70 :3 0 367 368
0 71 :3 0 369
36a 0 3a4 3e
:3 0 3f :3 0 36c
36d 0 3e :3 0
4f :3 0 36f 370
0 74 :2 0 2
:4 0 93 :2 0 51
:2 0 13 :2 0 1b2
375 377 :3 0 1b5
371 379 36e 37b
37a :2 0 41 :3 0
52 :3 0 37d 37e
0 43 :4 0 94
:4 0 46 :2 0 47
:3 0 1b9 382 384
:3 0 46 :2 0 77
:4 0 1bc 386 388
:3 0 46 :2 0 78
:4 0 1bf 38a 38c
:3 0 46 :2 0 71
:3 0 1c2 38e 390
:3 0 46 :2 0 79
:4 0 1c5 392 394
:3 0 46 :2 0 7a
:3 0 7b :3 0 13
:2 0 7c :2 0 1c8
397 39b 1cc 396
39d :3 0 1cf 37f
39f :2 0 3a1 1d2
3a2 37c 3a1 0
3a3 1d4 0 3a4
1d6 3a7 :3 0 3a7
0 3a7 3a6 3a4
3a5 :6 0 3a9 4
:3 0 1d9 3ab 1db
3aa 3a9 :2 0 3ac
1dd :2 0 3ae 0
3ae 3ad 35b 3ac
:6 0 430 1 :3 0
4b :3 0 2b :3 0
1f :2 0 1e0 3b0
3b3 4b :3 0 8b
:2 0 23 :3 0 1f
:2 0 1e3 3b5 3b9
1e8 3b6 3bb :3 0
6d :3 0 5b :3 0
2b :3 0 6e :3 0
b :4 0 95 1
:8 0 3d8 96 :4 0
3c3 :3 0 89 :3 0
7d :2 0 1ed 3c6
3c7 :3 0 9 :3 0
70 :3 0 3c9 3ca
0 1f :2 0 3cb
3cc 0 3ce 1f0
3d5 9 :3 0 70
:3 0 3cf 3d0 0
97 :2 0 3d1 3d2
0 3d4 1f2 3d6
3c8 3ce 0 3d7
0 3d4 0 3d7
1f4 0 3d8 1f7
42b 72 :3 0 9
:3 0 70 :3 0 3da
3db 0 71 :3 0
3dc 3dd 0 3df
1fa 3e1 1fc 3e0
3df :2 0 429 73
:3 0 9 :3 0 70
:3 0 3e4 3e5 0
71 :3 0 3e6 3e7
0 421 3e :3 0
3f :3 0 3e9 3ea
0 3e :3 0 4f
:3 0 3ec 3ed 0
74 :2 0 2 :4 0
98 :2 0 51 :2 0
13 :2 0 1fe 3f2
3f4 :3 0 201 3ee
3f6 3eb 3f8 3f7
:2 0 41 :3 0 52
:3 0 3fa 3fb 0
43 :4 0 99 :4 0
46 :2 0 47 :3 0
205 3ff 401 :3 0
46 :2 0 77 :4 0
208 403 405 :3 0
46 :2 0 78 :4 0
20b 407 409 :3 0
46 :2 0 71 :3 0
20e 40b 40d :3 0
46 :2 0 79 :4 0
211 40f 411 :3 0
46 :2 0 7a :3 0
7b :3 0 13 :2 0
7c :2 0 214 414
418 218 413 41a
:3 0 21b 3fc 41c
:2 0 41e 21e 41f
3f9 41e 0 420
220 0 421 222
424 :3 0 424 0
424 423 421 422
:6 0 426 6 :3 0
225 428 227 427
426 :2 0 429 229
:2 0 42b 0 42b
42a 3d8 429 :6 0
42d 1 :3 0 22c
42e 3bc 42d 0
42f 22e 0 430
230 431 34f 430
0 432 233 0
439 2e :3 0 9a
:3 0 f :3 0 235
434 436 433 437
0 439 237 43b
2d5 343 0 43c
0 439 0 43c
23b 0 48b 3e
:3 0 3f :3 0 43d
43e 0 3e :3 0
4f :3 0 440 441
0 9b :2 0 2
:4 0 9c :2 0 51
:2 0 13 :2 0 23e
446 448 :3 0 241
442 44a 43f 44c
44b :2 0 41 :3 0
52 :3 0 44e 44f
0 43 :4 0 9d
:4 0 46 :2 0 47
:3 0 245 453 455
:3 0 46 :2 0 77
:4 0 248 457 459
:3 0 46 :2 0 81
:4 0 24b 45b 45d
:3 0 46 :2 0 4b
:3 0 4c :3 0 9
:3 0 70 :3 0 462
463 0 24e 461
465 4d :4 0 250
460 468 253 45f
46a :3 0 46 :2 0
84 :4 0 256 46c
46e :3 0 46 :2 0
49 :4 0 259 470
472 :3 0 46 :2 0
3 :3 0 25c 474
476 :3 0 46 :2 0
49 :4 0 25f 478
47a :3 0 262 450
47c :2 0 47e 265
47f 44d 47e 0
480 267 0 48b
87 :3 0 9e :3 0
481 482 0 9
:3 0 70 :3 0 484
485 0 3 :3 0
89 :3 0 269 483
489 :2 0 48b 26d
52c 9 :3 0 9f
:2 0 4 48c 48d
0 3e :3 0 3f
:3 0 48f 490 0
3e :3 0 4f :3 0
492 493 0 74
:2 0 2 :4 0 a0
:2 0 51 :2 0 13
:2 0 27b 498 49a
:3 0 27e 494 49c
491 49e 49d :2 0
41 :3 0 52 :3 0
4a0 4a1 0 43
:4 0 a1 :4 0 46
:2 0 47 :3 0 282
4a5 4a7 :3 0 285
4a2 4a9 :2 0 4c2
41 :3 0 52 :3 0
4ab 4ac 0 43
:4 0 a2 :4 0 46
:2 0 9 :3 0 a3
:3 0 4b1 4b2 0
288 4b0 4b4 :3 0
46 :2 0 84 :4 0
28b 4b6 4b8 :3 0
46 :2 0 9 :3 0
a4 :3 0 4bb 4bc
0 28e 4ba 4be
:3 0 291 4ad 4c0
:2 0 4c2 294 4c3
49f 4c2 0 4c4
297 0 4d4 a5
:3 0 3d :3 0 9
:3 0 a3 :3 0 a6
:3 0 9 :3 0 a4
:3 0 3 :3 0 a7
:4 0 a8 1 :a 0
4d0 :2 0 4d4 4c6
4ce :2 0 8 :3 0
3d :3 0 4d2 :2 0
4d4 299 4d6 29d
4d5 4d4 :2 0 52a
73 :3 0 9 :3 0
70 :3 0 4d9 4da
0 71 :3 0 4db
4dc 0 522 3e
:3 0 3f :3 0 4de
4df 0 3e :3 0
4f :3 0 4e1 4e2
0 74 :2 0 2
:4 0 a9 :2 0 51
:2 0 13 :2 0 29f
4e7 4e9 :3 0 2a2
4e3 4eb 4e0 4ed
4ec :2 0 41 :3 0
52 :3 0 4ef 4f0
0 43 :4 0 aa
:4 0 46 :2 0 47
:3 0 2a6 4f4 4f6
:3 0 2a9 4f1 4f8
:2 0 512 41 :3 0
52 :3 0 4fa 4fb
0 43 :4 0 78
:4 0 46 :2 0 71
:3 0 2ac 4ff 501
:3 0 46 :2 0 79
:4 0 2af 503 505
:3 0 46 :2 0 7a
:3 0 7b :3 0 13
:2 0 7c :2 0 2b2
508 50c 2b6 507
50e :3 0 2b9 4fc
510 :2 0 512 2bc
513 4ee 512 0
514 2bf 0 522
a5 :3 0 3d :3 0
a6 :3 0 9 :3 0
a4 :3 0 3 :3 0
a7 :4 0 ab 1
:a 0 51e :2 0 522
516 51c :2 0 8
:3 0 3d :3 0 520
:2 0 522 2c1 525
:3 0 525 0 525
524 522 523 :6 0
527 1 :3 0 2c6
529 2c8 528 527
:2 0 52a 2ca :2 0
52c 2cd 52c 52b
48b 52a :6 0 52d
:2 0 2 14 52c
530 :3 0 52f 52d
531 :8 0 
2f9
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
42 1 40 1
47 1 4c 1
51 1 56 1
5b 1 60 1
65 1 6c 1
6a 1 71 1
77 1 7d 1
83 1 89 1
8f 1 94 1
9b 1 99 1
a0 1 a6 1
ac 1 b2 1
b8 1 be 1
c4 1 ca 1
d0 1 d6 1
db 1 e0 1
e6 1 ec 1
f2 1 f8 1
fd 1 103 1
109 1 10f 1
11c 1 128 2
12b 12d 2 130
132 2 134 136
2 138 13a 2
13c 13e 1 144
2 146 147 2
140 149 2 14b
14d 2 14f 151
2 153 155 2
157 159 2 15b
15d 4 124 12a
12f 15f 1 161
1 163 2 16d
16f 3 16b 16c
171 2 17a 17c
2 179 17e 1
180 1 182 2
1d9 1de 1 1e5
1 1e0 2 1f8
1fa 3 1f6 1f7
1fc 2 205 207
2 209 20b 2
20d 20f 2 211
213 2 215 217
3 21c 21d 21e
2 219 220 2
204 222 1 224
1 226 2 1ef
227 1 22b 1
1ea 2 1e8 22f
1 23a 2 236
23a 2 246 248
3 244 245 24a
2 253 255 2
257 259 2 25b
25d 1 265 2
267 268 2 25f
26a 2 26c 26e
2 270 272 2
274 276 2 278
27a 2 252 27c
1 27e 1 280
2 28a 28c 3
288 289 28e 2
297 299 2 296
29b 1 29d 1
29f 3 2a6 2a7
2a8 3 281 2a0
2aa 1 2ac 1a
2b0 2b1 2b2 2b3
2b4 2b5 2b6 2b7
2b8 2b9 2ba 2bb
2bc 2bd 2be 2bf
2c0 2c1 2c2 2c3
2c4 2c5 2c6 2c7
2c8 2c9 2 2ce
2cf 1 2d3 2
2d1 2d3 2 2de
2e0 3 2dc 2dd
2e2 2 2eb 2ed
2 2ef 2f1 2
2f3 2f5 1 2fb
2 2fd 2fe 2
2f7 300 2 302
304 2 306 308
2 30a 30c 2
30e 310 2 2ea
312 1 314 1
316 2 320 322
3 31e 31f 324
2 32d 32f 2
32c 331 1 333
1 335 2 33b
33c 3 33e 33f
340 3 317 336
342 2 348 349
1 34d 2 34b
34d 2 355 35a
1 361 1 35c
2 374 376 3
372 373 378 2
381 383 2 385
387 2 389 38b
2 38d 38f 2
391 393 3 398
399 39a 2 395
39c 2 380 39e
1 3a0 1 3a2
2 36b 3a3 1
3a7 1 366 2
364 3ab 2 3b1
3b2 2 3b7 3b8
1 3ba 2 3b4
3ba 1 3c5 2
3c4 3c5 1 3cd
1 3d3 2 3d5
3d6 2 3c2 3d7
1 3de 1 3d9
2 3f1 3f3 3
3ef 3f0 3f5 2
3fe 400 2 402
404 2 406 408
2 40a 40c 2
40e 410 3 415
416 417 2 412
419 2 3fd 41b
1 41d 1 41f
2 3e8 420 1
424 1 3e3 2
3e1 428 1 42b
1 42e 2 3ae
42f 1 431 1
435 3 346 432
438 2 43a 43b
2 445 447 3
443 444 449 2
452 454 2 456
458 2 45a 45c
1 464 2 466
467 2 45e 469
2 46b 46d 2
46f 471 2 473
475 2 477 479
2 451 47b 1
47d 1 47f 3
486 487 488 d
164 183 186 189
18c 18f 192 232
2ad 2cc 43c 480
48a 2 497 499
3 495 496 49b
2 4a4 4a6 2
4a3 4a8 2 4af
4b3 2 4b5 4b7
2 4b9 4bd 2
4ae 4bf 2 4aa
4c1 1 4c3 3
4c4 4cf 4d3 1
48e 2 4e6 4e8
3 4e4 4e5 4ea
2 4f3 4f5 2
4f2 4f7 2 4fe
500 2 502 504
3 509 50a 50b
2 506 50d 2
4fd 50f 2 4f9
511 1 513 4
4dd 514 51d 521
1 525 1 4d8
2 4d6 529 2b
1b 22 29 30
37 3e 45 4a
4f 54 59 5e
63 68 6f 75
7b 81 87 8d
92 97 9e a4
aa b0 b6 bc
c2 c8 ce d4
d9 de e4 ea
f0 f6 fb 101
107 10d 114 
1
4
0 
530
0
1
14
8
2f
0 1 2 1 4 1 6 1
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
2 0 1
83 1 0
be 1 0
3 1 0
f2 1 0
56 1 0
16 1 0
ec 1 0
1d 1 0
b2 1 0
a0 1 0
40 1 0
d0 1 0
94 1 0
c4 1 0
109 1 0
60 1 0
71 1 0
47 1 0
51 1 0
e0 1 0
7d 1 0
b8 1 0
99 1 0
db 1 0
89 1 0
e6 1 0
32 1 0
f8 1 0
4c 1 0
fd 1 0
6a 1 0
8f 1 0
65 1 0
39 1 0
2b 1 0
7 1 0
d6 1 0
ca 1 0
5b 1 0
24 1 0
77 1 0
ac 1 0
a6 1 0
10f 1 0
103 1 0
0

/
SHOW ERRORS FUNCTION SP_ACPT_ETC_ASSIGN;
ALTER FUNCTION SP_ACPT_ETC_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Accept ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST DATES
    3 - ETC + FORECAST DATES
****************************************************************************************/
Prompt == FUNCTION SP_ACPT_ETC_WBS ==
CREATE OR REPLACE FUNCTION SP_ACPT_ETC_WBS wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ec
2 :e:
1FUNCTION:
1SP_ACPT_ETC_WBS:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PRJ_ASSIGNMENT_ID:
132:
1H_PROJECT_ID:
1H_RANK:
1200:
1H_REC_USER:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_TA_START_DT:
1TIMESTAMP:
1H_TA_FINISH_DT:
1H_START_DATE:
1H_FINISH_DATE:
1H_START_DT:
1H_FINISH_DT:
1H_FINISH_D:
1DATE:
1H_WEEK_OF:
1H_LAST_SUBMITTED:
1H_TASK_ID:
1H_TSK_ASSIGNMENT_ID:
1H_BIT_FLAG:
1H_BITFLAG:
10:
1H_CONTOUR:
1H_EFFORT:
1H_REMAINING:
1H_TOTAL:
1H_TYPE:
1H_PASSED:
1H_CONSTR_DT:
1H_DAYOFYEAR:
1H_FINISH_TIME:
18:
1H_MINUTE:
1H_CONSTR_TYPE:
1H_ETC:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_SD:
1H_FD:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_NOT_EFFORT_PA:
1H_FF_FLAG:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
1CURSOR:
1CAWTSK:
1PROJECT_ID:
1ELEMENT_ID:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1COALESCE:
1PLANNED_START:
1SCHED_START:
1FORECAST_FINISH:
1PLANNED_FINISH:
1SCHED_FINISH:
1TMT_WBS:
1RANK:
1TYPE_ID:
1PMO_CNST:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1WORK_TODATE:
1ETC:
1SELECT PROJECT_ID, ELEMENT_ID, SCHED_EFFORT+PLANNED_EFFORT,:n         CASE WH+
1EN FORECAST_START IS NULL THEN COALESCE(PLANNED_START, SCHED_START) ELSE FORE+
1CAST_START END,:n         CASE WHEN FORECAST_FINISH IS NULL THEN COALESCE(PLA+
1NNED_FINISH, SCHED_FINISH) ELSE FORECAST_FINISH END:n         FROM TMT_WBS WH+
1ERE RANK LIKE h_rank AND TYPE_ID IN (pmo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,+
1pmo_cnst.SC_TASK_TYPE2,pmo_cnst.SC_TASK_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.+
1SC_PERSONAL_TASK,pmo_cnst.SC_ACTIVE_ADM_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pm+
1o_cnst.SC_WBS_CHANGE_REQUEST_TASK,pmo_cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.S+
1C_WBS_RISK_TASK,pmo_cnst.SC_WBS_ISSUE_TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,p+
1mo_cnst.SC_WBS_DEFECT_TASK,pmo_cnst.SC_WBS_SERVICE_REQUEST_TASK):n         AN+
1D (((SCHED_EFFORT+PLANNED_EFFORT) > 0 AND ((SCHED_EFFORT+PLANNED_EFFORT-WORK_+
1TODATE) <> ETC)) OR:n         (FORECAST_START IS NOT NULL OR FORECAST_FINISH +
1IS NOT NULL)) ORDER BY COALESCE(PLANNED_START, SCHED_START):
1CAWASS:
1TSK_ASSIGNMENT_ID:
1PROJECT_ASSIGNMENT_ID:
1SCHED_WORK:
1PLANNED_WORK:
1C_CONTOUR:
1LAST_SUBMITTED:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1BIT_FLAG:
1MILESTONE_PERCENT:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1TASK_ID:
1SELECT:n         TSK_ASSIGNMENT_ID,:n         PROJECT_ASSIGNMENT_ID,:n       +
1  SCHED_WORK+PLANNED_WORK,:n         FORECAST_START,:n         FORECAST_FINIS+
1H,:n         CASE WHEN h_bitflag = 2 AND FORECAST_START IS NuLL THEN 0 ELSE E+
1TC END,:n         SCHED_WORK+PLANNED_WORK - WORK_TODATE,:n         ETC,:n    +
1     C_CONTOUR,:n         LAST_SUBMITTED,:n         CASE WHEN FORECAST_FINISH+
1 IS NOT NuLL AND FORECAST_START IS NuLL AND FORECAST_FINISH BETWEEN COALESCE(+
1PLANNED_START, SCHED_START) AND COALESCE(PLANNED_FINISH, SCHED_FINISH) THEN 1+
1 ELSE 0 END,:n         UNRESOLVED_START,:n         UNRESOLVED_FINISH,:n      +
1   BILLABLE,:n         CAPITAL_EXPENSE,:n         REGULAR_COST,:n         REG+
1ULAR_RATE,:n         BIT_FLAG,:n         MILESTONE_PERCENT,:n         RESOURC+
1E_ID,:n         RESOURCE_TYPE,:n         WORK_TODATE:n         FROM TASK_ASSI+
1GNMENTS:n         WHERE PROJECT_ID = h_project_id:n         AND TASK_ID = h_t+
1ask_id:n         AND (((SCHED_WORK+PLANNED_WORK) > 0:n         AND ((SCHED_WO+
1RK + PLANNED_WORK - WORK_TODATE) <> ETC)):n         OR (FORECAST_START IS NOT+
1 NULL OR FORECAST_FINISH IS NOT NULL)):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ACPT_ETC_WBS(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1106:
1+:
1FPUT:
1               ENTER:: SP_ACPT_ETC_WBS(107) :: cplan.sql(20297) :: :
1RTRIM:
1SELECT RTRIM(RANK), TYPE_ID INTO h_rank, h_type:n      FROM TMT_WBS WHERE ELE+
1MENT_ID = id/*HOST(h_id)*/:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1125:
1           EXCEPTION:: SP_ACPT_ETC_WBS(126) :: cplan.sql(20316) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_SUCCESS:
1IS NOT NULL:
1%:
1-:
1OPEN:
1LOOP:
1FOUND:
1100:
1!=:
1EXIT:
12:
1FC_ACPT_DURATION:
1FC_ACPT_EFFORT:
1ELSIF:
1CANNOT_ACCEPT_FROM_PROJECT_AFF:
1CLOSE:
1232:
1           EXCEPTION:: SP_ACPT_ETC_WBS(233) :: cplan.sql(20423) :: :
1>:
1CONSTRAINT_DT:
1CONSTRAINT_TYPE:
1SELECT CONSTRAINT_DT, CONSTRAINT_TYPE, FORECAST_START, FORECAST_FINISH:n     +
1             INTO h_constr_DT, h_constr_type, h_start_DT, h_finish_DT:n      +
1            FROM TMT_WBS WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_t+
1ask_id:
1256:
1           EXCEPTION:: SP_ACPT_ETC_WBS(257) :: cplan.sql(20447) :: :
1TO_DATE:
1UPDATE TMT_WBS SET:n                        CONSTRAINT_DT =:n                +
1        CASE:n                        WHEN h_constr_type IN (1,2,3,4) AND TO_+
1DATE(SubStr(h_constr_DT, 1, 10)) < TO_DATE(SubStr(h_finish_DT, 1, 10)) THEN h+
1_finish_DT:n                        WHEN h_constr_type IN (0,5,6,7) THEN h_fi+
1nish_DT:n                        ELSE h_constr_DT:n                        EN+
1D,:n                        CONSTRAINT_TYPE =:n                        CASE:n+
1                        WHEN h_constr_type IN (1,2,3,4) AND TO_DATE(SubStr(h_+
1constr_DT, 1, 10)) < TO_DATE(SubStr(h_finish_DT, 1, 10)) THEN 2:n            +
1            WHEN h_constr_type IN (0,5,6,7) THEN 2:n                        E+
1LSE h_constr_type:n                        END:n                        WHERE+
1 PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1TRUE:
1292:
1           EXCEPTION:: SP_ACPT_ETC_WBS(293) :: cplan.sql(20483) :: :
1UPDATE TMT_WBS SET CONSTRAINT_DT = h_finish_DT, CONSTRAINT_TYPE = 2:n        +
1                WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1312:
1           EXCEPTION:: SP_ACPT_ETC_WBS(313) :: cplan.sql(20503) :: :
1IS NULL:
1UPDATE TMT_WBS SET:n                        CONSTRAINT_DT =:n                +
1        CASE:n                        WHEN h_constr_type IN (0,5,6,7) AND TO_+
1DATE(SubStr(h_constr_DT, 1, 10)) > TO_DATE(SubStr(h_start_DT, 1, 10)) THEN h_+
1start_DT:n                        WHEN h_constr_type IN (1,2,3,4) THEN h_star+
1t_DT:n                        ELSE h_constr_DT:n                        END,+
1:n                        CONSTRAINT_TYPE =:n                        CASE:n  +
1                      WHEN h_constr_type IN (0,5,6,7) AND TO_DATE(SubStr(h_co+
1nstr_DT, 1, 10)) > TO_DATE(SubStr(h_start_DT, 1, 10)) THEN 6:n               +
1         WHEN h_constr_type IN (1,2,3,4) THEN 6:n                        ELSE+
1 h_constr_type:n                        END:n                        WHERE PR+
1OJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1347:
1           EXCEPTION:: SP_ACPT_ETC_WBS(348) :: cplan.sql(20538) :: :
1UPDATE TMT_WBS SET CONSTRAINT_DT = h_start_DT, CONSTRAINT_TYPE = 6:n         +
1               WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1367:
1           EXCEPTION:: SP_ACPT_ETC_WBS(368) :: cplan.sql(20558) :: :
1388:
1           EXCEPTION:: SP_ACPT_ETC_WBS(389) :: cplan.sql(20579) :: :
1NLEN:
1LENGTH:
1NOT:
1MOD:
14:
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1INVALID_RANK_LIKE:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_PROPOSED_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PROP+
1OSED_BIT):n            WHERE PROJECT_ID = h_project_id AND RANK LIKE h_rank:
1425:
1           EXCEPTION:: SP_ACPT_ETC_WBS(426) :: cplan.sql(20616) :: :
1FC_ROLLUP:
1442:
1       RETURN_STATUS:: SP_ACPT_ETC_WBS(443) :: cplan.sql(20633) :: :
1STATE:: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1449:
1           EXCEPTION:: SP_ACPT_ETC_WBS(450) :: cplan.sql(20640) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1461:
1           EXCEPTION:: SP_ACPT_ETC_WBS(462) :: cplan.sql(20652) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
930
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :3b a0 12a bd b7 11 a4 b1
a0 f4 b4 bf c8 :30 a0 12a bd
b7 11 a4 b1 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:2 a0 d a0 51 d :8 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 7e b4 2e :2 5a a 10 :3 a0
7e 6e b4 2e :2 51 a5 b d
a0 7e 51 b4 2e d :2 a0 e9
dd b3 :7 a0 e9 d3 5 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 2b b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :3 a0 6b d :7 a0 a5 b
d :2 a0 6b a0 d :3 a0 51 a5
b 7e 51 b4 2e d b7 19
3c b7 a0 4d d a0 4d d
:2 a0 e9 dd b3 :18 a0 e9 d3 5
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
2b b7 19 3c :1c a0 a5 b d
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e 51 b4 2e
d a0 b7 :2 a0 51 a5 b a0
7e a0 6b b4 2e :3 a0 51 a5
b 7e 51 b4 2e d b7 :2 19
3c b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 a0 4d d a0 4d
d :d a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e b4 2e 5a
a0 7e b4 2e 5a :1b a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :8 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c a0 b7 a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a a 10 a0
7e b4 2e 5a :1b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :2 19 3c b7 19 3c b7 :2 19
3c b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b :2 7e 51 b4 2e
b4 2e 5a a 10 a3 a0 1c
51 81 b0 a0 7e b4 2e 5a
:4 a0 a5 b 51 a5 b d 51
7e 51 b4 2e a0 7e 51 b4
2e a 10 :2 a0 7e 51 b4 2e
d b7 19 3c b7 19 3c a0
7e 51 b4 2e 7e b4 2e :2 a0
7e 51 b4 2e 5a 7e 51 b4
2e 52 10 :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 a4 b1
11 4f :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 a5 b d b7 19
3c b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
d a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 51 a5
b d b7 :2 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
930
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
133 122 126 12e 101 14b 13a 13e
146 121 167 156 15a 162 11e 17f
16e 172 17a 155 19b 18a 18e 196
152 1b3 1a2 1a6 1ae 189 1cf 1be
1c2 1ca 186 1e7 1d6 1da 1e2 1bd
203 1f2 1f6 1fe 1ba 21f 20a 20e
211 212 21a 1f1 23c 22a 1ee 22e
22f 237 229 259 247 226 24b 24c
254 246 275 264 268 243 270 263
291 280 284 260 28c 27f 2ad 29c
2a0 27c 2a8 29b 2c9 2b8 2bc 298
2c4 2b7 2e5 2d4 2d8 2b4 2e0 2d3
301 2f0 2f4 2d0 2fc 2ef 31d 30c
310 2ec 318 30b 339 328 32c 334
308 351 340 344 34c 327 36e 35c
324 360 361 369 35b 38a 379 37d
358 385 378 3a6 395 399 375 3a1
394 3c2 3b1 3b5 391 3bd 3b0 3de
3cd 3d1 3ad 3d9 3cc 3fa 3e9 3ed
3c9 3f5 3e8 416 405 409 411 3e5
42e 41d 421 429 404 44a 439 43d
401 445 438 466 455 459 435 461
454 482 471 475 451 47d 470 49e
48d 491 46d 499 48c 4ba 4a9 4ad
489 4b5 4a8 4d6 4c5 4c9 4d1 4a5
4ee 4dd 4e1 4e9 4c4 50a 4f9 4fd
4c1 505 4f8 526 515 519 4f5 521
514 542 531 535 511 53d 530 55e
54d 551 52d 559 54c 57a 569 56d
549 575 568 596 585 589 591 565
5b1 59d 5a1 5a9 5ac 584 5b8 5bc
581 5cd 5d0 5d4 5d8 5dc 5e0 5e4
5e8 5ec 5f0 5f4 5f8 5fc 600 604
608 60c 610 614 618 61c 620 624
628 62c 630 634 638 63c 640 644
648 64c 650 654 658 65c 660 664
668 66c 670 674 678 67c 680 684
688 68c 690 694 698 69c 6a0 6a4
6a8 6ac 6b0 6b4 6b8 6bc 6c0 6cc
6d1 6d3 6df 6e3 6e5 6e9 6fa 6fb
6fe 702 706 70a 70e 712 716 71a
71e 722 726 72a 72e 732 736 73a
73e 742 746 74a 74e 752 756 75a
75e 762 766 76a 76e 772 776 77a
77e 782 786 78a 78e 792 796 79a
79e 7a2 7a6 7aa 7ae 7b2 7b6 7ba
7be 7c2 7ce 7d3 7d5 7e1 7e5 803
7eb 7ef 7f3 7f6 7fe 7ea 80a 80e
7e7 812 816 81a 81d 822 823 1
825 82a 82e 832 835 83a 83e 842
845 84a 84b 84d 852 855 859 85a
85f 864 867 86c 86d 872 875 879
87a 87f 882 887 888 88d 890 895
896 89b 89e 8a2 8a6 8aa 8ab 8ad
8b2 8b3 8b5 8b6 8bb 8be 8c3 8c4
8c9 8cc 8d1 8d2 8d7 8da 8de 8df
8e4 8e7 8ec 8ed 8f2 8f5 8fa 8fb
900 901 906 908 90c 90f 913 917
91a 91e 922 925 928 92d 930 933
936 937 93c 93d 1 93f 944 948
94c 94f 954 959 95c 960 961 966
967 96c 96e 972 975 979 97d 981
985 989 98d 991 994 998 99c 9a0
9a4 9a8 9ac 9b0 9b4 9b8 9c4 9c8
9cc 9cf 9d3 9d7 9d9 9dd 9e1 9e5
9e8 9ec 9f0 9f2 9f3 9f8 1 9fc
a00 a04 a07 a0b a0f a13 a17 a1a
a1e a22 a25 a28 a2d a30 a33 a36
a37 a3c a3d 1 a3f a44 a48 a4c
a4f a54 a59 a5c a60 a61 a66 a69
a6e a6f a74 a77 a7c a7d a82 a85
a89 a8a a8f a92 a97 a98 a9d aa0
aa4 aa8 aab aae aaf ab1 ab2 ab7
ab8 abd abf ac3 ac6 ac8 acc ace
ada adc ade adf ae4 ae8 aea af6
af8 afc b00 b03 b07 b0a b0e b11
b12 b17 b1a b1e b21 b22 b27 b2a
1 b2d b32 b36 b3a b3e b41 b46
b47 b4c b4f b52 b53 b55 b59 b5d
b60 b63 b64 b69 b6d b71 b75 b7a
b7e b7f b83 b87 b8b b8f b93 b97
b9b ba0 ba5 ba9 bad bb1 bb6 bba
bbe bc1 bc4 bc8 bca bce bd2 bd5
bd8 bdc bde be2 be6 be9 bed bf1
bf4 bf8 bfb bff c02 c03 c08 c0b
c0f c15 c17 c1b c1e c22 c26 c29
c2a c2c c2f c32 c33 c38 c3c c40
c43 c44 c46 c49 c4c c4d c52 c56
c5a c5e c61 c65 c69 c6d c71 c75
c79 c7d c81 c82 c84 c88 c8c c90
c93 c97 c9b c9f ca3 ca7 caa cab
cad cb0 cb3 cb4 cb9 cbd cbf cc3
cc6 cc8 ccc ccd cd1 cd5 cd6 cda
cde ce2 ce7 ceb cec cf0 cf4 cf8
cfc d00 d04 d08 d0c d10 d14 d18
d1c d20 d24 d28 d2c d30 d34 d38
d3c d40 d44 d48 d4c d51 d56 d5a
d5e d62 d67 d6b d6f d72 d75 d79
d7b d7f d83 d86 d89 d8d d8f d93
d97 d9a d9e da2 da5 da9 dac db0
db3 db4 db9 dbc dc0 dc6 dc8 dcc
dcf dd3 dd7 ddb ddf de3 de7 deb
def df3 df7 dfb dff e03 e07 e0b
e0f e13 e17 e1b e1f e23 e27 e2b
e2f e33 e37 e3b e3f e40 e42 e46
e4a e4e e51 e52 e54 e57 e5a e5b
e60 e64 e68 e6c e6f e70 e72 e75
e78 e79 e7e e82 e86 e88 e8c e90
e93 e94 e96 e9a e9d ea1 ea4 ea5
eaa eae eb2 eb6 eb9 eba ebc ebf
ec2 ec3 ec8 ecc ece ed2 ed6 ed9
edb edf ee6 eea eee ef3 ef5 ef9
efd f00 f04 f08 f0a f0e f12 f16
f19 f1d f21 f23 f24 f29 1 f2d
f31 f35 f38 f3c f40 f44 f48 f4b
f4f f53 f56 f59 f5e f61 f64 f67
f68 f6d f6e 1 f70 f75 f79 f7d
f80 f85 f8a f8d f91 f92 f97 f9a
f9f fa0 fa5 fa8 fad fae fb3 fb6
fba fbb fc0 fc3 fc8 fc9 fce fd1
fd5 fd9 fdc fdf fe0 fe2 fe3 fe8
fe9 fee ff0 ff4 ff7 ff9 ffd fff
100b 100d 100f 1010 1015 1019 101b 1027
1029 102d 1031 1034 1035 1037 103a 103d
103e 1043 1046 104a 104e 1051 1052 1054
1057 105a 105b 1060 1 1063 1068 106c
106d 1071 1075 1076 107a 107e 1082 1086
108a 108e 1092 1096 109a 109e 10a2 10a6
10aa 10ae 10ba 10be 10c2 10c5 10c9 10cd
10cf 10d3 10d7 10db 10de 10e2 10e6 10e8
10e9 10ee 1 10f2 10f6 10fa 10fd 1101
1105 1109 110d 1110 1114 1118 111b 111e
1123 1126 1129 112c 112d 1132 1133 1
1135 113a 113e 1142 1145 114a 114f 1152
1156 1157 115c 115f 1164 1165 116a 116d
1172 1173 1178 117b 117f 1180 1185 1188
118d 118e 1193 1196 119a 119e 11a1 11a4
11a5 11a7 11a8 11ad 11ae 11b3 11b5 11b9
11bc 11be 11c2 11c4 11d0 11d2 11d4 11d5
11da 11de 11e0 11ec 11ee 11f2 11f5 11f6
11fb 11fe 1202 1205 1206 120b 120e 1212
1216 121a 121e 1222 1226 122a 122e 1232
1236 123a 123e 1242 1246 124a 124e 1252
1256 125a 125e 1262 1266 126a 126e 1272
1276 127a 1286 128a 128f 1293 1296 1297
129c 12a0 12a4 12a7 12aa 12ae 12b0 12b4
12b8 12bb 12be 12c2 12c4 12c8 12cc 12cf
12d1 12d5 12d9 12dd 12e0 12e4 12e8 12ea
12eb 12f0 1 12f4 12f8 12fc 12ff 1303
1307 130b 130f 1312 1316 131a 131d 1320
1325 1328 132b 132e 132f 1334 1335 1
1337 133c 1340 1344 1347 134c 1351 1354
1358 1359 135e 1361 1366 1367 136c 136f
1374 1375 137a 137d 1381 1382 1387 138a
138f 1390 1395 1398 139c 13a0 13a3 13a6
13a7 13a9 13aa 13af 13b0 13b5 13b7 13bb
13be 13c0 13c4 13c6 13d2 13d4 13d6 13d7
13dc 13e0 13e2 13ee 13f0 13f2 13f6 13fa
13fe 1402 1406 140a 140e 1412 141e 1422
1427 142b 142e 142f 1434 1438 143c 143f
1442 1446 1448 144c 1450 1453 1456 145a
145c 1460 1464 1467 1469 146d 1471 1475
1478 147c 1480 1482 1483 1488 1 148c
1490 1494 1497 149b 149f 14a3 14a7 14aa
14ae 14b2 14b5 14b8 14bd 14c0 14c3 14c6
14c7 14cc 14cd 1 14cf 14d4 14d8 14dc
14df 14e4 14e9 14ec 14f0 14f1 14f6 14f9
14fe 14ff 1504 1507 150c 150d 1512 1515
1519 151a 151f 1522 1527 1528 152d 1530
1534 1538 153b 153e 153f 1541 1542 1547
1548 154d 154f 1553 1556 1558 155c 155e
156a 156c 156e 156f 1574 1578 157a 1586
1588 158a 158e 1592 1595 1599 159b 159f
15a2 15a3 15a8 15ab 15ae 15b2 15b5 15b6
15bb 15be 1 15c1 15c6 15ca 15cd 15ce
15d3 15d6 15da 15de 15e2 15e6 15ea 15ee
15f2 15f6 15fa 15fe 1602 1606 160a 160e
1612 1616 161a 161e 1622 1626 162a 162e
1632 1636 163a 163e 1642 164e 1652 1657
165b 165e 165f 1664 1668 166c 166f 1672
1676 1678 167c 1680 1683 1686 168a 168c
1690 1694 1697 1699 169d 16a1 16a5 16a8
16ac 16b0 16b2 16b3 16b8 1 16bc 16c0
16c4 16c7 16cb 16cf 16d3 16d7 16da 16de
16e2 16e5 16e8 16ed 16f0 16f3 16f6 16f7
16fc 16fd 1 16ff 1704 1708 170c 170f
1714 1719 171c 1720 1721 1726 1729 172e
172f 1734 1737 173c 173d 1742 1745 1749
174a 174f 1752 1757 1758 175d 1760 1764
1768 176b 176e 176f 1771 1772 1777 1778
177d 177f 1783 1786 1788 178c 178e 179a
179c 179e 179f 17a4 17a8 17aa 17b6 17b8
17ba 17be 17c2 17c6 17ca 17ce 17d2 17d6
17da 17e6 17ea 17ef 17f3 17f6 17f7 17fc
1800 1804 1807 180a 180e 1810 1814 1818
181b 181e 1822 1824 1828 182c 182f 1831
1835 1839 183d 1840 1844 1848 184a 184b
1850 1 1854 1858 185c 185f 1863 1867
186b 186f 1872 1876 187a 187d 1880 1885
1888 188b 188e 188f 1894 1895 1 1897
189c 18a0 18a4 18a7 18ac 18b1 18b4 18b8
18b9 18be 18c1 18c6 18c7 18cc 18cf 18d4
18d5 18da 18dd 18e1 18e2 18e7 18ea 18ef
18f0 18f5 18f8 18fc 1900 1903 1906 1907
1909 190a 190f 1910 1915 1917 191b 191e
1920 1924 1926 1932 1934 1936 1937 193c
1940 1942 194e 1950 1952 1956 195a 195d
195f 1963 1967 196a 196c 1970 1973 1975
1979 197d 1980 1982 1986 198d 1991 1995
199a 199c 19a0 19a4 19a7 19ab 19af 19b1
19b5 19b9 19bd 19c0 19c4 19c8 19ca 19cb
19d0 1 19d4 19d8 19dc 19df 19e3 19e7
19eb 19ef 19f2 19f6 19fa 19fd 1a00 1a05
1a08 1a0b 1a0e 1a0f 1a14 1a15 1 1a17
1a1c 1a20 1a24 1a27 1a2c 1a31 1a34 1a38
1a39 1a3e 1a41 1a46 1a47 1a4c 1a4f 1a54
1a55 1a5a 1a5d 1a61 1a62 1a67 1a6a 1a6f
1a70 1a75 1a78 1a7c 1a80 1a83 1a86 1a87
1a89 1a8a 1a8f 1a90 1a95 1a97 1a9b 1a9e
1aa0 1aa4 1aa6 1ab2 1ab4 1ab6 1ab7 1abc
1ac0 1ac2 1ace 1ad0 1ad4 1ad8 1adb 1adc
1ade 1ae1 1ae4 1ae5 1aea 1aed 1af1 1af5
1af8 1af9 1afb 1afe 1b01 1b04 1b05 1b0a
1b0b 1b10 1 1b13 1b30 1b1c 1b20 1b28
1b2b 1b1b 1b37 1b18 1b3b 1b3c 1b41 1b44
1b48 1b4c 1b50 1b54 1b55 1b57 1b5a 1b5b
1b5d 1b61 1b64 1b67 1b6a 1b6b 1b70 1b74
1b77 1b7a 1b7b 1 1b80 1b85 1b89 1b8d
1b90 1b93 1b94 1b99 1b9d 1b9f 1ba3 1ba6
1ba8 1bac 1baf 1bb3 1bb6 1bb9 1bba 1bbf
1bc2 1bc3 1bc8 1bcc 1bd0 1bd3 1bd6 1bd7
1bdc 1bdf 1be2 1be5 1be6 1 1beb 1bf0
1bf4 1bf8 1bfb 1bff 1c03 1c06 1c0a 1c0e
1c0f 1c14 1c16 1c1a 1c1d 1c1f 1c23 1c25
1c31 1c33 1c37 1c3b 1c3f 1c43 1c47 1c4b
1c4f 1c53 1c57 1c5b 1c5f 1c6b 1c6f 1c74
1c78 1c7b 1c7c 1c81 1c85 1c89 1c8c 1c8f
1c93 1c95 1c99 1c9d 1ca0 1ca3 1ca7 1ca9
1cad 1cb1 1cb4 1cb6 1cba 1cbe 1cc2 1cc5
1cc9 1ccd 1ccf 1cd0 1cd5 1 1cd9 1cdd
1ce1 1ce4 1ce8 1cec 1cf0 1cf4 1cf7 1cfb
1cff 1d02 1d05 1d0a 1d0d 1d10 1d13 1d14
1d19 1d1a 1 1d1c 1d21 1d25 1d29 1d2c
1d31 1d36 1d39 1d3d 1d3e 1d43 1d46 1d4b
1d4c 1d51 1d54 1d59 1d5a 1d5f 1d62 1d66
1d67 1d6c 1d6f 1d74 1d75 1d7a 1d7d 1d81
1d85 1d88 1d8b 1d8c 1d8e 1d8f 1d94 1d95
1d9a 1d9c 1da0 1da3 1da5 1da9 1dab 1db7
1db9 1dbb 1dbc 1dc1 1dc5 1dc7 1dd3 1dd5
1dd9 1ddd 1de1 1de2 1de4 1de8 1dea 1dee
1df1 1df3 1df7 1dfa 1dfe 1e02 1e05 1e06
1e08 1e0b 1e0e 1e0f 1e14 1e18 1e1c 1e1f
1e23 1e27 1e2a 1e2e 1e32 1e34 1e38 1e3c
1e3f 1e40 1e42 1e45 1e48 1e49 1e4e 1e52
1e56 1e59 1e5d 1e61 1e64 1e65 1e67 1e6b
1e6d 1e71 1e75 1e78 1e7c 1e80 1e83 1e87
1e8b 1e8e 1e91 1e96 1e99 1e9c 1e9f 1ea0
1ea5 1ea6 1 1ea8 1ead 1eb1 1eb5 1eb8
1ebd 1ec2 1ec5 1ec9 1eca 1ecf 1ed2 1ed7
1ed8 1edd 1ee0 1ee5 1ee6 1eeb 1eee 1ef2
1ef6 1efa 1efe 1f01 1f02 1f04 1f09 1f0a
1f0c 1f0d 1f12 1f15 1f1a 1f1b 1f20 1f23
1f28 1f29 1f2e 1f31 1f35 1f36 1f3b 1f3e
1f43 1f44 1f49 1f4a 1f4f 1f51 1f55 1f58
1f5c 1f60 1f63 1f67 1f6b 1f6e 1f72 1f76
1f77 1f7c 1f7e 1f82 1f86 1f89 1f8d 1f91
1f94 1f98 1f9c 1f9f 1fa2 1fa7 1faa 1fad
1fb0 1fb1 1fb6 1fb7 1 1fb9 1fbe 1fc2
1fc6 1fc9 1fce 1fd3 1fd6 1fda 1fdb 1fe0
1fe1 1fe6 1fea 1fee 1ff1 1ff6 1ffb 1ffe
2002 2006 2009 200a 200f 2012 2017 2018
201d 2020 2024 2028 202b 202c 2031 2032
2037 2039 203d 2040 2044 2048 204c 2050
2054 2058 205c 2060 2064 2070 2075 2079
207d 2081 2085 2087 2088 208d 1 2091
2095 2099 209c 20a0 20a4 20a8 20ac 20af
20b3 20b7 20ba 20bd 20c2 20c5 20c8 20cb
20cc 20d1 20d2 1 20d4 20d9 20dd 20e1
20e4 20e9 20ee 20f1 20f5 20f6 20fb 20fc
2101 2105 2109 210c 2111 2116 2119 211d
211e 2123 2126 212b 212c 2131 2134 2138
213c 213f 2142 2143 2145 2146 214b 214c
2151 2153 2157 215a 215e 2162 2166 216a
216e 2172 2176 2182 2187 218b 218f 2193
2197 2199 219d 219f 21ab 21ad 21af 21b0
21b5 21b9 21bb 21c7 21cb 21cd 21ce 21d7 
930
2
0 1 a 6 9 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 b 14 13 :2 b :2 4
f 18 17 :2 f :2 4 d 16 15
:2 d :2 4 f 18 17 :2 f :2 4 :3 12
:2 4 :3 13 :2 4 :3 11 :2 4 :3 12 :2 4 :3 f
:2 4 :3 10 :2 4 :3 f :2 4 :3 e :2 4 :3 15
:2 4 e 17 16 :2 e :2 4 18 21
20 :2 18 :2 4 f 18 17 :2 f :2 4
:2 e 1d e :2 4 :2 e 1d e :2 4
:2 d 1c d :2 4 :2 10 1f 10 :2 4
:2 c 1b c :2 4 :2 b 1a b :2 4
:2 d 1c d :2 4 :3 10 :2 4 :3 10 :2 4
12 1b 1a :2 12 :2 4 :2 d 1c d
:2 4 :2 12 21 12 :2 4 :2 a 19 a
:2 4 :2 f 1e f :2 4 :2 14 23 14
:2 4 :3 12 :2 4 :3 13 :2 4 :2 11 20 11
:2 4 :2 12 21 12 :2 4 :2 13 22 13
:2 4 :2 f 19 f :2 4 :2 f 19 f
:2 4 :3 9 :2 4 :3 9 :2 4 :2 f 1e f
:2 4 :2 16 25 16 :2 4 :2 11 20 11
:2 4 :2 14 23 14 :2 4 :2 e 1d e
:2 4 :3 10 :2 4 :2 16 2e 16 4 7
e 0 :2 7 11 1d 29 36 14
30 39 48 5a 14 31 3a 4a
5d f 1d 27 32 3e 47 4f
58 66 6f 7d 86 94 9d aa
b3 c4 cd e0 e9 fe 107 122
12b 143 14c 15d 166 178 181 199
1a2 1b5 1be 11 1e 38 45 54
64 b 29 50 59 68 a :6 7
e 0 :2 7 :3 a 15 :2 a 14 26
49 a 15 24 :3 a 14 34 4f
67 70 7f 90 99 a9 :b a f
10 1d e 18 11 1c 10 1d
2c 3c e 2c fffa :5 7 4 e
17 :3 e 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
57 5d 60 :2 57 6e 87 8 :2 6e
d 10 :2 6e 13 16 :2 6e b e
:2 6e 13 16 1f 27 :2 1f 34 :2 16
:2 6e b e :2 6e 13 16 :2 6e 1b
1e :2 6e 2a 2d :2 6e 32 35 :2 6e
:2 7 4d :2 4 7 :2 11 23 :2 2d 39
3c 4f 52 53 :2 4f :2 23 :3 7 :2 d
12 1e 61 64 :2 1e :2 7 56 :3 4
11 :2 4 12 :2 4 17 4 e 14
1b 28 30 c 1a 27 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 56 59 5a
:2 56 :2 29 :3 d :2 13 18 24 67 6a
:2 24 77 7a :2 24 7e 81 :2 24 8d
90 :2 24 98 9b :2 24 a7 aa b1
ba bd :2 aa :2 24 :2 d 5d :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a 7 :4 3b 3a 39 :3 7 11
18 1f 22 :2 18 27 2a :2 11 :2 7
13 14 :2 13 :2 7 c :4 7 10 1c
2a 35 3f 4d :3 a d 14 :2 d
:2 16 22 d 1a d :2 16 22 d
:4 a e :2 17 23 20 :2 2c :2 20 :3 d
3c :2 a d 16 20 :2 d 23 25
:2 23 10 19 24 :2 10 27 29 :2 27
10 25 :2 2e :2 10 1f 30 3e 49
57 66 :2 1f :2 10 :2 19 25 :2 10 1c
25 2f :2 1c 32 34 :2 1c 10 2b
:2 d 27 d 1d :2 d 1e :2 d 12
:4 d 16 :19 10 13 1a :2 13 :2 1c 28
13 20 13 :2 1c 28 13 :4 10 14
:2 1d 29 26 :2 32 :2 26 :3 13 42 :3 10
23 32 40 4b 60 25 33 41
50 5a 25 2c 37 49 54 25
35 41 54 25 31 3d 4d 57
25 34 3f :2 23 10 13 1c 2d
:2 13 30 32 :2 30 13 1f 28 32
:2 1f 35 37 :2 1f 13 10 34 16
1f 30 :2 16 35 33 :2 3e :2 33 13
26 2f 40 :2 26 43 45 :2 26 13
5d 34 :2 10 d 11 a 10 16
:3 10 :2 19 25 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5f
62 63 :2 5f :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d 80 83 :2 2d 87 8a
:2 2d 96 99 :2 2d a1 a4 :2 2d b0
b3 ba c3 c6 :2 b3 :2 2d :2 16 66
:2 13 :2 10 :4 1c :2 10 d :3 a 11 1a
25 :2 11 28 2b :2 28 10 33 3c
46 :2 33 49 4b :2 49 32 :3 10 1e
:2 10 1f 10 1a 29 3a 4a 18
25 34 40 18 26 33 44 51
:2 13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 62
65 66 :2 62 :2 35 :3 19 :2 1f 24 30
73 76 :2 30 83 86 :2 30 8a 8d
:2 30 99 9c :2 30 a4 a7 :2 30 b3
b6 bd c6 c9 :2 b6 :2 30 :2 19 69
:2 16 :2 13 :4 1f :2 13 10 :3 4e :4 14 13
:4 17 16 20 19 1e 3d 45 4c
63 6b 72 8c 1e 3e 1e 19
1e 3d 45 4c 63 6b 72 :2 1e
1f 2c 3d 4a 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 68 6b
6c :2 68 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :4 30 20 2c 3c
49 1f 2c 3d 4a 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 68
6b 6c :2 68 :2 3b :3 1f :2 25 2a 36
79 7c :2 36 89 8c :2 36 90 93
:2 36 9f a2 :2 36 aa ad :2 36 b9
bc c3 cc cf :2 bc :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :7 13 10 2d
:4 18 17 16 :4 37 36 35 :2 16 :4 17
16 20 19 1e 3d 45 4c 63
6b 72 8b 1e 3e 1e 19 1e
3d 45 4c 63 6b 72 :2 1e 1f
2c 3d 4a 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 68 6b 6c
:2 68 :2 3b :3 1f :2 25 2a 36 79 7c
:2 36 89 8c :2 36 90 93 :2 36 9f
a2 :2 36 aa ad :2 36 b9 bc c3
cc cf :2 bc :2 36 :2 1f 6f :2 1c :2 19
:4 25 :2 19 16 :4 30 20 2c 3c 48
1f 2c 3d 4a 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 68 6b
6c :2 68 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :7 13 4d 2d :2 10
4e :2 d :4 a 7 b 50 a 10
:3 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6a 6d :2 27 7a 7d :2 27 81 84
:2 27 90 93 :2 27 9b 9e :2 27 aa
ad b4 bd c0 :2 ad :2 27 :2 10 60
:2 d :2 a :4 16 :2 a 7 :3 50 b 14
1e :2 b 21 23 :2 21 a 2b 34
3e :2 2b 41 43 44 :2 43 :2 41 2a
:2 a b :2 10 1e 10 b :4 f e
c 14 1d 24 :2 1d 2d :2 14 c
f 11 14 :2 11 1a 1f 22 :2 1f
:2 f c 14 19 1b :2 14 c 24
:2 c 23 :2 b 12 17 1a :2 17 :3 e
20 :2 25 29 :2 20 1f 2c 2f :2 2c
:2 e c :2 17 2b :2 34 47 4f :2 c
31 :2 b :2 a :3 47 14 20 2e 37
3e 4a 53 13 20 31 3b d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5c 5f 60 :2 5c :2 2f :3 13 :2 19
1e 2a 6d 70 :2 2a 7d 80 :2 2a
84 87 :2 2a 93 96 :2 2a 9e a1
:2 2a ad b0 b7 c0 c3 :2 b0 :2 2a
:2 13 63 :2 10 :2 d :4 19 :2 d a :3 47
a 1d 27 :2 1d a 47 :2 7 50
:2 4 7 10 21 :2 7 24 26 :2 24
7 :2 10 1c :2 25 7 4 28 a
13 24 :2 a 27 29 :2 27 7 :2 10
1c 25 36 :2 1c 7 2d 28 :2 4
7 :2 11 23 :2 2d 39 3c 4f 52
53 :2 4f :2 23 :3 7 :2 d 12 1e 61
64 :2 1e 71 74 :2 1e 78 7b :2 1e
85 88 91 99 :2 a2 :2 91 ad :2 88
:2 1e b5 b8 :2 1e c0 c3 :2 1e c8
cb :2 1e ce d1 :2 1e :2 7 56 :3 4
:2 f 21 :2 2a 34 38 :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
53 56 57 :2 53 :2 26 :3 a :2 10 15
21 64 67 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 5a :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
50 53 54 :2 50 :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 57 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
930
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :5 e :5 f
:5 10 :5 11 :5 12 :5 13
:5 14 :5 15 :5 16 :7 17
:7 18 :7 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :5 21 :5 22 :7 23
:6 24 :6 25 :6 26 :6 27
:6 28 :5 29 :5 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:5 30 :5 31 :6 32 :6 33
:6 34 :6 35 :6 36 :5 37
:6 38 :2 3a 0 :2 3a
:4 3b :5 3c :5 3d :22 3e
:6 3f :5 40 3b :5 3a
:2 42 0 :2 42 44
45 :2 46 47 48
:3 49 :3 4a 4b 4c
4d :9 4e 4f 50
51 52 53 54
55 56 57 58
59 5a :2 5b :2 5c
:2 5d :4 5e :2 5f 44
:5 42 :7 61 :b 63 :11 64
65 :2 64 :2 65 :2 64
:2 65 :2 64 :2 66 :2 64
:9 66 :2 64 :2 67 :2 64
:2 67 :2 64 :2 67 :2 64
:2 67 :2 64 :2 67 :4 64
:3 63 :11 6a :b 6b :3 6a
:3 6f :3 70 :3 71 :5 74
:3 75 74 :5 76 73
78 :5 79 :3 78 :2 7a
:5 7c :11 7d :24 7e :3 7d
:2 7b :6 7a 77 :3 62
:12 83 :c 84 :6 85 :5 89
8b :9 8c :3 8d :5 8e
8d :5 90 8f :3 8d
:a 93 :2 94 :3 93 :9 99
:9 9b :5 9d :a 9e :5 9f
:b a1 :3 9b 99 :3 a5
:3 a7 :5 aa ac ad
ae af b0 b1
b2 b3 b4 b5
b6 b7 b8 b9
ba bb bc bd
be bf c0 c1
c2 c3 :3 ad :3 c4
:5 c5 c4 :5 c7 c6
:3 c4 :a ca :2 cb :3 ca
:6 d0 :5 d1 :5 d2 :4 d3
:5 d4 :3 d5 :3 d0 :9 d7
:b d8 d9 d7 :b d9
:b da d9 :3 d7 ac
dc a3 :4 e0 :5 e1
df e3 :5 e4 :3 e3
:2 e5 :5 e7 :11 e8 :24 e9
:3 e8 :2 e6 :6 e5 e2
:3 a3 :16 f1 :3 f2 :3 f3
:4 f6 :4 f7 :5 f8 f6
:5 f9 f5 fb :5 fc
:3 fb :2 fd :5 ff :11 100
:24 101 :3 100 :2 fe :6 fd
fa :3 f1 :5 107 :5 109
10b 10c :8 10e :2 10f
110 112 :7 114 115
116 :4 118 10b :6 119
:5 11a 119 :5 11c 11b
:3 119 10a 11f :5 120
:3 11f :2 121 :5 123 :11 124
:24 125 :3 124 :2 122 :6 121
11e :4 109 :4 12b :4 12c
12b :6 12d :5 12e 12d
:5 130 12f :3 12d 12a
133 :5 134 :3 133 :2 135
:5 137 :11 138 :24 139 :3 138
:2 136 :6 135 132 :4 129
:3 109 13e 107 :e 13e
:5 140 142 143 :8 145
:2 146 147 149 :7 14b
14c 14d :4 14f 142
:6 150 :5 151 150 :5 153
152 :3 150 141 156
:5 157 :3 156 :2 158 :5 15a
:11 15b :24 15c :3 15b :2 159
:6 158 155 :4 140 :4 162
:4 163 162 :6 164 :5 165
164 :5 167 166 :3 164
161 16a :5 16b :3 16a
:2 16c :5 16e :11 16f :24 170
:3 16f :2 16d :6 16c 169
:4 160 :3 140 13e :3 107
:3 f1 a3 :3 99 8b
178 83 :4 17c :5 17d
17b 17f :5 180 :3 17f
:2 181 :5 183 :11 184 :24 185
:3 184 :2 182 :6 181 17e
:3 83 :19 18c :6 18e :5 190
:a 191 :c 192 :7 193 :3 192
:3 190 :15 196 :a 197 :3 196
:2 18f :3 18c :7 19c :4 19d
19c :6 19e :5 19f 19e
:5 1a1 1a0 :3 19e 19b
1a4 :5 1a5 :3 1a4 :2 1a6
:5 1a8 :11 1a9 :24 1aa :3 1a9
:2 1a7 :6 1a6 1a3 :3 18c
:6 1af :3 18c :3 83 :9 1b4
:7 1b5 1b6 1b4 :9 1b6
:9 1b7 1b6 :3 1b4 :11 1ba
:30 1bb :3 1ba :a 1bd 62
:3 1c0 :11 1c1 :b 1c2 :17 1c3
:3 1c1 :2 1c5 :3 1c6 :3 1c7
1c8 1c6 1c5 1c6
:3 1c9 :3 1c0 :2 1ca :5 1cc
:11 1cd :b 1ce :18 1cf :3 1cd
:2 1d1 1d2 :3 1d3 1d4
1d2 1d1 1d2 :3 1d5
:2 1cb :6 1ca 1bf :7 1

21d9
4
:3 0 1 :3 0 2
:a 0 92b 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 92b 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 929
0 b :6 0 f
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 929
0 d :6 0 c
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 929
0 e :6 0 c
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 929
0 10 :6 0 13
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 929
0 11 :6 0 25
11e 0 23 4
:3 0 21 3a 3c
:6 0 3f 3d 0
929 0 12 :6 0
29 152 0 27
15 :3 0 41 :7 0
44 42 0 929
0 14 :6 0 15
:3 0 46 :7 0 49
47 0 929 0
16 :6 0 2d 186
0 2b 15 :3 0
4b :7 0 4e 4c
0 929 0 17
:6 0 15 :3 0 50
:7 0 53 51 0
929 0 18 :6 0
31 1ba 0 2f
15 :3 0 55 :7 0
58 56 0 929
0 19 :6 0 15
:3 0 5a :7 0 5d
5b 0 929 0
1a :6 0 35 1ee
0 33 1c :3 0
5f :7 0 62 60
0 929 0 1b
:6 0 1c :3 0 64
:7 0 67 65 0
929 0 1d :6 0
c :2 0 39 1c
:3 0 69 :7 0 6c
6a 0 929 0
1e :6 0 4 :3 0
c :2 0 37 6e
70 :6 0 73 71
0 929 0 1f
:6 0 13 :2 0 3d
4 :3 0 3b 75
77 :6 0 7a 78
0 929 0 20
:6 0 23 :2 0 41
4 :3 0 3f 7c
7e :6 0 81 7f
0 929 0 21
:6 0 23 :2 0 43
6 :3 0 83 :7 0
87 84 85 929
0 22 :6 0 23
:2 0 45 6 :3 0
89 :7 0 8d 8a
8b 929 0 24
:6 0 23 :2 0 47
6 :3 0 8f :7 0
93 90 91 929
0 25 :6 0 23
:2 0 49 6 :3 0
95 :7 0 99 96
97 929 0 26
:6 0 23 :2 0 4b
6 :3 0 9b :7 0
9f 9c 9d 929
0 27 :6 0 23
:2 0 4d 6 :3 0
a1 :7 0 a5 a2
a3 929 0 28
:6 0 51 324 0
4f 6 :3 0 a7
:7 0 ab a8 a9
929 0 29 :6 0
2d :2 0 53 15
:3 0 ad :7 0 b0
ae 0 929 0
2a :6 0 1c :3 0
b2 :7 0 b5 b3
0 929 0 2b
:6 0 23 :2 0 57
4 :3 0 55 b7
b9 :6 0 bc ba
0 929 0 2c
:6 0 23 :2 0 59
6 :3 0 be :7 0
c2 bf c0 929
0 2e :6 0 23
:2 0 5b 6 :3 0
c4 :7 0 c8 c5
c6 929 0 2f
:6 0 23 :2 0 5d
6 :3 0 ca :7 0
ce cb cc 929
0 30 :6 0 23
:2 0 5f 6 :3 0
d0 :7 0 d4 d1
d2 929 0 31
:6 0 63 401 0
61 6 :3 0 d6
:7 0 da d7 d8
929 0 32 :6 0
23 :2 0 65 15
:3 0 dc :7 0 df
dd 0 929 0
33 :6 0 15 :3 0
e1 :7 0 e4 e2
0 929 0 34
:6 0 23 :2 0 67
6 :3 0 e6 :7 0
ea e7 e8 929
0 35 :6 0 23
:2 0 69 6 :3 0
ec :7 0 f0 ed
ee 929 0 36
:6 0 3a :2 0 6b
6 :3 0 f2 :7 0
f6 f3 f4 929
0 37 :6 0 3a
:2 0 6d 39 :3 0
f8 :7 0 fc f9
fa 929 0 38
:6 0 71 4c1 0
6f 39 :3 0 fe
:7 0 102 ff 100
929 0 3b :6 0
23 :2 0 73 1c
:3 0 104 :7 0 107
105 0 929 0
3c :6 0 1c :3 0
109 :7 0 10c 10a
0 929 0 3d
:6 0 23 :2 0 75
6 :3 0 10e :7 0
112 10f 110 929
0 3e :6 0 23
:2 0 77 6 :3 0
114 :7 0 118 115
116 929 0 3f
:6 0 23 :2 0 79
6 :3 0 11a :7 0
11e 11b 11c 929
0 40 :6 0 23
:2 0 7b 6 :3 0
120 :7 0 124 121
122 929 0 41
:6 0 7f 581 0
7d 6 :3 0 126
:7 0 12a 127 128
929 0 42 :9 0
81 44 :3 0 12c
:7 0 12f 12d 0
929 0 43 :6 0
6 :3 0 131 0
2 :5 0 23 :2 0
135 132 133 929
0 45 :6 0 46
:3 0 47 :a 0 2
177 :4 0 137 13a
0 138 :3 0 48
:3 0 49 :3 0 4a
:3 0 4b :3 0 4c
:3 0 4d :3 0 4e
:3 0 4f :3 0 4c
:3 0 50 :3 0 4d
:3 0 51 :3 0 52
:3 0 50 :3 0 53
:3 0 54 :3 0 e
:3 0 55 :3 0 56
:3 0 57 :3 0 56
:3 0 58 :3 0 56
:3 0 59 :3 0 56
:3 0 5a :3 0 56
:3 0 5b :3 0 56
:3 0 5c :3 0 56
:3 0 5d :3 0 56
:3 0 5e :3 0 56
:3 0 5f :3 0 56
:3 0 60 :3 0 56
:3 0 61 :3 0 56
:3 0 62 :3 0 56
:3 0 63 :3 0 56
:3 0 64 :3 0 56
:3 0 65 :3 0 4a
:3 0 4b :3 0 4a
:3 0 4b :3 0 66
:3 0 67 :3 0 4c
:3 0 50 :3 0 4d
:3 0 4e :3 0 4f
:4 0 68 1 :8 0
178 137 13a 179
0 929 83 179
17b 178 17a :6 0
177 :7 0 179 46
:3 0 69 :a 0 3
1b2 :5 0 17d 180
0 17e :3 0 6a
:3 0 6b :3 0 6c
:3 0 6d :3 0 4c
:3 0 50 :3 0 22
:3 0 4c :3 0 67
:3 0 6c :3 0 6d
:3 0 66 :3 0 67
:3 0 6e :3 0 6f
:3 0 50 :3 0 4c
:3 0 50 :3 0 4d
:3 0 4e :3 0 4f
:3 0 4d :3 0 51
:3 0 52 :3 0 70
:3 0 71 :3 0 72
:3 0 73 :3 0 74
:3 0 75 :3 0 76
:3 0 77 :3 0 78
:3 0 79 :3 0 66
:3 0 7a :3 0 48
:3 0 d :3 0 7b
:3 0 1f :3 0 6c
:3 0 6d :3 0 6c
:3 0 6d :3 0 66
:3 0 67 :3 0 4c
:3 0 50 :4 0 7c
1 :8 0 1b3 17d
180 1b4 0 929
85 1b4 1b6 1b3
1b5 :6 0 1b2 :7 0
1b4 1be 1bf 0
87 9 :3 0 a
:2 0 4 1b8 1b9
0 1ba :7 0 1bd
1bb 0 929 0
7d :6 0 7e :3 0
7f :3 0 7e :3 0
80 :3 0 1c1 1c2
0 2 :4 0 89
1c3 1c5 1c0 1c7
1c6 :2 0 81 :3 0
82 :3 0 1c9 1ca
0 83 :4 0 7e
:3 0 84 :3 0 1cd
1ce 0 2 :4 0
8b 1cf 1d1 85
:4 0 86 :2 0 87
:3 0 8d 1d4 1d6
:3 0 88 :4 0 86
:2 0 89 :4 0 90
1d9 1db :3 0 86
:2 0 3 :3 0 93
1dd 1df :3 0 86
:2 0 89 :4 0 96
1e1 1e3 :3 0 86
:2 0 8a :4 0 99
1e5 1e7 :3 0 86
:2 0 4d :3 0 8b
:3 0 5 :3 0 9c
1eb 1ed 8c :4 0
9e 1ea 1f0 a1
1e9 1f2 :3 0 86
:2 0 8a :4 0 a4
1f4 1f6 :3 0 86
:2 0 89 :4 0 a7
1f8 1fa :3 0 86
:2 0 7 :3 0 aa
1fc 1fe :3 0 86
:2 0 89 :4 0 ad
200 202 :3 0 86
:2 0 8d :4 0 b0
204 206 :3 0 b3
1cb 208 :2 0 20a
b8 20b 1c8 20a
0 20c ba 0
889 7e :3 0 7f
:3 0 20d 20e 0
7e :3 0 8e :3 0
210 211 0 13
:2 0 2 :4 0 8f
:2 0 90 :2 0 13
:2 0 bc 216 218
:3 0 bf 212 21a
20f 21c 21b :2 0
81 :3 0 91 :3 0
21e 21f 0 83
:4 0 92 :4 0 86
:2 0 87 :3 0 c3
223 225 :3 0 c6
220 227 :2 0 229
c9 22a 21d 229
0 22b cb 0
889 22 :3 0 5
:3 0 22c 22d 0
889 10 :3 0 7
:3 0 22f 230 0
889 41 :3 0 23
:2 0 232 233 0
889 93 :3 0 54
:3 0 55 :3 0 e
:3 0 28 :3 0 53
:3 0 49 :3 0 3
:4 0 94 1 :8 0
243 9 :3 0 95
:3 0 23e 23f 0
96 :3 0 240 241
0 243 cd 296
97 :3 0 9 :3 0
95 :3 0 245 246
0 96 :3 0 247
248 0 24a d0
24c d2 24b 24a
:2 0 294 98 :3 0
9 :3 0 95 :3 0
24f 250 0 96
:3 0 251 252 0
28c 7e :3 0 7f
:3 0 254 255 0
7e :3 0 8e :3 0
257 258 0 99
:2 0 2 :4 0 9a
:2 0 90 :2 0 13
:2 0 d4 25d 25f
:3 0 d7 259 261
256 263 262 :2 0
81 :3 0 91 :3 0
265 266 0 83
:4 0 9b :4 0 86
:2 0 87 :3 0 db
26a 26c :3 0 86
:2 0 9c :4 0 de
26e 270 :3 0 86
:2 0 9d :4 0 e1
272 274 :3 0 86
:2 0 96 :3 0 e4
276 278 :3 0 86
:2 0 9e :4 0 e7
27a 27c :3 0 86
:2 0 9f :3 0 a0
:3 0 13 :2 0 a1
:2 0 ea 27f 283
ee 27e 285 :3 0
f1 267 287 :2 0
289 f4 28a 264
289 0 28b f6
0 28c f8 28f
:3 0 28f 0 28f
28e 28c 28d :6 0
291 4 :3 0 fb
293 fd 292 291
:2 0 294 ff :2 0
296 0 296 295
243 294 :6 0 889
1 :3 0 9 :3 0
95 :3 0 298 299
0 9 :3 0 a2
:2 0 a3 :3 0 29b
29d 0 104 29c
29f :3 0 2a0 :2 0
28 :3 0 a4 :2 0
107 2a3 2a4 :3 0
2a5 :2 0 2a6 :2 0
2a1 2a8 2a7 :2 0
e :3 0 9f :3 0
e :3 0 86 :2 0
a5 :4 0 109 2ad
2af :3 0 13 :2 0
f :2 0 10c 2ab
2b3 2aa 2b4 0
810 25 :3 0 a6
:2 0 13 :2 0 110
2b7 2b9 :3 0 2b6
2ba 0 810 a7
:3 0 47 :4 0 2bf
:2 0 810 2bd 2c0
:3 0 a8 :3 0 47
:3 0 d :3 0 1f
:3 0 25 :3 0 17
:3 0 18 :4 0 2c9
:2 0 6c2 2c2 2ca
:3 0 112 :3 0 47
:3 0 a9 :3 0 2cb
2cc :3 0 9 :3 0
95 :3 0 2ce 2cf
0 23 :2 0 2d0
2d1 0 2d3 118
2da 9 :3 0 95
:3 0 2d4 2d5 0
aa :2 0 2d6 2d7
0 2d9 11a 2db
2cd 2d3 0 2dc
0 2d9 0 2dc
11c 0 6c2 9
:3 0 95 :3 0 2dd
2de 0 9 :3 0
ab :2 0 a3 :3 0
2e0 2e2 0 121
2e1 2e4 :3 0 2e5
:2 0 ac :8 0 2e9
124 2ea 2e6 2e9
0 2eb 126 0
6c2 4d :3 0 25
:3 0 23 :2 0 128
2ec 2ef a2 :2 0
23 :2 0 12d 2f1
2f3 :3 0 4d :3 0
22 :3 0 23 :2 0
130 2f5 2f8 a2
:2 0 ad :2 0 135
2fa 2fc :3 0 45
:3 0 9 :3 0 95
:3 0 2ff 300 0
2fe 301 0 31d
43 :3 0 ae :3 0
d :3 0 1f :3 0
17 :3 0 18 :3 0
10 :3 0 138 304
30a 303 30b 0
31d 9 :3 0 95
:3 0 30d 30e 0
45 :3 0 30f 310
0 31d 29 :3 0
4d :3 0 29 :3 0
23 :2 0 13e 313
316 90 :2 0 13
:2 0 141 318 31a
:3 0 312 31b 0
31d 144 31e 2fd
31d 0 31f 149
0 320 14b 6bf
17 :4 0 321 322
0 6be 18 :4 0
324 325 0 6be
a7 :3 0 69 :4 0
32a :2 0 6be 328
32b :3 0 a8 :3 0
69 :3 0 20 :3 0
b :3 0 35 :3 0
17 :3 0 18 :3 0
25 :3 0 26 :3 0
30 :3 0 24 :3 0
1e :3 0 42 :3 0
14 :3 0 16 :3 0
3e :3 0 3f :3 0
38 :3 0 3b :3 0
21 :3 0 37 :3 0
11 :3 0 12 :3 0
36 :4 0 345 :2 0
3b7 32d 346 :3 0
14d :3 0 69 :3 0
a9 :3 0 347 348
:3 0 9 :3 0 95
:3 0 34a 34b 0
23 :2 0 34c 34d
0 34f 164 356
9 :3 0 95 :3 0
350 351 0 aa
:2 0 352 353 0
355 166 357 349
34f 0 358 0
355 0 358 168
0 3b7 9 :3 0
95 :3 0 359 35a
0 9 :3 0 ab
:2 0 a3 :3 0 35c
35e 0 16d 35d
360 :3 0 361 :2 0
ac :8 0 365 170
366 362 365 0
367 172 0 3b7
32 :3 0 af :3 0
d :3 0 1f :3 0
20 :3 0 b :3 0
35 :3 0 17 :3 0
18 :3 0 25 :3 0
26 :3 0 30 :3 0
24 :3 0 1e :3 0
42 :3 0 14 :3 0
16 :3 0 3e :3 0
3f :3 0 38 :3 0
3b :3 0 21 :3 0
37 :3 0 11 :3 0
12 :3 0 36 :3 0
22 :3 0 10 :3 0
174 369 384 368
385 0 3b7 4d
:3 0 32 :3 0 23
:2 0 18f 387 38a
a2 :2 0 23 :2 0
194 38c 38e :3 0
29 :3 0 4d :3 0
29 :3 0 23 :2 0
197 391 394 90
:2 0 13 :2 0 19a
396 398 :3 0 390
399 0 39c b0
:3 0 19d 3b5 4d
:3 0 32 :3 0 23
:2 0 19f 39d 3a0
56 :3 0 a2 :2 0
b1 :3 0 3a2 3a4
0 1a4 3a3 3a6
:3 0 41 :3 0 4d
:3 0 41 :3 0 23
:2 0 1a7 3a9 3ac
90 :2 0 13 :2 0
1aa 3ae 3b0 :3 0
3a8 3b1 0 3b3
1ad 3b4 3a7 3b3
0 3b6 38f 39c
0 3b6 1af 0
3b7 1b2 3b9 a8
:4 0 3b7 :4 0 6be
b2 :3 0 69 :4 0
3bd :2 0 3c3 3bb
0 9 :3 0 95
:3 0 3be 3bf 0
96 :3 0 3c0 3c1
0 3c3 1b8 416
97 :3 0 9 :3 0
95 :3 0 3c5 3c6
0 96 :3 0 3c7
3c8 0 3ca 1bb
3cc 1bd 3cb 3ca
:2 0 414 98 :3 0
9 :3 0 95 :3 0
3cf 3d0 0 96
:3 0 3d1 3d2 0
40c 7e :3 0 7f
:3 0 3d4 3d5 0
7e :3 0 8e :3 0
3d7 3d8 0 99
:2 0 2 :4 0 b3
:2 0 90 :2 0 13
:2 0 1bf 3dd 3df
:3 0 1c2 3d9 3e1
3d6 3e3 3e2 :2 0
81 :3 0 91 :3 0
3e5 3e6 0 83
:4 0 b4 :4 0 86
:2 0 87 :3 0 1c6
3ea 3ec :3 0 86
:2 0 9c :4 0 1c9
3ee 3f0 :3 0 86
:2 0 9d :4 0 1cc
3f2 3f4 :3 0 86
:2 0 96 :3 0 1cf
3f6 3f8 :3 0 86
:2 0 9e :4 0 1d2
3fa 3fc :3 0 86
:2 0 9f :3 0 a0
:3 0 13 :2 0 a1
:2 0 1d5 3ff 403
1d9 3fe 405 :3 0
1dc 3e7 407 :2 0
409 1df 40a 3e4
409 0 40b 1e1
0 40c 1e3 40f
:3 0 40f 0 40f
40e 40c 40d :6 0
411 8 :3 0 1e6
413 1e8 412 411
:2 0 414 1ea :2 0
416 0 416 415
3c3 414 :6 0 6be
6 :3 0 4d :3 0
22 :3 0 23 :2 0
1ed 418 41b ab
:2 0 13 :2 0 1f2
41d 41f :3 0 420
:2 0 4d :3 0 29
:3 0 23 :2 0 1f5
422 425 b5 :2 0
23 :2 0 1fa 427
429 :3 0 42a :2 0
421 42c 42b :2 0
19 :4 0 42e 42f
0 6bb 1a :4 0
431 432 0 6bb
b6 :3 0 b7 :3 0
4c :3 0 50 :3 0
2a :3 0 2f :3 0
19 :3 0 1a :3 0
53 :3 0 48 :3 0
d :3 0 49 :3 0
1f :4 0 b8 1
:8 0 447 9 :3 0
95 :3 0 442 443
0 96 :3 0 444
445 0 447 1fd
49a 97 :3 0 9
:3 0 95 :3 0 449
44a 0 96 :3 0
44b 44c 0 44e
200 450 202 44f
44e :2 0 498 98
:3 0 9 :3 0 95
:3 0 453 454 0
96 :3 0 455 456
0 490 7e :3 0
7f :3 0 458 459
0 7e :3 0 8e
:3 0 45b 45c 0
99 :2 0 2 :4 0
b9 :2 0 90 :2 0
13 :2 0 204 461
463 :3 0 207 45d
465 45a 467 466
:2 0 81 :3 0 91
:3 0 469 46a 0
83 :4 0 ba :4 0
86 :2 0 87 :3 0
20b 46e 470 :3 0
86 :2 0 9c :4 0
20e 472 474 :3 0
86 :2 0 9d :4 0
211 476 478 :3 0
86 :2 0 96 :3 0
214 47a 47c :3 0
86 :2 0 9e :4 0
217 47e 480 :3 0
86 :2 0 9f :3 0
a0 :3 0 13 :2 0
a1 :2 0 21a 483
487 21e 482 489
:3 0 221 46b 48b
:2 0 48d 224 48e
468 48d 0 48f
226 0 490 228
493 :3 0 493 0
493 492 490 491
:6 0 495 a :3 0
22b 497 22d 496
495 :2 0 498 22f
:2 0 49a 0 49a
499 447 498 :6 0
6bb 6 :3 0 1a
:3 0 a4 :2 0 232
49d 49e :3 0 49f
:2 0 2a :3 0 a4
:2 0 234 4a2 4a3
:3 0 4a4 :2 0 53
:3 0 b6 :3 0 2f
:3 0 bb :3 0 9f
:3 0 2a :3 0 bb
:3 0 9f :3 0 1a
:3 0 1a :3 0 2f
:3 0 1a :3 0 2a
:3 0 b7 :3 0 2f
:3 0 bb :3 0 9f
:3 0 2a :3 0 bb
:3 0 9f :3 0 1a
:3 0 2f :3 0 2f
:3 0 48 :3 0 d
:3 0 49 :3 0 1f
:4 0 bc 1 :8 0
4d7 a9 :4 0 4c2
:3 0 bd :3 0 a2
:2 0 238 4c5 4c6
:3 0 9 :3 0 95
:3 0 4c8 4c9 0
23 :2 0 4ca 4cb
0 4cd 23b 4d4
9 :3 0 95 :3 0
4ce 4cf 0 aa
:2 0 4d0 4d1 0
4d3 23d 4d5 4c7
4cd 0 4d6 0
4d3 0 4d6 23f
0 4d7 242 52a
97 :3 0 9 :3 0
95 :3 0 4d9 4da
0 96 :3 0 4db
4dc 0 4de 245
4e0 247 4df 4de
:2 0 528 98 :3 0
9 :3 0 95 :3 0
4e3 4e4 0 96
:3 0 4e5 4e6 0
520 7e :3 0 7f
:3 0 4e8 4e9 0
7e :3 0 8e :3 0
4eb 4ec 0 99
:2 0 2 :4 0 be
:2 0 90 :2 0 13
:2 0 249 4f1 4f3
:3 0 24c 4ed 4f5
4ea 4f7 4f6 :2 0
81 :3 0 91 :3 0
4f9 4fa 0 83
:4 0 bf :4 0 86
:2 0 87 :3 0 250
4fe 500 :3 0 86
:2 0 9c :4 0 253
502 504 :3 0 86
:2 0 9d :4 0 256
506 508 :3 0 86
:2 0 96 :3 0 259
50a 50c :3 0 86
:2 0 9e :4 0 25c
50e 510 :3 0 86
:2 0 9f :3 0 a0
:3 0 13 :2 0 a1
:2 0 25f 513 517
263 512 519 :3 0
266 4fb 51b :2 0
51d 269 51e 4f8
51d 0 51f 26b
0 520 26d 523
:3 0 523 0 523
522 520 521 :6 0
525 c :3 0 270
527 272 526 525
:2 0 528 274 :2 0
52a 0 52a 529
4d7 528 :6 0 52c
6 :3 0 277 5a1
53 :3 0 b6 :3 0
1a :3 0 b7 :3 0
48 :3 0 d :3 0
49 :3 0 1f :4 0
c0 1 :8 0 54b
a9 :4 0 536 :3 0
bd :3 0 a2 :2 0
27b 539 53a :3 0
9 :3 0 95 :3 0
53c 53d 0 23
:2 0 53e 53f 0
541 27e 548 9
:3 0 95 :3 0 542
543 0 aa :2 0
544 545 0 547
280 549 53b 541
0 54a 0 547
0 54a 282 0
54b 285 59e 97
:3 0 9 :3 0 95
:3 0 54d 54e 0
96 :3 0 54f 550
0 552 288 554
28a 553 552 :2 0
59c 98 :3 0 9
:3 0 95 :3 0 557
558 0 96 :3 0
559 55a 0 594
7e :3 0 7f :3 0
55c 55d 0 7e
:3 0 8e :3 0 55f
560 0 99 :2 0
2 :4 0 c1 :2 0
90 :2 0 13 :2 0
28c 565 567 :3 0
28f 561 569 55e
56b 56a :2 0 81
:3 0 91 :3 0 56d
56e 0 83 :4 0
c2 :4 0 86 :2 0
87 :3 0 293 572
574 :3 0 86 :2 0
9c :4 0 296 576
578 :3 0 86 :2 0
9d :4 0 299 57a
57c :3 0 86 :2 0
96 :3 0 29c 57e
580 :3 0 86 :2 0
9e :4 0 29f 582
584 :3 0 86 :2 0
9f :3 0 a0 :3 0
13 :2 0 a1 :2 0
2a2 587 58b 2a6
586 58d :3 0 2a9
56f 58f :2 0 591
2ac 592 56c 591
0 593 2ae 0
594 2b0 597 :3 0
597 0 597 596
594 595 :6 0 599
e :3 0 2b3 59b
2b5 59a 599 :2 0
59c 2b7 :2 0 59e
0 59e 59d 54b
59c :6 0 5a0 6
:3 0 2ba 5a2 4a5
52c 0 5a3 0
5a0 0 5a3 2bc
0 5a5 b0 :3 0
2bf 6b9 19 :3 0
a4 :2 0 2c1 5a7
5a8 :3 0 5a9 :2 0
5aa :2 0 1a :3 0
c3 :2 0 2c3 5ad
5ae :3 0 5af :2 0
5b0 :2 0 5ab 5b2
5b1 :2 0 2a :3 0
a4 :2 0 2c5 5b5
5b6 :3 0 5b7 :2 0
53 :3 0 b6 :3 0
2f :3 0 bb :3 0
9f :3 0 2a :3 0
bb :3 0 9f :3 0
19 :3 0 19 :3 0
2f :3 0 19 :3 0
2a :3 0 b7 :3 0
2f :3 0 bb :3 0
9f :3 0 2a :3 0
bb :3 0 9f :3 0
19 :3 0 2f :3 0
2f :3 0 48 :3 0
d :3 0 49 :3 0
1f :4 0 c4 1
:8 0 5ea a9 :4 0
5d5 :3 0 bd :3 0
a2 :2 0 2c9 5d8
5d9 :3 0 9 :3 0
95 :3 0 5db 5dc
0 23 :2 0 5dd
5de 0 5e0 2cc
5e7 9 :3 0 95
:3 0 5e1 5e2 0
aa :2 0 5e3 5e4
0 5e6 2ce 5e8
5da 5e0 0 5e9
0 5e6 0 5e9
2d0 0 5ea 2d3
63d 97 :3 0 9
:3 0 95 :3 0 5ec
5ed 0 96 :3 0
5ee 5ef 0 5f1
2d6 5f3 2d8 5f2
5f1 :2 0 63b 98
:3 0 9 :3 0 95
:3 0 5f6 5f7 0
96 :3 0 5f8 5f9
0 633 7e :3 0
7f :3 0 5fb 5fc
0 7e :3 0 8e
:3 0 5fe 5ff 0
99 :2 0 2 :4 0
c5 :2 0 90 :2 0
13 :2 0 2da 604
606 :3 0 2dd 600
608 5fd 60a 609
:2 0 81 :3 0 91
:3 0 60c 60d 0
83 :4 0 c6 :4 0
86 :2 0 87 :3 0
2e1 611 613 :3 0
86 :2 0 9c :4 0
2e4 615 617 :3 0
86 :2 0 9d :4 0
2e7 619 61b :3 0
86 :2 0 96 :3 0
2ea 61d 61f :3 0
86 :2 0 9e :4 0
2ed 621 623 :3 0
86 :2 0 9f :3 0
a0 :3 0 13 :2 0
a1 :2 0 2f0 626
62a 2f4 625 62c
:3 0 2f7 60e 62e
:2 0 630 2fa 631
60b 630 0 632
2fc 0 633 2fe
636 :3 0 636 0
636 635 633 634
:6 0 638 10 :3 0
301 63a 303 639
638 :2 0 63b 305
:2 0 63d 0 63d
63c 5ea 63b :6 0
63f 6 :3 0 308
6b4 53 :3 0 b6
:3 0 19 :3 0 b7
:3 0 48 :3 0 d
:3 0 49 :3 0 1f
:4 0 c7 1 :8 0
65e a9 :4 0 649
:3 0 bd :3 0 a2
:2 0 30c 64c 64d
:3 0 9 :3 0 95
:3 0 64f 650 0
23 :2 0 651 652
0 654 30f 65b
9 :3 0 95 :3 0
655 656 0 aa
:2 0 657 658 0
65a 311 65c 64e
654 0 65d 0
65a 0 65d 313
0 65e 316 6b1
97 :3 0 9 :3 0
95 :3 0 660 661
0 96 :3 0 662
663 0 665 319
667 31b 666 665
:2 0 6af 98 :3 0
9 :3 0 95 :3 0
66a 66b 0 96
:3 0 66c 66d 0
6a7 7e :3 0 7f
:3 0 66f 670 0
7e :3 0 8e :3 0
672 673 0 99
:2 0 2 :4 0 c8
:2 0 90 :2 0 13
:2 0 31d 678 67a
:3 0 320 674 67c
671 67e 67d :2 0
81 :3 0 91 :3 0
680 681 0 83
:4 0 c9 :4 0 86
:2 0 87 :3 0 324
685 687 :3 0 86
:2 0 9c :4 0 327
689 68b :3 0 86
:2 0 9d :4 0 32a
68d 68f :3 0 86
:2 0 96 :3 0 32d
691 693 :3 0 86
:2 0 9e :4 0 330
695 697 :3 0 86
:2 0 9f :3 0 a0
:3 0 13 :2 0 a1
:2 0 333 69a 69e
337 699 6a0 :3 0
33a 682 6a2 :2 0
6a4 33d 6a5 67f
6a4 0 6a6 33f
0 6a7 341 6aa
:3 0 6aa 0 6aa
6a9 6a7 6a8 :6 0
6ac 12 :3 0 344
6ae 346 6ad 6ac
:2 0 6af 348 :2 0
6b1 0 6b1 6b0
65e 6af :6 0 6b3
6 :3 0 34b 6b5
5b8 63f 0 6b6
0 6b3 0 6b6
34d 0 6b7 350
6b8 5b3 6b7 0
6ba 4a0 5a5 0
6ba 352 0 6bb
355 6bc 42d 6bb
0 6bd 35a 0
6be 35c 6c0 2f4
320 0 6c1 0
6be 0 6c1 363
0 6c2 366 6c4
a8 :4 0 6c2 :4 0
810 b2 :3 0 47
:4 0 6c8 :2 0 6ce
6c6 0 9 :3 0
95 :3 0 6c9 6ca
0 96 :3 0 6cb
6cc 0 6ce 36b
721 97 :3 0 9
:3 0 95 :3 0 6d0
6d1 0 96 :3 0
6d2 6d3 0 6d5
36e 6d7 370 6d6
6d5 :2 0 71f 98
:3 0 9 :3 0 95
:3 0 6da 6db 0
96 :3 0 6dc 6dd
0 717 7e :3 0
7f :3 0 6df 6e0
0 7e :3 0 8e
:3 0 6e2 6e3 0
99 :2 0 2 :4 0
ca :2 0 90 :2 0
13 :2 0 372 6e8
6ea :3 0 375 6e4
6ec 6e1 6ee 6ed
:2 0 81 :3 0 91
:3 0 6f0 6f1 0
83 :4 0 cb :4 0
86 :2 0 87 :3 0
379 6f5 6f7 :3 0
86 :2 0 9c :4 0
37c 6f9 6fb :3 0
86 :2 0 9d :4 0
37f 6fd 6ff :3 0
86 :2 0 96 :3 0
382 701 703 :3 0
86 :2 0 9e :4 0
385 705 707 :3 0
86 :2 0 9f :3 0
a0 :3 0 13 :2 0
a1 :2 0 388 70a
70e 38c 709 710
:3 0 38f 6f2 712
:2 0 714 392 715
6ef 714 0 716
394 0 717 396
71a :3 0 71a 0
71a 719 717 718
:6 0 71c 14 :3 0
399 71e 39b 71d
71c :2 0 71f 39d
:2 0 721 0 721
720 6ce 71f :6 0
810 1 :3 0 4d
:3 0 29 :3 0 23
:2 0 3a0 723 726
b5 :2 0 23 :2 0
3a5 728 72a :3 0
72b :2 0 4d :3 0
25 :3 0 23 :2 0
3a8 72d 730 b5
:2 0 a6 :2 0 13
:2 0 3ab 733 735
:3 0 3af 732 737
:3 0 738 :2 0 72c
73a 739 :2 0 a4
:2 0 3b2 6 :3 0
73d :7 0 23 :2 0
741 73e 73f 78e
0 cc :6 0 e
:3 0 3b4 743 744
:3 0 745 :2 0 cc
:3 0 4d :3 0 cd
:3 0 e :3 0 3b6
749 74b 23 :2 0
3b8 748 74e 747
74f 0 767 13
:2 0 ab :2 0 23
:2 0 3bd 752 754
:3 0 cc :3 0 ab
:2 0 23 :2 0 3c2
757 759 :3 0 755
75b 75a :2 0 cc
:3 0 cc :3 0 a6
:2 0 13 :2 0 3c5
75f 761 :3 0 75d
762 0 764 3c8
765 75c 764 0
766 3ca 0 767
3cc 768 746 767
0 769 3cf 0
78c cc :3 0 ab
:2 0 23 :2 0 3d3
76b 76d :3 0 ce
:2 0 3d6 76f 770
:3 0 cc :3 0 cf
:3 0 cf :2 0 d0
:2 0 3d8 774 776
:3 0 777 :2 0 ab
:2 0 23 :2 0 3dd
779 77b :3 0 771
77d 77c :2 0 d1
:3 0 d2 :3 0 77f
780 0 56 :3 0
d3 :3 0 782 783
0 e :3 0 bd
:3 0 3e0 781 787
:2 0 789 3e4 78a
77e 789 0 78b
3e6 0 78c 3e8
78f :3 0 78f 3eb
78f 78e 78c 78d
:6 0 80d 1 :3 0
53 :3 0 d4 :3 0
d5 :3 0 d6 :3 0
d4 :3 0 56 :3 0
d7 :3 0 48 :3 0
d :3 0 54 :3 0
e :4 0 d8 1
:8 0 7b2 a9 :4 0
79d :3 0 bd :3 0
a2 :2 0 3ef 7a0
7a1 :3 0 9 :3 0
95 :3 0 7a3 7a4
0 23 :2 0 7a5
7a6 0 7a8 3f2
7af 9 :3 0 95
:3 0 7a9 7aa 0
aa :2 0 7ab 7ac
0 7ae 3f4 7b0
7a2 7a8 0 7b1
0 7ae 0 7b1
3f6 0 7b2 3f9
805 97 :3 0 9
:3 0 95 :3 0 7b4
7b5 0 96 :3 0
7b6 7b7 0 7b9
3fc 7bb 3fe 7ba
7b9 :2 0 803 98
:3 0 9 :3 0 95
:3 0 7be 7bf 0
96 :3 0 7c0 7c1
0 7fb 7e :3 0
7f :3 0 7c3 7c4
0 7e :3 0 8e
:3 0 7c6 7c7 0
99 :2 0 2 :4 0
d9 :2 0 90 :2 0
13 :2 0 400 7cc
7ce :3 0 403 7c8
7d0 7c5 7d2 7d1
:2 0 81 :3 0 91
:3 0 7d4 7d5 0
83 :4 0 da :4 0
86 :2 0 87 :3 0
407 7d9 7db :3 0
86 :2 0 9c :4 0
40a 7dd 7df :3 0
86 :2 0 9d :4 0
40d 7e1 7e3 :3 0
86 :2 0 96 :3 0
410 7e5 7e7 :3 0
86 :2 0 9e :4 0
413 7e9 7eb :3 0
86 :2 0 9f :3 0
a0 :3 0 13 :2 0
a1 :2 0 416 7ee
7f2 41a 7ed 7f4
:3 0 41d 7d6 7f6
:2 0 7f8 420 7f9
7d3 7f8 0 7fa
422 0 7fb 424
7fe :3 0 7fe 0
7fe 7fd 7fb 7fc
:6 0 800 17 :3 0
427 802 429 801
800 :2 0 803 42b
:2 0 805 0 805
804 7b2 803 :6 0
80d 1 :3 0 32
:3 0 db :3 0 d
:3 0 42e 808 80a
807 80b 0 80d
430 80e 73b 80d
0 80f 434 0
810 436 811 2a9
810 0 812 43d
0 889 4d :3 0
41 :3 0 23 :2 0
43f 813 816 b5
:2 0 23 :2 0 444
818 81a :3 0 9
:3 0 95 :3 0 81c
81d 0 56 :3 0
b1 :3 0 81f 820
0 81e 821 0
824 b0 :3 0 447
839 4d :3 0 32
:3 0 23 :2 0 449
825 828 b5 :2 0
aa :2 0 44e 82a
82c :3 0 9 :3 0
95 :3 0 82e 82f
0 4d :3 0 32
:3 0 23 :2 0 451
831 834 830 835
0 837 454 838
82d 837 0 83a
81b 824 0 83a
456 0 889 7e
:3 0 7f :3 0 83b
83c 0 7e :3 0
8e :3 0 83e 83f
0 d0 :2 0 2
:4 0 dc :2 0 90
:2 0 13 :2 0 459
844 846 :3 0 45c
840 848 83d 84a
849 :2 0 81 :3 0
91 :3 0 84c 84d
0 83 :4 0 dd
:4 0 86 :2 0 87
:3 0 460 851 853
:3 0 86 :2 0 9c
:4 0 463 855 857
:3 0 86 :2 0 de
:4 0 466 859 85b
:3 0 86 :2 0 4d
:3 0 8b :3 0 9
:3 0 95 :3 0 860
861 0 469 85f
863 8c :4 0 46b
85e 866 46e 85d
868 :3 0 86 :2 0
df :4 0 471 86a
86c :3 0 86 :2 0
89 :4 0 474 86e
870 :3 0 86 :2 0
3 :3 0 477 872
874 :3 0 86 :2 0
89 :4 0 47a 876
878 :3 0 47d 84e
87a :2 0 87c 480
87d 84b 87c 0
87e 482 0 889
d1 :3 0 e0 :3 0
87f 880 0 9
:3 0 95 :3 0 882
883 0 3 :3 0
bd :3 0 484 881
887 :2 0 889 488
92a 9 :3 0 e1
:2 0 4 88a 88b
0 7e :3 0 7f
:3 0 88d 88e 0
7e :3 0 8e :3 0
890 891 0 99
:2 0 2 :4 0 e2
:2 0 90 :2 0 13
:2 0 493 896 898
:3 0 496 892 89a
88f 89c 89b :2 0
81 :3 0 91 :3 0
89e 89f 0 83
:4 0 e3 :4 0 86
:2 0 87 :3 0 49a
8a3 8a5 :3 0 49d
8a0 8a7 :2 0 8c0
81 :3 0 91 :3 0
8a9 8aa 0 83
:4 0 e4 :4 0 86
:2 0 9 :3 0 e5
:3 0 8af 8b0 0
4a0 8ae 8b2 :3 0
86 :2 0 df :4 0
4a3 8b4 8b6 :3 0
86 :2 0 9 :3 0
e6 :3 0 8b9 8ba
0 4a6 8b8 8bc
:3 0 4a9 8ab 8be
:2 0 8c0 4ac 8c1
89d 8c0 0 8c2
4af 0 8d2 a7
:3 0 7d :3 0 9
:3 0 e5 :3 0 e7
:3 0 9 :3 0 e6
:3 0 3 :3 0 e8
:4 0 e9 1 :a 0
8ce :2 0 8d2 8c4
8cc :2 0 8 :3 0
7d :3 0 8d0 :2 0
8d2 4b1 8d4 4b5
8d3 8d2 :2 0 928
98 :3 0 9 :3 0
95 :3 0 8d7 8d8
0 96 :3 0 8d9
8da 0 920 7e
:3 0 7f :3 0 8dc
8dd 0 7e :3 0
8e :3 0 8df 8e0
0 99 :2 0 2
:4 0 ea :2 0 90
:2 0 13 :2 0 4b7
8e5 8e7 :3 0 4ba
8e1 8e9 8de 8eb
8ea :2 0 81 :3 0
91 :3 0 8ed 8ee
0 83 :4 0 eb
:4 0 86 :2 0 87
:3 0 4be 8f2 8f4
:3 0 4c1 8ef 8f6
:2 0 910 81 :3 0
91 :3 0 8f8 8f9
0 83 :4 0 9d
:4 0 86 :2 0 96
:3 0 4c4 8fd 8ff
:3 0 86 :2 0 9e
:4 0 4c7 901 903
:3 0 86 :2 0 9f
:3 0 a0 :3 0 13
:2 0 a1 :2 0 4ca
906 90a 4ce 905
90c :3 0 4d1 8fa
90e :2 0 910 4d4
911 8ec 910 0
912 4d7 0 920
a7 :3 0 7d :3 0
e7 :3 0 9 :3 0
e6 :3 0 3 :3 0
e8 :4 0 ec 1
:a 0 91c :2 0 920
914 91a :2 0 8
:3 0 7d :3 0 91e
:2 0 920 4d9 923
:3 0 923 0 923
922 920 921 :6 0
925 1 :3 0 4de
927 4e0 926 925
:2 0 928 4e2 :2 0
92a 4e5 92a 929
889 928 :6 0 92b
:2 0 2 14 92a
92e :3 0 92d 92b
92f :8 0 
51a
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
40 1 45 1
4a 1 4f 1
54 1 59 1
5e 1 63 1
68 1 6f 1
6d 1 76 1
74 1 7d 1
7b 1 82 1
88 1 8e 1
94 1 9a 1
a0 1 a6 1
ac 1 b1 1
b8 1 b6 1
bd 1 c3 1
c9 1 cf 1
d5 1 db 1
e0 1 e5 1
eb 1 f1 1
f7 1 fd 1
103 1 108 1
10d 1 113 1
119 1 11f 1
125 1 12b 1
130 1 176 1
1b1 1 1b7 1
1c4 1 1d0 2
1d3 1d5 2 1d8
1da 2 1dc 1de
2 1e0 1e2 2
1e4 1e6 1 1ec
2 1ee 1ef 2
1e8 1f1 2 1f3
1f5 2 1f7 1f9
2 1fb 1fd 2
1ff 201 2 203
205 4 1cc 1d2
1d7 207 1 209
1 20b 2 215
217 3 213 214
219 2 222 224
2 221 226 1
228 1 22a 2
23d 242 1 249
1 244 2 25c
25e 3 25a 25b
260 2 269 26b
2 26d 26f 2
271 273 2 275
277 2 279 27b
3 280 281 282
2 27d 284 2
268 286 1 288
1 28a 2 253
28b 1 28f 1
24e 2 24c 293
1 29e 2 29a
29e 1 2a2 2
2ac 2ae 3 2b0
2b1 2b2 1 2b8
5 2c3 2c4 2c5
2c6 2c7 1 2d2
1 2d8 2 2da
2db 1 2e3 2
2df 2e3 1 2e8
1 2ea 2 2ed
2ee 1 2f2 2
2f0 2f2 2 2f6
2f7 1 2fb 2
2f9 2fb 5 305
306 307 308 309
2 314 315 2
317 319 4 302
30c 311 31c 1
31e 1 31f 16
32e 32f 330 331
332 333 334 335
336 337 338 339
33a 33b 33c 33d
33e 33f 340 341
342 343 1 34e
1 354 2 356
357 1 35f 2
35b 35f 1 364
1 366 1a 36a
36b 36c 36d 36e
36f 370 371 372
373 374 375 376
377 378 379 37a
37b 37c 37d 37e
37f 380 381 382
383 2 388 389
1 38d 2 38b
38d 2 392 393
2 395 397 1
39a 2 39e 39f
1 3a5 2 3a1
3a5 2 3aa 3ab
2 3ad 3af 1
3b2 2 3b5 3b4
5 344 358 367
386 3b6 2 3bc
3c2 1 3c9 1
3c4 2 3dc 3de
3 3da 3db 3e0
2 3e9 3eb 2
3ed 3ef 2 3f1
3f3 2 3f5 3f7
2 3f9 3fb 3
400 401 402 2
3fd 404 2 3e8
406 1 408 1
40a 2 3d3 40b
1 40f 1 3ce
2 3cc 413 2
419 41a 1 41e
2 41c 41e 2
423 424 1 428
2 426 428 2
441 446 1 44d
1 448 2 460
462 3 45e 45f
464 2 46d 46f
2 471 473 2
475 477 2 479
47b 2 47d 47f
3 484 485 486
2 481 488 2
46c 48a 1 48c
1 48e 2 457
48f 1 493 1
452 2 450 497
1 49c 1 4a1
1 4c4 2 4c3
4c4 1 4cc 1
4d2 2 4d4 4d5
2 4c1 4d6 1
4dd 1 4d8 2
4f0 4f2 3 4ee
4ef 4f4 2 4fd
4ff 2 501 503
2 505 507 2
509 50b 2 50d
50f 3 514 515
516 2 511 518
2 4fc 51a 1
51c 1 51e 2
4e7 51f 1 523
1 4e2 2 4e0
527 1 52a 1
538 2 537 538
1 540 1 546
2 548 549 2
535 54a 1 551
1 54c 2 564
566 3 562 563
568 2 571 573
2 575 577 2
579 57b 2 57d
57f 2 581 583
3 588 589 58a
2 585 58c 2
570 58e 1 590
1 592 2 55b
593 1 597 1
556 2 554 59b
1 59e 2 5a1
5a2 1 5a3 1
5a6 1 5ac 1
5b4 1 5d7 2
5d6 5d7 1 5df
1 5e5 2 5e7
5e8 2 5d4 5e9
1 5f0 1 5eb
2 603 605 3
601 602 607 2
610 612 2 614
616 2 618 61a
2 61c 61e 2
620 622 3 627
628 629 2 624
62b 2 60f 62d
1 62f 1 631
2 5fa 632 1
636 1 5f5 2
5f3 63a 1 63d
1 64b 2 64a
64b 1 653 1
659 2 65b 65c
2 648 65d 1
664 1 65f 2
677 679 3 675
676 67b 2 684
686 2 688 68a
2 68c 68e 2
690 692 2 694
696 3 69b 69c
69d 2 698 69f
2 683 6a1 1
6a3 1 6a5 2
66e 6a6 1 6aa
1 669 2 667
6ae 1 6b1 2
6b4 6b5 1 6b6
2 6b9 6b8 4
430 433 49a 6ba
1 6bc 6 323
326 329 3b9 416
6bd 2 6bf 6c0
4 2c8 2dc 2eb
6c1 2 6c7 6cd
1 6d4 1 6cf
2 6e7 6e9 3
6e5 6e6 6eb 2
6f4 6f6 2 6f8
6fa 2 6fc 6fe
2 700 702 2
704 706 3 70b
70c 70d 2 708
70f 2 6f3 711
1 713 1 715
2 6de 716 1
71a 1 6d9 2
6d7 71e 2 724
725 1 729 2
727 729 2 72e
72f 1 734 1
736 2 731 736
1 73c 1 742
1 74a 2 74c
74d 1 753 2
751 753 1 758
2 756 758 2
75e 760 1 763
1 765 2 750
766 1 768 1
76c 2 76a 76c
1 76e 2 772
775 1 77a 2
778 77a 3 784
785 786 1 788
1 78a 2 769
78b 1 740 1
79f 2 79e 79f
1 7a7 1 7ad
2 7af 7b0 2
79c 7b1 1 7b8
1 7b3 2 7cb
7cd 3 7c9 7ca
7cf 2 7d8 7da
2 7dc 7de 2
7e0 7e2 2 7e4
7e6 2 7e8 7ea
3 7ef 7f0 7f1
2 7ec 7f3 2
7d7 7f5 1 7f7
1 7f9 2 7c2
7fa 1 7fe 1
7bd 2 7bb 802
1 809 3 78f
805 80c 1 80e
6 2b5 2bb 2be
6c4 721 80f 1
811 2 814 815
1 819 2 817
819 1 822 2
826 827 1 82b
2 829 82b 2
832 833 1 836
2 839 838 2
843 845 3 841
842 847 2 850
852 2 854 856
2 858 85a 1
862 2 864 865
2 85c 867 2
869 86b 2 86d
86f 2 871 873
2 875 877 2
84f 879 1 87b
1 87d 3 884
885 886 a 20c
22b 22e 231 234
296 812 83a 87e
888 2 895 897
3 893 894 899
2 8a2 8a4 2
8a1 8a6 2 8ad
8b1 2 8b3 8b5
2 8b7 8bb 2
8ac 8bd 2 8a8
8bf 1 8c1 3
8c2 8cd 8d1 1
88c 2 8e4 8e6
3 8e2 8e3 8e8
2 8f1 8f3 2
8f0 8f5 2 8fc
8fe 2 900 902
3 907 908 909
2 904 90b 2
8fb 90d 2 8f7
90f 1 911 4
8db 912 91b 91f
1 923 1 8d6
2 8d4 927 34
1b 22 29 30
37 3e 43 48
4d 52 57 5c
61 66 6b 72
79 80 86 8c
92 98 9e a4
aa af b4 bb
c1 c7 cd d3
d9 de e3 e9
ef f5 fb 101
106 10b 111 117
11d 123 129 12e
134 177 1b2 1bc

1
4
0 
92e
0
1
28
19
39
0 1 1 1 4 1 6 6
8 6 a 6 c 6 e 6
10 6 12 1 14 1 1 17
1 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

b 1 0
2 0 1
e0 1 0
94 1 0
cf 1 0
3 1 0
f1 1 0
4f 1 0
74 1 0
119 1 0
16 1 0
c9 1 0
bd 1 0
39 1 0
db 1 0
fd 1 0
12b 1 0
b1 1 0
d5 1 0
73c 16 0
11f 1 0
68 1 0
8e 1 0
54 1 0
40 1 0
4a 1 0
137 1 2
10d 1 0
82 1 0
e5 1 0
b6 1 0
108 1 0
59 1 0
9a 1 0
113 1 0
6d 1 0
24 1 0
45 1 0
130 1 0
eb 1 0
7b 1 0
ac 1 0
63 1 0
a0 1 0
32 1 0
1d 1 0
17d 1 3
7 1 0
103 1 0
f7 1 0
5e 1 0
2b 1 0
88 1 0
125 1 0
c3 1 0
1b7 1 0
a6 1 0
0

/
SHOW ERRORS FUNCTION SP_ACPT_ETC_WBS;
ALTER FUNCTION SP_ACPT_ETC_WBS COMPILE DEBUG;
/****************************************************************************************
Reject ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_RJCT_ETC_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_RJCT_ETC_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
a2
2 :e:
1FUNCTION:
1SP_RJCT_ETC_ASSIGN:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PROJECT_ID:
1H_TASK_ID:
1H_START_DATE:
1TIMESTAMP:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_TEMP_SC_STATE:
1H_STEPS_EXIST:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1I_PERCENT_COMPLETE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_RJCT_ETC_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
130:
1+:
1FPUT:
1               ENTER:: SP_RJCT_ETC_ASSIGN(31) :: cplan.sql(20705) :: :
1PROJECT_ID:
1TASK_ID:
1BIT_FLAG:
1SCHED_WORK:
1PLANNED_WORK:
1WORK_TODATE:
1MILESTONE_PERCENT:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, TASK_ID, BIT_FLAG, SCHED_WORK+PLANNED_WORK, WORK_TODATE, M+
1ILESTONE_PERCENT:n      INTO h_project_id, h_task_id, h_bit_flag, h_sched_wor+
1k, h_work_todate, h_mlst_percent:n      FROM TASK_ASSIGNMENTS WHERE TSK_ASSIG+
1NMENT_ID = h_tsk_assignment_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
149:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(50) :: cplan.sql(20724) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
12:
1ETC:
1UPDATE TASK_ASSIGNMENTS SET ETC = SCHED_WORK - WORK_TODATE--, MILESTONE_PERCE+
1NT = (WORK_TODATE * 10000) / SCHED_WORK:n            WHERE TSK_ASSIGNMENT_ID +
1= h_tsk_assignment_id:
1FOUND:
1TRUE:
1100:
171:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(72) :: cplan.sql(20746) :: :
1ACTIVITIES:
1ETC_MODIFIED:
1ELEMENT_ID:
1TYPE_ID:
1PMO_CNST:
1SC_TIMESHEET_ACTIVITY:
1UPDATE ACTIVITIES:n            SET ETC_MODIFIED = 'N':n            WHERE TSK_+
1ASSIGNMENT_ID = h_tsk_assignment_id:n            AND TSK_ASSIGNMENT_ID <> ELE+
1MENT_ID:n            AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY:
194:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(95) :: cplan.sql(20769) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = PLANNED_WORK, WORK_TODATE = 0, MILESTONE_PE+
1RCENT = 0:n            WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1114:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(115) :: cplan.sql(20789) :: :
1TMT_WBS:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_SCHED_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SCH+
1ED_BIT) WHERE ELEMENT_ID = h_task_id:
1134:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(135) :: cplan.sql(20809) :: :
1FORECAST_START:
1FORECAST_FINISH:
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_i+
1d:
1155:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(156) :: cplan.sql(20830) :: :
1174:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(175) :: cplan.sql(20849) :: :
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0,:n               ETC = SCHED_WORK - WORK_TODATE--, MILEST+
1ONE_PERCENT = (WORK_TODATE * 10000) / SCHED_WORK:n               WHERE TSK_AS+
1SIGNMENT_ID = h_tsk_assignment_id:
1196:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(197) :: cplan.sql(20871) :: :
1UPDATE ACTIVITIES:n               SET ETC_MODIFIED = 'N':n               WHER+
1E TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n               AND TSK_ASSIGNMENT_+
1ID <> ELEMENT_ID:n               AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY:
1219:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(220) :: cplan.sql(20894) :: :
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0,:n               ETC = PLANNED_WORK, WORK_TODATE = 0, MIL+
1ESTONE_PERCENT = 0:n               WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id:
1240:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(241) :: cplan.sql(20915) :: :
1260:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(261) :: cplan.sql(20935) :: :
1BITAND:
1>:
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000.00:
1-:
1<:
1SC_PERCENT_COMPLETE_BIT:
1ACTUAL_FINISH:
1SCHED_FINISH:
1UPDATE TASK_ASSIGNMENTS SET:n            ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP+
1_BITS,pmo_cnst.SC_PERCENT_COMPLETE_BIT),:n            ACTUAL_FINISH = CASE:n +
1           WHEN ACTUAL_FINISH IS NULL AND ETC = 0 THEN SCHED_FINISH:n        +
1    ELSE ACTUAL_FINISH:n            END:n            WHERE TSK_ASSIGNMENT_ID +
1= h_tsk_assignment_id:
1292:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(293) :: cplan.sql(20967) :: :
1UPDATE TASK_ASSIGNMENTS SET:n         ACTUAL_FINISH = CASE:n         WHEN ACT+
1UAL_FINISH IS NULL AND ETC = 0 THEN SCHED_FINISH:n         ELSE ACTUAL_FINISH+
1:n         END:n         WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1317:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(318) :: cplan.sql(20992) :: :
1SC_SQL_SUCCESS:
1!=:
1FC_FIX_SUMMARY_TS:
1FC_ROLLUP:
14:
1332:
1       RETURN_STATUS:: SP_RJCT_ETC_ASSIGN(333) :: cplan.sql(21007) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1339:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(340) :: cplan.sql(21014) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1351:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(352) :: cplan.sql(21026) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
861
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :10 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :2 a0 :2 51
a5 b 7e 6e b4 2e :6 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :7 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 a0 51 a5 b 7e
51 b4 2e :6 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 a0 :2 51 a5 b
7e 6e b4 2e :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :a a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c :3 a0 51
a5 b 51 a5 b 5a 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :5 a0 a5
b 51 a5 b 7e :3 a0 a5 b
51 a5 b b4 2e 5a 7e 51
b4 2e 5a 7e :2 a0 51 a5 b
b4 2e a5 b d a0 7e 51
b4 2e 5a a0 :2 7e 51 b4 2e
b4 2e 52 10 :e a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :4 a0
a5 b d b7 19 3c :3 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
861
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dc cb cf d7 aa
f8 e3 e7 ea eb f3 ca 114
103 107 c7 10f 102 130 11f 123
ff 12b 11e 14c 13b 13f 11b 147
13a 168 157 15b 137 163 156 184
173 177 153 17f 172 1a0 18f 193
16f 19b 18e 1bc 1ab 1af 1b7 18b
1db 1c3 1c7 1cb 1ce 1d6 1aa 1e2
1e6 1a7 1ea 1ee 1f2 1f5 1fa 1fb
1 1fd 202 206 20a 20d 212 216
21a 21d 222 223 225 22a 22d 231
232 237 23c 23f 244 245 24a 24d
251 252 257 25a 25f 260 265 268
26d 26e 273 276 27a 27e 282 283
285 28a 28b 28d 28e 293 296 29b
29c 2a1 2a4 2a9 2aa 2af 2b2 2b6
2b7 2bc 2bf 2c4 2c5 2ca 2cd 2d2
2d3 2d8 2d9 2de 2e0 2e4 2e7 2eb
2ef 2f2 2f6 2fa 2fd 300 305 308
30b 30e 30f 314 315 1 317 31c
320 324 327 32c 331 334 338 339
33e 33f 344 346 34a 34d 351 355
359 35d 361 365 369 36d 371 375
379 37d 381 385 389 38d 391 395
399 39d 3a1 3a5 3b1 3b5 3b9 3bc
3c0 3c4 3c6 3ca 3ce 3d2 3d5 3d9
3dd 3df 3e0 3e5 1 3e9 3ed 3f1
3f4 3f8 3fc 400 404 407 40b 40f
412 415 41a 41d 420 423 424 429
42a 1 42c 431 435 439 43c 441
446 449 44d 44e 453 456 45b 45c
461 464 469 46a 46f 472 476 477
47c 47f 484 485 48a 48d 491 495
498 49b 49c 49e 49f 4a4 4a5 4aa
4ac 4b0 4b3 4b5 4b9 4bb 4c7 4c9
4cb 4cc 4d1 4d5 4d7 4e3 4e5 4e9
4ed 4f0 4f1 4f3 4f6 4f9 4fa 4ff
503 507 50a 50d 50e 510 513 518
519 51e 522 526 52a 52e 532 536
542 546 54b 54f 552 553 558 55c
560 563 566 56a 56c 570 574 577
57a 57e 580 584 588 58b 58d 591
595 599 59c 5a0 5a4 5a6 5a7 5ac
1 5b0 5b4 5b8 5bb 5bf 5c3 5c7
5cb 5ce 5d2 5d6 5d9 5dc 5e1 5e4
5e7 5ea 5eb 5f0 5f1 1 5f3 5f8
5fc 600 603 608 60d 610 614 615
61a 61d 622 623 628 62b 630 631
636 639 63d 63e 643 646 64b 64c
651 654 658 65c 65f 662 663 665
666 66b 66c 671 673 677 67a 67c
680 682 68e 690 692 693 698 69c
69e 6aa 6ac 6b0 6b4 6b8 6bc 6c0
6c4 6c8 6cc 6d0 6dc 6e0 6e5 6e9
6ec 6ed 6f2 6f6 6fa 6fd 700 704
706 70a 70e 711 714 718 71a 71e
722 725 727 72b 72f 733 736 73a
73e 740 741 746 1 74a 74e 752
755 759 75d 761 765 768 76c 770
773 776 77b 77e 781 784 785 78a
78b 1 78d 792 796 79a 79d 7a2
7a7 7aa 7ae 7af 7b4 7b7 7bc 7bd
7c2 7c5 7ca 7cb 7d0 7d3 7d7 7d8
7dd 7e0 7e5 7e6 7eb 7ee 7f2 7f6
7f9 7fc 7fd 7ff 800 805 806 80b
80d 811 814 816 81a 81c 828 82a
82c 82d 832 836 838 844 846 848
84c 850 854 858 85c 860 864 870
874 879 87d 880 881 886 88a 88e
891 894 898 89a 89e 8a2 8a5 8a8
8ac 8ae 8b2 8b6 8b9 8bb 8bf 8c3
8c7 8ca 8ce 8d2 8d4 8d5 8da 1
8de 8e2 8e6 8e9 8ed 8f1 8f5 8f9
8fc 900 904 907 90a 90f 912 915
918 919 91e 91f 1 921 926 92a
92e 931 936 93b 93e 942 943 948
94b 950 951 956 959 95e 95f 964
967 96b 96c 971 974 979 97a 97f
982 986 98a 98d 990 991 993 994
999 99a 99f 9a1 9a5 9a8 9aa 9ae
9b0 9bc 9be 9c0 9c1 9c6 9ca 9cc
9d8 9da 9dc 9e0 9e4 9e7 9eb 9ef
9f3 9f7 9fb 9ff a03 a07 a0b a17
a1b a20 a24 a27 a28 a2d a31 a35
a38 a3b a3f a41 a45 a49 a4c a4f
a53 a55 a59 a5d a60 a62 a66 a6a
a6e a71 a75 a79 a7b a7c a81 1
a85 a89 a8d a90 a94 a98 a9c aa0
aa3 aa7 aab aae ab1 ab6 ab9 abc
abf ac0 ac5 ac6 1 ac8 acd ad1
ad5 ad8 add ae2 ae5 ae9 aea aef
af2 af7 af8 afd b00 b05 b06 b0b
b0e b12 b13 b18 b1b b20 b21 b26
b29 b2d b31 b34 b37 b38 b3a b3b
b40 b41 b46 b48 b4c b4f b51 b55
b57 b63 b65 b67 b68 b6d b71 b73
b7f b81 b83 b87 b8b b8e b8f b91
b94 b97 b98 b9d ba1 ba5 ba9 bad
bb1 bb5 bc1 bc5 bca bce bd1 bd2
bd7 bdb bdf be2 be5 be9 beb bef
bf3 bf6 bf9 bfd bff c03 c07 c0a
c0c c10 c14 c18 c1b c1f c23 c25
c26 c2b 1 c2f c33 c37 c3a c3e
c42 c46 c4a c4d c51 c55 c58 c5b
c60 c63 c66 c69 c6a c6f c70 1
c72 c77 c7b c7f c82 c87 c8c c8f
c93 c94 c99 c9c ca1 ca2 ca7 caa
caf cb0 cb5 cb8 cbc cbd cc2 cc5
cca ccb cd0 cd3 cd7 cdb cde ce1
ce2 ce4 ce5 cea ceb cf0 cf2 cf6
cf9 cfb cff d01 d0d d0f d11 d12
d17 d1b d1d d29 d2b d2f d33 d37
d3b d3f d43 d47 d4b d4f d5b d5f
d64 d68 d6b d6c d71 d75 d79 d7c
d7f d83 d85 d89 d8d d90 d93 d97
d99 d9d da1 da4 da6 daa dae db2
db5 db9 dbd dbf dc0 dc5 1 dc9
dcd dd1 dd4 dd8 ddc de0 de4 de7
deb def df2 df5 dfa dfd e00 e03
e04 e09 e0a 1 e0c e11 e15 e19
e1c e21 e26 e29 e2d e2e e33 e36
e3b e3c e41 e44 e49 e4a e4f e52
e56 e57 e5c e5f e64 e65 e6a e6d
e71 e75 e78 e7b e7c e7e e7f e84
e85 e8a e8c e90 e93 e95 e99 e9b
ea7 ea9 eab eac eb1 eb5 eb7 ec3
ec5 ec7 ecb ecf ed2 ed5 ed6 ed8
edb ee0 ee1 ee6 eea eee ef2 ef6
efa efe f02 f06 f0a f16 f1a f1f
f23 f26 f27 f2c f30 f34 f37 f3a
f3e f40 f44 f48 f4b f4e f52 f54
f58 f5c f5f f61 f65 f69 f6d f70
f74 f78 f7a f7b f80 1 f84 f88
f8c f8f f93 f97 f9b f9f fa2 fa6
faa fad fb0 fb5 fb8 fbb fbe fbf
fc4 fc5 1 fc7 fcc fd0 fd4 fd7
fdc fe1 fe4 fe8 fe9 fee ff1 ff6
ff7 ffc fff 1004 1005 100a 100d 1011
1012 1017 101a 101f 1020 1025 1028 102c
1030 1033 1036 1037 1039 103a 103f 1040
1045 1047 104b 104e 1050 1054 1056 1062
1064 1066 1067 106c 1070 1072 107e 1080
1084 1088 108c 1090 1094 1098 109c 10a0
10a4 10b0 10b4 10b9 10bd 10c0 10c1 10c6
10ca 10ce 10d1 10d4 10d8 10da 10de 10e2
10e5 10e8 10ec 10ee 10f2 10f6 10f9 10fb
10ff 1103 1107 110a 110e 1112 1114 1115
111a 1 111e 1122 1126 1129 112d 1131
1135 1139 113c 1140 1144 1147 114a 114f
1152 1155 1158 1159 115e 115f 1 1161
1166 116a 116e 1171 1176 117b 117e 1182
1183 1188 118b 1190 1191 1196 1199 119e
119f 11a4 11a7 11ab 11ac 11b1 11b4 11b9
11ba 11bf 11c2 11c6 11ca 11cd 11d0 11d1
11d3 11d4 11d9 11da 11df 11e1 11e5 11e8
11ea 11ee 11f0 11fc 11fe 1200 1201 1206
120a 120c 1218 121a 121c 1220 1224 1228
122c 1230 1234 1238 123c 1240 1244 1250
1254 1259 125d 1260 1261 1266 126a 126e
1271 1274 1278 127a 127e 1282 1285 1288
128c 128e 1292 1296 1299 129b 129f 12a3
12a7 12aa 12ae 12b2 12b4 12b5 12ba 1
12be 12c2 12c6 12c9 12cd 12d1 12d5 12d9
12dc 12e0 12e4 12e7 12ea 12ef 12f2 12f5
12f8 12f9 12fe 12ff 1 1301 1306 130a
130e 1311 1316 131b 131e 1322 1323 1328
132b 1330 1331 1336 1339 133e 133f 1344
1347 134b 134c 1351 1354 1359 135a 135f
1362 1366 136a 136d 1370 1371 1373 1374
1379 137a 137f 1381 1385 1388 138a 138e
1390 139c 139e 13a0 13a1 13a6 13aa 13ac
13b8 13ba 13bc 13c0 13c4 13c7 13cb 13cf
13d3 13d7 13db 13df 13e3 13e7 13eb 13f7
13fb 1400 1404 1407 1408 140d 1411 1415
1418 141b 141f 1421 1425 1429 142c 142f
1433 1435 1439 143d 1440 1442 1446 144a
144e 1451 1455 1459 145b 145c 1461 1
1465 1469 146d 1470 1474 1478 147c 1480
1483 1487 148b 148e 1491 1496 1499 149c
149f 14a0 14a5 14a6 1 14a8 14ad 14b1
14b5 14b8 14bd 14c2 14c5 14c9 14ca 14cf
14d2 14d7 14d8 14dd 14e0 14e5 14e6 14eb
14ee 14f2 14f3 14f8 14fb 1500 1501 1506
1509 150d 1511 1514 1517 1518 151a 151b
1520 1521 1526 1528 152c 152f 1531 1535
1537 1543 1545 1547 1548 154d 1551 1553
155f 1561 1563 1567 156b 156e 1570 1574
1578 157b 157f 1583 1587 158a 158b 158d
1590 1591 1593 1596 1599 159c 159d 15a2
15a5 15a9 15ad 15b0 15b1 15b3 15b6 15b9
15ba 15bf 1 15c2 15c7 15cb 15cf 15d3
15d7 15db 15dc 15de 15e1 15e2 15e4 15e7
15eb 15ef 15f3 15f4 15f6 15f9 15fa 15fc
15fd 1602 1605 1608 160b 160c 1611 1614
1617 161b 161f 1622 1623 1625 1626 162b
162c 162e 1632 1636 1639 163c 163d 1642
1645 1649 164c 164f 1652 1653 1658 1659
1 165e 1663 1667 166b 166f 1673 1677
167b 167f 1683 1687 168b 168f 1693 1697
169b 16a7 16ab 16b0 16b4 16b7 16b8 16bd
16c1 16c5 16c8 16cb 16cf 16d1 16d5 16d9
16dc 16df 16e3 16e5 16e9 16ed 16f0 16f2
16f6 16fa 16fe 1701 1705 1709 170b 170c
1711 1 1715 1719 171d 1720 1724 1728
172c 1730 1733 1737 173b 173e 1741 1746
1749 174c 174f 1750 1755 1756 1 1758
175d 1761 1765 1768 176d 1772 1775 1779
177a 177f 1782 1787 1788 178d 1790 1795
1796 179b 179e 17a2 17a3 17a8 17ab 17b0
17b1 17b6 17b9 17bd 17c1 17c4 17c7 17c8
17ca 17cb 17d0 17d1 17d6 17d8 17dc 17df
17e1 17e5 17e7 17f3 17f5 17f7 17f8 17fd
1801 1803 180f 1811 1813 1817 181a 181c
1820 1824 1828 182c 1830 1834 1838 183c
1848 184c 1851 1855 1858 1859 185e 1862
1866 1869 186c 1870 1872 1876 187a 187d
1880 1884 1886 188a 188e 1891 1893 1897
189b 189f 18a2 18a6 18aa 18ac 18ad 18b2
1 18b6 18ba 18be 18c1 18c5 18c9 18cd
18d1 18d4 18d8 18dc 18df 18e2 18e7 18ea
18ed 18f0 18f1 18f6 18f7 1 18f9 18fe
1902 1906 1909 190e 1913 1916 191a 191b
1920 1923 1928 1929 192e 1931 1936 1937
193c 193f 1943 1944 1949 194c 1951 1952
1957 195a 195e 1962 1965 1968 1969 196b
196c 1971 1972 1977 1979 197d 1980 1982
1986 1988 1994 1996 1998 1999 199e 19a2
19a4 19b0 19b2 19b4 19b8 19bc 19bf 19c3
19c7 19ca 19ce 19d1 19d5 19d8 19d9 19de
19e1 19e5 19e9 19ec 19ed 19ef 19f2 19f5
19f6 19fb 1 19fe 1a03 1a07 1a0b 1a0f
1a13 1a14 1a16 1a1a 1a1c 1a20 1a23 1a27
1a2b 1a2f 1a30 1a32 1a36 1a3a 1a3e 1a41
1a45 1a49 1a4c 1a4f 1a54 1a57 1a5a 1a5d
1a5e 1a63 1a64 1 1a66 1a6b 1a6f 1a73
1a76 1a7b 1a80 1a83 1a87 1a88 1a8d 1a90
1a95 1a96 1a9b 1a9e 1aa3 1aa4 1aa9 1aac
1ab0 1ab4 1ab8 1abc 1abf 1ac0 1ac2 1ac7
1ac8 1aca 1acb 1ad0 1ad3 1ad8 1ad9 1ade
1ae1 1ae6 1ae7 1aec 1aef 1af3 1af4 1af9
1afc 1b01 1b02 1b07 1b08 1b0d 1b0f 1b13
1b16 1b1a 1b1e 1b21 1b25 1b29 1b2c 1b30
1b34 1b35 1b3a 1b3c 1b40 1b44 1b47 1b4b
1b4f 1b52 1b56 1b5a 1b5d 1b60 1b65 1b68
1b6b 1b6e 1b6f 1b74 1b75 1 1b77 1b7c
1b80 1b84 1b87 1b8c 1b91 1b94 1b98 1b99
1b9e 1b9f 1ba4 1ba8 1bac 1baf 1bb4 1bb9
1bbc 1bc0 1bc4 1bc7 1bc8 1bcd 1bd0 1bd5
1bd6 1bdb 1bde 1be2 1be6 1be9 1bea 1bef
1bf0 1bf5 1bf7 1bfb 1bfe 1c02 1c06 1c0a
1c0e 1c12 1c16 1c1a 1c1e 1c22 1c2e 1c33
1c37 1c3b 1c3f 1c43 1c45 1c46 1c4b 1
1c4f 1c53 1c57 1c5a 1c5e 1c62 1c66 1c6a
1c6d 1c71 1c75 1c78 1c7b 1c80 1c83 1c86
1c89 1c8a 1c8f 1c90 1 1c92 1c97 1c9b
1c9f 1ca2 1ca7 1cac 1caf 1cb3 1cb4 1cb9
1cba 1cbf 1cc3 1cc7 1cca 1ccf 1cd4 1cd7
1cdb 1cdc 1ce1 1ce4 1ce9 1cea 1cef 1cf2
1cf6 1cfa 1cfd 1d00 1d01 1d03 1d04 1d09
1d0a 1d0f 1d11 1d15 1d18 1d1c 1d20 1d24
1d28 1d2c 1d30 1d34 1d40 1d45 1d49 1d4d
1d51 1d55 1d57 1d5b 1d5d 1d69 1d6b 1d6d
1d6e 1d73 1d77 1d79 1d85 1d89 1d8b 1d8c
1d95 
861
2
0 1 a 6 9 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 e 17 16 :2 e :2 4
:3 11 :2 4 f 18 17 :2 f :2 4 :2 e
1d e :2 4 :2 14 23 14 :2 4 :2 12
21 12 :2 4 :2 11 20 11 :2 4 :2 12
21 12 :2 4 :2 13 22 13 :2 4 :3 17
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 5a 60 63 :2 5a 71 8d
8 :2 71 d 10 :2 71 13 16 :2 71
b e :2 71 13 16 1f 27 :2 1f
34 :2 16 :2 71 b e :2 71 13 16
:2 71 1b 1e :2 71 2a 2d :2 71 32
35 :2 71 :2 7 50 :2 4 7 :2 11 23
:2 2d 39 3c 52 54 55 :2 52 :2 23
:3 7 :2 d 12 1e 63 66 :2 1e :2 7
58 :3 4 11 :2 4 1b 4 e 1a
23 2d 38 46 53 c 1a 25
31 3f 4e c 23 37 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 59 5b 5c
:2 59 :2 29 :3 d :2 13 18 24 69 6c
:2 24 79 7c :2 24 80 83 :2 24 8f
92 :2 24 9a 9d :2 24 a9 ac b3
bc bf :2 ac :2 24 :2 d 5f :2 a :2 7
:4 13 :2 7 4 :3 1 7 10 1b :2 7
1e 20 :2 1e a 11 1d 20 :2 a
23 25 :2 23 14 29 2f 3c 13
27 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5f 61 62 :2 5f :2 2f
:3 13 :2 19 1e 2a 6f 72 :2 2a 7f
82 :2 2a 86 89 :2 2a 95 98 :2 2a
a0 a3 :2 2a af b2 b9 c2 c5
:2 b2 :2 2a :2 13 65 :2 10 :2 d :4 19 :2 d
a :3 29 14 11 13 27 11 26
11 1b 24 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 61 62
:2 5f :2 2f :3 13 :2 19 1e 2a 6f 72
:2 2a 7f 82 :2 2a 86 89 :2 2a 95
98 :2 2a a0 a3 :2 2a af b2 b9
c2 c5 :2 b2 :2 2a :2 13 65 :2 10 :2 d
:4 19 :2 d a :4 29 14 29 2f 3d
4e 13 27 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 62 63
:2 5f :2 2f :3 13 :2 19 1e 2a 70 73
:2 2a 80 83 :2 2a 87 8a :2 2a 96
99 :2 2a a1 a4 :2 2a b0 b3 ba
c3 c6 :2 b3 :2 2a :2 13 66 :2 10 :2 d
:4 19 :2 d a :7 7 11 1d 2b 34
3b 48 51 65 72 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 5c
5f 60 :2 5c :2 2c :3 10 :2 16 1b 27
6d 70 :2 27 7d 80 :2 27 84 87
:2 27 93 96 :2 27 9e a1 :2 27 ad
b0 b7 c0 c3 :2 b0 :2 27 :2 10 63
:2 d :2 a :4 16 :2 a 7 :4 22 a 13
1e :2 a 21 23 :2 21 14 29 40
58 13 27 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 62 63
:2 5f :2 2f :3 13 :2 19 1e 2a 70 73
:2 2a 80 83 :2 2a 87 8a :2 2a 96
99 :2 2a a1 a4 :2 2a b0 b3 ba
c3 c6 :2 b3 :2 2a :2 13 66 :2 10 :2 d
:4 19 :2 d a :3 25 14 20 2e 37
3e 4b 54 68 75 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5f
62 63 :2 5f :2 2f :3 13 :2 19 1e 2a
70 73 :2 2a 80 83 :2 2a 87 8a
:2 2a 96 99 :2 2a a1 a4 :2 2a b0
b3 ba c3 c6 :2 b3 :2 2a :2 13 66
:2 10 :2 d :4 19 :2 d a :4 25 d 14
20 23 :2 d 26 28 :2 26 17 2c
43 5b 10 16 23 16 2a 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 62 65 66 :2 62 :2 32 :3 16 :2 1c
21 2d 73 76 :2 2d 83 86 :2 2d
8a 8d :2 2d 99 9c :2 2d a4 a7
:2 2d b3 b6 bd c6 c9 :2 b6 :2 2d
:2 16 69 :2 13 :2 10 :4 1c :2 10 d :3 2c
17 14 16 2a 14 29 14 1e
27 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 62 65 66 :2 62 :2 32
:3 16 :2 1c 21 2d 73 76 :2 2d 83
86 :2 2d 8a 8d :2 2d 99 9c :2 2d
a4 a7 :2 2d b3 b6 bd c6 c9
:2 b6 :2 2d :2 16 69 :2 13 :2 10 :4 1c :2 10
d :4 2c 17 2c 43 5b 10 16
24 35 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 62 65
66 :2 62 :2 32 :3 16 :2 1c 21 2d 73
76 :2 2d 83 86 :2 2d 8a 8d :2 2d
99 9c :2 2d a4 a7 :2 2d b3 b6
bd c6 c9 :2 b6 :2 2d :2 16 69 :2 13
:2 10 :4 1c :2 10 d :7 a 14 20 2e
37 3e 4b 54 68 75 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5f 62 63 :2 5f :2 2f :3 13 :2 19 1e
2a 70 73 :2 2a 80 83 :2 2a 87
8a :2 2a 96 99 :2 2a a1 a4 :2 2a
b0 b3 ba c3 c6 :2 b3 :2 2a :2 13
66 :2 10 :2 d :4 19 :2 d a :7 7 :4 4
9 10 19 24 :2 10 28 :2 9 8
2c 2e :2 2c 7 36 3f 4f :2 36
52 54 :2 52 35 :3 7 1d 25 2e
38 :2 2e 48 :2 25 4b 4d 28 32
:2 28 41 :2 4d :2 25 24 45 47 :2 24
23 51 53 28 38 :2 53 :2 23 :2 1d
7 b 1e 20 :2 1e a 26 39
3b 3c :2 3b :2 39 :2 a 14 d 1b
24 2b 37 40 d 12 2c 39
12 13 27 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 62 63
:2 5f :2 2f :3 13 :2 19 1e 2a 70 73
:2 2a 80 83 :2 2a 87 8a :2 2a 96
99 :2 2a a1 a4 :2 2a b0 b3 ba
c3 c6 :2 b3 :2 2a :2 13 66 :2 10 :2 d
:4 19 :2 d a :4 3e :2 7 57 11 a
f 29 36 f 10 24 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
5c 5f 60 :2 5c :2 2c :3 10 :2 16 1b
27 6d 70 :2 27 7d 80 :2 27 84
87 :2 27 93 96 :2 27 9e a1 :2 27
ad b0 b7 c0 c3 :2 b0 :2 27 :2 10
63 :2 d :2 a :4 16 :2 a 7 :7 4 8
:2 11 1c 1a :2 25 :2 1a 7 3a 43
4e :2 3a 51 54 :2 51 39 :3 7 1a
2c 3a :2 1a 7 57 :3 4 17 21
:2 17 4 7 :2 11 23 :2 2d 39 3c
52 55 56 :2 52 :2 23 :3 7 :2 d 12
1e 64 67 :2 1e 74 77 :2 1e 7b
7e :2 1e 88 8b 94 9c :2 a5 :2 94
b0 :2 8b :2 1e b8 bb :2 1e c3 c6
:2 1e cb ce :2 1e d1 d4 :2 1e :2 7
59 :3 4 :2 f 21 :2 2a 34 38 :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 56 59 5a :2 56 :2 26 :3 a
:2 10 15 21 67 6a :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 5d :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 53 56 57 :2 53 :2 23 :3 7
:2 d 12 1e 64 67 :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
5a :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
861
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :5 b
:7 c :6 d :6 e :6 f
:6 10 :6 11 :6 12 :5 13
:7 15 :b 17 :11 18 19
:2 18 :2 19 :2 18 :2 19
:2 18 :2 1a :2 18 :9 1a
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1b :4 18 :3 17
:11 1e :b 1f :3 1e :3 23
:3 24 :7 27 :6 28 :3 29
27 :5 2a 26 2c
:5 2d :3 2c :2 2e :5 30
:11 31 :24 32 :3 31 :2 2f
:6 2e 2b :3 16 :9 37
:a 38 :4 3a :2 3b 3a
:6 3c :5 3d 3c :5 3f
3e :3 3c 39 42
:5 43 :3 42 :2 44 :5 46
:11 47 :24 48 :3 47 :2 45
:6 44 41 :3 38 4e
4f :2 50 :2 51 :3 52
4e :6 53 :5 54 53
:5 56 55 :3 53 4d
59 :5 5a :3 59 :2 5b
:5 5d :11 5e :24 5f :3 5e
:2 5c :6 5b 58 :4 38
:5 65 :2 66 65 :6 67
:5 68 67 :5 6a 69
:3 67 64 6d :5 6e
:3 6d :2 6f :5 71 :11 72
:24 73 :3 72 :2 70 :6 6f
6c :4 63 :3 38 :a 7a
:6 7b :5 7c 7b :5 7e
7d :3 7b 79 81
:5 82 :3 81 :2 83 :5 85
:11 86 :24 87 :3 86 :2 84
:6 83 80 :4 37 :9 8c
:4 8e :2 8f 8e :6 90
:5 91 90 :5 93 92
:3 90 8d 96 :5 97
:3 96 :2 98 :5 9a :11 9b
:24 9c :3 9b :2 99 :6 98
95 :3 8c :a a2 :6 a3
:5 a4 a3 :5 a6 a5
:3 a3 a1 a9 :5 aa
:3 a9 :2 ab :5 ad :11 ae
:24 af :3 ae :2 ac :6 ab
a8 :4 8c :a b4 :4 b6
:3 b7 :2 b8 b6 :6 b9
:5 ba b9 :5 bc bb
:3 b9 b5 bf :5 c0
:3 bf :2 c1 :5 c3 :11 c4
:24 c5 :3 c4 :2 c2 :6 c1
be :3 b4 cb cc
:2 cd :2 ce :3 cf cb
:6 d0 :5 d1 d0 :5 d3
d2 :3 d0 ca d6
:5 d7 :3 d6 :2 d8 :5 da
:11 db :24 dc :3 db :2 d9
:6 d8 d5 :4 b4 :4 e2
:4 e3 :2 e4 e2 :6 e5
:5 e6 e5 :5 e8 e7
:3 e5 e1 eb :5 ec
:3 eb :2 ed :5 ef :11 f0
:24 f1 :3 f0 :2 ee :6 ed
ea :4 e0 :3 b4 :a f8
:6 f9 :5 fa f9 :5 fc
fb :3 f9 f7 ff
:5 100 :3 ff :2 101 :5 103
:11 104 :24 105 :3 104 :2 102
:6 101 fe :4 b3 :3 8c
8b :3 37 :1b 10c :c 10d
:5 10e :5 10d :2 10e :3 10d
:2 10e :2 10f :2 10e :5 10d
:10 110 112 :6 113 114
:3 115 116 :2 118 112
:6 119 :5 11a 119 :5 11c
11b :3 119 111 11f
:5 120 :3 11f :2 121 :5 123
:11 124 :24 125 :3 124 :2 122
:6 121 11e :6 110 10c
12c 12d :3 12e 12f
:2 131 12c :6 132 :5 133
132 :5 135 134 :3 132
12b 138 :5 139 :3 138
:2 13a :5 13c :11 13d :24 13e
:3 13d :2 13b :6 13a 137
:4 12a :3 10c :16 144 :7 146
:3 144 :6 149 :11 14c :30 14d
:3 14c :a 14f 16 :3 152
:11 153 :b 154 :17 155 :3 153
:2 157 :3 158 :3 159 15a
158 157 158 :3 15b
:3 152 :2 15c :5 15e :11 15f
:b 160 :18 161 :3 15f :2 163
164 :3 165 166 164
163 164 :3 167 :2 15d
:6 15c 151 :7 1 
1d97
4
:3 0 1 :3 0 2
:a 0 85c 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 85c 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 85a
0 b :6 0 c
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 85a
0 d :6 0 19
c7 0 17 4
:3 0 15 25 27
:6 0 2a 28 0
85a 0 e :6 0
14 :2 0 1d 10
:3 0 2c :7 0 2f
2d 0 85a 0
f :6 0 4 :3 0
12 :2 0 1b 31
33 :6 0 36 34
0 85a 0 11
:6 0 14 :2 0 1f
6 :3 0 38 :7 0
3c 39 3a 85a
0 13 :6 0 14
:2 0 21 6 :3 0
3e :7 0 42 3f
40 85a 0 15
:6 0 14 :2 0 23
6 :3 0 44 :7 0
48 45 46 85a
0 16 :6 0 14
:2 0 25 6 :3 0
4a :7 0 4e 4b
4c 85a 0 17
:6 0 14 :2 0 27
6 :3 0 50 :7 0
54 51 52 85a
0 18 :6 0 2b
1a7 0 29 6
:3 0 56 :7 0 5a
57 58 85a 0
19 :6 0 67 68
0 2d 6 :3 0
5c :7 0 5f 5d
0 85a 0 1a
:6 0 9 :3 0 a
:2 0 4 61 62
0 63 :7 0 66
64 0 85a 0
1b :6 0 1c :3 0
1d :3 0 1c :3 0
1e :3 0 6a 6b
0 2 :4 0 2f
6c 6e 69 70
6f :2 0 1f :3 0
20 :3 0 72 73
0 21 :4 0 1c
:3 0 22 :3 0 76
77 0 2 :4 0
31 78 7a 23
:4 0 24 :2 0 25
:3 0 33 7d 7f
:3 0 26 :4 0 24
:2 0 27 :4 0 36
82 84 :3 0 24
:2 0 3 :3 0 39
86 88 :3 0 24
:2 0 27 :4 0 3c
8a 8c :3 0 24
:2 0 28 :4 0 3f
8e 90 :3 0 24
:2 0 29 :3 0 2a
:3 0 5 :3 0 42
94 96 2b :4 0
44 93 99 47
92 9b :3 0 24
:2 0 28 :4 0 4a
9d 9f :3 0 24
:2 0 27 :4 0 4d
a1 a3 :3 0 24
:2 0 7 :3 0 50
a5 a7 :3 0 24
:2 0 27 :4 0 53
a9 ab :3 0 24
:2 0 2c :4 0 56
ad af :3 0 59
74 b1 :2 0 b3
5e b4 71 b3
0 b5 60 0
7ba 1c :3 0 1d
:3 0 b6 b7 0
1c :3 0 2d :3 0
b9 ba 0 12
:2 0 2 :4 0 2e
:2 0 2f :2 0 12
:2 0 62 bf c1
:3 0 65 bb c3
b8 c5 c4 :2 0
1f :3 0 30 :3 0
c7 c8 0 21
:4 0 31 :4 0 24
:2 0 25 :3 0 69
cc ce :3 0 6c
c9 d0 :2 0 d2
6f d3 c6 d2
0 d4 71 0
7ba 13 :3 0 5
:3 0 d5 d6 0
7ba b :3 0 3
:3 0 d8 d9 0
7ba 32 :3 0 33
:3 0 34 :3 0 35
:3 0 36 :3 0 37
:3 0 38 :3 0 d
:3 0 e :3 0 11
:3 0 17 :3 0 18
:3 0 19 :3 0 39
:3 0 3a :3 0 b
:4 0 3b 1 :8 0
f1 9 :3 0 3c
:3 0 ec ed 0
3d :3 0 ee ef
0 f1 73 144
3e :3 0 9 :3 0
3c :3 0 f3 f4
0 3d :3 0 f5
f6 0 f8 76
fa 78 f9 f8
:2 0 142 3f :3 0
9 :3 0 3c :3 0
fd fe 0 3d
:3 0 ff 100 0
13a 1c :3 0 1d
:3 0 102 103 0
1c :3 0 2d :3 0
105 106 0 40
:2 0 2 :4 0 41
:2 0 2f :2 0 12
:2 0 7a 10b 10d
:3 0 7d 107 10f
104 111 110 :2 0
1f :3 0 30 :3 0
113 114 0 21
:4 0 42 :4 0 24
:2 0 25 :3 0 81
118 11a :3 0 24
:2 0 43 :4 0 84
11c 11e :3 0 24
:2 0 44 :4 0 87
120 122 :3 0 24
:2 0 3d :3 0 8a
124 126 :3 0 24
:2 0 45 :4 0 8d
128 12a :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 90 12d 131
94 12c 133 :3 0
97 115 135 :2 0
137 9a 138 112
137 0 139 9c
0 13a 9e 13d
:3 0 13d 0 13d
13c 13a 13b :6 0
13f 2 :3 0 a1
141 a3 140 13f
:2 0 142 a5 :2 0
144 0 144 143
f1 142 :6 0 7ba
1 :3 0 29 :3 0
13 :3 0 14 :2 0
a8 146 149 49
:2 0 12 :2 0 ad
14b 14d :3 0 46
:3 0 11 :3 0 12
:2 0 12 :2 0 b0
14f 153 49 :2 0
4a :4 0 b6 155
157 :3 0 39 :3 0
4b :3 0 35 :3 0
37 :3 0 3a :3 0
b :4 0 4c 1
:8 0 175 4d :4 0
160 :3 0 4e :3 0
49 :2 0 bb 163
164 :3 0 9 :3 0
3c :3 0 166 167
0 14 :2 0 168
169 0 16b be
172 9 :3 0 3c
:3 0 16c 16d 0
4f :2 0 16e 16f
0 171 c0 173
165 16b 0 174
0 171 0 174
c2 0 175 c5
1c8 3e :3 0 9
:3 0 3c :3 0 177
178 0 3d :3 0
179 17a 0 17c
c8 17e ca 17d
17c :2 0 1c6 3f
:3 0 9 :3 0 3c
:3 0 181 182 0
3d :3 0 183 184
0 1be 1c :3 0
1d :3 0 186 187
0 1c :3 0 2d
:3 0 189 18a 0
40 :2 0 2 :4 0
50 :2 0 2f :2 0
12 :2 0 cc 18f
191 :3 0 cf 18b
193 188 195 194
:2 0 1f :3 0 30
:3 0 197 198 0
21 :4 0 51 :4 0
24 :2 0 25 :3 0
d3 19c 19e :3 0
24 :2 0 43 :4 0
d6 1a0 1a2 :3 0
24 :2 0 44 :4 0
d9 1a4 1a6 :3 0
24 :2 0 3d :3 0
dc 1a8 1aa :3 0
24 :2 0 45 :4 0
df 1ac 1ae :3 0
24 :2 0 46 :3 0
47 :3 0 12 :2 0
48 :2 0 e2 1b1
1b5 e6 1b0 1b7
:3 0 e9 199 1b9
:2 0 1bb ec 1bc
196 1bb 0 1bd
ee 0 1be f0
1c1 :3 0 1c1 0
1c1 1c0 1be 1bf
:6 0 1c3 4 :3 0
f3 1c5 f5 1c4
1c3 :2 0 1c6 f7
:2 0 1c8 0 1c8
1c7 175 1c6 :6 0
23e 1 :3 0 52
:3 0 53 :3 0 3a
:3 0 b :3 0 3a
:3 0 54 :3 0 55
:3 0 56 :3 0 57
:4 0 58 1 :8 0
1e9 4d :4 0 1d4
:3 0 4e :3 0 49
:2 0 fc 1d7 1d8
:3 0 9 :3 0 3c
:3 0 1da 1db 0
14 :2 0 1dc 1dd
0 1df ff 1e6
9 :3 0 3c :3 0
1e0 1e1 0 4f
:2 0 1e2 1e3 0
1e5 101 1e7 1d9
1df 0 1e8 0
1e5 0 1e8 103
0 1e9 106 23c
3e :3 0 9 :3 0
3c :3 0 1eb 1ec
0 3d :3 0 1ed
1ee 0 1f0 109
1f2 10b 1f1 1f0
:2 0 23a 3f :3 0
9 :3 0 3c :3 0
1f5 1f6 0 3d
:3 0 1f7 1f8 0
232 1c :3 0 1d
:3 0 1fa 1fb 0
1c :3 0 2d :3 0
1fd 1fe 0 40
:2 0 2 :4 0 59
:2 0 2f :2 0 12
:2 0 10d 203 205
:3 0 110 1ff 207
1fc 209 208 :2 0
1f :3 0 30 :3 0
20b 20c 0 21
:4 0 5a :4 0 24
:2 0 25 :3 0 114
210 212 :3 0 24
:2 0 43 :4 0 117
214 216 :3 0 24
:2 0 44 :4 0 11a
218 21a :3 0 24
:2 0 3d :3 0 11d
21c 21e :3 0 24
:2 0 45 :4 0 120
220 222 :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 123 225 229
127 224 22b :3 0
12a 20d 22d :2 0
22f 12d 230 20a
22f 0 231 12f
0 232 131 235
:3 0 235 0 235
234 232 233 :6 0
237 6 :3 0 134
239 136 238 237
:2 0 23a 138 :2 0
23c 0 23c 23b
1e9 23a :6 0 23e
1 :3 0 13b 2b2
39 :3 0 4b :3 0
36 :3 0 37 :3 0
38 :3 0 3a :3 0
b :4 0 5b 1
:8 0 25c 4d :4 0
247 :3 0 4e :3 0
49 :2 0 140 24a
24b :3 0 9 :3 0
3c :3 0 24d 24e
0 14 :2 0 24f
250 0 252 143
259 9 :3 0 3c
:3 0 253 254 0
4f :2 0 255 256
0 258 145 25a
24c 252 0 25b
0 258 0 25b
147 0 25c 14a
2af 3e :3 0 9
:3 0 3c :3 0 25e
25f 0 3d :3 0
260 261 0 263
14d 265 14f 264
263 :2 0 2ad 3f
:3 0 9 :3 0 3c
:3 0 268 269 0
3d :3 0 26a 26b
0 2a5 1c :3 0
1d :3 0 26d 26e
0 1c :3 0 2d
:3 0 270 271 0
40 :2 0 2 :4 0
5c :2 0 2f :2 0
12 :2 0 151 276
278 :3 0 154 272
27a 26f 27c 27b
:2 0 1f :3 0 30
:3 0 27e 27f 0
21 :4 0 5d :4 0
24 :2 0 25 :3 0
158 283 285 :3 0
24 :2 0 43 :4 0
15b 287 289 :3 0
24 :2 0 44 :4 0
15e 28b 28d :3 0
24 :2 0 3d :3 0
161 28f 291 :3 0
24 :2 0 45 :4 0
164 293 295 :3 0
24 :2 0 46 :3 0
47 :3 0 12 :2 0
48 :2 0 167 298
29c 16b 297 29e
:3 0 16e 280 2a0
:2 0 2a2 171 2a3
27d 2a2 0 2a4
173 0 2a5 175
2a8 :3 0 2a8 0
2a8 2a7 2a5 2a6
:6 0 2aa 8 :3 0
178 2ac 17a 2ab
2aa :2 0 2ad 17c
:2 0 2af 0 2af
2ae 25c 2ad :6 0
2b1 1 :3 0 17f
2b3 158 23e 0
2b4 0 2b1 0
2b4 181 0 329
5e :3 0 5f :3 0
60 :3 0 61 :3 0
5f :3 0 56 :3 0
62 :3 0 54 :3 0
e :4 0 63 1
:8 0 2d4 4d :4 0
2bf :3 0 4e :3 0
49 :2 0 186 2c2
2c3 :3 0 9 :3 0
3c :3 0 2c5 2c6
0 14 :2 0 2c7
2c8 0 2ca 189
2d1 9 :3 0 3c
:3 0 2cb 2cc 0
4f :2 0 2cd 2ce
0 2d0 18b 2d2
2c4 2ca 0 2d3
0 2d0 0 2d3
18d 0 2d4 190
327 3e :3 0 9
:3 0 3c :3 0 2d6
2d7 0 3d :3 0
2d8 2d9 0 2db
193 2dd 195 2dc
2db :2 0 325 3f
:3 0 9 :3 0 3c
:3 0 2e0 2e1 0
3d :3 0 2e2 2e3
0 31d 1c :3 0
1d :3 0 2e5 2e6
0 1c :3 0 2d
:3 0 2e8 2e9 0
40 :2 0 2 :4 0
64 :2 0 2f :2 0
12 :2 0 197 2ee
2f0 :3 0 19a 2ea
2f2 2e7 2f4 2f3
:2 0 1f :3 0 30
:3 0 2f6 2f7 0
21 :4 0 65 :4 0
24 :2 0 25 :3 0
19e 2fb 2fd :3 0
24 :2 0 43 :4 0
1a1 2ff 301 :3 0
24 :2 0 44 :4 0
1a4 303 305 :3 0
24 :2 0 3d :3 0
1a7 307 309 :3 0
24 :2 0 45 :4 0
1aa 30b 30d :3 0
24 :2 0 46 :3 0
47 :3 0 12 :2 0
48 :2 0 1ad 310
314 1b1 30f 316
:3 0 1b4 2f8 318
:2 0 31a 1b7 31b
2f5 31a 0 31c
1b9 0 31d 1bb
320 :3 0 320 0
320 31f 31d 31e
:6 0 322 a :3 0
1be 324 1c0 323
322 :2 0 325 1c2
:2 0 327 0 327
326 2d4 325 :6 0
329 1 :3 0 1c5
5fe 29 :3 0 13
:3 0 14 :2 0 1c8
32a 32d 49 :2 0
4a :2 0 1cd 32f
331 :3 0 39 :3 0
66 :3 0 67 :3 0
68 :3 0 3a :3 0
b :4 0 69 1
:8 0 34f 4d :4 0
33a :3 0 4e :3 0
49 :2 0 1d2 33d
33e :3 0 9 :3 0
3c :3 0 340 341
0 14 :2 0 342
343 0 345 1d5
34c 9 :3 0 3c
:3 0 346 347 0
4f :2 0 348 349
0 34b 1d7 34d
33f 345 0 34e
0 34b 0 34e
1d9 0 34f 1dc
3a2 3e :3 0 9
:3 0 3c :3 0 351
352 0 3d :3 0
353 354 0 356
1df 358 1e1 357
356 :2 0 3a0 3f
:3 0 9 :3 0 3c
:3 0 35b 35c 0
3d :3 0 35d 35e
0 398 1c :3 0
1d :3 0 360 361
0 1c :3 0 2d
:3 0 363 364 0
40 :2 0 2 :4 0
6a :2 0 2f :2 0
12 :2 0 1e3 369
36b :3 0 1e6 365
36d 362 36f 36e
:2 0 1f :3 0 30
:3 0 371 372 0
21 :4 0 6b :4 0
24 :2 0 25 :3 0
1ea 376 378 :3 0
24 :2 0 43 :4 0
1ed 37a 37c :3 0
24 :2 0 44 :4 0
1f0 37e 380 :3 0
24 :2 0 3d :3 0
1f3 382 384 :3 0
24 :2 0 45 :4 0
1f6 386 388 :3 0
24 :2 0 46 :3 0
47 :3 0 12 :2 0
48 :2 0 1f9 38b
38f 1fd 38a 391
:3 0 200 373 393
:2 0 395 203 396
370 395 0 397
205 0 398 207
39b :3 0 39b 0
39b 39a 398 399
:6 0 39d c :3 0
20a 39f 20c 39e
39d :2 0 3a0 20e
:2 0 3a2 0 3a2
3a1 34f 3a0 :6 0
418 1 :3 0 5e
:3 0 5f :3 0 60
:3 0 61 :3 0 5f
:3 0 56 :3 0 62
:3 0 54 :3 0 e
:4 0 63 1 :8 0
3c3 4d :4 0 3ae
:3 0 4e :3 0 49
:2 0 213 3b1 3b2
:3 0 9 :3 0 3c
:3 0 3b4 3b5 0
14 :2 0 3b6 3b7
0 3b9 216 3c0
9 :3 0 3c :3 0
3ba 3bb 0 4f
:2 0 3bc 3bd 0
3bf 218 3c1 3b3
3b9 0 3c2 0
3bf 0 3c2 21a
0 3c3 21d 416
3e :3 0 9 :3 0
3c :3 0 3c5 3c6
0 3d :3 0 3c7
3c8 0 3ca 220
3cc 222 3cb 3ca
:2 0 414 3f :3 0
9 :3 0 3c :3 0
3cf 3d0 0 3d
:3 0 3d1 3d2 0
40c 1c :3 0 1d
:3 0 3d4 3d5 0
1c :3 0 2d :3 0
3d7 3d8 0 40
:2 0 2 :4 0 6c
:2 0 2f :2 0 12
:2 0 224 3dd 3df
:3 0 227 3d9 3e1
3d6 3e3 3e2 :2 0
1f :3 0 30 :3 0
3e5 3e6 0 21
:4 0 6d :4 0 24
:2 0 25 :3 0 22b
3ea 3ec :3 0 24
:2 0 43 :4 0 22e
3ee 3f0 :3 0 24
:2 0 44 :4 0 231
3f2 3f4 :3 0 24
:2 0 3d :3 0 234
3f6 3f8 :3 0 24
:2 0 45 :4 0 237
3fa 3fc :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 23a 3ff 403
23e 3fe 405 :3 0
241 3e7 407 :2 0
409 244 40a 3e4
409 0 40b 246
0 40c 248 40f
:3 0 40f 0 40f
40e 40c 40d :6 0
411 e :3 0 24b
413 24d 412 411
:2 0 414 24f :2 0
416 0 416 415
3c3 414 :6 0 418
1 :3 0 252 5fa
46 :3 0 11 :3 0
12 :2 0 12 :2 0
255 419 41d 49
:2 0 4a :4 0 25b
41f 421 :3 0 39
:3 0 66 :3 0 67
:3 0 68 :3 0 4b
:3 0 35 :3 0 37
:3 0 3a :3 0 b
:4 0 6e 1 :8 0
442 4d :4 0 42d
:3 0 4e :3 0 49
:2 0 260 430 431
:3 0 9 :3 0 3c
:3 0 433 434 0
14 :2 0 435 436
0 438 263 43f
9 :3 0 3c :3 0
439 43a 0 4f
:2 0 43b 43c 0
43e 265 440 432
438 0 441 0
43e 0 441 267
0 442 26a 495
3e :3 0 9 :3 0
3c :3 0 444 445
0 3d :3 0 446
447 0 449 26d
44b 26f 44a 449
:2 0 493 3f :3 0
9 :3 0 3c :3 0
44e 44f 0 3d
:3 0 450 451 0
48b 1c :3 0 1d
:3 0 453 454 0
1c :3 0 2d :3 0
456 457 0 40
:2 0 2 :4 0 6f
:2 0 2f :2 0 12
:2 0 271 45c 45e
:3 0 274 458 460
455 462 461 :2 0
1f :3 0 30 :3 0
464 465 0 21
:4 0 70 :4 0 24
:2 0 25 :3 0 278
469 46b :3 0 24
:2 0 43 :4 0 27b
46d 46f :3 0 24
:2 0 44 :4 0 27e
471 473 :3 0 24
:2 0 3d :3 0 281
475 477 :3 0 24
:2 0 45 :4 0 284
479 47b :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 287 47e 482
28b 47d 484 :3 0
28e 466 486 :2 0
488 291 489 463
488 0 48a 293
0 48b 295 48e
:3 0 48e 0 48e
48d 48b 48c :6 0
490 10 :3 0 298
492 29a 491 490
:2 0 493 29c :2 0
495 0 495 494
442 493 :6 0 50b
1 :3 0 52 :3 0
53 :3 0 3a :3 0
b :3 0 3a :3 0
54 :3 0 55 :3 0
56 :3 0 57 :4 0
71 1 :8 0 4b6
4d :4 0 4a1 :3 0
4e :3 0 49 :2 0
2a1 4a4 4a5 :3 0
9 :3 0 3c :3 0
4a7 4a8 0 14
:2 0 4a9 4aa 0
4ac 2a4 4b3 9
:3 0 3c :3 0 4ad
4ae 0 4f :2 0
4af 4b0 0 4b2
2a6 4b4 4a6 4ac
0 4b5 0 4b2
0 4b5 2a8 0
4b6 2ab 509 3e
:3 0 9 :3 0 3c
:3 0 4b8 4b9 0
3d :3 0 4ba 4bb
0 4bd 2ae 4bf
2b0 4be 4bd :2 0
507 3f :3 0 9
:3 0 3c :3 0 4c2
4c3 0 3d :3 0
4c4 4c5 0 4ff
1c :3 0 1d :3 0
4c7 4c8 0 1c
:3 0 2d :3 0 4ca
4cb 0 40 :2 0
2 :4 0 72 :2 0
2f :2 0 12 :2 0
2b2 4d0 4d2 :3 0
2b5 4cc 4d4 4c9
4d6 4d5 :2 0 1f
:3 0 30 :3 0 4d8
4d9 0 21 :4 0
73 :4 0 24 :2 0
25 :3 0 2b9 4dd
4df :3 0 24 :2 0
43 :4 0 2bc 4e1
4e3 :3 0 24 :2 0
44 :4 0 2bf 4e5
4e7 :3 0 24 :2 0
3d :3 0 2c2 4e9
4eb :3 0 24 :2 0
45 :4 0 2c5 4ed
4ef :3 0 24 :2 0
46 :3 0 47 :3 0
12 :2 0 48 :2 0
2c8 4f2 4f6 2cc
4f1 4f8 :3 0 2cf
4da 4fa :2 0 4fc
2d2 4fd 4d7 4fc
0 4fe 2d4 0
4ff 2d6 502 :3 0
502 0 502 501
4ff 500 :6 0 504
12 :3 0 2d9 506
2db 505 504 :2 0
507 2dd :2 0 509
0 509 508 4b6
507 :6 0 50b 1
:3 0 2e0 582 39
:3 0 66 :3 0 67
:3 0 68 :3 0 4b
:3 0 36 :3 0 37
:3 0 38 :3 0 3a
:3 0 b :4 0 74
1 :8 0 52c 4d
:4 0 517 :3 0 4e
:3 0 49 :2 0 2e5
51a 51b :3 0 9
:3 0 3c :3 0 51d
51e 0 14 :2 0
51f 520 0 522
2e8 529 9 :3 0
3c :3 0 523 524
0 4f :2 0 525
526 0 528 2ea
52a 51c 522 0
52b 0 528 0
52b 2ec 0 52c
2ef 57f 3e :3 0
9 :3 0 3c :3 0
52e 52f 0 3d
:3 0 530 531 0
533 2f2 535 2f4
534 533 :2 0 57d
3f :3 0 9 :3 0
3c :3 0 538 539
0 3d :3 0 53a
53b 0 575 1c
:3 0 1d :3 0 53d
53e 0 1c :3 0
2d :3 0 540 541
0 40 :2 0 2
:4 0 75 :2 0 2f
:2 0 12 :2 0 2f6
546 548 :3 0 2f9
542 54a 53f 54c
54b :2 0 1f :3 0
30 :3 0 54e 54f
0 21 :4 0 76
:4 0 24 :2 0 25
:3 0 2fd 553 555
:3 0 24 :2 0 43
:4 0 300 557 559
:3 0 24 :2 0 44
:4 0 303 55b 55d
:3 0 24 :2 0 3d
:3 0 306 55f 561
:3 0 24 :2 0 45
:4 0 309 563 565
:3 0 24 :2 0 46
:3 0 47 :3 0 12
:2 0 48 :2 0 30c
568 56c 310 567
56e :3 0 313 550
570 :2 0 572 316
573 54d 572 0
574 318 0 575
31a 578 :3 0 578
0 578 577 575
576 :6 0 57a 14
:3 0 31d 57c 31f
57b 57a :2 0 57d
321 :2 0 57f 0
57f 57e 52c 57d
:6 0 581 1 :3 0
324 583 422 50b
0 584 0 581
0 584 326 0
5f9 5e :3 0 5f
:3 0 60 :3 0 61
:3 0 5f :3 0 56
:3 0 62 :3 0 54
:3 0 e :4 0 63
1 :8 0 5a4 4d
:4 0 58f :3 0 4e
:3 0 49 :2 0 32b
592 593 :3 0 9
:3 0 3c :3 0 595
596 0 14 :2 0
597 598 0 59a
32e 5a1 9 :3 0
3c :3 0 59b 59c
0 4f :2 0 59d
59e 0 5a0 330
5a2 594 59a 0
5a3 0 5a0 0
5a3 332 0 5a4
335 5f7 3e :3 0
9 :3 0 3c :3 0
5a6 5a7 0 3d
:3 0 5a8 5a9 0
5ab 338 5ad 33a
5ac 5ab :2 0 5f5
3f :3 0 9 :3 0
3c :3 0 5b0 5b1
0 3d :3 0 5b2
5b3 0 5ed 1c
:3 0 1d :3 0 5b5
5b6 0 1c :3 0
2d :3 0 5b8 5b9
0 40 :2 0 2
:4 0 77 :2 0 2f
:2 0 12 :2 0 33c
5be 5c0 :3 0 33f
5ba 5c2 5b7 5c4
5c3 :2 0 1f :3 0
30 :3 0 5c6 5c7
0 21 :4 0 78
:4 0 24 :2 0 25
:3 0 343 5cb 5cd
:3 0 24 :2 0 43
:4 0 346 5cf 5d1
:3 0 24 :2 0 44
:4 0 349 5d3 5d5
:3 0 24 :2 0 3d
:3 0 34c 5d7 5d9
:3 0 24 :2 0 45
:4 0 34f 5db 5dd
:3 0 24 :2 0 46
:3 0 47 :3 0 12
:2 0 48 :2 0 352
5e0 5e4 356 5df
5e6 :3 0 359 5c8
5e8 :2 0 5ea 35c
5eb 5c5 5ea 0
5ec 35e 0 5ed
360 5f0 :3 0 5f0
0 5f0 5ef 5ed
5ee :6 0 5f2 16
:3 0 363 5f4 365
5f3 5f2 :2 0 5f5
367 :2 0 5f7 0
5f7 5f6 5a4 5f5
:6 0 5f9 1 :3 0
36a 5fb 332 418
0 5fc 0 5f9
0 5fc 36d 0
5fd 370 5ff 14e
329 0 600 0
5fd 0 600 372
0 7ba 79 :3 0
29 :3 0 13 :3 0
14 :2 0 375 602
605 12 :2 0 378
601 608 609 :2 0
49 :2 0 12 :2 0
37d 60b 60d :3 0
60e :2 0 29 :3 0
19 :3 0 14 :2 0
380 610 613 7a
:2 0 14 :2 0 385
615 617 :3 0 618
:2 0 60f 61a 619
:2 0 1a :3 0 7b
:3 0 29 :3 0 7c
:3 0 18 :3 0 388
61f 621 14 :2 0
38a 61e 624 7d
:2 0 29 :3 0 7c
:3 0 17 :3 0 38d
628 62a 14 :2 0
38f 627 62d 392
626 62f :3 0 630
:2 0 7e :2 0 7f
:2 0 395 632 634
:3 0 635 :2 0 80
:2 0 29 :3 0 19
:3 0 14 :2 0 398
638 63b 39b 637
63d :3 0 39e 61d
63f 61c 640 0
6ce 1a :3 0 7a
:2 0 12 :2 0 3a2
643 645 :3 0 646
:2 0 1a :3 0 81
:2 0 80 :2 0 12
:2 0 3a5 64a 64c
:3 0 3a9 649 64e
:3 0 647 650 64f
:2 0 39 :3 0 5f
:3 0 60 :3 0 61
:3 0 5f :3 0 56
:3 0 82 :3 0 83
:3 0 83 :3 0 4b
:3 0 84 :3 0 83
:3 0 3a :3 0 b
:4 0 85 1 :8 0
676 4d :4 0 661
:3 0 4e :3 0 49
:2 0 3ae 664 665
:3 0 9 :3 0 3c
:3 0 667 668 0
14 :2 0 669 66a
0 66c 3b1 673
9 :3 0 3c :3 0
66d 66e 0 4f
:2 0 66f 670 0
672 3b3 674 666
66c 0 675 0
672 0 675 3b5
0 676 3b8 6c9
3e :3 0 9 :3 0
3c :3 0 678 679
0 3d :3 0 67a
67b 0 67d 3bb
67f 3bd 67e 67d
:2 0 6c7 3f :3 0
9 :3 0 3c :3 0
682 683 0 3d
:3 0 684 685 0
6bf 1c :3 0 1d
:3 0 687 688 0
1c :3 0 2d :3 0
68a 68b 0 40
:2 0 2 :4 0 86
:2 0 2f :2 0 12
:2 0 3bf 690 692
:3 0 3c2 68c 694
689 696 695 :2 0
1f :3 0 30 :3 0
698 699 0 21
:4 0 87 :4 0 24
:2 0 25 :3 0 3c6
69d 69f :3 0 24
:2 0 43 :4 0 3c9
6a1 6a3 :3 0 24
:2 0 44 :4 0 3cc
6a5 6a7 :3 0 24
:2 0 3d :3 0 3cf
6a9 6ab :3 0 24
:2 0 45 :4 0 3d2
6ad 6af :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 3d5 6b2 6b6
3d9 6b1 6b8 :3 0
3dc 69a 6ba :2 0
6bc 3df 6bd 697
6bc 0 6be 3e1
0 6bf 3e3 6c2
:3 0 6c2 0 6c2
6c1 6bf 6c0 :6 0
6c4 18 :3 0 3e6
6c6 3e8 6c5 6c4
:2 0 6c7 3ea :2 0
6c9 0 6c9 6c8
676 6c7 :6 0 6cb
1 :3 0 3ed 6cc
651 6cb 0 6cd
3ef 0 6ce 3f1
743 39 :3 0 83
:3 0 83 :3 0 4b
:3 0 84 :3 0 83
:3 0 3a :3 0 b
:4 0 88 1 :8 0
6ed 4d :4 0 6d8
:3 0 4e :3 0 49
:2 0 3f6 6db 6dc
:3 0 9 :3 0 3c
:3 0 6de 6df 0
14 :2 0 6e0 6e1
0 6e3 3f9 6ea
9 :3 0 3c :3 0
6e4 6e5 0 4f
:2 0 6e6 6e7 0
6e9 3fb 6eb 6dd
6e3 0 6ec 0
6e9 0 6ec 3fd
0 6ed 400 740
3e :3 0 9 :3 0
3c :3 0 6ef 6f0
0 3d :3 0 6f1
6f2 0 6f4 403
6f6 405 6f5 6f4
:2 0 73e 3f :3 0
9 :3 0 3c :3 0
6f9 6fa 0 3d
:3 0 6fb 6fc 0
736 1c :3 0 1d
:3 0 6fe 6ff 0
1c :3 0 2d :3 0
701 702 0 40
:2 0 2 :4 0 89
:2 0 2f :2 0 12
:2 0 407 707 709
:3 0 40a 703 70b
700 70d 70c :2 0
1f :3 0 30 :3 0
70f 710 0 21
:4 0 8a :4 0 24
:2 0 25 :3 0 40e
714 716 :3 0 24
:2 0 43 :4 0 411
718 71a :3 0 24
:2 0 44 :4 0 414
71c 71e :3 0 24
:2 0 3d :3 0 417
720 722 :3 0 24
:2 0 45 :4 0 41a
724 726 :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 41d 729 72d
421 728 72f :3 0
424 711 731 :2 0
733 427 734 70e
733 0 735 429
0 736 42b 739
:3 0 739 0 739
738 736 737 :6 0
73b 1a :3 0 42e
73d 430 73c 73b
:2 0 73e 432 :2 0
740 0 740 73f
6ed 73e :6 0 742
1 :3 0 435 744
61b 6ce 0 745
0 742 0 745
437 0 7ba 9
:3 0 3c :3 0 746
747 0 9 :3 0
49 :2 0 8b :3 0
749 74b 0 43c
74a 74d :3 0 74e
:2 0 29 :3 0 13
:3 0 14 :2 0 43f
750 753 8c :2 0
4a :2 0 444 755
757 :3 0 758 :2 0
74f 75a 759 :2 0
15 :3 0 8d :3 0
d :3 0 b :3 0
447 75d 760 75c
761 0 763 44a
764 75b 763 0
765 44c 0 7ba
15 :3 0 8e :3 0
d :3 0 44e 767
769 766 76a 0
7ba 1c :3 0 1d
:3 0 76c 76d 0
1c :3 0 2d :3 0
76f 770 0 8f
:2 0 2 :4 0 90
:2 0 2f :2 0 12
:2 0 450 775 777
:3 0 453 771 779
76e 77b 77a :2 0
1f :3 0 30 :3 0
77d 77e 0 21
:4 0 91 :4 0 24
:2 0 25 :3 0 457
782 784 :3 0 24
:2 0 43 :4 0 45a
786 788 :3 0 24
:2 0 92 :4 0 45d
78a 78c :3 0 24
:2 0 29 :3 0 2a
:3 0 9 :3 0 3c
:3 0 791 792 0
460 790 794 2b
:4 0 462 78f 797
465 78e 799 :3 0
24 :2 0 93 :4 0
468 79b 79d :3 0
24 :2 0 27 :4 0
46b 79f 7a1 :3 0
24 :2 0 3 :3 0
46e 7a3 7a5 :3 0
24 :2 0 27 :4 0
471 7a7 7a9 :3 0
474 77f 7ab :2 0
7ad 477 7ae 77c
7ad 0 7af 479
0 7ba 94 :3 0
95 :3 0 7b0 7b1
0 9 :3 0 3c
:3 0 7b3 7b4 0
3 :3 0 4e :3 0
47b 7b2 7b8 :2 0
7ba 47f 85b 9
:3 0 96 :2 0 4
7bb 7bc 0 1c
:3 0 1d :3 0 7be
7bf 0 1c :3 0
2d :3 0 7c1 7c2
0 40 :2 0 2
:4 0 97 :2 0 2f
:2 0 12 :2 0 48b
7c7 7c9 :3 0 48e
7c3 7cb 7c0 7cd
7cc :2 0 1f :3 0
30 :3 0 7cf 7d0
0 21 :4 0 98
:4 0 24 :2 0 25
:3 0 492 7d4 7d6
:3 0 495 7d1 7d8
:2 0 7f1 1f :3 0
30 :3 0 7da 7db
0 21 :4 0 99
:4 0 24 :2 0 9
:3 0 9a :3 0 7e0
7e1 0 498 7df
7e3 :3 0 24 :2 0
93 :4 0 49b 7e5
7e7 :3 0 24 :2 0
9 :3 0 9b :3 0
7ea 7eb 0 49e
7e9 7ed :3 0 4a1
7dc 7ef :2 0 7f1
4a4 7f2 7ce 7f1
0 7f3 4a7 0
803 9c :3 0 1b
:3 0 9 :3 0 9a
:3 0 9d :3 0 9
:3 0 9b :3 0 3
:3 0 9e :4 0 9f
1 :a 0 7ff :2 0
803 7f5 7fd :2 0
8 :3 0 1b :3 0
801 :2 0 803 4a9
805 4ad 804 803
:2 0 859 3f :3 0
9 :3 0 3c :3 0
808 809 0 3d
:3 0 80a 80b 0
851 1c :3 0 1d
:3 0 80d 80e 0
1c :3 0 2d :3 0
810 811 0 40
:2 0 2 :4 0 a0
:2 0 2f :2 0 12
:2 0 4af 816 818
:3 0 4b2 812 81a
80f 81c 81b :2 0
1f :3 0 30 :3 0
81e 81f 0 21
:4 0 a1 :4 0 24
:2 0 25 :3 0 4b6
823 825 :3 0 4b9
820 827 :2 0 841
1f :3 0 30 :3 0
829 82a 0 21
:4 0 44 :4 0 24
:2 0 3d :3 0 4bc
82e 830 :3 0 24
:2 0 45 :4 0 4bf
832 834 :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 4c2 837 83b
4c6 836 83d :3 0
4c9 82b 83f :2 0
841 4cc 842 81d
841 0 843 4cf
0 851 9c :3 0
1b :3 0 9d :3 0
9 :3 0 9b :3 0
3 :3 0 9e :4 0
a2 1 :a 0 84d
:2 0 851 845 84b
:2 0 8 :3 0 1b
:3 0 84f :2 0 851
4d1 854 :3 0 854
0 854 853 851
852 :6 0 856 1
:3 0 4d6 858 4d8
857 856 :2 0 859
4da :2 0 85b 4dd
85b 85a 7ba 859
:6 0 85c :2 0 2
14 85b 85f :3 0
85e 85c 860 :8 0

4eb
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2b 1 32 1
30 1 37 1
3d 1 43 1
49 1 4f 1
55 1 5b 1
60 1 6d 1
79 2 7c 7e
2 81 83 2
85 87 2 89
8b 2 8d 8f
1 95 2 97
98 2 91 9a
2 9c 9e 2
a0 a2 2 a4
a6 2 a8 aa
2 ac ae 4
75 7b 80 b0
1 b2 1 b4
2 be c0 3
bc bd c2 2
cb cd 2 ca
cf 1 d1 1
d3 2 eb f0
1 f7 1 f2
2 10a 10c 3
108 109 10e 2
117 119 2 11b
11d 2 11f 121
2 123 125 2
127 129 3 12e
12f 130 2 12b
132 2 116 134
1 136 1 138
2 101 139 1
13d 1 fc 2
fa 141 2 147
148 1 14c 2
14a 14c 3 150
151 152 1 156
2 154 156 1
162 2 161 162
1 16a 1 170
2 172 173 2
15f 174 1 17b
1 176 2 18e
190 3 18c 18d
192 2 19b 19d
2 19f 1a1 2
1a3 1a5 2 1a7
1a9 2 1ab 1ad
3 1b2 1b3 1b4
2 1af 1b6 2
19a 1b8 1 1ba
1 1bc 2 185
1bd 1 1c1 1
180 2 17e 1c5
1 1d6 2 1d5
1d6 1 1de 1
1e4 2 1e6 1e7
2 1d3 1e8 1
1ef 1 1ea 2
202 204 3 200
201 206 2 20f
211 2 213 215
2 217 219 2
21b 21d 2 21f
221 3 226 227
228 2 223 22a
2 20e 22c 1
22e 1 230 2
1f9 231 1 235
1 1f4 2 1f2
239 2 1c8 23c
1 249 2 248
249 1 251 1
257 2 259 25a
2 246 25b 1
262 1 25d 2
275 277 3 273
274 279 2 282
284 2 286 288
2 28a 28c 2
28e 290 2 292
294 3 299 29a
29b 2 296 29d
2 281 29f 1
2a1 1 2a3 2
26c 2a4 1 2a8
1 267 2 265
2ac 1 2af 2
2b2 2b3 1 2c1
2 2c0 2c1 1
2c9 1 2cf 2
2d1 2d2 2 2be
2d3 1 2da 1
2d5 2 2ed 2ef
3 2eb 2ec 2f1
2 2fa 2fc 2
2fe 300 2 302
304 2 306 308
2 30a 30c 3
311 312 313 2
30e 315 2 2f9
317 1 319 1
31b 2 2e4 31c
1 320 1 2df
2 2dd 324 2
2b4 327 2 32b
32c 1 330 2
32e 330 1 33c
2 33b 33c 1
344 1 34a 2
34c 34d 2 339
34e 1 355 1
350 2 368 36a
3 366 367 36c
2 375 377 2
379 37b 2 37d
37f 2 381 383
2 385 387 3
38c 38d 38e 2
389 390 2 374
392 1 394 1
396 2 35f 397
1 39b 1 35a
2 358 39f 1
3b0 2 3af 3b0
1 3b8 1 3be
2 3c0 3c1 2
3ad 3c2 1 3c9
1 3c4 2 3dc
3de 3 3da 3db
3e0 2 3e9 3eb
2 3ed 3ef 2
3f1 3f3 2 3f5
3f7 2 3f9 3fb
3 400 401 402
2 3fd 404 2
3e8 406 1 408
1 40a 2 3d3
40b 1 40f 1
3ce 2 3cc 413
2 3a2 416 3
41a 41b 41c 1
420 2 41e 420
1 42f 2 42e
42f 1 437 1
43d 2 43f 440
2 42c 441 1
448 1 443 2
45b 45d 3 459
45a 45f 2 468
46a 2 46c 46e
2 470 472 2
474 476 2 478
47a 3 47f 480
481 2 47c 483
2 467 485 1
487 1 489 2
452 48a 1 48e
1 44d 2 44b
492 1 4a3 2
4a2 4a3 1 4ab
1 4b1 2 4b3
4b4 2 4a0 4b5
1 4bc 1 4b7
2 4cf 4d1 3
4cd 4ce 4d3 2
4dc 4de 2 4e0
4e2 2 4e4 4e6
2 4e8 4ea 2
4ec 4ee 3 4f3
4f4 4f5 2 4f0
4f7 2 4db 4f9
1 4fb 1 4fd
2 4c6 4fe 1
502 1 4c1 2
4bf 506 2 495
509 1 519 2
518 519 1 521
1 527 2 529
52a 2 516 52b
1 532 1 52d
2 545 547 3
543 544 549 2
552 554 2 556
558 2 55a 55c
2 55e 560 2
562 564 3 569
56a 56b 2 566
56d 2 551 56f
1 571 1 573
2 53c 574 1
578 1 537 2
535 57c 1 57f
2 582 583 1
591 2 590 591
1 599 1 59f
2 5a1 5a2 2
58e 5a3 1 5aa
1 5a5 2 5bd
5bf 3 5bb 5bc
5c1 2 5ca 5cc
2 5ce 5d0 2
5d2 5d4 2 5d6
5d8 2 5da 5dc
3 5e1 5e2 5e3
2 5de 5e5 2
5c9 5e7 1 5e9
1 5eb 2 5b4
5ec 1 5f0 1
5af 2 5ad 5f4
2 584 5f7 2
5fa 5fb 1 5fc
2 5fe 5ff 2
603 604 2 606
607 1 60c 2
60a 60c 2 611
612 1 616 2
614 616 1 620
2 622 623 1
629 2 62b 62c
2 625 62e 2
631 633 2 639
63a 2 636 63c
1 63e 1 644
2 642 644 1
64b 1 64d 2
648 64d 1 663
2 662 663 1
66b 1 671 2
673 674 2 660
675 1 67c 1
677 2 68f 691
3 68d 68e 693
2 69c 69e 2
6a0 6a2 2 6a4
6a6 2 6a8 6aa
2 6ac 6ae 3
6b3 6b4 6b5 2
6b0 6b7 2 69b
6b9 1 6bb 1
6bd 2 686 6be
1 6c2 1 681
2 67f 6c6 1
6c9 1 6cc 2
641 6cd 1 6da
2 6d9 6da 1
6e2 1 6e8 2
6ea 6eb 2 6d7
6ec 1 6f3 1
6ee 2 706 708
3 704 705 70a
2 713 715 2
717 719 2 71b
71d 2 71f 721
2 723 725 3
72a 72b 72c 2
727 72e 2 712
730 1 732 1
734 2 6fd 735
1 739 1 6f8
2 6f6 73d 1
740 2 743 744
1 74c 2 748
74c 2 751 752
1 756 2 754
756 2 75e 75f
1 762 1 764
1 768 2 774
776 3 772 773
778 2 781 783
2 785 787 2
789 78b 1 793
2 795 796 2
78d 798 2 79a
79c 2 79e 7a0
2 7a2 7a4 2
7a6 7a8 2 780
7aa 1 7ac 1
7ae 3 7b5 7b6
7b7 b b5 d4
d7 da 144 600
745 765 76b 7af
7b9 2 7c6 7c8
3 7c4 7c5 7ca
2 7d3 7d5 2
7d2 7d7 2 7de
7e2 2 7e4 7e6
2 7e8 7ec 2
7dd 7ee 2 7d9
7f0 1 7f2 3
7f3 7fe 802 1
7bd 2 815 817
3 813 814 819
2 822 824 2
821 826 2 82d
82f 2 831 833
3 838 839 83a
2 835 83c 2
82c 83e 2 828
840 1 842 4
80c 843 84c 850
1 854 1 807
2 805 858 d
1b 22 29 2e
35 3b 41 47
4d 53 59 5e
65 
1
4
0 
85f
0
1
28
1c
11
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 0 0 0 0
0 0 0 0 0 0 0 0

b 1 0
3 1 0
55 1 0
16 1 0
2 0 1
3d 1 0
2b 1 0
37 1 0
49 1 0
24 1 0
4f 1 0
30 1 0
43 1 0
1d 1 0
7 1 0
5b 1 0
60 1 0
0

/
SHOW ERRORS FUNCTION SP_RJCT_ETC_ASSIGN;
ALTER FUNCTION SP_RJCT_ETC_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Reject ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_RJCT_ETC_WBS ==
CREATE OR REPLACE FUNCTION SP_RJCT_ETC_WBS wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
eb
2 :e:
1FUNCTION:
1SP_RJCT_ETC_WBS:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_FINISH_DATE:
1TIMESTAMP:
1H_PROJECT_ID:
132:
1H_RANK:
1200:
1H_START_DATE:
1H_TASK_ID:
1H_TSK_ASSIGNMENT_ID:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_EFFORT:
1H_TYPE:
1H_START_D:
1DATE:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_TEMP_SC_NODATA:
1H_STEPS_EXIST:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1H_TEMP_SC_STATE_ALERT:
1H_ALERT_ID:
1H_REC_USER:
1H_CALLTYPE:
1H_TABLE_TYPE:
1I_STEPS_EXIST:
1I_PERCENT_COMPLETE:
1CURSOR:
1CAWTSKR:
1ELEMENT_ID:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1SCHED_START:
1FORECAST_FINISH:
1SCHED_FINISH:
1TMT_WBS:
1PROJECT_ID:
1RANK:
1TYPE_ID:
1PMO_CNST:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1WORK_TODATE:
1ETC:
1SELECT ELEMENT_ID, SCHED_EFFORT+PLANNED_EFFORT,:n         CASE WHEN FORECAST_+
1START IS NULL THEN SCHED_START ELSE FORECAST_START END,:n         CASE WHEN F+
1ORECAST_FINISH IS NULL THEN SCHED_FINISH ELSE FORECAST_FINISH END:n         F+
1ROM TMT_WBS:n         WHERE PROJECT_ID = h_project_id AND RANK LIKE h_rank AN+
1D TYPE_ID IN (pmo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,pmo_cnst.SC_TASK_TYPE2,+
1pmo_cnst.SC_TASK_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.SC_PERSONAL_TASK,pmo_cn+
1st.SC_ACTIVE_ADM_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pmo_cnst.SC_WBS_CHANGE_RE+
1QUEST_TASK,pmo_cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.SC_WBS_RISK_TASK,pmo_cns+
1t.SC_WBS_ISSUE_TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,pmo_cnst.SC_WBS_DEFECT_T+
1ASK,pmo_cnst.SC_WBS_SERVICE_REQUEST_TASK):n         AND (((SCHED_EFFORT+PLANN+
1ED_EFFORT) > 0 AND ((SCHED_EFFORT+PLANNED_EFFORT-WORK_TODATE) <> ETC)):n     +
1    OR (FORECAST_START IS NOT NULL OR FORECAST_FINISH IS NOT NULL)):
1CAWASSR:
1TSK_ASSIGNMENT_ID:
1BIT_FLAG:
1BEST:
1SCHED_WORK:
1PLANNED_WORK:
1MILESTONE_PERCENT:
1TASK_ASSIGNMENTS:
1TASK_ID:
1SELECT TSK_ASSIGNMENT_ID, BIT_FLAG, BEST, SCHED_WORK+PLANNED_WORK, WORK_TODAT+
1E, MILESTONE_PERCENT:n         FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_+
1ID = h_project_id:n         AND TASK_ID = h_task_id:n         AND (((SCHED_WO+
1RK+PLANNED_WORK) > 0 AND ((SCHED_WORK+PLANNED_WORK-WORK_TODATE) <> ETC)):n   +
1      OR (FORECAST_START IS NOT NULL OR FORECAST_FINISH IS NOT NULL)):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_RJCT_ETC_WBS(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_RJCT_ETC_WBS(61) :: cplan.sql(21109) :: :
13:
1SCETCFORCASTREJECTED:
1RTRIM:
1SELECT PROJECT_ID, RTRIM(RANK), TYPE_ID:n      INTO h_project_id, h_rank, h_t+
1ype:n      FROM TMT_WBS WHERE ELEMENT_ID = id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
185:
1           EXCEPTION:: SP_RJCT_ETC_WBS(86) :: cplan.sql(21134) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_SUCCESS:
1IS NOT NULL:
1%:
1-:
1START_FINISH_DATE:
1SELECT START_FINISH_DATE INTO h_start_D FROM TMT_WBS WHERE ELEMENT_ID = h_pro+
1ject_id:
1105:
1           EXCEPTION:: SP_RJCT_ETC_WBS(106) :: cplan.sql(21154) :: :
1OPEN:
1LOOP:
1FOUND:
1100:
1!=:
1EXIT:
12:
1FORECAST_DURATION:
1UPDATE TMT_WBS SET:n                  FORECAST_START = NULL,:n               +
1   FORECAST_FINISH = NULL,:n                  FORECAST_DURATION = 0:n        +
1          WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1TRUE:
1147:
1           EXCEPTION:: SP_RJCT_ETC_WBS(148) :: cplan.sql(21196) :: :
1FC_ISSUE_ALERT:
1CONTINUE0000:
1ACTIVITIES:
1ETC_MODIFIED:
1SC_TIMESHEET_ACTIVITY:
1UPDATE ACTIVITIES:n                        SET ETC_MODIFIED = 'N':n          +
1              WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n                +
1        AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n                        AND TYPE+
1_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY:
1198:
1           EXCEPTION:: SP_RJCT_ETC_WBS(199) :: cplan.sql(21247) :: :
1BAK_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n                                BAK_ASSIGN_STRIN+
1G = NULL:n                           WHERE TSK_ASSIGNMENT_ID = H_TSK_ASSIGNME+
1NT_ID:
1PROPOSED_START:
1PROPOSED_FINISH:
1PROPOSED_WORK:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1ASSIGN_STRING:
1ACTUAL_FINISH:
1UPDATE TASK_ASSIGNMENTS SET:n                           PROPOSED_START      =+
1 SCHED_START,:n                           PROPOSED_FINISH     = SCHED_FINISH,+
1:n                           PROPOSED_WORK       = SCHED_WORK,:n             +
1              BAK_START_DT        = SCHED_START,:n                           +
1BAK_FINISH_DT       = SCHED_FINISH,:n                           BAK_WORK     +
1       = SCHED_WORK,:n                           BAK_ASSIGN_STRING   = ASSIGN+
1_STRING,:n                           BEST                = SCHED_WORK,:n     +
1                      ETC                 = SCHED_WORK - WORK_TODATE,:n      +
1                     ACTUAL_FINISH       = NULL:n                           W+
1HERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1233:
1           EXCEPTION:: SP_RJCT_ETC_WBS(234) :: cplan.sql(21282) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           SCHED_WORK	= SCHED_WO+
1RK,:n                           ETC			= SCHED_WORK - WORK_TODATE:n           +
1                WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1263:
1           EXCEPTION:: SP_RJCT_ETC_WBS(264) :: cplan.sql(21312) :: :
1ACTUAL_DURATION:
1UPDATE TASK_ASSIGNMENTS SET:n                        ETC					= PLANNED_WORK, +
1:n                        MILESTONE_PERCENT	= 0 ,:n                        AC+
1TUAL_FINISH		= NULL, :n                        ACTUAL_DURATION		= 0:n        +
1                WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1288:
1           EXCEPTION:: SP_RJCT_ETC_WBS(289) :: cplan.sql(21337) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                        FORECAST_START = NULL,:n+
1                        FORECAST_FINISH = NULL,:n                        FORE+
1CAST_DURATION = 0:n                        WHERE TSK_ASSIGNMENT_ID = h_tsk_as+
1signment_id:
1315:
1           EXCEPTION:: SP_RJCT_ETC_WBS(316) :: cplan.sql(21364) :: :
1UPDATE ACTIVITIES:n                           SET ETC_MODIFIED = 'N':n       +
1                    WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n          +
1                 AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n                       +
1    AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY:
1340:
1           EXCEPTION:: SP_RJCT_ETC_WBS(341) :: cplan.sql(21389) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           FORECAST_START = NULL+
1,:n                           FORECAST_FINISH = NULL,:n                      +
1     FORECAST_DURATION = 0,:n                           SCHED_WORK = CASE WHE+
1N PROPOSED_WORK > WORK_TODATE THEN PROPOSED_WORK ELSE SCHED_WORK END,:n      +
1                     ETC = CASE WHEN PROPOSED_WORK > WORK_TODATE THEN PROPOSE+
1D_WORK - WORK_TODATE ELSE 0 END/*,:n                           MILESTONE_PERC+
1ENT = (WORK_TODATE * 10000) / SCHED_WORK*/:n                           WHERE +
1TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1366:
1           EXCEPTION:: SP_RJCT_ETC_WBS(367) :: cplan.sql(21415) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           FORECAST_START = NULL+
1,:n                           FORECAST_FINISH = NULL,:n                      +
1     FORECAST_DURATION = 0,:n                           ETC = PLANNED_WORK, M+
1ILESTONE_PERCENT = 0:n                           WHERE TSK_ASSIGNMENT_ID = h_+
1tsk_assignment_id:
1390:
1           EXCEPTION:: SP_RJCT_ETC_WBS(391) :: cplan.sql(21439) :: :
1SC_SQL_NO_DATA:
1BITAND:
1>:
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000.00:
1<:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS SET:n                           ROLLUP_BITS = PMO_STP+
1U.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PERCENT_COMPLETE_BIT),:n                    +
1       ACTUAL_FINISH = CASE:n                           WHEN ACTUAL_FINISH IS+
1 NULL AND ETC = 0 THEN SCHED_FINISH:n                           ELSE ACTUAL_F+
1INISH:n                           END:n                           WHERE TSK_A+
1SSIGNMENT_ID = h_tsk_assignment_id:
1434:
1           EXCEPTION:: SP_RJCT_ETC_WBS(435) :: cplan.sql(21483) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           ACTUAL_FINISH = CASE +
1WHEN (ACTUAL_FINISH IS NULL) AND ETC = 0 THEN SCHED_FINISH ELSE ACTUAL_FINISH+
1 END:n                           WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_i+
1d:
1455:
1           EXCEPTION:: SP_RJCT_ETC_WBS(456) :: cplan.sql(21504) :: :
1FC_FIX_SUMMARY_TS:
1CLOSE:
1480:
1           EXCEPTION:: SP_RJCT_ETC_WBS(481) :: cplan.sql(21529) :: :
1CONSTRAINT_TYPE:
1TO_DATE:
1CONSTRAINT_DT:
1UPDATE TMT_WBS SET:n            CONSTRAINT_TYPE =:n            CASE:n        +
1    WHEN TO_DATE(SubStr(SCHED_START, 1, 10)) <> TO_DATE(SubStr(h_start_D, 1, +
110)) THEN 6:n            ELSE 0:n            END,:n            CONSTRAINT_DT +
1=:n            CASE:n            WHEN TO_DATE(SubStr(SCHED_START, 1, 10)) <> +
1TO_DATE(SubStr(h_start_D, 1, 10)) THEN SCHED_START:n            ELSE NULL:n  +
1          END:n            WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h+
1_task_id:
1512:
1           EXCEPTION:: SP_RJCT_ETC_WBS(513) :: cplan.sql(21561) :: :
1531:
1           EXCEPTION:: SP_RJCT_ETC_WBS(532) :: cplan.sql(21580) :: :
1FC_ROLLUP:
14:
1543:
1       RETURN_STATUS:: SP_RJCT_ETC_WBS(544) :: cplan.sql(21592) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1550:
1           EXCEPTION:: SP_RJCT_ETC_WBS(551) :: cplan.sql(21599) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1562:
1           EXCEPTION:: SP_RJCT_ETC_WBS(563) :: cplan.sql(21611) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
b48
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a0 f4 b4
bf c8 :35 a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :14 a0 12a
bd b7 11 a4 b1 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d :2 a0 d a0 51 d a0 6e
d :a a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a a0 7e b4 2e
:2 5a a 10 :3 a0 7e 6e b4 2e
:2 51 a5 b d a0 7e 51 b4
2e d :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 e9 dd b3
:6 a0 e9 d3 5 :2 a0 f :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 2b b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 51 d :8 a0 51 a5 b a5
b d b7 a0 3b b7 :2 19 3c
b7 :2 a0 e9 dd b3 :8 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c a0 51 d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 :2 51 a5 b 7e 6e b4 2e
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b :2 7e 51 b4 2e
b4 2e :4 a0 12a :17 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :8 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :2 a0 51 a5
b 7e 51 b4 2e :6 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 a0 :2 51
a5 b 7e 6e b4 2e :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :10 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :2 19 3c b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 51 d b7 19 3c a0
51 d :8 a0 51 a5 b a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :3 a0 51 a5 b 51 a5 b
5a 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :5 a0 a5 b 51 a5 b 7e
:3 a0 a5 b 51 a5 b b4 2e
5a 7e 51 b4 2e 5a 7e :2 a0
51 a5 b b4 2e a5 b d
a0 7e 51 b4 2e 5a a0 :2 7e
51 b4 2e b4 2e 52 10 :e a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :4 a0 a5 b d b7
19 3c b7 19 3c b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :14 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f 93 4f
b0 46 b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b :2 7e 51 b4 2e
b4 2e :3 a0 a5 b d b7 19
3c b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
b48
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 82 71
75 7d 70 9f 8d 6d 91 92
9a 8c bc aa 89 ae af b7
a9 d8 c7 cb d3 a6 f4 df
e3 e6 e7 ef c6 111 ff c3
103 104 10c fe 12e 11c fb 120
121 129 11b 14a 139 13d 118 145
138 166 155 159 135 161 154 182
171 175 151 17d 170 19e 18d 191
199 16d 1b9 1a5 1a9 1b1 1b4 18c
1d5 1c4 1c8 189 1d0 1c3 1f1 1e0
1e4 1c0 1ec 1df 20d 1fc 200 1dc
208 1fb 229 218 21c 1f8 224 217
245 234 238 214 240 233 261 250
254 230 25c 24f 27d 26c 270 24c
278 26b 29a 288 268 28c 28d 295
287 2b7 2a5 284 2a9 2aa 2b2 2a4
2d3 2c2 2c6 2a1 2ce 2c1 2ef 2de
2e2 2be 2ea 2dd 30b 2fa 2fe 2da
306 2f9 327 316 31a 322 2f6 312
32e 33f 340 343 347 34b 34f 353
357 35b 35f 363 367 36b 36f 373
377 37b 37f 383 387 38b 38f 393
397 39b 39f 3a3 3a7 3ab 3af 3b3
3b7 3bb 3bf 3c3 3c7 3cb 3cf 3d3
3d7 3db 3df 3e3 3e7 3eb 3ef 3f3
3f7 3fb 3ff 403 407 40b 40f 413
417 41b 427 42c 42e 43a 43e 440
444 455 456 459 45d 461 465 469
46d 471 475 479 47d 481 485 489
48d 491 495 499 49d 4a1 4a5 4a9
4ad 4b9 4be 4c0 4cc 4d0 4ee 4d6
4da 4de 4e1 4e9 4d5 4f5 4f9 4d2
4fd 501 505 508 50d 50e 1 510
515 519 51d 520 525 529 52d 530
535 536 538 53d 540 544 545 54a
54f 552 557 558 55d 560 564 565
56a 56d 572 573 578 57b 580 581
586 589 58d 591 595 596 598 59d
59e 5a0 5a1 5a6 5a9 5ae 5af 5b4
5b7 5bc 5bd 5c2 5c5 5c9 5ca 5cf
5d2 5d7 5d8 5dd 5e0 5e5 5e6 5eb
5ec 5f1 5f3 5f7 5fa 5fe 602 605
609 60d 610 613 618 61b 61e 621
622 627 628 1 62a 62f 633 637
63a 63f 644 647 64b 64c 651 652
657 659 65d 660 664 668 66c 670
674 678 67c 67f 683 687 68c 690
694 698 69c 6a0 6a4 6a8 6ac 6b0
6b4 6b8 6c4 6c8 6cc 6cf 6d3 6d7
6d9 6dd 6e1 6e5 6e8 6ec 6f0 6f2
6f3 6f8 1 6fc 700 704 707 70b
70f 713 717 71a 71e 722 725 728
72d 730 733 736 737 73c 73d 1
73f 744 748 74c 74f 754 759 75c
760 761 766 769 76e 76f 774 777
77c 77d 782 785 789 78a 78f 792
797 798 79d 7a0 7a4 7a8 7ab 7ae
7af 7b1 7b2 7b7 7b8 7bd 7bf 7c3
7c6 7c8 7cc 7ce 7da 7dc 7de 7df
7e4 7e8 7ea 7f6 7f8 7fc 800 803
807 80a 80e 811 812 817 81a 81e
821 822 827 82a 1 82d 832 836
83a 83e 841 846 847 84c 84f 852
853 855 859 85d 860 863 864 869
86d 871 875 879 87d 881 88d 891
895 898 89c 8a0 8a2 8a6 8aa 8ae
8b1 8b5 8b9 8bb 8bc 8c1 1 8c5
8c9 8cd 8d0 8d4 8d8 8dc 8e0 8e3
8e7 8eb 8ee 8f1 8f6 8f9 8fc 8ff
900 905 906 1 908 90d 911 915
918 91d 922 925 929 92a 92f 932
937 938 93d 940 945 946 94b 94e
952 953 958 95b 960 961 966 969
96d 971 974 977 978 97a 97b 980
981 986 988 98c 98f 991 995 997
9a3 9a5 9a7 9a8 9ad 9b1 9b3 9bf
9c1 9c5 9c9 9ce 9d2 9d3 9d7 9db
9df 9e3 9e7 9eb 9f0 9f5 9f9 9fd
a01 a06 a0a a0e a11 a14 a18 a1a
a1e a22 a25 a28 a2c a2e a32 a36
a39 a3d a41 a44 a48 a4b a4f a52
a53 a58 a5b a5f a65 a67 a6b a6e
a72 a76 a79 a7a a7c a7f a82 a83
a88 a8c a90 a93 a94 a96 a99 a9c
a9d aa2 aa6 aaa aae ab2 ab6 aba
abe ac2 ace ad2 ad7 adb ade adf
ae4 ae8 aec aef af2 af6 af8 afc
b00 b03 b06 b0a b0c b10 b14 b17
b19 b1d b21 b25 b28 b2c b30 b32
b33 b38 1 b3c b40 b44 b47 b4b
b4f b53 b57 b5a b5e b62 b65 b68
b6d b70 b73 b76 b77 b7c b7d 1
b7f b84 b88 b8c b8f b94 b99 b9c
ba0 ba1 ba6 ba9 bae baf bb4 bb7
bbc bbd bc2 bc5 bc9 bca bcf bd2
bd7 bd8 bdd be0 be4 be8 beb bee
bef bf1 bf2 bf7 bf8 bfd bff c03
c06 c08 c0c c0e c1a c1c c1e c1f
c24 c28 c2a c36 c38 c3c c3f c43
c47 c4b c4f c53 c57 c5b c5f c63
c66 c67 c69 c6a c6c c70 c72 c76
c7c c7e c82 c86 c89 c8b c8f c93
c98 c9c c9d ca1 ca5 ca9 cad cb1
cb5 cb9 cbd cc2 cc7 ccb ccf cd3
cd8 cdc ce0 ce3 ce6 cea cec cf0
cf4 cf7 cfa cfe d00 d04 d08 d0b
d0f d13 d16 d1a d1d d21 d24 d25
d2a d2d d31 d37 d39 d3d d40 d44
d47 d4b d4f d53 d56 d57 d59 d5c
d5f d60 d65 d69 d6d d70 d73 d74
d76 d79 d7e d7f d84 d88 d8c d90
d94 d98 d9c da0 da4 da8 db4 db8
dbd dc1 dc4 dc5 dca dce dd2 dd5
dd8 ddc dde de2 de6 de9 dec df0
df2 df6 dfa dfd dff e03 e07 e0b
e0e e12 e16 e18 e19 e1e 1 e22
e26 e2a e2d e31 e35 e39 e3d e40
e44 e48 e4b e4e e53 e56 e59 e5c
e5d e62 e63 1 e65 e6a e6e e72
e75 e7a e7f e82 e86 e87 e8c e8f
e94 e95 e9a e9d ea2 ea3 ea8 eab
eaf eb0 eb5 eb8 ebd ebe ec3 ec6
eca ece ed1 ed4 ed5 ed7 ed8 edd
ede ee3 ee5 ee9 eec eee ef2 ef4
f00 f02 f04 f05 f0a f0e f10 f1c
f1e f22 f26 f29 f2a f2c f2f f32
f35 f36 f3b f3c f41 f45 f49 f4d
f51 f5d f61 f65 f69 f6d f71 f75
f79 f7d f81 f85 f89 f8d f91 f95
f99 f9d fa1 fa5 fa9 fad fb1 fb5
fb9 fc5 fc9 fce fd2 fd5 fd6 fdb
fdf fe3 fe6 fe9 fed fef ff3 ff7
ffa ffd 1001 1003 1007 100b 100e 1010
1014 1018 101c 101f 1023 1027 1029 102a
102f 1 1033 1037 103b 103e 1042 1046
104a 104e 1051 1055 1059 105c 105f 1064
1067 106a 106d 106e 1073 1074 1 1076
107b 107f 1083 1086 108b 1090 1093 1097
1098 109d 10a0 10a5 10a6 10ab 10ae 10b3
10b4 10b9 10bc 10c0 10c1 10c6 10c9 10ce
10cf 10d4 10d7 10db 10df 10e2 10e5 10e6
10e8 10e9 10ee 10ef 10f4 10f6 10fa 10fd
10ff 1103 1105 1111 1113 1115 1116 111b
111f 1121 112d 112f 1131 1135 1139 113d
1141 1145 1149 114d 1151 115d 1161 1166
116a 116d 116e 1173 1177 117b 117e 1181
1185 1187 118b 118f 1192 1195 1199 119b
119f 11a3 11a6 11a8 11ac 11b0 11b4 11b7
11bb 11bf 11c1 11c2 11c7 1 11cb 11cf
11d3 11d6 11da 11de 11e2 11e6 11e9 11ed
11f1 11f4 11f7 11fc 11ff 1202 1205 1206
120b 120c 1 120e 1213 1217 121b 121e
1223 1228 122b 122f 1230 1235 1238 123d
123e 1243 1246 124b 124c 1251 1254 1258
1259 125e 1261 1266 1267 126c 126f 1273
1277 127a 127d 127e 1280 1281 1286 1287
128c 128e 1292 1295 1297 129b 129d 12a9
12ab 12ad 12ae 12b3 12b7 12b9 12c5 12c7
12c9 12cd 12d1 12d4 12d6 12da 12de 12e2
12e6 12ea 12ee 12f2 12f6 1302 1306 130b
130f 1312 1313 1318 131c 1320 1323 1326
132a 132c 1330 1334 1337 133a 133e 1340
1344 1348 134b 134d 1351 1355 1359 135c
1360 1364 1366 1367 136c 1 1370 1374
1378 137b 137f 1383 1387 138b 138e 1392
1396 1399 139c 13a1 13a4 13a7 13aa 13ab
13b0 13b1 1 13b3 13b8 13bc 13c0 13c3
13c8 13cd 13d0 13d4 13d5 13da 13dd 13e2
13e3 13e8 13eb 13f0 13f1 13f6 13f9 13fd
13fe 1403 1406 140b 140c 1411 1414 1418
141c 141f 1422 1423 1425 1426 142b 142c
1431 1433 1437 143a 143c 1440 1442 144e
1450 1452 1453 1458 145c 145e 146a 146c
146e 1472 1476 1479 147b 147f 1483 1486
1487 1489 148c 148f 1490 1495 1499 149d
14a1 14a5 14a9 14ad 14b9 14bd 14c2 14c6
14c9 14ca 14cf 14d3 14d7 14da 14dd 14e1
14e3 14e7 14eb 14ee 14f1 14f5 14f7 14fb
14ff 1502 1504 1508 150c 1510 1513 1517
151b 151d 151e 1523 1 1527 152b 152f
1532 1536 153a 153e 1542 1545 1549 154d
1550 1553 1558 155b 155e 1561 1562 1567
1568 1 156a 156f 1573 1577 157a 157f
1584 1587 158b 158c 1591 1594 1599 159a
159f 15a2 15a7 15a8 15ad 15b0 15b4 15b5
15ba 15bd 15c2 15c3 15c8 15cb 15cf 15d3
15d6 15d9 15da 15dc 15dd 15e2 15e3 15e8
15ea 15ee 15f1 15f3 15f7 15f9 1605 1607
1609 160a 160f 1613 1615 1621 1623 1625
1629 162d 1630 1633 1634 1636 1639 163e
163f 1644 1648 164c 1650 1654 1658 165c
1660 1664 1668 1674 1678 167d 1681 1684
1685 168a 168e 1692 1695 1698 169c 169e
16a2 16a6 16a9 16ac 16b0 16b2 16b6 16ba
16bd 16bf 16c3 16c7 16cb 16ce 16d2 16d6
16d8 16d9 16de 1 16e2 16e6 16ea 16ed
16f1 16f5 16f9 16fd 1700 1704 1708 170b
170e 1713 1716 1719 171c 171d 1722 1723
1 1725 172a 172e 1732 1735 173a 173f
1742 1746 1747 174c 174f 1754 1755 175a
175d 1762 1763 1768 176b 176f 1770 1775
1778 177d 177e 1783 1786 178a 178e 1791
1794 1795 1797 1798 179d 179e 17a3 17a5
17a9 17ac 17ae 17b2 17b4 17c0 17c2 17c4
17c5 17ca 17ce 17d0 17dc 17de 17e2 17e6
17ea 17ee 17f2 17f6 17fa 17fe 1802 1806
180a 180e 1812 1816 181a 181e 182a 182e
1833 1837 183a 183b 1840 1844 1848 184b
184e 1852 1854 1858 185c 185f 1862 1866
1868 186c 1870 1873 1875 1879 187d 1881
1884 1888 188c 188e 188f 1894 1 1898
189c 18a0 18a3 18a7 18ab 18af 18b3 18b6
18ba 18be 18c1 18c4 18c9 18cc 18cf 18d2
18d3 18d8 18d9 1 18db 18e0 18e4 18e8
18eb 18f0 18f5 18f8 18fc 18fd 1902 1905
190a 190b 1910 1913 1918 1919 191e 1921
1925 1926 192b 192e 1933 1934 1939 193c
1940 1944 1947 194a 194b 194d 194e 1953
1954 1959 195b 195f 1962 1964 1968 196a
1976 1978 197a 197b 1980 1984 1986 1992
1994 1996 199a 199e 19a2 19a6 19aa 19ae
19b2 19b6 19ba 19c6 19ca 19cf 19d3 19d6
19d7 19dc 19e0 19e4 19e7 19ea 19ee 19f0
19f4 19f8 19fb 19fe 1a02 1a04 1a08 1a0c
1a0f 1a11 1a15 1a19 1a1d 1a20 1a24 1a28
1a2a 1a2b 1a30 1 1a34 1a38 1a3c 1a3f
1a43 1a47 1a4b 1a4f 1a52 1a56 1a5a 1a5d
1a60 1a65 1a68 1a6b 1a6e 1a6f 1a74 1a75
1 1a77 1a7c 1a80 1a84 1a87 1a8c 1a91
1a94 1a98 1a99 1a9e 1aa1 1aa6 1aa7 1aac
1aaf 1ab4 1ab5 1aba 1abd 1ac1 1ac2 1ac7
1aca 1acf 1ad0 1ad5 1ad8 1adc 1ae0 1ae3
1ae6 1ae7 1ae9 1aea 1aef 1af0 1af5 1af7
1afb 1afe 1b00 1b04 1b06 1b12 1b14 1b16
1b17 1b1c 1b20 1b22 1b2e 1b30 1b32 1b36
1b3a 1b3d 1b3f 1b43 1b47 1b4a 1b4c 1b50
1b54 1b57 1b5b 1b5f 1b62 1b66 1b69 1b6d
1b70 1b71 1b76 1b79 1b7d 1b80 1b84 1b86
1b8a 1b8d 1b91 1b94 1b98 1b9c 1ba0 1ba4
1ba8 1bac 1bb0 1bb4 1bb8 1bbb 1bbc 1bbe
1bbf 1bc1 1bc5 1bc9 1bcd 1bd0 1bd1 1bd3
1bd6 1bd9 1bda 1bdf 1be3 1be7 1beb 1bee
1bef 1bf1 1bf4 1bf5 1bf7 1bfa 1bfd 1c00
1c01 1c06 1c09 1c0d 1c11 1c14 1c15 1c17
1c1a 1c1d 1c1e 1c23 1 1c26 1c2b 1c2f
1c33 1c37 1c3b 1c3f 1c40 1c42 1c45 1c46
1c48 1c4b 1c4f 1c53 1c57 1c58 1c5a 1c5d
1c5e 1c60 1c61 1c66 1c69 1c6c 1c6f 1c70
1c75 1c78 1c7b 1c7f 1c83 1c86 1c87 1c89
1c8a 1c8f 1c90 1c92 1c96 1c9a 1c9d 1ca0
1ca1 1ca6 1ca9 1cad 1cb0 1cb3 1cb6 1cb7
1cbc 1cbd 1 1cc2 1cc7 1ccb 1ccf 1cd3
1cd7 1cdb 1cdf 1ce3 1ce7 1ceb 1cef 1cf3
1cf7 1cfb 1cff 1d0b 1d0f 1d14 1d18 1d1b
1d1c 1d21 1d25 1d29 1d2c 1d2f 1d33 1d35
1d39 1d3d 1d40 1d43 1d47 1d49 1d4d 1d51
1d54 1d56 1d5a 1d5e 1d62 1d65 1d69 1d6d
1d6f 1d70 1d75 1 1d79 1d7d 1d81 1d84
1d88 1d8c 1d90 1d94 1d97 1d9b 1d9f 1da2
1da5 1daa 1dad 1db0 1db3 1db4 1db9 1dba
1 1dbc 1dc1 1dc5 1dc9 1dcc 1dd1 1dd6
1dd9 1ddd 1dde 1de3 1de6 1deb 1dec 1df1
1df4 1df9 1dfa 1dff 1e02 1e06 1e07 1e0c
1e0f 1e14 1e15 1e1a 1e1d 1e21 1e25 1e28
1e2b 1e2c 1e2e 1e2f 1e34 1e35 1e3a 1e3c
1e40 1e43 1e45 1e49 1e4b 1e57 1e59 1e5b
1e5c 1e61 1e65 1e67 1e73 1e75 1e77 1e7b
1e7f 1e83 1e87 1e8b 1e8f 1e93 1e97 1ea3
1ea7 1eac 1eb0 1eb3 1eb4 1eb9 1ebd 1ec1
1ec4 1ec7 1ecb 1ecd 1ed1 1ed5 1ed8 1edb
1edf 1ee1 1ee5 1ee9 1eec 1eee 1ef2 1ef6
1efa 1efd 1f01 1f05 1f07 1f08 1f0d 1
1f11 1f15 1f19 1f1c 1f20 1f24 1f28 1f2c
1f2f 1f33 1f37 1f3a 1f3d 1f42 1f45 1f48
1f4b 1f4c 1f51 1f52 1 1f54 1f59 1f5d
1f61 1f64 1f69 1f6e 1f71 1f75 1f76 1f7b
1f7e 1f83 1f84 1f89 1f8c 1f91 1f92 1f97
1f9a 1f9e 1f9f 1fa4 1fa7 1fac 1fad 1fb2
1fb5 1fb9 1fbd 1fc0 1fc3 1fc4 1fc6 1fc7
1fcc 1fcd 1fd2 1fd4 1fd8 1fdb 1fdd 1fe1
1fe3 1fef 1ff1 1ff3 1ff4 1ff9 1ffd 1fff
200b 200d 200f 2013 2017 201a 201e 2022
2026 202a 202b 202d 2031 2033 2037 203a
203c 2040 2043 2045 2049 2050 2054 2058
205d 205f 2063 2067 206a 206e 2072 2074
2078 207c 2080 2083 2087 208b 208d 208e
2093 1 2097 209b 209f 20a2 20a6 20aa
20ae 20b2 20b5 20b9 20bd 20c0 20c3 20c8
20cb 20ce 20d1 20d2 20d7 20d8 1 20da
20df 20e3 20e7 20ea 20ef 20f4 20f7 20fb
20fc 2101 2104 2109 210a 210f 2112 2117
2118 211d 2120 2124 2125 212a 212d 2132
2133 2138 213b 213f 2143 2146 2149 214a
214c 214d 2152 2153 2158 215a 215e 2161
2163 2167 2169 2175 2177 2179 217a 217f
2183 2185 2191 2193 2195 2199 219d 21a0
21a4 21a8 21ac 21b0 21b4 21b8 21bc 21c0
21c4 21c8 21cc 21d0 21d4 21d8 21dc 21e0
21e4 21e8 21ec 21f0 21fc 2200 2205 2209
220c 220d 2212 2216 221a 221d 2220 2224
2226 222a 222e 2231 2234 2238 223a 223e
2242 2245 2247 224b 224f 2253 2256 225a
225e 2260 2261 2266 1 226a 226e 2272
2275 2279 227d 2281 2285 2288 228c 2290
2293 2296 229b 229e 22a1 22a4 22a5 22aa
22ab 1 22ad 22b2 22b6 22ba 22bd 22c2
22c7 22ca 22ce 22cf 22d4 22d7 22dc 22dd
22e2 22e5 22ea 22eb 22f0 22f3 22f7 22f8
22fd 2300 2305 2306 230b 230e 2312 2316
2319 231c 231d 231f 2320 2325 2326 232b
232d 2331 2334 2336 233a 233c 2348 234a
234c 234d 2352 2356 2358 2364 2366 236e
2370 2371 2374 2376 237a 2381 2385 2389
238e 2390 2394 2398 239b 239f 23a3 23a5
23a9 23ad 23b1 23b4 23b8 23bc 23be 23bf
23c4 1 23c8 23cc 23d0 23d3 23d7 23db
23df 23e3 23e6 23ea 23ee 23f1 23f4 23f9
23fc 23ff 2402 2403 2408 2409 1 240b
2410 2414 2418 241b 2420 2425 2428 242c
242d 2432 2435 243a 243b 2440 2443 2448
2449 244e 2451 2455 2456 245b 245e 2463
2464 2469 246c 2470 2474 2477 247a 247b
247d 247e 2483 2484 2489 248b 248f 2492
2494 2498 249a 24a6 24a8 24aa 24ab 24b0
24b4 24b6 24c2 24c4 24c8 24cc 24cf 24d0
24d2 24d5 24d8 24db 24dc 24e1 24e2 24e7
24eb 24ef 24f3 24f4 24f6 24fa 24fc 2500
2503 2505 2509 250c 2510 2514 2517 251b
251f 2522 2525 252a 252d 2530 2533 2534
2539 253a 1 253c 2541 2545 2549 254c
2551 2556 2559 255d 255e 2563 2566 256b
256c 2571 2574 2579 257a 257f 2582 2586
258a 258e 2592 2595 2596 2598 259d 259e
25a0 25a1 25a6 25a9 25ae 25af 25b4 25b7
25bc 25bd 25c2 25c5 25c9 25ca 25cf 25d2
25d7 25d8 25dd 25de 25e3 25e5 25e9 25ec
25f0 25f4 25f7 25fb 25ff 2602 2606 260a
260b 2610 2612 2616 261a 261d 2621 2625
2628 262c 2630 2633 2636 263b 263e 2641
2644 2645 264a 264b 1 264d 2652 2656
265a 265d 2662 2667 266a 266e 266f 2674
2675 267a 267e 2682 2685 268a 268f 2692
2696 269a 269d 269e 26a3 26a6 26ab 26ac
26b1 26b4 26b8 26bc 26bf 26c0 26c5 26c6
26cb 26cd 26d1 26d4 26d8 26dc 26e0 26e4
26e8 26ec 26f0 26f4 26f8 2704 2709 270d
2711 2715 2719 271b 271c 2721 1 2725
2729 272d 2730 2734 2738 273c 2740 2743
2747 274b 274e 2751 2756 2759 275c 275f
2760 2765 2766 1 2768 276d 2771 2775
2778 277d 2782 2785 2789 278a 278f 2790
2795 2799 279d 27a0 27a5 27aa 27ad 27b1
27b2 27b7 27ba 27bf 27c0 27c5 27c8 27cc
27d0 27d3 27d6 27d7 27d9 27da 27df 27e0
27e5 27e7 27eb 27ee 27f2 27f6 27fa 27fe
2802 2806 280a 2816 281b 281f 2823 2827
282b 282d 2831 2833 283f 2841 2843 2844
2849 284d 284f 285b 285f 2861 2862 286b 
b48
2
0 1 a 6 9 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 :3 12 :2 4 11 1a 19 :2 11 :2 4
b 14 13 :2 b :2 4 :3 11 :2 4 e
17 16 :2 e :2 4 18 21 20 :2 18
:2 4 f 18 17 :2 f :2 4 :2 e 1d
e :2 4 :2 d 1c d :2 4 :2 b 1a
b :2 4 :3 e :2 4 :2 14 23 14 :2 4
:2 f 1e f :2 4 :2 15 24 15 :2 4
:2 12 21 12 :2 4 :2 11 20 11 :2 4
:2 12 21 12 :2 4 :2 13 22 13 :2 4
:2 1a 29 1a :2 4 f 18 17 :2 f
:2 4 f 18 17 :2 f :2 4 :2 f 1e
f :2 4 :2 11 20 11 :2 4 :2 12 2a
12 :2 4 :3 17 4 7 e 0 :2 7
11 1d 2a 14 30 41 14 31
43 f 10 1d 2e 38 43 4f
58 60 69 77 80 8e 97 a5
ae bb c4 d5 de f1 fa 10f
118 133 13c 154 15d 16e 177 189
192 1aa 1b3 1c6 1cf 11 1e 38
45 54 64 e 2c a :6 7 e
0 :2 7 11 24 2e 34 3f 4d
5a f 10 1d e 18 11 1c
34 3f 4c 5c e 2c a :5 7
4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 57 5d 60 :2 57 6e 87
8 :2 6e d 10 :2 6e 13 16 :2 6e
b e :2 6e 13 16 1f 27 :2 1f
34 :2 16 :2 6e b e :2 6e 13 16
:2 6e 1b 1e :2 6e 2a 2d :2 6e 32
35 :2 6e :2 7 4d :2 4 7 :2 11 23
:2 2d 39 3c 4f 51 52 :2 4f :2 23
:3 7 :2 d 12 1e 60 63 :2 1e :2 7
55 :3 4 11 :2 4 12 :2 4 12 :2 4
12 4 e 1a 20 27 c 1a
22 c 1a 27 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 56 58 59 :2 56 :2 29
:3 d :2 13 18 24 66 69 :2 24 76
79 :2 24 7d 80 :2 24 8c 8f :2 24
97 9a :2 24 a6 a9 b0 b9 bc
:2 a9 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 :4 3b 3a 39 :3 7 11 18 1f
22 :2 18 27 2a :2 11 :2 7 13 14
:2 13 7 11 28 37 45 52 :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 59 5c
5d :2 59 :2 2c :3 10 :2 16 1b 27 6a
6d :2 27 7a 7d :2 27 81 84 :2 27
90 93 :2 27 9b 9e :2 27 aa ad
b4 bd c0 :2 ad :2 27 :2 10 60 :2 d
:2 a :4 16 :2 a 7 :3 50 7 c :4 7
10 1d 28 32 40 :3 a d 15
:2 d :2 16 22 d 1b d :2 16 22
d :4 a e :2 17 23 20 :2 2c :2 20
:3 d 3c :2 a d 16 20 :2 d 23
25 :2 23 10 19 24 :2 10 27 29
:2 27 1a :3 13 19 26 37 44 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 62 65 66 :2 62 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 99 9c :2 30 a4 a7
:2 30 b3 b6 bd c6 c9 :2 b6 :2 30
:2 19 69 :2 16 :2 13 :4 1f :2 13 10 :3 2b
10 20 :2 10 29 38 44 4f 5b
67 29 37 :2 67 :2 29 10 2b 15
10 :4 d 27 d 12 :4 d 16 23
38 44 50 5e 6d :3 10 13 1b
:2 13 :2 1c 28 13 21 13 :2 1c 28
13 :4 10 14 :2 1d 29 26 :2 32 :2 26
:3 13 42 :3 10 24 10 13 1c 27
:2 13 2a 2c :2 2a 16 1d 29 2c
:2 16 2f 31 :2 2f 20 1d 1f 33
1d 32 1d 27 30 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 68
6b 6c :2 68 :2 3b :3 1f :2 25 2a 36
79 7c :2 36 89 8c :2 36 90 93
:2 36 9f a2 :2 36 aa ad :2 36 b9
bc c3 cc cf :2 bc :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :3 35 19 22
2e :2 19 31 33 34 :2 33 :2 31 20
21 22 36 19 23 1c 32 1c
32 1c 32 1c 32 1c 32 1c
32 1c 32 1c 32 1c 32 3f
1c 22 36 1c 23 1f 2b :3 29
1f :2 28 34 1f 30 1f :2 28 34
1f :4 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 6b 6e 6f
:2 6b :2 3e :3 22 :2 28 2d 39 7c 7f
:2 39 8c 8f :2 39 93 96 :2 39 a2
a5 :2 39 ad b0 :2 39 bc bf c6
cf d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c
:4 28 :2 1c 19 :4 36 23 1c 29 1c
24 31 22 36 1c 23 1f 2b
:3 29 1f :2 28 34 1f 30 1f :2 28
34 1f :4 1c 19 21 1f :2 28 34
1f 2f :2 1c :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 6b 6e
6f :2 6b :2 3e :3 22 :2 28 2d 39 7c
7f :2 39 8c 8f :2 39 93 96 :2 39
a2 a5 :2 39 ad b0 :2 39 bc bf
c6 cf d2 :2 bf :2 39 :2 22 72 :2 1f
:2 1c :4 28 :2 1c 19 :7 16 35 20 19
23 :3 19 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 68 6b
6c :2 68 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :7 13 2e 16 1f
2a :2 16 2d 2f :2 2d 20 :3 19 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 68 6b 6c :2 68 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :4 31 19 20 2c 2f :2 19 32
34 :2 32 23 20 22 36 20 35
20 2a 33 1c 23 1f 2b :3 29
1f :2 28 34 1f 30 1f :2 28 34
1f :4 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 6b 6e 6f
:2 6b :2 3e :3 22 :2 28 2d 39 7c 7f
:2 39 8c 8f :2 39 93 96 :2 39 a2
a5 :2 39 ad b0 :2 39 bc bf c6
cf d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c
:4 28 :2 1c 19 :3 38 23 :4 1c 33 43
54 67 1c 2c 3c 4d 5d 22
36 1c 23 1f 2b :3 29 1f :2 28
34 1f 30 1f :2 28 34 1f :4 1c
19 21 1f :2 28 34 1f 2f :2 1c
:2 21 1f :2 28 34 1f 22 :2 2c 3e
:2 48 54 58 6b 6e 6f :2 6b :2 3e
:3 22 :2 28 2d 39 7c 7f :2 39 8c
8f :2 39 93 96 :2 39 a2 a5 :2 39
ad b0 :2 39 bc bf c6 cf d2
:2 bf :2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c
19 :4 38 23 :4 1c 22 30 22 36
1c 23 1f 2b :3 29 1f :2 28 34
1f 30 1f :2 28 34 1f :4 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6b 6e 6f :2 6b :2 3e :3 22
:2 28 2d 39 7c 7f :2 39 8c 8f
:2 39 93 96 :2 39 a2 a5 :2 39 ad
b0 :2 39 bc bf c6 cf d2 :2 bf
:2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c 19
:7 16 :4 13 :4 10 14 :2 1d 28 26 :2 31
:2 26 :2 13 27 13 41 :3 10 20 :2 10
29 38 44 59 65 2b 34 42
:2 2b :2 29 10 13 1c 2e :2 13 31
33 :2 31 18 1f 28 33 :2 1f 37
:2 18 17 3b 3d :2 3b 16 45 4e
5e :2 45 61 63 :2 61 44 :3 16 2c
34 3d 47 :2 3d 57 :2 34 5a 5c
28 32 :2 28 41 :2 5c :2 34 33 45
47 :2 33 32 51 53 28 38 :2 53
:2 32 :2 2c 16 1a 2d 2f :2 2d 19
35 48 4a 4b :2 4a :2 48 :2 19 23
1c 2a 33 3a 46 4f 1c 21
3b 48 21 22 36 1c 23 1f
2b :3 29 1f :2 28 34 1f 30 1f
:2 28 34 1f :4 1c 19 21 1f :2 28
34 1f 2f :2 1c :2 21 1f :2 28 34
1f 22 :2 2c 3e :2 48 54 58 6b
6e 6f :2 6b :2 3e :3 22 :2 28 2d 39
7c 7f :2 39 8c 8f :2 39 93 96
:2 39 a2 a5 :2 39 ad b0 :2 39 bc
bf c6 cf d2 :2 bf :2 39 :2 22 72
:2 1f :2 1c :4 28 :2 1c 19 :4 4d 23 1c
37 52 5f 71 22 36 1c 23
1f 2b :3 29 1f :2 28 34 1f 30
1f :2 28 34 1f :4 1c 19 21 1f
:2 28 34 1f 2f :2 1c :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
6b 6e 6f :2 6b :2 3e :3 22 :2 28 2d
39 7c 7f :2 39 8c 8f :2 39 93
96 :2 39 a2 a5 :2 39 ad b0 :2 39
bc bf c6 cf d2 :2 bf :2 39 :2 22
72 :2 1f :2 1c :4 28 :2 1c 19 :8 16 29
3b 49 :2 29 16 66 :2 13 35 :2 10
d 11 a 10 16 :3 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5f 62 63 :2 5f
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 96 99
:2 2d a1 a4 :2 2d b0 b3 ba c3
c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c
:2 10 d :7 a 14 d 12 1a 21
39 41 48 d 12 1a 21 39
41 48 60 13 20 31 3e d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5c 5f 60 :2 5c :2 2f :3 13 :2 19
1e 2a 6d 70 :2 2a 7d 80 :2 2a
84 87 :2 2a 93 96 :2 2a 9e a1
:2 2a ad b0 b7 c0 c3 :2 b0 :2 2a
:2 13 63 :2 10 :2 d :4 19 :2 d a :3 7
c a :3 7 b 50 a 10 :3 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 59 5c
5d :2 59 :2 2c :3 10 :2 16 1b 27 6a
6d :2 27 7a 7d :2 27 81 84 :2 27
90 93 :2 27 9b 9e :2 27 aa ad
b4 bd c0 :2 ad :2 27 :2 10 60 :2 d
:2 a :4 16 :2 a 7 :3 50 a 13 1d
:2 a 20 22 23 :2 22 :2 20 a 1d
27 :2 1d a 25 :2 7 50 :2 4 7
:2 11 23 :2 2d 39 3c 4f 52 53
:2 4f :2 23 :3 7 :2 d 12 1e 61 64
:2 1e 71 74 :2 1e 78 7b :2 1e 85
88 91 99 :2 a2 :2 91 ad :2 88 :2 1e
b5 b8 :2 1e c0 c3 :2 1e c8 cb
:2 1e ce d1 :2 1e :2 7 56 :3 4 :2 f
21 :2 2a 34 38 :2 4 1 9 12
9 a :2 14 26 :2 30 3c 40 53
56 57 :2 53 :2 26 :3 a :2 10 15 21
64 67 :2 21 :3 a :2 10 15 39 5c
5f :2 68 :2 39 76 79 :2 39 81 84
:2 8d :2 39 :2 a 5a :3 7 c 15 1e
2c a 13 1e f e 7 e
7 e 7 29 :2 4 :2 9 7 :2 10
1c :2 7 :2 11 23 :2 2d 39 3d 50
53 54 :2 50 :2 23 :3 7 :2 d 12 1e
61 64 :2 1e :3 7 :2 d 12 36 42
45 :2 36 4d 50 :2 36 5c 5f 66
6f 72 :2 5f :2 36 :2 7 57 :2 4 7
c 1b a 13 1e f e 7
e 7 e 7 :2 4 :4 10 :2 4 :8 1

b48
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:5 8 :7 9 :7 a :5 b
:7 c :7 d :7 e :6 f
:6 10 :6 11 :5 12 :6 13
:6 14 :6 15 :6 16 :6 17
:6 18 :6 19 :6 1a :7 1b
:7 1c :6 1d :6 1e :6 1f
:5 20 :2 22 0 :2 22
:3 23 :3 24 :3 25 26
:23 27 :6 28 :2 29 23
:5 22 :2 2b 0 :2 2b
:7 2c 2d :2 2e :2 2f
:6 30 :2 31 2c :5 2b
:7 33 :b 35 :11 36 37
:2 36 :2 37 :2 36 :2 37
:2 36 :2 38 :2 36 :9 38
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :4 36 :3 35
:11 3c :b 3d :3 3c :3 43
:3 46 :3 47 :3 48 :4 4b
:3 4c :3 4d 4b :5 4e
4a 50 :5 51 :3 50
:2 52 :5 54 :11 55 :24 56
:3 55 :2 53 :6 52 4f
:3 34 :12 5c :c 5d :6 5e
:6 61 :5 62 60 64
:5 65 :3 64 :2 66 :5 68
:11 69 :24 6a :3 69 :2 67
:6 66 63 :3 5c :5 6f
71 :8 72 :3 73 :5 74
73 :5 76 75 :3 73
:a 79 :2 7a :3 79 :9 7e
:9 80 83 84 85
86 :4 87 83 :6 88
:5 89 88 :5 8b 8a
:3 88 82 8e :5 8f
:3 8e :2 90 :5 92 :11 93
:24 94 :3 93 :2 91 :6 90
8d :3 80 :3 9a :7 9b
:2 9c :5 9b 80 :2 9e
9d :3 80 7e :5 a3
a5 :a a6 :3 a7 :5 a8
a7 :5 aa a9 :3 a7
:a ad :2 ae :3 ad :3 b2
:9 b3 :a b4 b6 b7
:2 b8 :2 b9 :3 ba b6
:6 bb :5 bc bb :5 be
bd :3 bb b5 c1
:5 c2 :3 c1 :2 c3 :5 c5
:11 c6 :24 c7 :3 c6 :2 c4
:6 c3 c0 :3 b4 :c cc
cd ce :2 cf cd
d2 :2 d3 :2 d4 :2 d5
:2 d6 :2 d7 :2 d8 :2 d9
:2 da :3 db dc :2 dd
d2 :6 de :5 df de
:5 e1 e0 :3 de d1
e4 :5 e5 :3 e4 :2 e6
:5 e8 :11 e9 :24 ea :3 e9
:2 e7 :6 e6 e3 :4 cc
f8 :2 f9 :3 fa :2 fb
f8 :6 fc :5 fd fc
:5 ff fe :3 fc f7
102 :5 103 :3 102 :2 104
:5 106 :11 107 :24 108 :3 107
:2 105 :6 104 101 :4 ee
:3 cc b4 10f :2 110
111 112 113 :2 114
10f :6 115 :5 116 115
:5 118 117 :3 115 10e
11b :5 11c :3 11b :2 11d
:5 11f :11 120 :24 121 :3 120
:2 11e :6 11d 11a :4 10d
:3 b4 b3 :9 128 12b
12c 12d 12e :2 12f
12b :6 130 :5 131 130
:5 133 132 :3 130 12a
136 :5 137 :3 136 :2 138
:5 13a :11 13b :24 13c :3 13b
:2 139 :6 138 135 :4 128
:a 142 144 145 :2 146
:2 147 :3 148 144 :6 149
:5 14a 149 :5 14c 14b
:3 149 143 14f :5 150
:3 14f :2 151 :5 153 :11 154
:24 155 :3 154 :2 152 :6 151
14e :3 142 15b 15c
15d 15e :5 15f :5 160
:2 162 15b :6 163 :5 164
163 :5 166 165 :3 163
15a 169 :5 16a :3 169
:2 16b :5 16d :11 16e :24 16f
:3 16e :2 16c :6 16b 168
:4 142 175 176 177
178 :3 179 :2 17a 175
:6 17b :5 17c 17b :5 17e
17d :3 17b 174 181
:5 182 :3 181 :2 183 :5 185
:11 186 :24 187 :3 186 :2 184
:6 183 180 :4 173 :3 142
140 :3 128 127 :3 b3
:a 18f :3 190 :3 18f :3 194
:6 195 :5 196 :3 195 :9 199
:1b 19a :c 19b :5 19c :5 19b
:2 19c :3 19b :2 19c :2 19d
:2 19c :5 19b :10 19e 1a0
:6 1a1 1a2 :3 1a3 1a4
:2 1a6 1a0 :6 1a7 :5 1a8
1a7 :5 1aa 1a9 :3 1a7
19f 1ad :5 1ae :3 1ad
:2 1af :5 1b1 :11 1b2 :24 1b3
:3 1b2 :2 1b0 :6 1af 1ac
:4 19e 1b9 :5 1ba :2 1bb
1b9 :6 1bc :5 1bd 1bc
:5 1bf 1be :3 1bc 1b8
1c2 :5 1c3 :3 1c2 :2 1c4
:5 1c6 :11 1c7 :24 1c8 :3 1c7
:2 1c5 :6 1c4 1c1 :4 1b7
:3 19e :7 1d1 :3 19a :3 199
a5 1d4 a0 :4 1d8
:5 1d9 1d7 1db :5 1dc
:3 1db :2 1dd :5 1df :11 1e0
:24 1e1 :3 1e0 :2 1de :6 1dd
1da :4 a0 :3 7e 1e9
1ea :6 1ec 1ef :7 1f1
:4 1f4 1e9 :6 1f5 :5 1f6
1f5 :5 1f8 1f7 :3 1f5
1e8 1fb :5 1fc :3 1fb
:2 1fd :5 1ff :11 200 :24 201
:3 200 :2 1fe :6 1fd 1fa
:3 71 205 206 :3 71
207 5c :4 20b :5 20c
20a 20e :5 20f :3 20e
:2 210 :5 212 :11 213 :24 214
:3 213 :2 211 :6 210 20d
:3 5c :c 219 :6 21a :3 219
:3 5c :11 21f :30 220 :3 21f
:a 222 34 :3 225 :11 226
:b 227 :17 228 :3 226 :2 22a
:3 22b :3 22c 22d 22b
22a 22b :3 22e :3 225
:2 22f :5 231 :11 232 :b 233
:18 234 :3 232 :2 236 237
:3 238 239 237 236
237 :3 23a :2 230 :6 22f
224 :7 1 
286d
4
:3 0 1 :3 0 2
:a 0 b43 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 b43 2 14
:2 0 e :2 0 d
c :3 0 17 :7 0
1a 18 0 b41
0 b :6 0 10
:2 0 11 4 :3 0
f 1c 1e :6 0
21 1f 0 b41
0 d :6 0 17
c3 0 15 4
:3 0 13 23 25
:6 0 28 26 0
b41 0 f :6 0
e :2 0 1b c
:3 0 2a :7 0 2d
2b 0 b41 0
11 :6 0 4 :3 0
e :2 0 19 2f
31 :6 0 34 32
0 b41 0 12
:6 0 15 :2 0 1f
4 :3 0 1d 36
38 :6 0 3b 39
0 b41 0 13
:6 0 17 :2 0 23
4 :3 0 21 3d
3f :6 0 42 40
0 b41 0 14
:6 0 17 :2 0 25
6 :3 0 44 :7 0
48 45 46 b41
0 16 :6 0 17
:2 0 27 6 :3 0
4a :7 0 4e 4b
4c b41 0 18
:6 0 2b 189 0
29 6 :3 0 50
:7 0 54 51 52
b41 0 19 :6 0
17 :2 0 2d 1b
:3 0 56 :7 0 59
57 0 b41 0
1a :6 0 6 :3 0
5b :7 0 17 :2 0
5f 5c 5d b41
0 1c :6 0 17
:2 0 2f 6 :3 0
61 :7 0 65 62
63 b41 0 1d
:6 0 17 :2 0 31
6 :3 0 67 :7 0
6b 68 69 b41
0 1e :6 0 17
:2 0 33 6 :3 0
6d :7 0 71 6e
6f b41 0 1f
:6 0 17 :2 0 35
6 :3 0 73 :7 0
77 74 75 b41
0 20 :6 0 17
:2 0 37 6 :3 0
79 :7 0 7d 7a
7b b41 0 21
:6 0 17 :2 0 39
6 :3 0 7f :7 0
83 80 81 b41
0 22 :6 0 e
:2 0 3b 6 :3 0
85 :7 0 89 86
87 b41 0 23
:6 0 e :2 0 3f
4 :3 0 3d 8b
8d :6 0 90 8e
0 b41 0 24
:6 0 17 :2 0 43
4 :3 0 41 92
94 :6 0 97 95
0 b41 0 25
:6 0 17 :2 0 45
6 :3 0 99 :7 0
9d 9a 9b b41
0 26 :6 0 17
:2 0 47 6 :3 0
9f :7 0 a3 a0
a1 b41 0 27
:6 0 4b 312 0
49 6 :3 0 a5
0 2 :5 0 a9
a6 a7 b41 0
28 :6 0 2a :3 0
6 :3 0 ab :7 0
ae ac 0 b41
0 29 :6 0 2b
:a 0 2 ea :5 0
b0 b3 0 b1
:3 0 2c :3 0 2d
:3 0 2e :3 0 2f
:3 0 30 :3 0 2f
:3 0 31 :3 0 32
:3 0 31 :3 0 33
:3 0 34 :3 0 d
:3 0 35 :3 0 f
:3 0 36 :3 0 37
:3 0 38 :3 0 37
:3 0 39 :3 0 37
:3 0 3a :3 0 37
:3 0 3b :3 0 37
:3 0 3c :3 0 37
:3 0 3d :3 0 37
:3 0 3e :3 0 37
:3 0 3f :3 0 37
:3 0 40 :3 0 37
:3 0 41 :3 0 37
:3 0 42 :3 0 37
:3 0 43 :3 0 37
:3 0 44 :3 0 37
:3 0 45 :3 0 37
:3 0 46 :3 0 2d
:3 0 2e :3 0 2d
:3 0 2e :3 0 47
:3 0 48 :3 0 2f
:3 0 31 :4 0 49
1 :8 0 eb b0
b3 ec 0 b41
4d ec ee eb
ed :6 0 ea :7 0
ec 2a :3 0 4a
:a 0 3 109 :5 0
f0 f3 0 f1
:3 0 4b :3 0 4c
:3 0 4d :3 0 4e
:3 0 4f :3 0 47
:3 0 50 :3 0 51
:3 0 34 :3 0 d
:3 0 52 :3 0 12
:3 0 4e :3 0 4f
:3 0 4e :3 0 4f
:3 0 47 :3 0 48
:3 0 2f :3 0 31
:4 0 53 1 :8 0
10a f0 f3 10b
0 b41 4f 10b
10d 10a 10c :6 0
109 :7 0 10b 115
116 0 51 9
:3 0 a :2 0 4
10f 110 0 111
:7 0 114 112 0
b41 0 54 :6 0
55 :3 0 56 :3 0
55 :3 0 57 :3 0
118 119 0 2
:4 0 53 11a 11c
117 11e 11d :2 0
58 :3 0 59 :3 0
120 121 0 5a
:4 0 55 :3 0 5b
:3 0 124 125 0
2 :4 0 55 126
128 5c :4 0 5d
:2 0 5e :3 0 57
12b 12d :3 0 5f
:4 0 5d :2 0 60
:4 0 5a 130 132
:3 0 5d :2 0 3
:3 0 5d 134 136
:3 0 5d :2 0 60
:4 0 60 138 13a
:3 0 5d :2 0 61
:4 0 63 13c 13e
:3 0 5d :2 0 62
:3 0 63 :3 0 5
:3 0 66 142 144
64 :4 0 68 141
147 6b 140 149
:3 0 5d :2 0 61
:4 0 6e 14b 14d
:3 0 5d :2 0 60
:4 0 71 14f 151
:3 0 5d :2 0 7
:3 0 74 153 155
:3 0 5d :2 0 60
:4 0 77 157 159
:3 0 5d :2 0 65
:4 0 7a 15b 15d
:3 0 7d 122 15f
:2 0 161 82 162
11f 161 0 163
84 0 aa1 55
:3 0 56 :3 0 164
165 0 55 :3 0
66 :3 0 167 168
0 15 :2 0 2
:4 0 67 :2 0 68
:2 0 15 :2 0 86
16d 16f :3 0 89
169 171 166 173
172 :2 0 58 :3 0
69 :3 0 175 176
0 5a :4 0 6a
:4 0 5d :2 0 5e
:3 0 8d 17a 17c
:3 0 90 177 17e
:2 0 180 93 181
174 180 0 182
95 0 aa1 16
:3 0 5 :3 0 183
184 0 aa1 25
:3 0 7 :3 0 186
187 0 aa1 26
:3 0 6b :2 0 189
18a 0 aa1 24
:3 0 6c :4 0 18c
18d 0 aa1 34
:3 0 6d :3 0 35
:3 0 36 :3 0 d
:3 0 f :3 0 19
:3 0 33 :3 0 2c
:3 0 3 :4 0 6e
1 :8 0 19f 9
:3 0 6f :3 0 19a
19b 0 70 :3 0
19c 19d 0 19f
97 1f2 71 :3 0
9 :3 0 6f :3 0
1a1 1a2 0 70
:3 0 1a3 1a4 0
1a6 9a 1a8 9c
1a7 1a6 :2 0 1f0
72 :3 0 9 :3 0
6f :3 0 1ab 1ac
0 70 :3 0 1ad
1ae 0 1e8 55
:3 0 56 :3 0 1b0
1b1 0 55 :3 0
66 :3 0 1b3 1b4
0 73 :2 0 2
:4 0 74 :2 0 68
:2 0 15 :2 0 9e
1b9 1bb :3 0 a1
1b5 1bd 1b2 1bf
1be :2 0 58 :3 0
69 :3 0 1c1 1c2
0 5a :4 0 75
:4 0 5d :2 0 5e
:3 0 a5 1c6 1c8
:3 0 5d :2 0 76
:4 0 a8 1ca 1cc
:3 0 5d :2 0 77
:4 0 ab 1ce 1d0
:3 0 5d :2 0 70
:3 0 ae 1d2 1d4
:3 0 5d :2 0 78
:4 0 b1 1d6 1d8
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 b4
1db 1df b8 1da
1e1 :3 0 bb 1c3
1e3 :2 0 1e5 be
1e6 1c0 1e5 0
1e7 c0 0 1e8
c2 1eb :3 0 1eb
0 1eb 1ea 1e8
1e9 :6 0 1ed 4
:3 0 c5 1ef c7
1ee 1ed :2 0 1f0
c9 :2 0 1f2 0
1f2 1f1 19f 1f0
:6 0 aa1 1 :3 0
9 :3 0 6f :3 0
1f4 1f5 0 9
:3 0 7c :2 0 7d
:3 0 1f7 1f9 0
ce 1f8 1fb :3 0
1fc :2 0 19 :3 0
7e :2 0 d1 1ff
200 :3 0 201 :2 0
202 :2 0 1fd 204
203 :2 0 f :3 0
79 :3 0 f :3 0
5d :2 0 7f :4 0
d3 209 20b :3 0
15 :2 0 10 :2 0
d6 207 20f 206
210 0 a50 18
:3 0 80 :2 0 15
:2 0 da 213 215
:3 0 212 216 0
a50 81 :3 0 1a
:3 0 33 :3 0 2c
:3 0 d :4 0 82
1 :8 0 223 9
:3 0 6f :3 0 21e
21f 0 70 :3 0
220 221 0 223
dc 276 71 :3 0
9 :3 0 6f :3 0
225 226 0 70
:3 0 227 228 0
22a df 22c e1
22b 22a :2 0 274
72 :3 0 9 :3 0
6f :3 0 22f 230
0 70 :3 0 231
232 0 26c 55
:3 0 56 :3 0 234
235 0 55 :3 0
66 :3 0 237 238
0 73 :2 0 2
:4 0 83 :2 0 68
:2 0 15 :2 0 e3
23d 23f :3 0 e6
239 241 236 243
242 :2 0 58 :3 0
69 :3 0 245 246
0 5a :4 0 84
:4 0 5d :2 0 5e
:3 0 ea 24a 24c
:3 0 5d :2 0 76
:4 0 ed 24e 250
:3 0 5d :2 0 77
:4 0 f0 252 254
:3 0 5d :2 0 70
:3 0 f3 256 258
:3 0 5d :2 0 78
:4 0 f6 25a 25c
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 f9
25f 263 fd 25e
265 :3 0 100 247
267 :2 0 269 103
26a 244 269 0
26b 105 0 26c
107 26f :3 0 26f
0 26f 26e 26c
26d :6 0 271 6
:3 0 10a 273 10c
272 271 :2 0 274
10e :2 0 276 0
276 275 223 274
:6 0 a50 1 :3 0
85 :3 0 2b :4 0
27b :2 0 a50 279
27c :3 0 86 :3 0
2b :3 0 12 :3 0
18 :3 0 11 :3 0
b :4 0 284 :2 0
9da 27e 285 :3 0
111 :3 0 2b :3 0
87 :3 0 286 287
:3 0 9 :3 0 6f
:3 0 289 28a 0
17 :2 0 28b 28c
0 28e 116 295
9 :3 0 6f :3 0
28f 290 0 88
:2 0 291 292 0
294 118 296 288
28e 0 297 0
294 0 297 11a
0 9da 9 :3 0
6f :3 0 298 299
0 9 :3 0 89
:2 0 7d :3 0 29b
29d 0 11f 29c
29f :3 0 2a0 :2 0
8a :8 0 2a4 122
2a5 2a1 2a4 0
2a6 124 0 9da
62 :3 0 18 :3 0
17 :2 0 126 2a7
2aa 7c :2 0 17
:2 0 12b 2ac 2ae
:3 0 62 :3 0 16
:3 0 17 :2 0 12e
2b0 2b3 7c :2 0
8b :2 0 133 2b5
2b7 :3 0 33 :3 0
2f :3 0 31 :3 0
8c :3 0 34 :3 0
d :3 0 2c :3 0
12 :4 0 8d 1
:8 0 2d7 87 :4 0
2c2 :3 0 8e :3 0
7c :2 0 138 2c5
2c6 :3 0 9 :3 0
6f :3 0 2c8 2c9
0 17 :2 0 2ca
2cb 0 2cd 13b
2d4 9 :3 0 6f
:3 0 2ce 2cf 0
88 :2 0 2d0 2d1
0 2d3 13d 2d5
2c7 2cd 0 2d6
0 2d3 0 2d6
13f 0 2d7 142
32a 71 :3 0 9
:3 0 6f :3 0 2d9
2da 0 70 :3 0
2db 2dc 0 2de
145 2e0 147 2df
2de :2 0 328 72
:3 0 9 :3 0 6f
:3 0 2e3 2e4 0
70 :3 0 2e5 2e6
0 320 55 :3 0
56 :3 0 2e8 2e9
0 55 :3 0 66
:3 0 2eb 2ec 0
73 :2 0 2 :4 0
8f :2 0 68 :2 0
15 :2 0 149 2f1
2f3 :3 0 14c 2ed
2f5 2ea 2f7 2f6
:2 0 58 :3 0 69
:3 0 2f9 2fa 0
5a :4 0 90 :4 0
5d :2 0 5e :3 0
150 2fe 300 :3 0
5d :2 0 76 :4 0
153 302 304 :3 0
5d :2 0 77 :4 0
156 306 308 :3 0
5d :2 0 70 :3 0
159 30a 30c :3 0
5d :2 0 78 :4 0
15c 30e 310 :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 15f 313
317 163 312 319
:3 0 166 2fb 31b
:2 0 31d 169 31e
2f8 31d 0 31f
16b 0 320 16d
323 :3 0 323 0
323 322 320 321
:6 0 325 9 :3 0
170 327 172 326
325 :2 0 328 174
:2 0 32a 0 32a
329 2d7 328 :6 0
33d 8 :3 0 27
:3 0 15 :2 0 32c
32d 0 33d 23
:3 0 91 :3 0 24
:3 0 12 :3 0 25
:3 0 26 :3 0 62
:3 0 27 :3 0 17
:2 0 177 335 338
17a 330 33a 32f
33b 0 33d 180
341 92 :3 0 33e
:4 0 340 184 342
2b8 33d 0 343
0 340 0 343
186 0 344 189
954 85 :3 0 4a
:4 0 348 :2 0 953
346 349 :3 0 86
:3 0 4a :3 0 13
:3 0 14 :3 0 1d
:3 0 20 :3 0 21
:3 0 22 :4 0 353
:2 0 8f2 34b 354
:3 0 18b :3 0 4a
:3 0 87 :3 0 355
356 :3 0 9 :3 0
6f :3 0 358 359
0 17 :2 0 35a
35b 0 35d 192
364 9 :3 0 6f
:3 0 35e 35f 0
88 :2 0 360 361
0 363 194 365
357 35d 0 366
0 363 0 366
196 0 8f2 9
:3 0 6f :3 0 367
368 0 9 :3 0
89 :2 0 7d :3 0
36a 36c 0 19b
36b 36e :3 0 36f
:2 0 8a :8 0 373
19e 374 370 373
0 375 1a0 0
8f2 1e :3 0 17
:2 0 376 377 0
8f2 62 :3 0 16
:3 0 17 :2 0 1a2
379 37c 7c :2 0
15 :2 0 1a7 37e
380 :3 0 79 :3 0
14 :3 0 15 :2 0
15 :2 0 1aa 382
386 7c :2 0 8b
:4 0 1b0 388 38a
:3 0 93 :3 0 94
:3 0 4b :3 0 13
:3 0 4b :3 0 2c
:3 0 36 :3 0 37
:3 0 95 :4 0 96
1 :8 0 3ab 87
:4 0 396 :3 0 8e
:3 0 7c :2 0 1b5
399 39a :3 0 9
:3 0 6f :3 0 39c
39d 0 17 :2 0
39e 39f 0 3a1
1b8 3a8 9 :3 0
6f :3 0 3a2 3a3
0 88 :2 0 3a4
3a5 0 3a7 1ba
3a9 39b 3a1 0
3aa 0 3a7 0
3aa 1bc 0 3ab
1bf 3fe 71 :3 0
9 :3 0 6f :3 0
3ad 3ae 0 70
:3 0 3af 3b0 0
3b2 1c2 3b4 1c4
3b3 3b2 :2 0 3fc
72 :3 0 9 :3 0
6f :3 0 3b7 3b8
0 70 :3 0 3b9
3ba 0 3f4 55
:3 0 56 :3 0 3bc
3bd 0 55 :3 0
66 :3 0 3bf 3c0
0 73 :2 0 2
:4 0 97 :2 0 68
:2 0 15 :2 0 1c6
3c5 3c7 :3 0 1c9
3c1 3c9 3be 3cb
3ca :2 0 58 :3 0
69 :3 0 3cd 3ce
0 5a :4 0 98
:4 0 5d :2 0 5e
:3 0 1cd 3d2 3d4
:3 0 5d :2 0 76
:4 0 1d0 3d6 3d8
:3 0 5d :2 0 77
:4 0 1d3 3da 3dc
:3 0 5d :2 0 70
:3 0 1d6 3de 3e0
:3 0 5d :2 0 78
:4 0 1d9 3e2 3e4
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 1dc
3e7 3eb 1e0 3e6
3ed :3 0 1e3 3cf
3ef :2 0 3f1 1e6
3f2 3cc 3f1 0
3f3 1e8 0 3f4
1ea 3f7 :3 0 3f7
0 3f7 3f6 3f4
3f5 :6 0 3f9 c
:3 0 1ed 3fb 1ef
3fa 3f9 :2 0 3fc
1f1 :2 0 3fe 0
3fe 3fd 3ab 3fc
:6 0 50b b :3 0
62 :3 0 1d :3 0
17 :2 0 1f4 400
403 7c :2 0 80
:2 0 15 :2 0 1f7
406 408 :3 0 1fb
405 40a :3 0 51
:3 0 99 :3 0 4b
:3 0 13 :4 0 9a
1 :8 0 493 51
:3 0 9b :3 0 30
:3 0 9c :3 0 32
:3 0 9d :3 0 4e
:3 0 9e :3 0 30
:3 0 9f :3 0 32
:3 0 a0 :3 0 4e
:3 0 99 :3 0 a1
:3 0 4d :3 0 4e
:3 0 48 :3 0 4e
:3 0 47 :3 0 a2
:3 0 4b :3 0 13
:4 0 a3 1 :8 0
43e 87 :4 0 429
:3 0 8e :3 0 7c
:2 0 200 42c 42d
:3 0 9 :3 0 6f
:3 0 42f 430 0
17 :2 0 431 432
0 434 203 43b
9 :3 0 6f :3 0
435 436 0 88
:2 0 437 438 0
43a 205 43c 42e
434 0 43d 0
43a 0 43d 207
0 43e 20a 491
71 :3 0 9 :3 0
6f :3 0 440 441
0 70 :3 0 442
443 0 445 20d
447 20f 446 445
:2 0 48f 72 :3 0
9 :3 0 6f :3 0
44a 44b 0 70
:3 0 44c 44d 0
487 55 :3 0 56
:3 0 44f 450 0
55 :3 0 66 :3 0
452 453 0 73
:2 0 2 :4 0 a4
:2 0 68 :2 0 15
:2 0 211 458 45a
:3 0 214 454 45c
451 45e 45d :2 0
58 :3 0 69 :3 0
460 461 0 5a
:4 0 a5 :4 0 5d
:2 0 5e :3 0 218
465 467 :3 0 5d
:2 0 76 :4 0 21b
469 46b :3 0 5d
:2 0 77 :4 0 21e
46d 46f :3 0 5d
:2 0 70 :3 0 221
471 473 :3 0 5d
:2 0 78 :4 0 224
475 477 :3 0 5d
:2 0 79 :3 0 7a
:3 0 15 :2 0 7b
:2 0 227 47a 47e
22b 479 480 :3 0
22e 462 482 :2 0
484 231 485 45f
484 0 486 233
0 487 235 48a
:3 0 48a 0 48a
489 487 488 :6 0
48c e :3 0 238
48e 23a 48d 48c
:2 0 48f 23c :2 0
491 0 491 490
43e 48f :6 0 493
b :3 0 23f 508
51 :3 0 4e :3 0
4e :3 0 48 :3 0
4e :3 0 47 :3 0
4b :3 0 13 :4 0
a6 1 :8 0 4b2
87 :4 0 49d :3 0
8e :3 0 7c :2 0
244 4a0 4a1 :3 0
9 :3 0 6f :3 0
4a3 4a4 0 17
:2 0 4a5 4a6 0
4a8 247 4af 9
:3 0 6f :3 0 4a9
4aa 0 88 :2 0
4ab 4ac 0 4ae
249 4b0 4a2 4a8
0 4b1 0 4ae
0 4b1 24b 0
4b2 24e 505 71
:3 0 9 :3 0 6f
:3 0 4b4 4b5 0
70 :3 0 4b6 4b7
0 4b9 251 4bb
253 4ba 4b9 :2 0
503 72 :3 0 9
:3 0 6f :3 0 4be
4bf 0 70 :3 0
4c0 4c1 0 4fb
55 :3 0 56 :3 0
4c3 4c4 0 55
:3 0 66 :3 0 4c6
4c7 0 73 :2 0
2 :4 0 a7 :2 0
68 :2 0 15 :2 0
255 4cc 4ce :3 0
258 4c8 4d0 4c5
4d2 4d1 :2 0 58
:3 0 69 :3 0 4d4
4d5 0 5a :4 0
a8 :4 0 5d :2 0
5e :3 0 25c 4d9
4db :3 0 5d :2 0
76 :4 0 25f 4dd
4df :3 0 5d :2 0
77 :4 0 262 4e1
4e3 :3 0 5d :2 0
70 :3 0 265 4e5
4e7 :3 0 5d :2 0
78 :4 0 268 4e9
4eb :3 0 5d :2 0
79 :3 0 7a :3 0
15 :2 0 7b :2 0
26b 4ee 4f2 26f
4ed 4f4 :3 0 272
4d6 4f6 :2 0 4f8
275 4f9 4d3 4f8
0 4fa 277 0
4fb 279 4fe :3 0
4fe 0 4fe 4fd
4fb 4fc :6 0 500
10 :3 0 27c 502
27e 501 500 :2 0
503 280 :2 0 505
0 505 504 4b2
503 :6 0 507 b
:3 0 283 509 40b
493 0 50a 0
507 0 50a 285
0 50b 288 580
51 :3 0 48 :3 0
4f :3 0 50 :3 0
a2 :3 0 a9 :3 0
4b :3 0 13 :4 0
aa 1 :8 0 52a
87 :4 0 515 :3 0
8e :3 0 7c :2 0
28d 518 519 :3 0
9 :3 0 6f :3 0
51b 51c 0 17
:2 0 51d 51e 0
520 290 527 9
:3 0 6f :3 0 521
522 0 88 :2 0
523 524 0 526
292 528 51a 520
0 529 0 526
0 529 294 0
52a 297 57d 71
:3 0 9 :3 0 6f
:3 0 52c 52d 0
70 :3 0 52e 52f
0 531 29a 533
29c 532 531 :2 0
57b 72 :3 0 9
:3 0 6f :3 0 536
537 0 70 :3 0
538 539 0 573
55 :3 0 56 :3 0
53b 53c 0 55
:3 0 66 :3 0 53e
53f 0 73 :2 0
2 :4 0 ab :2 0
68 :2 0 15 :2 0
29e 544 546 :3 0
2a1 540 548 53d
54a 549 :2 0 58
:3 0 69 :3 0 54c
54d 0 5a :4 0
ac :4 0 5d :2 0
5e :3 0 2a5 551
553 :3 0 5d :2 0
76 :4 0 2a8 555
557 :3 0 5d :2 0
77 :4 0 2ab 559
55b :3 0 5d :2 0
70 :3 0 2ae 55d
55f :3 0 5d :2 0
78 :4 0 2b1 561
563 :3 0 5d :2 0
79 :3 0 7a :3 0
15 :2 0 7b :2 0
2b4 566 56a 2b8
565 56c :3 0 2bb
54e 56e :2 0 570
2be 571 54b 570
0 572 2c0 0
573 2c2 576 :3 0
576 0 576 575
573 574 :6 0 578
12 :3 0 2c5 57a
2c7 579 578 :2 0
57b 2c9 :2 0 57d
0 57d 57c 52a
57b :6 0 57f b
:3 0 2cc 581 38b
50b 0 582 0
57f 0 582 2ce
0 583 2d1 776
62 :3 0 16 :3 0
17 :2 0 2d3 584
587 7c :2 0 8b
:2 0 2d8 589 58b
:3 0 51 :3 0 2f
:3 0 31 :3 0 8c
:3 0 4b :3 0 13
:4 0 ad 1 :8 0
5a9 87 :4 0 594
:3 0 8e :3 0 7c
:2 0 2dd 597 598
:3 0 9 :3 0 6f
:3 0 59a 59b 0
17 :2 0 59c 59d
0 59f 2e0 5a6
9 :3 0 6f :3 0
5a0 5a1 0 88
:2 0 5a2 5a3 0
5a5 2e2 5a7 599
59f 0 5a8 0
5a5 0 5a8 2e4
0 5a9 2e7 5fc
71 :3 0 9 :3 0
6f :3 0 5ab 5ac
0 70 :3 0 5ad
5ae 0 5b0 2ea
5b2 2ec 5b1 5b0
:2 0 5fa 72 :3 0
9 :3 0 6f :3 0
5b5 5b6 0 70
:3 0 5b7 5b8 0
5f2 55 :3 0 56
:3 0 5ba 5bb 0
55 :3 0 66 :3 0
5bd 5be 0 73
:2 0 2 :4 0 ae
:2 0 68 :2 0 15
:2 0 2ee 5c3 5c5
:3 0 2f1 5bf 5c7
5bc 5c9 5c8 :2 0
58 :3 0 69 :3 0
5cb 5cc 0 5a
:4 0 af :4 0 5d
:2 0 5e :3 0 2f5
5d0 5d2 :3 0 5d
:2 0 76 :4 0 2f8
5d4 5d6 :3 0 5d
:2 0 77 :4 0 2fb
5d8 5da :3 0 5d
:2 0 70 :3 0 2fe
5dc 5de :3 0 5d
:2 0 78 :4 0 301
5e0 5e2 :3 0 5d
:2 0 79 :3 0 7a
:3 0 15 :2 0 7b
:2 0 304 5e5 5e9
308 5e4 5eb :3 0
30b 5cd 5ed :2 0
5ef 30e 5f0 5ca
5ef 0 5f1 310
0 5f2 312 5f5
:3 0 5f5 0 5f5
5f4 5f2 5f3 :6 0
5f7 14 :3 0 315
5f9 317 5f8 5f7
:2 0 5fa 319 :2 0
5fc 0 5fc 5fb
5a9 5fa :6 0 5fe
b :3 0 31c 772
79 :3 0 14 :3 0
15 :2 0 15 :2 0
31e 5ff 603 7c
:2 0 8b :4 0 324
605 607 :3 0 93
:3 0 94 :3 0 4b
:3 0 13 :3 0 4b
:3 0 2c :3 0 36
:3 0 37 :3 0 95
:4 0 b0 1 :8 0
628 87 :4 0 613
:3 0 8e :3 0 7c
:2 0 329 616 617
:3 0 9 :3 0 6f
:3 0 619 61a 0
17 :2 0 61b 61c
0 61e 32c 625
9 :3 0 6f :3 0
61f 620 0 88
:2 0 621 622 0
624 32e 626 618
61e 0 627 0
624 0 627 330
0 628 333 67b
71 :3 0 9 :3 0
6f :3 0 62a 62b
0 70 :3 0 62c
62d 0 62f 336
631 338 630 62f
:2 0 679 72 :3 0
9 :3 0 6f :3 0
634 635 0 70
:3 0 636 637 0
671 55 :3 0 56
:3 0 639 63a 0
55 :3 0 66 :3 0
63c 63d 0 73
:2 0 2 :4 0 b1
:2 0 68 :2 0 15
:2 0 33a 642 644
:3 0 33d 63e 646
63b 648 647 :2 0
58 :3 0 69 :3 0
64a 64b 0 5a
:4 0 b2 :4 0 5d
:2 0 5e :3 0 341
64f 651 :3 0 5d
:2 0 76 :4 0 344
653 655 :3 0 5d
:2 0 77 :4 0 347
657 659 :3 0 5d
:2 0 70 :3 0 34a
65b 65d :3 0 5d
:2 0 78 :4 0 34d
65f 661 :3 0 5d
:2 0 79 :3 0 7a
:3 0 15 :2 0 7b
:2 0 350 664 668
354 663 66a :3 0
357 64c 66c :2 0
66e 35a 66f 649
66e 0 670 35c
0 671 35e 674
:3 0 674 0 674
673 671 672 :6 0
676 16 :3 0 361
678 363 677 676
:2 0 679 365 :2 0
67b 0 67b 67a
628 679 :6 0 6f8
b :3 0 51 :3 0
2f :3 0 31 :3 0
8c :3 0 4e :3 0
9d :3 0 47 :3 0
9d :3 0 4e :3 0
48 :3 0 9d :3 0
47 :3 0 9d :3 0
47 :3 0 4b :3 0
13 :4 0 b3 1
:8 0 6a3 87 :4 0
68e :3 0 8e :3 0
7c :2 0 36a 691
692 :3 0 9 :3 0
6f :3 0 694 695
0 17 :2 0 696
697 0 699 36d
6a0 9 :3 0 6f
:3 0 69a 69b 0
88 :2 0 69c 69d
0 69f 36f 6a1
693 699 0 6a2
0 69f 0 6a2
371 0 6a3 374
6f6 71 :3 0 9
:3 0 6f :3 0 6a5
6a6 0 70 :3 0
6a7 6a8 0 6aa
377 6ac 379 6ab
6aa :2 0 6f4 72
:3 0 9 :3 0 6f
:3 0 6af 6b0 0
70 :3 0 6b1 6b2
0 6ec 55 :3 0
56 :3 0 6b4 6b5
0 55 :3 0 66
:3 0 6b7 6b8 0
73 :2 0 2 :4 0
b4 :2 0 68 :2 0
15 :2 0 37b 6bd
6bf :3 0 37e 6b9
6c1 6b6 6c3 6c2
:2 0 58 :3 0 69
:3 0 6c5 6c6 0
5a :4 0 b5 :4 0
5d :2 0 5e :3 0
382 6ca 6cc :3 0
5d :2 0 76 :4 0
385 6ce 6d0 :3 0
5d :2 0 77 :4 0
388 6d2 6d4 :3 0
5d :2 0 70 :3 0
38b 6d6 6d8 :3 0
5d :2 0 78 :4 0
38e 6da 6dc :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 391 6df
6e3 395 6de 6e5
:3 0 398 6c7 6e7
:2 0 6e9 39b 6ea
6c4 6e9 0 6eb
39d 0 6ec 39f
6ef :3 0 6ef 0
6ef 6ee 6ec 6ed
:6 0 6f1 18 :3 0
3a2 6f3 3a4 6f2
6f1 :2 0 6f4 3a6
:2 0 6f6 0 6f6
6f5 6a3 6f4 :6 0
6f8 b :3 0 3a9
76e 51 :3 0 2f
:3 0 31 :3 0 8c
:3 0 48 :3 0 4f
:3 0 50 :3 0 4b
:3 0 13 :4 0 b6
1 :8 0 718 87
:4 0 703 :3 0 8e
:3 0 7c :2 0 3ae
706 707 :3 0 9
:3 0 6f :3 0 709
70a 0 17 :2 0
70b 70c 0 70e
3b1 715 9 :3 0
6f :3 0 70f 710
0 88 :2 0 711
712 0 714 3b3
716 708 70e 0
717 0 714 0
717 3b5 0 718
3b8 76b 71 :3 0
9 :3 0 6f :3 0
71a 71b 0 70
:3 0 71c 71d 0
71f 3bb 721 3bd
720 71f :2 0 769
72 :3 0 9 :3 0
6f :3 0 724 725
0 70 :3 0 726
727 0 761 55
:3 0 56 :3 0 729
72a 0 55 :3 0
66 :3 0 72c 72d
0 73 :2 0 2
:4 0 b7 :2 0 68
:2 0 15 :2 0 3bf
732 734 :3 0 3c2
72e 736 72b 738
737 :2 0 58 :3 0
69 :3 0 73a 73b
0 5a :4 0 b8
:4 0 5d :2 0 5e
:3 0 3c6 73f 741
:3 0 5d :2 0 76
:4 0 3c9 743 745
:3 0 5d :2 0 77
:4 0 3cc 747 749
:3 0 5d :2 0 70
:3 0 3cf 74b 74d
:3 0 5d :2 0 78
:4 0 3d2 74f 751
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 3d5
754 758 3d9 753
75a :3 0 3dc 73c
75c :2 0 75e 3df
75f 739 75e 0
760 3e1 0 761
3e3 764 :3 0 764
0 764 763 761
762 :6 0 766 1a
:3 0 3e6 768 3e8
767 766 :2 0 769
3ea :2 0 76b 0
76b 76a 718 769
:6 0 76d b :3 0
3ed 76f 608 6f8
0 770 0 76d
0 770 3ef 0
771 3f2 773 58c
5fe 0 774 0
771 0 774 3f4
0 775 3f7 777
381 583 0 778
0 775 0 778
3f9 0 8f2 9
:3 0 6f :3 0 779
77a 0 9 :3 0
7c :2 0 b9 :3 0
77c 77e 0 3fe
77d 780 :3 0 781
:2 0 1e :3 0 15
:2 0 783 784 0
786 401 787 782
786 0 788 403
0 8f2 27 :3 0
17 :2 0 789 78a
0 8f2 23 :3 0
91 :3 0 24 :3 0
13 :3 0 25 :3 0
26 :3 0 62 :3 0
27 :3 0 17 :2 0
405 792 795 408
78d 797 78c 798
0 8f2 62 :3 0
1e :3 0 17 :2 0
40e 79a 79d 7c
:2 0 17 :2 0 413
79f 7a1 :3 0 ba
:3 0 62 :3 0 16
:3 0 17 :2 0 416
7a4 7a7 15 :2 0
419 7a3 7aa 7ab
:2 0 7c :2 0 15
:2 0 41e 7ad 7af
:3 0 7b0 :2 0 62
:3 0 22 :3 0 17
:2 0 421 7b2 7b5
bb :2 0 17 :2 0
426 7b7 7b9 :3 0
7ba :2 0 7b1 7bc
7bb :2 0 29 :3 0
bc :3 0 62 :3 0
bd :3 0 21 :3 0
429 7c1 7c3 17
:2 0 42b 7c0 7c6
be :2 0 62 :3 0
bd :3 0 20 :3 0
42e 7ca 7cc 17
:2 0 430 7c9 7cf
433 7c8 7d1 :3 0
7d2 :2 0 bf :2 0
c0 :2 0 436 7d4
7d6 :3 0 7d7 :2 0
80 :2 0 62 :3 0
22 :3 0 17 :2 0
439 7da 7dd 43c
7d9 7df :3 0 43f
7bf 7e1 7be 7e2
0 8ec 29 :3 0
bb :2 0 15 :2 0
443 7e5 7e7 :3 0
7e8 :2 0 29 :3 0
c1 :2 0 80 :2 0
15 :2 0 446 7ec
7ee :3 0 44a 7eb
7f0 :3 0 7e9 7f2
7f1 :2 0 51 :3 0
c2 :3 0 c3 :3 0
c4 :3 0 c2 :3 0
37 :3 0 c5 :3 0
a2 :3 0 a2 :3 0
48 :3 0 32 :3 0
a2 :3 0 4b :3 0
13 :4 0 c6 1
:8 0 818 87 :4 0
803 :3 0 8e :3 0
7c :2 0 44f 806
807 :3 0 9 :3 0
6f :3 0 809 80a
0 17 :2 0 80b
80c 0 80e 452
815 9 :3 0 6f
:3 0 80f 810 0
88 :2 0 811 812
0 814 454 816
808 80e 0 817
0 814 0 817
456 0 818 459
86b 71 :3 0 9
:3 0 6f :3 0 81a
81b 0 70 :3 0
81c 81d 0 81f
45c 821 45e 820
81f :2 0 869 72
:3 0 9 :3 0 6f
:3 0 824 825 0
70 :3 0 826 827
0 861 55 :3 0
56 :3 0 829 82a
0 55 :3 0 66
:3 0 82c 82d 0
73 :2 0 2 :4 0
c7 :2 0 68 :2 0
15 :2 0 460 832
834 :3 0 463 82e
836 82b 838 837
:2 0 58 :3 0 69
:3 0 83a 83b 0
5a :4 0 c8 :4 0
5d :2 0 5e :3 0
467 83f 841 :3 0
5d :2 0 76 :4 0
46a 843 845 :3 0
5d :2 0 77 :4 0
46d 847 849 :3 0
5d :2 0 70 :3 0
470 84b 84d :3 0
5d :2 0 78 :4 0
473 84f 851 :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 476 854
858 47a 853 85a
:3 0 47d 83c 85c
:2 0 85e 480 85f
839 85e 0 860
482 0 861 484
864 :3 0 864 0
864 863 861 862
:6 0 866 1c :3 0
487 868 489 867
866 :2 0 869 48b
:2 0 86b 0 86b
86a 818 869 :6 0
86d b :3 0 48e
8e2 51 :3 0 a2
:3 0 a2 :3 0 48
:3 0 32 :3 0 a2
:3 0 4b :3 0 13
:4 0 c9 1 :8 0
88c 87 :4 0 877
:3 0 8e :3 0 7c
:2 0 492 87a 87b
:3 0 9 :3 0 6f
:3 0 87d 87e 0
17 :2 0 87f 880
0 882 495 889
9 :3 0 6f :3 0
883 884 0 88
:2 0 885 886 0
888 497 88a 87c
882 0 88b 0
888 0 88b 499
0 88c 49c 8df
71 :3 0 9 :3 0
6f :3 0 88e 88f
0 70 :3 0 890
891 0 893 49f
895 4a1 894 893
:2 0 8dd 72 :3 0
9 :3 0 6f :3 0
898 899 0 70
:3 0 89a 89b 0
8d5 55 :3 0 56
:3 0 89d 89e 0
55 :3 0 66 :3 0
8a0 8a1 0 73
:2 0 2 :4 0 ca
:2 0 68 :2 0 15
:2 0 4a3 8a6 8a8
:3 0 4a6 8a2 8aa
89f 8ac 8ab :2 0
58 :3 0 69 :3 0
8ae 8af 0 5a
:4 0 cb :4 0 5d
:2 0 5e :3 0 4aa
8b3 8b5 :3 0 5d
:2 0 76 :4 0 4ad
8b7 8b9 :3 0 5d
:2 0 77 :4 0 4b0
8bb 8bd :3 0 5d
:2 0 70 :3 0 4b3
8bf 8c1 :3 0 5d
:2 0 78 :4 0 4b6
8c3 8c5 :3 0 5d
:2 0 79 :3 0 7a
:3 0 15 :2 0 7b
:2 0 4b9 8c8 8cc
4bd 8c7 8ce :3 0
4c0 8b0 8d0 :2 0
8d2 4c3 8d3 8ad
8d2 0 8d4 4c5
0 8d5 4c7 8d8
:3 0 8d8 0 8d8
8d7 8d5 8d6 :6 0
8da 1e :3 0 4ca
8dc 4cc 8db 8da
:2 0 8dd 4ce :2 0
8df 0 8df 8de
88c 8dd :6 0 8e1
b :3 0 4d1 8e3
7f3 86d 0 8e4
0 8e1 0 8e4
4d3 0 8ec 1c
:3 0 cc :3 0 d
:3 0 13 :3 0 4d6
8e6 8e9 8e5 8ea
0 8ec 4d9 8ed
7bd 8ec 0 8ee
4dd 0 8ef 4df
8f0 7a2 8ef 0
8f1 4e1 0 8f2
4e3 8f4 86 :4 0
8f2 :4 0 953 cd
:3 0 4a :4 0 8f8
:2 0 8fe 8f6 0
9 :3 0 6f :3 0
8f9 8fa 0 70
:3 0 8fb 8fc 0
8fe 4ed 951 71
:3 0 9 :3 0 6f
:3 0 900 901 0
70 :3 0 902 903
0 905 4f0 907
4f2 906 905 :2 0
94f 72 :3 0 9
:3 0 6f :3 0 90a
90b 0 70 :3 0
90c 90d 0 947
55 :3 0 56 :3 0
90f 910 0 55
:3 0 66 :3 0 912
913 0 73 :2 0
2 :4 0 ce :2 0
68 :2 0 15 :2 0
4f4 918 91a :3 0
4f7 914 91c 911
91e 91d :2 0 58
:3 0 69 :3 0 920
921 0 5a :4 0
cf :4 0 5d :2 0
5e :3 0 4fb 925
927 :3 0 5d :2 0
76 :4 0 4fe 929
92b :3 0 5d :2 0
77 :4 0 501 92d
92f :3 0 5d :2 0
70 :3 0 504 931
933 :3 0 5d :2 0
78 :4 0 507 935
937 :3 0 5d :2 0
79 :3 0 7a :3 0
15 :2 0 7b :2 0
50a 93a 93e 50e
939 940 :3 0 511
922 942 :2 0 944
514 945 91f 944
0 946 516 0
947 518 94a :3 0
94a 0 94a 949
947 948 :6 0 94c
20 :3 0 51b 94e
51d 94d 94c :2 0
94f 51f :2 0 951
0 951 950 8fe
94f :6 0 953 8
:3 0 522 955 2af
344 0 956 0
953 0 956 526
0 9da 33 :3 0
d0 :3 0 d1 :3 0
79 :3 0 30 :3 0
d1 :3 0 79 :3 0
1a :3 0 d2 :3 0
d1 :3 0 79 :3 0
30 :3 0 d1 :3 0
79 :3 0 1a :3 0
30 :3 0 34 :3 0
d :3 0 2c :3 0
12 :4 0 d3 1
:8 0 981 87 :4 0
96c :3 0 8e :3 0
7c :2 0 52b 96f
970 :3 0 9 :3 0
6f :3 0 972 973
0 17 :2 0 974
975 0 977 52e
97e 9 :3 0 6f
:3 0 978 979 0
88 :2 0 97a 97b
0 97d 530 97f
971 977 0 980
0 97d 0 980
532 0 981 535
9d4 71 :3 0 9
:3 0 6f :3 0 983
984 0 70 :3 0
985 986 0 988
538 98a 53a 989
988 :2 0 9d2 72
:3 0 9 :3 0 6f
:3 0 98d 98e 0
70 :3 0 98f 990
0 9ca 55 :3 0
56 :3 0 992 993
0 55 :3 0 66
:3 0 995 996 0
73 :2 0 2 :4 0
d4 :2 0 68 :2 0
15 :2 0 53c 99b
99d :3 0 53f 997
99f 994 9a1 9a0
:2 0 58 :3 0 69
:3 0 9a3 9a4 0
5a :4 0 d5 :4 0
5d :2 0 5e :3 0
543 9a8 9aa :3 0
5d :2 0 76 :4 0
546 9ac 9ae :3 0
5d :2 0 77 :4 0
549 9b0 9b2 :3 0
5d :2 0 70 :3 0
54c 9b4 9b6 :3 0
5d :2 0 78 :4 0
54f 9b8 9ba :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 552 9bd
9c1 556 9bc 9c3
:3 0 559 9a5 9c5
:2 0 9c7 55c 9c8
9a2 9c7 0 9c9
55e 0 9ca 560
9cd :3 0 9cd 0
9cd 9cc 9ca 9cb
:6 0 9cf 22 :3 0
563 9d1 565 9d0
9cf :2 0 9d2 567
:2 0 9d4 0 9d4
9d3 981 9d2 :6 0
9da 8 :3 0 92
:5 0 9d8 24 0
9d9 56a 9d8 9d7
9da 56c 9dc 86
:4 0 9da :4 0 a50
cd :3 0 2b :4 0
9e0 :2 0 9e6 9de
0 9 :3 0 6f
:3 0 9e1 9e2 0
70 :3 0 9e3 9e4
0 9e6 573 a39
71 :3 0 9 :3 0
6f :3 0 9e8 9e9
0 70 :3 0 9ea
9eb 0 9ed 576
9ef 578 9ee 9ed
:2 0 a37 72 :3 0
9 :3 0 6f :3 0
9f2 9f3 0 70
:3 0 9f4 9f5 0
a2f 55 :3 0 56
:3 0 9f7 9f8 0
55 :3 0 66 :3 0
9fa 9fb 0 73
:2 0 2 :4 0 d6
:2 0 68 :2 0 15
:2 0 57a a00 a02
:3 0 57d 9fc a04
9f9 a06 a05 :2 0
58 :3 0 69 :3 0
a08 a09 0 5a
:4 0 d7 :4 0 5d
:2 0 5e :3 0 581
a0d a0f :3 0 5d
:2 0 76 :4 0 584
a11 a13 :3 0 5d
:2 0 77 :4 0 587
a15 a17 :3 0 5d
:2 0 70 :3 0 58a
a19 a1b :3 0 5d
:2 0 78 :4 0 58d
a1d a1f :3 0 5d
:2 0 79 :3 0 7a
:3 0 15 :2 0 7b
:2 0 590 a22 a26
594 a21 a28 :3 0
597 a0a a2a :2 0
a2c 59a a2d a07
a2c 0 a2e 59c
0 a2f 59e a32
:3 0 a32 0 a32
a31 a2f a30 :6 0
a34 24 :3 0 5a1
a36 5a3 a35 a34
:2 0 a37 5a5 :2 0
a39 0 a39 a38
9e6 a37 :6 0 a50
1 :3 0 62 :3 0
18 :3 0 17 :2 0
5a8 a3b a3e bb
:2 0 80 :2 0 15
:2 0 5ab a41 a43
:3 0 5af a40 a45
:3 0 1c :3 0 d8
:3 0 d :3 0 5b2
a48 a4a a47 a4b
0 a4d 5b4 a4e
a46 a4d 0 a4f
5b6 0 a50 5b8
a51 205 a50 0
a52 5c0 0 aa1
55 :3 0 56 :3 0
a53 a54 0 55
:3 0 66 :3 0 a56
a57 0 d9 :2 0
2 :4 0 da :2 0
68 :2 0 15 :2 0
5c2 a5c a5e :3 0
5c5 a58 a60 a55
a62 a61 :2 0 58
:3 0 69 :3 0 a64
a65 0 5a :4 0
db :4 0 5d :2 0
5e :3 0 5c9 a69
a6b :3 0 5d :2 0
76 :4 0 5cc a6d
a6f :3 0 5d :2 0
dc :4 0 5cf a71
a73 :3 0 5d :2 0
62 :3 0 63 :3 0
9 :3 0 6f :3 0
a78 a79 0 5d2
a77 a7b 64 :4 0
5d4 a76 a7e 5d7
a75 a80 :3 0 5d
:2 0 dd :4 0 5da
a82 a84 :3 0 5d
:2 0 60 :4 0 5dd
a86 a88 :3 0 5d
:2 0 3 :3 0 5e0
a8a a8c :3 0 5d
:2 0 60 :4 0 5e3
a8e a90 :3 0 5e6
a66 a92 :2 0 a94
5e9 a95 a63 a94
0 a96 5eb 0
aa1 de :3 0 df
:3 0 a97 a98 0
9 :3 0 6f :3 0
a9a a9b 0 3
:3 0 8e :3 0 5ed
a99 a9f :2 0 aa1
5f1 b42 9 :3 0
e0 :2 0 4 aa2
aa3 0 55 :3 0
56 :3 0 aa5 aa6
0 55 :3 0 66
:3 0 aa8 aa9 0
73 :2 0 2 :4 0
e1 :2 0 68 :2 0
15 :2 0 5fc aae
ab0 :3 0 5ff aaa
ab2 aa7 ab4 ab3
:2 0 58 :3 0 69
:3 0 ab6 ab7 0
5a :4 0 e2 :4 0
5d :2 0 5e :3 0
603 abb abd :3 0
606 ab8 abf :2 0
ad8 58 :3 0 69
:3 0 ac1 ac2 0
5a :4 0 e3 :4 0
5d :2 0 9 :3 0
e4 :3 0 ac7 ac8
0 609 ac6 aca
:3 0 5d :2 0 dd
:4 0 60c acc ace
:3 0 5d :2 0 9
:3 0 e5 :3 0 ad1
ad2 0 60f ad0
ad4 :3 0 612 ac3
ad6 :2 0 ad8 615
ad9 ab5 ad8 0
ada 618 0 aea
85 :3 0 54 :3 0
9 :3 0 e4 :3 0
e6 :3 0 9 :3 0
e5 :3 0 3 :3 0
e7 :4 0 e8 1
:a 0 ae6 :2 0 aea
adc ae4 :2 0 8
:3 0 54 :3 0 ae8
:2 0 aea 61a aec
61e aeb aea :2 0
b40 72 :3 0 9
:3 0 6f :3 0 aef
af0 0 70 :3 0
af1 af2 0 b38
55 :3 0 56 :3 0
af4 af5 0 55
:3 0 66 :3 0 af7
af8 0 73 :2 0
2 :4 0 e9 :2 0
68 :2 0 15 :2 0
620 afd aff :3 0
623 af9 b01 af6
b03 b02 :2 0 58
:3 0 69 :3 0 b05
b06 0 5a :4 0
ea :4 0 5d :2 0
5e :3 0 627 b0a
b0c :3 0 62a b07
b0e :2 0 b28 58
:3 0 69 :3 0 b10
b11 0 5a :4 0
77 :4 0 5d :2 0
70 :3 0 62d b15
b17 :3 0 5d :2 0
78 :4 0 630 b19
b1b :3 0 5d :2 0
79 :3 0 7a :3 0
15 :2 0 7b :2 0
633 b1e b22 637
b1d b24 :3 0 63a
b12 b26 :2 0 b28
63d b29 b04 b28
0 b2a 640 0
b38 85 :3 0 54
:3 0 e6 :3 0 9
:3 0 e5 :3 0 3
:3 0 e7 :4 0 eb
1 :a 0 b34 :2 0
b38 b2c b32 :2 0
8 :3 0 54 :3 0
b36 :2 0 b38 642
b3b :3 0 b3b 0
b3b b3a b38 b39
:6 0 b3d 1 :3 0
647 b3f 649 b3e
b3d :2 0 b40 64b
:2 0 b42 64e b42
b41 aa1 b40 :6 0
b43 :2 0 2 14
b42 b46 :3 0 b45
b43 b47 :8 0 
66b
4
:3 0 1 3 1
7 1 b 3
6 a e 1
16 1 1d 1
1b 1 24 1
22 1 29 1
30 1 2e 1
37 1 35 1
3e 1 3c 1
43 1 49 1
4f 1 55 1
5a 1 60 1
66 1 6c 1
72 1 78 1
7e 1 84 1
8c 1 8a 1
93 1 91 1
98 1 9e 1
a4 1 aa 1
e9 1 108 1
10e 1 11b 1
127 2 12a 12c
2 12f 131 2
133 135 2 137
139 2 13b 13d
1 143 2 145
146 2 13f 148
2 14a 14c 2
14e 150 2 152
154 2 156 158
2 15a 15c 4
123 129 12e 15e
1 160 1 162
2 16c 16e 3
16a 16b 170 2
179 17b 2 178
17d 1 17f 1
181 2 199 19e
1 1a5 1 1a0
2 1b8 1ba 3
1b6 1b7 1bc 2
1c5 1c7 2 1c9
1cb 2 1cd 1cf
2 1d1 1d3 2
1d5 1d7 3 1dc
1dd 1de 2 1d9
1e0 2 1c4 1e2
1 1e4 1 1e6
2 1af 1e7 1
1eb 1 1aa 2
1a8 1ef 1 1fa
2 1f6 1fa 1
1fe 2 208 20a
3 20c 20d 20e
1 214 2 21d
222 1 229 1
224 2 23c 23e
3 23a 23b 240
2 249 24b 2
24d 24f 2 251
253 2 255 257
2 259 25b 3
260 261 262 2
25d 264 2 248
266 1 268 1
26a 2 233 26b
1 26f 1 22e
2 22c 273 4
27f 280 281 282
1 28d 1 293
2 295 296 1
29e 2 29a 29e
1 2a3 1 2a5
2 2a8 2a9 1
2ad 2 2ab 2ad
2 2b1 2b2 1
2b6 2 2b4 2b6
1 2c4 2 2c3
2c4 1 2cc 1
2d2 2 2d4 2d5
2 2c1 2d6 1
2dd 1 2d8 2
2f0 2f2 3 2ee
2ef 2f4 2 2fd
2ff 2 301 303
2 305 307 2
309 30b 2 30d
30f 3 314 315
316 2 311 318
2 2fc 31a 1
31c 1 31e 2
2e7 31f 1 323
1 2e2 2 2e0
327 2 336 337
5 331 332 333
334 339 3 32a
32e 33c 1 33f
2 341 342 1
343 6 34c 34d
34e 34f 350 351
1 35c 1 362
2 364 365 1
36d 2 369 36d
1 372 1 374
2 37a 37b 1
37f 2 37d 37f
3 383 384 385
1 389 2 387
389 1 398 2
397 398 1 3a0
1 3a6 2 3a8
3a9 2 395 3aa
1 3b1 1 3ac
2 3c4 3c6 3
3c2 3c3 3c8 2
3d1 3d3 2 3d5
3d7 2 3d9 3db
2 3dd 3df 2
3e1 3e3 3 3e8
3e9 3ea 2 3e5
3ec 2 3d0 3ee
1 3f0 1 3f2
2 3bb 3f3 1
3f7 1 3b6 2
3b4 3fb 2 401
402 1 407 1
409 2 404 409
1 42b 2 42a
42b 1 433 1
439 2 43b 43c
2 428 43d 1
444 1 43f 2
457 459 3 455
456 45b 2 464
466 2 468 46a
2 46c 46e 2
470 472 2 474
476 3 47b 47c
47d 2 478 47f
2 463 481 1
483 1 485 2
44e 486 1 48a
1 449 2 447
48e 2 410 491
1 49f 2 49e
49f 1 4a7 1
4ad 2 4af 4b0
2 49c 4b1 1
4b8 1 4b3 2
4cb 4cd 3 4c9
4ca 4cf 2 4d8
4da 2 4dc 4de
2 4e0 4e2 2
4e4 4e6 2 4e8
4ea 3 4ef 4f0
4f1 2 4ec 4f3
2 4d7 4f5 1
4f7 1 4f9 2
4c2 4fa 1 4fe
1 4bd 2 4bb
502 1 505 2
508 509 2 3fe
50a 1 517 2
516 517 1 51f
1 525 2 527
528 2 514 529
1 530 1 52b
2 543 545 3
541 542 547 2
550 552 2 554
556 2 558 55a
2 55c 55e 2
560 562 3 567
568 569 2 564
56b 2 54f 56d
1 56f 1 571
2 53a 572 1
576 1 535 2
533 57a 1 57d
2 580 581 1
582 2 585 586
1 58a 2 588
58a 1 596 2
595 596 1 59e
1 5a4 2 5a6
5a7 2 593 5a8
1 5af 1 5aa
2 5c2 5c4 3
5c0 5c1 5c6 2
5cf 5d1 2 5d3
5d5 2 5d7 5d9
2 5db 5dd 2
5df 5e1 3 5e6
5e7 5e8 2 5e3
5ea 2 5ce 5ec
1 5ee 1 5f0
2 5b9 5f1 1
5f5 1 5b4 2
5b2 5f9 1 5fc
3 600 601 602
1 606 2 604
606 1 615 2
614 615 1 61d
1 623 2 625
626 2 612 627
1 62e 1 629
2 641 643 3
63f 640 645 2
64e 650 2 652
654 2 656 658
2 65a 65c 2
65e 660 3 665
666 667 2 662
669 2 64d 66b
1 66d 1 66f
2 638 670 1
674 1 633 2
631 678 1 690
2 68f 690 1
698 1 69e 2
6a0 6a1 2 68d
6a2 1 6a9 1
6a4 2 6bc 6be
3 6ba 6bb 6c0
2 6c9 6cb 2
6cd 6cf 2 6d1
6d3 2 6d5 6d7
2 6d9 6db 3
6e0 6e1 6e2 2
6dd 6e4 2 6c8
6e6 1 6e8 1
6ea 2 6b3 6eb
1 6ef 1 6ae
2 6ac 6f3 2
67b 6f6 1 705
2 704 705 1
70d 1 713 2
715 716 2 702
717 1 71e 1
719 2 731 733
3 72f 730 735
2 73e 740 2
742 744 2 746
748 2 74a 74c
2 74e 750 3
755 756 757 2
752 759 2 73d
75b 1 75d 1
75f 2 728 760
1 764 1 723
2 721 768 1
76b 2 76e 76f
1 770 2 772
773 1 774 2
776 777 1 77f
2 77b 77f 1
785 1 787 2
793 794 5 78e
78f 790 791 796
2 79b 79c 1
7a0 2 79e 7a0
2 7a5 7a6 2
7a8 7a9 1 7ae
2 7ac 7ae 2
7b3 7b4 1 7b8
2 7b6 7b8 1
7c2 2 7c4 7c5
1 7cb 2 7cd
7ce 2 7c7 7d0
2 7d3 7d5 2
7db 7dc 2 7d8
7de 1 7e0 1
7e6 2 7e4 7e6
1 7ed 1 7ef
2 7ea 7ef 1
805 2 804 805
1 80d 1 813
2 815 816 2
802 817 1 81e
1 819 2 831
833 3 82f 830
835 2 83e 840
2 842 844 2
846 848 2 84a
84c 2 84e 850
3 855 856 857
2 852 859 2
83d 85b 1 85d
1 85f 2 828
860 1 864 1
823 2 821 868
1 86b 1 879
2 878 879 1
881 1 887 2
889 88a 2 876
88b 1 892 1
88d 2 8a5 8a7
3 8a3 8a4 8a9
2 8b2 8b4 2
8b6 8b8 2 8ba
8bc 2 8be 8c0
2 8c2 8c4 3
8c9 8ca 8cb 2
8c6 8cd 2 8b1
8cf 1 8d1 1
8d3 2 89c 8d4
1 8d8 1 897
2 895 8dc 1
8df 2 8e2 8e3
2 8e7 8e8 3
7e3 8e4 8eb 1
8ed 1 8ee 1
8f0 9 352 366
375 378 778 788
78b 799 8f1 2
8f7 8fd 1 904
1 8ff 2 917
919 3 915 916
91b 2 924 926
2 928 92a 2
92c 92e 2 930
932 2 934 936
3 93b 93c 93d
2 938 93f 2
923 941 1 943
1 945 2 90e
946 1 94a 1
909 2 907 94e
3 347 8f4 951
2 954 955 1
96e 2 96d 96e
1 976 1 97c
2 97e 97f 2
96b 980 1 987
1 982 2 99a
99c 3 998 999
99e 2 9a7 9a9
2 9ab 9ad 2
9af 9b1 2 9b3
9b5 2 9b7 9b9
3 9be 9bf 9c0
2 9bb 9c2 2
9a6 9c4 1 9c6
1 9c8 2 991
9c9 1 9cd 1
98c 2 98a 9d1
1 9d6 6 283
297 2a6 956 9d4
9d9 2 9df 9e5
1 9ec 1 9e7
2 9ff a01 3
9fd 9fe a03 2
a0c a0e 2 a10
a12 2 a14 a16
2 a18 a1a 2
a1c a1e 3 a23
a24 a25 2 a20
a27 2 a0b a29
1 a2b 1 a2d
2 9f6 a2e 1
a32 1 9f1 2
9ef a36 2 a3c
a3d 1 a42 1
a44 2 a3f a44
1 a49 1 a4c
1 a4e 7 211
217 276 27a 9dc
a39 a4f 1 a51
2 a5b a5d 3
a59 a5a a5f 2
a68 a6a 2 a6c
a6e 2 a70 a72
1 a7a 2 a7c
a7d 2 a74 a7f
2 a81 a83 2
a85 a87 2 a89
a8b 2 a8d a8f
2 a67 a91 1
a93 1 a95 3
a9c a9d a9e a
163 182 185 188
18b 18e 1f2 a52
a96 aa0 2 aad
aaf 3 aab aac
ab1 2 aba abc
2 ab9 abe 2
ac5 ac9 2 acb
acd 2 acf ad3
2 ac4 ad5 2
ac0 ad7 1 ad9
3 ada ae5 ae9
1 aa4 2 afc
afe 3 afa afb
b00 2 b09 b0b
2 b08 b0d 2
b14 b16 2 b18
b1a 3 b1f b20
b21 2 b1c b23
2 b13 b25 2
b0f b27 1 b29
4 af3 b2a b33
b37 1 b3b 1
aee 2 aec b3f
1c 19 20 27
2c 33 3a 41
47 4d 53 58
5e 64 6a 70
76 7c 82 88
8f 96 9c a2
a8 ad ea 109
113 
1
4
0 
b46
0
1
28
26
21
0 1 1 1 4 1 6 1
8 9 8 b c b e b
10 b 12 b 14 b 16 b
18 b 1a b 1c b 1e 8
20 8 22 1 24 1 0 0

b 1 0
60 1 0
3 1 0
7e 1 0
16 1 0
35 1 0
98 1 0
2 0 1
9d6 8 24
84 1 0
5a 1 0
49 1 0
29 1 0
8a 1 0
f0 1 3
43 1 0
72 1 0
2e 1 0
22 1 0
78 1 0
a4 1 0
3c 1 0
6c 1 0
9e 1 0
4f 1 0
55 1 0
1b 1 0
66 1 0
7 1 0
91 1 0
b0 1 2
aa 1 0
10e 1 0
0

/
SHOW ERRORS FUNCTION SP_RJCT_ETC_WBS;
ALTER FUNCTION SP_RJCT_ETC_WBS COMPILE DEBUG;
Prompt == FUNCTION SP_U_WP_FORECAST ==
CREATE OR REPLACE FUNCTION SP_U_WP_FORECAST wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
138
2 :e:
1FUNCTION:
1SP_U_WP_FORECAST:
1ID:
1VARCHAR2:
1START_DATE001:
1TIMESTAMP:
1FINISH_DATE001:
1ACC_REJ_BITFLAG:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_REC_STATUS:
11:
1H_PROJECT_ID:
132:
1H_TASK_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_TSK_ASSIGNMENT_ID:
1H_RES_ASSIGNMENT_ID:
1H_RES_ID:
1H_REC_USER:
1H_SECURITY_ID:
1H_START_DATE:
1H_FINISH_DATE:
1H_START_DT:
1H_FINISH_DT:
1H_FORECAST_START:
1H_FORECAST_FINISH:
1H_ACTUAL_START:
1H_RANK:
1200:
1H_MLST_PERCENT:
10:
1H_TYPE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_TA_START_DT:
1H_TA_FINISH_DT:
1H_LAST_SUBMITTED:
1DATE:
1H_PROJAFFECTED_START:
1H_DAYOFYEAR:
1H_WEEK_OF:
1H_BIT_FLAG:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_ETC:
1H_TOTAL:
1H_SCHED_WORK:
1H_CONTINUE:
1H_EFFORT:
1H_CONTOUR:
1H_BITFLAG:
1H_ACC_REJ_BITFLAG:
1H_REMAINING:
1H_FF:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_ALERT_FLAG:
1H_ALERT_ID:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_FORECAST(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
168:
1+:
1FPUT:
1               ENTER:: SP_U_WP_FORECAST(69) :: cplan.sql(21696) :: :
1:
1=:
1PMO_CNST:
1SC_ACCEPT_REJECT_FORECAST:
1PROJECT_ID:
1RES_ASSIGNMENT_ID:
1PROJECT_ASSIGNMENT_ID:
1ACTUAL_START:
1MILESTONE_PERCENT:
1BIT_FLAG:
1FORECAST_START:
1SCHED_START:
1FORECAST_FINISH:
1SCHED_FINISH:
1TASK_ID:
1RESOURCE_ID:
1SCHED_WORK:
1PLANNED_WORK:
1WORK_TODATE:
1ETC:
1C_CONTOUR:
1LAST_SUBMITTED:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, RES_ASSIGNMENT_ID, PROJECT_ASSIGNMENT_ID, ACTUAL_START, MI+
1LESTONE_PERCENT, BIT_FLAG, :n      COALESCE(FORECAST_START,SCHED_START), COAL+
1ESCE(FORECAST_FINISH,SCHED_FINISH), FORECAST_START, FORECAST_FINISH, TASK_ID,+
1 RESOURCE_ID, SCHED_WORK, (PLANNED_WORK + SCHED_WORK - WORK_TODATE), ETC,:n  +
1    C_CONTOUR, LAST_SUBMITTED, UNRESOLVED_START, UNRESOLVED_FINISH, BILLABLE,+
1 CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RATE:n      INTO h_project_id, h_res_+
1assignment_id, h_prj_assignment_id, h_actual_start, h_mlst_percent, h_bit_fla+
1g,:n      h_start_DT, h_finish_DT, h_forecast_start, h_forecast_finish, h_tas+
1k_id, h_res_id, h_sched_work,h_remaining, h_etc,:n      h_contour, h_last_sub+
1mitted, h_ta_start_DT, h_ta_finish_DT, h_billable, h_capital_expense, h_reg_c+
1ost, h_reg_sale:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID =+
1 id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1104:
1           EXCEPTION:: SP_U_WP_FORECAST(105) :: cplan.sql(21732) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1112:
1        RETURN_ERROR:: SP_U_WP_FORECAST(113) :: cplan.sql(21740) :: :
1STATE:: :
1RECORD_NOT_FOUND:
1 ID:: :
1115:
1                EXIT:: SP_U_WP_FORECAST(116) :: cplan.sql(21743) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1REC_STATUS:
1TMT_WBS:
1ELEMENT_ID:
1SELECT REC_STATUS:n      INTO h_rec_status:n      FROM TMT_WBS:n      WHERE P+
1ROJECT_ID = h_project_id:n      AND ELEMENT_ID = h_task_id:
1134:
1           EXCEPTION:: SP_U_WP_FORECAST(135) :: cplan.sql(21762) :: :
1T:
1141:
1        RETURN_ERROR:: SP_U_WP_FORECAST(142) :: cplan.sql(21769) :: :
1CANNOT_UPDATE_LOCKED_RECORD:
1144:
1                EXIT:: SP_U_WP_FORECAST(145) :: cplan.sql(21772) :: :
110000:
1151:
1        RETURN_ERROR:: SP_U_WP_FORECAST(152) :: cplan.sql(21779) :: :
1ASSIGNMENT_ALREADY_CLOSED:
1154:
1                EXIT:: SP_U_WP_FORECAST(155) :: cplan.sql(21782) :: :
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1<:
1162:
1        RETURN_ERROR:: SP_U_WP_FORECAST(163) :: cplan.sql(21790) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1165:
1                EXIT:: SP_U_WP_FORECAST(166) :: cplan.sql(21793) :: :
1MAX:
1WEEK_OF:
1TIMESHEET_APPROVAL_STATUS:
1CURRENT_STATE:
1SC_APV_STATE_RM_APPROVED:
1SC_APV_STATE_PM_APPROVED:
1SC_APV_STATE_SUBMITTED:
1SELECT MAX(WEEK_OF) + 7      INTO h_week_of FROM TIMESHEET_APPROVAL_STATUS:n +
1     WHERE ELEMENT_ID = h_project_id AND RESOURCE_ID = h_res_id:n      AND CU+
1RRENT_STATE IN (pmo_cnst.SC_APV_STATE_RM_APPROVED,pmo_cnst.SC_APV_STATE_PM_AP+
1PROVED,pmo_cnst.SC_APV_STATE_SUBMITTED):
1184:
1           EXCEPTION:: SP_U_WP_FORECAST(185) :: cplan.sql(21812) :: :
1STRCMP:
1!=:
1SCETCFORCASTCHANGED:
1FC_ISSUE_ALERT:
1SCREDUCEDETC:
1IS NULL:
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET:n         FORECAST_START  = start_date001,:n     +
1    FORECAST_FINISH = finish_date001,:n         FORECAST_DURATION = 0:n      +
1   WHERE TSK_ASSIGNMENT_ID = id:
1FOUND:
1100:
1230:
1           EXCEPTION:: SP_U_WP_FORECAST(231) :: cplan.sql(21858) :: :
1UPDATE TASK_ASSIGNMENTS SET:n            FORECAST_START  = start_date001,:n  +
1          FORECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = id:
1257:
1           EXCEPTION:: SP_U_WP_FORECAST(258) :: cplan.sql(21885) :: :
1UPDATE TASK_ASSIGNMENTS SET:n            FORECAST_FINISH = finish_date001,:n +
1           FORECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = id:
1289:
1           EXCEPTION:: SP_U_WP_FORECAST(290) :: cplan.sql(21917) :: :
1>:
1313:
1        RETURN_ERROR:: SP_U_WP_FORECAST(314) :: cplan.sql(21941) :: :
1FORECAST_APPROVAL_EXISTS:
1316:
1                EXIT:: SP_U_WP_FORECAST(317) :: cplan.sql(21944) :: :
1324:
1        RETURN_ERROR:: SP_U_WP_FORECAST(325) :: cplan.sql(21952) :: :
1CANNOT_UPDATE_HAS_ACTUAL:
1327:
1                EXIT:: SP_U_WP_FORECAST(328) :: cplan.sql(21955) :: :
1ELSIF:
1DB2TIMESTAMP:
1DAY_YEAR:
1TIME:
1PMO_STPU:
1FIRST_AVAIL_TIME:
1BIT_SCHED:
1CALENDAR_DAY_OF_YEAR:
1TO_DATE:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.FIRST_AVAIL+
1_TIME(BIT_SCHED))) INTO h_start_date:n                  FROM CALENDAR_DAY_OF_+
1YEAR:n                  WHERE ELEMENT_ID = h_project_id:n                  AN+
1D DAY_YEAR = TO_DATE(SubStr(start_date001, 1, 10)):
1350:
1           EXCEPTION:: SP_U_WP_FORECAST(351) :: cplan.sql(21978) :: :
1DUAL:
1SELECT  (PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(start_date001, 1, 10)), PMO_O+
1RASTD.TIME('08::00')))  INTO  h_start_date FROM DUAL:
1367:
1           EXCEPTION:: SP_U_WP_FORECAST(368) :: cplan.sql(21995) :: :
1374:
1        RETURN_ERROR:: SP_U_WP_FORECAST(375) :: cplan.sql(22002) :: :
1377:
1                EXIT:: SP_U_WP_FORECAST(378) :: cplan.sql(22005) :: :
1390:
1        RETURN_ERROR:: SP_U_WP_FORECAST(391) :: cplan.sql(22018) :: :
1INVALID_PARAMS:
1393:
1                EXIT:: SP_U_WP_FORECAST(394) :: cplan.sql(22021) :: :
1<=:
18:
1399:
1      RETURN_INVALID:: SP_U_WP_FORECAST(400) :: cplan.sql(22027) :: :
1402:
1                EXIT:: SP_U_WP_FORECAST(403) :: cplan.sql(22030) :: :
1PMO_RETURN_INVALID_SP:
1LAST_AVAIL_TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.LAST_AVAIL_+
1TIME(BIT_SCHED))) INTO h_finish_date:n                  FROM CALENDAR_DAY_OF_+
1YEAR:n                  WHERE ELEMENT_ID = h_project_id:n                  AN+
1D DAY_YEAR = TO_DATE(SubStr(finish_date001, 1, 10)):
1431:
1           EXCEPTION:: SP_U_WP_FORECAST(432) :: cplan.sql(22059) :: :
1SELECT  (PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(finish_date001, 1, 10)), PMO_+
1ORASTD.TIME('17::00')))  INTO  h_finish_date FROM DUAL:
1449:
1           EXCEPTION:: SP_U_WP_FORECAST(450) :: cplan.sql(22077) :: :
1457:
1        RETURN_ERROR:: SP_U_WP_FORECAST(458) :: cplan.sql(22085) :: :
1460:
1                EXIT:: SP_U_WP_FORECAST(461) :: cplan.sql(22088) :: :
1UPDATE TASK_ASSIGNMENTS SET:n               FORECAST_START  = h_start_date,:n+
1               FORECAST_FINISH = h_finish_date,:n               FORECAST_DURA+
1TION = 0:n               WHERE TSK_ASSIGNMENT_ID = id:
1491:
1           EXCEPTION:: SP_U_WP_FORECAST(492) :: cplan.sql(22119) :: :
1COUNT:
1TASK_DAY_OF_YEAR:
1SELECT COUNT('X') INTO h_temp_var:n                     FROM DUAL:n          +
1           WHERE EXISTS (SELECT DAY_YEAR FROM TASK_DAY_OF_YEAR:n             +
1        WHERE PROJECT_ID = h_project_id AND ((TSK_ASSIGNMENT_ID = h_prj_assig+
1nment_id) OR (TSK_ASSIGNMENT_ID = h_tsk_assignment_id)):n                    +
1 AND DAY_YEAR = TO_DATE(SubStr(finish_date001, 1, 10))):
1516:
1           EXCEPTION:: SP_U_WP_FORECAST(517) :: cplan.sql(22144) :: :
1524:
1        RETURN_ERROR:: SP_U_WP_FORECAST(525) :: cplan.sql(22152) :: :
1PROJECT_ASSIGNMENT_REMAINING:
1527:
1                EXIT:: SP_U_WP_FORECAST(528) :: cplan.sql(22155) :: :
1SELECT COUNT('X') INTO h_temp_var:n                     FROM DUAL:n          +
1           WHERE EXISTS (SELECT DAY_YEAR FROM TASK_DAY_OF_YEAR:n             +
1        WHERE PROJECT_ID = h_project_id AND ((TSK_ASSIGNMENT_ID = h_prj_assig+
1nment_id) OR (TSK_ASSIGNMENT_ID = h_tsk_assignment_id)):n                    +
1 AND DAY_YEAR = TO_DATE(SubStr(start_date001, 1, 10))):
1549:
1           EXCEPTION:: SP_U_WP_FORECAST(550) :: cplan.sql(22177) :: :
1557:
1        RETURN_ERROR:: SP_U_WP_FORECAST(558) :: cplan.sql(22185) :: :
1560:
1                EXIT:: SP_U_WP_FORECAST(561) :: cplan.sql(22188) :: :
1SUM:
1SCHED_MIN:
1PARENT_ID:
1SELECT SUM(SCHED_MIN) INTO h_total FROM TASK_DAY_OF_YEAR:n                   +
1     WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_prj_assignment_id AND +
1DAY_YEAR >= TO_DATE(SubStr(start_date001, 1, 10)):
1580:
1           EXCEPTION:: SP_U_WP_FORECAST(581) :: cplan.sql(22208) :: :
1586:
1        RETURN_ERROR:: SP_U_WP_FORECAST(587) :: cplan.sql(22214) :: :
1589:
1                EXIT:: SP_U_WP_FORECAST(590) :: cplan.sql(22217) :: :
1597:
1        RETURN_ERROR:: SP_U_WP_FORECAST(598) :: cplan.sql(22225) :: :
1TASK_ASSIGNMENT_ERROR:
1600:
1                EXIT:: SP_U_WP_FORECAST(601) :: cplan.sql(22228) :: :
12:
1FC_ACPT_ETC_ASSIGN:
1U_ASSIGN_STRING:
13:
1FC_ROLLUP:
14:
1651:
1       RETURN_STATUS:: SP_U_WP_FORECAST(652) :: cplan.sql(22279) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1659:
1           EXCEPTION:: SP_U_WP_FORECAST(660) :: cplan.sql(22287) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_ID:
1OPEN:
1ERROR:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1671:
1           EXCEPTION:: SP_U_WP_FORECAST(672) :: cplan.sql(22299) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1218
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :2 a0 6e 7e a0
b4 2e 7e 6e b4 2e 6e a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :2 a0 6e 7e a0 b4
2e 7e 6e b4 2e 6e a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 6e
d a0 6e d a0 51 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
51 a5 b 7e 51 b4 2e 5a
:3 a0 6b d b7 19 3c :37 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :7 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 :2 51 a5
b 7e 6e b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c a0 7e b4 2e :2 5a a0 7e
b4 2e :2 5a a 10 :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 19 3c a0 4d d :f a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 d :2 a0 6b :2 a0 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b a0 7e a0 6b b4 2e 5a
a 10 a0 6e d a0 51 d
:3 a0 6b d :6 a0 51 a5 b d
:2 a0 6b a0 d a0 6e d a0
51 d :3 a0 6b d :6 a0 51 a5
b d :2 a0 6b a0 d b7 19
3c a0 7e b4 2e :2 5a :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 d b7 19 3c
a0 7e b4 2e :2 5a a0 7e b4
2e :2 5a a 10 :8 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a0 7e b4
2e 5a a0 7e b4 2e 5a a
10 :6 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e a0 51 d b7 19
3c b7 19 3c a0 7e b4 2e
5a a0 7e b4 2e 5a a 10
:6 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 19 3c
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e a0 7e b4 2e :2 5a
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 d b7
19 3c a0 7e b4 2e :2 5a a0
7e b4 2e :2 5a a 10 :2 a0 6b
:2 a0 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c a0 7e b4 2e
5a a0 7e b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:2 a0 d :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a0 4d d a0
b7 :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e :10 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :9 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c a0 b7 19 a0 7e
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :2 a0 51 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b 51 :2 a0 a5
57 b7 :2 19 3c b7 a0 51 d
a0 4d d b7 :2 19 3c a0 7e
b4 2e 5a a0 7e b4 2e :2 5a
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 a0 b7 a0 7e
b4 2e :2 5a :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
:2 19 3c a0 7e b4 2e :2 5a :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 a0 51 d b7
a0 51 d b7 :2 19 3c :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
a0 4d d a0 b7 :2 a0 6b :2 a0
a5 b 7e 51 b4 2e :10 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c a0 b7
19 :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :2 a0 51 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b 51 :2 a0 a5
57 b7 :2 19 3c b7 a0 4d d
b7 :2 19 3c :2 a0 d a0 51 d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a0 7e b4 2e 5a
a0 7e b4 2e 5a a0 51 d
:f a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c a0 b7 a0 7e
b4 2e 5a a0 51 d :f a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 :2 19 3c b7 19 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 19 3c b7
19 3c a0 51 d :2 a0 d a0
7e b4 2e 5a a0 7e b4 2e
:2 5a a 10 :2 a0 d b7 19 3c
:18 a0 51 a5 b d a0 51 d
:5 a0 :2 51 a5 b d a0 7e b4
2e 5a a0 51 d :5 a0 :2 51 a5
b d b7 19 3c b7 :2 19 3c
b7 19 3c b7 :2 19 3c :2 a0 6b
:2 a0 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a 10 a0 6e d
a0 51 d :3 a0 6b d :6 a0 51
a5 b d :2 a0 6b a0 d a0
6e d a0 51 d :3 a0 6b d
:6 a0 51 a5 b d :2 a0 6b a0
d b7 19 3c :3 a0 a5 b d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
1218
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 56
7c 80 84 88 8b 8f ac 97
9b 9e 9f a7 96 c9 b7 93
bb bc c4 b6 e6 d4 b3 d8
d9 e1 d3 103 f1 d0 f5 f6
fe f0 120 10e ed 112 113 11b
10d 13d 12b 10a 12f 130 138 12a
15a 148 127 14c 14d 155 147 177
165 144 169 16a 172 164 194 182
161 186 187 18f 181 1b0 19f 1a3
1ab 17e 1c8 1b7 1bb 1c3 19e 1e4
1d3 1d7 1df 19b 1fc 1eb 1ef 1f7
1d2 218 207 20b 213 1cf 230 21f
223 22b 206 24c 23b 23f 247 203
268 253 257 25a 25b 263 23a 284
273 277 237 27f 272 2a0 28f 293
26f 29b 28e 2bc 2ab 2af 28b 2b7
2aa 2d8 2c7 2cb 2a7 2d3 2c6 2f4
2e3 2e7 2ef 2c3 30c 2fb 2ff 307
2e2 328 317 31b 323 2df 340 32f
333 33b 316 35c 34b 34f 357 313
374 363 367 36f 34a 391 37f 347
383 384 38c 37e 3ad 39c 3a0 37b
3a8 39b 3c9 3b8 3bc 398 3c4 3b7
3e5 3d4 3d8 3b4 3e0 3d3 401 3f0
3f4 3d0 3fc 3ef 41d 40c 410 3ec
418 40b 439 428 42c 408 434 427
455 444 448 424 450 443 471 460
464 440 46c 45f 48d 47c 480 45c
488 47b 4a9 498 49c 478 4a4 497
4c5 4b4 4b8 494 4c0 4b3 4e1 4d0
4d4 4b0 4dc 4cf 4fd 4ec 4f0 4cc
4f8 4eb 519 508 50c 4e8 514 507
535 524 528 504 530 523 552 540
520 544 545 54d 53f 56e 55d 561
569 53c 589 575 579 581 584 55c
5a9 594 598 559 59c 5a4 593 5b0
5b4 590 5b8 5bc 5c0 5c3 5c8 5c9
1 5cb 5d0 5d4 5d8 5db 5e0 5e4
5e8 5eb 5f0 5f1 5f3 5f8 5fb 5ff
600 605 60a 60d 612 613 618 61b
61f 620 625 628 62d 62e 633 636
63b 63c 641 644 648 64c 651 654
658 659 65e 661 666 667 66c 671
672 674 679 67a 67c 67d 682 685
68a 68b 690 693 697 69b 6a0 6a3
6a7 6a8 6ad 6b0 6b5 6b6 6bb 6c0
6c1 6c3 6c8 6c9 6cb 6cc 6d1 6d4
6d9 6da 6df 6e2 6e6 6ea 6ee 6ef
6f1 6f6 6f7 6f9 6fa 6ff 702 707
708 70d 710 715 716 71b 71e 722
723 728 72b 730 731 736 739 73e
73f 744 745 74a 74c 750 753 757
75b 75e 762 766 769 76c 771 774
777 77a 77b 780 781 1 783 788
78c 790 793 798 79d 7a0 7a4 7a5
7aa 7ab 7b0 7b2 7b6 7b9 7bd 7c2
7c6 7ca 7cf 7d3 7d7 7da 7de 7e2
7e6 7ea 7ee 7f2 7f6 7fa 7fe 802
806 80a 80e 812 816 819 81a 81c
81f 822 823 828 82b 82f 833 837
83a 83e 840 844 847 84b 84f 853
857 85b 85f 863 867 86b 86f 873
877 87b 87f 883 887 88b 88f 893
897 89b 89f 8a3 8a7 8ab 8af 8b3
8b7 8bb 8bf 8c3 8c7 8cb 8cf 8d3
8d7 8db 8df 8e3 8e7 8eb 8ef 8f3
8f7 8fb 8ff 903 907 90b 90f 913
917 91b 91f 923 92f 933 937 93a
93e 942 944 948 94c 950 953 957
95b 95d 95e 963 1 967 96b 96f
972 976 97a 97e 982 985 989 98d
990 993 998 99b 99e 9a1 9a2 9a7
9a8 1 9aa 9af 9b3 9b7 9ba 9bf
9c4 9c7 9cb 9cc 9d1 9d4 9d9 9da
9df 9e2 9e7 9e8 9ed 9f0 9f4 9f5
9fa 9fd a02 a03 a08 a0b a0f a13
a16 a19 a1a a1c a1d a22 a23 a28
a2a a2e a31 a33 a37 a39 a45 a47
a49 a4a a4f a53 a55 a61 a63 a67
a6b a6e a72 a75 a79 a7c a7d a82
a85 a89 a8d a90 a94 a98 a9b a9e
aa3 aa6 aa9 aac aad ab2 ab3 1
ab5 aba abe ac2 ac5 aca acf ad2
ad6 ad7 adc adf ae4 ae5 aea aed
af2 af3 af8 afb aff b03 b07 b0b
b0e b0f b11 b16 b17 b19 b1a b1f
b22 b27 b28 b2d b30 b35 b36 b3b
b3e b42 b43 b48 b4b b50 b51 b56
b57 b5c b5e b62 b65 b69 b6d b70
b74 b78 b7b b7e b83 b86 b89 b8c
b8d b92 b93 1 b95 b9a b9e ba2
ba5 baa baf bb2 bb6 bb7 bbc bbd
bc2 bc4 bc8 bcb bcf bd3 bd6 bda
bde be1 be5 be9 bea bef bf1 bf5
bf8 bfc c00 c04 c08 c0c c10 c14
c20 c24 c28 c2b c2f c33 c35 c39
c3d c41 c44 c48 c4c c4e c4f c54
1 c58 c5c c60 c63 c67 c6b c6f
c73 c76 c7a c7e c81 c84 c89 c8c
c8f c92 c93 c98 c99 1 c9b ca0
ca4 ca8 cab cb0 cb5 cb8 cbc cbd
cc2 cc5 cca ccb cd0 cd3 cd8 cd9
cde ce1 ce5 ce6 ceb cee cf3 cf4
cf9 cfc d00 d04 d07 d0a d0b d0d
d0e d13 d14 d19 d1b d1f d22 d24
d28 d2a d36 d38 d3a d3b d40 d44
d46 d52 d54 d58 d5c d5f d62 d63
d65 d68 d6d d6e d73 d77 d7b d7e
d82 d86 d89 d8c d91 d94 d97 d9a
d9b da0 da1 1 da3 da8 dac db0
db3 db8 dbd dc0 dc4 dc5 dca dcd
dd2 dd3 dd8 ddb de0 de1 de6 de9
ded df1 df5 df9 dfc dfd dff e04
e05 e07 e08 e0d e10 e15 e16 e1b
e1e e23 e24 e29 e2c e30 e31 e36
e39 e3e e3f e44 e45 e4a e4c e50
e53 e57 e5b e5e e62 e66 e69 e6c
e71 e74 e77 e7a e7b e80 e81 1
e83 e88 e8c e90 e93 e98 e9d ea0
ea4 ea5 eaa eab eb0 eb2 eb6 eb9
ebd ec1 ec4 ec8 ecc ecf ed3 ed7
ed8 edd edf ee3 ee6 eea eee ef1
ef2 ef4 ef7 efa efb f00 f04 f08
f0b f0f f13 f16 f19 f1e f21 f24
f27 f28 f2d f2e 1 f30 f35 f39
f3d f40 f45 f4a f4d f51 f52 f57
f5a f5f f60 f65 f68 f6d f6e f73
f76 f7a f7e f82 f86 f89 f8a f8c
f91 f92 f94 f95 f9a f9d fa2 fa3
fa8 fab fb0 fb1 fb6 fb9 fbd fbe
fc3 fc6 fcb fcc fd1 fd2 fd7 fd9
fdd fe0 fe4 fe8 feb fef ff3 ff6
ff9 ffe 1001 1004 1007 1008 100d 100e
1 1010 1015 1019 101d 1020 1025 102a
102d 1031 1032 1037 1038 103d 103f 1043
1046 104a 104e 1051 1055 1059 105c 1060
1064 1065 106a 106c 1070 1073 1077 107a
107b 1080 1083 1086 108a 108d 108e 1093
1096 1 1099 109e 10a2 10a6 10a9 10ad
10b1 10b4 10b5 10b7 10ba 10bd 10be 10c3
10c7 10cb 10ce 10d2 10d6 10d9 10dc 10e1
10e4 10e7 10ea 10eb 10f0 10f1 1 10f3
10f8 10fc 1100 1103 1108 110d 1110 1114
1115 111a 111d 1122 1123 1128 112b 1130
1131 1136 1139 113d 1141 1145 1149 114c
114d 114f 1154 1155 1157 1158 115d 1160
1165 1166 116b 116e 1173 1174 1179 117c
1180 1181 1186 1189 118e 118f 1194 1195
119a 119c 11a0 11a3 11a7 11ab 11ae 11b2
11b6 11b9 11bc 11c1 11c4 11c7 11ca 11cb
11d0 11d1 1 11d3 11d8 11dc 11e0 11e3
11e8 11ed 11f0 11f4 11f5 11fa 11fb 1200
1202 1206 1209 120d 1211 1214 1218 121c
121f 1223 1227 1228 122d 122f 1233 1236
1238 123c 123f 1243 1244 1248 124c 1250
1254 1258 125c 1260 1264 1268 126c 1270
1274 1278 127c 1280 1284 1290 1294 1298
129b 129f 12a3 12a5 12a9 12ad 12b1 12b4
12b8 12bc 12be 12bf 12c4 1 12c8 12cc
12d0 12d3 12d7 12db 12df 12e3 12e6 12ea
12ee 12f1 12f4 12f9 12fc 12ff 1302 1303
1308 1309 1 130b 1310 1314 1318 131b
1320 1325 1328 132c 132d 1332 1335 133a
133b 1340 1343 1348 1349 134e 1351 1355
1356 135b 135e 1363 1364 1369 136c 1370
1374 1377 137a 137b 137d 137e 1383 1384
1389 138b 138f 1392 1394 1398 139a 13a6
13a8 13aa 13ab 13b0 13b4 13b6 13c2 13c4
13c8 13cc 13d0 13d4 13d8 13db 13df 13e3
13e4 13e6 13e9 13ec 13ed 13f2 13f5 13f9
13fd 1400 1401 1403 1407 140a 140e 1411
1412 1417 1 141a 141f 1423 1428 142c
1430 1433 1437 143b 143f 1443 1446 144a
144e 1452 1456 145a 145e 1462 1465 1466
1468 146c 1470 1474 1477 147b 147f 1483
1488 148c 1490 1493 1497 149b 149f 14a3
14a6 14aa 14ae 14b2 14b6 14ba 14be 14c2
14c5 14c6 14c8 14cc 14d0 14d4 14d7 14db
14df 14e1 14e5 14e8 14ec 14ef 14f0 14f5
14f8 14fb 14ff 1503 1506 150a 150e 1511
1512 1514 1517 151a 151b 1520 1 1523
1528 152c 1530 1534 1536 153a 153d 1541
1544 1545 154a 154d 1550 1554 1557 1558
155d 1560 1 1563 1568 156c 1570 1574
1578 157c 1580 1584 1588 1594 1598 159d
15a1 15a4 15a5 15aa 15ae 15b2 15b5 15b8
15bc 15be 15c2 15c6 15c9 15cc 15d0 15d2
15d6 15da 15dd 15df 15e3 15e7 15eb 15ee
15f2 15f6 15f8 15f9 15fe 1 1602 1606
160a 160d 1611 1615 1619 161d 1620 1624
1628 162b 162e 1633 1636 1639 163c 163d
1642 1643 1 1645 164a 164e 1652 1655
165a 165f 1662 1666 1667 166c 166f 1674
1675 167a 167d 1682 1683 1688 168b 168f
1690 1695 1698 169d 169e 16a3 16a6 16aa
16ae 16b1 16b4 16b5 16b7 16b8 16bd 16be
16c3 16c5 16c9 16cc 16ce 16d2 16d4 16e0
16e2 16e4 16e5 16ea 16ee 16f0 16fc 16fe
1700 1704 1707 1708 170d 1710 1714 1717
1718 171d 1 1720 1725 1729 172d 1731
1735 1739 173d 1749 174d 1752 1756 1759
175a 175f 1763 1767 176a 176d 1771 1773
1777 177b 177e 1781 1785 1787 178b 178f
1792 1794 1798 179c 17a0 17a3 17a7 17ab
17ad 17ae 17b3 1 17b7 17bb 17bf 17c2
17c6 17ca 17ce 17d2 17d5 17d9 17dd 17e0
17e3 17e8 17eb 17ee 17f1 17f2 17f7 17f8
1 17fa 17ff 1803 1807 180a 180f 1814
1817 181b 181c 1821 1824 1829 182a 182f
1832 1837 1838 183d 1840 1844 1845 184a
184d 1852 1853 1858 185b 185f 1863 1866
1869 186a 186c 186d 1872 1873 1878 187a
187e 1881 1883 1887 1889 1895 1897 1899
189a 189f 18a3 18a5 18b1 18b3 18b7 18bb
18be 18c2 18c6 18c9 18ca 18cc 18cf 18d2
18d3 18d8 18dc 18df 18e3 18e5 18e9 18ec
18ee 18f2 18f5 18f9 18fc 18fd 1902 1905
1909 190c 190d 1912 1 1915 191a 191e
1922 1926 192a 192e 1932 193e 1942 1947
194b 194e 194f 1954 1958 195c 195f 1962
1966 1968 196c 1970 1973 1976 197a 197c
1980 1984 1987 1989 198d 1991 1995 1998
199c 19a0 19a2 19a3 19a8 1 19ac 19b0
19b4 19b7 19bb 19bf 19c3 19c7 19ca 19ce
19d2 19d5 19d8 19dd 19e0 19e3 19e6 19e7
19ec 19ed 1 19ef 19f4 19f8 19fc 19ff
1a04 1a09 1a0c 1a10 1a11 1a16 1a19 1a1e
1a1f 1a24 1a27 1a2c 1a2d 1a32 1a35 1a39
1a3a 1a3f 1a42 1a47 1a48 1a4d 1a50 1a54
1a58 1a5b 1a5e 1a5f 1a61 1a62 1a67 1a68
1a6d 1a6f 1a73 1a76 1a78 1a7c 1a7e 1a8a
1a8c 1a8e 1a8f 1a94 1a98 1a9a 1aa6 1aa8
1aac 1ab0 1ab3 1ab7 1abb 1abe 1abf 1ac1
1ac4 1ac7 1ac8 1acd 1ad1 1ad4 1ad8 1ada
1ade 1ae1 1ae3 1ae7 1aea 1aee 1af2 1af5
1af6 1af8 1afb 1afe 1aff 1b04 1b08 1b0b
1b0c 1b11 1b14 1b17 1b1b 1b1f 1b22 1b26
1b2a 1b2d 1b2e 1b30 1b33 1b36 1b37 1b3c
1 1b3f 1b44 1b48 1b4c 1b50 1b52 1b56
1b59 1b5d 1b60 1b61 1b66 1b69 1b6c 1b70
1b73 1b74 1b79 1b7c 1 1b7f 1b84 1b88
1b8c 1b8f 1b93 1b97 1b98 1b9a 1b9d 1ba0
1ba1 1ba6 1 1ba9 1bae 1bb2 1bb6 1bb9
1bbd 1bc1 1bc4 1bc7 1bcc 1bcf 1bd2 1bd5
1bd6 1bdb 1bdc 1 1bde 1be3 1be7 1beb
1bee 1bf3 1bf8 1bfb 1bff 1c00 1c05 1c08
1c0d 1c0e 1c13 1c16 1c1b 1c1c 1c21 1c24
1c28 1c2c 1c30 1c34 1c37 1c38 1c3a 1c3f
1c40 1c42 1c43 1c48 1c4b 1c50 1c51 1c56
1c59 1c5e 1c5f 1c64 1c67 1c6b 1c6c 1c71
1c74 1c79 1c7a 1c7f 1c80 1c85 1c87 1c8b
1c8e 1c92 1c96 1c99 1c9d 1ca1 1ca4 1ca7
1cac 1caf 1cb2 1cb5 1cb6 1cbb 1cbc 1
1cbe 1cc3 1cc7 1ccb 1cce 1cd3 1cd8 1cdb
1cdf 1ce0 1ce5 1ce6 1ceb 1ced 1cf1 1cf4
1cf8 1cfc 1cff 1d03 1d07 1d0a 1d0e 1d12
1d13 1d18 1d1a 1d1e 1d21 1d25 1d28 1d29
1d2e 1d31 1d35 1d38 1d39 1d3e 1d41 1d45
1d49 1d4c 1d50 1d54 1d57 1d5a 1d5f 1d62
1d65 1d68 1d69 1d6e 1d6f 1 1d71 1d76
1d7a 1d7e 1d81 1d86 1d8b 1d8e 1d92 1d93
1d98 1d9b 1da0 1da1 1da6 1da9 1dae 1daf
1db4 1db7 1dbb 1dbf 1dc3 1dc7 1dca 1dcb
1dcd 1dd2 1dd3 1dd5 1dd6 1ddb 1dde 1de3
1de4 1de9 1dec 1df1 1df2 1df7 1dfa 1dfe
1dff 1e04 1e07 1e0c 1e0d 1e12 1e13 1e18
1e1a 1e1e 1e21 1e25 1e29 1e2c 1e30 1e34
1e37 1e3a 1e3f 1e42 1e45 1e48 1e49 1e4e
1e4f 1 1e51 1e56 1e5a 1e5e 1e61 1e66
1e6b 1e6e 1e72 1e73 1e78 1e79 1e7e 1e80
1e84 1e87 1e8b 1e8f 1e92 1e96 1e9a 1e9d
1ea1 1ea5 1ea6 1eab 1ead 1eb1 1eb4 1eb8
1ebc 1ec0 1ec4 1ec8 1ecb 1ecf 1ed3 1ed6
1ed7 1ed9 1edc 1edf 1ee0 1ee5 1ee9 1eea
1eee 1ef2 1ef4 1ef8 1efc 1eff 1f03 1f07
1f0a 1f0b 1f0d 1f10 1f13 1f14 1f19 1f1d
1f21 1f25 1f29 1f2d 1f31 1f35 1f39 1f3d
1f41 1f45 1f49 1f4d 1f51 1f55 1f59 1f65
1f69 1f6d 1f70 1f74 1f78 1f7a 1f7e 1f82
1f86 1f89 1f8d 1f91 1f93 1f94 1f99 1
1f9d 1fa1 1fa5 1fa8 1fac 1fb0 1fb4 1fb8
1fbb 1fbf 1fc3 1fc6 1fc9 1fce 1fd1 1fd4
1fd7 1fd8 1fdd 1fde 1 1fe0 1fe5 1fe9
1fed 1ff0 1ff5 1ffa 1ffd 2001 2002 2007
200a 200f 2010 2015 2018 201d 201e 2023
2026 202a 202b 2030 2033 2038 2039 203e
2041 2045 2049 204c 204f 2050 2052 2053
2058 2059 205e 2060 2064 2067 2069 206d
206f 207b 207d 207f 2080 2085 2089 208b
2097 2099 209d 20a1 20a4 20a8 20ab 20af
20b2 20b3 20b8 20bb 20bf 20c3 20c7 20cb
20cf 20d3 20d7 20db 20df 20eb 20ef 20f3
20f6 20fa 20fe 2100 2104 2108 210c 210f
2113 2117 2119 211a 211f 1 2123 2127
212b 212e 2132 2136 213a 213e 2141 2145
2149 214c 214f 2154 2157 215a 215d 215e
2163 2164 1 2166 216b 216f 2173 2176
217b 2180 2183 2187 2188 218d 2190 2195
2196 219b 219e 21a3 21a4 21a9 21ac 21b0
21b1 21b6 21b9 21be 21bf 21c4 21c7 21cb
21cf 21d2 21d5 21d6 21d8 21d9 21de 21df
21e4 21e6 21ea 21ed 21ef 21f3 21f5 2201
2203 2205 2206 220b 220f 2211 221d 221f
2221 2225 2228 222c 222e 2232 2236 2239
223a 223f 2242 2246 224a 224d 2251 2255
2258 225b 2260 2263 2266 2269 226a 226f
2270 1 2272 2277 227b 227f 2282 2287
228c 228f 2293 2294 2299 229c 22a1 22a2
22a7 22aa 22af 22b0 22b5 22b8 22bc 22c0
22c3 22c4 22c6 22cb 22cc 22ce 22cf 22d4
22d7 22dc 22dd 22e2 22e5 22ea 22eb 22f0
22f3 22f7 22f8 22fd 2300 2305 2306 230b
230c 2311 2313 2317 231a 231e 2322 2325
2329 232d 2330 2333 2338 233b 233e 2341
2342 2347 2348 1 234a 234f 2353 2357
235a 235f 2364 2367 236b 236c 2371 2372
2377 2379 237d 2380 2384 2388 238b 238e
2392 2396 2397 239c 239e 23a2 23a6 23a9
23ab 23af 23b2 23b6 23ba 23bb 23bf 23c1
23c5 23c9 23cc 23d0 23d3 23d4 23d9 23dc
23e0 23e3 23e4 23e9 23ec 23ef 23f3 23f7
23fa 23fe 2402 2405 2406 2408 240b 240e
240f 2414 1 2417 241c 2420 2424 2427
242b 242f 2432 2435 243a 243d 2440 2443
2444 2449 244a 1 244c 2451 2455 2459
245c 2461 2466 2469 246d 246e 2473 2476
247b 247c 2481 2484 2489 248a 248f 2492
2496 249a 249e 24a2 24a5 24a6 24a8 24ad
24ae 24b0 24b1 24b6 24b9 24be 24bf 24c4
24c7 24cc 24cd 24d2 24d5 24d9 24da 24df
24e2 24e7 24e8 24ed 24ee 24f3 24f5 24f9
24fc 2500 2504 2507 250b 250f 2512 2515
251a 251d 2520 2523 2524 2529 252a 1
252c 2531 2535 2539 253c 2541 2546 2549
254d 254e 2553 2554 2559 255b 255f 2562
2566 256a 256d 2571 2575 2578 257c 2580
2581 2586 258a 258c 2590 2593 2594 2599
259c 259f 25a3 25a7 25aa 25ae 25b2 25b5
25b6 25b8 25bb 25be 25bf 25c4 1 25c7
25cc 25d0 25d4 25d7 25db 25df 25e2 25e5
25ea 25ed 25f0 25f3 25f4 25f9 25fa 1
25fc 2601 2605 2609 260c 2611 2616 2619
261d 261e 2623 2626 262b 262c 2631 2634
2639 263a 263f 2642 2646 264a 264e 2652
2655 2656 2658 265d 265e 2660 2661 2666
2667 266c 266e 2672 2675 2679 267d 2680
2684 2688 268b 268e 2693 2696 2699 269c
269d 26a2 26a3 1 26a5 26aa 26ae 26b2
26b5 26ba 26bf 26c2 26c6 26c7 26cc 26cd
26d2 26d4 26d8 26db 26df 26e3 26e6 26ea
26ee 26f1 26f5 26f6 26fb 26fd 2701 2705
2708 270c 270f 2710 2715 2718 271b 271f
2723 2726 272a 272e 2731 2732 2734 2737
273a 273b 2740 1 2743 2748 274c 274f
2753 2755 2759 275c 2760 2762 2766 276a
276d 2771 2775 2778 277c 2780 2783 2784
2786 2789 278c 278d 2792 2796 2797 279b
279f 27a1 27a5 27a9 27ac 27b0 27b4 27b5
27b7 27ba 27bd 27be 27c3 27c7 27cb 27cf
27d3 27d7 27db 27df 27e3 27e7 27eb 27ef
27f3 27f7 27fb 27ff 2803 280f 2813 2817
281a 281e 2822 2824 2828 282c 2830 2833
2837 283b 283d 283e 2843 1 2847 284b
284f 2852 2856 285a 285e 2862 2865 2869
286d 2870 2873 2878 287b 287e 2881 2882
2887 2888 1 288a 288f 2893 2897 289a
289f 28a4 28a7 28ab 28ac 28b1 28b4 28b9
28ba 28bf 28c2 28c7 28c8 28cd 28d0 28d4
28d5 28da 28dd 28e2 28e3 28e8 28eb 28ef
28f3 28f6 28f9 28fa 28fc 28fd 2902 2903
2908 290a 290e 2911 2913 2917 2919 2925
2927 2929 292a 292f 2933 2935 2941 2943
2947 294b 294e 2952 2955 2959 295c 295d
2962 2965 2969 296d 2971 2975 2979 297d
2981 2985 2989 2995 2999 299d 29a0 29a4
29a8 29aa 29ae 29b2 29b6 29b9 29bd 29c1
29c3 29c4 29c9 1 29cd 29d1 29d5 29d8
29dc 29e0 29e4 29e8 29eb 29ef 29f3 29f6
29f9 29fe 2a01 2a04 2a07 2a08 2a0d 2a0e
1 2a10 2a15 2a19 2a1d 2a20 2a25 2a2a
2a2d 2a31 2a32 2a37 2a3a 2a3f 2a40 2a45
2a48 2a4d 2a4e 2a53 2a56 2a5a 2a5b 2a60
2a63 2a68 2a69 2a6e 2a71 2a75 2a79 2a7c
2a7f 2a80 2a82 2a83 2a88 2a89 2a8e 2a90
2a94 2a97 2a99 2a9d 2a9f 2aab 2aad 2aaf
2ab0 2ab5 2ab9 2abb 2ac7 2ac9 2acb 2acf
2ad2 2ad6 2ad8 2adc 2ae0 2ae4 2ae7 2aeb
2aef 2af2 2af3 2af5 2af8 2afb 2afc 2b01
2b05 2b09 2b0c 2b10 2b14 2b17 2b1a 2b1f
2b22 2b25 2b28 2b29 2b2e 2b2f 1 2b31
2b36 2b3a 2b3e 2b41 2b46 2b4b 2b4e 2b52
2b53 2b58 2b5b 2b60 2b61 2b66 2b69 2b6e
2b6f 2b74 2b77 2b7b 2b7f 2b82 2b83 2b85
2b8a 2b8b 2b8d 2b8e 2b93 2b96 2b9b 2b9c
2ba1 2ba4 2ba9 2baa 2baf 2bb2 2bb6 2bb7
2bbc 2bbf 2bc4 2bc5 2bca 2bcb 2bd0 2bd2
2bd6 2bd9 2bdd 2be1 2be4 2be8 2bec 2bef
2bf2 2bf7 2bfa 2bfd 2c00 2c01 2c06 2c07
1 2c09 2c0e 2c12 2c16 2c19 2c1e 2c23
2c26 2c2a 2c2b 2c30 2c31 2c36 2c38 2c3c
2c3f 2c43 2c47 2c4a 2c4d 2c51 2c55 2c56
2c5b 2c5d 2c61 2c65 2c68 2c6a 2c6e 2c6f
2c73 2c75 2c79 2c7d 2c80 2c84 2c88 2c8c
2c90 2c93 2c97 2c9b 2c9f 2ca2 2ca3 2ca5
2ca9 2cac 2cb0 2cb3 2cb4 2cb9 2cbd 2cc1
2cc5 2cc9 2ccd 2cd1 2cd5 2cd9 2ce5 2ce9
2cee 2cf2 2cf5 2cf6 2cfb 2cff 2d03 2d06
2d09 2d0d 2d0f 2d13 2d17 2d1a 2d1d 2d21
2d23 2d27 2d2b 2d2e 2d30 2d34 2d38 2d3c
2d3f 2d43 2d47 2d49 2d4a 2d4f 1 2d53
2d57 2d5b 2d5e 2d62 2d66 2d6a 2d6e 2d71
2d75 2d79 2d7c 2d7f 2d84 2d87 2d8a 2d8d
2d8e 2d93 2d94 1 2d96 2d9b 2d9f 2da3
2da6 2dab 2db0 2db3 2db7 2db8 2dbd 2dc0
2dc5 2dc6 2dcb 2dce 2dd3 2dd4 2dd9 2ddc
2de0 2de1 2de6 2de9 2dee 2def 2df4 2df7
2dfb 2dff 2e02 2e05 2e06 2e08 2e09 2e0e
2e0f 2e14 2e16 2e1a 2e1d 2e1f 2e23 2e25
2e31 2e33 2e35 2e36 2e3b 2e3f 2e41 2e4d
2e4f 2e51 2e55 2e58 2e59 2e5e 2e61 2e65
2e68 2e69 2e6e 2e71 2e75 2e78 2e7c 2e80
2e84 2e88 2e8c 2e90 2e94 2e98 2e9c 2ea0
2ea4 2ea8 2eac 2eb0 2eb4 2eb8 2ec4 2ec8
2ecc 2ecf 2ed3 2ed7 2ed9 2edd 2ee1 2ee5
2ee8 2eec 2ef0 2ef2 2ef3 2ef8 1 2efc
2f00 2f04 2f07 2f0b 2f0f 2f13 2f17 2f1a
2f1e 2f22 2f25 2f28 2f2d 2f30 2f33 2f36
2f37 2f3c 2f3d 1 2f3f 2f44 2f48 2f4c
2f4f 2f54 2f59 2f5c 2f60 2f61 2f66 2f69
2f6e 2f6f 2f74 2f77 2f7c 2f7d 2f82 2f85
2f89 2f8a 2f8f 2f92 2f97 2f98 2f9d 2fa0
2fa4 2fa8 2fab 2fae 2faf 2fb1 2fb2 2fb7
2fb8 2fbd 2fbf 2fc3 2fc6 2fc8 2fcc 2fce
2fda 2fdc 2fde 2fdf 2fe4 2fe8 2fea 2ff6
2ff8 2ffc 3000 3003 3004 3006 3009 300c
300d 3012 3016 301a 301d 3021 3025 3028
302b 3030 3033 3036 3039 303a 303f 3040
1 3042 3047 304b 304f 3052 3057 305c
305f 3063 3064 3069 306c 3071 3072 3077
307a 307f 3080 3085 3088 308c 3090 3094
3098 309b 309c 309e 30a3 30a4 30a6 30a7
30ac 30af 30b4 30b5 30ba 30bd 30c2 30c3
30c8 30cb 30cf 30d0 30d5 30d8 30dd 30de
30e3 30e4 30e9 30eb 30ef 30f2 30f6 30fa
30fd 3101 3105 3108 310b 3110 3113 3116
3119 311a 311f 3120 1 3122 3127 312b
312f 3132 3137 313c 313f 3143 3144 3149
314a 314f 3151 3155 3158 315c 3160 3163
3167 316b 316e 3172 3176 3177 317c 317e
3182 3185 3189 318b 318f 3192 3193 3198
319b 319f 31a2 31a6 31aa 31ae 31b2 31b6
31ba 31be 31c2 31c6 31ca 31ce 31d2 31d6
31da 31de 31e2 31ee 31f2 31f6 31f9 31fd
3201 3203 3207 320b 320f 3212 3216 321a
321c 321d 3222 1 3226 322a 322e 3231
3235 3239 323d 3241 3244 3248 324c 324f
3252 3257 325a 325d 3260 3261 3266 3267
1 3269 326e 3272 3276 3279 327e 3283
3286 328a 328b 3290 3293 3298 3299 329e
32a1 32a6 32a7 32ac 32af 32b3 32b4 32b9
32bc 32c1 32c2 32c7 32ca 32ce 32d2 32d5
32d8 32d9 32db 32dc 32e1 32e2 32e7 32e9
32ed 32f0 32f2 32f6 32f8 3304 3306 3308
3309 330e 3312 3314 3320 3322 3326 332a
332d 332e 3330 3333 3336 3337 333c 3340
3344 3347 334b 334f 3352 3355 335a 335d
3360 3363 3364 3369 336a 1 336c 3371
3375 3379 337c 3381 3386 3389 338d 338e
3393 3396 339b 339c 33a1 33a4 33a9 33aa
33af 33b2 33b6 33ba 33be 33c2 33c5 33c6
33c8 33cd 33ce 33d0 33d1 33d6 33d9 33de
33df 33e4 33e7 33ec 33ed 33f2 33f5 33f9
33fa 33ff 3402 3407 3408 340d 340e 3413
3415 3419 341c 3420 3424 3427 342b 342f
3432 3435 343a 343d 3440 3443 3444 3449
344a 1 344c 3451 3455 3459 345c 3461
3466 3469 346d 346e 3473 3474 3479 347b
347f 3482 3486 348a 348d 3491 3495 3498
349c 34a0 34a1 34a6 34a8 34ac 34b0 34b4
34b8 34bc 34c0 34c4 34c8 34cc 34d0 34d4
34d8 34e4 34e8 34ec 34ef 34f3 34f7 34f9
34fd 3501 3505 3508 350c 3510 3512 3513
3518 1 351c 3520 3524 3527 352b 352f
3533 3537 353a 353e 3542 3545 3548 354d
3550 3553 3556 3557 355c 355d 1 355f
3564 3568 356c 356f 3574 3579 357c 3580
3581 3586 3589 358e 358f 3594 3597 359c
359d 35a2 35a5 35a9 35aa 35af 35b2 35b7
35b8 35bd 35c0 35c4 35c8 35cb 35ce 35cf
35d1 35d2 35d7 35d8 35dd 35df 35e3 35e6
35e8 35ec 35ee 35fa 35fc 35fe 35ff 3604
3608 360a 3616 3618 361c 3620 3623 3624
3626 362a 362d 3631 3634 3635 3637 3638
363d 3641 3645 3648 364c 3650 3653 3656
365b 365e 3661 3664 3665 366a 366b 1
366d 3672 3676 367a 367d 3682 3687 368a
368e 368f 3694 3697 369c 369d 36a2 36a5
36aa 36ab 36b0 36b3 36b7 36bb 36bf 36c3
36c6 36c7 36c9 36ce 36cf 36d1 36d2 36d7
36da 36df 36e0 36e5 36e8 36ed 36ee 36f3
36f6 36fa 36fb 3700 3703 3708 3709 370e
370f 3714 3716 371a 371d 3721 3725 3728
372c 3730 3733 3736 373b 373e 3741 3744
3745 374a 374b 1 374d 3752 3756 375a
375d 3762 3767 376a 376e 376f 3774 3775
377a 377c 3780 3783 3787 378b 378e 3792
3796 3799 379d 37a1 37a2 37a7 37a9 37ad
37b0 37b2 37b6 37ba 37bd 37bf 37c3 37c7
37cb 37ce 37d2 37d6 37d9 37dc 37e1 37e4
37e7 37ea 37eb 37f0 37f1 1 37f3 37f8
37fc 3800 3803 3808 380d 3810 3814 3815
381a 381d 3822 3823 3828 382b 3830 3831
3836 3839 383d 3841 3845 3849 384c 384d
384f 3854 3855 3857 3858 385d 3860 3865
3866 386b 386e 3873 3874 3879 387c 3880
3881 3886 3889 388e 388f 3894 3895 389a
389c 38a0 38a3 38a7 38ab 38ae 38b2 38b6
38b9 38bc 38c1 38c4 38c7 38ca 38cb 38d0
38d1 1 38d3 38d8 38dc 38e0 38e3 38e8
38ed 38f0 38f4 38f5 38fa 38fb 3900 3902
3906 3909 390d 3911 3914 3918 391c 391f
3923 3927 3928 392d 392f 3933 3937 393a
393c 3940 3943 3947 394a 394e 3952 3956
395a 395e 3961 3962 3967 396a 396e 3971
3972 3977 397a 1 397d 3982 3986 398a
398e 3990 3994 3997 399b 399f 39a3 39a7
39ab 39af 39b3 39b7 39bb 39bf 39c3 39c7
39cb 39cf 39d3 39d7 39db 39df 39e3 39e7
39eb 39ef 39f3 39f7 39fa 39fb 39fd 3a01
3a05 3a08 3a0c 3a10 3a14 3a18 3a1c 3a20
3a23 3a26 3a27 3a29 3a2d 3a31 3a34 3a35
3a3a 3a3d 3a41 3a44 3a48 3a4c 3a50 3a54
3a58 3a5c 3a5f 3a62 3a63 3a65 3a69 3a6b
3a6f 3a72 3a74 3a78 3a7c 3a7f 3a81 3a85
3a88 3a8a 3a8e 3a92 3a95 3a99 3a9d 3aa0
3aa4 3aa8 3aa9 3aab 3aae 3ab1 3ab2 3ab7
3aba 3abe 3ac2 3ac5 3ac6 3ac8 3acc 3acf
3ad3 3ad6 3ad7 3adc 1 3adf 3ae4 3ae8
3aed 3af1 3af5 3af8 3afc 3b00 3b04 3b08
3b0b 3b0f 3b13 3b17 3b1b 3b1f 3b23 3b27
3b2a 3b2b 3b2d 3b31 3b35 3b39 3b3c 3b40
3b44 3b48 3b4d 3b51 3b55 3b58 3b5c 3b60
3b64 3b68 3b6b 3b6f 3b73 3b77 3b7b 3b7f
3b83 3b87 3b8a 3b8b 3b8d 3b91 3b95 3b99
3b9c 3ba0 3ba4 3ba6 3baa 3bad 3bb1 3bb5
3bb9 3bba 3bbc 3bc0 3bc4 3bc8 3bcb 3bcf
3bd3 3bd6 3bd9 3bde 3be1 3be4 3be7 3be8
3bed 3bee 1 3bf0 3bf5 3bf9 3bfd 3c00
3c05 3c0a 3c0d 3c11 3c12 3c17 3c1a 3c1f
3c20 3c25 3c28 3c2d 3c2e 3c33 3c36 3c3a
3c3e 3c42 3c46 3c49 3c4a 3c4c 3c51 3c52
3c54 3c55 3c5a 3c5d 3c62 3c63 3c68 3c6b
3c70 3c71 3c76 3c79 3c7d 3c7e 3c83 3c86
3c8b 3c8c 3c91 3c92 3c97 3c99 3c9d 3ca0
3ca4 3ca8 3cab 3caf 3cb3 3cb6 3cba 3cbe
3cbf 3cc4 3cc6 3cca 3cce 3cd1 3cd5 3cd9
3cdc 3ce0 3ce4 3ce7 3cea 3cef 3cf2 3cf5
3cf8 3cf9 3cfe 3cff 1 3d01 3d06 3d0a
3d0e 3d11 3d16 3d1b 3d1e 3d22 3d23 3d28
3d29 3d2e 3d32 3d36 3d39 3d3e 3d43 3d46
3d4a 3d4e 3d51 3d52 3d57 3d5a 3d5f 3d60
3d65 3d68 3d6c 3d70 3d73 3d74 3d79 3d7a
3d7f 3d81 3d85 3d88 3d8c 3d90 3d94 3d98
3d9c 3da0 3da4 3da8 3dac 3db8 3dbd 3dc1
3dc5 3dc9 3dcd 3dcf 3dd0 3dd5 1 3dd9
3ddd 3de1 3de4 3de8 3dec 3df0 3df4 3df7
3dfb 3dff 3e02 3e05 3e0a 3e0d 3e10 3e13
3e14 3e19 3e1a 1 3e1c 3e21 3e25 3e29
3e2c 3e31 3e36 3e39 3e3d 3e3e 3e43 3e44
3e49 3e4d 3e51 3e54 3e59 3e5e 3e61 3e65
3e66 3e6b 3e6e 3e73 3e74 3e79 3e7c 3e80
3e84 3e87 3e8a 3e8b 3e8d 3e8e 3e93 3e94
3e99 3e9b 3e9f 3ea2 3ea6 3eaa 3eae 3eb2
3eb6 3eba 3ebe 3eca 3ecf 3ed3 3ed7 3edb
3edf 3ee1 3ee5 3ee7 3ef3 3ef5 3ef7 3ef8
3efd 3f01 3f03 3f0f 3f13 3f15 3f16 3f1f 
1218
2
0 1 a 6 9 :3 6 14 :3 6
15 :3 6 16 :3 6 12 :2 6 1 3
a 13 a :2 1 4 11 1a 19
:2 11 :2 4 11 1a 19 :2 11 :2 4 e
17 16 :2 e :2 4 18 21 20 :2 18
:2 4 18 21 20 :2 18 :2 4 18 21
20 :2 18 :2 4 d 16 15 :2 d :2 4
f 18 17 :2 f :2 4 12 1b 1a
:2 12 :2 4 :3 11 :2 4 :3 12 :2 4 :3 f :2 4
:3 10 :2 4 :3 15 :2 4 :3 16 :2 4 :3 13 :2 4
b 14 13 :2 b :2 4 :2 13 22 13
:2 4 :2 b 1a b :2 4 :2 f 19 f
:2 4 :2 f 19 f :2 4 :3 12 :2 4 :3 13
:2 4 :3 15 :2 4 :3 19 :2 4 :3 10 :2 4 :3 e
:2 4 f 18 17 :2 f :2 4 :2 f 1e
f :2 4 :2 16 25 16 :2 4 :2 a 19
a :2 4 :2 c 1b c :2 4 :2 11 20
11 :2 4 :2 f 1e f :2 4 :2 d 1c
d :2 4 :2 e 1d e :2 4 :2 e 1d
e :2 4 :2 16 25 16 :2 4 :2 10 1f
10 :2 4 :2 9 18 9 :2 4 :2 f 1e
f :2 4 :2 14 23 14 :2 4 :2 11 20
11 :2 4 f 18 17 :2 f :2 4 :3 10
:2 4 :2 16 2e 16 :2 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 58 5e
61 :2 58 6f 89 8 :2 6f d 10
:2 6f 13 16 :2 6f b e :2 6f 13
16 1f 26 2b 2e :2 26 3c 3f
:2 26 44 :2 1f 4d :2 16 :2 6f b e
:2 6f 13 16 1f 26 2b 2e :2 26
3d 40 :2 26 45 :2 1f 4e :2 16 :2 6f
b e :2 6f 13 16 1f 27 :2 1f
39 :2 16 :2 6f b e :2 6f 13 16
:2 6f 1b 1e :2 6f 2a 2d :2 6f 32
35 :2 6f :2 7 4e :2 4 7 :2 11 23
:2 2d 39 3c 50 52 53 :2 50 :2 23
:3 7 :2 d 12 1e 61 64 :2 1e :2 7
56 :3 4 14 :2 4 15 :2 4 12 :2 4
14 :2 4 15 :2 4 1b :2 4 19 4
8 11 24 :2 8 27 29 :2 27 :2 7
1c :2 25 7 2c :2 4 e 1a 2d
44 52 65 7 10 1f 2d 36
46 55 65 76 7f 8c 99 a8
b5 c3 7 12 22 34 47 51
62 70 c 1a 2f 44 54 64
7 13 20 32 45 50 5a 67
74 7 12 24 33 43 4f 62
6e c d 21 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 57 5a 5b :2 57 :2 29
:3 d :2 13 18 24 68 6b :2 24 78
7b :2 24 7f 82 :2 24 8e 91 :2 24
99 9c :2 24 a8 ab b2 bb be
:2 ab :2 24 :2 d 5e :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 a :2 14 26 :2 30 3c 40 54
57 58 :2 54 :2 26 :3 a :2 10 15 21
65 68 :2 21 75 78 :2 21 7c 7f
:2 21 89 8c 95 9d :2 a6 :2 95 b9
:2 8c :2 21 c1 c4 :2 21 cc cf :2 21
d4 d7 :2 21 da dd :2 21 :2 a 5b
:2 7 a :2 14 26 :2 30 3c 3f 53
56 57 :2 53 :2 26 :3 a :2 10 15 21
65 68 :2 21 :2 a 5a :3 7 :2 12 26
:2 2f 41 45 :2 7 35 :2 4 e :2 c
d 1a b 18 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 57 5a 5b :2 57 :2 29
:3 d :2 13 18 24 68 6b :2 24 78
7b :2 24 7f 82 :2 24 8e 91 :2 24
99 9c :2 24 a8 ab b2 bb be
:2 ab :2 24 :2 d 5e :2 a :2 7 :4 13 :2 7
4 :3 1 7 e 1c 1f :2 7 22
24 :2 22 a :2 14 26 :2 30 3c 40
54 57 58 :2 54 :2 26 :3 a :2 10 15
21 65 68 :2 21 75 78 :2 21 7c
7f :2 21 89 8c 95 9d :2 a6 :2 95
c4 :2 8c :2 21 cc cf :2 21 d7 da
:2 21 df e2 :2 21 e5 e8 :2 21 :2 a
5b :2 7 a :2 14 26 :2 30 3c 3f
53 56 57 :2 53 :2 26 :3 a :2 10 15
21 65 68 :2 21 :2 a 5a :3 7 :2 12
26 :2 2f 4c 50 :2 7 28 :2 4 7
10 20 :2 7 23 25 :2 23 a :2 14
26 :2 30 3c 40 54 57 58 :2 54
:2 26 :3 a :2 10 15 21 65 68 :2 21
75 78 :2 21 7c 7f :2 21 89 8c
95 9d :2 a6 :2 95 c2 :2 8c :2 21 ca
cd :2 21 d5 d8 :2 21 dd e0 :2 21
e3 e6 :2 21 :2 a 5b :2 7 a :2 14
26 :2 30 3c 3f 53 56 57 :2 53
:2 26 :3 a :2 10 15 21 65 68 :2 21
:2 a 5a :3 7 :2 12 26 :2 2f 4a 4e
:2 7 2b :2 4 :4 9 8 7 :4 2b 2a
29 :2 7 a :2 15 1d 2c 3a :2 a
3e 40 :2 3e d :2 17 29 :2 33 3f
43 57 5a 5b :2 57 :2 29 :3 d :2 13
18 24 68 6b :2 24 78 7b :2 24
7f 82 :2 24 8c 8f 98 a0 :2 a9
:2 98 c6 :2 8f :2 24 ce d1 :2 24 d9
dc :2 24 e1 e4 :2 24 e7 ea :2 24
:2 d 5e :2 a d :2 17 29 :2 33 3f
42 56 59 5a :2 56 :2 29 :3 d :2 13
18 24 68 6b :2 24 :2 d 5d :3 a
:2 15 29 :2 32 4e 52 :2 a 42 :2 7
48 :3 4 11 4 e 12 29 38
d 1a 2b 39 b 1d 26 3f
48 61 6a :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 57 5a 5b :2 57 :2 29 :3 d
:2 13 18 24 68 6b :2 24 78 7b
:2 24 7f 82 :2 24 8e 91 :2 24 99
9c :2 24 a8 ab b2 bb be :2 ab
:2 24 :2 d 5e :2 a :2 7 :4 13 :2 7 4
:3 1 4 12 4 8 :2 13 1a 24
:2 8 30 32 :2 30 7 3a a 1d
:2 3a 23 20 :2 2c :2 20 39 :3 7 15
:2 7 17 :2 7 1c :2 25 :2 7 16 25
31 46 52 60 :2 16 :2 7 :2 10 1c
:2 7 15 :2 7 17 :2 7 1c :2 25 :2 7
16 25 31 46 52 60 :2 16 :2 7
:2 10 1c 7 47 :2 4 :4 9 8 7
29 :2 34 3c 4a 56 :2 29 5a 5c
:2 5a 28 :3 7 17 7 5f :2 4 :4 9
8 7 :4 27 26 25 :2 7 11 a
1c a 1c a 10 24 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
5a 5d 5e :2 5a :2 2c :3 10 :2 16 1b
27 6b 6e :2 27 7b 7e :2 27 82
85 :2 27 91 94 :2 27 9c 9f :2 27
ab ae b5 be c1 :2 ae :2 27 :2 10
61 :2 d :2 a :4 16 :2 a 7 :4 40 :4 b
a :4 27 26 :2 a 14 d 1f d
13 27 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5d 60 61 :2 5d
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 94 97
:2 2a 9f a2 :2 2a ae b1 b8 c1
c4 :2 b1 :2 2a :2 13 64 :2 10 :2 d :4 19
:2 d a :3 45 d :2 18 20 2f 42
:2 d 46 48 :2 46 d 1b d 4a
:2 a 45 :2 7 :4 b a :4 28 27 :2 a
14 d 1f d 13 27 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5d 60 61 :2 5d :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 94 97 :2 2a 9f a2 :2 2a
ae b1 b8 c1 c4 :2 b1 :2 2a :2 13
64 :2 10 :2 d :4 19 :2 d a :3 47 d
:2 18 20 2e 40 :2 d 44 46 :2 44
d 1b d 48 :2 a 47 :2 7 a
13 1f :2 a 22 24 :2 22 :4 f e
d 30 :2 3b 43 52 5f :2 30 63
65 :2 63 2f :3 d 1e d 68 :2 a
:4 f e d :4 2d 2c 2b :2 d 4e
:2 59 60 12 :2 4e 21 23 :2 21 4d
:2 d 10 :2 1a 2c :2 36 42 46 5a
5d 5e :2 5a :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 7b 7e :2 27 82 85
:2 27 8f 92 9b a3 :2 ac :2 9b c7
:2 92 :2 27 cf d2 :2 27 da dd :2 27
e2 e5 :2 27 ee f1 :2 27 :2 10 61
:2 d 10 :2 1a 2c :2 36 42 45 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 :2 10 60 :3 d :2 18 2c
:2 35 4f 59 :2 d 26 :2 a :4 e d
:4 11 10 13 :2 1d 2f :2 39 45 49
5d 60 61 :2 5d :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 92 95 9e a6 :2 af :2 9e
ca :2 95 :2 2a d2 d5 :2 2a dd e0
:2 2a e5 e8 :2 2a eb ee :2 2a :2 13
64 :2 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 :2 1b
2f :2 38 52 56 :2 10 2d :3 d 19
d 10 :2 1b 23 31 40 :2 10 44
46 :2 44 10 20 10 d 48 13
:2 1e 26 34 40 :2 13 44 47 :2 44
1a 25 32 3c 47 4c 55 66
78 18 19 26 17 22 2a 31
:2 13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 63
66 67 :2 63 :2 35 :3 19 :2 1f 24 30
74 77 :2 30 84 87 :2 30 8b 8e
:2 30 9a 9d :2 30 a5 a8 :2 30 b4
b7 be c7 ca :2 b7 :2 30 :2 19 6a
:2 16 :2 13 :4 1f :2 13 10 :3 49 14 :2 1d
28 26 :2 31 :2 26 13 1f 2a 37
3f 46 5e 69 80 92 :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :4 41 :2 10 d 49 48
:4 14 :2 13 :2 1d 2f :2 39 45 49 5d
60 61 :2 5d :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a 7e 81 :2 2a 85 88
:2 2a 92 95 9e a6 :2 9e aa :2 95
:2 2a b2 b5 :2 2a bd c0 :2 2a c5
c8 :2 2a cb ce :2 2a :2 13 64 :2 10
13 :2 1d 2f :2 39 45 48 5c 5f
60 :2 5c :2 2f :3 13 :2 19 1e 2a 6e
71 :2 2a :2 13 63 :3 10 :2 1b 2f 32
36 :2 10 2c 48 :2 d 29 d 19
:2 d 1d d :4 a :4 e d :4 12 11
10 2f :2 3a 42 51 60 :2 2f 64
66 :2 64 2e :2 10 13 :2 1d 2f :2 39
45 49 5d 60 61 :2 5d :2 2f :3 13
:2 19 1e 2a 6e 71 :2 2a 7e 81
:2 2a 85 88 :2 2a 92 95 9e a6
:2 af :2 9e c0 :2 95 :2 2a c8 cb :2 2a
d3 d6 :2 2a db de :2 2a e1 e4
:2 2a :2 13 64 :2 10 13 :2 1d 2f :2 39
45 48 5c 5f 60 :2 5c :2 2f :3 13
:2 19 1e 2a 6e 71 :2 2a :2 13 63
:3 10 :2 1b 2f :2 38 48 4c :2 10 d
69 :4 15 14 13 39 :2 44 4c 5b
15 :2 39 19 1c :2 19 38 :3 13 :2 1d
2f :2 39 45 48 5c 5f 60 :2 5c
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 92 95
9e a6 :2 af :2 9e ca :2 95 :2 2a :2 13
63 :2 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 :2 1b
31 :2 3a 54 :2 10 1f 69 :2 d :4 12
11 10 2f :2 3a 42 51 5e :2 2f
62 64 :2 62 2e :3 10 18 10 67
10 18 10 :4 d 10 :2 1b 23 32
42 :2 10 46 48 :2 46 10 21 10
d 4a 13 :2 1e 25 34 :2 13 41
44 :2 41 1a 25 32 3c 47 4c
55 65 77 18 19 26 17 22
2a 31 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 63 66 67 :2 63 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 84 87 :2 30
8b 8e :2 30 9a 9d :2 30 a5 a8
:2 30 b4 b7 be c7 ca :2 b7 :2 30
:2 19 6a :2 16 :2 13 :4 1f :2 13 10 :3 46
14 :2 1d 28 26 :2 31 :2 26 13 1f
2a 37 3f 46 5f 6a 81 94
:2 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :4 41 :2 10 d
46 4a 13 :2 1e 26 35 44 :2 13
48 4a :2 48 13 :2 1d 2f :2 39 45
49 5d 60 61 :2 5d :2 2f :3 13 :2 19
1e 2a 6e 71 :2 2a 7e 81 :2 2a
85 88 :2 2a 92 95 9e a6 :2 9e
aa :2 95 :2 2a b2 b5 :2 2a bd c0
:2 2a c5 c8 :2 2a cb ce :2 2a :2 13
64 :2 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 :2 1b
2f 32 36 :2 10 4c 4a :2 d 2a
d 1e d :5 a 18 :2 a 18 a
d 16 29 :2 d 2f 2c :2 38 :2 2c
17 10 22 10 22 10 16 2a
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 60 63 64 :2 60 :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d 81 84
:2 2d 88 8b :2 2d 97 9a :2 2d a2
a5 :2 2d b1 b4 bb c4 c7 :2 b4
:2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10 d
:4 52 :4 11 10 :4 14 :2 13 21 13 1d
2d 1b 2b 39 1c 29 3c 50
69 7d 1a 25 2d 34 :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :3 30 16 1f 2b :2 16
2e 30 :2 2e 19 :2 23 35 :2 3f 4b
4f 63 66 67 :2 63 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 84 87 :2 30
8b 8e :2 30 98 9b a4 ac :2 b5
:2 a4 d4 :2 9b :2 30 dc df :2 30 e7
ea :2 30 ef f2 :2 30 106 109 :2 30
:2 19 6a :2 16 19 :2 23 35 :2 3f 4b
4e 62 65 66 :2 62 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 :2 19 69 :3 16
:2 21 35 :2 3e 5c 1e :2 16 32 :2 13
10 30 :4 17 16 13 21 13 1d
2d 1b 2b 39 1c 29 3c 50
69 7d 1a 25 2d 34 :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :3 32 16 1f 2b :2 16
2e 30 :2 2e 19 :2 23 35 :2 3f 4b
4f 63 66 67 :2 63 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 84 87 :2 30
8b 8e :2 30 98 9b a4 ac :2 b5
:2 a4 d4 :2 9b :2 30 dc df :2 30 e7
ea :2 30 ef f2 :2 30 106 109 :2 30
:2 19 6a :2 16 19 :2 23 35 :2 3f 4b
4e 62 65 66 :2 62 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 :2 19 69 :3 16
:2 21 35 :2 3e 5c 1e :2 16 32 20
24 34 41 1f 2c 3d 49 61
6d 75 7c :2 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 69 6c 6d :2 69 :2 3b :3 1f
:2 25 2a 36 7a 7d :2 36 8a 8d
:2 36 91 94 :2 36 a0 a3 :2 36 ab
ae :2 36 ba bd c4 cd d0 :2 bd
:2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19 16
:3 13 19 22 2b :2 19 30 2e 39
40 :2 30 :2 2e 1c :2 26 38 :2 42 4e
52 66 69 6a :2 66 :2 38 :3 1c :2 22
27 33 77 7a :2 33 87 8a :2 33
8e 91 :2 33 9b 9e a7 af :2 b8
:2 a7 d7 :2 9e :2 33 df e2 :2 33 ea
ed :2 33 f2 f5 :2 33 109 10c :2 33
:2 1c 6d :2 19 1c :2 26 38 :2 42 4e
51 65 68 69 :2 65 :2 38 :3 1c :2 22
27 33 77 7a :2 33 :2 1c 6c :3 19
:2 24 38 :2 41 5f 21 :2 19 43 :2 16
:4 13 32 30 16 :2 20 32 :2 3c 48
4c 60 63 64 :2 60 :2 32 :3 16 :2 1c
21 2d 71 74 :2 2d 81 84 :2 2d
88 8b :2 2d 95 98 a1 a9 :2 b2
:2 a1 ca :2 98 :2 2d d2 d5 :2 2d dd
e0 :2 2d e5 e8 :2 2d fc ff :2 2d
:2 16 67 :2 13 16 :2 20 32 :2 3c 48
4b 5f 62 63 :2 5f :2 32 :3 16 :2 1c
21 2d 71 74 :2 2d :2 16 66 :3 13
:2 1e 32 :2 3b 52 1b :2 13 :4 10 32
:3 d 1a :2 d 24 d :4 11 10 :4 2d
2c 2b :3 10 20 10 4c :3 d 20
33 41 4c 29 3e 4c 29 3b
47 51 29 37 3e 49 4f 29
38 48 54 29 35 48 54 :2 20
:2 d 1b :2 d 20 30 3e 53 5f
62 :2 20 d :4 11 :2 10 1e :2 10 23
33 41 56 62 65 :2 23 10 32
:2 d :4 a 26 :2 7 :4 4 8 :2 13 1a
24 :2 8 30 32 :2 30 7 3a a
1d :2 3a 23 20 :2 2c :2 20 39 :3 7
15 :2 7 17 :2 7 1c :2 25 :2 7 16
25 31 46 52 60 :2 16 :2 7 :2 10
1c :2 7 15 :2 7 17 :2 7 1c :2 25
:2 7 16 25 31 46 52 60 :2 16
:2 7 :2 10 1c 7 47 :3 4 17 21
:2 17 4 7 :2 11 23 :2 2d 39 3c
50 53 54 :2 50 :2 23 :3 7 :2 d 12
1e 62 65 :2 1e 72 75 :2 1e 79
7c :2 1e 86 89 92 9a :2 a3 :2 92
ae :2 89 :2 1e b6 b9 :2 1e c1 c4
:2 1e c9 cc :2 1e cf d2 :2 1e :2 7
57 :3 4 :2 f 21 :2 2a 34 38 :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 54 57 58 :2 54 :2 26 :3 a
:2 10 15 21 65 68 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 5b :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 51 54 55 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
58 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
1218
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 2
:4 8 :2 1 :7 a :7 b
:7 c :7 d :7 e :7 f
:7 10 :7 11 :7 12 :5 13
:5 14 :5 15 :5 16 :5 17
:5 18 :5 19 :7 1a :6 1b
:6 1c :6 1d :6 1e :5 1f
:5 20 :5 21 :5 22 :5 23
:5 24 :7 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :7 35 :5 36 :6 37
:7 39 :b 3b :11 3c 3d
:2 3c :2 3d :2 3c :2 3d
:2 3c :2 3e :2 3c :12 3e
:2 3c :2 3f :2 3c :12 3f
:2 3c :2 40 :2 3c :9 40
:2 3c :2 41 :2 3c :2 41
:2 3c :2 41 :2 3c :2 41
:2 3c :2 41 :4 3c :3 3b
:11 44 :b 45 :3 44 :3 4b
:3 4c :3 4e :3 50 :3 51
:3 52 :3 53 :a 54 :5 55
:3 54 :6 59 :f 5a :8 5b
:6 5c :9 5d :8 5e 5f
:2 60 59 :5 61 58
63 :5 64 :3 63 :2 65
:5 67 :11 68 :24 69 :3 68
:2 66 :6 65 62 :3 3a
:a 6f :11 70 :30 71 :3 70
:11 73 :b 74 :3 73 :a 76
:3 6f 7a 7b 7c
:2 7d :2 7e 7a :5 7f
79 81 :5 82 :3 81
:2 83 :5 85 :11 86 :24 87
:3 86 :2 84 :6 83 80
:3 3a :a 8c :11 8d :30 8e
:3 8d :11 90 :b 91 :3 90
:a 93 :3 8c :9 96 :11 97
:30 98 :3 97 :11 9a :b 9b
:3 9a :a 9d :3 96 :e a0
:c a1 :11 a2 :30 a3 :3 a2
:11 a5 :b a6 :3 a5 :a a8
:3 a1 :3 a0 :3 ac :4 ae
:4 af :7 b0 ae :5 b1
ad b3 :5 b4 :3 b3
:2 b5 :5 b7 :11 b8 :24 b9
:3 b8 :2 b6 :6 b5 b2
:3 3a :3 bf :d c0 :2 c1
:2 c0 :6 c1 :3 c0 :3 c2
:3 c3 :5 c4 :a c5 :5 c6
:3 c8 :3 c9 :5 ca :a cb
:5 cc c1 :2 c0 :15 d0
:3 d1 :3 d0 :e d4 d6
:2 d7 :2 d8 d9 :2 da
d6 :6 db :5 dc db
:5 de dd :3 db d5
e1 :5 e2 :3 e1 :2 e3
:5 e5 :11 e6 :24 e7 :3 e6
:2 e4 :6 e3 e0 :4 d4
:c ee f2 :2 f3 f4
:2 f5 f2 :6 f6 :5 f7
f6 :5 f9 f8 :3 f6
f1 fc :5 fd :3 fc
:2 fe :5 100 :11 101 :24 102
:3 101 :2 ff :6 fe fb
:3 ee :c 109 :3 10b :3 109
:3 ee :c 10f 112 :2 113
114 :2 115 112 :6 116
:5 117 116 :5 119 118
:3 116 111 11c :5 11d
:3 11c :2 11e :5 120 :11 121
:24 122 :3 121 :2 11f :6 11e
11b :3 10f :c 12a :3 12c
:3 12a :3 10f :9 130 :15 133
:3 134 :3 133 :12 137 138
:2 137 :4 138 :3 137 :11 139
:30 13a :3 139 :11 13c :b 13d
:3 13c :a 13f 138 :2 137
:5 142 :5 143 :11 144 :30 145
:3 144 :11 147 :b 148 :3 147
:a 14a :3 143 :3 14e :c 14f
:3 150 151 14f :c 151
:9 153 154 :2 155 :4 156
153 :5 157 152 159
:5 15a :3 159 :2 15b :5 15d
:11 15e :24 15f :3 15e :2 15c
:6 15b 158 :3 151 :a 164
:a 167 :5 168 166 16a
:5 16b :3 16a :2 16c :5 16e
:11 16f :24 170 :3 16f :2 16d
:6 16c 169 :6 164 175
151 14f :5 175 :11 176
:2e 177 :3 176 :11 179 :b 17a
:3 179 :8 17c 175 :3 14f
142 :3 17f :3 180 17e
:3 142 :5 183 :15 185 :11 186
:30 187 :3 186 :11 189 :b 18a
:3 189 :a 18c 18d 185
:b 18d 18e :2 18d :4 18e
:3 18d :11 18f :20 190 :3 18f
:11 192 :b 193 :3 192 :9 195
18e :3 185 :15 198 :3 199
198 :3 19b 19a :3 198
:c 19f :3 1a0 1a1 19f
:b 1a1 :9 1a4 1a5 :2 1a6
:4 1a7 1a4 :5 1a8 1a3
1aa :5 1ab :3 1aa :2 1ac
:5 1ae :11 1af :24 1b0 :3 1af
:2 1ad :6 1ac 1a9 :3 1a1
:a 1b6 :a 1b9 :5 1ba 1b8
1bc :5 1bd :3 1bc :2 1be
:5 1c0 :11 1c1 :24 1c2 :3 1c1
:2 1bf :6 1be 1bb :6 1b6
1c7 1a1 19f :c 1c7
:11 1c9 :2e 1ca :3 1c9 :11 1cc
:b 1cd :3 1cc :8 1cf 1c7
:3 19f 183 :3 1d2 1d1
:3 183 :3 1d5 :3 1d6 :b 1d9
1db :2 1dc :2 1dd 1de
:2 1df 1db :6 1e0 :5 1e1
1e0 :5 1e3 1e2 :3 1e0
1da 1e6 :5 1e7 :3 1e6
:2 1e8 :5 1ea :11 1eb :24 1ec
:3 1eb :2 1e9 :6 1e8 1e5
:4 1d9 :5 1f3 :5 1f5 :3 1f6
:2 1f8 1f9 :2 1fa :6 1fb
:4 1fc 1f8 :5 1fd 1f7
1ff :5 200 :3 1ff :2 201
:5 203 :11 204 :24 205 :3 204
:2 202 :6 201 1fe :3 1f5
:9 209 :11 20c :30 20d :3 20c
:11 20f :b 210 :3 20f :7 212
213 :2 212 :3 209 215
1f5 :5 215 :3 217 :2 219
21a :2 21b :6 21c :4 21d
219 :5 21e 218 220
:5 221 :3 220 :2 222 :5 224
:11 225 :24 226 :3 225 :2 223
:6 222 21f :3 215 :9 22b
:11 22d :30 22e :3 22d :11 230
:b 231 :3 230 :7 233 234
:2 233 22b :4 23b :8 23c
23b :5 23d 23a 23f
:5 240 :3 23f :2 241 :5 243
:11 244 :24 245 :3 244 :2 242
:6 241 23e :3 235 :d 249
:11 24a :30 24b :3 24a :11 24d
:b 24e :3 24d :7 250 251
:2 250 :3 249 235 :3 22b
215 1f5 :11 255 :30 256
:3 255 :11 258 :b 259 :3 258
:7 25b 25c :2 25b 254
:3 1f5 :3 1f3 :3 261 :3 262
:d 264 :3 265 :3 264 :5 268
:3 269 :4 26a :5 26b :4 26c
:4 26d :3 268 :3 26f :a 270
:5 272 :3 273 :a 274 :3 272
1f0 :3 1d9 :3 130 ec
:3 d4 :d 27a :2 27b :2 27a
:6 27b :3 27a :3 27c :3 27d
:5 27e :a 27f :5 280 :3 282
:3 283 :5 284 :a 285 :5 286
27b :2 27a :6 289 :11 28b
:30 28c :3 28b :a 28e 3a
:3 292 :11 293 :b 294 :17 295
:3 293 :2 297 :3 298 :3 299
29a 298 297 298
:3 29b :3 292 :2 29c :5 29e
:11 29f :b 2a0 :18 2a1 :3 29f
:2 2a3 2a4 :3 2a5 2a6
2a4 2a3 2a4 :3 2a7
:2 29d :6 29c 291 :7 1

3f21
4
:3 0 1 :3 0 2
:a 0 1213 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d :2 0 b
9 :3 0 8 :7 0
11 10 :3 0 4
:3 0 a :7 0 15
14 :3 0 b :3 0
c :3 0 d :2 0
4 19 1a 0
17 1b 0 1213
2 1c :2 0 11
:2 0 15 4 :3 0
f :2 0 13 1f
21 :6 0 24 22
0 1211 0 e
:6 0 11 :2 0 19
4 :3 0 17 26
28 :6 0 2b 29
0 1211 0 10
:6 0 11 :2 0 1d
4 :3 0 1b 2d
2f :6 0 32 30
0 1211 0 12
:6 0 11 :2 0 21
4 :3 0 1f 34
36 :6 0 39 37
0 1211 0 13
:6 0 11 :2 0 25
4 :3 0 23 3b
3d :6 0 40 3e
0 1211 0 14
:6 0 11 :2 0 29
4 :3 0 27 42
44 :6 0 47 45
0 1211 0 15
:6 0 11 :2 0 2d
4 :3 0 2b 49
4b :6 0 4e 4c
0 1211 0 16
:6 0 11 :2 0 31
4 :3 0 2f 50
52 :6 0 55 53
0 1211 0 17
:6 0 37 19b 0
35 4 :3 0 33
57 59 :6 0 5c
5a 0 1211 0
18 :6 0 3b 1cf
0 39 6 :3 0
5e :7 0 61 5f
0 1211 0 19
:6 0 6 :3 0 63
:7 0 66 64 0
1211 0 1a :6 0
3f 203 0 3d
6 :3 0 68 :7 0
6b 69 0 1211
0 1b :6 0 6
:3 0 6d :7 0 70
6e 0 1211 0
1c :6 0 43 237
0 41 6 :3 0
72 :7 0 75 73
0 1211 0 1d
:6 0 6 :3 0 77
:7 0 7a 78 0
1211 0 1e :6 0
23 :2 0 47 6
:3 0 7c :7 0 7f
7d 0 1211 0
1f :6 0 4 :3 0
21 :2 0 45 81
83 :6 0 86 84
0 1211 0 20
:6 0 23 :2 0 49
9 :3 0 88 :7 0
8c 89 8a 1211
0 22 :6 0 27
:2 0 4b 9 :3 0
8e :7 0 92 8f
90 1211 0 24
:6 0 27 :2 0 4d
26 :3 0 94 :7 0
98 95 96 1211
0 25 :6 0 51
2df 0 4f 26
:3 0 9a :7 0 9e
9b 9c 1211 0
28 :6 0 55 313
0 53 6 :3 0
a0 :7 0 a3 a1
0 1211 0 29
:6 0 6 :3 0 a5
:7 0 a8 a6 0
1211 0 2a :6 0
59 347 0 57
2c :3 0 aa :7 0
ad ab 0 1211
0 2b :6 0 2c
:3 0 af :7 0 b2
b0 0 1211 0
2d :6 0 f :2 0
5b 2c :3 0 b4
:7 0 b7 b5 0
1211 0 2e :6 0
2c :3 0 b9 :7 0
bc ba 0 1211
0 2f :6 0 23
:2 0 5f 4 :3 0
5d be c0 :6 0
c3 c1 0 1211
0 30 :6 0 23
:2 0 61 9 :3 0
c5 :7 0 c9 c6
c7 1211 0 31
:6 0 23 :2 0 63
9 :3 0 cb :7 0
cf cc cd 1211
0 32 :6 0 23
:2 0 65 9 :3 0
d1 :7 0 d5 d2
d3 1211 0 33
:6 0 23 :2 0 67
9 :3 0 d7 :7 0
db d8 d9 1211
0 34 :6 0 23
:2 0 69 9 :3 0
dd :7 0 e1 de
df 1211 0 35
:6 0 23 :2 0 6b
9 :3 0 e3 :7 0
e7 e4 e5 1211
0 36 :6 0 23
:2 0 6d 9 :3 0
e9 :7 0 ed ea
eb 1211 0 37
:6 0 23 :2 0 6f
9 :3 0 ef :7 0
f3 f0 f1 1211
0 38 :6 0 23
:2 0 71 9 :3 0
f5 :7 0 f9 f6
f7 1211 0 39
:6 0 23 :2 0 73
9 :3 0 fb :7 0
ff fc fd 1211
0 3a :6 0 23
:2 0 75 9 :3 0
101 :7 0 105 102
103 1211 0 3b
:6 0 23 :2 0 77
9 :3 0 107 :7 0
10b 108 109 1211
0 3c :6 0 23
:2 0 79 9 :3 0
10d :7 0 111 10e
10f 1211 0 3d
:6 0 23 :2 0 7b
9 :3 0 113 :7 0
117 114 115 1211
0 3e :6 0 11
:2 0 7d 9 :3 0
119 :7 0 11d 11a
11b 1211 0 3f
:6 0 83 559 0
81 4 :3 0 7f
11f 121 :6 0 124
122 0 1211 0
40 :6 0 131 132
0 85 42 :3 0
126 :7 0 129 127
0 1211 0 41
:6 0 9 :3 0 12b
0 2 :5 0 23
:2 0 12f 12c 12d
1211 0 43 :6 0
137 138 0 87
c :3 0 d :2 0
4 133 :7 0 136
134 0 1211 0
44 :6 0 45 :3 0
46 :3 0 45 :3 0
47 :3 0 13a 13b
0 2 :4 0 89
13c 13e 139 140
13f :2 0 48 :3 0
49 :3 0 142 143
0 4a :4 0 45
:3 0 4b :3 0 146
147 0 2 :4 0
8b 148 14a 4c
:4 0 4d :2 0 4e
:3 0 8d 14d 14f
:3 0 4f :4 0 4d
:2 0 50 :4 0 90
152 154 :3 0 4d
:2 0 3 :3 0 93
156 158 :3 0 4d
:2 0 50 :4 0 96
15a 15c :3 0 4d
:2 0 51 :4 0 99
15e 160 :3 0 4d
:2 0 52 :3 0 53
:3 0 50 :4 0 4d
:2 0 5 :3 0 9c
166 168 :3 0 4d
:2 0 50 :4 0 9f
16a 16c :3 0 54
:4 0 a2 164 16f
55 :4 0 a5 163
172 a8 162 174
:3 0 4d :2 0 51
:4 0 ab 176 178
:3 0 4d :2 0 52
:3 0 53 :3 0 50
:4 0 4d :2 0 7
:3 0 ae 17e 180
:3 0 4d :2 0 50
:4 0 b1 182 184
:3 0 54 :4 0 b4
17c 187 55 :4 0
b7 17b 18a ba
17a 18c :3 0 4d
:2 0 51 :4 0 bd
18e 190 :3 0 4d
:2 0 52 :3 0 56
:3 0 8 :3 0 c0
194 196 55 :4 0
c2 193 199 c5
192 19b :3 0 4d
:2 0 51 :4 0 c8
19d 19f :3 0 4d
:2 0 50 :4 0 cb
1a1 1a3 :3 0 4d
:2 0 a :3 0 ce
1a5 1a7 :3 0 4d
:2 0 50 :4 0 d1
1a9 1ab :3 0 4d
:2 0 57 :4 0 d4
1ad 1af :3 0 d7
144 1b1 :2 0 1b3
dc 1b4 141 1b3
0 1b5 de 0
1171 45 :3 0 46
:3 0 1b6 1b7 0
45 :3 0 58 :3 0
1b9 1ba 0 f
:2 0 2 :4 0 59
:2 0 5a :2 0 f
:2 0 e0 1bf 1c1
:3 0 e3 1bb 1c3
1b8 1c5 1c4 :2 0
48 :3 0 5b :3 0
1c7 1c8 0 4a
:4 0 5c :4 0 4d
:2 0 4e :3 0 e7
1cc 1ce :3 0 ea
1c9 1d0 :2 0 1d2
ed 1d3 1c6 1d2
0 1d4 ef 0
1171 19 :3 0 5d
:4 0 1d5 1d6 0
1171 1a :3 0 5d
:4 0 1d8 1d9 0
1171 36 :3 0 f
:2 0 1db 1dc 0
1171 19 :3 0 5
:3 0 1de 1df 0
1171 1a :3 0 7
:3 0 1e1 1e2 0
1171 14 :3 0 3
:3 0 1e4 1e5 0
1171 3a :3 0 8
:3 0 1e7 1e8 0
1171 52 :3 0 3a
:3 0 23 :2 0 f1
1ea 1ed 5e :2 0
f :2 0 f6 1ef
1f1 :3 0 1f2 :2 0
3a :3 0 5f :3 0
60 :3 0 1f5 1f6
0 1f4 1f7 0
1f9 f9 1fa 1f3
1f9 0 1fb fb
0 1171 61 :3 0
62 :3 0 63 :3 0
64 :3 0 65 :3 0
66 :3 0 52 :3 0
67 :3 0 68 :3 0
52 :3 0 69 :3 0
6a :3 0 67 :3 0
69 :3 0 6b :3 0
6c :3 0 6d :3 0
6e :3 0 6d :3 0
6f :3 0 70 :3 0
71 :3 0 72 :3 0
73 :3 0 74 :3 0
75 :3 0 76 :3 0
77 :3 0 78 :3 0
10 :3 0 15 :3 0
13 :3 0 1f :3 0
22 :3 0 30 :3 0
1b :3 0 1c :3 0
1d :3 0 1e :3 0
12 :3 0 16 :3 0
35 :3 0 3b :3 0
33 :3 0 38 :3 0
2b :3 0 29 :3 0
2a :3 0 31 :3 0
32 :3 0 25 :3 0
28 :3 0 79 :3 0
7a :3 0 3 :4 0
7b 1 :8 0 239
c :3 0 7c :3 0
234 235 0 7d
:3 0 236 237 0
239 fd 28c 7e
:3 0 c :3 0 7c
:3 0 23b 23c 0
7d :3 0 23d 23e
0 240 100 242
102 241 240 :2 0
28a 7f :3 0 c
:3 0 7c :3 0 245
246 0 7d :3 0
247 248 0 282
45 :3 0 46 :3 0
24a 24b 0 45
:3 0 58 :3 0 24d
24e 0 80 :2 0
2 :4 0 81 :2 0
5a :2 0 f :2 0
104 253 255 :3 0
107 24f 257 24c
259 258 :2 0 48
:3 0 5b :3 0 25b
25c 0 4a :4 0
82 :4 0 4d :2 0
4e :3 0 10b 260
262 :3 0 4d :2 0
83 :4 0 10e 264
266 :3 0 4d :2 0
84 :4 0 111 268
26a :3 0 4d :2 0
7d :3 0 114 26c
26e :3 0 4d :2 0
85 :4 0 117 270
272 :3 0 4d :2 0
86 :3 0 87 :3 0
f :2 0 88 :2 0
11a 275 279 11e
274 27b :3 0 121
25d 27d :2 0 27f
124 280 25a 27f
0 281 126 0
282 128 285 :3 0
285 0 285 284
282 283 :6 0 287
2 :3 0 12b 289
12d 288 287 :2 0
28a 12f :2 0 28c
0 28c 28b 239
28a :6 0 1171 1
:3 0 c :3 0 7c
:3 0 28e 28f 0
c :3 0 5e :2 0
89 :3 0 291 293
0 134 292 295
:3 0 296 :2 0 45
:3 0 46 :3 0 298
299 0 45 :3 0
58 :3 0 29b 29c
0 11 :2 0 2
:4 0 8a :2 0 5a
:2 0 f :2 0 137
2a1 2a3 :3 0 13a
29d 2a5 29a 2a7
2a6 :2 0 48 :3 0
5b :3 0 2a9 2aa
0 4a :4 0 8b
:4 0 4d :2 0 4e
:3 0 13e 2ae 2b0
:3 0 4d :2 0 83
:4 0 141 2b2 2b4
:3 0 4d :2 0 8c
:4 0 144 2b6 2b8
:3 0 4d :2 0 52
:3 0 56 :3 0 5f
:3 0 8d :3 0 2bd
2be 0 147 2bc
2c0 55 :4 0 149
2bb 2c3 14c 2ba
2c5 :3 0 4d :2 0
8e :4 0 14f 2c7
2c9 :3 0 4d :2 0
50 :4 0 152 2cb
2cd :3 0 4d :2 0
3 :3 0 155 2cf
2d1 :3 0 4d :2 0
50 :4 0 158 2d3
2d5 :3 0 15b 2ab
2d7 :2 0 2d9 15e
2da 2a8 2d9 0
2db 160 0 305
45 :3 0 46 :3 0
2dc 2dd 0 45
:3 0 58 :3 0 2df
2e0 0 f :2 0
2 :4 0 8f :2 0
5a :2 0 f :2 0
162 2e5 2e7 :3 0
165 2e1 2e9 2de
2eb 2ea :2 0 48
:3 0 5b :3 0 2ed
2ee 0 4a :4 0
90 :4 0 4d :2 0
4e :3 0 169 2f2
2f4 :3 0 16c 2ef
2f6 :2 0 2f8 16f
2f9 2ec 2f8 0
2fa 171 0 305
91 :3 0 92 :3 0
2fb 2fc 0 5f
:3 0 8d :3 0 2fe
2ff 0 3 :3 0
93 :3 0 173 2fd
303 :2 0 305 177
306 297 305 0
307 17b 0 1171
94 :3 0 e :3 0
95 :3 0 61 :3 0
10 :3 0 96 :3 0
12 :4 0 97 1
:8 0 315 c :3 0
7c :3 0 310 311
0 7d :3 0 312
313 0 315 17d
368 7e :3 0 c
:3 0 7c :3 0 317
318 0 7d :3 0
319 31a 0 31c
180 31e 182 31d
31c :2 0 366 7f
:3 0 c :3 0 7c
:3 0 321 322 0
7d :3 0 323 324
0 35e 45 :3 0
46 :3 0 326 327
0 45 :3 0 58
:3 0 329 32a 0
80 :2 0 2 :4 0
98 :2 0 5a :2 0
f :2 0 184 32f
331 :3 0 187 32b
333 328 335 334
:2 0 48 :3 0 5b
:3 0 337 338 0
4a :4 0 99 :4 0
4d :2 0 4e :3 0
18b 33c 33e :3 0
4d :2 0 83 :4 0
18e 340 342 :3 0
4d :2 0 84 :4 0
191 344 346 :3 0
4d :2 0 7d :3 0
194 348 34a :3 0
4d :2 0 85 :4 0
197 34c 34e :3 0
4d :2 0 86 :3 0
87 :3 0 f :2 0
88 :2 0 19a 351
355 19e 350 357
:3 0 1a1 339 359
:2 0 35b 1a4 35c
336 35b 0 35d
1a6 0 35e 1a8
361 :3 0 361 0
361 360 35e 35f
:6 0 363 4 :3 0
1ab 365 1ad 364
363 :2 0 366 1af
:2 0 368 0 368
367 315 366 :6 0
1171 1 :3 0 86
:3 0 e :3 0 f
:2 0 f :2 0 1b2
36a 36e 5e :2 0
9a :4 0 1b8 370
372 :3 0 45 :3 0
46 :3 0 374 375
0 45 :3 0 58
:3 0 377 378 0
11 :2 0 2 :4 0
9b :2 0 5a :2 0
f :2 0 1bb 37d
37f :3 0 1be 379
381 376 383 382
:2 0 48 :3 0 5b
:3 0 385 386 0
4a :4 0 9c :4 0
4d :2 0 4e :3 0
1c2 38a 38c :3 0
4d :2 0 83 :4 0
1c5 38e 390 :3 0
4d :2 0 8c :4 0
1c8 392 394 :3 0
4d :2 0 52 :3 0
56 :3 0 5f :3 0
9d :3 0 399 39a
0 1cb 398 39c
55 :4 0 1cd 397
39f 1d0 396 3a1
:3 0 4d :2 0 8e
:4 0 1d3 3a3 3a5
:3 0 4d :2 0 50
:4 0 1d6 3a7 3a9
:3 0 4d :2 0 3
:3 0 1d9 3ab 3ad
:3 0 4d :2 0 50
:4 0 1dc 3af 3b1
:3 0 1df 387 3b3
:2 0 3b5 1e2 3b6
384 3b5 0 3b7
1e4 0 3e1 45
:3 0 46 :3 0 3b8
3b9 0 45 :3 0
58 :3 0 3bb 3bc
0 f :2 0 2
:4 0 9e :2 0 5a
:2 0 f :2 0 1e6
3c1 3c3 :3 0 1e9
3bd 3c5 3ba 3c7
3c6 :2 0 48 :3 0
5b :3 0 3c9 3ca
0 4a :4 0 9f
:4 0 4d :2 0 4e
:3 0 1ed 3ce 3d0
:3 0 1f0 3cb 3d2
:2 0 3d4 1f3 3d5
3c8 3d4 0 3d6
1f5 0 3e1 91
:3 0 92 :3 0 3d7
3d8 0 5f :3 0
9d :3 0 3da 3db
0 3 :3 0 93
:3 0 1f7 3d9 3df
:2 0 3e1 1fb 3e2
373 3e1 0 3e3
1ff 0 1171 52
:3 0 22 :3 0 23
:2 0 201 3e4 3e7
5e :2 0 a0 :2 0
206 3e9 3eb :3 0
45 :3 0 46 :3 0
3ed 3ee 0 45
:3 0 58 :3 0 3f0
3f1 0 11 :2 0
2 :4 0 a1 :2 0
5a :2 0 f :2 0
209 3f6 3f8 :3 0
20c 3f2 3fa 3ef
3fc 3fb :2 0 48
:3 0 5b :3 0 3fe
3ff 0 4a :4 0
a2 :4 0 4d :2 0
4e :3 0 210 403
405 :3 0 4d :2 0
83 :4 0 213 407
409 :3 0 4d :2 0
8c :4 0 216 40b
40d :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 a3 :3 0
412 413 0 219
411 415 55 :4 0
21b 410 418 21e
40f 41a :3 0 4d
:2 0 8e :4 0 221
41c 41e :3 0 4d
:2 0 50 :4 0 224
420 422 :3 0 4d
:2 0 3 :3 0 227
424 426 :3 0 4d
:2 0 50 :4 0 22a
428 42a :3 0 22d
400 42c :2 0 42e
230 42f 3fd 42e
0 430 232 0
45a 45 :3 0 46
:3 0 431 432 0
45 :3 0 58 :3 0
434 435 0 f
:2 0 2 :4 0 a4
:2 0 5a :2 0 f
:2 0 234 43a 43c
:3 0 237 436 43e
433 440 43f :2 0
48 :3 0 5b :3 0
442 443 0 4a
:4 0 a5 :4 0 4d
:2 0 4e :3 0 23b
447 449 :3 0 23e
444 44b :2 0 44d
241 44e 441 44d
0 44f 243 0
45a 91 :3 0 92
:3 0 450 451 0
5f :3 0 a3 :3 0
453 454 0 3
:3 0 93 :3 0 245
452 458 :2 0 45a
249 45b 3ec 45a
0 45c 24d 0
1171 5 :3 0 a6
:2 0 24f 45e 45f
:3 0 460 :2 0 461
:2 0 7 :3 0 a6
:2 0 251 464 465
:3 0 466 :2 0 467
:2 0 462 469 468
:2 0 a7 :3 0 a8
:3 0 46b 46c 0
1a :3 0 19 :3 0
a9 :2 0 253 46d
471 aa :2 0 23
:2 0 259 473 475
:3 0 45 :3 0 46
:3 0 477 478 0
45 :3 0 58 :3 0
47a 47b 0 11
:2 0 2 :4 0 ab
:2 0 5a :2 0 f
:2 0 25c 480 482
:3 0 25f 47c 484
479 486 485 :2 0
48 :3 0 5b :3 0
488 489 0 4a
:4 0 ac :4 0 4d
:2 0 4e :3 0 263
48d 48f :3 0 4d
:2 0 83 :4 0 266
491 493 :3 0 4d
:2 0 8c :4 0 269
495 497 :3 0 4d
:2 0 52 :3 0 56
:3 0 5f :3 0 ad
:3 0 49c 49d 0
26c 49b 49f 55
:4 0 26e 49a 4a2
271 499 4a4 :3 0
4d :2 0 8e :4 0
274 4a6 4a8 :3 0
4d :2 0 50 :4 0
277 4aa 4ac :3 0
4d :2 0 3 :3 0
27a 4ae 4b0 :3 0
4d :2 0 50 :4 0
27d 4b2 4b4 :3 0
280 48a 4b6 :2 0
4b8 283 4b9 487
4b8 0 4ba 285
0 4e4 45 :3 0
46 :3 0 4bb 4bc
0 45 :3 0 58
:3 0 4be 4bf 0
f :2 0 2 :4 0
ae :2 0 5a :2 0
f :2 0 287 4c4
4c6 :3 0 28a 4c0
4c8 4bd 4ca 4c9
:2 0 48 :3 0 5b
:3 0 4cc 4cd 0
4a :4 0 af :4 0
4d :2 0 4e :3 0
28e 4d1 4d3 :3 0
291 4ce 4d5 :2 0
4d7 294 4d8 4cb
4d7 0 4d9 296
0 4e4 91 :3 0
92 :3 0 4da 4db
0 5f :3 0 ad
:3 0 4dd 4de 0
3 :3 0 93 :3 0
298 4dc 4e2 :2 0
4e4 29c 4e5 476
4e4 0 4e6 2a0
0 4e7 2a2 4e8
46a 4e7 0 4e9
2a4 0 1171 2f
:4 0 4ea 4eb 0
1171 b0 :3 0 b1
:3 0 2f :3 0 b2
:3 0 96 :3 0 10
:3 0 6c :3 0 16
:3 0 b3 :3 0 5f
:3 0 b4 :3 0 5f
:3 0 b5 :3 0 5f
:3 0 b6 :4 0 b7
1 :8 0 502 c
:3 0 7c :3 0 4fd
4fe 0 7d :3 0
4ff 500 0 502
2a6 555 7e :3 0
c :3 0 7c :3 0
504 505 0 7d
:3 0 506 507 0
509 2a9 50b 2ab
50a 509 :2 0 553
7f :3 0 c :3 0
7c :3 0 50e 50f
0 7d :3 0 510
511 0 54b 45
:3 0 46 :3 0 513
514 0 45 :3 0
58 :3 0 516 517
0 80 :2 0 2
:4 0 b8 :2 0 5a
:2 0 f :2 0 2ad
51c 51e :3 0 2b0
518 520 515 522
521 :2 0 48 :3 0
5b :3 0 524 525
0 4a :4 0 b9
:4 0 4d :2 0 4e
:3 0 2b4 529 52b
:3 0 4d :2 0 83
:4 0 2b7 52d 52f
:3 0 4d :2 0 84
:4 0 2ba 531 533
:3 0 4d :2 0 7d
:3 0 2bd 535 537
:3 0 4d :2 0 85
:4 0 2c0 539 53b
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 2c3
53e 542 2c7 53d
544 :3 0 2ca 526
546 :2 0 548 2cd
549 523 548 0
54a 2cf 0 54b
2d1 54e :3 0 54e
0 54e 54d 54b
54c :6 0 550 6
:3 0 2d4 552 2d6
551 550 :2 0 553
2d8 :2 0 555 0
555 554 502 553
:6 0 1171 1 :3 0
17 :3 0 a :3 0
557 558 0 1171
a7 :3 0 ba :3 0
55a 55b 0 16
:3 0 17 :3 0 2db
55c 55f 5e :2 0
23 :2 0 2e0 561
563 :3 0 564 :2 0
52 :3 0 3a :3 0
23 :2 0 2e3 566
569 5f :3 0 bb
:2 0 60 :3 0 56b
56d 0 2e8 56c
56f :3 0 570 :2 0
565 572 571 :2 0
40 :3 0 bc :4 0
574 575 0 5a8
3f :3 0 f :2 0
577 578 0 5a8
43 :3 0 c :3 0
7c :3 0 57b 57c
0 57a 57d 0
5a8 41 :3 0 bd
:3 0 40 :3 0 14
:3 0 17 :3 0 3f
:3 0 23 :2 0 2eb
580 586 57f 587
0 5a8 c :3 0
7c :3 0 589 58a
0 43 :3 0 58b
58c 0 5a8 40
:3 0 be :4 0 58e
58f 0 5a8 3f
:3 0 23 :2 0 591
592 0 5a8 43
:3 0 c :3 0 7c
:3 0 595 596 0
594 597 0 5a8
41 :3 0 bd :3 0
40 :3 0 14 :3 0
17 :3 0 3f :3 0
23 :2 0 2f1 59a
5a0 599 5a1 0
5a8 c :3 0 7c
:3 0 5a3 5a4 0
43 :3 0 5a5 5a6
0 5a8 2f7 5a9
573 5a8 0 5aa
302 0 1171 19
:3 0 a6 :2 0 304
5ac 5ad :3 0 5ae
:2 0 5af :2 0 a7
:3 0 a8 :3 0 5b1
5b2 0 19 :3 0
1b :3 0 a9 :2 0
306 5b3 5b7 5e
:2 0 23 :2 0 30c
5b9 5bb :3 0 5bc
:2 0 5b0 5be 5bd
:2 0 19 :3 0 1b
:3 0 5c0 5c1 0
5c3 30f 5c4 5bf
5c3 0 5c5 311
0 1171 5 :3 0
bf :2 0 313 5c7
5c8 :3 0 5c9 :2 0
5ca :2 0 7 :3 0
bf :2 0 315 5cd
5ce :3 0 5cf :2 0
5d0 :2 0 5cb 5d2
5d1 :2 0 79 :3 0
67 :3 0 5 :3 0
69 :3 0 7 :3 0
c0 :3 0 7a :3 0
3 :4 0 c1 1
:8 0 5f2 c2 :4 0
5dd :3 0 93 :3 0
5e :2 0 319 5e0
5e1 :3 0 c :3 0
7c :3 0 5e3 5e4
0 23 :2 0 5e5
5e6 0 5e8 31c
5ef c :3 0 7c
:3 0 5e9 5ea 0
c3 :2 0 5eb 5ec
0 5ee 31e 5f0
5e2 5e8 0 5f1
0 5ee 0 5f1
320 0 5f2 323
645 7e :3 0 c
:3 0 7c :3 0 5f4
5f5 0 7d :3 0
5f6 5f7 0 5f9
326 5fb 328 5fa
5f9 :2 0 643 7f
:3 0 c :3 0 7c
:3 0 5fe 5ff 0
7d :3 0 600 601
0 63b 45 :3 0
46 :3 0 603 604
0 45 :3 0 58
:3 0 606 607 0
80 :2 0 2 :4 0
c4 :2 0 5a :2 0
f :2 0 32a 60c
60e :3 0 32d 608
610 605 612 611
:2 0 48 :3 0 5b
:3 0 614 615 0
4a :4 0 c5 :4 0
4d :2 0 4e :3 0
331 619 61b :3 0
4d :2 0 83 :4 0
334 61d 61f :3 0
4d :2 0 84 :4 0
337 621 623 :3 0
4d :2 0 7d :3 0
33a 625 627 :3 0
4d :2 0 85 :4 0
33d 629 62b :3 0
4d :2 0 86 :3 0
87 :3 0 f :2 0
88 :2 0 340 62e
632 344 62d 634
:3 0 347 616 636
:2 0 638 34a 639
613 638 0 63a
34c 0 63b 34e
63e :3 0 63e 0
63e 63d 63b 63c
:6 0 640 8 :3 0
351 642 353 641
640 :2 0 643 355
:2 0 645 0 645
644 5f2 643 :6 0
647 1 :3 0 358
10c9 5 :3 0 bf
:2 0 35a 649 64a
:3 0 64b :2 0 1d
:3 0 a6 :2 0 35c
64e 64f :3 0 650
:2 0 64c 652 651
:2 0 79 :3 0 67
:3 0 5 :3 0 c0
:3 0 7a :3 0 3
:4 0 c6 1 :8 0
670 c2 :4 0 65b
:3 0 93 :3 0 5e
:2 0 360 65e 65f
:3 0 c :3 0 7c
:3 0 661 662 0
23 :2 0 663 664
0 666 363 66d
c :3 0 7c :3 0
667 668 0 c3
:2 0 669 66a 0
66c 365 66e 660
666 0 66f 0
66c 0 66f 367
0 670 36a 6c3
7e :3 0 c :3 0
7c :3 0 672 673
0 7d :3 0 674
675 0 677 36d
679 36f 678 677
:2 0 6c1 7f :3 0
c :3 0 7c :3 0
67c 67d 0 7d
:3 0 67e 67f 0
6b9 45 :3 0 46
:3 0 681 682 0
45 :3 0 58 :3 0
684 685 0 80
:2 0 2 :4 0 c7
:2 0 5a :2 0 f
:2 0 371 68a 68c
:3 0 374 686 68e
683 690 68f :2 0
48 :3 0 5b :3 0
692 693 0 4a
:4 0 c8 :4 0 4d
:2 0 4e :3 0 378
697 699 :3 0 4d
:2 0 83 :4 0 37b
69b 69d :3 0 4d
:2 0 84 :4 0 37e
69f 6a1 :3 0 4d
:2 0 7d :3 0 381
6a3 6a5 :3 0 4d
:2 0 85 :4 0 384
6a7 6a9 :3 0 4d
:2 0 86 :3 0 87
:3 0 f :2 0 88
:2 0 387 6ac 6b0
38b 6ab 6b2 :3 0
38e 694 6b4 :2 0
6b6 391 6b7 691
6b6 0 6b8 393
0 6b9 395 6bc
:3 0 6bc 0 6bc
6bb 6b9 6ba :6 0
6be a :3 0 398
6c0 39a 6bf 6be
:2 0 6c1 39c :2 0
6c3 0 6c3 6c2
670 6c1 :6 0 6d7
1 :3 0 a7 :3 0
a8 :3 0 6c5 6c6
0 1a :3 0 1e
:3 0 a9 :2 0 39f
6c7 6cb 5e :2 0
23 :2 0 3a5 6cd
6cf :3 0 36 :3 0
23 :2 0 6d1 6d2
0 6d4 3a8 6d5
6d0 6d4 0 6d6
3aa 0 6d7 3ac
6d8 653 6d7 0
6d9 3af 0 10c8
7 :3 0 bf :2 0
3b1 6db 6dc :3 0
6dd :2 0 1e :3 0
a6 :2 0 3b3 6e0
6e1 :3 0 6e2 :2 0
6de 6e4 6e3 :2 0
79 :3 0 69 :3 0
7 :3 0 c0 :3 0
7a :3 0 3 :4 0
c9 1 :8 0 702
c2 :4 0 6ed :3 0
93 :3 0 5e :2 0
3b7 6f0 6f1 :3 0
c :3 0 7c :3 0
6f3 6f4 0 23
:2 0 6f5 6f6 0
6f8 3ba 6ff c
:3 0 7c :3 0 6f9
6fa 0 c3 :2 0
6fb 6fc 0 6fe
3bc 700 6f2 6f8
0 701 0 6fe
0 701 3be 0
702 3c1 755 7e
:3 0 c :3 0 7c
:3 0 704 705 0
7d :3 0 706 707
0 709 3c4 70b
3c6 70a 709 :2 0
753 7f :3 0 c
:3 0 7c :3 0 70e
70f 0 7d :3 0
710 711 0 74b
45 :3 0 46 :3 0
713 714 0 45
:3 0 58 :3 0 716
717 0 80 :2 0
2 :4 0 ca :2 0
5a :2 0 f :2 0
3c8 71c 71e :3 0
3cb 718 720 715
722 721 :2 0 48
:3 0 5b :3 0 724
725 0 4a :4 0
cb :4 0 4d :2 0
4e :3 0 3cf 729
72b :3 0 4d :2 0
83 :4 0 3d2 72d
72f :3 0 4d :2 0
84 :4 0 3d5 731
733 :3 0 4d :2 0
7d :3 0 3d8 735
737 :3 0 4d :2 0
85 :4 0 3db 739
73b :3 0 4d :2 0
86 :3 0 87 :3 0
f :2 0 88 :2 0
3de 73e 742 3e2
73d 744 :3 0 3e5
726 746 :2 0 748
3e8 749 723 748
0 74a 3ea 0
74b 3ec 74e :3 0
74e 0 74e 74d
74b 74c :6 0 750
c :3 0 3ef 752
3f1 751 750 :2 0
753 3f3 :2 0 755
0 755 754 702
753 :6 0 769 1
:3 0 a7 :3 0 a8
:3 0 757 758 0
19 :3 0 1d :3 0
a9 :2 0 3f6 759
75d 5e :2 0 23
:2 0 3fc 75f 761
:3 0 36 :3 0 23
:2 0 763 764 0
766 3ff 767 762
766 0 768 401
0 769 403 76a
6e5 769 0 76b
406 0 10c8 52
:3 0 36 :3 0 23
:2 0 408 76c 76f
5e :2 0 f :2 0
40d 771 773 :3 0
1a :3 0 a6 :2 0
410 776 777 :3 0
778 :2 0 779 :2 0
a7 :3 0 a8 :3 0
77b 77c 0 1a
:3 0 1c :3 0 a9
:2 0 412 77d 781
5e :2 0 23 :2 0
418 783 785 :3 0
786 :2 0 77a 788
787 :2 0 1a :3 0
1c :3 0 78a 78b
0 78d 41b 78e
789 78d 0 78f
41d 0 10c5 2f
:3 0 a6 :2 0 41f
791 792 :3 0 793
:2 0 794 :2 0 1a
:3 0 a6 :2 0 421
797 798 :3 0 799
:2 0 79a :2 0 795
79c 79b :2 0 a7
:3 0 ba :3 0 79e
79f 0 2f :3 0
1a :3 0 423 7a0
7a3 cc :2 0 23
:2 0 428 7a5 7a7
:3 0 7a8 :2 0 79d
7aa 7a9 :2 0 45
:3 0 46 :3 0 7ac
7ad 0 45 :3 0
58 :3 0 7af 7b0
0 11 :2 0 2
:4 0 cd :2 0 5a
:2 0 f :2 0 42b
7b5 7b7 :3 0 42e
7b1 7b9 7ae 7bb
7ba :2 0 48 :3 0
5b :3 0 7bd 7be
0 4a :4 0 ce
:4 0 4d :2 0 4e
:3 0 432 7c2 7c4
:3 0 4d :2 0 83
:4 0 435 7c6 7c8
:3 0 4d :2 0 8c
:4 0 438 7ca 7cc
:3 0 4d :2 0 52
:3 0 56 :3 0 5f
:3 0 cf :3 0 7d1
7d2 0 43b 7d0
7d4 55 :4 0 43d
7cf 7d7 440 7ce
7d9 :3 0 4d :2 0
8e :4 0 443 7db
7dd :3 0 4d :2 0
50 :4 0 446 7df
7e1 :3 0 4d :2 0
16 :3 0 449 7e3
7e5 :3 0 4d :2 0
50 :4 0 44c 7e7
7e9 :3 0 44f 7bf
7eb :2 0 7ed 452
7ee 7bc 7ed 0
7ef 454 0 819
45 :3 0 46 :3 0
7f0 7f1 0 45
:3 0 58 :3 0 7f3
7f4 0 f :2 0
2 :4 0 d0 :2 0
5a :2 0 f :2 0
456 7f9 7fb :3 0
459 7f5 7fd 7f2
7ff 7fe :2 0 48
:3 0 5b :3 0 801
802 0 4a :4 0
d1 :4 0 4d :2 0
4e :3 0 45d 806
808 :3 0 460 803
80a :2 0 80c 463
80d 800 80c 0
80e 465 0 819
91 :3 0 92 :3 0
80f 810 0 5f
:3 0 cf :3 0 812
813 0 16 :3 0
93 :3 0 467 811
817 :2 0 819 46b
81a 7ab 819 0
81b 46f 0 10c5
5 :3 0 a6 :2 0
471 81d 81e :3 0
81f :2 0 1f :3 0
a6 :2 0 473 822
823 :3 0 824 :2 0
45 :3 0 46 :3 0
826 827 0 45
:3 0 58 :3 0 829
82a 0 11 :2 0
2 :4 0 d2 :2 0
5a :2 0 f :2 0
475 82f 831 :3 0
478 82b 833 828
835 834 :2 0 48
:3 0 5b :3 0 837
838 0 4a :4 0
d3 :4 0 4d :2 0
4e :3 0 47c 83c
83e :3 0 4d :2 0
83 :4 0 47f 840
842 :3 0 4d :2 0
8c :4 0 482 844
846 :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 d4 :3 0
84b 84c 0 485
84a 84e 55 :4 0
487 849 851 48a
848 853 :3 0 4d
:2 0 8e :4 0 48d
855 857 :3 0 4d
:2 0 50 :4 0 490
859 85b :3 0 4d
:2 0 3 :3 0 493
85d 85f :3 0 4d
:2 0 50 :4 0 496
861 863 :3 0 499
839 865 :2 0 867
49c 868 836 867
0 869 49e 0
893 45 :3 0 46
:3 0 86a 86b 0
45 :3 0 58 :3 0
86d 86e 0 f
:2 0 2 :4 0 d5
:2 0 5a :2 0 f
:2 0 4a0 873 875
:3 0 4a3 86f 877
86c 879 878 :2 0
48 :3 0 5b :3 0
87b 87c 0 4a
:4 0 d6 :4 0 4d
:2 0 4e :3 0 4a7
880 882 :3 0 4aa
87d 884 :2 0 886
4ad 887 87a 886
0 888 4af 0
893 91 :3 0 92
:3 0 889 88a 0
5f :3 0 d4 :3 0
88c 88d 0 3
:3 0 93 :3 0 4b1
88b 891 :2 0 893
4b5 894 825 893
0 895 4b9 0
a07 37 :3 0 33
:3 0 896 897 0
a07 a7 :3 0 a8
:3 0 899 89a 0
19 :3 0 29 :3 0
a9 :2 0 4bb 89b
89f 5e :2 0 23
:2 0 4c1 8a1 8a3
:3 0 19 :4 0 8a5
8a6 0 8a9 d7
:3 0 4c4 a05 a7
:3 0 a8 :3 0 8aa
8ab 0 19 :3 0
1b :3 0 a9 :2 0
4c6 8ac 8b0 bb
:2 0 23 :2 0 4cc
8b2 8b4 :3 0 a7
:3 0 d8 :3 0 d9
:3 0 a7 :3 0 da
:3 0 db :3 0 dc
:3 0 dd :3 0 19
:3 0 de :3 0 96
:3 0 10 :3 0 d9
:3 0 df :3 0 86
:3 0 5 :4 0 e0
1 :8 0 8cc c
:3 0 7c :3 0 8c7
8c8 0 7d :3 0
8c9 8ca 0 8cc
4cf 91f 7e :3 0
c :3 0 7c :3 0
8ce 8cf 0 7d
:3 0 8d0 8d1 0
8d3 4d2 8d5 4d4
8d4 8d3 :2 0 91d
7f :3 0 c :3 0
7c :3 0 8d8 8d9
0 7d :3 0 8da
8db 0 915 45
:3 0 46 :3 0 8dd
8de 0 45 :3 0
58 :3 0 8e0 8e1
0 80 :2 0 2
:4 0 e1 :2 0 5a
:2 0 f :2 0 4d6
8e6 8e8 :3 0 4d9
8e2 8ea 8df 8ec
8eb :2 0 48 :3 0
5b :3 0 8ee 8ef
0 4a :4 0 e2
:4 0 4d :2 0 4e
:3 0 4dd 8f3 8f5
:3 0 4d :2 0 83
:4 0 4e0 8f7 8f9
:3 0 4d :2 0 84
:4 0 4e3 8fb 8fd
:3 0 4d :2 0 7d
:3 0 4e6 8ff 901
:3 0 4d :2 0 85
:4 0 4e9 903 905
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 4ec
908 90c 4f0 907
90e :3 0 4f3 8f0
910 :2 0 912 4f6
913 8ed 912 0
914 4f8 0 915
4fa 918 :3 0 918
0 918 917 915
916 :6 0 91a e
:3 0 4fd 91c 4ff
91b 91a :2 0 91d
501 :2 0 91f 0
91f 91e 8cc 91d
:6 0 993 1 :3 0
c :3 0 7c :3 0
921 922 0 c
:3 0 5e :2 0 89
:3 0 924 926 0
506 925 928 :3 0
929 :2 0 a7 :3 0
d8 :3 0 df :3 0
86 :3 0 5 :3 0
a7 :3 0 da :3 0
19 :3 0 e3 :4 0
e4 1 :8 0 93a
c :3 0 7c :3 0
935 936 0 7d
:3 0 937 938 0
93a 509 98d 7e
:3 0 c :3 0 7c
:3 0 93c 93d 0
7d :3 0 93e 93f
0 941 50c 943
50e 942 941 :2 0
98b 7f :3 0 c
:3 0 7c :3 0 946
947 0 7d :3 0
948 949 0 983
45 :3 0 46 :3 0
94b 94c 0 45
:3 0 58 :3 0 94e
94f 0 80 :2 0
2 :4 0 e5 :2 0
5a :2 0 f :2 0
510 954 956 :3 0
513 950 958 94d
95a 959 :2 0 48
:3 0 5b :3 0 95c
95d 0 4a :4 0
e6 :4 0 4d :2 0
4e :3 0 517 961
963 :3 0 4d :2 0
83 :4 0 51a 965
967 :3 0 4d :2 0
84 :4 0 51d 969
96b :3 0 4d :2 0
7d :3 0 520 96d
96f :3 0 4d :2 0
85 :4 0 523 971
973 :3 0 4d :2 0
86 :3 0 87 :3 0
f :2 0 88 :2 0
526 976 97a 52a
975 97c :3 0 52d
95e 97e :2 0 980
530 981 95b 980
0 982 532 0
983 534 986 :3 0
986 0 986 985
983 984 :6 0 988
10 :3 0 537 98a
539 989 988 :2 0
98b 53b :2 0 98d
0 98d 98c 93a
98b :6 0 98f 1
:3 0 53e 990 92a
98f 0 991 540
0 993 d7 :3 0
542 994 8b5 993
0 a06 7 :3 0
bf :2 0 545 996
997 :3 0 998 :2 0
45 :3 0 46 :3 0
99a 99b 0 45
:3 0 58 :3 0 99d
99e 0 11 :2 0
2 :4 0 e7 :2 0
5a :2 0 f :2 0
547 9a3 9a5 :3 0
54a 99f 9a7 99c
9a9 9a8 :2 0 48
:3 0 5b :3 0 9ab
9ac 0 4a :4 0
e8 :4 0 4d :2 0
4e :3 0 54e 9b0
9b2 :3 0 4d :2 0
83 :4 0 551 9b4
9b6 :3 0 4d :2 0
8c :4 0 554 9b8
9ba :3 0 4d :2 0
52 :3 0 56 :3 0
23 :2 0 557 9be
9c0 55 :4 0 559
9bd 9c3 55c 9bc
9c5 :3 0 4d :2 0
8e :4 0 55f 9c7
9c9 :3 0 4d :2 0
50 :4 0 562 9cb
9cd :3 0 4d :2 0
3 :3 0 565 9cf
9d1 :3 0 4d :2 0
50 :4 0 568 9d3
9d5 :3 0 56b 9ad
9d7 :2 0 9d9 56e
9da 9aa 9d9 0
9db 570 0 a03
45 :3 0 46 :3 0
9dc 9dd 0 45
:3 0 58 :3 0 9df
9e0 0 f :2 0
2 :4 0 e9 :2 0
5a :2 0 f :2 0
572 9e5 9e7 :3 0
575 9e1 9e9 9de
9eb 9ea :2 0 48
:3 0 5b :3 0 9ed
9ee 0 4a :4 0
ea :4 0 4d :2 0
4e :3 0 579 9f2
9f4 :3 0 57c 9ef
9f6 :2 0 9f8 57f
9f9 9ec 9f8 0
9fa 581 0 a03
91 :3 0 92 :3 0
9fb 9fc 0 23
:2 0 3 :3 0 93
:3 0 583 9fd a01
:2 0 a03 587 a04
999 a03 0 a06
8a4 8a9 0 a06
58b 0 a07 58f
a0f 37 :3 0 23
:2 0 a08 a09 0
a0e 19 :4 0 a0b
a0c 0 a0e 593
a10 820 a07 0
a11 0 a0e 0
a11 596 0 10c5
7 :3 0 a6 :2 0
599 a13 a14 :3 0
a15 :2 0 5 :3 0
bf :2 0 59b a18
a19 :3 0 a1a :2 0
a1b :2 0 a7 :3 0
a8 :3 0 a1d a1e
0 1a :3 0 29
:3 0 a9 :2 0 59d
a1f a23 aa :2 0
23 :2 0 5a3 a25
a27 :3 0 a28 :2 0
a1c a2a a29 :2 0
45 :3 0 46 :3 0
a2c a2d 0 45
:3 0 58 :3 0 a2f
a30 0 11 :2 0
2 :4 0 eb :2 0
5a :2 0 f :2 0
5a6 a35 a37 :3 0
5a9 a31 a39 a2e
a3b a3a :2 0 48
:3 0 5b :3 0 a3d
a3e 0 4a :4 0
ec :4 0 4d :2 0
4e :3 0 5ad a42
a44 :3 0 4d :2 0
83 :4 0 5b0 a46
a48 :3 0 4d :2 0
8c :4 0 5b3 a4a
a4c :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 ed :3 0
a51 a52 0 5b6
a50 a54 55 :4 0
5b8 a4f a57 5bb
a4e a59 :3 0 4d
:2 0 8e :4 0 5be
a5b a5d :3 0 4d
:2 0 50 :4 0 5c1
a5f a61 :3 0 4d
:2 0 3 :3 0 5c4
a63 a65 :3 0 4d
:2 0 50 :4 0 5c7
a67 a69 :3 0 5ca
a3f a6b :2 0 a6d
5cd a6e a3c a6d
0 a6f 5cf 0
a9a 45 :3 0 46
:3 0 a70 a71 0
45 :3 0 58 :3 0
a73 a74 0 f
:2 0 2 :4 0 ee
:2 0 5a :2 0 f
:2 0 5d1 a79 a7b
:3 0 5d4 a75 a7d
a72 a7f a7e :2 0
48 :3 0 5b :3 0
a81 a82 0 4a
:4 0 ef :4 0 4d
:2 0 4e :3 0 5d8
a86 a88 :3 0 5db
a83 a8a :2 0 a8c
5de a8d a80 a8c
0 a8e 5e0 0
a9a 91 :3 0 92
:3 0 a8f a90 0
5f :3 0 ed :3 0
a92 a93 0 3
:3 0 93 :3 0 5e2
a91 a97 :2 0 a9a
d7 :3 0 5e6 b0e
2b :3 0 a6 :2 0
5ea a9c a9d :3 0
a9e :2 0 a9f :2 0
a7 :3 0 a8 :3 0
aa1 aa2 0 1a
:3 0 2b :3 0 a9
:2 0 5ec aa3 aa7
f0 :2 0 23 :2 0
5f2 aa9 aab :3 0
aac :2 0 aa0 aae
aad :2 0 45 :3 0
46 :3 0 ab0 ab1
0 45 :3 0 58
:3 0 ab3 ab4 0
f1 :2 0 2 :4 0
f2 :2 0 5a :2 0
f :2 0 5f5 ab9
abb :3 0 5f8 ab5
abd ab2 abf abe
:2 0 48 :3 0 5b
:3 0 ac1 ac2 0
4a :4 0 f3 :4 0
4d :2 0 4e :3 0
5fc ac6 ac8 :3 0
4d :2 0 83 :4 0
5ff aca acc :3 0
4d :2 0 8c :4 0
602 ace ad0 :3 0
4d :2 0 52 :3 0
56 :3 0 5f :3 0
d4 :3 0 ad5 ad6
0 605 ad4 ad8
55 :4 0 607 ad3
adb 60a ad2 add
:3 0 60d ac3 adf
:2 0 ae1 610 ae2
ac0 ae1 0 ae3
612 0 b0c 45
:3 0 46 :3 0 ae4
ae5 0 45 :3 0
58 :3 0 ae7 ae8
0 f :2 0 2
:4 0 f4 :2 0 5a
:2 0 f :2 0 614
aed aef :3 0 617
ae9 af1 ae6 af3
af2 :2 0 48 :3 0
5b :3 0 af5 af6
0 4a :4 0 f5
:4 0 4d :2 0 4e
:3 0 61b afa afc
:3 0 61e af7 afe
:2 0 b00 621 b01
af4 b00 0 b02
623 0 b0c 91
:3 0 f6 :3 0 b03
b04 0 5f :3 0
d4 :3 0 b06 b07
0 93 :3 0 625
b05 b0a :2 0 b0c
628 b0d aaf b0c
0 b0f a2b a9a
0 b0f 62c 0
ca4 5 :3 0 bf
:2 0 62f b11 b12
:3 0 b13 :2 0 b14
:2 0 a7 :3 0 a8
:3 0 b16 b17 0
1a :3 0 1c :3 0
a9 :2 0 631 b18
b1c aa :2 0 23
:2 0 637 b1e b20
:3 0 b21 :2 0 b15
b23 b22 :2 0 3c
:3 0 f :2 0 b25
b26 0 b28 63a
b2d 3c :3 0 23
:2 0 b29 b2a 0
b2c 63c b2e b24
b28 0 b2f 0
b2c 0 b2f 63e
0 ca4 a7 :3 0
a8 :3 0 b30 b31
0 1a :3 0 2a
:3 0 a9 :2 0 641
b32 b36 5e :2 0
23 :2 0 647 b38
b3a :3 0 1a :4 0
b3c b3d 0 b40
d7 :3 0 64a ca2
a7 :3 0 ba :3 0
b41 b42 0 1a
:3 0 1c :3 0 64c
b43 b46 bb :2 0
23 :2 0 651 b48
b4a :3 0 a7 :3 0
d8 :3 0 d9 :3 0
a7 :3 0 da :3 0
db :3 0 f7 :3 0
dd :3 0 1a :3 0
de :3 0 96 :3 0
10 :3 0 d9 :3 0
df :3 0 86 :3 0
7 :4 0 f8 1
:8 0 b62 c :3 0
7c :3 0 b5d b5e
0 7d :3 0 b5f
b60 0 b62 654
bb5 7e :3 0 c
:3 0 7c :3 0 b64
b65 0 7d :3 0
b66 b67 0 b69
657 b6b 659 b6a
b69 :2 0 bb3 7f
:3 0 c :3 0 7c
:3 0 b6e b6f 0
7d :3 0 b70 b71
0 bab 45 :3 0
46 :3 0 b73 b74
0 45 :3 0 58
:3 0 b76 b77 0
80 :2 0 2 :4 0
f9 :2 0 5a :2 0
f :2 0 65b b7c
b7e :3 0 65e b78
b80 b75 b82 b81
:2 0 48 :3 0 5b
:3 0 b84 b85 0
4a :4 0 fa :4 0
4d :2 0 4e :3 0
662 b89 b8b :3 0
4d :2 0 83 :4 0
665 b8d b8f :3 0
4d :2 0 84 :4 0
668 b91 b93 :3 0
4d :2 0 7d :3 0
66b b95 b97 :3 0
4d :2 0 85 :4 0
66e b99 b9b :3 0
4d :2 0 86 :3 0
87 :3 0 f :2 0
88 :2 0 671 b9e
ba2 675 b9d ba4
:3 0 678 b86 ba6
:2 0 ba8 67b ba9
b83 ba8 0 baa
67d 0 bab 67f
bae :3 0 bae 0
bae bad bab bac
:6 0 bb0 12 :3 0
682 bb2 684 bb1
bb0 :2 0 bb3 686
:2 0 bb5 0 bb5
bb4 b62 bb3 :6 0
c29 1 :3 0 c
:3 0 7c :3 0 bb7
bb8 0 c :3 0
5e :2 0 89 :3 0
bba bbc 0 68b
bbb bbe :3 0 bbf
:2 0 a7 :3 0 d8
:3 0 df :3 0 86
:3 0 7 :3 0 a7
:3 0 da :3 0 1a
:3 0 e3 :4 0 fb
1 :8 0 bd0 c
:3 0 7c :3 0 bcb
bcc 0 7d :3 0
bcd bce 0 bd0
68e c23 7e :3 0
c :3 0 7c :3 0
bd2 bd3 0 7d
:3 0 bd4 bd5 0
bd7 691 bd9 693
bd8 bd7 :2 0 c21
7f :3 0 c :3 0
7c :3 0 bdc bdd
0 7d :3 0 bde
bdf 0 c19 45
:3 0 46 :3 0 be1
be2 0 45 :3 0
58 :3 0 be4 be5
0 80 :2 0 2
:4 0 fc :2 0 5a
:2 0 f :2 0 695
bea bec :3 0 698
be6 bee be3 bf0
bef :2 0 48 :3 0
5b :3 0 bf2 bf3
0 4a :4 0 fd
:4 0 4d :2 0 4e
:3 0 69c bf7 bf9
:3 0 4d :2 0 83
:4 0 69f bfb bfd
:3 0 4d :2 0 84
:4 0 6a2 bff c01
:3 0 4d :2 0 7d
:3 0 6a5 c03 c05
:3 0 4d :2 0 85
:4 0 6a8 c07 c09
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 6ab
c0c c10 6af c0b
c12 :3 0 6b2 bf4
c14 :2 0 c16 6b5
c17 bf1 c16 0
c18 6b7 0 c19
6b9 c1c :3 0 c1c
0 c1c c1b c19
c1a :6 0 c1e 14
:3 0 6bc c20 6be
c1f c1e :2 0 c21
6c0 :2 0 c23 0
c23 c22 bd0 c21
:6 0 c25 1 :3 0
6c3 c26 bc0 c25
0 c27 6c5 0
c29 d7 :3 0 6c7
c2a b4b c29 0
ca3 a7 :3 0 a8
:3 0 c2b c2c 0
1a :3 0 29 :3 0
a9 :2 0 6ca c2d
c31 5e :2 0 23
:2 0 6d0 c33 c35
:3 0 45 :3 0 46
:3 0 c37 c38 0
45 :3 0 58 :3 0
c3a c3b 0 11
:2 0 2 :4 0 fe
:2 0 5a :2 0 f
:2 0 6d3 c40 c42
:3 0 6d6 c3c c44
c39 c46 c45 :2 0
48 :3 0 5b :3 0
c48 c49 0 4a
:4 0 ff :4 0 4d
:2 0 4e :3 0 6da
c4d c4f :3 0 4d
:2 0 83 :4 0 6dd
c51 c53 :3 0 4d
:2 0 8c :4 0 6e0
c55 c57 :3 0 4d
:2 0 52 :3 0 56
:3 0 23 :2 0 6e3
c5b c5d 55 :4 0
6e5 c5a c60 6e8
c59 c62 :3 0 4d
:2 0 8e :4 0 6eb
c64 c66 :3 0 4d
:2 0 50 :4 0 6ee
c68 c6a :3 0 4d
:2 0 3 :3 0 6f1
c6c c6e :3 0 4d
:2 0 50 :4 0 6f4
c70 c72 :3 0 6f7
c4a c74 :2 0 c76
6fa c77 c47 c76
0 c78 6fc 0
ca0 45 :3 0 46
:3 0 c79 c7a 0
45 :3 0 58 :3 0
c7c c7d 0 f
:2 0 2 :4 0 100
:2 0 5a :2 0 f
:2 0 6fe c82 c84
:3 0 701 c7e c86
c7b c88 c87 :2 0
48 :3 0 5b :3 0
c8a c8b 0 4a
:4 0 101 :4 0 4d
:2 0 4e :3 0 705
c8f c91 :3 0 708
c8c c93 :2 0 c95
70b c96 c89 c95
0 c97 70d 0
ca0 91 :3 0 92
:3 0 c98 c99 0
23 :2 0 3 :3 0
93 :3 0 70f c9a
c9e :2 0 ca0 713
ca1 c36 ca0 0
ca3 b3b b40 0
ca3 717 0 ca4
71b ca9 1a :4 0
ca5 ca6 0 ca8
71f caa a16 ca4
0 cab 0 ca8
0 cab 721 0
10c5 17 :3 0 a
:3 0 cac cad 0
10c5 3d :3 0 23
:2 0 caf cb0 0
10c5 52 :3 0 3a
:3 0 23 :2 0 724
cb2 cb5 5f :3 0
bb :2 0 60 :3 0
cb7 cb9 0 729
cb8 cbb :3 0 79
:3 0 67 :3 0 19
:3 0 69 :3 0 1a
:3 0 c0 :3 0 7a
:3 0 3 :4 0 102
1 :8 0 cdb c2
:4 0 cc6 :3 0 93
:3 0 5e :2 0 72e
cc9 cca :3 0 c
:3 0 7c :3 0 ccc
ccd 0 23 :2 0
cce ccf 0 cd1
731 cd8 c :3 0
7c :3 0 cd2 cd3
0 c3 :2 0 cd4
cd5 0 cd7 733
cd9 ccb cd1 0
cda 0 cd7 0
cda 735 0 cdb
738 d2e 7e :3 0
c :3 0 7c :3 0
cdd cde 0 7d
:3 0 cdf ce0 0
ce2 73b ce4 73d
ce3 ce2 :2 0 d2c
7f :3 0 c :3 0
7c :3 0 ce7 ce8
0 7d :3 0 ce9
cea 0 d24 45
:3 0 46 :3 0 cec
ced 0 45 :3 0
58 :3 0 cef cf0
0 80 :2 0 2
:4 0 103 :2 0 5a
:2 0 f :2 0 73f
cf5 cf7 :3 0 742
cf1 cf9 cee cfb
cfa :2 0 48 :3 0
5b :3 0 cfd cfe
0 4a :4 0 104
:4 0 4d :2 0 4e
:3 0 746 d02 d04
:3 0 4d :2 0 83
:4 0 749 d06 d08
:3 0 4d :2 0 84
:4 0 74c d0a d0c
:3 0 4d :2 0 7d
:3 0 74f d0e d10
:3 0 4d :2 0 85
:4 0 752 d12 d14
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 755
d17 d1b 759 d16
d1d :3 0 75c cff
d1f :2 0 d21 75f
d22 cfc d21 0
d23 761 0 d24
763 d27 :3 0 d27
0 d27 d26 d24
d25 :6 0 d29 16
:3 0 766 d2b 768
d2a d29 :2 0 d2c
76a :2 0 d2e 0
d2e d2d cdb d2c
:6 0 d30 1 :3 0
76d 10c2 13 :3 0
a6 :2 0 76f d32
d33 :3 0 d34 :2 0
7 :3 0 a6 :2 0
771 d37 d38 :3 0
d39 :2 0 3d :3 0
23 :2 0 d3b d3c
0 e22 105 :3 0
3d :3 0 e3 :3 0
d9 :3 0 106 :3 0
61 :3 0 10 :3 0
7a :3 0 13 :3 0
7a :3 0 14 :3 0
d9 :3 0 df :3 0
86 :3 0 7 :4 0
107 1 :8 0 d53
c :3 0 7c :3 0
d4e d4f 0 7d
:3 0 d50 d51 0
d53 773 da6 7e
:3 0 c :3 0 7c
:3 0 d55 d56 0
7d :3 0 d57 d58
0 d5a 776 d5c
778 d5b d5a :2 0
da4 7f :3 0 c
:3 0 7c :3 0 d5f
d60 0 7d :3 0
d61 d62 0 d9c
45 :3 0 46 :3 0
d64 d65 0 45
:3 0 58 :3 0 d67
d68 0 80 :2 0
2 :4 0 108 :2 0
5a :2 0 f :2 0
77a d6d d6f :3 0
77d d69 d71 d66
d73 d72 :2 0 48
:3 0 5b :3 0 d75
d76 0 4a :4 0
109 :4 0 4d :2 0
4e :3 0 781 d7a
d7c :3 0 4d :2 0
83 :4 0 784 d7e
d80 :3 0 4d :2 0
84 :4 0 787 d82
d84 :3 0 4d :2 0
7d :3 0 78a d86
d88 :3 0 4d :2 0
85 :4 0 78d d8a
d8c :3 0 4d :2 0
86 :3 0 87 :3 0
f :2 0 88 :2 0
790 d8f d93 794
d8e d95 :3 0 797
d77 d97 :2 0 d99
79a d9a d74 d99
0 d9b 79c 0
d9c 79e d9f :3 0
d9f 0 d9f d9e
d9c d9d :6 0 da1
18 :3 0 7a1 da3
7a3 da2 da1 :2 0
da4 7a5 :2 0 da6
0 da6 da5 d53
da4 :6 0 e22 1
:3 0 52 :3 0 3d
:3 0 23 :2 0 7a8
da8 dab 5e :2 0
23 :2 0 7ad dad
daf :3 0 45 :3 0
46 :3 0 db1 db2
0 45 :3 0 58
:3 0 db4 db5 0
11 :2 0 2 :4 0
10a :2 0 5a :2 0
f :2 0 7b0 dba
dbc :3 0 7b3 db6
dbe db3 dc0 dbf
:2 0 48 :3 0 5b
:3 0 dc2 dc3 0
4a :4 0 10b :4 0
4d :2 0 4e :3 0
7b7 dc7 dc9 :3 0
4d :2 0 83 :4 0
7ba dcb dcd :3 0
4d :2 0 8c :4 0
7bd dcf dd1 :3 0
4d :2 0 52 :3 0
56 :3 0 5f :3 0
10c :3 0 dd6 dd7
0 7c0 dd5 dd9
55 :4 0 7c2 dd4
ddc 7c5 dd3 dde
:3 0 4d :2 0 8e
:4 0 7c8 de0 de2
:3 0 4d :2 0 50
:4 0 7cb de4 de6
:3 0 4d :2 0 14
:3 0 7ce de8 dea
:3 0 4d :2 0 50
:4 0 7d1 dec dee
:3 0 7d4 dc4 df0
:2 0 df2 7d7 df3
dc1 df2 0 df4
7d9 0 e1e 45
:3 0 46 :3 0 df5
df6 0 45 :3 0
58 :3 0 df8 df9
0 f :2 0 2
:4 0 10d :2 0 5a
:2 0 f :2 0 7db
dfe e00 :3 0 7de
dfa e02 df7 e04
e03 :2 0 48 :3 0
5b :3 0 e06 e07
0 4a :4 0 10e
:4 0 4d :2 0 4e
:3 0 7e2 e0b e0d
:3 0 7e5 e08 e0f
:2 0 e11 7e8 e12
e05 e11 0 e13
7ea 0 e1e 91
:3 0 92 :3 0 e14
e15 0 5f :3 0
10c :3 0 e17 e18
0 14 :3 0 93
:3 0 7ec e16 e1c
:2 0 e1e 7f0 e1f
db0 e1e 0 e20
7f4 0 e22 d7
:3 0 7f6 1064 5
:3 0 a6 :2 0 7fa
e24 e25 :3 0 e26
:2 0 3d :3 0 23
:2 0 e28 e29 0
ff4 105 :3 0 3d
:3 0 e3 :3 0 d9
:3 0 106 :3 0 61
:3 0 10 :3 0 7a
:3 0 13 :3 0 7a
:3 0 14 :3 0 d9
:3 0 df :3 0 86
:3 0 5 :4 0 10f
1 :8 0 e40 c
:3 0 7c :3 0 e3b
e3c 0 7d :3 0
e3d e3e 0 e40
7fc e93 7e :3 0
c :3 0 7c :3 0
e42 e43 0 7d
:3 0 e44 e45 0
e47 7ff e49 801
e48 e47 :2 0 e91
7f :3 0 c :3 0
7c :3 0 e4c e4d
0 7d :3 0 e4e
e4f 0 e89 45
:3 0 46 :3 0 e51
e52 0 45 :3 0
58 :3 0 e54 e55
0 80 :2 0 2
:4 0 110 :2 0 5a
:2 0 f :2 0 803
e5a e5c :3 0 806
e56 e5e e53 e60
e5f :2 0 48 :3 0
5b :3 0 e62 e63
0 4a :4 0 111
:4 0 4d :2 0 4e
:3 0 80a e67 e69
:3 0 4d :2 0 83
:4 0 80d e6b e6d
:3 0 4d :2 0 84
:4 0 810 e6f e71
:3 0 4d :2 0 7d
:3 0 813 e73 e75
:3 0 4d :2 0 85
:4 0 816 e77 e79
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 819
e7c e80 81d e7b
e82 :3 0 820 e64
e84 :2 0 e86 823
e87 e61 e86 0
e88 825 0 e89
827 e8c :3 0 e8c
0 e8c e8b e89
e8a :6 0 e8e 1a
:3 0 82a e90 82c
e8f e8e :2 0 e91
82e :2 0 e93 0
e93 e92 e40 e91
:6 0 ff4 1 :3 0
52 :3 0 3d :3 0
23 :2 0 831 e95
e98 5e :2 0 23
:2 0 836 e9a e9c
:3 0 45 :3 0 46
:3 0 e9e e9f 0
45 :3 0 58 :3 0
ea1 ea2 0 11
:2 0 2 :4 0 112
:2 0 5a :2 0 f
:2 0 839 ea7 ea9
:3 0 83c ea3 eab
ea0 ead eac :2 0
48 :3 0 5b :3 0
eaf eb0 0 4a
:4 0 113 :4 0 4d
:2 0 4e :3 0 840
eb4 eb6 :3 0 4d
:2 0 83 :4 0 843
eb8 eba :3 0 4d
:2 0 8c :4 0 846
ebc ebe :3 0 4d
:2 0 52 :3 0 56
:3 0 5f :3 0 10c
:3 0 ec3 ec4 0
849 ec2 ec6 55
:4 0 84b ec1 ec9
84e ec0 ecb :3 0
4d :2 0 8e :4 0
851 ecd ecf :3 0
4d :2 0 50 :4 0
854 ed1 ed3 :3 0
4d :2 0 14 :3 0
857 ed5 ed7 :3 0
4d :2 0 50 :4 0
85a ed9 edb :3 0
85d eb1 edd :2 0
edf 860 ee0 eae
edf 0 ee1 862
0 f0b 45 :3 0
46 :3 0 ee2 ee3
0 45 :3 0 58
:3 0 ee5 ee6 0
f :2 0 2 :4 0
114 :2 0 5a :2 0
f :2 0 864 eeb
eed :3 0 867 ee7
eef ee4 ef1 ef0
:2 0 48 :3 0 5b
:3 0 ef3 ef4 0
4a :4 0 115 :4 0
4d :2 0 4e :3 0
86b ef8 efa :3 0
86e ef5 efc :2 0
efe 871 eff ef2
efe 0 f00 873
0 f0b 91 :3 0
92 :3 0 f01 f02
0 5f :3 0 10c
:3 0 f04 f05 0
14 :3 0 93 :3 0
875 f03 f09 :2 0
f0b 879 ff1 116
:3 0 117 :3 0 34
:3 0 106 :3 0 61
:3 0 10 :3 0 118
:3 0 13 :3 0 d9
:3 0 df :3 0 86
:3 0 5 :4 0 119
1 :8 0 f1e c
:3 0 7c :3 0 f19
f1a 0 7d :3 0
f1b f1c 0 f1e
87d f71 7e :3 0
c :3 0 7c :3 0
f20 f21 0 7d
:3 0 f22 f23 0
f25 880 f27 882
f26 f25 :2 0 f6f
7f :3 0 c :3 0
7c :3 0 f2a f2b
0 7d :3 0 f2c
f2d 0 f67 45
:3 0 46 :3 0 f2f
f30 0 45 :3 0
58 :3 0 f32 f33
0 80 :2 0 2
:4 0 11a :2 0 5a
:2 0 f :2 0 884
f38 f3a :3 0 887
f34 f3c f31 f3e
f3d :2 0 48 :3 0
5b :3 0 f40 f41
0 4a :4 0 11b
:4 0 4d :2 0 4e
:3 0 88b f45 f47
:3 0 4d :2 0 83
:4 0 88e f49 f4b
:3 0 4d :2 0 84
:4 0 891 f4d f4f
:3 0 4d :2 0 7d
:3 0 894 f51 f53
:3 0 4d :2 0 85
:4 0 897 f55 f57
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 89a
f5a f5e 89e f59
f60 :3 0 8a1 f42
f62 :2 0 f64 8a4
f65 f3f f64 0
f66 8a6 0 f67
8a8 f6a :3 0 f6a
0 f6a f69 f67
f68 :6 0 f6c 1c
:3 0 8ab f6e 8ad
f6d f6c :2 0 f6f
8af :2 0 f71 0
f71 f70 f1e f6f
:6 0 ff0 1 :3 0
52 :3 0 34 :3 0
23 :2 0 8b2 f73
f76 52 :3 0 aa
:2 0 33 :3 0 23
:2 0 8b5 f78 f7c
8ba f79 f7e :3 0
45 :3 0 46 :3 0
f80 f81 0 45
:3 0 58 :3 0 f83
f84 0 11 :2 0
2 :4 0 11c :2 0
5a :2 0 f :2 0
8bd f89 f8b :3 0
8c0 f85 f8d f82
f8f f8e :2 0 48
:3 0 5b :3 0 f91
f92 0 4a :4 0
11d :4 0 4d :2 0
4e :3 0 8c4 f96
f98 :3 0 4d :2 0
83 :4 0 8c7 f9a
f9c :3 0 4d :2 0
8c :4 0 8ca f9e
fa0 :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 10c :3 0
fa5 fa6 0 8cd
fa4 fa8 55 :4 0
8cf fa3 fab 8d2
fa2 fad :3 0 4d
:2 0 8e :4 0 8d5
faf fb1 :3 0 4d
:2 0 50 :4 0 8d8
fb3 fb5 :3 0 4d
:2 0 14 :3 0 8db
fb7 fb9 :3 0 4d
:2 0 50 :4 0 8de
fbb fbd :3 0 8e1
f93 fbf :2 0 fc1
8e4 fc2 f90 fc1
0 fc3 8e6 0
fed 45 :3 0 46
:3 0 fc4 fc5 0
45 :3 0 58 :3 0
fc7 fc8 0 f
:2 0 2 :4 0 11e
:2 0 5a :2 0 f
:2 0 8e8 fcd fcf
:3 0 8eb fc9 fd1
fc6 fd3 fd2 :2 0
48 :3 0 5b :3 0
fd5 fd6 0 4a
:4 0 11f :4 0 4d
:2 0 4e :3 0 8ef
fda fdc :3 0 8f2
fd7 fde :2 0 fe0
8f5 fe1 fd4 fe0
0 fe2 8f7 0
fed 91 :3 0 92
:3 0 fe3 fe4 0
5f :3 0 10c :3 0
fe6 fe7 0 14
:3 0 93 :3 0 8f9
fe5 feb :2 0 fed
8fd fee f7f fed
0 fef 901 0
ff0 903 ff2 e9d
f0b 0 ff3 0
ff0 0 ff3 906
0 ff4 909 ff5
e27 ff4 0 1066
45 :3 0 46 :3 0
ff6 ff7 0 45
:3 0 58 :3 0 ff9
ffa 0 11 :2 0
2 :4 0 120 :2 0
5a :2 0 f :2 0
90d fff 1001 :3 0
910 ffb 1003 ff8
1005 1004 :2 0 48
:3 0 5b :3 0 1007
1008 0 4a :4 0
121 :4 0 4d :2 0
4e :3 0 914 100c
100e :3 0 4d :2 0
83 :4 0 917 1010
1012 :3 0 4d :2 0
8c :4 0 91a 1014
1016 :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 122 :3 0
101b 101c 0 91d
101a 101e 55 :4 0
91f 1019 1021 922
1018 1023 :3 0 4d
:2 0 8e :4 0 925
1025 1027 :3 0 4d
:2 0 50 :4 0 928
1029 102b :3 0 4d
:2 0 14 :3 0 92b
102d 102f :3 0 4d
:2 0 50 :4 0 92e
1031 1033 :3 0 931
1009 1035 :2 0 1037
934 1038 1006 1037
0 1039 936 0
1063 45 :3 0 46
:3 0 103a 103b 0
45 :3 0 58 :3 0
103d 103e 0 f
:2 0 2 :4 0 123
:2 0 5a :2 0 f
:2 0 938 1043 1045
:3 0 93b 103f 1047
103c 1049 1048 :2 0
48 :3 0 5b :3 0
104b 104c 0 4a
:4 0 124 :4 0 4d
:2 0 4e :3 0 93f
1050 1052 :3 0 942
104d 1054 :2 0 1056
945 1057 104a 1056
0 1058 947 0
1063 91 :3 0 92
:3 0 1059 105a 0
5f :3 0 122 :3 0
105c 105d 0 14
:3 0 93 :3 0 949
105b 1061 :2 0 1063
94d 1065 d3a e22
0 1066 0 1063
0 1066 951 0
1067 955 1068 d35
1067 0 1069 957
0 10c1 39 :3 0
125 :2 0 106a 106b
0 10c1 14 :3 0
3 :3 0 106d 106e
0 10c1 19 :3 0
bf :2 0 959 1071
1072 :3 0 1073 :2 0
2b :3 0 a6 :2 0
95b 1076 1077 :3 0
1078 :2 0 1079 :2 0
1074 107b 107a :2 0
19 :3 0 1b :3 0
107d 107e 0 1080
95d 1081 107c 1080
0 1082 95f 0
10c1 3e :3 0 126
:3 0 10 :3 0 12
:3 0 14 :3 0 13
:3 0 19 :3 0 1a
:3 0 2b :3 0 30
:3 0 37 :3 0 3b
:3 0 35 :3 0 33
:3 0 38 :3 0 3c
:3 0 39 :3 0 29
:3 0 2a :3 0 25
:3 0 28 :3 0 31
:3 0 32 :3 0 17
:3 0 23 :2 0 961
1084 109c 1083 109d
0 10c1 3d :3 0
125 :2 0 109f 10a0
0 10c1 3e :3 0
127 :3 0 10 :3 0
14 :3 0 3d :3 0
23 :2 0 23 :2 0
979 10a3 10a9 10a2
10aa 0 10c1 13
:3 0 a6 :2 0 97f
10ad 10ae :3 0 10af
:2 0 3d :3 0 128
:2 0 10b1 10b2 0
10be 3e :3 0 127
:3 0 10 :3 0 13
:3 0 3d :3 0 23
:2 0 23 :2 0 981
10b5 10bb 10b4 10bc
0 10be 987 10bf
10b0 10be 0 10c0
98a 0 10c1 98c
10c3 cbc d30 0
10c4 0 10c1 0
10c4 995 0 10c5
998 10c6 774 10c5
0 10c7 9a0 0
10c8 9a2 10ca 5d3
647 0 10cb 0
10c8 0 10cb 9a6
0 1171 a7 :3 0
ba :3 0 10cc 10cd
0 16 :3 0 17
:3 0 9a9 10ce 10d1
5e :2 0 23 :2 0
9ae 10d3 10d5 :3 0
10d6 :2 0 52 :3 0
3a :3 0 23 :2 0
9b1 10d8 10db 5f
:3 0 bb :2 0 60
:3 0 10dd 10df 0
9b6 10de 10e1 :3 0
10e2 :2 0 10d7 10e4
10e3 :2 0 40 :3 0
bc :4 0 10e6 10e7
0 111a 3f :3 0
125 :2 0 10e9 10ea
0 111a 43 :3 0
c :3 0 7c :3 0
10ed 10ee 0 10ec
10ef 0 111a 41
:3 0 bd :3 0 40
:3 0 14 :3 0 17
:3 0 3f :3 0 23
:2 0 9b9 10f2 10f8
10f1 10f9 0 111a
c :3 0 7c :3 0
10fb 10fc 0 43
:3 0 10fd 10fe 0
111a 40 :3 0 be
:4 0 1100 1101 0
111a 3f :3 0 125
:2 0 1103 1104 0
111a 43 :3 0 c
:3 0 7c :3 0 1107
1108 0 1106 1109
0 111a 41 :3 0
bd :3 0 40 :3 0
14 :3 0 17 :3 0
3f :3 0 23 :2 0
9bf 110c 1112 110b
1113 0 111a c
:3 0 7c :3 0 1115
1116 0 43 :3 0
1117 1118 0 111a
9c5 111b 10e5 111a
0 111c 9d0 0
1171 3e :3 0 129
:3 0 10 :3 0 9d2
111e 1120 111d 1121
0 1171 45 :3 0
46 :3 0 1123 1124
0 45 :3 0 58
:3 0 1126 1127 0
12a :2 0 2 :4 0
12b :2 0 5a :2 0
f :2 0 9d4 112c
112e :3 0 9d7 1128
1130 1125 1132 1131
:2 0 48 :3 0 5b
:3 0 1134 1135 0
4a :4 0 12c :4 0
4d :2 0 4e :3 0
9db 1139 113b :3 0
4d :2 0 83 :4 0
9de 113d 113f :3 0
4d :2 0 8c :4 0
9e1 1141 1143 :3 0
4d :2 0 52 :3 0
56 :3 0 c :3 0
7c :3 0 1148 1149
0 9e4 1147 114b
55 :4 0 9e6 1146
114e 9e9 1145 1150
:3 0 4d :2 0 8e
:4 0 9ec 1152 1154
:3 0 4d :2 0 50
:4 0 9ef 1156 1158
:3 0 4d :2 0 3
:3 0 9f2 115a 115c
:3 0 4d :2 0 50
:4 0 9f5 115e 1160
:3 0 9f8 1136 1162
:2 0 1164 9fb 1165
1133 1164 0 1166
9fd 0 1171 91
:3 0 12d :3 0 1167
1168 0 c :3 0
7c :3 0 116a 116b
0 3 :3 0 93
:3 0 9ff 1169 116f
:2 0 1171 a03 1212
c :3 0 12e :2 0
4 1172 1173 0
45 :3 0 46 :3 0
1175 1176 0 45
:3 0 58 :3 0 1178
1179 0 80 :2 0
2 :4 0 12f :2 0
5a :2 0 f :2 0
a1e 117e 1180 :3 0
a21 117a 1182 1177
1184 1183 :2 0 48
:3 0 5b :3 0 1186
1187 0 4a :4 0
130 :4 0 4d :2 0
4e :3 0 a25 118b
118d :3 0 a28 1188
118f :2 0 11a8 48
:3 0 5b :3 0 1191
1192 0 4a :4 0
131 :4 0 4d :2 0
c :3 0 b3 :3 0
1197 1198 0 a2b
1196 119a :3 0 4d
:2 0 8e :4 0 a2e
119c 119e :3 0 4d
:2 0 c :3 0 132
:3 0 11a1 11a2 0
a31 11a0 11a4 :3 0
a34 1193 11a6 :2 0
11a8 a37 11a9 1185
11a8 0 11aa a3a
0 11ba 133 :3 0
44 :3 0 c :3 0
b3 :3 0 134 :3 0
c :3 0 132 :3 0
3 :3 0 e3 :4 0
135 1 :a 0 11b6
:2 0 11ba 11ac 11b4
:2 0 b :3 0 44
:3 0 11b8 :2 0 11ba
a3c 11bc a40 11bb
11ba :2 0 1210 7f
:3 0 c :3 0 7c
:3 0 11bf 11c0 0
7d :3 0 11c1 11c2
0 1208 45 :3 0
46 :3 0 11c4 11c5
0 45 :3 0 58
:3 0 11c7 11c8 0
80 :2 0 2 :4 0
136 :2 0 5a :2 0
f :2 0 a42 11cd
11cf :3 0 a45 11c9
11d1 11c6 11d3 11d2
:2 0 48 :3 0 5b
:3 0 11d5 11d6 0
4a :4 0 137 :4 0
4d :2 0 4e :3 0
a49 11da 11dc :3 0
a4c 11d7 11de :2 0
11f8 48 :3 0 5b
:3 0 11e0 11e1 0
4a :4 0 84 :4 0
4d :2 0 7d :3 0
a4f 11e5 11e7 :3 0
4d :2 0 85 :4 0
a52 11e9 11eb :3 0
4d :2 0 86 :3 0
87 :3 0 f :2 0
88 :2 0 a55 11ee
11f2 a59 11ed 11f4
:3 0 a5c 11e2 11f6
:2 0 11f8 a5f 11f9
11d4 11f8 0 11fa
a62 0 1208 133
:3 0 44 :3 0 134
:3 0 c :3 0 132
:3 0 3 :3 0 e3
:4 0 138 1 :a 0
1204 :2 0 1208 11fc
1202 :2 0 b :3 0
44 :3 0 1206 :2 0
1208 a64 120b :3 0
120b 0 120b 120a
1208 1209 :6 0 120d
1 :3 0 a69 120f
a6b 120e 120d :2 0
1210 a6d :2 0 1212
a70 1212 1211 1171
1210 :6 0 1213 :2 0
2 1c 1212 1216
:3 0 1215 1213 1217
:8 0 
aa0
4
:3 0 1 3 1
7 1 b 1
f 1 13 5
6 a e 12
16 1 20 1
1e 1 27 1
25 1 2e 1
2c 1 35 1
33 1 3c 1
3a 1 43 1
41 1 4a 1
48 1 51 1
4f 1 58 1
56 1 5d 1
62 1 67 1
6c 1 71 1
76 1 7b 1
82 1 80 1
87 1 8d 1
93 1 99 1
9f 1 a4 1
a9 1 ae 1
b3 1 b8 1
bf 1 bd 1
c4 1 ca 1
d0 1 d6 1
dc 1 e2 1
e8 1 ee 1
f4 1 fa 1
100 1 106 1
10c 1 112 1
118 1 120 1
11e 1 125 1
12a 1 130 1
13d 1 149 2
14c 14e 2 151
153 2 155 157
2 159 15b 2
15d 15f 2 165
167 2 169 16b
2 16d 16e 2
170 171 2 161
173 2 175 177
2 17d 17f 2
181 183 2 185
186 2 188 189
2 179 18b 2
18d 18f 1 195
2 197 198 2
191 19a 2 19c
19e 2 1a0 1a2
2 1a4 1a6 2
1a8 1aa 2 1ac
1ae 4 145 14b
150 1b0 1 1b2
1 1b4 2 1be
1c0 3 1bc 1bd
1c2 2 1cb 1cd
2 1ca 1cf 1
1d1 1 1d3 2
1eb 1ec 1 1f0
2 1ee 1f0 1
1f8 1 1fa 2
233 238 1 23f
1 23a 2 252
254 3 250 251
256 2 25f 261
2 263 265 2
267 269 2 26b
26d 2 26f 271
3 276 277 278
2 273 27a 2
25e 27c 1 27e
1 280 2 249
281 1 285 1
244 2 242 289
1 294 2 290
294 2 2a0 2a2
3 29e 29f 2a4
2 2ad 2af 2
2b1 2b3 2 2b5
2b7 1 2bf 2
2c1 2c2 2 2b9
2c4 2 2c6 2c8
2 2ca 2cc 2
2ce 2d0 2 2d2
2d4 2 2ac 2d6
1 2d8 1 2da
2 2e4 2e6 3
2e2 2e3 2e8 2
2f1 2f3 2 2f0
2f5 1 2f7 1
2f9 3 300 301
302 3 2db 2fa
304 1 306 2
30f 314 1 31b
1 316 2 32e
330 3 32c 32d
332 2 33b 33d
2 33f 341 2
343 345 2 347
349 2 34b 34d
3 352 353 354
2 34f 356 2
33a 358 1 35a
1 35c 2 325
35d 1 361 1
320 2 31e 365
3 36b 36c 36d
1 371 2 36f
371 2 37c 37e
3 37a 37b 380
2 389 38b 2
38d 38f 2 391
393 1 39b 2
39d 39e 2 395
3a0 2 3a2 3a4
2 3a6 3a8 2
3aa 3ac 2 3ae
3b0 2 388 3b2
1 3b4 1 3b6
2 3c0 3c2 3
3be 3bf 3c4 2
3cd 3cf 2 3cc
3d1 1 3d3 1
3d5 3 3dc 3dd
3de 3 3b7 3d6
3e0 1 3e2 2
3e5 3e6 1 3ea
2 3e8 3ea 2
3f5 3f7 3 3f3
3f4 3f9 2 402
404 2 406 408
2 40a 40c 1
414 2 416 417
2 40e 419 2
41b 41d 2 41f
421 2 423 425
2 427 429 2
401 42b 1 42d
1 42f 2 439
43b 3 437 438
43d 2 446 448
2 445 44a 1
44c 1 44e 3
455 456 457 3
430 44f 459 1
45b 1 45d 1
463 3 46e 46f
470 1 474 2
472 474 2 47f
481 3 47d 47e
483 2 48c 48e
2 490 492 2
494 496 1 49e
2 4a0 4a1 2
498 4a3 2 4a5
4a7 2 4a9 4ab
2 4ad 4af 2
4b1 4b3 2 48b
4b5 1 4b7 1
4b9 2 4c3 4c5
3 4c1 4c2 4c7
2 4d0 4d2 2
4cf 4d4 1 4d6
1 4d8 3 4df
4e0 4e1 3 4ba
4d9 4e3 1 4e5
1 4e6 1 4e8
2 4fc 501 1
508 1 503 2
51b 51d 3 519
51a 51f 2 528
52a 2 52c 52e
2 530 532 2
534 536 2 538
53a 3 53f 540
541 2 53c 543
2 527 545 1
547 1 549 2
512 54a 1 54e
1 50d 2 50b
552 2 55d 55e
1 562 2 560
562 2 567 568
1 56e 2 56a
56e 5 581 582
583 584 585 5
59b 59c 59d 59e
59f a 576 579
57e 588 58d 590
593 598 5a2 5a7
1 5a9 1 5ab
3 5b4 5b5 5b6
1 5ba 2 5b8
5ba 1 5c2 1
5c4 1 5c6 1
5cc 1 5df 2
5de 5df 1 5e7
1 5ed 2 5ef
5f0 2 5dc 5f1
1 5f8 1 5f3
2 60b 60d 3
609 60a 60f 2
618 61a 2 61c
61e 2 620 622
2 624 626 2
628 62a 3 62f
630 631 2 62c
633 2 617 635
1 637 1 639
2 602 63a 1
63e 1 5fd 2
5fb 642 1 645
1 648 1 64d
1 65d 2 65c
65d 1 665 1
66b 2 66d 66e
2 65a 66f 1
676 1 671 2
689 68b 3 687
688 68d 2 696
698 2 69a 69c
2 69e 6a0 2
6a2 6a4 2 6a6
6a8 3 6ad 6ae
6af 2 6aa 6b1
2 695 6b3 1
6b5 1 6b7 2
680 6b8 1 6bc
1 67b 2 679
6c0 3 6c8 6c9
6ca 1 6ce 2
6cc 6ce 1 6d3
1 6d5 2 6c3
6d6 1 6d8 1
6da 1 6df 1
6ef 2 6ee 6ef
1 6f7 1 6fd
2 6ff 700 2
6ec 701 1 708
1 703 2 71b
71d 3 719 71a
71f 2 728 72a
2 72c 72e 2
730 732 2 734
736 2 738 73a
3 73f 740 741
2 73c 743 2
727 745 1 747
1 749 2 712
74a 1 74e 1
70d 2 70b 752
3 75a 75b 75c
1 760 2 75e
760 1 765 1
767 2 755 768
1 76a 2 76d
76e 1 772 2
770 772 1 775
3 77e 77f 780
1 784 2 782
784 1 78c 1
78e 1 790 1
796 2 7a1 7a2
1 7a6 2 7a4
7a6 2 7b4 7b6
3 7b2 7b3 7b8
2 7c1 7c3 2
7c5 7c7 2 7c9
7cb 1 7d3 2
7d5 7d6 2 7cd
7d8 2 7da 7dc
2 7de 7e0 2
7e2 7e4 2 7e6
7e8 2 7c0 7ea
1 7ec 1 7ee
2 7f8 7fa 3
7f6 7f7 7fc 2
805 807 2 804
809 1 80b 1
80d 3 814 815
816 3 7ef 80e
818 1 81a 1
81c 1 821 2
82e 830 3 82c
82d 832 2 83b
83d 2 83f 841
2 843 845 1
84d 2 84f 850
2 847 852 2
854 856 2 858
85a 2 85c 85e
2 860 862 2
83a 864 1 866
1 868 2 872
874 3 870 871
876 2 87f 881
2 87e 883 1
885 1 887 3
88e 88f 890 3
869 888 892 1
894 3 89c 89d
89e 1 8a2 2
8a0 8a2 1 8a7
3 8ad 8ae 8af
1 8b3 2 8b1
8b3 2 8c6 8cb
1 8d2 1 8cd
2 8e5 8e7 3
8e3 8e4 8e9 2
8f2 8f4 2 8f6
8f8 2 8fa 8fc
2 8fe 900 2
902 904 3 909
90a 90b 2 906
90d 2 8f1 90f
1 911 1 913
2 8dc 914 1
918 1 8d7 2
8d5 91c 1 927
2 923 927 2
934 939 1 940
1 93b 2 953
955 3 951 952
957 2 960 962
2 964 966 2
968 96a 2 96c
96e 2 970 972
3 977 978 979
2 974 97b 2
95f 97d 1 97f
1 981 2 94a
982 1 986 1
945 2 943 98a
1 98d 1 990
2 91f 991 1
995 2 9a2 9a4
3 9a0 9a1 9a6
2 9af 9b1 2
9b3 9b5 2 9b7
9b9 1 9bf 2
9c1 9c2 2 9bb
9c4 2 9c6 9c8
2 9ca 9cc 2
9ce 9d0 2 9d2
9d4 2 9ae 9d6
1 9d8 1 9da
2 9e4 9e6 3
9e2 9e3 9e8 2
9f1 9f3 2 9f0
9f5 1 9f7 1
9f9 3 9fe 9ff
a00 3 9db 9fa
a02 3 a05 994
a04 3 895 898
a06 2 a0a a0d
2 a0f a10 1
a12 1 a17 3
a20 a21 a22 1
a26 2 a24 a26
2 a34 a36 3
a32 a33 a38 2
a41 a43 2 a45
a47 2 a49 a4b
1 a53 2 a55
a56 2 a4d a58
2 a5a a5c 2
a5e a60 2 a62
a64 2 a66 a68
2 a40 a6a 1
a6c 1 a6e 2
a78 a7a 3 a76
a77 a7c 2 a85
a87 2 a84 a89
1 a8b 1 a8d
3 a94 a95 a96
3 a6f a8e a98
1 a9b 3 aa4
aa5 aa6 1 aaa
2 aa8 aaa 2
ab8 aba 3 ab6
ab7 abc 2 ac5
ac7 2 ac9 acb
2 acd acf 1
ad7 2 ad9 ada
2 ad1 adc 2
ac4 ade 1 ae0
1 ae2 2 aec
aee 3 aea aeb
af0 2 af9 afb
2 af8 afd 1
aff 1 b01 2
b08 b09 3 ae3
b02 b0b 2 b0e
b0d 1 b10 3
b19 b1a b1b 1
b1f 2 b1d b1f
1 b27 1 b2b
2 b2d b2e 3
b33 b34 b35 1
b39 2 b37 b39
1 b3e 2 b44
b45 1 b49 2
b47 b49 2 b5c
b61 1 b68 1
b63 2 b7b b7d
3 b79 b7a b7f
2 b88 b8a 2
b8c b8e 2 b90
b92 2 b94 b96
2 b98 b9a 3
b9f ba0 ba1 2
b9c ba3 2 b87
ba5 1 ba7 1
ba9 2 b72 baa
1 bae 1 b6d
2 b6b bb2 1
bbd 2 bb9 bbd
2 bca bcf 1
bd6 1 bd1 2
be9 beb 3 be7
be8 bed 2 bf6
bf8 2 bfa bfc
2 bfe c00 2
c02 c04 2 c06
c08 3 c0d c0e
c0f 2 c0a c11
2 bf5 c13 1
c15 1 c17 2
be0 c18 1 c1c
1 bdb 2 bd9
c20 1 c23 1
c26 2 bb5 c27
3 c2e c2f c30
1 c34 2 c32
c34 2 c3f c41
3 c3d c3e c43
2 c4c c4e 2
c50 c52 2 c54
c56 1 c5c 2
c5e c5f 2 c58
c61 2 c63 c65
2 c67 c69 2
c6b c6d 2 c6f
c71 2 c4b c73
1 c75 1 c77
2 c81 c83 3
c7f c80 c85 2
c8e c90 2 c8d
c92 1 c94 1
c96 3 c9b c9c
c9d 3 c78 c97
c9f 3 ca2 c2a
ca1 3 b0f b2f
ca3 1 ca7 2
ca9 caa 2 cb3
cb4 1 cba 2
cb6 cba 1 cc8
2 cc7 cc8 1
cd0 1 cd6 2
cd8 cd9 2 cc5
cda 1 ce1 1
cdc 2 cf4 cf6
3 cf2 cf3 cf8
2 d01 d03 2
d05 d07 2 d09
d0b 2 d0d d0f
2 d11 d13 3
d18 d19 d1a 2
d15 d1c 2 d00
d1e 1 d20 1
d22 2 ceb d23
1 d27 1 ce6
2 ce4 d2b 1
d2e 1 d31 1
d36 2 d4d d52
1 d59 1 d54
2 d6c d6e 3
d6a d6b d70 2
d79 d7b 2 d7d
d7f 2 d81 d83
2 d85 d87 2
d89 d8b 3 d90
d91 d92 2 d8d
d94 2 d78 d96
1 d98 1 d9a
2 d63 d9b 1
d9f 1 d5e 2
d5c da3 2 da9
daa 1 dae 2
dac dae 2 db9
dbb 3 db7 db8
dbd 2 dc6 dc8
2 dca dcc 2
dce dd0 1 dd8
2 dda ddb 2
dd2 ddd 2 ddf
de1 2 de3 de5
2 de7 de9 2
deb ded 2 dc5
def 1 df1 1
df3 2 dfd dff
3 dfb dfc e01
2 e0a e0c 2
e09 e0e 1 e10
1 e12 3 e19
e1a e1b 3 df4
e13 e1d 1 e1f
3 d3d da6 e20
1 e23 2 e3a
e3f 1 e46 1
e41 2 e59 e5b
3 e57 e58 e5d
2 e66 e68 2
e6a e6c 2 e6e
e70 2 e72 e74
2 e76 e78 3
e7d e7e e7f 2
e7a e81 2 e65
e83 1 e85 1
e87 2 e50 e88
1 e8c 1 e4b
2 e49 e90 2
e96 e97 1 e9b
2 e99 e9b 2
ea6 ea8 3 ea4
ea5 eaa 2 eb3
eb5 2 eb7 eb9
2 ebb ebd 1
ec5 2 ec7 ec8
2 ebf eca 2
ecc ece 2 ed0
ed2 2 ed4 ed6
2 ed8 eda 2
eb2 edc 1 ede
1 ee0 2 eea
eec 3 ee8 ee9
eee 2 ef7 ef9
2 ef6 efb 1
efd 1 eff 3
f06 f07 f08 3
ee1 f00 f0a 2
f18 f1d 1 f24
1 f1f 2 f37
f39 3 f35 f36
f3b 2 f44 f46
2 f48 f4a 2
f4c f4e 2 f50
f52 2 f54 f56
3 f5b f5c f5d
2 f58 f5f 2
f43 f61 1 f63
1 f65 2 f2e
f66 1 f6a 1
f29 2 f27 f6e
2 f74 f75 2
f7a f7b 1 f7d
2 f77 f7d 2
f88 f8a 3 f86
f87 f8c 2 f95
f97 2 f99 f9b
2 f9d f9f 1
fa7 2 fa9 faa
2 fa1 fac 2
fae fb0 2 fb2
fb4 2 fb6 fb8
2 fba fbc 2
f94 fbe 1 fc0
1 fc2 2 fcc
fce 3 fca fcb
fd0 2 fd9 fdb
2 fd8 fdd 1
fdf 1 fe1 3
fe8 fe9 fea 3
fc3 fe2 fec 1
fee 2 f71 fef
2 ff1 ff2 3
e2a e93 ff3 2
ffe 1000 3 ffc
ffd 1002 2 100b
100d 2 100f 1011
2 1013 1015 1
101d 2 101f 1020
2 1017 1022 2
1024 1026 2 1028
102a 2 102c 102e
2 1030 1032 2
100a 1034 1 1036
1 1038 2 1042
1044 3 1040 1041
1046 2 104f 1051
2 104e 1053 1
1055 1 1057 3
105e 105f 1060 3
1039 1058 1062 3
1064 ff5 1065 1
1066 1 1068 1
1070 1 1075 1
107f 1 1081 17
1085 1086 1087 1088
1089 108a 108b 108c
108d 108e 108f 1090
1091 1092 1093 1094
1095 1096 1097 1098
1099 109a 109b 5
10a4 10a5 10a6 10a7
10a8 1 10ac 5
10b6 10b7 10b8 10b9
10ba 2 10b3 10bd
1 10bf 8 1069
106c 106f 1082 109e
10a1 10ab 10c0 2
10c2 10c3 7 78f
81b a11 cab cae
cb1 10c4 1 10c6
3 6d9 76b 10c7
2 10c9 10ca 2
10cf 10d0 1 10d4
2 10d2 10d4 2
10d9 10da 1 10e0
2 10dc 10e0 5
10f3 10f4 10f5 10f6
10f7 5 110d 110e
110f 1110 1111 a
10e8 10eb 10f0 10fa
10ff 1102 1105 110a
1114 1119 1 111b
1 111f 2 112b
112d 3 1129 112a
112f 2 1138 113a
2 113c 113e 2
1140 1142 1 114a
2 114c 114d 2
1144 114f 2 1151
1153 2 1155 1157
2 1159 115b 2
115d 115f 2 1137
1161 1 1163 1
1165 3 116c 116d
116e 1a 1b5 1d4
1d7 1da 1dd 1e0
1e3 1e6 1e9 1fb
28c 307 368 3e3
45c 4e9 4ec 555
559 5aa 5c5 10cb
111c 1122 1166 1170
2 117d 117f 3
117b 117c 1181 2
118a 118c 2 1189
118e 2 1195 1199
2 119b 119d 2
119f 11a3 2 1194
11a5 2 1190 11a7
1 11a9 3 11aa
11b5 11b9 1 1174
2 11cc 11ce 3
11ca 11cb 11d0 2
11d9 11db 2 11d8
11dd 2 11e4 11e6
2 11e8 11ea 3
11ef 11f0 11f1 2
11ec 11f3 2 11e3
11f5 2 11df 11f7
1 11f9 4 11c3
11fa 1203 1207 1
120b 1 11be 2
11bc 120f 2f 23
2a 31 38 3f
46 4d 54 5b
60 65 6a 6f
74 79 7e 85
8b 91 97 9d
a2 a7 ac b1
b6 bb c2 c8
ce d4 da e0
e6 ec f2 f8
fe 104 10a 110
116 11c 123 128
12e 135 
1
4
0 
1216
0
1
28
1e
35
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 0 0
0 0 0 0 0 0 0 0

13 1 0
100 1 0
10c 1 0
76 1 0
3 1 0
87 1 0
62 1 0
3a 1 0
33 1 0
d0 1 0
118 1 0
99 1 0
fa 1 0
125 1 0
b3 1 0
112 1 0
a9 1 0
e8 1 0
67 1 0
1e 1 0
9f 1 0
5d 1 0
11e 1 0
c4 1 0
56 1 0
f4 1 0
dc 1 0
6c 1 0
106 1 0
d6 1 0
41 1 0
ca 1 0
2c 1 0
80 1 0
ae 1 0
a4 1 0
7b 1 0
12a 1 0
7 1 0
bd 1 0
b8 1 0
8d 1 0
48 1 0
25 1 0
2 0 1
71 1 0
f 1 0
93 1 0
e2 1 0
4f 1 0
ee 1 0
b 1 0
130 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_FORECAST;
ALTER FUNCTION SP_U_WP_FORECAST COMPILE DEBUG;
/*****************************************************************************/
Prompt == FUNCTION SP_U_ASSIGN_DESCR ==
CREATE OR REPLACE FUNCTION SP_U_ASSIGN_DESCR wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
57
2 :e:
1FUNCTION:
1SP_U_ASSIGN_DESCR:
1PRJ_ID:
1VARCHAR2:
1RES_ID001:
1DESCRIPTION001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_ASSIGN_DESCR(:
1':
1, :
1);:
1CHECK_TRACE:
11:
120:
1+:
1FPUT:
1               ENTER:: SP_U_ASSIGN_DESCR(21) :: cplan.sql(22336) :: :
1IS NULL:
132:
125:
1        RETURN_ERROR:: SP_U_ASSIGN_DESCR(26) :: cplan.sql(22341) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
1 ID:: :
128:
1                EXIT:: SP_U_ASSIGN_DESCR(29) :: cplan.sql(22344) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1PROJECT_ASSIGNMENTS:
1DESCRIPTION:
1RESOURCE_ID:
1PROJECT_ID:
1UPDATE PROJECT_ASSIGNMENTS:n      SET DESCRIPTION = description001:n      WHE+
1RE RESOURCE_ID = res_id001:n      AND PROJECT_ID = prj_id:
1FOUND:
1=:
1SC_STATE:
10:
1100:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
151:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(52) :: cplan.sql(22367) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
14:
157:
1       RETURN_STATUS:: SP_U_ASSIGN_DESCR(58) :: cplan.sql(22373) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
164:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(65) :: cplan.sql(22380) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
176:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(77) :: cplan.sql(22392) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
283
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c a0 7e b4
2e 5a a0 7e b4 2e 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :7 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
283
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 9b 83 87 8b 8e 96
82 a2 a6 7f aa ae b2 b5
ba bb 1 bd c2 c6 ca cd
d2 d6 da dd e2 e3 e5 ea
ed f1 f2 f7 fc ff 104 105
10a 10d 111 112 117 11a 11f 120
125 128 12d 12e 133 136 13b 13c
141 144 148 149 14e 151 156 157
15c 15f 164 165 16a 16d 172 173
178 17b 17f 180 185 188 18d 18e
193 196 19b 19c 1a1 1a4 1a9 1aa
1af 1b2 1b6 1b7 1bc 1bf 1c4 1c5
1ca 1cd 1d2 1d3 1d8 1d9 1de 1e0
1e4 1e7 1eb 1ef 1f2 1f6 1fa 1fd
200 205 208 20b 20e 20f 214 215
1 217 21c 220 224 227 22c 231
234 238 239 23e 23f 244 246 24a
24d 251 254 255 25a 25d 261 264
265 26a 1 26d 272 276 27a 27d
281 285 288 28b 290 293 296 299
29a 29f 2a0 1 2a2 2a7 2ab 2af
2b2 2b7 2bc 2bf 2c3 2c4 2c9 2cc
2d1 2d2 2d7 2da 2df 2e0 2e5 2e8
2ec 2f0 2f4 2f8 2fb 2fc 2fe 303
304 306 307 30c 30f 314 315 31a
31d 322 323 328 32b 32f 330 335
338 33d 33e 343 344 349 34b 34f
352 356 35a 35d 361 365 368 36b
370 373 376 379 37a 37f 380 1
382 387 38b 38f 392 397 39c 39f
3a3 3a4 3a9 3aa 3af 3b1 3b5 3b8
3bc 3c0 3c3 3c7 3cb 3ce 3d2 3d6
3d7 3dc 3de 3e2 3e5 3e9 3ed 3f1
3f5 3f9 3fd 401 40d 411 416 41a
41d 41e 423 427 42b 42e 431 435
437 43b 43f 442 445 449 44b 44f
453 456 458 45c 460 464 467 46b
46f 471 472 477 1 47b 47f 483
486 48a 48e 492 496 499 49d 4a1
4a4 4a7 4ac 4af 4b2 4b5 4b6 4bb
4bc 1 4be 4c3 4c7 4cb 4ce 4d3
4d8 4db 4df 4e0 4e5 4e8 4ed 4ee
4f3 4f6 4fb 4fc 501 504 508 509
50e 511 516 517 51c 51f 523 527
52a 52d 52e 530 531 536 537 53c
53e 542 545 547 54b 54d 559 55b
55d 55e 563 567 569 575 577 57b
57f 582 586 58a 58d 590 595 598
59b 59e 59f 5a4 5a5 1 5a7 5ac
5b0 5b4 5b7 5bc 5c1 5c4 5c8 5c9
5ce 5d1 5d6 5d7 5dc 5df 5e4 5e5
5ea 5ed 5f1 5f5 5f9 5fd 600 601
603 608 609 60b 60c 611 614 619
61a 61f 622 627 628 62d 630 634
635 63a 63d 642 643 648 649 64e
650 654 657 65b 65f 662 666 66a
66d 671 675 676 67b 67d 681 685
688 68c 690 693 697 69b 69e 6a1
6a6 6a9 6ac 6af 6b0 6b5 6b6 1
6b8 6bd 6c1 6c5 6c8 6cd 6d2 6d5
6d9 6da 6df 6e0 6e5 6e9 6ed 6f0
6f5 6fa 6fd 701 705 708 709 70e
711 716 717 71c 71f 723 727 72a
72b 730 731 736 738 73c 73f 743
747 74b 74f 753 757 75b 75f 763
76f 774 778 77c 780 784 786 787
78c 1 790 794 798 79b 79f 7a3
7a7 7ab 7ae 7b2 7b6 7b9 7bc 7c1
7c4 7c7 7ca 7cb 7d0 7d1 1 7d3
7d8 7dc 7e0 7e3 7e8 7ed 7f0 7f4
7f5 7fa 7fb 800 804 808 80b 810
815 818 81c 81d 822 825 82a 82b
830 833 837 83b 83e 841 842 844
845 84a 84b 850 852 856 859 85d
861 865 869 86d 871 875 881 886
88a 88e 892 896 898 89c 89e 8aa
8ac 8ae 8af 8b4 8b8 8ba 8c6 8ca
8cc 8cd 8d6 
283
2
0 1 a 6 d :3 6 10 :3 6
15 :3 6 12 :2 6 1 3 a 13
a :2 1 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 59 5f 62 :2 59
70 8b 8 :2 70 d 10 :2 70 17
1a :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 28 2b :2 70 b e
:2 70 13 16 :2 70 1b 1e :2 70 2d
30 :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 2a 2d :2 70 32 35
:2 70 :2 7 4f :2 4 7 :2 11 23 :2 2d
39 3c 51 53 54 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 57
:2 4 :4 8 7 :4 1c 1b :2 7 a :2 14
26 :2 30 3c 40 55 57 58 :2 55
:2 26 :3 a :2 10 15 21 65 68 :2 21
75 78 :2 21 7c 7f :2 21 89 8c
95 9d :2 a6 :2 95 b7 :2 8c :2 21 bf
c2 :2 21 ca cd :2 21 d2 d5 :2 21
dc df :2 21 :2 a 5b :2 7 a :2 14
26 :2 30 3c 3f 54 56 57 :2 54
:2 26 :3 a :2 10 15 21 65 68 :2 21
:2 a 5a :3 7 :2 12 26 :2 2f 3f 47
:2 7 2f :2 4 e b 19 d 1b
b 18 7 e a 16 :3 14 a
:2 13 1f a 1b a :2 13 1f a
:4 7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 58 5a 5b :2 58
:2 29 :3 d :2 13 18 24 68 6b :2 24
78 7b :2 24 7f 82 :2 24 8e 91
:2 24 99 9c :2 24 a8 ab b2 bb
be :2 ab :2 24 :2 d 5e :2 a :2 7 :4 13
:2 7 4 :3 1 7 :2 11 23 :2 2d 39
3c 51 53 54 :2 51 :2 23 :3 7 :2 d
12 1e 62 65 :2 1e 72 75 :2 1e
79 7c :2 1e 86 89 92 9a :2 a3
:2 92 ae :2 89 :2 1e b6 b9 :2 1e c1
c4 :2 1e c9 cc :2 1e d3 d6 :2 1e
:2 7 57 :3 4 :2 f 21 :2 2a 34 3c
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 55 57 58 :2 55 :2 26
:3 a :2 10 15 21 65 68 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 5b
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 52 54 55 :2 52 :2 23
:3 7 :2 d 12 1e 62 65 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 58 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
283
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 a :b c :11 d
e :2 d :2 e :2 d
:2 e :2 d :2 f :2 d
:2 f :2 d :2 f :2 d
:2 f :2 d :2 10 :2 d
:2 10 :2 d :2 10 :2 d
:2 10 :2 d :2 11 :2 d
:2 11 :2 d :2 11 :2 d
:2 11 :2 d :2 11 :4 d
:3 c :11 14 :b 15 :3 14
:c 18 :11 19 :30 1a :3 19
:11 1c :b 1d :3 1c :a 1f
:3 18 24 :2 25 :2 26
:2 27 24 :6 28 :5 29
28 :5 2b 2a :3 28
23 2e :5 2f :3 2e
:2 30 :5 32 :11 33 :24 34
:3 33 :2 31 :6 30 2d
:3 b :11 39 :30 3a :3 39
:a 3c b :3 3f :11 40
:b 41 :17 42 :3 40 :2 44
:3 45 :3 46 47 45
44 45 :3 48 :3 3f
:2 49 :5 4b :11 4c :b 4d
:18 4e :3 4c :2 50 51
:3 52 53 51 50
51 :3 54 :2 4a :6 49
3e :7 1 
8d8
4
:3 0 1 :3 0 2
:a 0 27e 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 15 16 0
b 4 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :3 0
a :2 0 4 13
17 0 27e 2
18 :2 0 21 22
0 10 9 :3 0
a :2 0 4 1b
1c 0 1d :7 0
20 1e 0 27c
0 b :6 0 c
:3 0 d :3 0 c
:3 0 e :3 0 24
25 0 2 :4 0
12 26 28 23
2a 29 :2 0 f
:3 0 10 :3 0 2c
2d 0 11 :4 0
c :3 0 12 :3 0
30 31 0 2
:4 0 14 32 34
13 :4 0 14 :2 0
15 :3 0 16 37
39 :3 0 16 :4 0
14 :2 0 17 :4 0
19 3c 3e :3 0
14 :2 0 3 :3 0
1c 40 42 :3 0
14 :2 0 17 :4 0
1f 44 46 :3 0
14 :2 0 18 :4 0
22 48 4a :3 0
14 :2 0 17 :4 0
25 4c 4e :3 0
14 :2 0 5 :3 0
28 50 52 :3 0
14 :2 0 17 :4 0
2b 54 56 :3 0
14 :2 0 18 :4 0
2e 58 5a :3 0
14 :2 0 17 :4 0
31 5c 5e :3 0
14 :2 0 6 :3 0
34 60 62 :3 0
14 :2 0 17 :4 0
37 64 66 :3 0
14 :2 0 18 :4 0
3a 68 6a :3 0
14 :2 0 17 :4 0
3d 6c 6e :3 0
14 :2 0 7 :3 0
40 70 72 :3 0
14 :2 0 17 :4 0
43 74 76 :3 0
14 :2 0 19 :4 0
46 78 7a :3 0
49 2e 7c :2 0
7e 4e 7f 2b
7e 0 80 50
0 1dc c :3 0
d :3 0 81 82
0 c :3 0 1a
:3 0 84 85 0
1b :2 0 2 :4 0
1c :2 0 1d :2 0
1b :2 0 52 8a
8c :3 0 55 86
8e 83 90 8f
:2 0 f :3 0 1e
:3 0 92 93 0
11 :4 0 1f :4 0
14 :2 0 15 :3 0
59 97 99 :3 0
5c 94 9b :2 0
9d 5f 9e 91
9d 0 9f 61
0 1dc 3 :3 0
20 :2 0 63 a1
a2 :3 0 a3 :2 0
5 :3 0 20 :2 0
65 a6 a7 :3 0
a8 :2 0 a4 aa
a9 :2 0 c :3 0
d :3 0 ac ad
0 c :3 0 1a
:3 0 af b0 0
21 :2 0 2 :4 0
22 :2 0 1d :2 0
1b :2 0 67 b5
b7 :3 0 6a b1
b9 ae bb ba
:2 0 f :3 0 1e
:3 0 bd be 0
11 :4 0 23 :4 0
14 :2 0 15 :3 0
6e c2 c4 :3 0
14 :2 0 24 :4 0
71 c6 c8 :3 0
14 :2 0 25 :4 0
74 ca cc :3 0
14 :2 0 26 :3 0
27 :3 0 28 :3 0
29 :3 0 d1 d2
0 77 d0 d4
2a :4 0 79 cf
d7 7c ce d9
:3 0 14 :2 0 2b
:4 0 7f db dd
:3 0 14 :2 0 17
:4 0 82 df e1
:3 0 14 :2 0 3
:3 0 85 e3 e5
:3 0 14 :2 0 17
:4 0 88 e7 e9
:3 0 8b bf eb
:2 0 ed 8e ee
bc ed 0 ef
90 0 119 c
:3 0 d :3 0 f0
f1 0 c :3 0
1a :3 0 f3 f4
0 1b :2 0 2
:4 0 2c :2 0 1d
:2 0 1b :2 0 92
f9 fb :3 0 95
f5 fd f2 ff
fe :2 0 f :3 0
1e :3 0 101 102
0 11 :4 0 2d
:4 0 14 :2 0 15
:3 0 99 106 108
:3 0 9c 103 10a
:2 0 10c 9f 10d
100 10c 0 10e
a1 0 119 2e
:3 0 2f :3 0 10f
110 0 28 :3 0
29 :3 0 112 113
0 3 :3 0 30
:3 0 a3 111 117
:2 0 119 a7 11a
ab 119 0 11b
ab 0 1dc 31
:3 0 32 :3 0 6
:3 0 33 :3 0 5
:3 0 34 :3 0 3
:4 0 35 1 :8 0
139 36 :4 0 124
:3 0 30 :3 0 37
:2 0 af 127 128
:3 0 9 :3 0 38
:3 0 12a 12b 0
39 :2 0 12c 12d
0 12f b2 136
9 :3 0 38 :3 0
130 131 0 3a
:2 0 132 133 0
135 b4 137 129
12f 0 138 0
135 0 138 b6
0 139 b9 18c
3b :3 0 9 :3 0
38 :3 0 13b 13c
0 3c :3 0 13d
13e 0 140 bc
142 be 141 140
:2 0 18a 3d :3 0
9 :3 0 38 :3 0
145 146 0 3c
:3 0 147 148 0
182 c :3 0 d
:3 0 14a 14b 0
c :3 0 1a :3 0
14d 14e 0 3e
:2 0 2 :4 0 3f
:2 0 1d :2 0 1b
:2 0 c0 153 155
:3 0 c3 14f 157
14c 159 158 :2 0
f :3 0 1e :3 0
15b 15c 0 11
:4 0 40 :4 0 14
:2 0 15 :3 0 c7
160 162 :3 0 14
:2 0 24 :4 0 ca
164 166 :3 0 14
:2 0 41 :4 0 cd
168 16a :3 0 14
:2 0 3c :3 0 d0
16c 16e :3 0 14
:2 0 42 :4 0 d3
170 172 :3 0 14
:2 0 43 :3 0 44
:3 0 1b :2 0 45
:2 0 d6 175 179
da 174 17b :3 0
dd 15d 17d :2 0
17f e0 180 15a
17f 0 181 e2
0 182 e4 185
:3 0 185 0 185
184 182 183 :6 0
187 2 :3 0 e7
189 e9 188 187
:2 0 18a eb :2 0
18c 0 18c 18b
139 18a :6 0 1dc
1 :3 0 c :3 0
d :3 0 18e 18f
0 c :3 0 1a
:3 0 191 192 0
46 :2 0 2 :4 0
47 :2 0 1d :2 0
1b :2 0 ee 197
199 :3 0 f1 193
19b 190 19d 19c
:2 0 f :3 0 1e
:3 0 19f 1a0 0
11 :4 0 48 :4 0
14 :2 0 15 :3 0
f5 1a4 1a6 :3 0
14 :2 0 24 :4 0
f8 1a8 1aa :3 0
14 :2 0 25 :4 0
fb 1ac 1ae :3 0
14 :2 0 26 :3 0
27 :3 0 9 :3 0
38 :3 0 1b3 1b4
0 fe 1b2 1b6
2a :4 0 100 1b1
1b9 103 1b0 1bb
:3 0 14 :2 0 2b
:4 0 106 1bd 1bf
:3 0 14 :2 0 17
:4 0 109 1c1 1c3
:3 0 14 :2 0 3
:3 0 10c 1c5 1c7
:3 0 14 :2 0 17
:4 0 10f 1c9 1cb
:3 0 112 1a1 1cd
:2 0 1cf 115 1d0
19e 1cf 0 1d1
117 0 1dc 2e
:3 0 49 :3 0 1d2
1d3 0 9 :3 0
38 :3 0 1d5 1d6
0 3 :3 0 30
:3 0 119 1d4 1da
:2 0 1dc 11d 27d
9 :3 0 4a :2 0
4 1dd 1de 0
c :3 0 d :3 0
1e0 1e1 0 c
:3 0 1a :3 0 1e3
1e4 0 3e :2 0
2 :4 0 4b :2 0
1d :2 0 1b :2 0
124 1e9 1eb :3 0
127 1e5 1ed 1e2
1ef 1ee :2 0 f
:3 0 1e :3 0 1f1
1f2 0 11 :4 0
4c :4 0 14 :2 0
15 :3 0 12b 1f6
1f8 :3 0 12e 1f3
1fa :2 0 213 f
:3 0 1e :3 0 1fc
1fd 0 11 :4 0
4d :4 0 14 :2 0
9 :3 0 4e :3 0
202 203 0 131
201 205 :3 0 14
:2 0 2b :4 0 134
207 209 :3 0 14
:2 0 9 :3 0 4f
:3 0 20c 20d 0
137 20b 20f :3 0
13a 1fe 211 :2 0
213 13d 214 1f0
213 0 215 140
0 225 50 :3 0
b :3 0 9 :3 0
4e :3 0 51 :3 0
9 :3 0 4f :3 0
52 :3 0 53 :4 0
54 1 :a 0 221
:2 0 225 217 21f
:2 0 8 :3 0 b
:3 0 223 :2 0 225
142 227 146 226
225 :2 0 27b 3d
:3 0 9 :3 0 38
:3 0 22a 22b 0
3c :3 0 22c 22d
0 273 c :3 0
d :3 0 22f 230
0 c :3 0 1a
:3 0 232 233 0
3e :2 0 2 :4 0
55 :2 0 1d :2 0
1b :2 0 148 238
23a :3 0 14b 234
23c 231 23e 23d
:2 0 f :3 0 1e
:3 0 240 241 0
11 :4 0 56 :4 0
14 :2 0 15 :3 0
14f 245 247 :3 0
152 242 249 :2 0
263 f :3 0 1e
:3 0 24b 24c 0
11 :4 0 41 :4 0
14 :2 0 3c :3 0
155 250 252 :3 0
14 :2 0 42 :4 0
158 254 256 :3 0
14 :2 0 43 :3 0
44 :3 0 1b :2 0
45 :2 0 15b 259
25d 15f 258 25f
:3 0 162 24d 261
:2 0 263 165 264
23f 263 0 265
168 0 273 50
:3 0 b :3 0 51
:3 0 9 :3 0 4f
:3 0 52 :3 0 53
:4 0 57 1 :a 0
26f :2 0 273 267
26d :2 0 8 :3 0
b :3 0 271 :2 0
273 16a 276 :3 0
276 0 276 275
273 274 :6 0 278
1 :3 0 16f 27a
171 279 278 :2 0
27b 173 :2 0 27d
176 27d 27c 1dc
27b :6 0 27e :2 0
2 18 27d 281
:3 0 280 27e 282
:8 0 
178
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1a
1 27 1 33
2 36 38 2
3b 3d 2 3f
41 2 43 45
2 47 49 2
4b 4d 2 4f
51 2 53 55
2 57 59 2
5b 5d 2 5f
61 2 63 65
2 67 69 2
6b 6d 2 6f
71 2 73 75
2 77 79 4
2f 35 3a 7b
1 7d 1 7f
2 89 8b 3
87 88 8d 2
96 98 2 95
9a 1 9c 1
9e 1 a0 1
a5 2 b4 b6
3 b2 b3 b8
2 c1 c3 2
c5 c7 2 c9
cb 1 d3 2
d5 d6 2 cd
d8 2 da dc
2 de e0 2
e2 e4 2 e6
e8 2 c0 ea
1 ec 1 ee
2 f8 fa 3
f6 f7 fc 2
105 107 2 104
109 1 10b 1
10d 3 114 115
116 3 ef 10e
118 1 11a 1
126 2 125 126
1 12e 1 134
2 136 137 2
123 138 1 13f
1 13a 2 152
154 3 150 151
156 2 15f 161
2 163 165 2
167 169 2 16b
16d 2 16f 171
3 176 177 178
2 173 17a 2
15e 17c 1 17e
1 180 2 149
181 1 185 1
144 2 142 189
2 196 198 3
194 195 19a 2
1a3 1a5 2 1a7
1a9 2 1ab 1ad
1 1b5 2 1b7
1b8 2 1af 1ba
2 1bc 1be 2
1c0 1c2 2 1c4
1c6 2 1c8 1ca
2 1a2 1cc 1
1ce 1 1d0 3
1d7 1d8 1d9 6
80 9f 11b 18c
1d1 1db 2 1e8
1ea 3 1e6 1e7
1ec 2 1f5 1f7
2 1f4 1f9 2
200 204 2 206
208 2 20a 20e
2 1ff 210 2
1fb 212 1 214
3 215 220 224
1 1df 2 237
239 3 235 236
23b 2 244 246
2 243 248 2
24f 251 2 253
255 3 25a 25b
25c 2 257 25e
2 24e 260 2
24a 262 1 264
4 22e 265 26e
272 1 276 1
229 2 227 27a
1 1f 
1
4
0 
281
0
1
14
4
6
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
f 1 0
b 1 0
7 1 0
2 0 1
3 1 0
1a 1 0
0

/
SHOW ERRORS FUNCTION SP_U_ASSIGN_DESCR;
ALTER FUNCTION SP_U_ASSIGN_DESCR COMPILE DEBUG;
/****************************************************************************************/
Prompt == FUNCTION SP_TEST_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_TEST_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
bc
2 :e:
1FUNCTION:
1SP_TEST_ASSIGN:
1RANK001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_RANK:
1200:
1H_FULL_NAME:
1255:
1H_PROJECT_ID:
132:
1H_RES_ASSIGNMENT_ID:
1H_TSK_ASSIGNMENT_ID:
1H_SECURITY_ID:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_PARTICIPANT:
10:
1H_BITFLAG:
1CURSOR:
1C_RPA0:
1ELEMENT_ID:
1TMT_WBS:
1TYPE_ID:
1PMO_CNST:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1RANK:
1SELECT ELEMENT_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (pmo_cnst.SC_PROJEC+
1T,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PROJ_TYPE2,pmo_cnst+
1.SC_PROJ_TYPE3) AND RANK LIKE h_rank || '%':
1C_RPA1:
1RES_ASSIGNMENT_ID:
1TSK_ASSIGNMENT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1TASK_ID:
1SELECT RES_ASSIGNMENT_ID, TSK_ASSIGNMENT_ID, RESOURCE_ID, RESOURCE_TYPE:n    +
1     FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_ID = h_project_id AND TASK+
1_ID = h_project_id:
1C_FPA1:
1RA:
1PARTICIPANT:
1SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1PROJECT_ASSIGNMENTS:
1PA:
1SELECT ra.RESOURCE_ID, ra.RESOURCE_TYPE, ra.PARTICIPANT, ra.SECURITY_ID:n    +
1     FROM RESOURCE_ASSIGNMENTS ra:n         WHERE ELEMENT_ID = h_project_id A+
1ND NOT EXISTS (:n         SELECT 'X' FROM PROJECT_ASSIGNMENTS pa WHERE pa.PRO+
1JECT_ID = h_project_id AND pa.RESOURCE_ID = ra.RESOURCE_ID):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_TEST_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
141:
1+:
1FPUT:
1               ENTER:: SP_TEST_ASSIGN(42) :: cplan.sql(22450) :: :
1OPEN:
1LOOP:
1FOUND:
1SC_STATE:
1100:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
1=:
1COUNT:
1DUAL:
1PROJECT_ASSIGNMENT_ID:
1SELECT COUNT('X') INTO h_bitflag FROM DUAL WHERE EXISTS (SELECT 'X' FROM TASK+
1_ASSIGNMENTS:n               WHERE PROJECT_ASSIGNMENT_ID = h_tsk_assignment_i+
1d AND RESOURCE_ID = h_res_id):
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
187:
1           EXCEPTION:: SP_TEST_ASSIGN(88) :: cplan.sql(22496) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1UPDATE TASK_ASSIGNMENTS SET PROJECT_ASSIGNMENT_ID = NuLL:n                  W+
1HERE PROJECT_ASSIGNMENT_ID = h_tsk_assignment_id:
1TRUE:
1108:
1           EXCEPTION:: SP_TEST_ASSIGN(109) :: cplan.sql(22517) :: :
1TASK_DAY_OF_YEAR:
1PARENT_ID:
1UPDATE TASK_DAY_OF_YEAR SET PARENT_ID = TSK_ASSIGNMENT_ID:n                  +
1WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_tsk_assignment_id:
1128:
1           EXCEPTION:: SP_TEST_ASSIGN(129) :: cplan.sql(22537) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS:n               WHERE RES_ASSIGNMENT_ID = h_+
1res_assignment_id:n               AND SECURITY_ID = 'SCPROJECTASSIGNMENT':
1150:
1           EXCEPTION:: SP_TEST_ASSIGN(151) :: cplan.sql(22559) :: :
1DELETE FROM PROJECT_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND RESOURCE_+
1ID = h_res_id:
1170:
1           EXCEPTION:: SP_TEST_ASSIGN(171) :: cplan.sql(22579) :: :
1NICK_NAME:
1RESOURCES:
1SELECT NICK_NAME || ';' INTO h_full_name:n                     FROM RESOURCES+
1:n                     WHERE RESOURCE_ID = h_res_id:
1188:
1           EXCEPTION:: SP_TEST_ASSIGN(189) :: cplan.sql(22597) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME || ';' INTO h_full_name:n                     FROM PROFIL+
1ES:n                     WHERE PROFILE_ID = h_res_id:
1205:
1           EXCEPTION:: SP_TEST_ASSIGN(206) :: cplan.sql(22614) :: :
1ASSIGN_NAMES:
1REPLACE:
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_full_name, ''):n  +
1                WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_project_id:
1226:
1           EXCEPTION:: SP_TEST_ASSIGN(227) :: cplan.sql(22635) :: :
1PMO_STPU:
1BIT_ANDNOT:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT = PMO_STPU.BIT_ANDNOT(PARTICIPANT+
1,4096):n                  WHERE RES_ASSIGNMENT_ID = h_res_assignment_id:
1246:
1           EXCEPTION:: SP_TEST_ASSIGN(247) :: cplan.sql(22655) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1266:
1           EXCEPTION:: SP_TEST_ASSIGN(267) :: cplan.sql(22675) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_tsk_assignment_id:
1285:
1           EXCEPTION:: SP_TEST_ASSIGN(286) :: cplan.sql(22694) :: :
1CLOSE:
1301:
1           EXCEPTION:: SP_TEST_ASSIGN(302) :: cplan.sql(22710) :: :
1COMMIT:
1ELSIF:
1SELECT NICK_NAME || ';' INTO h_full_name:n                  FROM RESOURCES:n +
1                 WHERE RESOURCE_ID = h_res_id:
1334:
1           EXCEPTION:: SP_TEST_ASSIGN(335) :: cplan.sql(22743) :: :
1SELECT PROFILE_NAME || ';' INTO h_full_name:n                  FROM PROFILES+
1:n                  WHERE PROFILE_ID = h_res_id:
1351:
1           EXCEPTION:: SP_TEST_ASSIGN(352) :: cplan.sql(22760) :: :
1INSTR:
1UPDATE TMT_WBS SET ASSIGN_NAMES = CASE:n               WHEN InStr(ASSIGN_NAME+
1S, h_full_name) > 0 THEN ASSIGN_NAMES:n               ELSE ASSIGN_NAMES || h_+
1full_name END:n               WHERE PROJECT_ID = h_project_id AND ELEMENT_ID +
1= h_project_id:
1374:
1           EXCEPTION:: SP_TEST_ASSIGN(375) :: cplan.sql(22783) :: :
1ELEMENT_TYPE_BITS:
1ROLLUP_BITS:
1SC_ASSIGNMENT_BIT:
1INSERT INTO PROJECT_ASSIGNMENTS (PROJECT_ID, RESOURCE_ID, PARTICIPANT, SECURI+
1TY_ID, RESOURCE_TYPE, ELEMENT_TYPE_BITS,ROLLUP_BITS):n               VALUES(h+
1_project_id, h_res_id, h_participant, h_security_id, h_res_type, 1, pmo_cnst.+
1SC_ASSIGNMENT_BIT):
1394:
1           EXCEPTION:: SP_TEST_ASSIGN(395) :: cplan.sql(22803) :: :
1411:
1           EXCEPTION:: SP_TEST_ASSIGN(412) :: cplan.sql(22820) :: :
1430:
1           EXCEPTION:: SP_TEST_ASSIGN(431) :: cplan.sql(22839) :: :
14:
1436:
1       RETURN_STATUS:: SP_TEST_ASSIGN(437) :: cplan.sql(22845) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1443:
1           EXCEPTION:: SP_TEST_ASSIGN(444) :: cplan.sql(22852) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1455:
1           EXCEPTION:: SP_TEST_ASSIGN(456) :: cplan.sql(22864) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
a60
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :f a0 12a bd b7 11 a4 b1
a0 f4 b4 bf c8 :9 a0 12a bd
b7 11 a4 b1 a0 f4 b4 bf
c8 :15 a0 12a bd b7 11 a4 b1
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 e9
dd b3 :3 a0 e9 d3 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 2b b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 e9 dd b3 :6 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c a0 51 d
:8 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :4 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :7 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 :2 51
a5 b 7e 6e b4 2e :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :7 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :3 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :5 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 12a a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 e9 dd b3
:6 a0 e9 d3 5 :2 a0 f :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 2b b7 19 3c
:2 a0 :2 51 a5 b 7e 6e b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:c a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:f a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 12a
b7 :2 19 3c b7 a0 47 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 a0 6b
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e a5 57 b7 19 3c :9 a0 12a
e9 dd :2 a0 65 b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c :7 a0 12a e9 dd
:2 a0 65 b7 a4 b1 11 4f b7
a6 9 a4 b1 11 68 4f 1d
17 b5 
a60
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 72 5d 61 64 65 6d
5c 8f 7d 59 81 82 8a 7c
ac 9a 79 9e 9f a7 99 c9
b7 96 bb bc c4 b6 e6 d4
b3 d8 d9 e1 d3 103 f1 d0
f5 f6 fe f0 120 10e ed 112
113 11b 10d 13d 12b 10a 12f 130
138 12a 159 148 14c 127 154 147
175 164 168 144 170 163 17c 180
160 191 194 198 19c 1a0 1a4 1a8
1ac 1b0 1b4 1b8 1bc 1c0 1c4 1c8
1cc 1d0 1d4 1e0 1e5 1e7 1f3 1f7
1f9 1fd 20e 20f 212 216 21a 21e
222 226 22a 22e 232 236 23a 246
24b 24d 259 25d 25f 263 274 275
278 27c 280 284 288 28c 290 294
298 29c 2a0 2a4 2a8 2ac 2b0 2b4
2b8 2bc 2c0 2c4 2c8 2cc 2d0 2dc
2e1 2e3 2ef 2f3 311 2f9 2fd 301
304 30c 2f8 318 31c 2f5 320 324
328 32b 330 331 1 333 338 33c
340 343 348 34c 350 353 358 359
35b 360 363 367 368 36d 372 375
37a 37b 380 383 387 388 38d 390
395 396 39b 39e 3a3 3a4 3a9 3ac
3b0 3b4 3b8 3b9 3bb 3c0 3c1 3c3
3c4 3c9 3cc 3d1 3d2 3d7 3d8 3dd
3df 3e3 3e6 3ea 3ee 3f1 3f5 3f9
3fc 3ff 404 407 40a 40d 40e 413
414 1 416 41b 41f 423 426 42b
430 433 437 438 43d 43e 443 445
449 44c 450 454 458 45c 460 464
468 46c 471 475 476 47a 47e 482
487 48c 490 494 499 49d 4a1 4a4
4a7 4ab 4ad 4b1 4b5 4b8 4bb 4bf
4c1 4c5 4c9 4cc 4d0 4d4 4d7 4db
4de 4e2 4e5 4e6 4eb 4ee 4f2 4f8
4fa 4fe 501 505 509 50c 50d 50f
512 515 516 51b 51f 523 528 52c
52d 531 535 539 53d 541 545 54a
54f 553 557 55b 560 564 568 56b
56e 572 574 578 57c 57f 582 586
588 58c 590 593 597 59b 59e 5a2
5a5 5a9 5ac 5ad 5b2 5b5 5b9 5bf
5c1 5c5 5c8 5cc 5cf 5d3 5d7 5db
5df 5e3 5e7 5eb 5ef 5f3 5ff 603
607 60a 60e 612 614 618 61c 620
623 627 62b 62d 62e 633 1 637
63b 63f 642 646 64a 64e 652 655
659 65d 660 663 668 66b 66e 671
672 677 678 1 67a 67f 683 687
68a 68f 694 697 69b 69c 6a1 6a4
6a9 6aa 6af 6b2 6b7 6b8 6bd 6c0
6c4 6c5 6ca 6cd 6d2 6d3 6d8 6db
6df 6e3 6e6 6e9 6ea 6ec 6ed 6f2
6f3 6f8 6fa 6fe 701 703 707 709
715 717 719 71a 71f 723 725 731
733 737 73b 73e 73f 741 744 747
748 74d 751 755 759 75d 769 76d
772 776 779 77a 77f 783 787 78a
78d 791 793 797 79b 79e 7a1 7a5
7a7 7ab 7af 7b2 7b4 7b8 7bc 7c0
7c3 7c7 7cb 7cd 7ce 7d3 1 7d7
7db 7df 7e2 7e6 7ea 7ee 7f2 7f5
7f9 7fd 800 803 808 80b 80e 811
812 817 818 1 81a 81f 823 827
82a 82f 834 837 83b 83c 841 844
849 84a 84f 852 857 858 85d 860
864 865 86a 86d 872 873 878 87b
87f 883 886 889 88a 88c 88d 892
893 898 89a 89e 8a1 8a3 8a7 8a9
8b5 8b7 8b9 8ba 8bf 8c3 8c5 8d1
8d3 8d7 8db 8df 8e3 8e7 8eb 8ef
8fb 8ff 904 908 90b 90c 911 915
919 91c 91f 923 925 929 92d 930
933 937 939 93d 941 944 946 94a
94e 952 955 959 95d 95f 960 965
1 969 96d 971 974 978 97c 980
984 987 98b 98f 992 995 99a 99d
9a0 9a3 9a4 9a9 9aa 1 9ac 9b1
9b5 9b9 9bc 9c1 9c6 9c9 9cd 9ce
9d3 9d6 9db 9dc 9e1 9e4 9e9 9ea
9ef 9f2 9f6 9f7 9fc 9ff a04 a05
a0a a0d a11 a15 a18 a1b a1c a1e
a1f a24 a25 a2a a2c a30 a33 a35
a39 a3b a47 a49 a4b a4c a51 a55
a57 a63 a65 a67 a6b a6e a72 a76
a7a a7e a8a a8e a93 a97 a9a a9b
aa0 aa4 aa8 aab aae ab2 ab4 ab8
abc abf ac2 ac6 ac8 acc ad0 ad3
ad5 ad9 add ae1 ae4 ae8 aec aee
aef af4 1 af8 afc b00 b03 b07
b0b b0f b13 b16 b1a b1e b21 b24
b29 b2c b2f b32 b33 b38 b39 1
b3b b40 b44 b48 b4b b50 b55 b58
b5c b5d b62 b65 b6a b6b b70 b73
b78 b79 b7e b81 b85 b86 b8b b8e
b93 b94 b99 b9c ba0 ba4 ba7 baa
bab bad bae bb3 bb4 bb9 bbb bbf
bc2 bc4 bc8 bca bd6 bd8 bda bdb
be0 be4 be6 bf2 bf4 bf8 bfc bff
c03 c06 c0a c0d c0e c13 c16 c1a
c1e c22 c26 c2a c36 c3a c3f c43
c46 c47 c4c c50 c54 c57 c5a c5e
c60 c64 c68 c6b c6e c72 c74 c78
c7c c7f c81 c85 c89 c8d c90 c94
c98 c9a c9b ca0 1 ca4 ca8 cac
caf cb3 cb7 cbb cbf cc2 cc6 cca
ccd cd0 cd5 cd8 cdb cde cdf ce4
ce5 1 ce7 cec cf0 cf4 cf7 cfc
d01 d04 d08 d09 d0e d11 d16 d17
d1c d1f d24 d25 d2a d2d d31 d32
d37 d3a d3f d40 d45 d48 d4c d50
d53 d56 d57 d59 d5a d5f d60 d65
d67 d6b d6e d70 d74 d76 d82 d84
d86 d87 d8c d90 d92 d9e da0 da4
da8 dab dae daf db1 db4 db9 dba
dbf dc3 dc7 dcb dcf dd3 ddf de3
de7 dea dee df2 df4 df8 dfc e00
e03 e07 e0b e0d e0e e13 1 e17
e1b e1f e22 e26 e2a e2e e32 e35
e39 e3d e40 e43 e48 e4b e4e e51
e52 e57 e58 1 e5a e5f e63 e67
e6a e6f e74 e77 e7b e7c e81 e84
e89 e8a e8f e92 e97 e98 e9d ea0
ea4 ea5 eaa ead eb2 eb3 eb8 ebb
ebf ec3 ec6 ec9 eca ecc ecd ed2
ed3 ed8 eda ede ee1 ee3 ee7 ee9
ef5 ef7 ef9 efa eff f03 f05 f11
f13 f15 f19 f1d f21 f25 f29 f35
f39 f3d f40 f44 f48 f4a f4e f52
f56 f59 f5d f61 f63 f64 f69 1
f6d f71 f75 f78 f7c f80 f84 f88
f8b f8f f93 f96 f99 f9e fa1 fa4
fa7 fa8 fad fae 1 fb0 fb5 fb9
fbd fc0 fc5 fca fcd fd1 fd2 fd7
fda fdf fe0 fe5 fe8 fed fee ff3
ff6 ffa ffb 1000 1003 1008 1009 100e
1011 1015 1019 101c 101f 1020 1022 1023
1028 1029 102e 1030 1034 1037 1039 103d
103f 104b 104d 104f 1050 1055 1059 105b
1067 1069 106b 106f 1073 1076 107a 107e
1082 1086 108a 108e 1092 1096 109a 10a6
10aa 10af 10b3 10b6 10b7 10bc 10c0 10c4
10c7 10ca 10ce 10d0 10d4 10d8 10db 10de
10e2 10e4 10e8 10ec 10ef 10f1 10f5 10f9
10fd 1100 1104 1108 110a 110b 1110 1
1114 1118 111c 111f 1123 1127 112b 112f
1132 1136 113a 113d 1140 1145 1148 114b
114e 114f 1154 1155 1 1157 115c 1160
1164 1167 116c 1171 1174 1178 1179 117e
1181 1186 1187 118c 118f 1194 1195 119a
119d 11a1 11a2 11a7 11aa 11af 11b0 11b5
11b8 11bc 11c0 11c3 11c6 11c7 11c9 11ca
11cf 11d0 11d5 11d7 11db 11de 11e0 11e4
11e6 11f2 11f4 11f6 11f7 11fc 1200 1202
120e 1210 1212 1216 121a 121e 1222 1226
122a 122e 123a 123e 1243 1247 124a 124b
1250 1254 1258 125b 125e 1262 1264 1268
126c 126f 1272 1276 1278 127c 1280 1283
1285 1289 128d 1291 1294 1298 129c 129e
129f 12a4 1 12a8 12ac 12b0 12b3 12b7
12bb 12bf 12c3 12c6 12ca 12ce 12d1 12d4
12d9 12dc 12df 12e2 12e3 12e8 12e9 1
12eb 12f0 12f4 12f8 12fb 1300 1305 1308
130c 130d 1312 1315 131a 131b 1320 1323
1328 1329 132e 1331 1335 1336 133b 133e
1343 1344 1349 134c 1350 1354 1357 135a
135b 135d 135e 1363 1364 1369 136b 136f
1372 1374 1378 137a 1386 1388 138a 138b
1390 1394 1396 13a2 13a4 13a6 13aa 13ae
13b1 13b5 13b9 13bd 13c9 13cd 13d2 13d6
13d9 13da 13df 13e3 13e7 13ea 13ed 13f1
13f3 13f7 13fb 13fe 1401 1405 1407 140b
140f 1412 1414 1418 141c 1420 1423 1427
142b 142d 142e 1433 1 1437 143b 143f
1442 1446 144a 144e 1452 1455 1459 145d
1460 1463 1468 146b 146e 1471 1472 1477
1478 1 147a 147f 1483 1487 148a 148f
1494 1497 149b 149c 14a1 14a4 14a9 14aa
14af 14b2 14b7 14b8 14bd 14c0 14c4 14c5
14ca 14cd 14d2 14d3 14d8 14db 14df 14e3
14e6 14e9 14ea 14ec 14ed 14f2 14f3 14f8
14fa 14fe 1501 1503 1507 1509 1515 1517
1519 151a 151f 1523 1525 1531 1533 1537
153b 153f 1543 1547 1553 1557 155c 1560
1563 1564 1569 156d 1571 1574 1577 157b
157d 1581 1585 1588 158b 158f 1591 1595
1599 159c 159e 15a2 15a6 15aa 15ad 15b1
15b5 15b7 15b8 15bd 1 15c1 15c5 15c9
15cc 15d0 15d4 15d8 15dc 15df 15e3 15e7
15ea 15ed 15f2 15f5 15f8 15fb 15fc 1601
1602 1 1604 1609 160d 1611 1614 1619
161e 1621 1625 1626 162b 162e 1633 1634
1639 163c 1641 1642 1647 164a 164e 164f
1654 1657 165c 165d 1662 1665 1669 166d
1670 1673 1674 1676 1677 167c 167d 1682
1684 1688 168b 168d 1691 1693 169f 16a1
16a3 16a4 16a9 16ad 16af 16bb 16bd 16bf
16c3 16ca 16ce 16d2 16d7 16d9 16dd 16e1
16e4 16e8 16ec 16ee 16f2 16f6 16fa 16fd
1701 1705 1707 1708 170d 1 1711 1715
1719 171c 1720 1724 1728 172c 172f 1733
1737 173a 173d 1742 1745 1748 174b 174c
1751 1752 1 1754 1759 175d 1761 1764
1769 176e 1771 1775 1776 177b 177e 1783
1784 1789 178c 1791 1792 1797 179a 179e
179f 17a4 17a7 17ac 17ad 17b2 17b5 17b9
17bd 17c0 17c3 17c4 17c6 17c7 17cc 17cd
17d2 17d4 17d8 17db 17dd 17e1 17e3 17ef
17f1 17f3 17f4 17f9 17fd 17ff 180b 180d
1811 181d 1821 1823 1827 182b 182e 182f
1831 1834 1837 1838 183d 1841 1845 184a
184e 184f 1853 1857 185b 185f 1863 1867
186c 1871 1875 1879 187d 1882 1886 188a
188d 1890 1894 1896 189a 189e 18a1 18a4
18a8 18aa 18ae 18b2 18b5 18b9 18bd 18c0
18c4 18c7 18cb 18ce 18cf 18d4 18d7 18db
18e1 18e3 18e7 18ea 18ee 18f2 18f5 18f8
18f9 18fb 18fe 1903 1904 1909 190d 1911
1915 1919 191d 1929 192d 1931 1934 1938
193c 193e 1942 1946 194a 194d 1951 1955
1957 1958 195d 1 1961 1965 1969 196c
1970 1974 1978 197c 197f 1983 1987 198a
198d 1992 1995 1998 199b 199c 19a1 19a2
1 19a4 19a9 19ad 19b1 19b4 19b9 19be
19c1 19c5 19c6 19cb 19ce 19d3 19d4 19d9
19dc 19e1 19e2 19e7 19ea 19ee 19ef 19f4
19f7 19fc 19fd 1a02 1a05 1a09 1a0d 1a10
1a13 1a14 1a16 1a17 1a1c 1a1d 1a22 1a24
1a28 1a2b 1a2d 1a31 1a33 1a3f 1a41 1a43
1a44 1a49 1a4d 1a4f 1a5b 1a5d 1a5f 1a63
1a67 1a6b 1a6f 1a73 1a7f 1a83 1a87 1a8a
1a8e 1a92 1a94 1a98 1a9c 1aa0 1aa3 1aa7
1aab 1aad 1aae 1ab3 1 1ab7 1abb 1abf
1ac2 1ac6 1aca 1ace 1ad2 1ad5 1ad9 1add
1ae0 1ae3 1ae8 1aeb 1aee 1af1 1af2 1af7
1af8 1 1afa 1aff 1b03 1b07 1b0a 1b0f
1b14 1b17 1b1b 1b1c 1b21 1b24 1b29 1b2a
1b2f 1b32 1b37 1b38 1b3d 1b40 1b44 1b45
1b4a 1b4d 1b52 1b53 1b58 1b5b 1b5f 1b63
1b66 1b69 1b6a 1b6c 1b6d 1b72 1b73 1b78
1b7a 1b7e 1b81 1b83 1b87 1b89 1b95 1b97
1b99 1b9a 1b9f 1ba3 1ba5 1bb1 1bb3 1bb5
1bb9 1bbd 1bc0 1bc4 1bc8 1bcc 1bd0 1bd4
1bd8 1bdc 1be0 1be4 1be8 1bec 1bf0 1bfc
1c00 1c05 1c09 1c0c 1c0d 1c12 1c16 1c1a
1c1d 1c20 1c24 1c26 1c2a 1c2e 1c31 1c34
1c38 1c3a 1c3e 1c42 1c45 1c47 1c4b 1c4f
1c53 1c56 1c5a 1c5e 1c60 1c61 1c66 1
1c6a 1c6e 1c72 1c75 1c79 1c7d 1c81 1c85
1c88 1c8c 1c90 1c93 1c96 1c9b 1c9e 1ca1
1ca4 1ca5 1caa 1cab 1 1cad 1cb2 1cb6
1cba 1cbd 1cc2 1cc7 1cca 1cce 1ccf 1cd4
1cd7 1cdc 1cdd 1ce2 1ce5 1cea 1ceb 1cf0
1cf3 1cf7 1cf8 1cfd 1d00 1d05 1d06 1d0b
1d0e 1d12 1d16 1d19 1d1c 1d1d 1d1f 1d20
1d25 1d26 1d2b 1d2d 1d31 1d34 1d36 1d3a
1d3c 1d48 1d4a 1d4c 1d4d 1d52 1d56 1d58
1d64 1d66 1d6a 1d6e 1d72 1d76 1d7a 1d7e
1d82 1d86 1d8a 1d8e 1d92 1d96 1d9a 1d9e
1da2 1dae 1db2 1db7 1dbb 1dbe 1dbf 1dc4
1dc8 1dcc 1dcf 1dd2 1dd6 1dd8 1ddc 1de0
1de3 1de6 1dea 1dec 1df0 1df4 1df7 1df9
1dfd 1e01 1e05 1e08 1e0c 1e10 1e12 1e13
1e18 1 1e1c 1e20 1e24 1e27 1e2b 1e2f
1e33 1e37 1e3a 1e3e 1e42 1e45 1e48 1e4d
1e50 1e53 1e56 1e57 1e5c 1e5d 1 1e5f
1e64 1e68 1e6c 1e6f 1e74 1e79 1e7c 1e80
1e81 1e86 1e89 1e8e 1e8f 1e94 1e97 1e9c
1e9d 1ea2 1ea5 1ea9 1eaa 1eaf 1eb2 1eb7
1eb8 1ebd 1ec0 1ec4 1ec8 1ecb 1ece 1ecf
1ed1 1ed2 1ed7 1ed8 1edd 1edf 1ee3 1ee6
1ee8 1eec 1eee 1efa 1efc 1efe 1eff 1f04
1f08 1f0a 1f16 1f18 1f1a 1f1e 1f25 1f29
1f2d 1f32 1f34 1f38 1f3c 1f3f 1f43 1f47
1f49 1f4d 1f51 1f55 1f58 1f5c 1f60 1f62
1f63 1f68 1 1f6c 1f70 1f74 1f77 1f7b
1f7f 1f83 1f87 1f8a 1f8e 1f92 1f95 1f98
1f9d 1fa0 1fa3 1fa6 1fa7 1fac 1fad 1
1faf 1fb4 1fb8 1fbc 1fbf 1fc4 1fc9 1fcc
1fd0 1fd1 1fd6 1fd9 1fde 1fdf 1fe4 1fe7
1fec 1fed 1ff2 1ff5 1ff9 1ffa 1fff 2002
2007 2008 200d 2010 2014 2018 201b 201e
201f 2021 2022 2027 2028 202d 202f 2033
2036 2038 203c 203e 204a 204c 204e 204f
2054 2058 205a 2066 2068 206c 2078 207a
207e 2082 2085 2087 208b 2092 2096 209a
209f 20a1 20a5 20a9 20ac 20b0 20b4 20b6
20ba 20be 20c2 20c5 20c9 20cd 20cf 20d0
20d5 1 20d9 20dd 20e1 20e4 20e8 20ec
20f0 20f4 20f7 20fb 20ff 2102 2105 210a
210d 2110 2113 2114 2119 211a 1 211c
2121 2125 2129 212c 2131 2136 2139 213d
213e 2143 2146 214b 214c 2151 2154 2159
215a 215f 2162 2166 2167 216c 216f 2174
2175 217a 217d 2181 2185 2188 218b 218c
218e 218f 2194 2195 219a 219c 21a0 21a3
21a5 21a9 21ab 21b7 21b9 21bb 21bc 21c1
21c5 21c7 21d3 21d5 21d9 21dd 21e0 21e4
21e8 21eb 21ee 21f3 21f6 21f9 21fc 21fd
2202 2203 1 2205 220a 220e 2212 2215
221a 221f 2222 2226 2227 222c 222f 2234
2235 223a 223d 2242 2243 2248 224b 224f
2253 2257 225b 225e 225f 2261 2266 2267
2269 226a 226f 2272 2277 2278 227d 2280
2285 2286 228b 228e 2292 2293 2298 229b
22a0 22a1 22a6 22a7 22ac 22ae 22b2 22b5
22b9 22bd 22c0 22c4 22c8 22cb 22cf 22d3
22d4 22d9 22db 22df 22e3 22e6 22ea 22ee
22f1 22f5 22f9 22fc 22ff 2304 2307 230a
230d 230e 2313 2314 1 2316 231b 231f
2323 2326 232b 2330 2333 2337 2338 233d
233e 2343 2347 234b 234e 2353 2358 235b
235f 2363 2366 2367 236c 236f 2374 2375
237a 237d 2381 2385 2388 2389 238e 238f
2394 2396 239a 239d 23a1 23a5 23a9 23ad
23b1 23b5 23b9 23bd 23c1 23cd 23d2 23d6
23da 23de 23e2 23e4 23e5 23ea 1 23ee
23f2 23f6 23f9 23fd 2401 2405 2409 240c
2410 2414 2417 241a 241f 2422 2425 2428
2429 242e 242f 1 2431 2436 243a 243e
2441 2446 244b 244e 2452 2453 2458 2459
245e 2462 2466 2469 246e 2473 2476 247a
247b 2480 2483 2488 2489 248e 2491 2495
2499 249c 249f 24a0 24a2 24a3 24a8 24a9
24ae 24b0 24b4 24b7 24bb 24bf 24c3 24c7
24cb 24cf 24d3 24df 24e4 24e8 24ec 24f0
24f4 24f6 24fa 24fc 2508 250a 250c 250d
2512 2516 2518 2524 2528 252a 252b 2534 
a60
2
0 1 a 6 e :3 6 11 :2 6
1 3 a 13 a :2 1 4 b
14 13 :2 b :2 4 10 19 18 :2 10
:2 4 11 1a 19 :2 11 :2 4 18 21
20 :2 18 :2 4 18 21 20 :2 18 :2 4
12 1b 1a :2 12 :2 4 d 16 15
:2 d :2 4 f 18 17 :2 f :2 4 :2 12
21 12 :2 4 :2 e 1d e 4 7
e 0 :2 7 11 21 10 1c 25
30 39 45 4e 5c 65 73 7c
8f 99 a :6 7 e 0 :2 7 11
24 37 44 f 10 1d 2e 38
a :6 7 e 0 :2 7 11 14 21
24 33 36 43 46 f 24 10
1d 1a 2e 37 3a 47 58 5b
69 6c a :5 7 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 56 5c
5f :2 56 6d 85 8 :2 6d d 10
:2 6d 18 1b :2 6d b e :2 6d 13
16 1f 27 :2 1f 34 :2 16 :2 6d 3c
3f :2 6d :2 7 4c :2 4 7 :2 11 23
:2 2d 39 3c 4e 50 51 :2 4e :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e :2 7
54 :3 4 e :2 4 11 :2 4 9 :4 4
d 19 :2 7 a 11 :2 a :2 13 1f
a 17 a :2 13 1f a :4 7 b
:2 14 20 1d :2 29 :2 1d :3 a 39 :2 7
a 13 1e :2 a 21 23 :2 21 a
f :4 a 13 1f 34 49 53 :3 d
10 17 :2 10 :2 19 25 10 1d 10
:2 19 25 10 :4 d 11 :2 1a 26 23
:2 2f :2 23 :3 10 3f :3 d 1a d 17
27 36 59 16 2e 46 54 :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 60
61 :2 5e :2 32 :3 16 :2 1c 21 2d 6e
71 :2 2d 7e 81 :2 2d 85 88 :2 2d
94 97 :2 2d 9f a2 :2 2d ae b1
b8 c1 c4 :2 b1 :2 2d :2 16 64 :2 13
:2 10 :4 1c :2 10 d :3 a 10 19 24
:2 10 27 2a :2 27 1a 2f 19 31
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 64 65 :2 61 :2 35 :3 19
:2 1f 24 30 72 75 :2 30 82 85
:2 30 89 8c :2 30 98 9b :2 30 a3
a6 :2 30 b2 b5 bc c5 c8 :2 b5
:2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13 10
:3 2c 1a 2f 3b 19 26 37 43
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 64 65 :2 61 :2 35 :3 19
:2 1f 24 30 72 75 :2 30 82 85
:2 30 89 8c :2 30 98 9b :2 30 a3
a6 :2 30 b2 b5 bc c5 c8 :2 b5
:2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13 10
:4 2c :2 d 1c 16 2a 14 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 61 62 :2 5e :2 32 :3 16 :2 1c 21
2d 6f 72 :2 2d 7f 82 :2 2d 86
89 :2 2d 95 98 :2 2d a0 a3 :2 2d
af b2 b9 c2 c5 :2 b2 :2 2d :2 16
65 :2 13 :2 10 :4 1c :2 10 d :3 a 11
:2 1a 25 23 :2 2e :2 23 10 1f 39
46 57 65 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 64 65
:2 61 :2 35 :3 19 :2 1f 24 30 72 75
:2 30 82 85 :2 30 89 8c :2 30 98
9b :2 30 a3 a6 :2 30 b2 b5 bc
c5 c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13
:4 1f :2 13 10 :3 3e 13 1a 26 29
:2 13 2c 2e :2 2c 1d 33 1b 1c
2a :2 16 :2 1f 2b 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 67 68 :2 64 :2 38 :3 1c :2 22 27
33 75 78 :2 33 85 88 :2 33 8c
8f :2 33 9b 9e :2 33 a6 a9 :2 33
b5 b8 bf c8 cb :2 b8 :2 33 :2 1c
6b :2 19 :2 16 :4 22 :2 16 13 :4 32 1d
36 1b 1c 29 :2 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 67 68 :2 64 :2 38
:3 1c :2 22 27 33 75 78 :2 33 85
88 :2 33 8c 8f :2 33 9b 9e :2 33
a6 a9 :2 33 b5 b8 bf c8 cb
:2 b8 :2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16
13 :7 10 1a 26 35 3e 4c 19
26 37 44 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 64 65
:2 61 :2 35 :3 19 :2 1f 24 30 72 75
:2 30 82 85 :2 30 89 8c :2 30 98
9b :2 30 a3 a6 :2 30 b2 b5 bc
c5 c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13
:4 1f :2 13 10 :4 3e 1a 33 41 4a
55 19 2d 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 64 65
:2 61 :2 35 :3 19 :2 1f 24 30 72 75
:2 30 82 85 :2 30 89 8c :2 30 98
9b :2 30 a3 a6 :2 30 b2 b5 bc
c5 c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13
:4 1f :2 13 10 :7 d 1c 33 47 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 61 62 :2 5e :2 32 :3 16 :2 1c
21 2d 6f 72 :2 2d 7f 82 :2 2d
86 89 :2 2d 95 98 :2 2d a0 a3
:2 2d af b2 b9 c2 c5 :2 b2 :2 2d
:2 16 65 :2 13 :2 10 :4 1c :2 10 d :3 a
1c 33 40 51 65 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5e
61 62 :2 5e :2 32 :3 16 :2 1c 21 2d
6f 72 :2 2d 7f 82 :2 2d 86 89
:2 2d 95 98 :2 2d a0 a3 :2 2d af
b2 b9 c2 c5 :2 b2 :2 2d :2 16 65
:2 13 :2 10 :4 1c :2 10 d :4 a e 25
d 13 :3 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5e 5f :2 5b :2 2f :3 13 :2 19
1e 2a 6c 6f :2 2a 7c 7f :2 2a
83 86 :2 2a 92 95 :2 2a 9d a0
:2 2a ac af b6 bf c2 :2 af :2 2a
:2 13 62 :2 10 :2 d :4 19 :2 d a :3 25
:2 a 7 25 d 16 21 :2 d 24
26 :2 24 a f :4 a 13 1f 29
35 44 :3 d 10 17 :2 10 :2 19 25
10 1d 10 :2 19 25 10 :4 d 11
:2 1a 26 23 :2 2f :2 23 :3 10 3f :2 d
10 17 23 26 :2 10 29 2b :2 29
1a 30 18 19 27 :2 13 :2 1c 28
13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 64 65 :2 61
:2 35 :3 19 :2 1f 24 30 72 75 :2 30
82 85 :2 30 89 8c :2 30 98 9b
:2 30 a3 a6 :2 30 b2 b5 bc c5
c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13 :4 1f
:2 13 10 :4 2f 1a 33 18 19 26
:2 13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 61
64 65 :2 61 :2 35 :3 19 :2 1f 24 30
72 75 :2 30 82 85 :2 30 89 8c
:2 30 98 9b :2 30 a3 a6 :2 30 b2
b5 bc c5 c8 :2 b5 :2 30 :2 19 68
:2 16 :2 13 :4 1f :2 13 10 :7 d 17 23
15 1b 29 3f 15 25 16 23
34 41 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 61 62 :2 5e
:2 32 :3 16 :2 1c 21 2d 6f 72 :2 2d
7f 82 :2 2d 86 89 :2 2d 95 98
:2 2d a0 a3 :2 2d af b2 b9 c2
c5 :2 b2 :2 2d :2 16 65 :2 13 :2 10 :4 1c
:2 10 d :3 a 1c 31 3d 4a 57
64 73 85 17 25 2f 3e 4d
5c 65 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 61 62 :2 5e
:2 32 :3 16 :2 1c 21 2d 6f 72 :2 2d
7f 82 :2 2d 86 89 :2 2d 95 98
:2 2d a0 a3 :2 2d af b2 b9 c2
c5 :2 b2 :2 2d :2 16 65 :2 13 :2 10 :4 1c
:2 10 d :4 a e 28 d 13 :3 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5e
5f :2 5b :2 2f :3 13 :2 19 1e 2a 6c
6f :2 2a 7c 7f :2 2a 83 86 :2 2a
92 95 :2 2a 9d a0 :2 2a ac af
b6 bf c2 :2 af :2 2a :2 13 62 :2 10
:2 d :4 19 :2 d a :3 28 :2 a 28 25
:2 7 4 8 1 7 d :3 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 55 58 59
:2 55 :2 29 :3 d :2 13 18 24 66 69
:2 24 76 79 :2 24 7d 80 :2 24 8c
8f :2 24 97 9a :2 24 a6 a9 b0
b9 bc :2 a9 :2 24 :2 d 5c :2 a :2 7
:4 13 :2 7 4 :3 1 7 :2 11 23 :2 2d
39 3c 4e 51 52 :2 4e :2 23 :3 7
:2 d 12 1e 60 63 :2 1e 70 73
:2 1e 77 7a :2 1e 84 87 90 98
:2 a1 :2 90 ac :2 87 :2 1e b4 b7 :2 1e
bf c2 :2 1e c7 ca :2 1e d1 d4
:2 1e :2 7 55 :3 4 :2 f 21 :2 2a 34
3c :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 52 55 56 :2 52
:2 26 :3 a :2 10 15 21 63 66 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
59 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4f 52 53 :2 4f
:2 23 :3 7 :2 d 12 1e 60 63 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 56 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
a60
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :7 7
:7 8 :7 9 :7 a :7 b
:7 c :7 d :7 e :6 f
:6 10 :2 12 0 :2 12
:2 13 :d 14 13 :5 12
:2 16 0 :2 16 :4 17
18 :4 19 17 :5 16
:2 1b 0 :2 1b :8 1c
:2 1d :2 1e :9 1f 1c
:5 1b :7 21 :b 23 :11 24
25 :2 24 :2 25 :2 24
:2 25 :2 24 :2 26 :2 24
:9 26 :2 24 :2 26 :4 24
:3 23 :11 29 :b 2a :3 29
:3 2d :3 2e :5 30 32
:4 33 :3 34 :5 35 34
:5 37 36 :3 34 :a 39
:2 3a :3 39 :9 3e :5 3f
41 :8 42 :3 43 :5 44
43 :5 46 45 :3 43
:a 48 :2 49 :3 48 :3 4c
:4 4e :4 4f 4e :5 50
4d 52 :5 53 :3 52
:2 54 :5 56 :11 57 :24 58
:3 57 :2 55 :6 54 51
:3 41 :9 5d :2 5f :2 60
5f :6 61 :5 62 61
:5 64 63 :3 61 5e
67 :5 68 :3 67 :2 69
:5 6b :11 6c :24 6d :3 6c
:2 6a :6 69 66 :3 5d
:3 73 :4 74 73 :6 75
:5 76 75 :5 78 77
:3 75 72 7b :5 7c
:3 7b :2 7d :5 7f :11 80
:24 81 :3 80 :2 7e :6 7d
7a :6 5d 88 :2 89
8a 88 :6 8b :5 8c
8b :5 8e 8d :3 8b
87 91 :5 92 :3 91
:2 93 :5 95 :11 96 :24 97
:3 96 :2 94 :6 93 90
:3 41 :a 9c :6 9e :6 9f
:5 a0 9f :5 a2 a1
:3 9f 9d a5 :5 a6
:3 a5 :2 a7 :5 a9 :11 aa
:24 ab :3 aa :2 a8 :6 a7
a4 :3 9c :a b0 :2 b2
b3 :2 b4 b2 :5 b5
b1 b7 :5 b8 :3 b7
:2 b9 :5 bb :11 bc :24 bd
:3 bc :2 ba :6 b9 b6
:4 b0 :2 c3 c4 :2 c5
c3 :5 c6 c2 c8
:5 c9 :3 c8 :2 ca :5 cc
:11 cd :24 ce :3 cd :2 cb
:6 ca c7 :4 c1 :3 b0
:5 d5 :4 d6 d5 :6 d7
:5 d8 d7 :5 da d9
:3 d7 d4 dd :5 de
:3 dd :2 df :5 e1 :11 e2
:24 e3 :3 e2 :2 e0 :6 df
dc :4 9c :5 e9 :2 ea
e9 :6 eb :5 ec eb
:5 ee ed :3 eb e8
f1 :5 f2 :3 f1 :2 f3
:5 f5 :11 f6 :24 f7 :3 f6
:2 f4 :6 f3 f0 :4 e7
:3 9c :4 fe :6 ff :5 100
ff :5 102 101 :3 ff
fd 105 :5 106 :3 105
:2 107 :5 109 :11 10a :24 10b
:3 10a :2 108 :6 107 104
:3 41 :6 111 :6 112 :5 113
112 :5 115 114 :3 112
110 118 :5 119 :3 118
:2 11a :5 11c :11 11d :24 11e
:3 11d :2 11b :6 11a 117
:4 41 122 3e :4 125
:5 126 124 128 :5 129
:3 128 :2 12a :5 12c :11 12d
:24 12e :3 12d :2 12b :6 12a
127 :3 3e :2 133 134
3e :9 134 :5 135 137
:8 138 :3 139 :5 13a 139
:5 13c 13b :3 139 :a 13e
:2 13f :3 13e :a 142 :2 144
145 :2 146 144 :5 147
143 149 :5 14a :3 149
:2 14b :5 14d :11 14e :24 14f
:3 14e :2 14c :6 14b 148
:4 142 :2 155 156 :2 157
155 :5 158 154 15a
:5 15b :3 15a :2 15c :5 15e
:11 15f :24 160 :3 15f :2 15d
:6 15c 159 :4 153 :3 142
:2 167 :4 168 :2 169 :4 16a
167 :6 16b :5 16c 16b
:5 16e 16d :3 16b 166
171 :5 172 :3 171 :2 173
:5 175 :11 176 :24 177 :3 176
:2 174 :6 173 170 :3 137
:8 17d :7 17e 17d :6 17f
:5 180 17f :5 182 181
:3 17f 17c 185 :5 186
:3 185 :2 187 :5 189 :11 18a
:24 18b :3 18a :2 188 :6 187
184 :4 137 190 134
:4 193 :5 194 192 196
:5 197 :3 196 :2 198 :5 19a
:11 19b :24 19c :3 19b :2 199
:6 198 195 :3 134 :2 1a1
134 :3 3e 32 1a3
22 :4 1a6 :5 1a7 1a5
1a9 :5 1aa :3 1a9 :2 1ab
:5 1ad :11 1ae :24 1af :3 1ae
:2 1ac :6 1ab 1a8 :3 22
:11 1b4 :30 1b5 :3 1b4 :a 1b7
22 :3 1ba :11 1bb :b 1bc
:17 1bd :3 1bb :2 1bf :3 1c0
:3 1c1 1c2 1c0 1bf
1c0 :3 1c3 :3 1ba :2 1c4
:5 1c6 :11 1c7 :b 1c8 :18 1c9
:3 1c7 :2 1cb 1cc :3 1cd
1ce 1cc 1cb 1cc
:3 1cf :2 1c5 :6 1c4 1b9
:7 1 
2536
4
:3 0 1 :3 0 2
:a 0 a5b 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 6
:3 0 5 :7 0 9
8 :3 0 7 :3 0
8 :3 0 9 :2 0
4 b f 0
a5b 2 10 :2 0
d :2 0 c 4
:3 0 b :2 0 a
13 15 :6 0 18
16 0 a59 0
a :6 0 f :2 0
10 4 :3 0 e
1a 1c :6 0 1f
1d 0 a59 0
c :6 0 f :2 0
14 4 :3 0 12
21 23 :6 0 26
24 0 a59 0
e :6 0 f :2 0
18 4 :3 0 16
28 2a :6 0 2d
2b 0 a59 0
10 :6 0 f :2 0
1c 4 :3 0 1a
2f 31 :6 0 34
32 0 a59 0
11 :6 0 f :2 0
20 4 :3 0 1e
36 38 :6 0 3b
39 0 a59 0
12 :6 0 15 :2 0
24 4 :3 0 22
3d 3f :6 0 42
40 0 a59 0
13 :6 0 17 :2 0
28 4 :3 0 26
44 46 :6 0 49
47 0 a59 0
14 :6 0 17 :2 0
2a 6 :3 0 4b
:7 0 4f 4c 4d
a59 0 16 :9 0
2c 6 :3 0 51
:7 0 55 52 53
a59 0 18 :6 0
19 :3 0 1a :a 0
2 6b :4 0 57
5a 0 58 :3 0
1b :3 0 1c :3 0
1d :3 0 1e :3 0
1f :3 0 1e :3 0
20 :3 0 1e :3 0
21 :3 0 1e :3 0
22 :3 0 1e :3 0
23 :3 0 24 :3 0
a :4 0 25 1
:8 0 6c 57 5a
6d 0 a59 2e
6d 6f 6c 6e
:6 0 6b :7 0 6d
19 :3 0 26 :a 0
3 7f :5 0 71
74 0 72 :3 0
27 :3 0 28 :3 0
29 :3 0 2a :3 0
2b :3 0 2c :3 0
e :3 0 2d :3 0
e :4 0 2e 1
:8 0 80 71 74
81 0 a59 30
81 83 80 82
:6 0 7f :7 0 81
19 :3 0 2f :a 0
4 9f :5 0 85
88 0 86 :3 0
30 :3 0 29 :3 0
30 :3 0 2a :3 0
30 :3 0 31 :3 0
30 :3 0 32 :3 0
33 :3 0 30 :3 0
1b :3 0 e :3 0
34 :3 0 35 :3 0
35 :3 0 2c :3 0
e :3 0 35 :3 0
29 :3 0 30 :3 0
29 :4 0 36 1
:8 0 a0 85 88
a1 0 a59 32
a1 a3 a0 a2
:6 0 9f :7 0 a1
ab ac 0 34
8 :3 0 9 :2 0
4 a5 a6 0
a7 :7 0 aa a8
0 a59 0 37
:6 0 38 :3 0 39
:3 0 38 :3 0 3a
:3 0 ae af 0
2 :4 0 36 b0
b2 ad b4 b3
:2 0 3b :3 0 3c
:3 0 b6 b7 0
3d :4 0 38 :3 0
3e :3 0 ba bb
0 2 :4 0 38
bc be 3f :4 0
40 :2 0 41 :3 0
3a c1 c3 :3 0
42 :4 0 40 :2 0
43 :4 0 3d c6
c8 :3 0 40 :2 0
3 :3 0 40 ca
cc :3 0 40 :2 0
43 :4 0 43 ce
d0 :3 0 40 :2 0
44 :4 0 46 d2
d4 :3 0 40 :2 0
45 :3 0 46 :3 0
5 :3 0 49 d8
da 47 :4 0 4b
d7 dd 4e d6
df :3 0 40 :2 0
48 :4 0 51 e1
e3 :3 0 54 b8
e5 :2 0 e7 59
e8 b5 e7 0
e9 5b 0 9b9
38 :3 0 39 :3 0
ea eb 0 38
:3 0 49 :3 0 ed
ee 0 15 :2 0
2 :4 0 4a :2 0
4b :2 0 15 :2 0
5d f3 f5 :3 0
60 ef f7 ec
f9 f8 :2 0 3b
:3 0 4c :3 0 fb
fc 0 3d :4 0
4d :4 0 40 :2 0
41 :3 0 64 100
102 :3 0 67 fd
104 :2 0 106 6a
107 fa 106 0
108 6c 0 9b9
a :3 0 3 :3 0
109 10a 0 9b9
18 :3 0 5 :3 0
10c 10d 0 9b9
4e :3 0 1a :4 0
112 :2 0 9b9 110
113 :3 0 4f :3 0
1a :3 0 e :4 0
118 :2 0 90a 115
116 :3 0 1a :3 0
50 :3 0 119 11a
:3 0 8 :3 0 51
:3 0 11c 11d 0
17 :2 0 11e 11f
0 121 6e 128
8 :3 0 51 :3 0
122 123 0 52
:2 0 124 125 0
127 70 129 11b
121 0 12a 0
127 0 12a 72
0 90a 8 :3 0
51 :3 0 12b 12c
0 8 :3 0 53
:2 0 54 :3 0 12e
130 0 77 12f
132 :3 0 133 :2 0
55 :8 0 137 7a
138 134 137 0
139 7c 0 90a
45 :3 0 18 :3 0
17 :2 0 7e 13a
13d 56 :2 0 17
:2 0 83 13f 141
:3 0 4e :3 0 26
:4 0 146 :2 0 6aa
144 147 :3 0 4f
:3 0 26 :3 0 10
:3 0 11 :3 0 13
:3 0 14 :4 0 14f
:2 0 646 149 150
:3 0 86 :3 0 26
:3 0 50 :3 0 151
152 :3 0 8 :3 0
51 :3 0 154 155
0 17 :2 0 156
157 0 159 8b
160 8 :3 0 51
:3 0 15a 15b 0
52 :2 0 15c 15d
0 15f 8d 161
153 159 0 162
0 15f 0 162
8f 0 646 8
:3 0 51 :3 0 163
164 0 8 :3 0
53 :2 0 54 :3 0
166 168 0 94
167 16a :3 0 16b
:2 0 55 :8 0 16f
97 170 16c 16f
0 171 99 0
646 18 :3 0 17
:2 0 172 173 0
646 57 :3 0 18
:3 0 58 :3 0 2b
:3 0 59 :3 0 11
:3 0 29 :3 0 13
:4 0 5a 1 :8 0
183 8 :3 0 51
:3 0 17e 17f 0
5b :3 0 180 181
0 183 9b 1d6
5c :3 0 8 :3 0
51 :3 0 185 186
0 5b :3 0 187
188 0 18a 9e
18c a0 18b 18a
:2 0 1d4 5d :3 0
8 :3 0 51 :3 0
18f 190 0 5b
:3 0 191 192 0
1cc 38 :3 0 39
:3 0 194 195 0
38 :3 0 49 :3 0
197 198 0 5e
:2 0 2 :4 0 5f
:2 0 4b :2 0 15
:2 0 a2 19d 19f
:3 0 a5 199 1a1
196 1a3 1a2 :2 0
3b :3 0 4c :3 0
1a5 1a6 0 3d
:4 0 60 :4 0 40
:2 0 41 :3 0 a9
1aa 1ac :3 0 40
:2 0 61 :4 0 ac
1ae 1b0 :3 0 40
:2 0 62 :4 0 af
1b2 1b4 :3 0 40
:2 0 5b :3 0 b2
1b6 1b8 :3 0 40
:2 0 63 :4 0 b5
1ba 1bc :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 b8 1bf 1c3
bc 1be 1c5 :3 0
bf 1a7 1c7 :2 0
1c9 c2 1ca 1a4
1c9 0 1cb c4
0 1cc c6 1cf
:3 0 1cf 0 1cf
1ce 1cc 1cd :6 0
1d1 7 :3 0 c9
1d3 cb 1d2 1d1
:2 0 1d4 cd :2 0
1d6 0 1d6 1d5
183 1d4 :6 0 646
6 :3 0 45 :3 0
18 :3 0 17 :2 0
d0 1d8 1db 53
:2 0 17 :2 0 d5
1dd 1df :3 0 2b
:3 0 59 :3 0 59
:3 0 11 :4 0 67
1 :8 0 1fb 50
:4 0 1e6 :3 0 68
:3 0 56 :2 0 da
1e9 1ea :3 0 8
:3 0 51 :3 0 1ec
1ed 0 17 :2 0
1ee 1ef 0 1f1
dd 1f8 8 :3 0
51 :3 0 1f2 1f3
0 52 :2 0 1f4
1f5 0 1f7 df
1f9 1eb 1f1 0
1fa 0 1f7 0
1fa e1 0 1fb
e4 24e 5c :3 0
8 :3 0 51 :3 0
1fd 1fe 0 5b
:3 0 1ff 200 0
202 e7 204 e9
203 202 :2 0 24c
5d :3 0 8 :3 0
51 :3 0 207 208
0 5b :3 0 209
20a 0 244 38
:3 0 39 :3 0 20c
20d 0 38 :3 0
49 :3 0 20f 210
0 5e :2 0 2
:4 0 69 :2 0 4b
:2 0 15 :2 0 eb
215 217 :3 0 ee
211 219 20e 21b
21a :2 0 3b :3 0
4c :3 0 21d 21e
0 3d :4 0 6a
:4 0 40 :2 0 41
:3 0 f2 222 224
:3 0 40 :2 0 61
:4 0 f5 226 228
:3 0 40 :2 0 62
:4 0 f8 22a 22c
:3 0 40 :2 0 5b
:3 0 fb 22e 230
:3 0 40 :2 0 63
:4 0 fe 232 234
:3 0 40 :2 0 64
:3 0 65 :3 0 15
:2 0 66 :2 0 101
237 23b 105 236
23d :3 0 108 21f
23f :2 0 241 10b
242 21c 241 0
243 10d 0 244
10f 247 :3 0 247
0 247 246 244
245 :6 0 249 9
:3 0 112 24b 114
24a 249 :2 0 24c
116 :2 0 24e 0
24e 24d 1fb 24c
:6 0 2c2 6 :3 0
6b :3 0 6c :3 0
28 :3 0 2c :3 0
e :3 0 6c :3 0
11 :4 0 6d 1
:8 0 26d 50 :4 0
258 :3 0 68 :3 0
56 :2 0 11b 25b
25c :3 0 8 :3 0
51 :3 0 25e 25f
0 17 :2 0 260
261 0 263 11e
26a 8 :3 0 51
:3 0 264 265 0
52 :2 0 266 267
0 269 120 26b
25d 263 0 26c
0 269 0 26c
122 0 26d 125
2c0 5c :3 0 8
:3 0 51 :3 0 26f
270 0 5b :3 0
271 272 0 274
128 276 12a 275
274 :2 0 2be 5d
:3 0 8 :3 0 51
:3 0 279 27a 0
5b :3 0 27b 27c
0 2b6 38 :3 0
39 :3 0 27e 27f
0 38 :3 0 49
:3 0 281 282 0
5e :2 0 2 :4 0
6e :2 0 4b :2 0
15 :2 0 12c 287
289 :3 0 12f 283
28b 280 28d 28c
:2 0 3b :3 0 4c
:3 0 28f 290 0
3d :4 0 6f :4 0
40 :2 0 41 :3 0
133 294 296 :3 0
40 :2 0 61 :4 0
136 298 29a :3 0
40 :2 0 62 :4 0
139 29c 29e :3 0
40 :2 0 5b :3 0
13c 2a0 2a2 :3 0
40 :2 0 63 :4 0
13f 2a4 2a6 :3 0
40 :2 0 64 :3 0
65 :3 0 15 :2 0
66 :2 0 142 2a9
2ad 146 2a8 2af
:3 0 149 291 2b1
:2 0 2b3 14c 2b4
28e 2b3 0 2b5
14e 0 2b6 150
2b9 :3 0 2b9 0
2b9 2b8 2b6 2b7
:6 0 2bb b :3 0
153 2bd 155 2bc
2bb :2 0 2be 157
:2 0 2c0 0 2c0
2bf 26d 2be :6 0
2c2 6 :3 0 15a
2c3 1e0 2c2 0
2c4 15d 0 646
33 :3 0 27 :3 0
10 :3 0 32 :4 0
70 1 :8 0 2df
50 :4 0 2ca :3 0
68 :3 0 56 :2 0
161 2cd 2ce :3 0
8 :3 0 51 :3 0
2d0 2d1 0 17
:2 0 2d2 2d3 0
2d5 164 2dc 8
:3 0 51 :3 0 2d6
2d7 0 52 :2 0
2d8 2d9 0 2db
166 2dd 2cf 2d5
0 2de 0 2db
0 2de 168 0
2df 16b 332 5c
:3 0 8 :3 0 51
:3 0 2e1 2e2 0
5b :3 0 2e3 2e4
0 2e6 16e 2e8
170 2e7 2e6 :2 0
330 5d :3 0 8
:3 0 51 :3 0 2eb
2ec 0 5b :3 0
2ed 2ee 0 328
38 :3 0 39 :3 0
2f0 2f1 0 38
:3 0 49 :3 0 2f3
2f4 0 5e :2 0
2 :4 0 71 :2 0
4b :2 0 15 :2 0
172 2f9 2fb :3 0
175 2f5 2fd 2f2
2ff 2fe :2 0 3b
:3 0 4c :3 0 301
302 0 3d :4 0
72 :4 0 40 :2 0
41 :3 0 179 306
308 :3 0 40 :2 0
61 :4 0 17c 30a
30c :3 0 40 :2 0
62 :4 0 17f 30e
310 :3 0 40 :2 0
5b :3 0 182 312
314 :3 0 40 :2 0
63 :4 0 185 316
318 :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
188 31b 31f 18c
31a 321 :3 0 18f
303 323 :2 0 325
192 326 300 325
0 327 194 0
328 196 32b :3 0
32b 0 32b 32a
328 329 :6 0 32d
d :3 0 199 32f
19b 32e 32d :2 0
330 19d :2 0 332
0 332 331 2df
330 :6 0 646 6
:3 0 8 :3 0 51
:3 0 334 335 0
8 :3 0 56 :2 0
54 :3 0 337 339
0 1a2 338 33b
:3 0 33c :2 0 34
:3 0 2c :3 0 e
:3 0 29 :3 0 13
:4 0 73 1 :8 0
359 50 :4 0 344
:3 0 68 :3 0 56
:2 0 1a7 347 348
:3 0 8 :3 0 51
:3 0 34a 34b 0
17 :2 0 34c 34d
0 34f 1aa 356
8 :3 0 51 :3 0
350 351 0 52
:2 0 352 353 0
355 1ac 357 349
34f 0 358 0
355 0 358 1ae
0 359 1b1 3ac
5c :3 0 8 :3 0
51 :3 0 35b 35c
0 5b :3 0 35d
35e 0 360 1b4
362 1b6 361 360
:2 0 3aa 5d :3 0
8 :3 0 51 :3 0
365 366 0 5b
:3 0 367 368 0
3a2 38 :3 0 39
:3 0 36a 36b 0
38 :3 0 49 :3 0
36d 36e 0 5e
:2 0 2 :4 0 74
:2 0 4b :2 0 15
:2 0 1b8 373 375
:3 0 1bb 36f 377
36c 379 378 :2 0
3b :3 0 4c :3 0
37b 37c 0 3d
:4 0 75 :4 0 40
:2 0 41 :3 0 1bf
380 382 :3 0 40
:2 0 61 :4 0 1c2
384 386 :3 0 40
:2 0 62 :4 0 1c5
388 38a :3 0 40
:2 0 5b :3 0 1c8
38c 38e :3 0 40
:2 0 63 :4 0 1cb
390 392 :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 1ce 395 399
1d2 394 39b :3 0
1d5 37d 39d :2 0
39f 1d8 3a0 37a
39f 0 3a1 1da
0 3a2 1dc 3a5
:3 0 3a5 0 3a5
3a4 3a2 3a3 :6 0
3a7 f :3 0 1df
3a9 1e1 3a8 3a7
:2 0 3aa 1e3 :2 0
3ac 0 3ac 3ab
359 3aa :6 0 4f1
6 :3 0 64 :3 0
14 :3 0 15 :2 0
15 :2 0 1e6 3ae
3b2 56 :2 0 17
:4 0 1ec 3b4 3b6
:3 0 76 :3 0 c
:3 0 77 :3 0 29
:3 0 13 :4 0 78
1 :8 0 3c3 8
:3 0 51 :3 0 3be
3bf 0 5b :3 0
3c0 3c1 0 3c3
1ef 416 5c :3 0
8 :3 0 51 :3 0
3c5 3c6 0 5b
:3 0 3c7 3c8 0
3ca 1f2 3cc 1f4
3cb 3ca :2 0 414
5d :3 0 8 :3 0
51 :3 0 3cf 3d0
0 5b :3 0 3d1
3d2 0 40c 38
:3 0 39 :3 0 3d4
3d5 0 38 :3 0
49 :3 0 3d7 3d8
0 5e :2 0 2
:4 0 79 :2 0 4b
:2 0 15 :2 0 1f6
3dd 3df :3 0 1f9
3d9 3e1 3d6 3e3
3e2 :2 0 3b :3 0
4c :3 0 3e5 3e6
0 3d :4 0 7a
:4 0 40 :2 0 41
:3 0 1fd 3ea 3ec
:3 0 40 :2 0 61
:4 0 200 3ee 3f0
:3 0 40 :2 0 62
:4 0 203 3f2 3f4
:3 0 40 :2 0 5b
:3 0 206 3f6 3f8
:3 0 40 :2 0 63
:4 0 209 3fa 3fc
:3 0 40 :2 0 64
:3 0 65 :3 0 15
:2 0 66 :2 0 20c
3ff 403 210 3fe
405 :3 0 213 3e7
407 :2 0 409 216
40a 3e4 409 0
40b 218 0 40c
21a 40f :3 0 40f
0 40f 40e 40c
40d :6 0 411 11
:3 0 21d 413 21f
412 411 :2 0 414
221 :2 0 416 0
416 415 3c3 414
:6 0 418 6 :3 0
224 47a 7b :3 0
c :3 0 7c :3 0
7d :3 0 13 :4 0
7e 1 :8 0 424
8 :3 0 51 :3 0
41f 420 0 5b
:3 0 421 422 0
424 226 477 5c
:3 0 8 :3 0 51
:3 0 426 427 0
5b :3 0 428 429
0 42b 229 42d
22b 42c 42b :2 0
475 5d :3 0 8
:3 0 51 :3 0 430
431 0 5b :3 0
432 433 0 46d
38 :3 0 39 :3 0
435 436 0 38
:3 0 49 :3 0 438
439 0 5e :2 0
2 :4 0 7f :2 0
4b :2 0 15 :2 0
22d 43e 440 :3 0
230 43a 442 437
444 443 :2 0 3b
:3 0 4c :3 0 446
447 0 3d :4 0
80 :4 0 40 :2 0
41 :3 0 234 44b
44d :3 0 40 :2 0
61 :4 0 237 44f
451 :3 0 40 :2 0
62 :4 0 23a 453
455 :3 0 40 :2 0
5b :3 0 23d 457
459 :3 0 40 :2 0
63 :4 0 240 45b
45d :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
243 460 464 247
45f 466 :3 0 24a
448 468 :2 0 46a
24d 46b 445 46a
0 46c 24f 0
46d 251 470 :3 0
470 0 470 46f
46d 46e :6 0 472
13 :3 0 254 474
256 473 472 :2 0
475 258 :2 0 477
0 477 476 424
475 :6 0 479 6
:3 0 25b 47b 3b7
418 0 47c 0
479 0 47c 25d
0 4f1 1c :3 0
81 :3 0 82 :3 0
81 :3 0 c :3 0
2c :3 0 e :3 0
1b :3 0 e :4 0
83 1 :8 0 49c
50 :4 0 487 :3 0
68 :3 0 56 :2 0
262 48a 48b :3 0
8 :3 0 51 :3 0
48d 48e 0 17
:2 0 48f 490 0
492 265 499 8
:3 0 51 :3 0 493
494 0 52 :2 0
495 496 0 498
267 49a 48c 492
0 49b 0 498
0 49b 269 0
49c 26c 4ef 5c
:3 0 8 :3 0 51
:3 0 49e 49f 0
5b :3 0 4a0 4a1
0 4a3 26f 4a5
271 4a4 4a3 :2 0
4ed 5d :3 0 8
:3 0 51 :3 0 4a8
4a9 0 5b :3 0
4aa 4ab 0 4e5
38 :3 0 39 :3 0
4ad 4ae 0 38
:3 0 49 :3 0 4b0
4b1 0 5e :2 0
2 :4 0 84 :2 0
4b :2 0 15 :2 0
273 4b6 4b8 :3 0
276 4b2 4ba 4af
4bc 4bb :2 0 3b
:3 0 4c :3 0 4be
4bf 0 3d :4 0
85 :4 0 40 :2 0
41 :3 0 27a 4c3
4c5 :3 0 40 :2 0
61 :4 0 27d 4c7
4c9 :3 0 40 :2 0
62 :4 0 280 4cb
4cd :3 0 40 :2 0
5b :3 0 283 4cf
4d1 :3 0 40 :2 0
63 :4 0 286 4d3
4d5 :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
289 4d8 4dc 28d
4d7 4de :3 0 290
4c0 4e0 :2 0 4e2
293 4e3 4bd 4e2
0 4e4 295 0
4e5 297 4e8 :3 0
4e8 0 4e8 4e7
4e5 4e6 :6 0 4ea
15 :3 0 29a 4ec
29c 4eb 4ea :2 0
4ed 29e :2 0 4ef
0 4ef 4ee 49c
4ed :6 0 4f1 6
:3 0 2a1 565 33
:3 0 31 :3 0 86
:3 0 87 :3 0 31
:3 0 27 :3 0 10
:4 0 88 1 :8 0
50f 50 :4 0 4fa
:3 0 68 :3 0 56
:2 0 2a7 4fd 4fe
:3 0 8 :3 0 51
:3 0 500 501 0
17 :2 0 502 503
0 505 2aa 50c
8 :3 0 51 :3 0
506 507 0 52
:2 0 508 509 0
50b 2ac 50d 4ff
505 0 50e 0
50b 0 50e 2ae
0 50f 2b1 562
5c :3 0 8 :3 0
51 :3 0 511 512
0 5b :3 0 513
514 0 516 2b4
518 2b6 517 516
:2 0 560 5d :3 0
8 :3 0 51 :3 0
51b 51c 0 5b
:3 0 51d 51e 0
558 38 :3 0 39
:3 0 520 521 0
38 :3 0 49 :3 0
523 524 0 5e
:2 0 2 :4 0 89
:2 0 4b :2 0 15
:2 0 2b8 529 52b
:3 0 2bb 525 52d
522 52f 52e :2 0
3b :3 0 4c :3 0
531 532 0 3d
:4 0 8a :4 0 40
:2 0 41 :3 0 2bf
536 538 :3 0 40
:2 0 61 :4 0 2c2
53a 53c :3 0 40
:2 0 62 :4 0 2c5
53e 540 :3 0 40
:2 0 5b :3 0 2c8
542 544 :3 0 40
:2 0 63 :4 0 2cb
546 548 :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 2ce 54b 54f
2d2 54a 551 :3 0
2d5 533 553 :2 0
555 2d8 556 530
555 0 557 2da
0 558 2dc 55b
:3 0 55b 0 55b
55a 558 559 :6 0
55d 17 :3 0 2df
55f 2e1 55e 55d
:2 0 560 2e3 :2 0
562 0 562 561
50f 560 :6 0 564
6 :3 0 2e6 566
33d 4f1 0 567
0 564 0 567
2e8 0 646 2b
:3 0 28 :3 0 11
:4 0 8b 1 :8 0
581 50 :4 0 56c
:3 0 68 :3 0 56
:2 0 2ed 56f 570
:3 0 8 :3 0 51
:3 0 572 573 0
17 :2 0 574 575
0 577 2f0 57e
8 :3 0 51 :3 0
578 579 0 52
:2 0 57a 57b 0
57d 2f2 57f 571
577 0 580 0
57d 0 580 2f4
0 581 2f7 5d4
5c :3 0 8 :3 0
51 :3 0 583 584
0 5b :3 0 585
586 0 588 2fa
58a 2fc 589 588
:2 0 5d2 5d :3 0
8 :3 0 51 :3 0
58d 58e 0 5b
:3 0 58f 590 0
5ca 38 :3 0 39
:3 0 592 593 0
38 :3 0 49 :3 0
595 596 0 5e
:2 0 2 :4 0 8c
:2 0 4b :2 0 15
:2 0 2fe 59b 59d
:3 0 301 597 59f
594 5a1 5a0 :2 0
3b :3 0 4c :3 0
5a3 5a4 0 3d
:4 0 8d :4 0 40
:2 0 41 :3 0 305
5a8 5aa :3 0 40
:2 0 61 :4 0 308
5ac 5ae :3 0 40
:2 0 62 :4 0 30b
5b0 5b2 :3 0 40
:2 0 5b :3 0 30e
5b4 5b6 :3 0 40
:2 0 63 :4 0 311
5b8 5ba :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 314 5bd 5c1
318 5bc 5c3 :3 0
31b 5a5 5c5 :2 0
5c7 31e 5c8 5a2
5c7 0 5c9 320
0 5ca 322 5cd
:3 0 5cd 0 5cd
5cc 5ca 5cb :6 0
5cf 19 :3 0 325
5d1 327 5d0 5cf
:2 0 5d2 329 :2 0
5d4 0 5d4 5d3
581 5d2 :6 0 646
6 :3 0 6b :3 0
2c :3 0 e :3 0
28 :3 0 11 :4 0
8e 1 :8 0 5f1
50 :4 0 5dc :3 0
68 :3 0 56 :2 0
32e 5df 5e0 :3 0
8 :3 0 51 :3 0
5e2 5e3 0 17
:2 0 5e4 5e5 0
5e7 331 5ee 8
:3 0 51 :3 0 5e8
5e9 0 52 :2 0
5ea 5eb 0 5ed
333 5ef 5e1 5e7
0 5f0 0 5ed
0 5f0 335 0
5f1 338 644 5c
:3 0 8 :3 0 51
:3 0 5f3 5f4 0
5b :3 0 5f5 5f6
0 5f8 33b 5fa
33d 5f9 5f8 :2 0
642 5d :3 0 8
:3 0 51 :3 0 5fd
5fe 0 5b :3 0
5ff 600 0 63a
38 :3 0 39 :3 0
602 603 0 38
:3 0 49 :3 0 605
606 0 5e :2 0
2 :4 0 8f :2 0
4b :2 0 15 :2 0
33f 60b 60d :3 0
342 607 60f 604
611 610 :2 0 3b
:3 0 4c :3 0 613
614 0 3d :4 0
90 :4 0 40 :2 0
41 :3 0 346 618
61a :3 0 40 :2 0
61 :4 0 349 61c
61e :3 0 40 :2 0
62 :4 0 34c 620
622 :3 0 40 :2 0
5b :3 0 34f 624
626 :3 0 40 :2 0
63 :4 0 352 628
62a :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
355 62d 631 359
62c 633 :3 0 35c
615 635 :2 0 637
35f 638 612 637
0 639 361 0
63a 363 63d :3 0
63d 0 63d 63c
63a 63b :6 0 63f
1b :3 0 366 641
368 640 63f :2 0
642 36a :2 0 644
0 644 643 5f1
642 :6 0 646 6
:3 0 36d 648 4f
:4 0 646 :4 0 6aa
91 :3 0 26 :4 0
64c :2 0 652 64a
0 8 :3 0 51
:3 0 64d 64e 0
5b :3 0 64f 650
0 652 378 6a5
5c :3 0 8 :3 0
51 :3 0 654 655
0 5b :3 0 656
657 0 659 37b
65b 37d 65a 659
:2 0 6a3 5d :3 0
8 :3 0 51 :3 0
65e 65f 0 5b
:3 0 660 661 0
69b 38 :3 0 39
:3 0 663 664 0
38 :3 0 49 :3 0
666 667 0 5e
:2 0 2 :4 0 92
:2 0 4b :2 0 15
:2 0 37f 66c 66e
:3 0 382 668 670
665 672 671 :2 0
3b :3 0 4c :3 0
674 675 0 3d
:4 0 93 :4 0 40
:2 0 41 :3 0 386
679 67b :3 0 40
:2 0 61 :4 0 389
67d 67f :3 0 40
:2 0 62 :4 0 38c
681 683 :3 0 40
:2 0 5b :3 0 38f
685 687 :3 0 40
:2 0 63 :4 0 392
689 68b :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 395 68e 692
399 68d 694 :3 0
39c 676 696 :2 0
698 39f 699 673
698 0 69a 3a1
0 69b 3a3 69e
:3 0 69e 0 69e
69d 69b 69c :6 0
6a0 1d :3 0 3a6
6a2 3a8 6a1 6a0
:2 0 6a3 3aa :2 0
6a5 0 6a5 6a4
652 6a3 :6 0 6aa
5 :3 0 94 :4 0
94 1 :8 0 6aa
95 :3 0 3ad 908
45 :3 0 18 :3 0
17 :2 0 3b2 6ab
6ae 56 :2 0 15
:2 0 3b7 6b0 6b2
:3 0 4e :3 0 2f
:4 0 6b7 :2 0 906
6b5 6b8 :3 0 4f
:3 0 2f :3 0 13
:3 0 14 :3 0 16
:3 0 12 :4 0 6c0
:2 0 8a3 6ba 6c1
:3 0 3ba :3 0 2f
:3 0 50 :3 0 6c2
6c3 :3 0 8 :3 0
51 :3 0 6c5 6c6
0 17 :2 0 6c7
6c8 0 6ca 3bf
6d1 8 :3 0 51
:3 0 6cb 6cc 0
52 :2 0 6cd 6ce
0 6d0 3c1 6d2
6c4 6ca 0 6d3
0 6d0 0 6d3
3c3 0 8a3 8
:3 0 51 :3 0 6d4
6d5 0 8 :3 0
53 :2 0 54 :3 0
6d7 6d9 0 3c8
6d8 6db :3 0 6dc
:2 0 55 :8 0 6e0
3cb 6e1 6dd 6e0
0 6e2 3cd 0
8a3 64 :3 0 14
:3 0 15 :2 0 15
:2 0 3cf 6e3 6e7
56 :2 0 17 :4 0
3d5 6e9 6eb :3 0
76 :3 0 c :3 0
77 :3 0 29 :3 0
13 :4 0 96 1
:8 0 6f8 8 :3 0
51 :3 0 6f3 6f4
0 5b :3 0 6f5
6f6 0 6f8 3d8
74b 5c :3 0 8
:3 0 51 :3 0 6fa
6fb 0 5b :3 0
6fc 6fd 0 6ff
3db 701 3dd 700
6ff :2 0 749 5d
:3 0 8 :3 0 51
:3 0 704 705 0
5b :3 0 706 707
0 741 38 :3 0
39 :3 0 709 70a
0 38 :3 0 49
:3 0 70c 70d 0
5e :2 0 2 :4 0
97 :2 0 4b :2 0
15 :2 0 3df 712
714 :3 0 3e2 70e
716 70b 718 717
:2 0 3b :3 0 4c
:3 0 71a 71b 0
3d :4 0 98 :4 0
40 :2 0 41 :3 0
3e6 71f 721 :3 0
40 :2 0 61 :4 0
3e9 723 725 :3 0
40 :2 0 62 :4 0
3ec 727 729 :3 0
40 :2 0 5b :3 0
3ef 72b 72d :3 0
40 :2 0 63 :4 0
3f2 72f 731 :3 0
40 :2 0 64 :3 0
65 :3 0 15 :2 0
66 :2 0 3f5 734
738 3f9 733 73a
:3 0 3fc 71c 73c
:2 0 73e 3ff 73f
719 73e 0 740
401 0 741 403
744 :3 0 744 0
744 743 741 742
:6 0 746 20 :3 0
406 748 408 747
746 :2 0 749 40a
:2 0 74b 0 74b
74a 6f8 749 :6 0
74d 1f :3 0 40d
7af 7b :3 0 c
:3 0 7c :3 0 7d
:3 0 13 :4 0 99
1 :8 0 759 8
:3 0 51 :3 0 754
755 0 5b :3 0
756 757 0 759
40f 7ac 5c :3 0
8 :3 0 51 :3 0
75b 75c 0 5b
:3 0 75d 75e 0
760 412 762 414
761 760 :2 0 7aa
5d :3 0 8 :3 0
51 :3 0 765 766
0 5b :3 0 767
768 0 7a2 38
:3 0 39 :3 0 76a
76b 0 38 :3 0
49 :3 0 76d 76e
0 5e :2 0 2
:4 0 9a :2 0 4b
:2 0 15 :2 0 416
773 775 :3 0 419
76f 777 76c 779
778 :2 0 3b :3 0
4c :3 0 77b 77c
0 3d :4 0 9b
:4 0 40 :2 0 41
:3 0 41d 780 782
:3 0 40 :2 0 61
:4 0 420 784 786
:3 0 40 :2 0 62
:4 0 423 788 78a
:3 0 40 :2 0 5b
:3 0 426 78c 78e
:3 0 40 :2 0 63
:4 0 429 790 792
:3 0 40 :2 0 64
:3 0 65 :3 0 15
:2 0 66 :2 0 42c
795 799 430 794
79b :3 0 433 77d
79d :2 0 79f 436
7a0 77a 79f 0
7a1 438 0 7a2
43a 7a5 :3 0 7a5
0 7a5 7a4 7a2
7a3 :6 0 7a7 22
:3 0 43d 7a9 43f
7a8 7a7 :2 0 7aa
441 :2 0 7ac 0
7ac 7ab 759 7aa
:6 0 7ae 1f :3 0
444 7b0 6ec 74d
0 7b1 0 7ae
0 7b1 446 0
8a3 1c :3 0 81
:3 0 9c :3 0 81
:3 0 c :3 0 81
:3 0 81 :3 0 c
:3 0 2c :3 0 e
:3 0 1b :3 0 e
:4 0 9d 1 :8 0
7d4 50 :4 0 7bf
:3 0 68 :3 0 56
:2 0 44b 7c2 7c3
:3 0 8 :3 0 51
:3 0 7c5 7c6 0
17 :2 0 7c7 7c8
0 7ca 44e 7d1
8 :3 0 51 :3 0
7cb 7cc 0 52
:2 0 7cd 7ce 0
7d0 450 7d2 7c4
7ca 0 7d3 0
7d0 0 7d3 452
0 7d4 455 827
5c :3 0 8 :3 0
51 :3 0 7d6 7d7
0 5b :3 0 7d8
7d9 0 7db 458
7dd 45a 7dc 7db
:2 0 825 5d :3 0
8 :3 0 51 :3 0
7e0 7e1 0 5b
:3 0 7e2 7e3 0
81d 38 :3 0 39
:3 0 7e5 7e6 0
38 :3 0 49 :3 0
7e8 7e9 0 5e
:2 0 2 :4 0 9e
:2 0 4b :2 0 15
:2 0 45c 7ee 7f0
:3 0 45f 7ea 7f2
7e7 7f4 7f3 :2 0
3b :3 0 4c :3 0
7f6 7f7 0 3d
:4 0 9f :4 0 40
:2 0 41 :3 0 463
7fb 7fd :3 0 40
:2 0 61 :4 0 466
7ff 801 :3 0 40
:2 0 62 :4 0 469
803 805 :3 0 40
:2 0 5b :3 0 46c
807 809 :3 0 40
:2 0 63 :4 0 46f
80b 80d :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 472 810 814
476 80f 816 :3 0
479 7f8 818 :2 0
81a 47c 81b 7f5
81a 0 81c 47e
0 81d 480 820
:3 0 820 0 820
81f 81d 81e :6 0
822 24 :3 0 483
824 485 823 822
:2 0 825 487 :2 0
827 0 827 826
7d4 825 :6 0 8a3
1f :3 0 34 :3 0
2c :3 0 29 :3 0
31 :3 0 32 :3 0
2a :3 0 a0 :3 0
a1 :3 0 e :3 0
13 :3 0 16 :3 0
12 :3 0 14 :3 0
1e :3 0 a2 :4 0
a3 1 :8 0 84e
50 :4 0 839 :3 0
68 :3 0 56 :2 0
48c 83c 83d :3 0
8 :3 0 51 :3 0
83f 840 0 17
:2 0 841 842 0
844 48f 84b 8
:3 0 51 :3 0 845
846 0 52 :2 0
847 848 0 84a
491 84c 83e 844
0 84d 0 84a
0 84d 493 0
84e 496 8a1 5c
:3 0 8 :3 0 51
:3 0 850 851 0
5b :3 0 852 853
0 855 499 857
49b 856 855 :2 0
89f 5d :3 0 8
:3 0 51 :3 0 85a
85b 0 5b :3 0
85c 85d 0 897
38 :3 0 39 :3 0
85f 860 0 38
:3 0 49 :3 0 862
863 0 5e :2 0
2 :4 0 a4 :2 0
4b :2 0 15 :2 0
49d 868 86a :3 0
4a0 864 86c 861
86e 86d :2 0 3b
:3 0 4c :3 0 870
871 0 3d :4 0
a5 :4 0 40 :2 0
41 :3 0 4a4 875
877 :3 0 40 :2 0
61 :4 0 4a7 879
87b :3 0 40 :2 0
62 :4 0 4aa 87d
87f :3 0 40 :2 0
5b :3 0 4ad 881
883 :3 0 40 :2 0
63 :4 0 4b0 885
887 :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
4b3 88a 88e 4b7
889 890 :3 0 4ba
872 892 :2 0 894
4bd 895 86f 894
0 896 4bf 0
897 4c1 89a :3 0
89a 0 89a 899
897 898 :6 0 89c
26 :3 0 4c4 89e
4c6 89d 89c :2 0
89f 4c8 :2 0 8a1
0 8a1 8a0 84e
89f :6 0 8a3 1f
:3 0 4cb 8a5 4f
:4 0 8a3 :4 0 906
91 :3 0 2f :4 0
8a9 :2 0 8af 8a7
0 8 :3 0 51
:3 0 8aa 8ab 0
5b :3 0 8ac 8ad
0 8af 4d2 902
5c :3 0 8 :3 0
51 :3 0 8b1 8b2
0 5b :3 0 8b3
8b4 0 8b6 4d5
8b8 4d7 8b7 8b6
:2 0 900 5d :3 0
8 :3 0 51 :3 0
8bb 8bc 0 5b
:3 0 8bd 8be 0
8f8 38 :3 0 39
:3 0 8c0 8c1 0
38 :3 0 49 :3 0
8c3 8c4 0 5e
:2 0 2 :4 0 a6
:2 0 4b :2 0 15
:2 0 4d9 8c9 8cb
:3 0 4dc 8c5 8cd
8c2 8cf 8ce :2 0
3b :3 0 4c :3 0
8d1 8d2 0 3d
:4 0 a7 :4 0 40
:2 0 41 :3 0 4e0
8d6 8d8 :3 0 40
:2 0 61 :4 0 4e3
8da 8dc :3 0 40
:2 0 62 :4 0 4e6
8de 8e0 :3 0 40
:2 0 5b :3 0 4e9
8e2 8e4 :3 0 40
:2 0 63 :4 0 4ec
8e6 8e8 :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 4ef 8eb 8ef
4f3 8ea 8f1 :3 0
4f6 8d3 8f3 :2 0
8f5 4f9 8f6 8d0
8f5 0 8f7 4fb
0 8f8 4fd 8fb
:3 0 8fb 0 8fb
8fa 8f8 8f9 :6 0
8fd 28 :3 0 500
8ff 502 8fe 8fd
:2 0 900 504 :2 0
902 0 902 901
8af 900 :6 0 906
5 :3 0 94 :4 0
94 1 :8 0 906
507 907 6b3 906
0 909 142 6aa
0 909 50c 0
90a 50f 90c 4f
:4 0 90a :4 0 9b9
91 :3 0 1a :4 0
910 :2 0 916 90e
0 8 :3 0 51
:3 0 911 912 0
5b :3 0 913 914
0 916 514 969
5c :3 0 8 :3 0
51 :3 0 918 919
0 5b :3 0 91a
91b 0 91d 517
91f 519 91e 91d
:2 0 967 5d :3 0
8 :3 0 51 :3 0
922 923 0 5b
:3 0 924 925 0
95f 38 :3 0 39
:3 0 927 928 0
38 :3 0 49 :3 0
92a 92b 0 5e
:2 0 2 :4 0 a8
:2 0 4b :2 0 15
:2 0 51b 930 932
:3 0 51e 92c 934
929 936 935 :2 0
3b :3 0 4c :3 0
938 939 0 3d
:4 0 a9 :4 0 40
:2 0 41 :3 0 522
93d 93f :3 0 40
:2 0 61 :4 0 525
941 943 :3 0 40
:2 0 62 :4 0 528
945 947 :3 0 40
:2 0 5b :3 0 52b
949 94b :3 0 40
:2 0 63 :4 0 52e
94d 94f :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 531 952 956
535 951 958 :3 0
538 93a 95a :2 0
95c 53b 95d 937
95c 0 95e 53d
0 95f 53f 962
:3 0 962 0 962
961 95f 960 :6 0
964 2a :3 0 542
966 544 965 964
:2 0 967 546 :2 0
969 0 969 968
916 967 :6 0 9b9
1 :3 0 38 :3 0
39 :3 0 96b 96c
0 38 :3 0 49
:3 0 96e 96f 0
aa :2 0 2 :4 0
ab :2 0 4b :2 0
15 :2 0 549 974
976 :3 0 54c 970
978 96d 97a 979
:2 0 3b :3 0 4c
:3 0 97c 97d 0
3d :4 0 ac :4 0
40 :2 0 41 :3 0
550 981 983 :3 0
40 :2 0 61 :4 0
553 985 987 :3 0
40 :2 0 ad :4 0
556 989 98b :3 0
40 :2 0 45 :3 0
46 :3 0 8 :3 0
51 :3 0 990 991
0 559 98f 993
47 :4 0 55b 98e
996 55e 98d 998
:3 0 40 :2 0 ae
:4 0 561 99a 99c
:3 0 40 :2 0 43
:4 0 564 99e 9a0
:3 0 40 :2 0 a
:3 0 567 9a2 9a4
:3 0 40 :2 0 43
:4 0 56a 9a6 9a8
:3 0 56d 97e 9aa
:2 0 9ac 570 9ad
97b 9ac 0 9ae
572 0 9b9 af
:3 0 b0 :3 0 9af
9b0 0 8 :3 0
51 :3 0 9b2 9b3
0 a :3 0 68
:3 0 574 9b1 9b7
:2 0 9b9 578 a5a
8 :3 0 b1 :2 0
4 9ba 9bb 0
38 :3 0 39 :3 0
9bd 9be 0 38
:3 0 49 :3 0 9c0
9c1 0 5e :2 0
2 :4 0 b2 :2 0
4b :2 0 15 :2 0
582 9c6 9c8 :3 0
585 9c2 9ca 9bf
9cc 9cb :2 0 3b
:3 0 4c :3 0 9ce
9cf 0 3d :4 0
b3 :4 0 40 :2 0
41 :3 0 589 9d3
9d5 :3 0 58c 9d0
9d7 :2 0 9f0 3b
:3 0 4c :3 0 9d9
9da 0 3d :4 0
b4 :4 0 40 :2 0
8 :3 0 b5 :3 0
9df 9e0 0 58f
9de 9e2 :3 0 40
:2 0 ae :4 0 592
9e4 9e6 :3 0 40
:2 0 8 :3 0 b6
:3 0 9e9 9ea 0
595 9e8 9ec :3 0
598 9db 9ee :2 0
9f0 59b 9f1 9cd
9f0 0 9f2 59e
0 a02 4e :3 0
37 :3 0 8 :3 0
b5 :3 0 b7 :3 0
8 :3 0 b6 :3 0
b8 :3 0 58 :4 0
b9 1 :a 0 9fe
:2 0 a02 9f4 9fc
:2 0 7 :3 0 37
:3 0 a00 :2 0 a02
5a0 a04 5a4 a03
a02 :2 0 a58 5d
:3 0 8 :3 0 51
:3 0 a07 a08 0
5b :3 0 a09 a0a
0 a50 38 :3 0
39 :3 0 a0c a0d
0 38 :3 0 49
:3 0 a0f a10 0
5e :2 0 2 :4 0
ba :2 0 4b :2 0
15 :2 0 5a6 a15
a17 :3 0 5a9 a11
a19 a0e a1b a1a
:2 0 3b :3 0 4c
:3 0 a1d a1e 0
3d :4 0 bb :4 0
40 :2 0 41 :3 0
5ad a22 a24 :3 0
5b0 a1f a26 :2 0
a40 3b :3 0 4c
:3 0 a28 a29 0
3d :4 0 62 :4 0
40 :2 0 5b :3 0
5b3 a2d a2f :3 0
40 :2 0 63 :4 0
5b6 a31 a33 :3 0
40 :2 0 64 :3 0
65 :3 0 15 :2 0
66 :2 0 5b9 a36
a3a 5bd a35 a3c
:3 0 5c0 a2a a3e
:2 0 a40 5c3 a41
a1c a40 0 a42
5c6 0 a50 4e
:3 0 37 :3 0 b7
:3 0 8 :3 0 b6
:3 0 b8 :3 0 58
:4 0 bc 1 :a 0
a4c :2 0 a50 a44
a4a :2 0 7 :3 0
37 :3 0 a4e :2 0
a50 5c8 a53 :3 0
a53 0 a53 a52
a50 a51 :6 0 a55
1 :3 0 5cd a57
5cf a56 a55 :2 0
a58 5d1 :2 0 a5a
5d4 a5a a59 9b9
a58 :6 0 a5b :2 0
2 10 a5a a5e
:3 0 a5d a5b a5f
:8 0 
5e3
4
:3 0 1 3 1
7 2 6 a
1 14 1 12
1 1b 1 19
1 22 1 20
1 29 1 27
1 30 1 2e
1 37 1 35
1 3e 1 3c
1 45 1 43
1 4a 1 50
1 6a 1 7e
1 9e 1 a4
1 b1 1 bd
2 c0 c2 2
c5 c7 2 c9
cb 2 cd cf
2 d1 d3 1
d9 2 db dc
2 d5 de 2
e0 e2 4 b9
bf c4 e4 1
e6 1 e8 2
f2 f4 3 f0
f1 f6 2 ff
101 2 fe 103
1 105 1 107
1 120 1 126
2 128 129 1
131 2 12d 131
1 136 1 138
2 13b 13c 1
140 2 13e 140
4 14a 14b 14c
14d 1 158 1
15e 2 160 161
1 169 2 165
169 1 16e 1
170 2 17d 182
1 189 1 184
2 19c 19e 3
19a 19b 1a0 2
1a9 1ab 2 1ad
1af 2 1b1 1b3
2 1b5 1b7 2
1b9 1bb 3 1c0
1c1 1c2 2 1bd
1c4 2 1a8 1c6
1 1c8 1 1ca
2 193 1cb 1
1cf 1 18e 2
18c 1d3 2 1d9
1da 1 1de 2
1dc 1de 1 1e8
2 1e7 1e8 1
1f0 1 1f6 2
1f8 1f9 2 1e5
1fa 1 201 1
1fc 2 214 216
3 212 213 218
2 221 223 2
225 227 2 229
22b 2 22d 22f
2 231 233 3
238 239 23a 2
235 23c 2 220
23e 1 240 1
242 2 20b 243
1 247 1 206
2 204 24b 1
25a 2 259 25a
1 262 1 268
2 26a 26b 2
257 26c 1 273
1 26e 2 286
288 3 284 285
28a 2 293 295
2 297 299 2
29b 29d 2 29f
2a1 2 2a3 2a5
3 2aa 2ab 2ac
2 2a7 2ae 2
292 2b0 1 2b2
1 2b4 2 27d
2b5 1 2b9 1
278 2 276 2bd
2 24e 2c0 1
2c3 1 2cc 2
2cb 2cc 1 2d4
1 2da 2 2dc
2dd 2 2c9 2de
1 2e5 1 2e0
2 2f8 2fa 3
2f6 2f7 2fc 2
305 307 2 309
30b 2 30d 30f
2 311 313 2
315 317 3 31c
31d 31e 2 319
320 2 304 322
1 324 1 326
2 2ef 327 1
32b 1 2ea 2
2e8 32f 1 33a
2 336 33a 1
346 2 345 346
1 34e 1 354
2 356 357 2
343 358 1 35f
1 35a 2 372
374 3 370 371
376 2 37f 381
2 383 385 2
387 389 2 38b
38d 2 38f 391
3 396 397 398
2 393 39a 2
37e 39c 1 39e
1 3a0 2 369
3a1 1 3a5 1
364 2 362 3a9
3 3af 3b0 3b1
1 3b5 2 3b3
3b5 2 3bd 3c2
1 3c9 1 3c4
2 3dc 3de 3
3da 3db 3e0 2
3e9 3eb 2 3ed
3ef 2 3f1 3f3
2 3f5 3f7 2
3f9 3fb 3 400
401 402 2 3fd
404 2 3e8 406
1 408 1 40a
2 3d3 40b 1
40f 1 3ce 2
3cc 413 1 416
2 41e 423 1
42a 1 425 2
43d 43f 3 43b
43c 441 2 44a
44c 2 44e 450
2 452 454 2
456 458 2 45a
45c 3 461 462
463 2 45e 465
2 449 467 1
469 1 46b 2
434 46c 1 470
1 42f 2 42d
474 1 477 2
47a 47b 1 489
2 488 489 1
491 1 497 2
499 49a 2 486
49b 1 4a2 1
49d 2 4b5 4b7
3 4b3 4b4 4b9
2 4c2 4c4 2
4c6 4c8 2 4ca
4cc 2 4ce 4d0
2 4d2 4d4 3
4d9 4da 4db 2
4d6 4dd 2 4c1
4df 1 4e1 1
4e3 2 4ac 4e4
1 4e8 1 4a7
2 4a5 4ec 3
3ac 47c 4ef 1
4fc 2 4fb 4fc
1 504 1 50a
2 50c 50d 2
4f9 50e 1 515
1 510 2 528
52a 3 526 527
52c 2 535 537
2 539 53b 2
53d 53f 2 541
543 2 545 547
3 54c 54d 54e
2 549 550 2
534 552 1 554
1 556 2 51f
557 1 55b 1
51a 2 518 55f
1 562 2 565
566 1 56e 2
56d 56e 1 576
1 57c 2 57e
57f 2 56b 580
1 587 1 582
2 59a 59c 3
598 599 59e 2
5a7 5a9 2 5ab
5ad 2 5af 5b1
2 5b3 5b5 2
5b7 5b9 3 5be
5bf 5c0 2 5bb
5c2 2 5a6 5c4
1 5c6 1 5c8
2 591 5c9 1
5cd 1 58c 2
58a 5d1 1 5de
2 5dd 5de 1
5e6 1 5ec 2
5ee 5ef 2 5db
5f0 1 5f7 1
5f2 2 60a 60c
3 608 609 60e
2 617 619 2
61b 61d 2 61f
621 2 623 625
2 627 629 3
62e 62f 630 2
62b 632 2 616
634 1 636 1
638 2 601 639
1 63d 1 5fc
2 5fa 641 a
14e 162 171 174
1d6 2c4 332 567
5d4 644 2 64b
651 1 658 1
653 2 66b 66d
3 669 66a 66f
2 678 67a 2
67c 67e 2 680
682 2 684 686
2 688 68a 3
68f 690 691 2
68c 693 2 677
695 1 697 1
699 2 662 69a
1 69e 1 65d
2 65b 6a2 4
145 648 6a5 6a8
2 6ac 6ad 1
6b1 2 6af 6b1
4 6bb 6bc 6bd
6be 1 6c9 1
6cf 2 6d1 6d2
1 6da 2 6d6
6da 1 6df 1
6e1 3 6e4 6e5
6e6 1 6ea 2
6e8 6ea 2 6f2
6f7 1 6fe 1
6f9 2 711 713
3 70f 710 715
2 71e 720 2
722 724 2 726
728 2 72a 72c
2 72e 730 3
735 736 737 2
732 739 2 71d
73b 1 73d 1
73f 2 708 740
1 744 1 703
2 701 748 1
74b 2 753 758
1 75f 1 75a
2 772 774 3
770 771 776 2
77f 781 2 783
785 2 787 789
2 78b 78d 2
78f 791 3 796
797 798 2 793
79a 2 77e 79c
1 79e 1 7a0
2 769 7a1 1
7a5 1 764 2
762 7a9 1 7ac
2 7af 7b0 1
7c1 2 7c0 7c1
1 7c9 1 7cf
2 7d1 7d2 2
7be 7d3 1 7da
1 7d5 2 7ed
7ef 3 7eb 7ec
7f1 2 7fa 7fc
2 7fe 800 2
802 804 2 806
808 2 80a 80c
3 811 812 813
2 80e 815 2
7f9 817 1 819
1 81b 2 7e4
81c 1 820 1
7df 2 7dd 824
1 83b 2 83a
83b 1 843 1
849 2 84b 84c
2 838 84d 1
854 1 84f 2
867 869 3 865
866 86b 2 874
876 2 878 87a
2 87c 87e 2
880 882 2 884
886 3 88b 88c
88d 2 888 88f
2 873 891 1
893 1 895 2
85e 896 1 89a
1 859 2 857
89e 6 6bf 6d3
6e2 7b1 827 8a1
2 8a8 8ae 1
8b5 1 8b0 2
8c8 8ca 3 8c6
8c7 8cc 2 8d5
8d7 2 8d9 8db
2 8dd 8df 2
8e1 8e3 2 8e5
8e7 3 8ec 8ed
8ee 2 8e9 8f0
2 8d4 8f2 1
8f4 1 8f6 2
8bf 8f7 1 8fb
1 8ba 2 8b8
8ff 4 6b6 8a5
902 905 2 908
907 4 117 12a
139 909 2 90f
915 1 91c 1
917 2 92f 931
3 92d 92e 933
2 93c 93e 2
940 942 2 944
946 2 948 94a
2 94c 94e 3
953 954 955 2
950 957 2 93b
959 1 95b 1
95d 2 926 95e
1 962 1 921
2 91f 966 2
973 975 3 971
972 977 2 980
982 2 984 986
2 988 98a 1
992 2 994 995
2 98c 997 2
999 99b 2 99d
99f 2 9a1 9a3
2 9a5 9a7 2
97f 9a9 1 9ab
1 9ad 3 9b4
9b5 9b6 9 e9
108 10b 10e 111
90c 969 9ae 9b8
2 9c5 9c7 3
9c3 9c4 9c9 2
9d2 9d4 2 9d1
9d6 2 9dd 9e1
2 9e3 9e5 2
9e7 9eb 2 9dc
9ed 2 9d8 9ef
1 9f1 3 9f2
9fd a01 1 9bc
2 a14 a16 3
a12 a13 a18 2
a21 a23 2 a20
a25 2 a2c a2e
2 a30 a32 3
a37 a38 a39 2
a34 a3b 2 a2b
a3d 2 a27 a3f
1 a41 4 a0b
a42 a4b a4f 1
a53 1 a06 2
a04 a57 e 17
1e 25 2c 33
3a 41 48 4e
54 6b 7f 9f
a9 
1
4
0 
a5e
0
1
50
2c
11
0 1 1 1 1 5 6 7
6 9 6 b 6 d 6 f
6 11 6 13 6 15 6 17
6 19 6 1b 5 1d 5 1f
20 1f 22 1f 24 1f 26 5
28 1 2a 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3 1 0
57 1 2
2e 1 0
71 1 3
85 1 4
43 1 0
4a 1 0
35 1 0
50 1 0
27 1 0
12 1 0
3c 1 0
20 1 0
2 0 1
7 1 0
19 1 0
a4 1 0
0

/
SHOW ERRORS FUNCTION SP_TEST_ASSIGN;
ALTER FUNCTION SP_TEST_ASSIGN COMPILE DEBUG;
/*********************************************************************************************************************************************/
Prompt == FUNCTION FC_MIGRATION ==
CREATE OR REPLACE FUNCTION FC_MIGRATION wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
83
2 :e:
1FUNCTION:
1FC_MIGRATION:
1H_PROJECT_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1RETURN:
1PLS_INTEGER:
1H_LEVEL:
10:
1H_ROLLUP_BITS:
1H_TEMP_SC_STATE:
1CURSOR:
1C01:
1PROJECT_ID:
1LEVEL_ID:
1TMT_WBS:
1TYPE_ID:
1PMO_CNST:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1RANK:
1SELECT PROJECT_ID, LEVEL_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (pmo_cnst+
1.SC_PROJECT,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PROJ_TYPE+
12,pmo_cnst.SC_PROJ_TYPE3):n         ORDER BY RANK DESC:
1C02:
1C03:
1ELEMENT_ID:
1SELECT LEVEL_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (pmo_cnst.SC_PROJECT,+
1pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PROJ_TYPE2,pmo_cnst.S+
1C_PROJ_TYPE3) AND ELEMENT_ID = h_project_id:n         ORDER BY RANK DESC:
1C04:
1SELECT /*PROJECT_ID,*/ LEVEL_ID:n         FROM TMT_WBS:n         WHERE TYPE_I+
1D IN (pmo_cnst.SC_PROJECT,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cns+
1t.SC_PROJ_TYPE2,pmo_cnst.SC_PROJ_TYPE3) AND ELEMENT_ID = h_project_id:n      +
1   ORDER BY RANK DESC:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_MIGRATION(:
1':
1);:
1CHECK_TRACE:
11:
137:
1+:
1FPUT:
1               ENTER:: FC_MIGRATION(38) :: cplan.sql(22918) :: :
1IS NULL:
1OPEN:
1LOOP:
1FOUND:
1PMO_DB2M:
1SC_STATE:
1100:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
13269638:
1TASK_ASSIGNMENTS:
1ROLLUP_BITS:
1ACTUAL_START:
1SC_SET_ALL_BITS:
1UPDATE TASK_ASSIGNMENTS SET ROLLUP_BITS = CASE WHEN ACTUAL_START IS NuLL THEN+
1 pmo_cnst.SC_SET_ALL_BITS ELSE h_rollup_bits END:n            WHERE PROJECT_I+
1D = h_project_id:
1TRUE:
1=:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
174:
1           EXCEPTION:: FC_MIGRATION(75) :: cplan.sql(22955) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1PMO_FUNC:
1BIT_OR:
1SC_PLANNED_BIT:
1SC_SCHED_BIT:
1PLANNED_FINISH:
1SCHED_FINISH:
1ACTUAL_FINISH:
1FORECAST_FINISH:
1FORECAST_START:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1UPDATE TMT_WBS SET ROLLUP_BITS = pmo_cnst.SC_SET_ALL_BITS, PLANNED_FINISH = N+
1uLL, SCHED_FINISH = NuLL,:n            ACTUAL_FINISH = NuLL,:n            FOR+
1ECAST_FINISH = CASE WHEN FORECAST_START IS NuLL THEN FORECAST_FINISH ELSE NuL+
1L END:n            WHERE PROJECT_ID = h_project_id AND (PLANNED_EFFORT + SCHE+
1D_EFFORT > 0):
198:
1           EXCEPTION:: FC_MIGRATION(99) :: cplan.sql(22979) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = h_rollup_bits, PLANNED_FINISH = NuLL, SCHED_+
1FINISH = NuLL:n            WHERE PROJECT_ID = h_project_id AND ((PLANNED_EFFO+
1RT + SCHED_EFFORT) = 0):
1118:
1           EXCEPTION:: FC_MIGRATION(119) :: cplan.sql(22999) :: :
1TMT_CRI:
1UPDATE TMT_CRI SET ROLLUP_BITS = pmo_cnst.SC_SET_ALL_BITS, PLANNED_FINISH = N+
1uLL, SCHED_FINISH = NuLL:n            WHERE PROJECT_ID = h_project_id AND TYP+
1E_ID <> 14:
1138:
1           EXCEPTION:: FC_MIGRATION(139) :: cplan.sql(23019) :: :
1COALESCE:
1FC_ROLLUP:
1COMMIT:
1CLOSE:
1160:
1           EXCEPTION:: FC_MIGRATION(161) :: cplan.sql(23041) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = pmo_cnst.SC_SET_ALL_BITS, ACTUAL_FINISH = Nu+
1LL,:n            FORECAST_FINISH = CASE WHEN FORECAST_START IS NuLL THEN FORE+
1CAST_FINISH ELSE NuLL END:n            WHERE PROJECT_ID = h_project_id AND ((+
1PLANNED_EFFORT + SCHED_EFFORT) = 0):
1197:
1           EXCEPTION:: FC_MIGRATION(198) :: cplan.sql(23078) :: :
1219:
1           EXCEPTION:: FC_MIGRATION(220) :: cplan.sql(23100) :: :
1UPDATE TASK_ASSIGNMENTS SET ROLLUP_BITS = pmo_cnst.SC_SET_ALL_BITS WHERE PROJ+
1ECT_ID = h_project_id:
1256:
1           EXCEPTION:: FC_MIGRATION(257) :: cplan.sql(23137) :: :
1278:
1           EXCEPTION:: FC_MIGRATION(279) :: cplan.sql(23159) :: :
1298:
1           EXCEPTION:: FC_MIGRATION(299) :: cplan.sql(23179) :: :
1318:
1           EXCEPTION:: FC_MIGRATION(319) :: cplan.sql(23199) :: :
1340:
1           EXCEPTION:: FC_MIGRATION(341) :: cplan.sql(23221) :: :
1377:
1           EXCEPTION:: FC_MIGRATION(378) :: cplan.sql(23258) :: :
1399:
1           EXCEPTION:: FC_MIGRATION(400) :: cplan.sql(23280) :: :
1406:
1                EXIT:: FC_MIGRATION(407) :: cplan.sql(23287) :: :
1STATE:: :
0

0
0
853
2
0 a0 8d 90 :3 a0 b0 3f b4
:2 a0 2c 6a a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a0 f4 b4
bf c8 :f a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :f a0 12a
bd b7 11 a4 b1 a0 f4 b4
bf c8 :10 a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :10 a0 12a
bd b7 11 a4 b1 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
5a :2 a0 e9 dd b3 :4 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c a0 51 d
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 6b :2 a0 6b :2 a0 6b a5 b
d :e a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :3 a0 a5 b d a0 12a b7
19 3c b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 e9 dd b3 :4 a0 e9 d3 5
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
2b b7 19 3c :c a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :3 a0 a5 b d
a0 12a b7 19 3c b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 a0 e9 dd b3
:3 a0 e9 d3 :2 a0 f :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a a0 2b b7 19 3c :3 a0
6b :2 a0 6b :2 a0 6b a5 b d
:6 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:e a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 a5 b d a0 12a b7 19
3c b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
e9 dd b3 :3 a0 e9 d3 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 2b b7
19 3c :c a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :3 a0 a5 b d a0 12a
b7 19 3c b7 a0 47 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
a4 b1 11 68 4f 1d 17 b5 
853
2
0 3 7 2b 1f 23 27 1e
32 1b 37 3b 3f 43 5f 4b
4f 57 5a 4a 7b 6a 6e 47
76 69 97 86 8a 66 92 85
9e a2 82 b3 b6 ba be c2
c6 ca ce d2 d6 da de e2
e6 ea ee f2 f6 102 107 109
115 119 11b 11f 130 131 134 138
13c 140 144 148 14c 150 154 158
15c 160 164 168 16c 170 174 180
185 187 193 197 199 19d 1ae 1af
1b2 1b6 1ba 1be 1c2 1c6 1ca 1ce
1d2 1d6 1da 1de 1e2 1e6 1ea 1ee
1f2 1f6 202 207 209 215 219 21b
21f 230 231 234 238 23c 240 244
248 24c 250 254 258 25c 260 264
268 26c 270 274 278 284 289 28b
297 29b 29d 2a1 2a5 2a8 2ac 2b0
2b3 2b8 2b9 1 2bb 2c0 2c4 2c8
2cb 2d0 2d4 2d8 2db 2e0 2e1 2e3
2e8 2eb 2ef 2f0 2f5 2fa 2fd 302
303 308 30b 30f 310 315 318 31d
31e 323 326 32b 32c 331 332 337
339 33d 340 344 348 34b 34f 353
356 359 35e 361 364 367 368 36d
36e 1 370 375 379 37d 380 385
38a 38d 391 392 397 398 39d 39f
3a3 3a6 3aa 3ad 3ae 3b3 3b6 3ba
3be 3c3 3c7 3c8 3cc 3d0 3d4 3d8
3dd 3e2 3e6 3ea 3ee 3f3 3f7 3fb
3fe 401 405 407 40b 40f 412 415
419 41b 41f 423 426 42a 42e 431
435 438 43c 43f 440 445 448 44c
452 454 458 45b 45f 462 466 46a
46e 472 476 47a 47e 482 486 492
496 49b 49f 4a2 4a3 4a8 4ac 4b0
4b3 4b6 4ba 4bc 4c0 4c4 4c7 4ca
4ce 4d0 4d4 4d8 4db 4dd 4e1 4e5
4e9 4ec 4f0 4f4 4f6 4f7 4fc 1
500 504 508 50b 50f 513 517 51b
51e 522 526 529 52c 531 534 537
53a 53b 540 541 1 543 548 54c
550 553 558 55d 560 564 565 56a
56d 572 573 578 57b 580 581 586
589 58d 58e 593 596 59b 59c 5a1
5a4 5a8 5ac 5af 5b2 5b3 5b5 5b6
5bb 5bc 5c1 5c3 5c7 5ca 5cc 5d0
5d2 5de 5e0 5e2 5e3 5e8 5ec 5ee
5fa 5fc 600 604 608 60b 60f 613
616 61a 61e 621 622 624 628 62c
630 634 638 63c 640 644 648 64c
650 654 658 65c 660 66c 670 675
679 67c 67d 682 686 68a 68d 690
694 696 69a 69e 6a1 6a4 6a8 6aa
6ae 6b2 6b5 6b7 6bb 6bf 6c3 6c6
6ca 6ce 6d0 6d1 6d6 1 6da 6de
6e2 6e5 6e9 6ed 6f1 6f5 6f8 6fc
700 703 706 70b 70e 711 714 715
71a 71b 1 71d 722 726 72a 72d
732 737 73a 73e 73f 744 747 74c
74d 752 755 75a 75b 760 763 767
768 76d 770 775 776 77b 77e 782
786 789 78c 78d 78f 790 795 796
79b 79d 7a1 7a4 7a6 7aa 7ac 7b8
7ba 7bc 7bd 7c2 7c6 7c8 7d4 7d6
7da 7de 7e2 7e6 7ea 7ee 7f2 7f6
7fa 806 80a 80f 813 816 817 81c
820 824 827 82a 82e 830 834 838
83b 83e 842 844 848 84c 84f 851
855 859 85d 860 864 868 86a 86b
870 1 874 878 87c 87f 883 887
88b 88f 892 896 89a 89d 8a0 8a5
8a8 8ab 8ae 8af 8b4 8b5 1 8b7
8bc 8c0 8c4 8c7 8cc 8d1 8d4 8d8
8d9 8de 8e1 8e6 8e7 8ec 8ef 8f4
8f5 8fa 8fd 901 902 907 90a 90f
910 915 918 91c 920 923 926 927
929 92a 92f 930 935 937 93b 93e
940 944 946 952 954 956 957 95c
960 962 96e 970 974 978 97c 980
984 988 98c 990 994 9a0 9a4 9a9
9ad 9b0 9b1 9b6 9ba 9be 9c1 9c4
9c8 9ca 9ce 9d2 9d5 9d8 9dc 9de
9e2 9e6 9e9 9eb 9ef 9f3 9f7 9fa
9fe a02 a04 a05 a0a 1 a0e a12
a16 a19 a1d a21 a25 a29 a2c a30
a34 a37 a3a a3f a42 a45 a48 a49
a4e a4f 1 a51 a56 a5a a5e a61
a66 a6b a6e a72 a73 a78 a7b a80
a81 a86 a89 a8e a8f a94 a97 a9b
a9c aa1 aa4 aa9 aaa aaf ab2 ab6
aba abd ac0 ac1 ac3 ac4 ac9 aca
acf ad1 ad5 ad8 ada ade ae0 aec
aee af0 af1 af6 afa afc b08 b0a
b0e b12 b15 b16 b18 b1b b1e b1f
b24 b28 b2c b30 b31 b33 b37 b3b
b47 b49 b4d b50 b52 b56 b5d b61
b65 b6a b6c b70 b74 b77 b7b b7f
b81 b85 b89 b8d b90 b94 b98 b9a
b9b ba0 1 ba4 ba8 bac baf bb3
bb7 bbb bbf bc2 bc6 bca bcd bd0
bd5 bd8 bdb bde bdf be4 be5 1
be7 bec bf0 bf4 bf7 bfc c01 c04
c08 c09 c0e c11 c16 c17 c1c c1f
c24 c25 c2a c2d c31 c32 c37 c3a
c3f c40 c45 c48 c4c c50 c53 c56
c57 c59 c5a c5f c60 c65 c67 c6b
c6e c70 c74 c76 c82 c84 c86 c87
c8c c90 c92 c9e ca0 ca4 ca8 cad
cb1 cb2 cb6 cba cbe cc2 cc7 ccc
cd0 cd4 cd8 cdd ce1 ce5 ce8 ceb
cef cf1 cf5 cf9 cfc cff d03 d05
d09 d0d d10 d14 d18 d1b d1f d22
d26 d29 d2a d2f d32 d36 d3c d3e
d42 d45 d49 d4d d51 d55 d59 d5d
d61 d65 d69 d6d d71 d75 d81 d85
d8a d8e d91 d92 d97 d9b d9f da2
da5 da9 dab daf db3 db6 db9 dbd
dbf dc3 dc7 dca dcc dd0 dd4 dd8
ddb ddf de3 de5 de6 deb 1 def
df3 df7 dfa dfe e02 e06 e0a e0d
e11 e15 e18 e1b e20 e23 e26 e29
e2a e2f e30 1 e32 e37 e3b e3f
e42 e47 e4c e4f e53 e54 e59 e5c
e61 e62 e67 e6a e6f e70 e75 e78
e7c e7d e82 e85 e8a e8b e90 e93
e97 e9b e9e ea1 ea2 ea4 ea5 eaa
eab eb0 eb2 eb6 eb9 ebb ebf ec1
ecd ecf ed1 ed2 ed7 edb edd ee9
eeb eef ef3 ef6 ef7 ef9 efc eff
f00 f05 f09 f0d f11 f12 f14 f18
f1c f28 f2a f2e f31 f33 f37 f3e
f42 f46 f4b f4d f51 f55 f58 f5c
f60 f62 f66 f6a f6e f71 f75 f79
f7b f7c f81 1 f85 f89 f8d f90
f94 f98 f9c fa0 fa3 fa7 fab fae
fb1 fb6 fb9 fbc fbf fc0 fc5 fc6
1 fc8 fcd fd1 fd5 fd8 fdd fe2
fe5 fe9 fea fef ff2 ff7 ff8 ffd
1000 1005 1006 100b 100e 1012 1013 1018
101b 1020 1021 1026 1029 102d 1031 1034
1037 1038 103a 103b 1040 1041 1046 1048
104c 104f 1051 1055 1057 1063 1065 1067
1068 106d 1071 1073 107f 1081 1083 1087
108b 1090 1094 1095 1099 109d 10a1 10a6
10ab 10af 10b3 10b8 10bc 10c0 10c3 10c6
10ca 10cc 10d0 10d4 10d7 10da 10de 10e0
10e4 10e8 10eb 10ef 10f3 10f6 10fa 10fd
1101 1104 1105 110a 110d 1111 1117 1119
111d 1120 1124 1128 112c 112f 1133 1137
113a 113e 1142 1145 1146 1148 114c 1150
1154 1158 115c 1160 1164 1170 1174 1179
117d 1180 1181 1186 118a 118e 1191 1194
1198 119a 119e 11a2 11a5 11a8 11ac 11ae
11b2 11b6 11b9 11bb 11bf 11c3 11c7 11ca
11ce 11d2 11d4 11d5 11da 1 11de 11e2
11e6 11e9 11ed 11f1 11f5 11f9 11fc 1200
1204 1207 120a 120f 1212 1215 1218 1219
121e 121f 1 1221 1226 122a 122e 1231
1236 123b 123e 1242 1243 1248 124b 1250
1251 1256 1259 125e 125f 1264 1267 126b
126c 1271 1274 1279 127a 127f 1282 1286
128a 128d 1290 1291 1293 1294 1299 129a
129f 12a1 12a5 12a8 12aa 12ae 12b0 12bc
12be 12c0 12c1 12c6 12ca 12cc 12d8 12da
12de 12e2 12e6 12ea 12ee 12f2 12f6 12fa
12fe 1302 1306 130a 130e 1312 131e 1322
1327 132b 132e 132f 1334 1338 133c 133f
1342 1346 1348 134c 1350 1353 1356 135a
135c 1360 1364 1367 1369 136d 1371 1375
1378 137c 1380 1382 1383 1388 1 138c
1390 1394 1397 139b 139f 13a3 13a7 13aa
13ae 13b2 13b5 13b8 13bd 13c0 13c3 13c6
13c7 13cc 13cd 1 13cf 13d4 13d8 13dc
13df 13e4 13e9 13ec 13f0 13f1 13f6 13f9
13fe 13ff 1404 1407 140c 140d 1412 1415
1419 141a 141f 1422 1427 1428 142d 1430
1434 1438 143b 143e 143f 1441 1442 1447
1448 144d 144f 1453 1456 1458 145c 145e
146a 146c 146e 146f 1474 1478 147a 1486
1488 148c 1490 1494 1498 149c 14a0 14a4
14a8 14ac 14b8 14bc 14c1 14c5 14c8 14c9
14ce 14d2 14d6 14d9 14dc 14e0 14e2 14e6
14ea 14ed 14f0 14f4 14f6 14fa 14fe 1501
1503 1507 150b 150f 1512 1516 151a 151c
151d 1522 1 1526 152a 152e 1531 1535
1539 153d 1541 1544 1548 154c 154f 1552
1557 155a 155d 1560 1561 1566 1567 1
1569 156e 1572 1576 1579 157e 1583 1586
158a 158b 1590 1593 1598 1599 159e 15a1
15a6 15a7 15ac 15af 15b3 15b4 15b9 15bc
15c1 15c2 15c7 15ca 15ce 15d2 15d5 15d8
15d9 15db 15dc 15e1 15e2 15e7 15e9 15ed
15f0 15f2 15f6 15f8 1604 1606 1608 1609
160e 1612 1614 1620 1622 1626 162a 162e
1632 1636 163a 163e 1642 1646 1652 1656
165b 165f 1662 1663 1668 166c 1670 1673
1676 167a 167c 1680 1684 1687 168a 168e
1690 1694 1698 169b 169d 16a1 16a5 16a9
16ac 16b0 16b4 16b6 16b7 16bc 1 16c0
16c4 16c8 16cb 16cf 16d3 16d7 16db 16de
16e2 16e6 16e9 16ec 16f1 16f4 16f7 16fa
16fb 1700 1701 1 1703 1708 170c 1710
1713 1718 171d 1720 1724 1725 172a 172d
1732 1733 1738 173b 1740 1741 1746 1749
174d 174e 1753 1756 175b 175c 1761 1764
1768 176c 176f 1772 1773 1775 1776 177b
177c 1781 1783 1787 178a 178c 1790 1792
179e 17a0 17a2 17a3 17a8 17ac 17ae 17ba
17bc 17c0 17c4 17c7 17c8 17ca 17cd 17d0
17d1 17d6 17da 17de 17e2 17e3 17e5 17e9
17ed 17f9 17fb 17ff 1802 1804 1808 180f
1813 1817 181c 181e 1822 1826 1829 182d
1831 1833 1837 183b 183f 1842 1846 184a
184c 184d 1852 1 1856 185a 185e 1861
1865 1869 186d 1871 1874 1878 187c 187f
1882 1887 188a 188d 1890 1891 1896 1897
1 1899 189e 18a2 18a6 18a9 18ae 18b3
18b6 18ba 18bb 18c0 18c3 18c8 18c9 18ce
18d1 18d6 18d7 18dc 18df 18e3 18e4 18e9
18ec 18f1 18f2 18f7 18fa 18fe 1902 1905
1908 1909 190b 190c 1911 1912 1917 1919
191d 1920 1922 1926 1928 1934 1936 1938
1939 193e 1942 1944 1950 1952 1956 195a
195f 1963 1964 1968 196c 1970 1975 197a
197e 1982 1987 198b 198f 1992 1995 1999
199b 199f 19a3 19a6 19a9 19ad 19af 19b3
19b7 19ba 19be 19c2 19c5 19c9 19cc 19d0
19d3 19d4 19d9 19dc 19e0 19e6 19e8 19ec
19ef 19f3 19f7 19fb 19ff 1a03 1a07 1a0b
1a0f 1a13 1a17 1a1b 1a1f 1a2b 1a2f 1a34
1a38 1a3b 1a3c 1a41 1a45 1a49 1a4c 1a4f
1a53 1a55 1a59 1a5d 1a60 1a63 1a67 1a69
1a6d 1a71 1a74 1a76 1a7a 1a7e 1a82 1a85
1a89 1a8d 1a8f 1a90 1a95 1 1a99 1a9d
1aa1 1aa4 1aa8 1aac 1ab0 1ab4 1ab7 1abb
1abf 1ac2 1ac5 1aca 1acd 1ad0 1ad3 1ad4
1ad9 1ada 1 1adc 1ae1 1ae5 1ae9 1aec
1af1 1af6 1af9 1afd 1afe 1b03 1b06 1b0b
1b0c 1b11 1b14 1b19 1b1a 1b1f 1b22 1b26
1b27 1b2c 1b2f 1b34 1b35 1b3a 1b3d 1b41
1b45 1b48 1b4b 1b4c 1b4e 1b4f 1b54 1b55
1b5a 1b5c 1b60 1b63 1b65 1b69 1b6b 1b77
1b79 1b7b 1b7c 1b81 1b85 1b87 1b93 1b95
1b99 1b9d 1ba0 1ba1 1ba3 1ba6 1ba9 1baa
1baf 1bb3 1bb7 1bbb 1bbc 1bbe 1bc2 1bc6
1bd2 1bd4 1bd8 1bdb 1bdd 1be1 1be8 1bec
1bf0 1bf5 1bf7 1bfb 1bff 1c02 1c06 1c0a
1c0c 1c10 1c14 1c18 1c1b 1c1f 1c23 1c25
1c26 1c2b 1 1c2f 1c33 1c37 1c3a 1c3e
1c42 1c46 1c4a 1c4d 1c51 1c55 1c58 1c5b
1c60 1c63 1c66 1c69 1c6a 1c6f 1c70 1
1c72 1c77 1c7b 1c7f 1c82 1c87 1c8c 1c8f
1c93 1c94 1c99 1c9c 1ca1 1ca2 1ca7 1caa
1caf 1cb0 1cb5 1cb8 1cbc 1cbd 1cc2 1cc5
1cca 1ccb 1cd0 1cd3 1cd7 1cdb 1cde 1ce1
1ce2 1ce4 1ce5 1cea 1ceb 1cf0 1cf2 1cf6
1cf9 1cfb 1cff 1d01 1d0d 1d0f 1d11 1d12
1d17 1d1b 1d1d 1d29 1d2b 1d2d 1d31 1d35
1d38 1d3c 1d40 1d43 1d47 1d4b 1d4e 1d51
1d56 1d59 1d5c 1d5f 1d60 1d65 1d66 1
1d68 1d6d 1d71 1d75 1d78 1d7d 1d82 1d85
1d89 1d8a 1d8f 1d92 1d97 1d98 1d9d 1da0
1da5 1da6 1dab 1dae 1db2 1db6 1db9 1dba
1dbf 1dc0 1dc5 1dc7 1dcb 1dce 1dd2 1dd6
1dda 1ddd 1de1 1de3 1de7 1de9 1df5 1df9
1dfb 1dfc 1e05 
853
2
0 1 a 6 16 1a 21 :2 6
1 3 a :2 1 4 :2 c 1b c
:2 4 :2 12 21 12 :2 4 :2 14 23 14
4 7 e 0 :2 7 11 1d 2b
10 1c 25 30 39 45 4e 5c
65 73 7c 13 a :6 7 e 0
:2 7 11 1d 2b 10 1c 25 30
39 45 4e 5c 65 73 7c 13
a :6 7 e 0 :2 7 11 1f 10
1c 25 30 39 45 4e 5c 65
73 7c 8f 9c 13 a :6 7 e
0 :2 7 21 f 10 1c 25 30
39 45 4e 5c 65 73 7c 8f
9c 13 a :6 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
54 5a 5d :2 54 6b 81 8 :2 6b
d 10 :2 6b 1d 20 :2 6b 25 28
:2 6b :2 7 4a :2 4 7 :2 11 23 :2 2d
39 3c 4c 4e 4f :2 4c :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :2 7 52
:2 4 :4 8 :2 7 c :4 7 10 19 27
:3 a d 11 :2 d :2 16 22 d 17
d :2 16 22 d :4 a e :2 17 23
20 :2 2c :2 20 :3 d 3c :3 a 1b a
14 29 41 5b 64 79 13 20
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5b 5c :2 59 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8f 92 :2 2a 9a
9d :2 2a a9 ac b3 bc bf :2 ac
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 7 a 1b :2 24 2b :2 34 44 :2 4d
:2 1b a 14 20 2e 37 48 5f
:2 d 29 45 13 20 32 43 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 59 5b 5c :2 59 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8f 92 :2 2a 9a 9d
:2 2a a9 ac b3 bc bf :2 ac :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 7
14 20 2e 3d 54 13 20 33
44 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5c 5d :2 59 :2 2f
:3 13 :2 19 1e 2a 6a 6d :2 2a 7a
7d :2 2a 81 84 :2 2a 90 93 :2 2a
9b 9e :2 2a aa ad b4 bd c0
:2 ad :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :3 7 14 20 2e 37 48 5f
13 20 31 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 59 5c 5d
:2 59 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 90
93 :2 2a 9b 9e :2 2a aa ad b4
bd c0 :2 ad :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :3 7 d 16 1f :2 d
22 24 :2 22 d 20 2a :2 20 :3 d
26 :2 a 7 b 1e a 10 :3 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 1e 7 c :4 7
10 19 27 :3 a d 11 :2 d :2 16
22 d 17 d :2 16 22 d :4 a
e :2 17 23 20 :2 2c :2 20 :3 d 3c
:2 a 14 20 2e 37 48 d 29
45 13 20 33 44 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 59
5c 5d :2 59 :2 2f :3 13 :2 19 1e 2a
6a 6d :2 2a 7a 7d :2 2a 81 84
:2 2a 90 93 :2 2a 9b 9e :2 2a aa
ad b4 bd c0 :2 ad :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 7 d 16
1f :2 d 22 24 :2 22 d 20 2a
:2 20 :3 d 26 :2 a 7 b 1e a
10 :3 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 77 7a :2 27 7e
81 :2 27 8d 90 :2 27 98 9b :2 27
a7 aa b1 ba bd :2 aa :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :4 1e 7
c :4 7 10 19 :2 a d 11 :2 d
:2 16 22 d 17 d :2 16 22 d
:4 a e :2 17 23 20 :2 2c :2 20 :3 d
3c :3 a 1b :2 24 2b :2 34 44 :2 4d
:2 1b a 14 29 37 40 56 63
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a 7a 7d
:2 2a 81 84 :2 2a 90 93 :2 2a 9b
9e :2 2a aa ad b4 bd c0 :2 ad
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 7 14 20 2e 37 48 5f :2 d
29 45 13 20 32 43 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
59 5c 5d :2 59 :2 2f :3 13 :2 19 1e
2a 6a 6d :2 2a 7a 7d :2 2a 81
84 :2 2a 90 93 :2 2a 9b 9e :2 2a
aa ad b4 bd c0 :2 ad :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :3 7 14
20 2e 3d 54 13 20 33 44
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a 7a 7d
:2 2a 81 84 :2 2a 90 93 :2 2a 9b
9e :2 2a aa ad b4 bd c0 :2 ad
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 7 14 20 2e 37 48 5f 13
20 31 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 59 5c 5d :2 59
:2 2f :3 13 :2 19 1e 2a 6a 6d :2 2a
7a 7d :2 2a 81 84 :2 2a 90 93
:2 2a 9b 9e :2 2a aa ad b4 bd
c0 :2 ad :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :3 7 d 16 1f :2 d 22
24 :2 22 d 20 2a :2 20 :3 d 26
:2 a 7 b 4 a 10 :3 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 77 7a :2 27 7e 81 :2 27 8d
90 :2 27 98 9b :2 27 a7 aa b1
ba bd :2 aa :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 4 7 c :4 7 10
19 :2 a d 11 :2 d :2 16 22 d
17 d :2 16 22 d :4 a e :2 17
23 20 :2 2c :2 20 :3 d 3c :2 a 14
20 2e 37 48 d 29 45 13
20 33 44 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 59 5c 5d
:2 59 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 90
93 :2 2a 9b 9e :2 2a aa ad b4
bd c0 :2 ad :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :3 7 d 16 1f :2 d
22 24 :2 22 d 20 2a :2 20 :3 d
26 :2 a 7 b 4 a 10 :3 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :7 4 7 :2 11 23
:2 2d 39 3c 4c 4f 50 :2 4c :2 23
:3 7 :2 d 12 1e 5e 61 :2 1e 6e
71 :2 1e 75 78 :2 1e 82 85 :2 8e
:2 1e :2 7 53 :3 4 b :2 14 4 :9 1

853
4
0 :2 1 :6 3 2
:2 4 :2 1 :6 6 :6 7
:6 8 :2 a 0 :2 a
:3 b :b c d b
:5 a :2 f 0 :2 f
:3 10 :b 11 12 10
:5 f :2 14 0 :2 14
:2 15 :d 16 17 15
:5 14 :2 19 0 :2 19
1a 1b :d 1c 1d
1a :5 19 :b 20 :11 21
22 :2 21 :2 22 :2 21
:2 22 :2 21 :2 22 :4 21
:3 20 :11 25 :b 26 :3 25
:5 29 :5 2c 2e :6 2f
:3 30 :5 31 30 :5 33
32 :3 30 :a 35 :2 36
:3 35 :3 39 :6 3d :2 3e
3d :6 3f :5 40 3f
:5 42 41 :3 3f 3c
45 :5 46 :3 45 :2 47
:5 49 :11 4a :24 4b :3 4a
:2 48 :6 47 44 :3 2e
:d 50 :6 53 54 :3 55
:4 56 53 :6 57 :5 58
57 :5 5a 59 :3 57
52 5d :5 5e :3 5d
:2 5f :5 61 :11 62 :24 63
:3 62 :2 60 :6 5f 5c
:3 2e :5 69 :4 6a 69
:6 6b :5 6c 6b :5 6e
6d :3 6b 68 71
:5 72 :3 71 :2 73 :5 75
:11 76 :24 77 :3 76 :2 74
:6 73 70 :3 2e :6 7d
:3 7e 7d :6 7f :5 80
7f :5 82 81 :3 7f
7c 85 :5 86 :3 85
:2 87 :5 89 :11 8a :24 8b
:3 8a :2 88 :6 87 84
:3 2e :9 90 :6 91 :2 93
:3 90 2e 95 29
:4 98 :5 99 97 9b
:5 9c :3 9b :2 9d :5 9f
:11 a0 :24 a1 :3 a0 :2 9e
:6 9d 9a :3 29 :5 a8
aa :6 ab :3 ac :5 ad
ac :5 af ae :3 ac
:a b2 :2 b3 :3 b2 :5 b7
:3 b8 :4 b9 b7 :6 ba
:5 bb ba :5 bd bc
:3 ba b6 c0 :5 c1
:3 c0 :2 c2 :5 c4 :11 c5
:24 c6 :3 c5 :2 c3 :6 c2
bf :3 aa :9 cb :6 cc
:2 ce :3 cb aa d0
29 :4 d3 :5 d4 d2
d6 :5 d7 :3 d6 :2 d8
:5 da :11 db :24 dc :3 db
:2 d9 :6 d8 d5 :4 29
:5 e3 e5 :4 e6 :3 e7
:5 e8 e7 :5 ea e9
:3 e7 :a ed :2 ee :3 ed
:d f1 :7 f4 :6 f5 :5 f6
f5 :5 f8 f7 :3 f5
f3 fb :5 fc :3 fb
:2 fd :5 ff :11 100 :24 101
:3 100 :2 fe :6 fd fa
:3 e5 :6 107 108 :3 109
:4 10a 107 :6 10b :5 10c
10b :5 10e 10d :3 10b
106 111 :5 112 :3 111
:2 113 :5 115 :11 116 :24 117
:3 116 :2 114 :6 113 110
:3 e5 :5 11d :4 11e 11d
:6 11f :5 120 11f :5 122
121 :3 11f 11c 125
:5 126 :3 125 :2 127 :5 129
:11 12a :24 12b :3 12a :2 128
:6 127 124 :3 e5 :6 131
:3 132 131 :6 133 :5 134
133 :5 136 135 :3 133
130 139 :5 13a :3 139
:2 13b :5 13d :11 13e :24 13f
:3 13e :2 13c :6 13b 138
:3 e5 :9 144 :6 145 :2 147
:3 144 e5 149 e0
:4 14c :5 14d 14b 14f
:5 150 :3 14f :2 151 :5 153
:11 154 :24 155 :3 154 :2 152
:6 151 14e :3 e0 :5 15c
15e :4 15f :3 160 :5 161
160 :5 163 162 :3 160
:a 166 :2 167 :3 166 :5 16b
:3 16c :4 16d 16b :6 16e
:5 16f 16e :5 171 170
:3 16e 16a 174 :5 175
:3 174 :2 176 :5 178 :11 179
:24 17a :3 179 :2 177 :6 176
173 :3 15e :9 17f :6 180
:2 182 :3 17f 15e 184
e0 :4 187 :5 188 186
18a :5 18b :3 18a :2 18c
:5 18e :11 18f :24 190 :3 18f
:2 18d :6 18c 189 :4 e0
:3 29 :11 196 :19 197 :3 196
:5 199 :2 1f :7 1 
1e07
4
:3 0 1 :3 0 2
:a 0 84e 1 :7 0
5 :2 0 3 4
:3 0 5 :3 0 6
:3 0 3 :5 0 1
7 6 :3 0 7
:3 0 8 :3 0 9
b 0 84e 2
c :2 0 a :2 0
7 8 :3 0 f
:7 0 a :2 0 13
10 11 84c 0
9 :6 0 a :2 0
9 8 :3 0 15
:7 0 19 16 17
84c 0 b :9 0
b 8 :3 0 1b
:7 0 1f 1c 1d
84c 0 c :6 0
d :3 0 e :a 0
2 35 :4 0 21
24 0 22 :3 0
f :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
19 :4 0 1a 1
:8 0 36 21 24
37 0 84c d
37 39 36 38
:6 0 35 :7 0 37
d :3 0 1b :a 0
3 4f :5 0 3b
3e 0 3c :3 0
f :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
19 :4 0 1a 1
:8 0 50 3b 3e
51 0 84c f
51 53 50 52
:6 0 4f :7 0 51
d :3 0 1c :a 0
4 6a :5 0 55
58 0 56 :3 0
10 :3 0 11 :3 0
12 :3 0 13 :3 0
14 :3 0 13 :3 0
15 :3 0 13 :3 0
16 :3 0 13 :3 0
17 :3 0 13 :3 0
18 :3 0 1d :3 0
3 :3 0 19 :4 0
1e 1 :8 0 6b
55 58 6c 0
84c 11 6c 6e
6b 6d :6 0 6a
:7 0 6c d :3 0
1f :a 0 5 85
:5 0 70 73 0
71 :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
1d :3 0 3 :3 0
19 :4 0 20 1
:8 0 86 70 73
87 0 84c 13
87 89 86 88
:6 0 85 :7 0 87
21 :3 0 22 :3 0
8a 8b 0 21
:3 0 23 :3 0 8d
8e 0 2 :4 0
15 8f 91 8c
93 92 :2 0 24
:3 0 25 :3 0 95
96 0 26 :4 0
21 :3 0 27 :3 0
99 9a 0 2
:4 0 17 9b 9d
28 :4 0 29 :2 0
2a :3 0 19 a0
a2 :3 0 2b :4 0
29 :2 0 2c :4 0
1c a5 a7 :3 0
29 :2 0 3 :3 0
1f a9 ab :3 0
29 :2 0 2c :4 0
22 ad af :3 0
29 :2 0 2d :4 0
25 b1 b3 :3 0
28 97 b5 :2 0
b7 2d b8 94
b7 0 b9 2f
0 84a 21 :3 0
22 :3 0 ba bb
0 21 :3 0 2e
:3 0 bd be 0
2f :2 0 2 :4 0
30 :2 0 31 :2 0
2f :2 0 31 c3
c5 :3 0 34 bf
c7 bc c9 c8
:2 0 24 :3 0 32
:3 0 cb cc 0
26 :4 0 33 :4 0
29 :2 0 2a :3 0
38 d0 d2 :3 0
3b cd d4 :2 0
d6 3e d7 ca
d6 0 d8 40
0 84a 3 :3 0
34 :2 0 42 da
db :3 0 dc :2 0
35 :3 0 e :4 0
e1 :2 0 47d df
e2 :3 0 36 :3 0
e :3 0 3 :3 0
9 :4 0 e8 :2 0
303 e4 e9 :3 0
44 :3 0 e :3 0
37 :3 0 ea eb
:3 0 38 :3 0 39
:3 0 ed ee 0
a :2 0 ef f0
0 f2 47 f9
38 :3 0 39 :3 0
f3 f4 0 3a
:2 0 f5 f6 0
f8 49 fa ec
f2 0 fb 0
f8 0 fb 4b
0 303 38 :3 0
39 :3 0 fc fd
0 38 :3 0 3b
:2 0 3c :3 0 ff
101 0 50 100
103 :3 0 104 :2 0
3d :8 0 108 53
109 105 108 0
10a 55 0 303
b :3 0 3e :2 0
10b 10c 0 303
3f :3 0 40 :3 0
41 :3 0 13 :3 0
42 :3 0 b :3 0
f :3 0 3 :4 0
43 1 :8 0 12c
37 :4 0 117 :3 0
44 :3 0 45 :2 0
59 11a 11b :3 0
38 :3 0 39 :3 0
11d 11e 0 a
:2 0 11f 120 0
122 5c 129 38
:3 0 39 :3 0 123
124 0 3a :2 0
125 126 0 128
5e 12a 11c 122
0 12b 0 128
0 12b 60 0
12c 63 17f 46
:3 0 38 :3 0 39
:3 0 12e 12f 0
47 :3 0 130 131
0 133 66 135
68 134 133 :2 0
17d 48 :3 0 38
:3 0 39 :3 0 138
139 0 47 :3 0
13a 13b 0 175
21 :3 0 22 :3 0
13d 13e 0 21
:3 0 2e :3 0 140
141 0 49 :2 0
2 :4 0 4a :2 0
31 :2 0 2f :2 0
6a 146 148 :3 0
6d 142 14a 13f
14c 14b :2 0 24
:3 0 32 :3 0 14e
14f 0 26 :4 0
4b :4 0 29 :2 0
2a :3 0 71 153
155 :3 0 29 :2 0
4c :4 0 74 157
159 :3 0 29 :2 0
4d :4 0 77 15b
15d :3 0 29 :2 0
47 :3 0 7a 15f
161 :3 0 29 :2 0
4e :4 0 7d 163
165 :3 0 29 :2 0
4f :3 0 50 :3 0
2f :2 0 51 :2 0
80 168 16c 84
167 16e :3 0 87
150 170 :2 0 172
8a 173 14d 172
0 174 8c 0
175 8e 178 :3 0
178 0 178 177
175 176 :6 0 17a
7 :3 0 91 17c
93 17b 17a :2 0
17d 95 :2 0 17f
0 17f 17e 12c
17d :6 0 303 6
:3 0 b :3 0 52
:3 0 53 :3 0 182
183 0 13 :3 0
54 :3 0 185 186
0 13 :3 0 55
:3 0 188 189 0
98 184 18b 181
18c 0 303 11
:3 0 40 :3 0 13
:3 0 42 :3 0 56
:3 0 57 :3 0 58
:3 0 59 :3 0 5a
:3 0 59 :3 0 f
:3 0 3 :3 0 5b
:3 0 5c :4 0 5d
1 :8 0 1b2 37
:4 0 19d :3 0 44
:3 0 45 :2 0 9d
1a0 1a1 :3 0 38
:3 0 39 :3 0 1a3
1a4 0 a :2 0
1a5 1a6 0 1a8
a0 1af 38 :3 0
39 :3 0 1a9 1aa
0 3a :2 0 1ab
1ac 0 1ae a2
1b0 1a2 1a8 0
1b1 0 1ae 0
1b1 a4 0 1b2
a7 205 46 :3 0
38 :3 0 39 :3 0
1b4 1b5 0 47
:3 0 1b6 1b7 0
1b9 aa 1bb ac
1ba 1b9 :2 0 203
48 :3 0 38 :3 0
39 :3 0 1be 1bf
0 47 :3 0 1c0
1c1 0 1fb 21
:3 0 22 :3 0 1c3
1c4 0 21 :3 0
2e :3 0 1c6 1c7
0 49 :2 0 2
:4 0 5e :2 0 31
:2 0 2f :2 0 ae
1cc 1ce :3 0 b1
1c8 1d0 1c5 1d2
1d1 :2 0 24 :3 0
32 :3 0 1d4 1d5
0 26 :4 0 5f
:4 0 29 :2 0 2a
:3 0 b5 1d9 1db
:3 0 29 :2 0 4c
:4 0 b8 1dd 1df
:3 0 29 :2 0 4d
:4 0 bb 1e1 1e3
:3 0 29 :2 0 47
:3 0 be 1e5 1e7
:3 0 29 :2 0 4e
:4 0 c1 1e9 1eb
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 c4
1ee 1f2 c8 1ed
1f4 :3 0 cb 1d6
1f6 :2 0 1f8 ce
1f9 1d3 1f8 0
1fa d0 0 1fb
d2 1fe :3 0 1fe
0 1fe 1fd 1fb
1fc :6 0 200 9
:3 0 d5 202 d7
201 200 :2 0 203
d9 :2 0 205 0
205 204 1b2 203
:6 0 303 6 :3 0
11 :3 0 40 :3 0
b :3 0 56 :3 0
57 :3 0 f :3 0
3 :3 0 5b :3 0
5c :4 0 60 1
:8 0 226 37 :4 0
211 :3 0 44 :3 0
45 :2 0 de 214
215 :3 0 38 :3 0
39 :3 0 217 218
0 a :2 0 219
21a 0 21c e1
223 38 :3 0 39
:3 0 21d 21e 0
3a :2 0 21f 220
0 222 e3 224
216 21c 0 225
0 222 0 225
e5 0 226 e8
279 46 :3 0 38
:3 0 39 :3 0 228
229 0 47 :3 0
22a 22b 0 22d
eb 22f ed 22e
22d :2 0 277 48
:3 0 38 :3 0 39
:3 0 232 233 0
47 :3 0 234 235
0 26f 21 :3 0
22 :3 0 237 238
0 21 :3 0 2e
:3 0 23a 23b 0
49 :2 0 2 :4 0
61 :2 0 31 :2 0
2f :2 0 ef 240
242 :3 0 f2 23c
244 239 246 245
:2 0 24 :3 0 32
:3 0 248 249 0
26 :4 0 62 :4 0
29 :2 0 2a :3 0
f6 24d 24f :3 0
29 :2 0 4c :4 0
f9 251 253 :3 0
29 :2 0 4d :4 0
fc 255 257 :3 0
29 :2 0 47 :3 0
ff 259 25b :3 0
29 :2 0 4e :4 0
102 25d 25f :3 0
29 :2 0 4f :3 0
50 :3 0 2f :2 0
51 :2 0 105 262
266 109 261 268
:3 0 10c 24a 26a
:2 0 26c 10f 26d
247 26c 0 26e
111 0 26f 113
272 :3 0 272 0
272 271 26f 270
:6 0 274 b :3 0
116 276 118 275
274 :2 0 277 11a
:2 0 279 0 279
278 226 277 :6 0
303 6 :3 0 63
:3 0 40 :3 0 13
:3 0 42 :3 0 56
:3 0 57 :3 0 f
:3 0 3 :3 0 12
:4 0 64 1 :8 0
29a 37 :4 0 285
:3 0 44 :3 0 45
:2 0 11f 288 289
:3 0 38 :3 0 39
:3 0 28b 28c 0
a :2 0 28d 28e
0 290 122 297
38 :3 0 39 :3 0
291 292 0 3a
:2 0 293 294 0
296 124 298 28a
290 0 299 0
296 0 299 126
0 29a 129 2ed
46 :3 0 38 :3 0
39 :3 0 29c 29d
0 47 :3 0 29e
29f 0 2a1 12c
2a3 12e 2a2 2a1
:2 0 2eb 48 :3 0
38 :3 0 39 :3 0
2a6 2a7 0 47
:3 0 2a8 2a9 0
2e3 21 :3 0 22
:3 0 2ab 2ac 0
21 :3 0 2e :3 0
2ae 2af 0 49
:2 0 2 :4 0 65
:2 0 31 :2 0 2f
:2 0 130 2b4 2b6
:3 0 133 2b0 2b8
2ad 2ba 2b9 :2 0
24 :3 0 32 :3 0
2bc 2bd 0 26
:4 0 66 :4 0 29
:2 0 2a :3 0 137
2c1 2c3 :3 0 29
:2 0 4c :4 0 13a
2c5 2c7 :3 0 29
:2 0 4d :4 0 13d
2c9 2cb :3 0 29
:2 0 47 :3 0 140
2cd 2cf :3 0 29
:2 0 4e :4 0 143
2d1 2d3 :3 0 29
:2 0 4f :3 0 50
:3 0 2f :2 0 51
:2 0 146 2d6 2da
14a 2d5 2dc :3 0
14d 2be 2de :2 0
2e0 150 2e1 2bb
2e0 0 2e2 152
0 2e3 154 2e6
:3 0 2e6 0 2e6
2e5 2e3 2e4 :6 0
2e8 d :3 0 157
2ea 159 2e9 2e8
:2 0 2eb 15b :2 0
2ed 0 2ed 2ec
29a 2eb :6 0 303
6 :3 0 67 :3 0
9 :3 0 a :2 0
15e 2ef 2f2 45
:2 0 a :2 0 163
2f4 2f6 :3 0 c
:3 0 68 :3 0 3
:3 0 166 2f9 2fb
2f8 2fc 0 300
69 :4 0 69 1
:8 0 300 168 301
2f7 300 0 302
16b 0 303 16d
305 36 :4 0 303
:4 0 47d 6a :3 0
e :4 0 309 :2 0
30f 307 0 38
:3 0 39 :3 0 30a
30b 0 47 :3 0
30c 30d 0 30f
178 362 46 :3 0
38 :3 0 39 :3 0
311 312 0 47
:3 0 313 314 0
316 17b 318 17d
317 316 :2 0 360
48 :3 0 38 :3 0
39 :3 0 31b 31c
0 47 :3 0 31d
31e 0 358 21
:3 0 22 :3 0 320
321 0 21 :3 0
2e :3 0 323 324
0 49 :2 0 2
:4 0 6b :2 0 31
:2 0 2f :2 0 17f
329 32b :3 0 182
325 32d 322 32f
32e :2 0 24 :3 0
32 :3 0 331 332
0 26 :4 0 6c
:4 0 29 :2 0 2a
:3 0 186 336 338
:3 0 29 :2 0 4c
:4 0 189 33a 33c
:3 0 29 :2 0 4d
:4 0 18c 33e 340
:3 0 29 :2 0 47
:3 0 18f 342 344
:3 0 29 :2 0 4e
:4 0 192 346 348
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 195
34b 34f 199 34a
351 :3 0 19c 333
353 :2 0 355 19f
356 330 355 0
357 1a1 0 358
1a3 35b :3 0 35b
0 35b 35a 358
359 :6 0 35d f
:3 0 1a6 35f 1a8
35e 35d :2 0 360
1aa :2 0 362 0
362 361 30f 360
:6 0 47d 1 :3 0
35 :3 0 1b :4 0
367 :2 0 47d 365
368 :3 0 36 :3 0
1b :3 0 3 :3 0
9 :4 0 36e :2 0
41c 36a 36f :3 0
1ad :3 0 1b :3 0
37 :3 0 370 371
:3 0 38 :3 0 39
:3 0 373 374 0
a :2 0 375 376
0 378 1b0 37f
38 :3 0 39 :3 0
379 37a 0 3a
:2 0 37b 37c 0
37e 1b2 380 372
378 0 381 0
37e 0 381 1b4
0 41c 38 :3 0
39 :3 0 382 383
0 38 :3 0 3b
:2 0 3c :3 0 385
387 0 1b9 386
389 :3 0 38a :2 0
3d :8 0 38e 1bc
38f 38b 38e 0
390 1be 0 41c
11 :3 0 40 :3 0
13 :3 0 42 :3 0
58 :3 0 59 :3 0
5a :3 0 59 :3 0
f :3 0 3 :3 0
5b :3 0 5c :4 0
6d 1 :8 0 3b3
37 :4 0 39e :3 0
44 :3 0 45 :2 0
1c2 3a1 3a2 :3 0
38 :3 0 39 :3 0
3a4 3a5 0 a
:2 0 3a6 3a7 0
3a9 1c5 3b0 38
:3 0 39 :3 0 3aa
3ab 0 3a :2 0
3ac 3ad 0 3af
1c7 3b1 3a3 3a9
0 3b2 0 3af
0 3b2 1c9 0
3b3 1cc 406 46
:3 0 38 :3 0 39
:3 0 3b5 3b6 0
47 :3 0 3b7 3b8
0 3ba 1cf 3bc
1d1 3bb 3ba :2 0
404 48 :3 0 38
:3 0 39 :3 0 3bf
3c0 0 47 :3 0
3c1 3c2 0 3fc
21 :3 0 22 :3 0
3c4 3c5 0 21
:3 0 2e :3 0 3c7
3c8 0 49 :2 0
2 :4 0 6e :2 0
31 :2 0 2f :2 0
1d3 3cd 3cf :3 0
1d6 3c9 3d1 3c6
3d3 3d2 :2 0 24
:3 0 32 :3 0 3d5
3d6 0 26 :4 0
6f :4 0 29 :2 0
2a :3 0 1da 3da
3dc :3 0 29 :2 0
4c :4 0 1dd 3de
3e0 :3 0 29 :2 0
4d :4 0 1e0 3e2
3e4 :3 0 29 :2 0
47 :3 0 1e3 3e6
3e8 :3 0 29 :2 0
4e :4 0 1e6 3ea
3ec :3 0 29 :2 0
4f :3 0 50 :3 0
2f :2 0 51 :2 0
1e9 3ef 3f3 1ed
3ee 3f5 :3 0 1f0
3d7 3f7 :2 0 3f9
1f3 3fa 3d4 3f9
0 3fb 1f5 0
3fc 1f7 3ff :3 0
3ff 0 3ff 3fe
3fc 3fd :6 0 401
12 :3 0 1fa 403
1fc 402 401 :2 0
404 1fe :2 0 406
0 406 405 3b3
404 :6 0 41c 11
:3 0 67 :3 0 9
:3 0 a :2 0 201
408 40b 45 :2 0
a :2 0 206 40d
40f :3 0 c :3 0
68 :3 0 3 :3 0
209 412 414 411
415 0 419 69
:4 0 69 1 :8 0
419 20b 41a 410
419 0 41b 20e
0 41c 210 41e
36 :4 0 41c :4 0
47d 6a :3 0 1b
:4 0 422 :2 0 428
420 0 38 :3 0
39 :3 0 423 424
0 47 :3 0 425
426 0 428 216
47b 46 :3 0 38
:3 0 39 :3 0 42a
42b 0 47 :3 0
42c 42d 0 42f
219 431 21b 430
42f :2 0 479 48
:3 0 38 :3 0 39
:3 0 434 435 0
47 :3 0 436 437
0 471 21 :3 0
22 :3 0 439 43a
0 21 :3 0 2e
:3 0 43c 43d 0
49 :2 0 2 :4 0
70 :2 0 31 :2 0
2f :2 0 21d 442
444 :3 0 220 43e
446 43b 448 447
:2 0 24 :3 0 32
:3 0 44a 44b 0
26 :4 0 71 :4 0
29 :2 0 2a :3 0
224 44f 451 :3 0
29 :2 0 4c :4 0
227 453 455 :3 0
29 :2 0 4d :4 0
22a 457 459 :3 0
29 :2 0 47 :3 0
22d 45b 45d :3 0
29 :2 0 4e :4 0
230 45f 461 :3 0
29 :2 0 4f :3 0
50 :3 0 2f :2 0
51 :2 0 233 464
468 237 463 46a
:3 0 23a 44c 46c
:2 0 46e 23d 46f
449 46e 0 470
23f 0 471 241
474 :3 0 474 0
474 473 471 472
:6 0 476 14 :3 0
244 478 246 477
476 :2 0 479 248
:2 0 47b 0 47b
47a 428 479 :6 0
47d 1 :3 0 24b
815 35 :3 0 1c
:4 0 481 :2 0 814
47f 482 :3 0 36
:3 0 1c :3 0 9
:4 0 487 :2 0 69c
484 485 :3 0 1c
:3 0 37 :3 0 488
489 :3 0 38 :3 0
39 :3 0 48b 48c
0 a :2 0 48d
48e 0 490 252
497 38 :3 0 39
:3 0 491 492 0
3a :2 0 493 494
0 496 254 498
48a 490 0 499
0 496 0 499
256 0 69c 38
:3 0 39 :3 0 49a
49b 0 38 :3 0
3b :2 0 3c :3 0
49d 49f 0 25b
49e 4a1 :3 0 4a2
:2 0 3d :8 0 4a6
25e 4a7 4a3 4a6
0 4a8 260 0
69c b :3 0 52
:3 0 53 :3 0 4aa
4ab 0 13 :3 0
54 :3 0 4ad 4ae
0 13 :3 0 55
:3 0 4b0 4b1 0
262 4ac 4b3 4a9
4b4 0 69c 3f
:3 0 40 :3 0 13
:3 0 42 :3 0 f
:3 0 3 :4 0 72
1 :8 0 4d2 37
:4 0 4bd :3 0 44
:3 0 45 :2 0 267
4c0 4c1 :3 0 38
:3 0 39 :3 0 4c3
4c4 0 a :2 0
4c5 4c6 0 4c8
26a 4cf 38 :3 0
39 :3 0 4c9 4ca
0 3a :2 0 4cb
4cc 0 4ce 26c
4d0 4c2 4c8 0
4d1 0 4ce 0
4d1 26e 0 4d2
271 525 46 :3 0
38 :3 0 39 :3 0
4d4 4d5 0 47
:3 0 4d6 4d7 0
4d9 274 4db 276
4da 4d9 :2 0 523
48 :3 0 38 :3 0
39 :3 0 4de 4df
0 47 :3 0 4e0
4e1 0 51b 21
:3 0 22 :3 0 4e3
4e4 0 21 :3 0
2e :3 0 4e6 4e7
0 49 :2 0 2
:4 0 73 :2 0 31
:2 0 2f :2 0 278
4ec 4ee :3 0 27b
4e8 4f0 4e5 4f2
4f1 :2 0 24 :3 0
32 :3 0 4f4 4f5
0 26 :4 0 74
:4 0 29 :2 0 2a
:3 0 27f 4f9 4fb
:3 0 29 :2 0 4c
:4 0 282 4fd 4ff
:3 0 29 :2 0 4d
:4 0 285 501 503
:3 0 29 :2 0 47
:3 0 288 505 507
:3 0 29 :2 0 4e
:4 0 28b 509 50b
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 28e
50e 512 292 50d
514 :3 0 295 4f6
516 :2 0 518 298
519 4f3 518 0
51a 29a 0 51b
29c 51e :3 0 51e
0 51e 51d 51b
51c :6 0 520 17
:3 0 29f 522 2a1
521 520 :2 0 523
2a3 :2 0 525 0
525 524 4d2 523
:6 0 69c 16 :3 0
11 :3 0 40 :3 0
13 :3 0 42 :3 0
56 :3 0 57 :3 0
58 :3 0 59 :3 0
5a :3 0 59 :3 0
f :3 0 3 :3 0
5b :3 0 5c :4 0
5d 1 :8 0 54b
37 :4 0 536 :3 0
44 :3 0 45 :2 0
2a8 539 53a :3 0
38 :3 0 39 :3 0
53c 53d 0 a
:2 0 53e 53f 0
541 2ab 548 38
:3 0 39 :3 0 542
543 0 3a :2 0
544 545 0 547
2ad 549 53b 541
0 54a 0 547
0 54a 2af 0
54b 2b2 59e 46
:3 0 38 :3 0 39
:3 0 54d 54e 0
47 :3 0 54f 550
0 552 2b5 554
2b7 553 552 :2 0
59c 48 :3 0 38
:3 0 39 :3 0 557
558 0 47 :3 0
559 55a 0 594
21 :3 0 22 :3 0
55c 55d 0 21
:3 0 2e :3 0 55f
560 0 49 :2 0
2 :4 0 75 :2 0
31 :2 0 2f :2 0
2b9 565 567 :3 0
2bc 561 569 55e
56b 56a :2 0 24
:3 0 32 :3 0 56d
56e 0 26 :4 0
76 :4 0 29 :2 0
2a :3 0 2c0 572
574 :3 0 29 :2 0
4c :4 0 2c3 576
578 :3 0 29 :2 0
4d :4 0 2c6 57a
57c :3 0 29 :2 0
47 :3 0 2c9 57e
580 :3 0 29 :2 0
4e :4 0 2cc 582
584 :3 0 29 :2 0
4f :3 0 50 :3 0
2f :2 0 51 :2 0
2cf 587 58b 2d3
586 58d :3 0 2d6
56f 58f :2 0 591
2d9 592 56c 591
0 593 2db 0
594 2dd 597 :3 0
597 0 597 596
594 595 :6 0 599
19 :3 0 2e0 59b
2e2 59a 599 :2 0
59c 2e4 :2 0 59e
0 59e 59d 54b
59c :6 0 69c 16
:3 0 11 :3 0 40
:3 0 b :3 0 56
:3 0 57 :3 0 f
:3 0 3 :3 0 5b
:3 0 5c :4 0 60
1 :8 0 5bf 37
:4 0 5aa :3 0 44
:3 0 45 :2 0 2e9
5ad 5ae :3 0 38
:3 0 39 :3 0 5b0
5b1 0 a :2 0
5b2 5b3 0 5b5
2ec 5bc 38 :3 0
39 :3 0 5b6 5b7
0 3a :2 0 5b8
5b9 0 5bb 2ee
5bd 5af 5b5 0
5be 0 5bb 0
5be 2f0 0 5bf
2f3 612 46 :3 0
38 :3 0 39 :3 0
5c1 5c2 0 47
:3 0 5c3 5c4 0
5c6 2f6 5c8 2f8
5c7 5c6 :2 0 610
48 :3 0 38 :3 0
39 :3 0 5cb 5cc
0 47 :3 0 5cd
5ce 0 608 21
:3 0 22 :3 0 5d0
5d1 0 21 :3 0
2e :3 0 5d3 5d4
0 49 :2 0 2
:4 0 77 :2 0 31
:2 0 2f :2 0 2fa
5d9 5db :3 0 2fd
5d5 5dd 5d2 5df
5de :2 0 24 :3 0
32 :3 0 5e1 5e2
0 26 :4 0 78
:4 0 29 :2 0 2a
:3 0 301 5e6 5e8
:3 0 29 :2 0 4c
:4 0 304 5ea 5ec
:3 0 29 :2 0 4d
:4 0 307 5ee 5f0
:3 0 29 :2 0 47
:3 0 30a 5f2 5f4
:3 0 29 :2 0 4e
:4 0 30d 5f6 5f8
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 310
5fb 5ff 314 5fa
601 :3 0 317 5e3
603 :2 0 605 31a
606 5e0 605 0
607 31c 0 608
31e 60b :3 0 60b
0 60b 60a 608
609 :6 0 60d 1b
:3 0 321 60f 323
60e 60d :2 0 610
325 :2 0 612 0
612 611 5bf 610
:6 0 69c 16 :3 0
63 :3 0 40 :3 0
13 :3 0 42 :3 0
56 :3 0 57 :3 0
f :3 0 3 :3 0
12 :4 0 64 1
:8 0 633 37 :4 0
61e :3 0 44 :3 0
45 :2 0 32a 621
622 :3 0 38 :3 0
39 :3 0 624 625
0 a :2 0 626
627 0 629 32d
630 38 :3 0 39
:3 0 62a 62b 0
3a :2 0 62c 62d
0 62f 32f 631
623 629 0 632
0 62f 0 632
331 0 633 334
686 46 :3 0 38
:3 0 39 :3 0 635
636 0 47 :3 0
637 638 0 63a
337 63c 339 63b
63a :2 0 684 48
:3 0 38 :3 0 39
:3 0 63f 640 0
47 :3 0 641 642
0 67c 21 :3 0
22 :3 0 644 645
0 21 :3 0 2e
:3 0 647 648 0
49 :2 0 2 :4 0
79 :2 0 31 :2 0
2f :2 0 33b 64d
64f :3 0 33e 649
651 646 653 652
:2 0 24 :3 0 32
:3 0 655 656 0
26 :4 0 7a :4 0
29 :2 0 2a :3 0
342 65a 65c :3 0
29 :2 0 4c :4 0
345 65e 660 :3 0
29 :2 0 4d :4 0
348 662 664 :3 0
29 :2 0 47 :3 0
34b 666 668 :3 0
29 :2 0 4e :4 0
34e 66a 66c :3 0
29 :2 0 4f :3 0
50 :3 0 2f :2 0
51 :2 0 351 66f
673 355 66e 675
:3 0 358 657 677
:2 0 679 35b 67a
654 679 0 67b
35d 0 67c 35f
67f :3 0 67f 0
67f 67e 67c 67d
:6 0 681 1d :3 0
362 683 364 682
681 :2 0 684 366
:2 0 686 0 686
685 633 684 :6 0
69c 16 :3 0 67
:3 0 9 :3 0 a
:2 0 369 688 68b
45 :2 0 a :2 0
36e 68d 68f :3 0
c :3 0 68 :3 0
3 :3 0 371 692
694 691 695 0
699 69 :4 0 69
1 :8 0 699 373
69a 690 699 0
69b 376 0 69c
378 69e 36 :4 0
69c :4 0 814 6a
:3 0 1c :4 0 6a2
:2 0 6a8 6a0 0
38 :3 0 39 :3 0
6a3 6a4 0 47
:3 0 6a5 6a6 0
6a8 382 6fb 46
:3 0 38 :3 0 39
:3 0 6aa 6ab 0
47 :3 0 6ac 6ad
0 6af 385 6b1
387 6b0 6af :2 0
6f9 48 :3 0 38
:3 0 39 :3 0 6b4
6b5 0 47 :3 0
6b6 6b7 0 6f1
21 :3 0 22 :3 0
6b9 6ba 0 21
:3 0 2e :3 0 6bc
6bd 0 49 :2 0
2 :4 0 7b :2 0
31 :2 0 2f :2 0
389 6c2 6c4 :3 0
38c 6be 6c6 6bb
6c8 6c7 :2 0 24
:3 0 32 :3 0 6ca
6cb 0 26 :4 0
7c :4 0 29 :2 0
2a :3 0 390 6cf
6d1 :3 0 29 :2 0
4c :4 0 393 6d3
6d5 :3 0 29 :2 0
4d :4 0 396 6d7
6d9 :3 0 29 :2 0
47 :3 0 399 6db
6dd :3 0 29 :2 0
4e :4 0 39c 6df
6e1 :3 0 29 :2 0
4f :3 0 50 :3 0
2f :2 0 51 :2 0
39f 6e4 6e8 3a3
6e3 6ea :3 0 3a6
6cc 6ec :2 0 6ee
3a9 6ef 6c9 6ee
0 6f0 3ab 0
6f1 3ad 6f4 :3 0
6f4 0 6f4 6f3
6f1 6f2 :6 0 6f6
1f :3 0 3b0 6f8
3b2 6f7 6f6 :2 0
6f9 3b4 :2 0 6fb
0 6fb 6fa 6a8
6f9 :6 0 814 1
:3 0 35 :3 0 1f
:4 0 700 :2 0 814
6fe 701 :3 0 36
:3 0 1f :3 0 9
:4 0 706 :2 0 7b3
703 704 :3 0 1f
:3 0 37 :3 0 707
708 :3 0 38 :3 0
39 :3 0 70a 70b
0 a :2 0 70c
70d 0 70f 3b7
716 38 :3 0 39
:3 0 710 711 0
3a :2 0 712 713
0 715 3b9 717
709 70f 0 718
0 715 0 718
3bb 0 7b3 38
:3 0 39 :3 0 719
71a 0 38 :3 0
3b :2 0 3c :3 0
71c 71e 0 3c0
71d 720 :3 0 721
:2 0 3d :8 0 725
3c3 726 722 725
0 727 3c5 0
7b3 11 :3 0 40
:3 0 13 :3 0 42
:3 0 58 :3 0 59
:3 0 5a :3 0 59
:3 0 f :3 0 3
:3 0 5b :3 0 5c
:4 0 6d 1 :8 0
74a 37 :4 0 735
:3 0 44 :3 0 45
:2 0 3c9 738 739
:3 0 38 :3 0 39
:3 0 73b 73c 0
a :2 0 73d 73e
0 740 3cc 747
38 :3 0 39 :3 0
741 742 0 3a
:2 0 743 744 0
746 3ce 748 73a
740 0 749 0
746 0 749 3d0
0 74a 3d3 79d
46 :3 0 38 :3 0
39 :3 0 74c 74d
0 47 :3 0 74e
74f 0 751 3d6
753 3d8 752 751
:2 0 79b 48 :3 0
38 :3 0 39 :3 0
756 757 0 47
:3 0 758 759 0
793 21 :3 0 22
:3 0 75b 75c 0
21 :3 0 2e :3 0
75e 75f 0 49
:2 0 2 :4 0 7d
:2 0 31 :2 0 2f
:2 0 3da 764 766
:3 0 3dd 760 768
75d 76a 769 :2 0
24 :3 0 32 :3 0
76c 76d 0 26
:4 0 7e :4 0 29
:2 0 2a :3 0 3e1
771 773 :3 0 29
:2 0 4c :4 0 3e4
775 777 :3 0 29
:2 0 4d :4 0 3e7
779 77b :3 0 29
:2 0 47 :3 0 3ea
77d 77f :3 0 29
:2 0 4e :4 0 3ed
781 783 :3 0 29
:2 0 4f :3 0 50
:3 0 2f :2 0 51
:2 0 3f0 786 78a
3f4 785 78c :3 0
3f7 76e 78e :2 0
790 3fa 791 76b
790 0 792 3fc
0 793 3fe 796
:3 0 796 0 796
795 793 794 :6 0
798 22 :3 0 401
79a 403 799 798
:2 0 79b 405 :2 0
79d 0 79d 79c
74a 79b :6 0 7b3
21 :3 0 67 :3 0
9 :3 0 a :2 0
408 79f 7a2 45
:2 0 a :2 0 40d
7a4 7a6 :3 0 c
:3 0 68 :3 0 3
:3 0 410 7a9 7ab
7a8 7ac 0 7b0
69 :4 0 69 1
:8 0 7b0 412 7b1
7a7 7b0 0 7b2
415 0 7b3 417
7b5 36 :4 0 7b3
:4 0 814 6a :3 0
1f :4 0 7b9 :2 0
7bf 7b7 0 38
:3 0 39 :3 0 7ba
7bb 0 47 :3 0
7bc 7bd 0 7bf
41d 812 46 :3 0
38 :3 0 39 :3 0
7c1 7c2 0 47
:3 0 7c3 7c4 0
7c6 420 7c8 422
7c7 7c6 :2 0 810
48 :3 0 38 :3 0
39 :3 0 7cb 7cc
0 47 :3 0 7cd
7ce 0 808 21
:3 0 22 :3 0 7d0
7d1 0 21 :3 0
2e :3 0 7d3 7d4
0 49 :2 0 2
:4 0 7f :2 0 31
:2 0 2f :2 0 424
7d9 7db :3 0 427
7d5 7dd 7d2 7df
7de :2 0 24 :3 0
32 :3 0 7e1 7e2
0 26 :4 0 80
:4 0 29 :2 0 2a
:3 0 42b 7e6 7e8
:3 0 29 :2 0 4c
:4 0 42e 7ea 7ec
:3 0 29 :2 0 4d
:4 0 431 7ee 7f0
:3 0 29 :2 0 47
:3 0 434 7f2 7f4
:3 0 29 :2 0 4e
:4 0 437 7f6 7f8
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 43a
7fb 7ff 43e 7fa
801 :3 0 441 7e3
803 :2 0 805 444
806 7e0 805 0
807 446 0 808
448 80b :3 0 80b
0 80b 80a 808
809 :6 0 80d 24
:3 0 44b 80f 44d
80e 80d :2 0 810
44f :2 0 812 0
812 811 7bf 810
:6 0 814 1 :3 0
452 816 dd 47d
0 817 0 814
0 817 459 0
84a 21 :3 0 22
:3 0 818 819 0
21 :3 0 2e :3 0
81b 81c 0 2f
:2 0 2 :4 0 81
:2 0 31 :2 0 2f
:2 0 45c 821 823
:3 0 45f 81d 825
81a 827 826 :2 0
24 :3 0 32 :3 0
829 82a 0 26
:4 0 82 :4 0 29
:2 0 2a :3 0 463
82e 830 :3 0 29
:2 0 4c :4 0 466
832 834 :3 0 29
:2 0 83 :4 0 469
836 838 :3 0 29
:2 0 38 :3 0 39
:3 0 83b 83c 0
46c 83a 83e :3 0
46f 82b 840 :2 0
842 472 843 828
842 0 844 474
0 84a 7 :3 0
38 :3 0 39 :3 0
846 847 0 848
:2 0 84a 476 84d
:3 0 84d 47c 84d
84c 84a 84b :6 0
84e :2 0 2 c
84d 851 :3 0 850
84e 852 :8 0 
484
4
:3 0 1 3 1
8 1 e 1
14 1 1a 1
34 1 4e 1
69 1 84 1
90 1 9c 2
9f a1 2 a4
a6 2 a8 aa
2 ac ae 2
b0 b2 4 98
9e a3 b4 1
b6 1 b8 2
c2 c4 3 c0
c1 c6 2 cf
d1 2 ce d3
1 d5 1 d7
1 d9 2 e5
e6 1 f1 1
f7 2 f9 fa
1 102 2 fe
102 1 107 1
109 1 119 2
118 119 1 121
1 127 2 129
12a 2 116 12b
1 132 1 12d
2 145 147 3
143 144 149 2
152 154 2 156
158 2 15a 15c
2 15e 160 2
162 164 3 169
16a 16b 2 166
16d 2 151 16f
1 171 1 173
2 13c 174 1
178 1 137 2
135 17c 2 187
18a 1 19f 2
19e 19f 1 1a7
1 1ad 2 1af
1b0 2 19c 1b1
1 1b8 1 1b3
2 1cb 1cd 3
1c9 1ca 1cf 2
1d8 1da 2 1dc
1de 2 1e0 1e2
2 1e4 1e6 2
1e8 1ea 3 1ef
1f0 1f1 2 1ec
1f3 2 1d7 1f5
1 1f7 1 1f9
2 1c2 1fa 1
1fe 1 1bd 2
1bb 202 1 213
2 212 213 1
21b 1 221 2
223 224 2 210
225 1 22c 1
227 2 23f 241
3 23d 23e 243
2 24c 24e 2
250 252 2 254
256 2 258 25a
2 25c 25e 3
263 264 265 2
260 267 2 24b
269 1 26b 1
26d 2 236 26e
1 272 1 231
2 22f 276 1
287 2 286 287
1 28f 1 295
2 297 298 2
284 299 1 2a0
1 29b 2 2b3
2b5 3 2b1 2b2
2b7 2 2c0 2c2
2 2c4 2c6 2
2c8 2ca 2 2cc
2ce 2 2d0 2d2
3 2d7 2d8 2d9
2 2d4 2db 2
2bf 2dd 1 2df
1 2e1 2 2aa
2e2 1 2e6 1
2a5 2 2a3 2ea
2 2f0 2f1 1
2f5 2 2f3 2f5
1 2fa 2 2fd
2ff 1 301 a
e7 fb 10a 10d
17f 18d 205 279
2ed 302 2 308
30e 1 315 1
310 2 328 32a
3 326 327 32c
2 335 337 2
339 33b 2 33d
33f 2 341 343
2 345 347 3
34c 34d 34e 2
349 350 2 334
352 1 354 1
356 2 31f 357
1 35b 1 31a
2 318 35f 2
36b 36c 1 377
1 37d 2 37f
380 1 388 2
384 388 1 38d
1 38f 1 3a0
2 39f 3a0 1
3a8 1 3ae 2
3b0 3b1 2 39d
3b2 1 3b9 1
3b4 2 3cc 3ce
3 3ca 3cb 3d0
2 3d9 3db 2
3dd 3df 2 3e1
3e3 2 3e5 3e7
2 3e9 3eb 3
3f0 3f1 3f2 2
3ed 3f4 2 3d8
3f6 1 3f8 1
3fa 2 3c3 3fb
1 3ff 1 3be
2 3bc 403 2
409 40a 1 40e
2 40c 40e 1
413 2 416 418
1 41a 5 36d
381 390 406 41b
2 421 427 1
42e 1 429 2
441 443 3 43f
440 445 2 44e
450 2 452 454
2 456 458 2
45a 45c 2 45e
460 3 465 466
467 2 462 469
2 44d 46b 1
46d 1 46f 2
438 470 1 474
1 433 2 431
478 6 e0 305
362 366 41e 47b
1 48f 1 495
2 497 498 1
4a0 2 49c 4a0
1 4a5 1 4a7
2 4af 4b2 1
4bf 2 4be 4bf
1 4c7 1 4cd
2 4cf 4d0 2
4bc 4d1 1 4d8
1 4d3 2 4eb
4ed 3 4e9 4ea
4ef 2 4f8 4fa
2 4fc 4fe 2
500 502 2 504
506 2 508 50a
3 50f 510 511
2 50c 513 2
4f7 515 1 517
1 519 2 4e2
51a 1 51e 1
4dd 2 4db 522
1 538 2 537
538 1 540 1
546 2 548 549
2 535 54a 1
551 1 54c 2
564 566 3 562
563 568 2 571
573 2 575 577
2 579 57b 2
57d 57f 2 581
583 3 588 589
58a 2 585 58c
2 570 58e 1
590 1 592 2
55b 593 1 597
1 556 2 554
59b 1 5ac 2
5ab 5ac 1 5b4
1 5ba 2 5bc
5bd 2 5a9 5be
1 5c5 1 5c0
2 5d8 5da 3
5d6 5d7 5dc 2
5e5 5e7 2 5e9
5eb 2 5ed 5ef
2 5f1 5f3 2
5f5 5f7 3 5fc
5fd 5fe 2 5f9
600 2 5e4 602
1 604 1 606
2 5cf 607 1
60b 1 5ca 2
5c8 60f 1 620
2 61f 620 1
628 1 62e 2
630 631 2 61d
632 1 639 1
634 2 64c 64e
3 64a 64b 650
2 659 65b 2
65d 65f 2 661
663 2 665 667
2 669 66b 3
670 671 672 2
66d 674 2 658
676 1 678 1
67a 2 643 67b
1 67f 1 63e
2 63c 683 2
689 68a 1 68e
2 68c 68e 1
693 2 696 698
1 69a 9 486
499 4a8 4b5 525
59e 612 686 69b
2 6a1 6a7 1
6ae 1 6a9 2
6c1 6c3 3 6bf
6c0 6c5 2 6ce
6d0 2 6d2 6d4
2 6d6 6d8 2
6da 6dc 2 6de
6e0 3 6e5 6e6
6e7 2 6e2 6e9
2 6cd 6eb 1
6ed 1 6ef 2
6b8 6f0 1 6f4
1 6b3 2 6b1
6f8 1 70e 1
714 2 716 717
1 71f 2 71b
71f 1 724 1
726 1 737 2
736 737 1 73f
1 745 2 747
748 2 734 749
1 750 1 74b
2 763 765 3
761 762 767 2
770 772 2 774
776 2 778 77a
2 77c 77e 2
780 782 3 787
788 789 2 784
78b 2 76f 78d
1 78f 1 791
2 75a 792 1
796 1 755 2
753 79a 2 7a0
7a1 1 7a5 2
7a3 7a5 1 7aa
2 7ad 7af 1
7b1 5 705 718
727 79d 7b2 2
7b8 7be 1 7c5
1 7c0 2 7d8
7da 3 7d6 7d7
7dc 2 7e5 7e7
2 7e9 7eb 2
7ed 7ef 2 7f1
7f3 2 7f5 7f7
3 7fc 7fd 7fe
2 7f9 800 2
7e4 802 1 804
1 806 2 7cf
807 1 80b 1
7ca 2 7c8 80f
6 480 69e 6fb
6ff 7b5 812 2
815 816 2 820
822 3 81e 81f
824 2 82d 82f
2 831 833 2
835 837 2 839
83d 2 82c 83f
1 841 1 843
5 b9 d8 817
844 849 7 12
18 1e 35 4f
6a 85 
1
4
0 
851
0
1
28
25
9
0 1 1 1 1 1 6 7
6 9 6 b 6 d 1 f
1 11 12 1 14 1 16 17
16 19 16 1b 16 1d 1 1f
1 21 22 1 24 0 0 0

21 1 2
3b 1 3
55 1 4
70 1 5
1a 1 0
14 1 0
2 0 1
e 1 0
3 1 0
0

/
SHOW ERRORS FUNCTION FC_MIGRATION;
ALTER FUNCTION FC_MIGRATION COMPILE DEBUG;
